/* Generated by Cython 3.0.11 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "giacpy/giacpymisc.h"
        ],
        "include_dirs": [
            "giacpy",
            "."
        ],
        "language": "c++",
        "libraries": [
            "giac"
        ],
        "name": "giacpy.giacpy",
        "sources": [
            "giacpy/giacpy.pyx"
        ]
    },
    "module_name": "giacpy.giacpy"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_11" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x03000BF0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 0
  #endif
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef __cplusplus
  #error "Cython files generated with the C++ option must be compiled with a C++ compiler."
#endif
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #else
    #define CYTHON_INLINE inline
  #endif
#endif
template<typename T>
void __Pyx_call_destructor(T& x) {
    x.~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(const T& ref) : ptr(const_cast<T*>(&ref)) { }
    T *operator->() { return ptr; }
    T *operator&() { return ptr; }
    operator T&() { return *ptr; }
    template<typename U> bool operator ==(const U& other) const { return *ptr == other; }
    template<typename U> bool operator !=(const U& other) const { return *ptr != other; }
    template<typename U> bool operator==(const __Pyx_FakeReference<U>& other) const { return *ptr == *other.ptr; }
    template<typename U> bool operator!=(const __Pyx_FakeReference<U>& other) const { return *ptr != *other.ptr; }
  private:
    T *ptr;
};

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__;  (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
    #define __PYX_EXTERN_C extern "C++"
#endif

#define __PYX_HAVE__giacpy__giacpy
#define __PYX_HAVE_API__giacpy__giacpy
/* Early includes */
#include <string.h>
#include <string>
#include "ios"
#include "new"
#include "stdexcept"
#include "typeinfo"
#include "giac/giac.h"
#include "giacpymisc.h"
#include <stdio.h>
#include <signal.h>
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "giacpy/giacpy.pyx",
  "<stringsource>",
  "giacpy/auto-methods.pxi",
  "type.pxd",
  "giacpy/interrupt.pxi",
  "giacpy/keywords.pxi",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base;
struct __pyx_obj_6giacpy_6giacpy_Pygen;
struct __pyx_obj_6giacpy_6giacpy_GiacSetting;
struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__;

/* "libc/signal.pxd":3
 * # 7.14 Signal handling <signal.h>
 * 
 * ctypedef void (*sighandler_t)(int SIGNUM) noexcept nogil             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "<signal.h>" nogil:
 */
typedef void (*__pyx_t_4libc_6signal_sighandler_t)(int);

/* "giacpy/giacpy.pxd":208
 * 
 * # We put some C++ declaration of here to let them be available from other cython modules.
 * cdef class GiacMethods_base:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base {
  PyObject_HEAD
};


/* "giacpy/giacpy.pxd":211
 *     pass
 * 
 * cdef class Pygen(GiacMethods_base):             # <<<<<<<<<<<<<<
 *     cdef gen * gptr # a pointer toward the corresponding c++ element of type giac::gen
 * 
 */
struct __pyx_obj_6giacpy_6giacpy_Pygen {
  struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base __pyx_base;
  giac::gen *gptr;
};


/* "giacpy/giacpy.pyx":508
 * # A class to adjust giac configuration
 * #######################################
 * cdef class GiacSetting(Pygen):             # <<<<<<<<<<<<<<
 *      """
 *      A class to customise the Computer Algebra  System settings
 */
struct __pyx_obj_6giacpy_6giacpy_GiacSetting {
  struct __pyx_obj_6giacpy_6giacpy_Pygen __pyx_base;
};


/* "giacpy/giacpy.pyx":1035
 * 
 * 
 *      def __iter__(self):             # <<<<<<<<<<<<<<
 *        """
 *          Pygen lists of 10**6 elements should be yield
 */
struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ {
  PyObject_HEAD
  int __pyx_v_i;
  struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self;
  Py_ssize_t __pyx_t_0;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
};

/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* MoveIfSupported.proto */
#if CYTHON_USE_CPP_STD_MOVE
  #include <utility>
  #define __PYX_STD_MOVE_IF_SUPPORTED(x) std::move(x)
#else
  #define __PYX_STD_MOVE_IF_SUPPORTED(x) x
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* pybytes_as_double.proto */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj);
static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length);
static CYTHON_INLINE double __Pyx_PyBytes_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
    as_c_string = PyBytes_AS_STRING(obj);
    size = PyBytes_GET_SIZE(obj);
#else
    if (PyBytes_AsStringAndSize(obj, &as_c_string, &size) < 0) {
        return (double)-1;
    }
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}
static CYTHON_INLINE double __Pyx_PyByteArray_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
    as_c_string = PyByteArray_AS_STRING(obj);
    size = PyByteArray_GET_SIZE(obj);
#else
    as_c_string = PyByteArray_AsString(obj);
    if (as_c_string == NULL) {
        return (double)-1;
    }
    size = PyByteArray_Size(obj);
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}

/* pyunicode_as_double.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
static const char* __Pyx__PyUnicode_AsDouble_Copy(const void* data, const int kind, char* buffer, Py_ssize_t start, Py_ssize_t end) {
    int last_was_punctuation;
    Py_ssize_t i;
    last_was_punctuation = 1;
    for (i=start; i <= end; i++) {
        Py_UCS4 chr = PyUnicode_READ(kind, data, i);
        int is_punctuation = (chr == '_') | (chr == '.');
        *buffer = (char)chr;
        buffer += (chr != '_');
        if (unlikely(chr > 127)) goto parse_failure;
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyUnicode_AsDouble_inf_nan(const void* data, int kind, Py_ssize_t start, Py_ssize_t length) {
    int matches = 1;
    Py_UCS4 chr;
    Py_UCS4 sign = PyUnicode_READ(kind, data, start);
    int is_signed = (sign == '-') | (sign == '+');
    start += is_signed;
    length -= is_signed;
    switch (PyUnicode_READ(kind, data, start)) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'a') | (chr == 'A');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'n') | (chr == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'f') | (chr == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+3);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+4);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+5);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+6);
            matches &= (chr == 't') | (chr == 'T');
            chr = PyUnicode_READ(kind, data, start+7);
            matches &= (chr == 'y') | (chr == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static double __Pyx_PyUnicode_AsDouble_WithSpaces(PyObject *obj) {
    double value;
    const char *last;
    char *end;
    Py_ssize_t start, length = PyUnicode_GET_LENGTH(obj);
    const int kind = PyUnicode_KIND(obj);
    const void* data = PyUnicode_DATA(obj);
    start = 0;
    while (Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, start)))
        start++;
    while (start < length - 1 && Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, length - 1)))
        length--;
    length -= start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyUnicode_AsDouble_inf_nan(data, kind, start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    if (length < 40) {
        char number[40];
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((length + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}
#endif
static CYTHON_INLINE double __Pyx_PyUnicode_AsDouble(PyObject *obj) {
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(__Pyx_PyUnicode_READY(obj) == -1))
        return (double)-1;
    if (likely(PyUnicode_IS_ASCII(obj))) {
        const char *s;
        Py_ssize_t length;
        s = PyUnicode_AsUTF8AndSize(obj, &length);
        return __Pyx__PyBytes_AsDouble(obj, s, length);
    }
    return __Pyx_PyUnicode_AsDouble_WithSpaces(obj);
#else
    return __Pyx_SlowPyString_AsDouble(obj);
#endif
}

/* pynumber_float.proto */
static CYTHON_INLINE PyObject* __Pyx__PyNumber_Float(PyObject* obj);
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : __Pyx__PyNumber_Float(x))

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_FloorDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceFloorDivide(op1, op2) : PyNumber_FloorDivide(op1, op2))
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right)
    #endif
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_ConcatInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_ConcatInPlaceSafe(left, right) ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_ConcatInPlace(left, right))

/* StrConcatInPlace.proto */
#if PY_MAJOR_VERSION >= 3
    #define __Pyx_PyStr_Concat __Pyx_PyUnicode_Concat
    #define __Pyx_PyStr_ConcatInPlace __Pyx_PyUnicode_ConcatInPlace
#else
    #define __Pyx_PyStr_Concat PyNumber_Add
    #define __Pyx_PyStr_ConcatInPlace PyNumber_InPlaceAdd
#endif
#define __Pyx_PyStr_ConcatSafe(a, b) ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
    PyNumber_Add(a, b) : __Pyx_PyStr_Concat(a, b))
#define __Pyx_PyStr_ConcatInPlaceSafe(a, b) ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
    PyNumber_InPlaceAdd(a, b) : __Pyx_PyStr_ConcatInPlace(a, b))

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_11
#define __PYX_HAVE_RT_ImportType_proto_3_0_11
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_11(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_11(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_11 {
   __Pyx_ImportType_CheckSize_Error_3_0_11 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_11 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_11 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_11(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_11 check_size);
#endif

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CppExceptionConversion.proto */
#ifndef __Pyx_CppExn2PyErr
#include <new>
#include <typeinfo>
#include <stdexcept>
#include <ios>
static void __Pyx_CppExn2PyErr() {
  try {
    if (PyErr_Occurred())
      ; // let the latest Python exn pass through and ignore the current one
    else
      throw;
  } catch (const std::bad_alloc& exn) {
    PyErr_SetString(PyExc_MemoryError, exn.what());
  } catch (const std::bad_cast& exn) {
    PyErr_SetString(PyExc_TypeError, exn.what());
  } catch (const std::bad_typeid& exn) {
    PyErr_SetString(PyExc_TypeError, exn.what());
  } catch (const std::domain_error& exn) {
    PyErr_SetString(PyExc_ValueError, exn.what());
  } catch (const std::invalid_argument& exn) {
    PyErr_SetString(PyExc_ValueError, exn.what());
  } catch (const std::ios_base::failure& exn) {
    PyErr_SetString(PyExc_IOError, exn.what());
  } catch (const std::out_of_range& exn) {
    PyErr_SetString(PyExc_IndexError, exn.what());
  } catch (const std::overflow_error& exn) {
    PyErr_SetString(PyExc_OverflowError, exn.what());
  } catch (const std::range_error& exn) {
    PyErr_SetString(PyExc_ArithmeticError, exn.what());
  } catch (const std::underflow_error& exn) {
    PyErr_SetString(PyExc_ArithmeticError, exn.what());
  } catch (const std::exception& exn) {
    PyErr_SetString(PyExc_RuntimeError, exn.what());
  }
  catch (...)
  {
    PyErr_SetString(PyExc_RuntimeError, "Unknown exception");
  }
}
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE short __Pyx_PyInt_As_short(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_char(unsigned char value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_signed_char(signed char value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */

/* Module declarations from "libc.string" */

/* Module declarations from "libcpp.string" */

/* Module declarations from "giacpy" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.exc" */

/* Module declarations from "libc.signal" */

/* Module declarations from "giacpy.giacpy" */
static giac::context *__pyx_v_6giacpy_6giacpy_context_ptr;
static CYTHON_INLINE PyObject *__pyx_f_6giacpy_6giacpy__wrap_gen(giac::gen); /*proto*/
static giac::vecteur __pyx_f_6giacpy_6giacpy__wrap_pylist(PyObject *); /*proto*/
static giac::vecteur __pyx_f_6giacpy_6giacpy__getgiacslice(struct __pyx_obj_6giacpy_6giacpy_Pygen *, PyObject *); /*proto*/
static giac::gen __pyx_f_6giacpy_6giacpy_pylongtogen(PyObject *); /*proto*/
static PyObject *__pyx_f_6giacpy_6giacpy___pyx_unpickle_GiacMethods_base__set_state(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *, PyObject *); /*proto*/
static std::string __pyx_convert_string_from_py_6libcpp_6string_std__in_string(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string(std::string const &); /*proto*/
static CYTHON_INLINE PyObject *__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string(std::string const &); /*proto*/
static CYTHON_INLINE PyObject *__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string(std::string const &); /*proto*/
static CYTHON_INLINE PyObject *__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(std::string const &); /*proto*/
static CYTHON_INLINE PyObject *__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string(std::string const &); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "giacpy.giacpy"
extern int __pyx_module_is_main_giacpy__giacpy;
int __pyx_module_is_main_giacpy__giacpy = 0;

/* Implementation of "giacpy.giacpy" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_KeyboardInterrupt;
static PyObject *__pyx_builtin_print;
/* #### Code section: string_decls ### */
static const char __pyx_k_A[] = "A";
static const char __pyx_k_F[] = "_F";
static const char __pyx_k_G[] = "_G_";
static const char __pyx_k_H[] = "_H";
static const char __pyx_k_I[] = "I";
static const char __pyx_k_J[] = "_J";
static const char __pyx_k_K[] = "_K";
static const char __pyx_k_N[] = "_N";
static const char __pyx_k_P[] = "_P";
static const char __pyx_k_R[] = "_R";
static const char __pyx_k_S[] = "_S";
static const char __pyx_k_T[] = "_T";
static const char __pyx_k_V[] = "_V";
static const char __pyx_k_W[] = "_W";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "b";
static const char __pyx_k_c[] = "_c_";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_g[] = "_g";
static const char __pyx_k_h[] = "_h";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "_j";
static const char __pyx_k_k[] = "_k_";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_m[] = "_m";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_q[] = "_q_";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_t[] = "_t";
static const char __pyx_k_u[] = "_u";
static const char __pyx_k_Bq[] = "_Bq";
static const char __pyx_k_Ci[] = "Ci";
static const char __pyx_k_Ei[] = "Ei";
static const char __pyx_k_GF[] = "GF";
static const char __pyx_k_Gy[] = "_Gy";
static const char __pyx_k_Hz[] = "_Hz";
static const char __pyx_k_I0[] = "_I0_";
static const char __pyx_k_LN[] = "LN";
static const char __pyx_k_LQ[] = "LQ";
static const char __pyx_k_LU[] = "LU";
static const char __pyx_k_Li[] = "Li";
static const char __pyx_k_MW[] = "_MW";
static const char __pyx_k_NA[] = "_NA_";
static const char __pyx_k_Pa[] = "_Pa";
static const char __pyx_k_Pi[] = "Pi";
static const char __pyx_k_QR[] = "QR";
static const char __pyx_k_Si[] = "Si";
static const char __pyx_k_St[] = "_St";
static const char __pyx_k_Sv[] = "_Sv";
static const char __pyx_k_Vm[] = "_Vm_";
static const char __pyx_k_Wb[] = "_Wb";
static const char __pyx_k_Wh[] = "_Wh";
static const char __pyx_k__8[] = ".";
static const char __pyx_k_a0[] = "_a0_";
static const char __pyx_k_at[] = "at";
static const char __pyx_k_au[] = "_au";
static const char __pyx_k_bu[] = "_bu";
static const char __pyx_k_by[] = "by";
static const char __pyx_k_c3[] = "_c3_";
static const char __pyx_k_cd[] = "_cd";
static const char __pyx_k_cm[] = "_cm";
static const char __pyx_k_ct[] = "_ct";
static const char __pyx_k_cu[] = "_cu";
static const char __pyx_k_dB[] = "_dB";
static const char __pyx_k_de[] = "de";
static const char __pyx_k_do[] = "do";
static const char __pyx_k_eV[] = "_eV";
static const char __pyx_k_el[] = "el";
static const char __pyx_k_en[] = "en";
static const char __pyx_k_et[] = "et";
static const char __pyx_k_f0[] = "_f0_";
static const char __pyx_k_fc[] = "_fc";
static const char __pyx_k_fi[] = "fi";
static const char __pyx_k_fm[] = "_fm";
static const char __pyx_k_fr[] = "fr";
static const char __pyx_k_ft[] = "_ft";
static const char __pyx_k_ga[] = "_ga";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_gf[] = "_gf";
static const char __pyx_k_ha[] = "_ha";
static const char __pyx_k_hp[] = "_hp";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_if[] = "if";
static const char __pyx_k_im[] = "im";
static const char __pyx_k_in[] = "in";
static const char __pyx_k_kg[] = "_kg";
static const char __pyx_k_km[] = "_km";
static const char __pyx_k_kq[] = "_kq_";
static const char __pyx_k_lb[] = "_lb";
static const char __pyx_k_lm[] = "_lm";
static const char __pyx_k_ln[] = "ln";
static const char __pyx_k_lu[] = "lu";
static const char __pyx_k_lx[] = "_lx";
static const char __pyx_k_me[] = "_me_";
static const char __pyx_k_ml[] = "_ml";
static const char __pyx_k_mm[] = "_mm";
static const char __pyx_k_mn[] = "_mn";
static const char __pyx_k_mp[] = "_mp_";
static const char __pyx_k_od[] = "od";
static const char __pyx_k_of[] = "of";
static const char __pyx_k_op[] = "op";
static const char __pyx_k_or[] = "or";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_ou[] = "ou";
static const char __pyx_k_oz[] = "_oz";
static const char __pyx_k_pc[] = "_pc";
static const char __pyx_k_ph[] = "_ph";
static const char __pyx_k_pi[] = "pi";
static const char __pyx_k_pk[] = "_pk";
static const char __pyx_k_qe[] = "_qe_";
static const char __pyx_k_qr[] = "qr";
static const char __pyx_k_qt[] = "_qt";
static const char __pyx_k_rd[] = "_rd";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_sb[] = "_sb";
static const char __pyx_k_sd[] = "_sd_";
static const char __pyx_k_si[] = "si";
static const char __pyx_k_sq[] = "sq";
static const char __pyx_k_sr[] = "_sr";
static const char __pyx_k_st[] = "_st";
static const char __pyx_k_to[] = "to";
static const char __pyx_k_tr[] = "_tr";
static const char __pyx_k_yd[] = "_yd";
static const char __pyx_k_yr[] = "_yr";
static const char __pyx_k_A_2[] = "_A";
static const char __pyx_k_Btu[] = "_Btu";
static const char __pyx_k_COS[] = "COS";
static const char __pyx_k_COT[] = "COT";
static const char __pyx_k_CSC[] = "CSC";
static const char __pyx_k_CST[] = "CST";
static const char __pyx_k_Col[] = "Col";
static const char __pyx_k_Det[] = "Det";
static const char __pyx_k_EXP[] = "EXP";
static const char __pyx_k_F_2[] = "_F_";
static const char __pyx_k_Fdy[] = "_Fdy";
static const char __pyx_k_Gal[] = "_Gal";
static const char __pyx_k_Gcd[] = "Gcd";
static const char __pyx_k_Int[] = "Int";
static const char __pyx_k_LSQ[] = "LSQ";
static const char __pyx_k_MHz[] = "_MHz";
static const char __pyx_k_MSE[] = "MSE";
static const char __pyx_k_MeV[] = "_MeV";
static const char __pyx_k_Ohm[] = "_Ohm";
static const char __pyx_k_Phi[] = "Phi";
static const char __pyx_k_Psi[] = "Psi";
static const char __pyx_k_Quo[] = "Quo";
static const char __pyx_k_R_2[] = "_R_";
static const char __pyx_k_Rem[] = "Rem";
static const char __pyx_k_Row[] = "Row";
static const char __pyx_k_SIN[] = "SIN";
static const char __pyx_k_SVD[] = "SVD";
static const char __pyx_k_SVL[] = "SVL";
static const char __pyx_k_TAN[] = "TAN";
static const char __pyx_k_TeX[] = "TeX";
static const char __pyx_k_VAS[] = "VAS";
static const char __pyx_k__10[] = "";
static const char __pyx_k__12[] = "?";
static const char __pyx_k__14[] = "*";
static const char __pyx_k_a2q[] = "a2q";
static const char __pyx_k_a_2[] = "_a";
static const char __pyx_k_abs[] = "abs";
static const char __pyx_k_add[] = "add";
static const char __pyx_k_all[] = "__all__";
static const char __pyx_k_and[] = "and";
static const char __pyx_k_ans[] = "ans";
static const char __pyx_k_arc[] = "arc";
static const char __pyx_k_arg[] = "arg";
static const char __pyx_k_asc[] = "asc";
static const char __pyx_k_atm[] = "_atm";
static const char __pyx_k_b_2[] = "_b";
static const char __pyx_k_bar[] = "_bar";
static const char __pyx_k_bbl[] = "_bbl";
static const char __pyx_k_cal[] = "_cal";
static const char __pyx_k_cap[] = "cap";
static const char __pyx_k_cat[] = "cat";
static const char __pyx_k_cdf[] = "cdf";
static const char __pyx_k_chr[] = "chr";
static const char __pyx_k_col[] = "col";
static const char __pyx_k_cos[] = "cos";
static const char __pyx_k_cot[] = "cot";
static const char __pyx_k_csc[] = "csc";
static const char __pyx_k_d_2[] = "_d";
static const char __pyx_k_deg[] = "_deg";
static const char __pyx_k_del[] = "del";
static const char __pyx_k_det[] = "det";
static const char __pyx_k_dfc[] = "dfc";
static const char __pyx_k_dim[] = "dim";
static const char __pyx_k_div[] = "div";
static const char __pyx_k_doc[] = "doc/";
static const char __pyx_k_dot[] = "dot";
static const char __pyx_k_dwt[] = "dwt";
static const char __pyx_k_dyn[] = "_dyn";
static const char __pyx_k_e2r[] = "e2r";
static const char __pyx_k_egv[] = "egv";
static const char __pyx_k_emd[] = "emd";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_erf[] = "erf";
static const char __pyx_k_erg[] = "_erg";
static const char __pyx_k_exp[] = "exp";
static const char __pyx_k_fbm[] = "_fbm";
static const char __pyx_k_fft[] = "fft";
static const char __pyx_k_for[] = "for";
static const char __pyx_k_fsi[] = "fsi";
static const char __pyx_k_g_2[] = "_g_";
static const char __pyx_k_gcd[] = "gcd";
static const char __pyx_k_gon[] = "_gon";
static const char __pyx_k_h_2[] = "_h_";
static const char __pyx_k_has[] = "has";
static const char __pyx_k_hht[] = "hht";
static const char __pyx_k_hsv[] = "hsv";
static const char __pyx_k_i_2[] = "i[]";
static const char __pyx_k_idn[] = "idn";
static const char __pyx_k_inf[] = "inf";
static const char __pyx_k_int[] = "int";
static const char __pyx_k_inv[] = "inv";
static const char __pyx_k_kWh[] = "_kWh";
static const char __pyx_k_kde[] = "kde";
static const char __pyx_k_ker[] = "ker";
static const char __pyx_k_kip[] = "_kip";
static const char __pyx_k_kph[] = "_kph";
static const char __pyx_k_l_2[] = "_l";
static const char __pyx_k_lam[] = "_lam";
static const char __pyx_k_lbf[] = "_lbf";
static const char __pyx_k_lbt[] = "_lbt";
static const char __pyx_k_lcm[] = "lcm";
static const char __pyx_k_ldl[] = "ldl";
static const char __pyx_k_len[] = "len";
static const char __pyx_k_lep[] = "_lep";
static const char __pyx_k_lhs[] = "lhs";
static const char __pyx_k_lin[] = "lin";
static const char __pyx_k_lis[] = "lis";
static const char __pyx_k_lll[] = "lll";
static const char __pyx_k_log[] = "log";
static const char __pyx_k_lsq[] = "lsq";
static const char __pyx_k_lyr[] = "_lyr";
static const char __pyx_k_m_2[] = "_m^2";
static const char __pyx_k_m_3[] = "_m^3";
static const char __pyx_k_m_s[] = "_(m/s)";
static const char __pyx_k_map[] = "map";
static const char __pyx_k_max[] = "max";
static const char __pyx_k_mgf[] = "mgf";
static const char __pyx_k_mho[] = "_mho";
static const char __pyx_k_mid[] = "mid";
static const char __pyx_k_mil[] = "_mil";
static const char __pyx_k_min[] = "min";
static const char __pyx_k_mod[] = "mod";
static const char __pyx_k_mol[] = "_mol";
static const char __pyx_k_mph[] = "_mph";
static const char __pyx_k_mu0[] = "_mu0_";
static const char __pyx_k_muB[] = "_muB_";
static const char __pyx_k_muN[] = "_muN_";
static const char __pyx_k_mul[] = "mul";
static const char __pyx_k_nCr[] = "nCr";
static const char __pyx_k_nPr[] = "nPr";
static const char __pyx_k_neg[] = "__neg__";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_non[] = "non";
static const char __pyx_k_nop[] = "nop";
static const char __pyx_k_not[] = "not";
static const char __pyx_k_odd[] = "odd";
static const char __pyx_k_ord[] = "ord";
static const char __pyx_k_ozt[] = "_ozt";
static const char __pyx_k_pas[] = "pas";
static const char __pyx_k_pdl[] = "_pdl";
static const char __pyx_k_phi[] = "_phi_";
static const char __pyx_k_pie[] = "pie";
static const char __pyx_k_pnt[] = "pnt";
static const char __pyx_k_pow[] = "pow";
static const char __pyx_k_psi[] = "_psi";
static const char __pyx_k_pwd[] = "pwd";
static const char __pyx_k_q2a[] = "q2a";
static const char __pyx_k_qme[] = "_qme_";
static const char __pyx_k_quo[] = "quo";
static const char __pyx_k_r2e[] = "r2e";
static const char __pyx_k_rad[] = "_rad";
static const char __pyx_k_red[] = "red";
static const char __pyx_k_ref[] = "ref";
static const char __pyx_k_rem[] = "rem";
static const char __pyx_k_rgb[] = "rgb";
static const char __pyx_k_rhs[] = "rhs";
static const char __pyx_k_rms[] = "rms";
static const char __pyx_k_rod[] = "_rod";
static const char __pyx_k_row[] = "row";
static const char __pyx_k_rpm[] = "_rpm";
static const char __pyx_k_rur[] = "rur";
static const char __pyx_k_s_2[] = "_s";
static const char __pyx_k_s_s[] = "%s[%s]";
static const char __pyx_k_sec[] = "sec";
static const char __pyx_k_seq[] = "seq";
static const char __pyx_k_set[] = "set[]";
static const char __pyx_k_sin[] = "sin";
static const char __pyx_k_sst[] = "sst";
static const char __pyx_k_sto[] = "sto";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sub[] = "__sub__";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_svd[] = "svd";
static const char __pyx_k_syr[] = "_syr_";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_tan[] = "tan";
static const char __pyx_k_tar[] = "tar";
static const char __pyx_k_tec[] = "_tec";
static const char __pyx_k_tep[] = "_tep";
static const char __pyx_k_tex[] = "_tex";
static const char __pyx_k_tmp[] = "tmp";
static const char __pyx_k_ton[] = "_ton";
static const char __pyx_k_tri[] = "tri";
static const char __pyx_k_trn[] = "trn";
static const char __pyx_k_try[] = "try";
static const char __pyx_k_tsp[] = "_tsp";
static const char __pyx_k_url[] = "url";
static const char __pyx_k_val[] = "_val";
static const char __pyx_k_var[] = "var";
static const char __pyx_k_xor[] = "xor";
static const char __pyx_k_zip[] = "zip";
static const char __pyx_k_ACOT[] = "ACOT";
static const char __pyx_k_ACSC[] = "ACSC";
static const char __pyx_k_ASEC[] = "ASEC";
static const char __pyx_k_ASIN[] = "ASIN";
static const char __pyx_k_ATAN[] = "ATAN";
static const char __pyx_k_Beta[] = "Beta";
static const char __pyx_k_COND[] = "COND";
static const char __pyx_k_COSH[] = "COSH";
static const char __pyx_k_Ci_2[] = "_Ci";
static const char __pyx_k_Disp[] = "Disp";
static const char __pyx_k_F_OK[] = "F_OK";
static const char __pyx_k_Fill[] = "Fill";
static const char __pyx_k_IFTE[] = "IFTE";
static const char __pyx_k_Kcal[] = "_Kcal";
static const char __pyx_k_Line[] = "Line";
static const char __pyx_k_NULL[] = "NULL";
static const char __pyx_k_PSun[] = "_PSun_";
static const char __pyx_k_RSun[] = "_RSun_";
static const char __pyx_k_ReLU[] = "ReLU";
static const char __pyx_k_Rref[] = "Rref";
static const char __pyx_k_StdP[] = "_StdP_";
static const char __pyx_k_StdT[] = "_StdT_";
static const char __pyx_k_TRUE[] = "TRUE";
static const char __pyx_k_Text[] = "Text";
static const char __pyx_k_True[] = "True";
static const char __pyx_k_UTPC[] = "UTPC";
static const char __pyx_k_UTPF[] = "UTPF";
static const char __pyx_k_UTPN[] = "UTPN";
static const char __pyx_k_UTPT[] = "UTPT";
static const char __pyx_k_VARS[] = "VARS";
static const char __pyx_k_WAIT[] = "WAIT";
static const char __pyx_k_Zeta[] = "Zeta";
static const char __pyx_k_acos[] = "acos";
static const char __pyx_k_acot[] = "acot";
static const char __pyx_k_acre[] = "_acre";
static const char __pyx_k_acsc[] = "acsc";
static const char __pyx_k_angl[] = "_angl_";
static const char __pyx_k_arcs[] = "_arcs";
static const char __pyx_k_area[] = "area";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_asec[] = "asec";
static const char __pyx_k_asin[] = "asin";
static const char __pyx_k_atan[] = "atan";
static const char __pyx_k_axes[] = "axes";
static const char __pyx_k_axis[] = "axis";
static const char __pyx_k_back[] = "back";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_bins[] = "bins";
static const char __pyx_k_bleu[] = "bleu";
static const char __pyx_k_bloc[] = "bloc";
static const char __pyx_k_blue[] = "blue";
static const char __pyx_k_buUS[] = "_buUS";
static const char __pyx_k_call[] = "__call__";
static const char __pyx_k_case[] = "case";
static const char __pyx_k_cd_2[] = "cd";
static const char __pyx_k_ceil[] = "ceil";
static const char __pyx_k_char[] = "char";
static const char __pyx_k_cm_2[] = "_cm^2";
static const char __pyx_k_cm_3[] = "_cm^3";
static const char __pyx_k_cm_s[] = "_(cm/s)";
static const char __pyx_k_comb[] = "comb";
static const char __pyx_k_cond[] = "cond";
static const char __pyx_k_cone[] = "cone";
static const char __pyx_k_conj[] = "conj";
static const char __pyx_k_cont[] = "cont";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_cosh[] = "cosh";
static const char __pyx_k_cote[] = "cote";
static const char __pyx_k_cube[] = "cube";
static const char __pyx_k_curl[] = "curl";
static const char __pyx_k_cyan[] = "cyan";
static const char __pyx_k_diag[] = "diag";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_diff[] = "diff";
static const char __pyx_k_dotP[] = "dotP";
static const char __pyx_k_egcd[] = "egcd";
static const char __pyx_k_egvl[] = "egvl";
static const char __pyx_k_elif[] = "elif";
static const char __pyx_k_else[] = "else";
static const char __pyx_k_erfc[] = "erfc";
static const char __pyx_k_eval[] = "eval";
static const char __pyx_k_even[] = "even";
static const char __pyx_k_expr[] = "expr";
static const char __pyx_k_f2nd[] = "f2nd";
static const char __pyx_k_fMax[] = "fMax";
static const char __pyx_k_fMin[] = "fMin";
static const char __pyx_k_fath[] = "_fath";
static const char __pyx_k_faux[] = "faux";
static const char __pyx_k_file[] = "file:";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_flam[] = "_flam";
static const char __pyx_k_fmod[] = "fmod";
static const char __pyx_k_frac[] = "frac";
static const char __pyx_k_from[] = "from";
static const char __pyx_k_ftUS[] = "_ftUS";
static const char __pyx_k_ft_2[] = "_ft^2";
static const char __pyx_k_ft_3[] = "_ft^3";
static const char __pyx_k_ft_s[] = "_(ft/s)";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_fxnd[] = "fxnd";
static const char __pyx_k_galC[] = "_galC";
static const char __pyx_k_giac[] = "giac";
static const char __pyx_k_gl_x[] = "gl_x";
static const char __pyx_k_gl_y[] = "gl_y";
static const char __pyx_k_gl_z[] = "gl_z";
static const char __pyx_k_gmol[] = "_gmol";
static const char __pyx_k_gold[] = "gold";
static const char __pyx_k_goto[] = "goto";
static const char __pyx_k_grad[] = "grad";
static const char __pyx_k_grey[] = "grey";
static const char __pyx_k_halt[] = "halt";
static const char __pyx_k_hbar[] = "_hbar_";
static const char __pyx_k_head[] = "head";
static const char __pyx_k_help[] = "help";
static const char __pyx_k_hold[] = "hold";
static const char __pyx_k_ibpu[] = "ibpu";
static const char __pyx_k_icdf[] = "icdf";
static const char __pyx_k_idwt[] = "idwt";
static const char __pyx_k_ifft[] = "ifft";
static const char __pyx_k_ifte[] = "ifte";
static const char __pyx_k_igcd[] = "igcd";
static const char __pyx_k_imag[] = "imag";
static const char __pyx_k_inHg[] = "_inHg";
static const char __pyx_k_in_2[] = "_in";
static const char __pyx_k_in_3[] = "_in^3";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_iquo[] = "iquo";
static const char __pyx_k_irem[] = "irem";
static const char __pyx_k_isom[] = "isom";
static const char __pyx_k_iter[] = "__iter__";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_kill[] = "kill";
static const char __pyx_k_km_2[] = "_km^2";
static const char __pyx_k_knot[] = "_knot";
static const char __pyx_k_lang[] = "lang";
static const char __pyx_k_left[] = "left";
static const char __pyx_k_lgcd[] = "lgcd";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_list[] = "list";
static const char __pyx_k_log2[] = "log2";
static const char __pyx_k_logb[] = "logb";
static const char __pyx_k_long[] = "long";
static const char __pyx_k_lvar[] = "lvar";
static const char __pyx_k_mRow[] = "mRow";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_math[] = "math";
static const char __pyx_k_mean[] = "mean";
static const char __pyx_k_miUS[] = "_miUS";
static const char __pyx_k_mi_2[] = "_mi^2";
static const char __pyx_k_mile[] = "_mile";
static const char __pyx_k_mksa[] = "mksa";
static const char __pyx_k_mmHg[] = "_mmHg";
static const char __pyx_k_modf[] = "modf";
static const char __pyx_k_mods[] = "mods";
static const char __pyx_k_mpme[] = "_mpme_";
static const char __pyx_k_nInt[] = "nInt";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_navy[] = "navy";
static const char __pyx_k_noir[] = "noir";
static const char __pyx_k_nops[] = "nops";
static const char __pyx_k_norm[] = "norm";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_ozUK[] = "_ozUK";
static const char __pyx_k_ozfl[] = "_ozfl";
static const char __pyx_k_pade[] = "pade";
static const char __pyx_k_pari[] = "pari";
static const char __pyx_k_part[] = "part";
static const char __pyx_k_pcar[] = "pcar";
static const char __pyx_k_perm[] = "perm";
static const char __pyx_k_pink[] = "pink";
static const char __pyx_k_plex[] = "plex";
static const char __pyx_k_plot[] = "plot";
static const char __pyx_k_pmin[] = "pmin";
static const char __pyx_k_pole[] = "pole";
static const char __pyx_k_pour[] = "pour";
static const char __pyx_k_proc[] = "proc";
static const char __pyx_k_ptUK[] = "_ptUK";
static const char __pyx_k_qcas[] = "qcas";
static const char __pyx_k_rand[] = "rand";
static const char __pyx_k_rank[] = "rank";
static const char __pyx_k_ranm[] = "ranm";
static const char __pyx_k_ranv[] = "ranv";
static const char __pyx_k_rdiv[] = "rdiv";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_real[] = "real";
static const char __pyx_k_rect[] = "rect";
static const char __pyx_k_repr[] = "__repr__";
static const char __pyx_k_rond[] = "rond";
static const char __pyx_k_root[] = "root";
static const char __pyx_k_rref[] = "rref";
static const char __pyx_k_same[] = "same";
static const char __pyx_k_save[] = "save";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_sign[] = "sign";
static const char __pyx_k_sinc[] = "sinc";
static const char __pyx_k_sinh[] = "sinh";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_slug[] = "_slug";
static const char __pyx_k_smod[] = "smod";
static const char __pyx_k_sort[] = "sort";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_sqrt[] = "sqrt";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_stft[] = "stft";
static const char __pyx_k_subs[] = "subs";
static const char __pyx_k_surd[] = "surd";
static const char __pyx_k_tail[] = "tail";
static const char __pyx_k_tanh[] = "tanh";
static const char __pyx_k_tbsp[] = "_tbsp";
static const char __pyx_k_tdeg[] = "tdeg";
static const char __pyx_k_teal[] = "teal";
static const char __pyx_k_test[] = "test";
static const char __pyx_k_then[] = "then";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_tlin[] = "tlin";
static const char __pyx_k_torr[] = "_torr";
static const char __pyx_k_tr_s[] = "_(tr/s)";
static const char __pyx_k_tran[] = "tran";
static const char __pyx_k_tree[] = "tree";
static const char __pyx_k_trim[] = "trim";
static const char __pyx_k_true[] = "true";
static const char __pyx_k_tuer[] = "tuer";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_vers[] = "vers";
static const char __pyx_k_vert[] = "vert";
static const char __pyx_k_vrai[] = "vrai";
static const char __pyx_k_when[] = "when";
static const char __pyx_k_yd_2[] = "_yd^2";
static const char __pyx_k_yd_3[] = "_yd^3";
static const char __pyx_k_ACOSH[] = "ACOSH";
static const char __pyx_k_ASINH[] = "ASINH";
static const char __pyx_k_ATANH[] = "ATANH";
static const char __pyx_k_ClrIO[] = "ClrIO";
static const char __pyx_k_Dirac[] = "Dirac";
static const char __pyx_k_DispG[] = "DispG";
static const char __pyx_k_ERROR[] = "ERROR";
static const char __pyx_k_FALSE[] = "FALSE";
static const char __pyx_k_False[] = "False";
static const char __pyx_k_Gamma[] = "Gamma";
static const char __pyx_k_Graph[] = "Graph";
static const char __pyx_k_Input[] = "Input";
static const char __pyx_k_Pause[] = "Pause";
static const char __pyx_k_PopUp[] = "PopUp";
static const char __pyx_k_Pygen[] = "Pygen";
static const char __pyx_k_REDIM[] = "REDIM";
static const char __pyx_k_SCALE[] = "SCALE";
static const char __pyx_k_SCHUR[] = "SCHUR";
static const char __pyx_k_SortA[] = "SortA";
static const char __pyx_k_SortD[] = "SortD";
static const char __pyx_k_Store[] = "Store";
static const char __pyx_k_Title[] = "Title";
static const char __pyx_k_UTF_8[] = "UTF-8";
static const char __pyx_k__1655[] = "[]";
static const char __pyx_k__1656[] = "[..]";
static const char __pyx_k__1657[] = "!";
static const char __pyx_k__1658[] = "!=";
static const char __pyx_k__1659[] = "#";
static const char __pyx_k__1660[] = "$";
static const char __pyx_k__1661[] = "%";
static const char __pyx_k__1662[] = "/%";
static const char __pyx_k__1663[] = "%/";
static const char __pyx_k__1664[] = "%{%}";
static const char __pyx_k__1665[] = "&&";
static const char __pyx_k__1666[] = "&*";
static const char __pyx_k__1667[] = "&^";
static const char __pyx_k__1668[] = "'";
static const char __pyx_k__1669[] = "()";
static const char __pyx_k__1670[] = "*=";
static const char __pyx_k__1671[] = "+";
static const char __pyx_k__1672[] = "-";
static const char __pyx_k__1673[] = "+&";
static const char __pyx_k__1674[] = "+=";
static const char __pyx_k__1675[] = "-<";
static const char __pyx_k__1676[] = "-=";
static const char __pyx_k__1677[] = "->";
static const char __pyx_k__1678[] = ".*";
static const char __pyx_k__1679[] = ".+";
static const char __pyx_k__1680[] = ".-";
static const char __pyx_k__1681[] = "./";
static const char __pyx_k__1682[] = ".^";
static const char __pyx_k__1683[] = "/=";
static const char __pyx_k__1684[] = ":=";
static const char __pyx_k__1685[] = "<";
static const char __pyx_k__1686[] = "<=";
static const char __pyx_k__1687[] = "=";
static const char __pyx_k__1688[] = "=<";
static const char __pyx_k__1689[] = "==";
static const char __pyx_k__1690[] = "=>";
static const char __pyx_k__1691[] = ">";
static const char __pyx_k__1692[] = ">=";
static const char __pyx_k__1693[] = "@";
static const char __pyx_k__1694[] = "@@";
static const char __pyx_k__1695[] = "^";
static const char __pyx_k__1696[] = "_\303\202\302\265";
static const char __pyx_k__1697[] = "_\302\265";
static const char __pyx_k__1698[] = "{}";
static const char __pyx_k__1699[] = "|";
static const char __pyx_k__1700[] = "||";
static const char __pyx_k_abcuv[] = "abcuv";
static const char __pyx_k_about[] = "about";
static const char __pyx_k_acosh[] = "acosh";
static const char __pyx_k_add_2[] = "__add__";
static const char __pyx_k_affix[] = "affix";
static const char __pyx_k_alors[] = "alors";
static const char __pyx_k_alpha[] = "_alpha_";
static const char __pyx_k_angle[] = "angle";
static const char __pyx_k_apply[] = "apply";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_asinh[] = "asinh";
static const char __pyx_k_atan2[] = "atan2";
static const char __pyx_k_atanh[] = "atanh";
static const char __pyx_k_avgRC[] = "avgRC";
static const char __pyx_k_basis[] = "basis";
static const char __pyx_k_bblep[] = "_bblep";
static const char __pyx_k_begin[] = "begin";
static const char __pyx_k_betad[] = "betad";
static const char __pyx_k_bitor[] = "bitor";
static const char __pyx_k_black[] = "black";
static const char __pyx_k_blanc[] = "blanc";
static const char __pyx_k_break[] = "break";
static const char __pyx_k_brown[] = "brown";
static const char __pyx_k_c1oc2[] = "c1oc2";
static const char __pyx_k_c1op2[] = "c1op2";
static const char __pyx_k_catch[] = "catch";
static const char __pyx_k_chain[] = "_chain";
static const char __pyx_k_chrem[] = "chrem";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_clear[] = "clear";
static const char __pyx_k_click[] = "click";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_coeff[] = "coeff";
static const char __pyx_k_color[] = "color";
static const char __pyx_k_condi[] = "condi";
static const char __pyx_k_conic[] = "conic";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_cross[] = "cross";
static const char __pyx_k_curve[] = "curve";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_denom[] = "denom";
static const char __pyx_k_dfc2f[] = "dfc2f";
static const char __pyx_k_div_2[] = "__div__";
static const char __pyx_k_divis[] = "divis";
static const char __pyx_k_divpc[] = "divpc";
static const char __pyx_k_doc_2[] = "__doc__";
static const char __pyx_k_droit[] = "droit";
static const char __pyx_k_ecris[] = "ecris";
static const char __pyx_k_edges[] = "edges";
static const char __pyx_k_eigVc[] = "eigVc";
static const char __pyx_k_eigVl[] = "eigVl";
static const char __pyx_k_entry[] = "entry";
static const char __pyx_k_equal[] = "equal";
static const char __pyx_k_erase[] = "erase";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_euler[] = "euler";
static const char __pyx_k_evala[] = "evala";
static const char __pyx_k_evalb[] = "evalb";
static const char __pyx_k_evalc[] = "evalc";
static const char __pyx_k_evalf[] = "evalf";
static const char __pyx_k_evalm[] = "evalm";
static const char __pyx_k_exact[] = "exact";
static const char __pyx_k_expln[] = "expln";
static const char __pyx_k_ezgcd[] = "ezgcd";
static const char __pyx_k_fPart[] = "fPart";
static const char __pyx_k_faces[] = "faces";
static const char __pyx_k_faire[] = "faire";
static const char __pyx_k_false[] = "false";
static const char __pyx_k_fermi[] = "_fermi";
static const char __pyx_k_float[] = "float";
static const char __pyx_k_floor[] = "floor";
static const char __pyx_k_foldl[] = "foldl";
static const char __pyx_k_foldr[] = "foldr";
static const char __pyx_k_fopen[] = "fopen";
static const char __pyx_k_fpour[] = "fpour";
static const char __pyx_k_froot[] = "froot";
static const char __pyx_k_ft_lb[] = "_(ft*lb)";
static const char __pyx_k_galUK[] = "_galUK";
static const char __pyx_k_galUS[] = "_galUS";
static const char __pyx_k_gauss[] = "gauss";
static const char __pyx_k_gcdex[] = "gcdex";
static const char __pyx_k_girth[] = "girth";
static const char __pyx_k_grain[] = "_grain";
static const char __pyx_k_graph[] = "graph";
static const char __pyx_k_green[] = "green";
static const char __pyx_k_iPart[] = "iPart";
static const char __pyx_k_ibpdv[] = "ibpdv";
static const char __pyx_k_icomp[] = "icomp";
static const char __pyx_k_iegcd[] = "iegcd";
static const char __pyx_k_image[] = "image";
static const char __pyx_k_inH20[] = "_inH20";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_input[] = "input";
static const char __pyx_k_inter[] = "inter";
static const char __pyx_k_isinf[] = "isinf";
static const char __pyx_k_isnan[] = "isnan";
static const char __pyx_k_istft[] = "istft";
static const char __pyx_k_label[] = "label";
static const char __pyx_k_latex[] = "latex";
static const char __pyx_k_lbmol[] = "_lbmol";
static const char __pyx_k_limit[] = "limit";
static const char __pyx_k_liqpt[] = "_liqpt";
static const char __pyx_k_lname[] = "lname";
static const char __pyx_k_local[] = "local";
static const char __pyx_k_locus[] = "locus";
static const char __pyx_k_log10[] = "log10";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_lsmod[] = "lsmod";
static const char __pyx_k_m_s_2[] = "_(m/s^2)";
static const char __pyx_k_mille[] = "_mille";
static const char __pyx_k_minus[] = "minus";
static const char __pyx_k_moyal[] = "moyal";
static const char __pyx_k_mul_2[] = "__mul__";
static const char __pyx_k_ncols[] = "ncols";
static const char __pyx_k_nrows[] = "nrows";
static const char __pyx_k_nstep[] = "nstep";
static const char __pyx_k_numer[] = "numer";
static const char __pyx_k_olive[] = "olive";
static const char __pyx_k_order[] = "order";
static const char __pyx_k_p1oc2[] = "p1oc2";
static const char __pyx_k_p1op2[] = "p1op2";
static const char __pyx_k_pa2b2[] = "pa2b2";
static const char __pyx_k_param[] = "param";
static const char __pyx_k_pcoef[] = "pcoef";
static const char __pyx_k_penup[] = "penup";
static const char __pyx_k_peval[] = "peval";
static const char __pyx_k_pivot[] = "pivot";
static const char __pyx_k_pixon[] = "pixon";
static const char __pyx_k_plane[] = "plane";
static const char __pyx_k_point[] = "point";
static const char __pyx_k_polar[] = "polar";
static const char __pyx_k_pow_2[] = "__pow__";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_prism[] = "prism";
static const char __pyx_k_proot[] = "proot";
static const char __pyx_k_ptayl[] = "ptayl";
static const char __pyx_k_purge[] = "purge";
static const char __pyx_k_quest[] = "quest";
static const char __pyx_k_quote[] = "quote";
static const char __pyx_k_rad_2[] = "_rad_";
static const char __pyx_k_rad_s[] = "_(rad/s)";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_redim[] = "redim";
static const char __pyx_k_rem_2[] = "_rem";
static const char __pyx_k_right[] = "right";
static const char __pyx_k_risch[] = "risch";
static const char __pyx_k_rmmod[] = "rmmod";
static const char __pyx_k_roots[] = "roots";
static const char __pyx_k_rouge[] = "rouge";
static const char __pyx_k_round[] = "round";
static const char __pyx_k_saute[] = "saute";
static const char __pyx_k_sauve[] = "sauve";
static const char __pyx_k_scale[] = "scale";
static const char __pyx_k_schur[] = "schur";
static const char __pyx_k_shift[] = "shift";
static const char __pyx_k_sigma[] = "_sigma_";
static const char __pyx_k_signe[] = "signe";
static const char __pyx_k_simp2[] = "simp2";
static const char __pyx_k_sinon[] = "sinon";
static const char __pyx_k_sizes[] = "sizes";
static const char __pyx_k_sleep[] = "sleep";
static const char __pyx_k_slope[] = "slope";
static const char __pyx_k_smith[] = "smith";
static const char __pyx_k_solve[] = "solve";
static const char __pyx_k_somme[] = "somme";
static const char __pyx_k_sorta[] = "sorta";
static const char __pyx_k_sortd[] = "sortd";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_srand[] = "srand";
static const char __pyx_k_stack[] = "stack";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_str_2[] = "__str__";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_sturm[] = "sturm";
static const char __pyx_k_style[] = "style";
static const char __pyx_k_subst[] = "subst";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_table[] = "table";
static const char __pyx_k_therm[] = "_therm";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_title[] = "title";
static const char __pyx_k_titre[] = "titre";
static const char __pyx_k_tonUK[] = "_tonUK";
static const char __pyx_k_trace[] = "trace";
static const char __pyx_k_trail[] = "trail";
static const char __pyx_k_train[] = "train";
static const char __pyx_k_trunc[] = "trunc";
static const char __pyx_k_tstep[] = "tstep";
static const char __pyx_k_twopi[] = "_twopi_";
static const char __pyx_k_undef[] = "undef";
static const char __pyx_k_union[] = "union";
static const char __pyx_k_unitV[] = "unitV";
static const char __pyx_k_until[] = "until";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_ustep[] = "ustep";
static const char __pyx_k_vstep[] = "vstep";
static const char __pyx_k_watch[] = "watch";
static const char __pyx_k_while[] = "while";
static const char __pyx_k_white[] = "white";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_xstep[] = "xstep";
static const char __pyx_k_ystep[] = "ystep";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_zstep[] = "zstep";
static const char __pyx_k_Circle[] = "Circle";
static const char __pyx_k_DIGITS[] = "DIGITS";
static const char __pyx_k_DelVar[] = "DelVar";
static const char __pyx_k_Dialog[] = "Dialog";
static const char __pyx_k_Digits[] = "Digits";
static const char __pyx_k_Factor[] = "Factor";
static const char __pyx_k_NewPic[] = "NewPic";
static const char __pyx_k_Output[] = "Output";
static const char __pyx_k_REarth[] = "_REarth_";
static const char __pyx_k_RclPic[] = "RclPic";
static const char __pyx_k_StoPic[] = "StoPic";
static const char __pyx_k_access[] = "access";
static const char __pyx_k_algvar[] = "algvar";
static const char __pyx_k_alog10[] = "alog10";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_approx[] = "approx";
static const char __pyx_k_arcLen[] = "arcLen";
static const char __pyx_k_arccos[] = "arccos";
static const char __pyx_k_arclen[] = "arclen";
static const char __pyx_k_arcmin[] = "_arcmin";
static const char __pyx_k_arcsin[] = "arcsin";
static const char __pyx_k_arctan[] = "arctan";
static const char __pyx_k_areaat[] = "areaat";
static const char __pyx_k_assert[] = "assert";
static const char __pyx_k_assign[] = "assign";
static const char __pyx_k_assume[] = "assume";
static const char __pyx_k_avance[] = "avance";
static const char __pyx_k_batons[] = "batons";
static const char __pyx_k_bezier[] = "bezier";
static const char __pyx_k_bitand[] = "bitand";
static const char __pyx_k_bitxor[] = "bitxor";
static const char __pyx_k_border[] = "border";
static const char __pyx_k_boxcar[] = "boxcar";
static const char __pyx_k_cSolve[] = "cSolve";
static const char __pyx_k_cZeros[] = "cZeros";
static const char __pyx_k_cascmd[] = "/cascmd_";
static const char __pyx_k_cauchy[] = "cauchy";
static const char __pyx_k_center[] = "center";
static const char __pyx_k_choice[] = "choice";
static const char __pyx_k_circle[] = "circle";
static const char __pyx_k_coeffs[] = "coeffs";
static const char __pyx_k_colDim[] = "colDim";
static const char __pyx_k_coldim[] = "coldim";
static const char __pyx_k_concat[] = "concat";
static const char __pyx_k_convex[] = "convex";
static const char __pyx_k_crayon[] = "crayon";
static const char __pyx_k_crossP[] = "crossP";
static const char __pyx_k_csolve[] = "csolve";
static const char __pyx_k_cumSum[] = "cumSum";
static const char __pyx_k_cumsum[] = "cumsum";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_degree[] = "degree";
static const char __pyx_k_derive[] = "derive";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_disque[] = "disque";
static const char __pyx_k_divide[] = "divide";
static const char __pyx_k_divmod[] = "divmod";
static const char __pyx_k_domain[] = "domain";
static const char __pyx_k_double[] = "_double";
static const char __pyx_k_dsolve[] = "dsolve";
static const char __pyx_k_efface[] = "efface";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_end_if[] = "end_if";
static const char __pyx_k_expand[] = "expand";
static const char __pyx_k_extend[] = "extend";
static const char __pyx_k_factor[] = "factor";
static const char __pyx_k_fadeev[] = "fadeev";
static const char __pyx_k_fclose[] = "fclose";
static const char __pyx_k_fcoeff[] = "fcoeff";
static const char __pyx_k_ffaire[] = "ffaire";
static const char __pyx_k_filled[] = "filled";
static const char __pyx_k_fisher[] = "fisher";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_fprint[] = "fprint";
static const char __pyx_k_frames[] = "frames";
static const char __pyx_k_fsolve[] = "fsolve";
static const char __pyx_k_gammad[] = "gammad";
static const char __pyx_k_gauche[] = "gauche";
static const char __pyx_k_gbasis[] = "gbasis";
static const char __pyx_k_getKey[] = "getKey";
static const char __pyx_k_getNum[] = "getNum";
static const char __pyx_k_grad_2[] = "_grad";
static const char __pyx_k_graphe[] = "graphe";
static const char __pyx_k_hasard[] = "hasard";
static const char __pyx_k_heugcd[] = "heugcd";
static const char __pyx_k_horner[] = "horner";
static const char __pyx_k_iabcuv[] = "iabcuv";
static const char __pyx_k_ibasis[] = "ibasis";
static const char __pyx_k_ichrem[] = "ichrem";
static const char __pyx_k_idivis[] = "idivis";
static const char __pyx_k_igamma[] = "igamma";
static const char __pyx_k_igcdex[] = "igcdex";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_in_2_2[] = "_in^2";
static const char __pyx_k_indets[] = "indets";
static const char __pyx_k_insert[] = "insert";
static const char __pyx_k_insmod[] = "insmod";
static const char __pyx_k_intDiv[] = "intDiv";
static const char __pyx_k_interp[] = "interp";
static const char __pyx_k_ismith[] = "ismith";
static const char __pyx_k_isolve[] = "isolve";
static const char __pyx_k_jordan[] = "jordan";
static const char __pyx_k_jusqua[] = "jusqua";
static const char __pyx_k_jusque[] = "jusque";
static const char __pyx_k_kernel[] = "kernel";
static const char __pyx_k_kmeans[] = "kmeans";
static const char __pyx_k_l1norm[] = "l1norm";
static const char __pyx_k_l2norm[] = "l2norm";
static const char __pyx_k_labels[] = "labels";
static const char __pyx_k_lcoeff[] = "lcoeff";
static const char __pyx_k_legend[] = "legend";
static const char __pyx_k_length[] = "length";
static const char __pyx_k_limite[] = "limite";
static const char __pyx_k_linabs[] = "linabs";
static const char __pyx_k_mEarth[] = "_mEarth_";
static const char __pyx_k_markov[] = "markov";
static const char __pyx_k_mathml[] = "mathml";
static const char __pyx_k_matpow[] = "matpow";
static const char __pyx_k_matrix[] = "matrix";
static const char __pyx_k_median[] = "median";
static const char __pyx_k_member[] = "member";
static const char __pyx_k_miUS_2[] = "_miUS^2";
static const char __pyx_k_mkisom[] = "mkisom";
static const char __pyx_k_modgcd[] = "modgcd";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_nDeriv[] = "nDeriv";
static const char __pyx_k_nSolve[] = "nSolve";
static const char __pyx_k_newMat[] = "newMat";
static const char __pyx_k_newton[] = "newton";
static const char __pyx_k_nodisp[] = "nodisp";
static const char __pyx_k_normal[] = "normal";
static const char __pyx_k_oldies[] = "oldies";
static const char __pyx_k_option[] = "option";
static const char __pyx_k_orange[] = "orange";
static const char __pyx_k_output[] = "output";
static const char __pyx_k_pcoeff[] = "pcoeff";
static const char __pyx_k_period[] = "period";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_pixoff[] = "pixoff";
static const char __pyx_k_planar[] = "planar";
static const char __pyx_k_plot3d[] = "plot3d";
static const char __pyx_k_powmod[] = "powmod";
static const char __pyx_k_preval[] = "preval";
static const char __pyx_k_printf[] = "printf";
static const char __pyx_k_psrgcd[] = "psrgcd";
static const char __pyx_k_purple[] = "purple";
static const char __pyx_k_quorem[] = "quorem";
static const char __pyx_k_radius[] = "radius";
static const char __pyx_k_ramene[] = "ramene";
static const char __pyx_k_random[] = "random";
static const char __pyx_k_recule[] = "recule";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remain[] = "remain";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_repeat[] = "repeat";
static const char __pyx_k_repete[] = "repete";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_revert[] = "revert";
static const char __pyx_k_revlex[] = "revlex";
static const char __pyx_k_rm_a_z[] = "rm_a_z";
static const char __pyx_k_rootof[] = "rootof";
static const char __pyx_k_rotate[] = "rotate";
static const char __pyx_k_rowAdd[] = "rowAdd";
static const char __pyx_k_rowDim[] = "rowDim";
static const char __pyx_k_rowdim[] = "rowdim";
static const char __pyx_k_rsolve[] = "rsolve";
static const char __pyx_k_saisir[] = "saisir";
static const char __pyx_k_sample[] = "sample";
static const char __pyx_k_select[] = "select";
static const char __pyx_k_series[] = "series";
static const char __pyx_k_simult[] = "simult";
static const char __pyx_k_sincos[] = "sincos";
static const char __pyx_k_sommet[] = "sommet";
static const char __pyx_k_sorted[] = "sorted";
static const char __pyx_k_sphere[] = "sphere";
static const char __pyx_k_splice[] = "splice";
static const char __pyx_k_spline[] = "spline";
static const char __pyx_k_spring[] = "spring";
static const char __pyx_k_square[] = "square";
static const char __pyx_k_sst_in[] = "sst_in";
static const char __pyx_k_stdDev[] = "stdDev";
static const char __pyx_k_stddev[] = "stddev";
static const char __pyx_k_string[] = "string";
static const char __pyx_k_subMat[] = "subMat";
static const char __pyx_k_subsop[] = "subsop";
static const char __pyx_k_switch[] = "switch";
static const char __pyx_k_symbol[] = "symbol";
static const char __pyx_k_tabvar[] = "tabvar";
static const char __pyx_k_taylor[] = "taylor";
static const char __pyx_k_tcoeff[] = "tcoeff";
static const char __pyx_k_test_2[] = "__test__";
static const char __pyx_k_thiele[] = "thiele";
static const char __pyx_k_toqcas[] = "toqcas";
static const char __pyx_k_tr_min[] = "_(tr/min)";
static const char __pyx_k_trames[] = "trames";
static const char __pyx_k_type_2[] = "_type";
static const char __pyx_k_ugamma[] = "ugamma";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_vector[] = "vector";
static const char __pyx_k_violet[] = "violet";
static const char __pyx_k_yellow[] = "yellow";
static const char __pyx_k_ztrans[] = "ztrans";
static const char __pyx_k_Airy_Ai[] = "Airy_Ai";
static const char __pyx_k_Airy_Bi[] = "Airy_Bi";
static const char __pyx_k_Archive[] = "Archive";
static const char __pyx_k_BesselJ[] = "BesselJ";
static const char __pyx_k_BesselY[] = "BesselY";
static const char __pyx_k_ClrDraw[] = "ClrDraw";
static const char __pyx_k_CopyVar[] = "CopyVar";
static const char __pyx_k_DOM_INT[] = "DOM_INT";
static const char __pyx_k_DOM_RAT[] = "DOM_RAT";
static const char __pyx_k_DOM_int[] = "DOM_int";
static const char __pyx_k_DelFold[] = "DelFold";
static const char __pyx_k_DrawInv[] = "DrawInv";
static const char __pyx_k_DrawPol[] = "DrawPol";
static const char __pyx_k_DrawSlp[] = "DrawSlp";
static const char __pyx_k_EndDlog[] = "EndDlog";
static const char __pyx_k_Fourier[] = "Fourier";
static const char __pyx_k_GetFold[] = "GetFold";
static const char __pyx_k_Hilbert[] = "Hilbert";
static const char __pyx_k_Inverse[] = "Inverse";
static const char __pyx_k_LineTan[] = "LineTan";
static const char __pyx_k_NORMALD[] = "NORMALD";
static const char __pyx_k_NewFold[] = "NewFold";
static const char __pyx_k_REPLACE[] = "REPLACE";
static const char __pyx_k_Rankine[] = "_Rankine";
static const char __pyx_k_Request[] = "Request";
static const char __pyx_k_RplcPic[] = "RplcPic";
static const char __pyx_k_SWAPCOL[] = "SWAPCOL";
static const char __pyx_k_SWAPROW[] = "SWAPROW";
static const char __pyx_k_SetFold[] = "SetFold";
static const char __pyx_k_acyclic[] = "acyclic";
static const char __pyx_k_add_arc[] = "add_arc";
static const char __pyx_k_algsubs[] = "algsubs";
static const char __pyx_k_angleat[] = "angleat";
static const char __pyx_k_animate[] = "animate";
static const char __pyx_k_arccosh[] = "arccosh";
static const char __pyx_k_archive[] = "archive";
static const char __pyx_k_arcsinh[] = "arcsinh";
static const char __pyx_k_arctanh[] = "arctanh";
static const char __pyx_k_augment[] = "augment";
static const char __pyx_k_barplot[] = "barplot";
static const char __pyx_k_besselJ[] = "besselJ";
static const char __pyx_k_besselY[] = "besselY";
static const char __pyx_k_bspline[] = "bspline";
static const char __pyx_k_cFactor[] = "cFactor";
static const char __pyx_k_cauchyd[] = "cauchyd";
static const char __pyx_k_ceiling[] = "ceiling";
static const char __pyx_k_cfactor[] = "cfactor";
static const char __pyx_k_cfsolve[] = "cfsolve";
static const char __pyx_k_chinrem[] = "chinrem";
static const char __pyx_k_classes[] = "classes";
static const char __pyx_k_cluster[] = "cluster";
static const char __pyx_k_colNorm[] = "colNorm";
static const char __pyx_k_colSwap[] = "colSwap";
static const char __pyx_k_collect[] = "collect";
static const char __pyx_k_colnorm[] = "colnorm";
static const char __pyx_k_colswap[] = "colswap";
static const char __pyx_k_combine[] = "combine";
static const char __pyx_k_comment[] = "comment";
static const char __pyx_k_compare[] = "compare";
static const char __pyx_k_complex[] = "complex";
static const char __pyx_k_confrac[] = "confrac";
static const char __pyx_k_content[] = "content";
static const char __pyx_k_convert[] = "convert";
static const char __pyx_k_csv2gen[] = "csv2gen";
static const char __pyx_k_deSolve[] = "deSolve";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_degreeF[] = "_degreeF";
static const char __pyx_k_degrees[] = "degrees";
static const char __pyx_k_delcols[] = "delcols";
static const char __pyx_k_delrows[] = "delrows";
static const char __pyx_k_deriver[] = "deriver";
static const char __pyx_k_desolve[] = "desolve";
static const char __pyx_k_digraph[] = "digraph";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_display[] = "display";
static const char __pyx_k_dotprod[] = "dotprod";
static const char __pyx_k_element[] = "element";
static const char __pyx_k_ellipse[] = "ellipse";
static const char __pyx_k_end_for[] = "end_for";
static const char __pyx_k_epsilon[] = "epsilon";
static const char __pyx_k_erase3d[] = "erase3d";
static const char __pyx_k_evolute[] = "evolute";
static const char __pyx_k_execute[] = "execute";
static const char __pyx_k_exp2pow[] = "exp2pow";
static const char __pyx_k_extrema[] = "extrema";
static const char __pyx_k_factors[] = "factors";
static const char __pyx_k_feuille[] = "feuille";
static const char __pyx_k_fisherd[] = "fisherd";
static const char __pyx_k_fitpoly[] = "fitpoly";
static const char __pyx_k_flatten[] = "flatten";
static const char __pyx_k_forward[] = "forward";
static const char __pyx_k_fourier[] = "fourier";
static const char __pyx_k_fracmod[] = "fracmod";
static const char __pyx_k_ft_lb_2[] = "_ft*lb";
static const char __pyx_k_gauss15[] = "gauss15";
static const char __pyx_k_genpoly[] = "genpoly";
static const char __pyx_k_getType[] = "getType";
static const char __pyx_k_gnuplot[] = "gnuplot";
static const char __pyx_k_greduce[] = "greduce";
static const char __pyx_k_halftan[] = "halftan";
static const char __pyx_k_hamdist[] = "hamdist";
static const char __pyx_k_hamming[] = "hamming";
static const char __pyx_k_has_arc[] = "has_arc";
static const char __pyx_k_heading[] = "heading";
static const char __pyx_k_heapify[] = "heapify";
static const char __pyx_k_heappop[] = "heappop";
static const char __pyx_k_hermite[] = "hermite";
static const char __pyx_k_hessian[] = "hessian";
static const char __pyx_k_hexagon[] = "hexagon";
static const char __pyx_k_hilbert[] = "hilbert";
static const char __pyx_k_hsv2rgb[] = "hsv2rgb";
static const char __pyx_k_hyp2exp[] = "hyp2exp";
static const char __pyx_k_ifactor[] = "ifactor";
static const char __pyx_k_ignored[] = "ignored";
static const char __pyx_k_imfplot[] = "imfplot";
static const char __pyx_k_indices[] = "indices";
static const char __pyx_k_inertia[] = "inertia";
static const char __pyx_k_integer[] = "integer";
static const char __pyx_k_inverse[] = "inverse";
static const char __pyx_k_iquorem[] = "iquorem";
static const char __pyx_k_isPrime[] = "isPrime";
static const char __pyx_k_is_tree[] = "is_tree";
static const char __pyx_k_isprime[] = "isprime";
static const char __pyx_k_jusqu_a[] = "jusqu_a";
static const char __pyx_k_kspaths[] = "kspaths";
static const char __pyx_k_lambda0[] = "_lambda0_";
static const char __pyx_k_lambdac[] = "_lambdac_";
static const char __pyx_k_laplace[] = "laplace";
static const char __pyx_k_ldegree[] = "ldegree";
static const char __pyx_k_linstep[] = "linstep";
static const char __pyx_k_lowpass[] = "lowpass";
static const char __pyx_k_lpsolve[] = "lpsolve";
static const char __pyx_k_mRowAdd[] = "mRowAdd";
static const char __pyx_k_magenta[] = "magenta";
static const char __pyx_k_makemat[] = "makemat";
static const char __pyx_k_maxflow[] = "maxflow";
static const char __pyx_k_maxnorm[] = "maxnorm";
static const char __pyx_k_maxsize[] = "maxsize";
static const char __pyx_k_minimax[] = "minimax";
static const char __pyx_k_mixdown[] = "mixdown";
static const char __pyx_k_moyenne[] = "moyenne";
static const char __pyx_k_newList[] = "newList";
static const char __pyx_k_normald[] = "normald";
static const char __pyx_k_normalt[] = "normalt";
static const char __pyx_k_nprimes[] = "nprimes";
static const char __pyx_k_numdiff[] = "numdiff";
static const char __pyx_k_odeplot[] = "odeplot";
static const char __pyx_k_parameq[] = "parameq";
static const char __pyx_k_parfrac[] = "parfrac";
static const char __pyx_k_pendown[] = "pendown";
static const char __pyx_k_perminv[] = "perminv";
static const char __pyx_k_playsnd[] = "playsnd";
static const char __pyx_k_plotcdf[] = "plotcdf";
static const char __pyx_k_plotimf[] = "plotimf";
static const char __pyx_k_plotode[] = "plotode";
static const char __pyx_k_plotseq[] = "plotseq";
static const char __pyx_k_plotwav[] = "plotwav";
static const char __pyx_k_point2d[] = "point2d";
static const char __pyx_k_point3d[] = "point3d";
static const char __pyx_k_poisson[] = "poisson";
static const char __pyx_k_polygon[] = "polygon";
static const char __pyx_k_polynom[] = "polynom";
static const char __pyx_k_pow2exp[] = "pow2exp";
static const char __pyx_k_powerpc[] = "powerpc";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_prepend[] = "prepend";
static const char __pyx_k_product[] = "product";
static const char __pyx_k_program[] = "program";
static const char __pyx_k_pyramid[] = "pyramid";
static const char __pyx_k_quadric[] = "quadric";
static const char __pyx_k_rad_s_2[] = "_(rad/s^2)";
static const char __pyx_k_radians[] = "radians";
static const char __pyx_k_randMat[] = "randMat";
static const char __pyx_k_randexp[] = "randexp";
static const char __pyx_k_randint[] = "randint";
static const char __pyx_k_randvar[] = "randvar";
static const char __pyx_k_readrgb[] = "readrgb";
static const char __pyx_k_readwav[] = "readwav";
static const char __pyx_k_regroup[] = "regroup";
static const char __pyx_k_reorder[] = "reorder";
static const char __pyx_k_repeter[] = "repeter";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_residue[] = "residue";
static const char __pyx_k_restart[] = "restart";
static const char __pyx_k_reverse[] = "reverse";
static const char __pyx_k_revlist[] = "revlist";
static const char __pyx_k_rgb2hsv[] = "rgb2hsv";
static const char __pyx_k_rgb2xyz[] = "rgb2xyz";
static const char __pyx_k_rhombus[] = "rhombus";
static const char __pyx_k_rmwatch[] = "rmwatch";
static const char __pyx_k_romberg[] = "romberg";
static const char __pyx_k_rowNorm[] = "rowNorm";
static const char __pyx_k_rowSwap[] = "rowSwap";
static const char __pyx_k_rownorm[] = "rownorm";
static const char __pyx_k_rowswap[] = "rowswap";
static const char __pyx_k_segment[] = "segment";
static const char __pyx_k_seqplot[] = "seqplot";
static const char __pyx_k_shuffle[] = "shuffle";
static const char __pyx_k_simpson[] = "simpson";
static const char __pyx_k_slopeat[] = "slopeat";
static const char __pyx_k_sqrfree[] = "sqrfree";
static const char __pyx_k_stddevp[] = "stddevp";
static const char __pyx_k_student[] = "student";
static const char __pyx_k_sturmab[] = "sturmab";
static const char __pyx_k_subtype[] = "subtype";
static const char __pyx_k_swapcol[] = "swapcol";
static const char __pyx_k_swaprow[] = "swaprow";
static const char __pyx_k_tExpand[] = "tExpand";
static const char __pyx_k_tabsign[] = "tabsign";
static const char __pyx_k_tangent[] = "tangent";
static const char __pyx_k_tantque[] = "tantque";
static const char __pyx_k_texpand[] = "texpand";
static const char __pyx_k_tonnetz[] = "tonnetz";
static const char __pyx_k_tpsolve[] = "tpsolve";
static const char __pyx_k_trapeze[] = "trapeze";
static const char __pyx_k_trigcos[] = "trigcos";
static const char __pyx_k_trigsin[] = "trigsin";
static const char __pyx_k_trigtan[] = "trigtan";
static const char __pyx_k_truediv[] = "__truediv__";
static const char __pyx_k_ufactor[] = "ufactor";
static const char __pyx_k_unapply[] = "unapply";
static const char __pyx_k_uniform[] = "uniform";
static const char __pyx_k_unquote[] = "unquote";
static const char __pyx_k_version[] = "version";
static const char __pyx_k_weibull[] = "weibull";
static const char __pyx_k_weights[] = "weights";
static const char __pyx_k_xyz2rgb[] = "xyz2rgb";
static const char __pyx_k_znorder[] = "znorder";
static const char __pyx_k_Angstrom[] = "_Angstrom";
static const char __pyx_k_ClrGraph[] = "ClrGraph";
static const char __pyx_k_CyclePic[] = "CyclePic";
static const char __pyx_k_DOM_FUNC[] = "DOM_FUNC";
static const char __pyx_k_DOM_LIST[] = "DOM_LIST";
static const char __pyx_k_DispHome[] = "DispHome";
static const char __pyx_k_DrawFunc[] = "DrawFunc";
static const char __pyx_k_DrawParm[] = "DrawParm";
static const char __pyx_k_DropDown[] = "DropDown";
static const char __pyx_k_DrwCtour[] = "DrwCtour";
static const char __pyx_k_GIACNULL[] = "GIACNULL";
static const char __pyx_k_InputStr[] = "InputStr";
static const char __pyx_k_LambertW[] = "LambertW";
static const char __pyx_k_LineHorz[] = "LineHorz";
static const char __pyx_k_LineVert[] = "LineVert";
static const char __pyx_k_Pymaxint[] = "Pymaxint";
static const char __pyx_k_RandSeed[] = "RandSeed";
static const char __pyx_k_SCALEADD[] = "SCALEADD";
static const char __pyx_k_Unarchiv[] = "Unarchiv";
static const char __pyx_k_abscissa[] = "abscissa";
static const char __pyx_k_adaptive[] = "adaptive";
static const char __pyx_k_add_edge[] = "add_edge";
static const char __pyx_k_addtable[] = "addtable";
static const char __pyx_k_altitude[] = "altitude";
static const char __pyx_k_areaplot[] = "areaplot";
static const char __pyx_k_arrivals[] = "arrivals";
static const char __pyx_k_atrig2ln[] = "atrig2ln";
static const char __pyx_k_backward[] = "backward";
static const char __pyx_k_bar_plot[] = "bar_plot";
static const char __pyx_k_binomial[] = "binomial";
static const char __pyx_k_bisector[] = "bisector";
static const char __pyx_k_builtins[] = "__builtins__";
static const char __pyx_k_bvpsolve[] = "bvpsolve";
static const char __pyx_k_channels[] = "channels";
static const char __pyx_k_charpoly[] = "charpoly";
static const char __pyx_k_cholesky[] = "cholesky";
static const char __pyx_k_colormap[] = "colormap";
static const char __pyx_k_colspace[] = "colspace";
static const char __pyx_k_comDenom[] = "comDenom";
static const char __pyx_k_contains[] = "contains";
static const char __pyx_k_continue[] = "continue";
static const char __pyx_k_count_eq[] = "count_eq";
static const char __pyx_k_cycleinv[] = "cycleinv";
static const char __pyx_k_cylinder[] = "cylinder";
static const char __pyx_k_dijkstra[] = "dijkstra";
static const char __pyx_k_directed[] = "directed";
static const char __pyx_k_distance[] = "distance";
static const char __pyx_k_divisors[] = "divisors";
static const char __pyx_k_double_2[] = "double";
static const char __pyx_k_draw_arc[] = "draw_arc";
static const char __pyx_k_duration[] = "duration";
static const char __pyx_k_envelope[] = "envelope";
static const char __pyx_k_epsilon0[] = "_epsilon0_";
static const char __pyx_k_equation[] = "equation";
static const char __pyx_k_excircle[] = "excircle";
static const char __pyx_k_exp2list[] = "exp2list";
static const char __pyx_k_exp2trig[] = "exp2trig";
static const char __pyx_k_fdistrib[] = "fdistrib";
static const char __pyx_k_filename[] = "filename";
static const char __pyx_k_findhelp[] = "findhelp";
static const char __pyx_k_fitdistr[] = "fitdistr";
static const char __pyx_k_fonction[] = "fonction";
static const char __pyx_k_frame_2d[] = "frame_2d";
static const char __pyx_k_frame_3d[] = "frame_3d";
static const char __pyx_k_ftantque[] = "ftantque";
static const char __pyx_k_funcplot[] = "funcplot";
static const char __pyx_k_function[] = "function";
static const char __pyx_k_getDenom[] = "getDenom";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_gl_ortho[] = "gl_ortho";
static const char __pyx_k_gl_xtick[] = "gl_xtick";
static const char __pyx_k_gl_ytick[] = "gl_ytick";
static const char __pyx_k_gl_ztick[] = "gl_ztick";
static const char __pyx_k_graphe3d[] = "graphe3d";
static const char __pyx_k_hadamard[] = "hadamard";
static const char __pyx_k_has_edge[] = "has_edge";
static const char __pyx_k_heappush[] = "heappush";
static const char __pyx_k_highpass[] = "highpass";
static const char __pyx_k_htmlhelp[] = "htmlhelp";
static const char __pyx_k_ichinrem[] = "ichinrem";
static const char __pyx_k_icontent[] = "icontent";
static const char __pyx_k_identity[] = "identity";
static const char __pyx_k_ifactors[] = "ifactors";
static const char __pyx_k_ifourier[] = "ifourier";
static const char __pyx_k_ihermite[] = "ihermite";
static const char __pyx_k_ilaplace[] = "ilaplace";
static const char __pyx_k_inString[] = "inString";
static const char __pyx_k_in_ideal[] = "in_ideal";
static const char __pyx_k_incircle[] = "incircle";
static const char __pyx_k_infinity[] = "infinity";
static const char __pyx_k_instfreq[] = "instfreq";
static const char __pyx_k_integrer[] = "integrer";
static const char __pyx_k_interval[] = "interval";
static const char __pyx_k_is_cycle[] = "is_cycle";
static const char __pyx_k_is_permu[] = "is_permu";
static const char __pyx_k_is_prime[] = "is_prime";
static const char __pyx_k_isposdef[] = "isposdef";
static const char __pyx_k_ithprime[] = "ithprime";
static const char __pyx_k_lagrange[] = "lagrange";
static const char __pyx_k_laguerre[] = "laguerre";
static const char __pyx_k_legendre[] = "legendre";
static const char __pyx_k_linfnorm[] = "linfnorm";
static const char __pyx_k_linsolve[] = "linsolve";
static const char __pyx_k_linspace[] = "linspace";
static const char __pyx_k_list2exp[] = "list2exp";
static const char __pyx_k_list2mat[] = "list2mat";
static const char __pyx_k_listplot[] = "listplot";
static const char __pyx_k_lnexpand[] = "lnexpand";
static const char __pyx_k_log_loss[] = "log_loss";
static const char __pyx_k_logistic[] = "logistic";
static const char __pyx_k_makelist[] = "makelist";
static const char __pyx_k_mat2list[] = "mat2list";
static const char __pyx_k_maxcount[] = "maxcount";
static const char __pyx_k_maximize[] = "maximize";
static const char __pyx_k_midpoint[] = "midpoint";
static const char __pyx_k_minimize[] = "minimize";
static const char __pyx_k_momentum[] = "momentum";
static const char __pyx_k_multiply[] = "multiply";
static const char __pyx_k_nextperm[] = "nextperm";
static const char __pyx_k_nlpsolve[] = "nlpsolve";
static const char __pyx_k_odesolve[] = "odesolve";
static const char __pyx_k_ordinate[] = "ordinate";
static const char __pyx_k_parabola[] = "parabola";
static const char __pyx_k_parallel[] = "parallel";
static const char __pyx_k_partfrac[] = "partfrac";
static const char __pyx_k_pencolor[] = "pencolor";
static const char __pyx_k_periodic[] = "periodic";
static const char __pyx_k_plotarea[] = "plotarea";
static const char __pyx_k_plotfunc[] = "plotfunc";
static const char __pyx_k_plotlist[] = "plotlist";
static const char __pyx_k_polyEval[] = "polyEval";
static const char __pyx_k_position[] = "position";
static const char __pyx_k_posubLMQ[] = "posubLMQ";
static const char __pyx_k_powermod[] = "powermod";
static const char __pyx_k_prevperm[] = "prevperm";
static const char __pyx_k_primpart[] = "primpart";
static const char __pyx_k_propFrac[] = "propFrac";
static const char __pyx_k_propfrac[] = "propfrac";
static const char __pyx_k_pyx_capi[] = "__pyx_capi__";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_quantile[] = "quantile";
static const char __pyx_k_randNorm[] = "randNorm";
static const char __pyx_k_randPoly[] = "randPoly";
static const char __pyx_k_randnorm[] = "randnorm";
static const char __pyx_k_randperm[] = "randperm";
static const char __pyx_k_randpoly[] = "randpoly";
static const char __pyx_k_randseed[] = "randseed";
static const char __pyx_k_rational[] = "rational";
static const char __pyx_k_realroot[] = "realroot";
static const char __pyx_k_resample[] = "resample";
static const char __pyx_k_resoudre[] = "resoudre";
static const char __pyx_k_rombergm[] = "rombergm";
static const char __pyx_k_rombergt[] = "rombergt";
static const char __pyx_k_rotation[] = "rotation";
static const char __pyx_k_rowspace[] = "rowspace";
static const char __pyx_k_scaleadd[] = "scaleadd";
static const char __pyx_k_seqsolve[] = "seqsolve";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_simplify[] = "simplify";
static const char __pyx_k_snedecor[] = "snedecor";
static const char __pyx_k_sortperm[] = "sortperm";
static const char __pyx_k_soundsec[] = "soundsec";
static const char __pyx_k_studentd[] = "studentd";
static const char __pyx_k_studentt[] = "studentt";
static const char __pyx_k_sturmseq[] = "sturmseq";
static const char __pyx_k_subgraph[] = "subgraph";
static const char __pyx_k_suppress[] = "suppress";
static const char __pyx_k_syst2mat[] = "syst2mat";
static const char __pyx_k_tCollect[] = "tCollect";
static const char __pyx_k_tableseq[] = "tableseq";
static const char __pyx_k_tangente[] = "tangente";
static const char __pyx_k_tcollect[] = "tcollect";
static const char __pyx_k_topology[] = "topology";
static const char __pyx_k_toremove[] = "toremove";
static const char __pyx_k_triangle[] = "triangle";
static const char __pyx_k_trig2exp[] = "trig2exp";
static const char __pyx_k_truncate[] = "truncate";
static const char __pyx_k_uniformd[] = "uniformd";
static const char __pyx_k_variance[] = "variance";
static const char __pyx_k_vertices[] = "vertices";
static const char __pyx_k_weibulld[] = "weibulld";
static const char __pyx_k_weighted[] = "weighted";
static const char __pyx_k_writergb[] = "writergb";
static const char __pyx_k_writewav[] = "writewav";
static const char __pyx_k_DOM_FLOAT[] = "DOM_FLOAT";
static const char __pyx_k_DOM_IDENT[] = "DOM_IDENT";
static const char __pyx_k_Heaviside[] = "Heaviside";
static const char __pyx_k_Nullspace[] = "Nullspace";
static const char __pyx_k_Resultant[] = "Resultant";
static const char __pyx_k_Rinfinity[] = "_Rinfinity_";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_acos2asin[] = "acos2asin";
static const char __pyx_k_acos2atan[] = "acos2atan";
static const char __pyx_k_affichage[] = "affichage";
static const char __pyx_k_animate3d[] = "animate3d";
static const char __pyx_k_animation[] = "animation";
static const char __pyx_k_areaatraw[] = "areaatraw";
static const char __pyx_k_asin2acos[] = "asin2acos";
static const char __pyx_k_asin2atan[] = "asin2atan";
static const char __pyx_k_atan2acos[] = "atan2acos";
static const char __pyx_k_atan2asin[] = "atan2asin";
static const char __pyx_k_backquote[] = "backquote";
static const char __pyx_k_bandwidth[] = "bandwidth";
static const char __pyx_k_bernoulli[] = "bernoulli";
static const char __pyx_k_betad_cdf[] = "betad_cdf";
static const char __pyx_k_bezoutian[] = "bezoutian";
static const char __pyx_k_bipartite[] = "bipartite";
static const char __pyx_k_bit_depth[] = "bit_depth";
static const char __pyx_k_blacklist[] = "blacklist";
static const char __pyx_k_camembert[] = "camembert";
static const char __pyx_k_cas_setup[] = "cas_setup";
static const char __pyx_k_chisquare[] = "chisquare";
static const char __pyx_k_choosebox[] = "choosebox";
static const char __pyx_k_companion[] = "companion";
static const char __pyx_k_connected[] = "connected";
static const char __pyx_k_convertir[] = "convertir";
static const char __pyx_k_count_inf[] = "count_inf";
static const char __pyx_k_count_sup[] = "count_sup";
static const char __pyx_k_cpartfrac[] = "cpartfrac";
static const char __pyx_k_createwav[] = "createwav";
static const char __pyx_k_curvature[] = "curvature";
static const char __pyx_k_dash_line[] = "dash_line";
static const char __pyx_k_dayofweek[] = "dayofweek";
static const char __pyx_k_deltalist[] = "deltalist";
static const char __pyx_k_det_minor[] = "det_minor";
static const char __pyx_k_distance2[] = "distance2";
static const char __pyx_k_dot_paper[] = "dot_paper";
static const char __pyx_k_draw_line[] = "draw_line";
static const char __pyx_k_eigenvals[] = "eigenvals";
static const char __pyx_k_eliminate[] = "eliminate";
static const char __pyx_k_end_while[] = "end_while";
static const char __pyx_k_epaisseur[] = "epaisseur";
static const char __pyx_k_epsilon0q[] = "_epsilon0q_";
static const char __pyx_k_epsilonox[] = "_epsilonox_";
static const char __pyx_k_epsilonsi[] = "_epsilonsi_";
static const char __pyx_k_est_permu[] = "est_permu";
static const char __pyx_k_expexpand[] = "expexpand";
static const char __pyx_k_factor_xn[] = "factor_xn";
static const char __pyx_k_factorial[] = "factorial";
static const char __pyx_k_ffonction[] = "ffonction";
static const char __pyx_k_ffunction[] = "ffunction";
static const char __pyx_k_fieldplot[] = "fieldplot";
static const char __pyx_k_fitspline[] = "fitspline";
static const char __pyx_k_gaussjord[] = "gaussjord";
static const char __pyx_k_gaussquad[] = "gaussquad";
static const char __pyx_k_geometric[] = "geometric";
static const char __pyx_k_graph2tex[] = "graph2tex";
static const char __pyx_k_groupermu[] = "groupermu";
static const char __pyx_k_half_cone[] = "half_cone";
static const char __pyx_k_half_line[] = "half_line";
static const char __pyx_k_histogram[] = "histogram";
static const char __pyx_k_homothety[] = "homothety";
static const char __pyx_k_hyperbola[] = "hyperbola";
static const char __pyx_k_inputform[] = "inputform";
static const char __pyx_k_instphase[] = "instphase";
static const char __pyx_k_integrate[] = "integrate";
static const char __pyx_k_intersect[] = "intersect";
static const char __pyx_k_inversion[] = "inversion";
static const char __pyx_k_invztrans[] = "invztrans";
static const char __pyx_k_iratrecon[] = "iratrecon";
static const char __pyx_k_is_clique[] = "is_clique";
static const char __pyx_k_is_forest[] = "is_forest";
static const char __pyx_k_is_inside[] = "is_inside";
static const char __pyx_k_is_planar[] = "is_planar";
static const char __pyx_k_is_square[] = "is_square";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_laplacian[] = "laplacian";
static const char __pyx_k_lcf_graph[] = "lcf_graph";
static const char __pyx_k_listrange[] = "listrange";
static const char __pyx_k_lncollect[] = "lncollect";
static const char __pyx_k_lp_assume[] = "lp_assume";
static const char __pyx_k_lp_binary[] = "lp_binary";
static const char __pyx_k_lp_hybrid[] = "lp_hybrid";
static const char __pyx_k_lp_method[] = "lp_method";
static const char __pyx_k_makesuite[] = "makesuite";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_monotonic[] = "monotonic";
static const char __pyx_k_moretests[] = "moretests";
static const char __pyx_k_moustache[] = "moustache";
static const char __pyx_k_mycielski[] = "mycielski";
static const char __pyx_k_neighbors[] = "neighbors";
static const char __pyx_k_nextprime[] = "nextprime";
static const char __pyx_k_nom_cache[] = "nom_cache";
static const char __pyx_k_nonnegint[] = "nonnegint";
static const char __pyx_k_normalize[] = "normalize";
static const char __pyx_k_nullspace[] = "nullspace";
static const char __pyx_k_odd_girth[] = "odd_girth";
static const char __pyx_k_odd_graph[] = "odd_graph";
static const char __pyx_k_otherwise[] = "otherwise";
static const char __pyx_k_parameter[] = "parameter";
static const char __pyx_k_paramplot[] = "paramplot";
static const char __pyx_k_perimeter[] = "perimeter";
static const char __pyx_k_permu2mat[] = "permu2mat";
static const char __pyx_k_piecewise[] = "piecewise";
static const char __pyx_k_plotfield[] = "plotfield";
static const char __pyx_k_plotparam[] = "plotparam";
static const char __pyx_k_plotpolar[] = "plotpolar";
static const char __pyx_k_plotproba[] = "plotproba";
static const char __pyx_k_point_div[] = "point_div";
static const char __pyx_k_polarplot[] = "polarplot";
static const char __pyx_k_poly2symb[] = "poly2symb";
static const char __pyx_k_poslbdLMQ[] = "poslbdLMQ";
static const char __pyx_k_potential[] = "potential";
static const char __pyx_k_powexpand[] = "powexpand";
static const char __pyx_k_prevprime[] = "prevprime";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_qepsilon0[] = "_qepsilon0_";
static const char __pyx_k_quadrant1[] = "quadrant1";
static const char __pyx_k_quadrant2[] = "quadrant2";
static const char __pyx_k_quadrant3[] = "quadrant3";
static const char __pyx_k_quadrant4[] = "quadrant4";
static const char __pyx_k_quartile1[] = "quartile1";
static const char __pyx_k_quartile3[] = "quartile3";
static const char __pyx_k_quartiles[] = "quartiles";
static const char __pyx_k_randbetad[] = "randbetad";
static const char __pyx_k_ratinterp[] = "ratinterp";
static const char __pyx_k_ratnormal[] = "ratnormal";
static const char __pyx_k_reachable[] = "reachable";
static const char __pyx_k_rectangle[] = "rectangle";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_repr_html[] = "_repr_html_";
static const char __pyx_k_resultant[] = "resultant";
static const char __pyx_k_set_pixel[] = "set_pixel";
static const char __pyx_k_signature[] = "signature";
static const char __pyx_k_snedecord[] = "snedecord";
static const char __pyx_k_subtype_2[] = "_subtype";
static const char __pyx_k_supposons[] = "supposons";
static const char __pyx_k_sylvester[] = "sylvester";
static const char __pyx_k_symb2poly[] = "symb2poly";
static const char __pyx_k_tablefunc[] = "tablefunc";
static const char __pyx_k_textinput[] = "textinput";
static const char __pyx_k_thickness[] = "thickness";
static const char __pyx_k_threads_s[] = "threads:=%s";
static const char __pyx_k_threshold[] = "threshold";
static const char __pyx_k_transpose[] = "transpose";
static const char __pyx_k_trapezoid[] = "trapezoid";
static const char __pyx_k_tsimplify[] = "tsimplify";
static const char __pyx_k_unarchive[] = "unarchive";
static const char __pyx_k_usimplify[] = "usimplify";
static const char __pyx_k_valuation[] = "valuation";
static const char __pyx_k_web_graph[] = "web_graph";
static const char __pyx_k_wilcoxonp[] = "wilcoxonp";
static const char __pyx_k_wilcoxons[] = "wilcoxons";
static const char __pyx_k_wilcoxont[] = "wilcoxont";
static const char __pyx_k_with_sqrt[] = "with_sqrt";
static const char __pyx_k_xcas_mode[] = "xcas_mode";
static const char __pyx_k_xml_print[] = "xml_print";
static const char __pyx_k_xyztrange[] = "xyztrange";
static const char __pyx_k_DOM_STRING[] = "DOM_STRING";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_Pygen_eval[] = "Pygen.eval";
static const char __pyx_k_Pygen_help[] = "Pygen.help";
static const char __pyx_k_Pygen_qcas[] = "Pygen.qcas";
static const char __pyx_k_Pygen_save[] = "Pygen.save";
static const char __pyx_k_add_vertex[] = "add_vertex";
static const char __pyx_k_angleatraw[] = "angleatraw";
static const char __pyx_k_barycenter[] = "barycenter";
static const char __pyx_k_betad_icdf[] = "betad_icdf";
static const char __pyx_k_bit_length[] = "bit_length";
static const char __pyx_k_block_size[] = "block_size";
static const char __pyx_k_boxwhisker[] = "boxwhisker";
static const char __pyx_k_breakpoint[] = "breakpoint";
static const char __pyx_k_cauchy_cdf[] = "cauchy_cdf";
static const char __pyx_k_changebase[] = "changebase";
static const char __pyx_k_chisquared[] = "chisquared";
static const char __pyx_k_chisquaret[] = "chisquaret";
static const char __pyx_k_convexhull[] = "convexhull";
static const char __pyx_k_cos2sintan[] = "cos2sintan";
static const char __pyx_k_covariance[] = "covariance";
static const char __pyx_k_cycle2perm[] = "cycle2perm";
static const char __pyx_k_cyclotomic[] = "cyclotomic";
static const char __pyx_k_delete_arc[] = "delete_arc";
static const char __pyx_k_departures[] = "departures";
static const char __pyx_k_developper[] = "developper";
static const char __pyx_k_distanceat[] = "distanceat";
static const char __pyx_k_divergence[] = "divergence";
static const char __pyx_k_draw_graph[] = "draw_graph";
static const char __pyx_k_draw_pixel[] = "draw_pixel";
static const char __pyx_k_ecart_type[] = "ecart_type";
static const char __pyx_k_ecm_factor[] = "ecm_factor";
static const char __pyx_k_eigenvects[] = "eigenvects";
static const char __pyx_k_equal2diff[] = "equal2diff";
static const char __pyx_k_equal2list[] = "equal2list";
static const char __pyx_k_est_inclus[] = "est_inclus";
static const char __pyx_k_eval_level[] = "eval_level";
static const char __pyx_k_exbisector[] = "exbisector";
static const char __pyx_k_expression[] = "expression";
static const char __pyx_k_factoriser[] = "factoriser";
static const char __pyx_k_fisher_cdf[] = "fisher_cdf";
static const char __pyx_k_fourier_an[] = "fourier_an";
static const char __pyx_k_fourier_bn[] = "fourier_bn";
static const char __pyx_k_fourier_cn[] = "fourier_cn";
static const char __pyx_k_gammad_cdf[] = "gammad_cdf";
static const char __pyx_k_gl_texture[] = "gl_texture";
static const char __pyx_k_graph_join[] = "graph_join";
static const char __pyx_k_graph_rank[] = "graph_rank";
static const char __pyx_k_grid_graph[] = "grid_graph";
static const char __pyx_k_grid_paper[] = "grid_paper";
static const char __pyx_k_haar_graph[] = "haar_graph";
static const char __pyx_k_hessenberg[] = "hessenberg";
static const char __pyx_k_identifier[] = "identifier";
static const char __pyx_k_index_html[] = "/index.html";
static const char __pyx_k_infinity_2[] = "+infinity";
static const char __pyx_k_infinity_3[] = "-infinity";
static const char __pyx_k_invlaplace[] = "invlaplace";
static const char __pyx_k_is_acyclic[] = "is_acyclic";
static const char __pyx_k_is_cut_set[] = "is_cut_set";
static const char __pyx_k_is_element[] = "is_element";
static const char __pyx_k_is_network[] = "is_network";
static const char __pyx_k_is_regular[] = "is_regular";
static const char __pyx_k_is_rhombus[] = "is_rhombus";
static const char __pyx_k_isopolygon[] = "isopolygon";
static const char __pyx_k_keep_pivot[] = "keep_pivot";
static const char __pyx_k_line_graph[] = "line_graph";
static const char __pyx_k_line_inter[] = "line_inter";
static const char __pyx_k_line_paper[] = "line_paper";
static const char __pyx_k_lineariser[] = "lineariser";
static const char __pyx_k_lis_phrase[] = "lis_phrase";
static const char __pyx_k_lp_integer[] = "lp_integer";
static const char __pyx_k_lp_maxcuts[] = "lp_maxcuts";
static const char __pyx_k_lp_simplex[] = "lp_simplex";
static const char __pyx_k_lp_verbose[] = "lp_verbose";
static const char __pyx_k_makevector[] = "makevector";
static const char __pyx_k_maple2xcas[] = "maple2xcas";
static const char __pyx_k_maple_mode[] = "maple_mode";
static const char __pyx_k_mupad2xcas[] = "mupad2xcas";
static const char __pyx_k_nlp_binary[] = "nlp_binary";
static const char __pyx_k_nlp_method[] = "nlp_method";
static const char __pyx_k_normal_cdf[] = "normal_cdf";
static const char __pyx_k_octahedron[] = "octahedron";
static const char __pyx_k_order_size[] = "order_size";
static const char __pyx_k_orthogonal[] = "orthogonal";
static const char __pyx_k_path_graph[] = "path_graph";
static const char __pyx_k_permuorder[] = "permuorder";
static const char __pyx_k_plane_dual[] = "plane_dual";
static const char __pyx_k_plus_point[] = "plus_point";
static const char __pyx_k_point_plus[] = "point_plus";
static const char __pyx_k_polyhedron[] = "polyhedron";
static const char __pyx_k_printpow_1[] = "printpow(-1)";
static const char __pyx_k_projection[] = "projection";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_randfisher[] = "randfisher";
static const char __pyx_k_randgammad[] = "randgammad";
static const char __pyx_k_randmarkov[] = "randmarkov";
static const char __pyx_k_randmatrix[] = "randmatrix";
static const char __pyx_k_randvector[] = "randvector";
static const char __pyx_k_rat_jordan[] = "rat_jordan";
static const char __pyx_k_reflection[] = "reflection";
static const char __pyx_k_repr_latex[] = "_repr_latex_";
static const char __pyx_k_rur_gbasis[] = "rur_gbasis";
static const char __pyx_k_samplerate[] = "samplerate";
static const char __pyx_k_set_screen[] = "set_screen";
static const char __pyx_k_similarity[] = "similarity";
static const char __pyx_k_simplifier[] = "simplifier";
static const char __pyx_k_sin2costan[] = "sin2costan";
static const char __pyx_k_slopeatraw[] = "slopeatraw";
static const char __pyx_k_solid_line[] = "solid_line";
static const char __pyx_k_star_graph[] = "star_graph";
static const char __pyx_k_star_point[] = "star_point";
static const char __pyx_k_substituer[] = "substituer";
static const char __pyx_k_tan2sincos[] = "tan2sincos";
static const char __pyx_k_threadeval[] = "threadeval";
static const char __pyx_k_trigexpand[] = "trigexpand";
static const char __pyx_k_triginterp[] = "triginterp";
static const char __pyx_k_unfactored[] = "unfactored";
static const char __pyx_k_vpotential[] = "vpotential";
static const char __pyx_k_webbrowser[] = "webbrowser";
static const char __pyx_k_znprimroot[] = "znprimroot";
static const char __pyx_k_DOM_COMPLEX[] = "DOM_COMPLEX";
static const char __pyx_k_GiacMethods[] = "GiacMethods";
static const char __pyx_k_GiacSetting[] = "GiacSetting";
static const char __pyx_k_JordanBlock[] = "JordanBlock";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_Pygen_redim[] = "Pygen.redim";
static const char __pyx_k_approx_mode[] = "approx_mode";
static const char __pyx_k_betavariate[] = "betavariate";
static const char __pyx_k_blockmatrix[] = "blockmatrix";
static const char __pyx_k_cas_setup_2[] = "cas_setup()";
static const char __pyx_k_cas_setup_s[] = "cas_setup(%s)";
static const char __pyx_k_cauchy_icdf[] = "cauchy_icdf";
static const char __pyx_k_cauchyd_cdf[] = "cauchyd_cdf";
static const char __pyx_k_complexroot[] = "complexroot";
static const char __pyx_k_context_ptr[] = "context_ptr";
static const char __pyx_k_contourplot[] = "contourplot";
static const char __pyx_k_convolution[] = "convolution";
static const char __pyx_k_coordinates[] = "coordinates";
static const char __pyx_k_correlation[] = "correlation";
static const char __pyx_k_cross_point[] = "cross_point";
static const char __pyx_k_cross_ratio[] = "cross_ratio";
static const char __pyx_k_cycle_basis[] = "cycle_basis";
static const char __pyx_k_cycle_graph[] = "cycle_graph";
static const char __pyx_k_decstring23[] = "decstring23";
static const char __pyx_k_delete_edge[] = "delete_edge";
static const char __pyx_k_densityplot[] = "densityplot";
static const char __pyx_k_draw_circle[] = "draw_circle";
static const char __pyx_k_eigenvalues[] = "eigenvalues";
static const char __pyx_k_encstring23[] = "encstring23";
static const char __pyx_k_euler_gamma[] = "euler_gamma";
static const char __pyx_k_exponential[] = "exponential";
static const char __pyx_k_expovariate[] = "expovariate";
static const char __pyx_k_find_cycles[] = "find_cycles";
static const char __pyx_k_fisher_icdf[] = "fisher_icdf";
static const char __pyx_k_fisherd_cdf[] = "fisherd_cdf";
static const char __pyx_k_frank_wolfe[] = "frank_wolfe";
static const char __pyx_k_frequencies[] = "frequencies";
static const char __pyx_k_fullparfrac[] = "fullparfrac";
static const char __pyx_k_gammad_icdf[] = "gammad_icdf";
static const char __pyx_k_giacbasedir[] = "giacbasedir";
static const char __pyx_k_giacpy2qcas[] = "giacpy2qcas";
static const char __pyx_k_gl_rotation[] = "gl_rotation";
static const char __pyx_k_gl_showaxes[] = "gl_showaxes";
static const char __pyx_k_gramschmidt[] = "gramschmidt";
static const char __pyx_k_graph3d2tex[] = "graph3d2tex";
static const char __pyx_k_graph_equal[] = "graph_equal";
static const char __pyx_k_graph_power[] = "graph_power";
static const char __pyx_k_graph_union[] = "graph_union";
static const char __pyx_k_hann_window[] = "hann_window";
static const char __pyx_k_hidden_name[] = "hidden_name";
static const char __pyx_k_homogeneize[] = "homogeneize";
static const char __pyx_k_icosahedron[] = "icosahedron";
static const char __pyx_k_is_coplanar[] = "is_coplanar";
static const char __pyx_k_is_directed[] = "is_directed";
static const char __pyx_k_is_eulerian[] = "is_eulerian";
static const char __pyx_k_is_harmonic[] = "is_harmonic";
static const char __pyx_k_is_included[] = "is_included";
static const char __pyx_k_is_parallel[] = "is_parallel";
static const char __pyx_k_is_weighted[] = "is_weighted";
static const char __pyx_k_keep_algext[] = "keep_algext";
static const char __pyx_k_kolmogorovd[] = "kolmogorovd";
static const char __pyx_k_kolmogorovt[] = "kolmogorovt";
static const char __pyx_k_kovacicsols[] = "kovacicsols";
static const char __pyx_k_leve_crayon[] = "leve_crayon";
static const char __pyx_k_levenshtein[] = "levenshtein";
static const char __pyx_k_ligne_tiret[] = "ligne_tiret";
static const char __pyx_k_loadgiacgen[] = "loadgiacgen";
static const char __pyx_k_lp_maximize[] = "lp_maximize";
static const char __pyx_k_lp_presolve[] = "lp_presolve";
static const char __pyx_k_make_symbol[] = "make_symbol";
static const char __pyx_k_maple2mupad[] = "maple2mupad";
static const char __pyx_k_matrix_norm[] = "matrix_norm";
static const char __pyx_k_median_line[] = "median_line";
static const char __pyx_k_minimum_cut[] = "minimum_cut";
static const char __pyx_k_moremethods[] = "moremethods";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_multinomial[] = "multinomial";
static const char __pyx_k_mupad2maple[] = "mupad2maple";
static const char __pyx_k_negbinomial[] = "negbinomial";
static const char __pyx_k_nlp_integer[] = "nlp_integer";
static const char __pyx_k_nlp_verbose[] = "nlp_verbose";
static const char __pyx_k_normal_icdf[] = "normal_icdf";
static const char __pyx_k_normald_cdf[] = "normald_cdf";
static const char __pyx_k_orthocenter[] = "orthocenter";
static const char __pyx_k_paley_graph[] = "paley_graph";
static const char __pyx_k_pas_de_cote[] = "pas_de_cote";
static const char __pyx_k_perimeterat[] = "perimeterat";
static const char __pyx_k_plotcontour[] = "plotcontour";
static const char __pyx_k_plotdensity[] = "plotdensity";
static const char __pyx_k_point_arret[] = "point_arret";
static const char __pyx_k_point_carre[] = "point_carre";
static const char __pyx_k_point_croix[] = "point_croix";
static const char __pyx_k_point_point[] = "point_point";
static const char __pyx_k_poisson_cdf[] = "poisson_cdf";
static const char __pyx_k_polar_point[] = "polar_point";
static const char __pyx_k_polygonplot[] = "polygonplot";
static const char __pyx_k_prism_graph[] = "prism_graph";
static const char __pyx_k_random_tree[] = "random_tree";
static const char __pyx_k_randpoisson[] = "randpoisson";
static const char __pyx_k_randstudent[] = "randstudent";
static const char __pyx_k_rm_all_vars[] = "rm_all_vars";
static const char __pyx_k_rur_certify[] = "rur_certify";
static const char __pyx_k_scatterplot[] = "scatterplot";
static const char __pyx_k_shift_phase[] = "shift_phase";
static const char __pyx_k_show_pixels[] = "show_pixels";
static const char __pyx_k_st_ordering[] = "st_ordering";
static const char __pyx_k_stereo2mono[] = "stereo2mono";
static const char __pyx_k_student_cdf[] = "student_cdf";
static const char __pyx_k_sum_riemann[] = "sum_riemann";
static const char __pyx_k_switch_axes[] = "switch_axes";
static const char __pyx_k_tan2cossin2[] = "tan2cossin2";
static const char __pyx_k_tan2sincos2[] = "tan2sincos2";
static const char __pyx_k_tchebyshev1[] = "tchebyshev1";
static const char __pyx_k_tchebyshev2[] = "tchebyshev2";
static const char __pyx_k_tetrahedron[] = "tetrahedron";
static const char __pyx_k_trail2edges[] = "trail2edges";
static const char __pyx_k_translation[] = "translation";
static const char __pyx_k_tree_height[] = "tree_height";
static const char __pyx_k_uniform_cdf[] = "uniform_cdf";
static const char __pyx_k_vandermonde[] = "vandermonde";
static const char __pyx_k_weibull_cdf[] = "weibull_cdf";
static const char __pyx_k_wheel_graph[] = "wheel_graph";
static const char __pyx_k_widget_size[] = "widget_size";
static const char __pyx_k_DOM_SYMBOLIC[] = "DOM_SYMBOLIC";
static const char __pyx_k_GiacFunction[] = "GiacFunction";
static const char __pyx_k_Pygen___iter[] = "Pygen.__iter__";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_VAS_positive[] = "VAS_positive";
static const char __pyx_k_additionally[] = "additionally";
static const char __pyx_k_angle_radian[] = "angle_radian";
static const char __pyx_k_autosimplify[] = "autosimplify";
static const char __pyx_k_bellman_ford[] = "bellman_ford";
static const char __pyx_k_binomial_cdf[] = "binomial_cdf";
static const char __pyx_k_brent_solver[] = "brent_solver";
static const char __pyx_k_cache_tortue[] = "cache_tortue";
static const char __pyx_k_cauchyd_icdf[] = "cauchyd_icdf";
static const char __pyx_k_channel_data[] = "channel_data";
static const char __pyx_k_circumcircle[] = "circumcircle";
static const char __pyx_k_clique_cover[] = "clique_cover";
static const char __pyx_k_complex_mode[] = "complex_mode";
static const char __pyx_k_condensation[] = "condensation";
static const char __pyx_k_crossproduct[] = "crossproduct";
static const char __pyx_k_cycles2permu[] = "cycles2permu";
static const char __pyx_k_dashdot_line[] = "dashdot_line";
static const char __pyx_k_dodecahedron[] = "dodecahedron";
static const char __pyx_k_draw_polygon[] = "draw_polygon";
static const char __pyx_k_eigenvectors[] = "eigenvectors";
static const char __pyx_k_epsilon2zero[] = "epsilon2zero";
static const char __pyx_k_exponentiald[] = "exponentiald";
static const char __pyx_k_export_graph[] = "export_graph";
static const char __pyx_k_find_cliques[] = "find_cliques";
static const char __pyx_k_find_minimum[] = "find_minimum";
static const char __pyx_k_fisherd_icdf[] = "fisherd_icdf";
static const char __pyx_k_flower_snark[] = "flower_snark";
static const char __pyx_k_gammavariate[] = "gammavariate";
static const char __pyx_k_giacsettings[] = "giacsettings";
static const char __pyx_k_gl_shownames[] = "gl_shownames";
static const char __pyx_k_graphe_suite[] = "graphe_suite";
static const char __pyx_k_greedy_color[] = "greedy_color";
static const char __pyx_k_implicitdiff[] = "implicitdiff";
static const char __pyx_k_implicitplot[] = "implicitplot";
static const char __pyx_k_import_graph[] = "import_graph";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_bipartite[] = "is_bipartite";
static const char __pyx_k_is_collinear[] = "is_collinear";
static const char __pyx_k_is_concyclic[] = "is_concyclic";
static const char __pyx_k_is_conjugate[] = "is_conjugate";
static const char __pyx_k_is_connected[] = "is_connected";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_is_isosceles[] = "is_isosceles";
static const char __pyx_k_is_reachable[] = "is_reachable";
static const char __pyx_k_is_rectangle[] = "is_rectangle";
static const char __pyx_k_kneser_graph[] = "kneser_graph";
static const char __pyx_k_line_width_1[] = "line_width_1";
static const char __pyx_k_line_width_2[] = "line_width_2";
static const char __pyx_k_line_width_3[] = "line_width_3";
static const char __pyx_k_line_width_4[] = "line_width_4";
static const char __pyx_k_line_width_5[] = "line_width_5";
static const char __pyx_k_line_width_6[] = "line_width_6";
static const char __pyx_k_line_width_7[] = "line_width_7";
static const char __pyx_k_lp_heuristic[] = "lp_heuristic";
static const char __pyx_k_lp_nodelimit[] = "lp_nodelimit";
static const char __pyx_k_lp_nonnegint[] = "lp_nonnegint";
static const char __pyx_k_lp_timelimit[] = "lp_timelimit";
static const char __pyx_k_lp_varselect[] = "lp_varselect";
static const char __pyx_k_middle_point[] = "middle_point";
static const char __pyx_k_mostkeywords[] = "mostkeywords";
static const char __pyx_k_nlp_maximize[] = "nlp_maximize";
static const char __pyx_k_nlp_presolve[] = "nlp_presolve";
static const char __pyx_k_nonevaluable[] = "nonevaluable";
static const char __pyx_k_normald_icdf[] = "normald_icdf";
static const char __pyx_k_nuage_points[] = "nuage_points";
static const char __pyx_k_open_polygon[] = "open_polygon";
static const char __pyx_k_permu2cycles[] = "permu2cycles";
static const char __pyx_k_plotimplicit[] = "plotimplicit";
static const char __pyx_k_plotspectrum[] = "plotspectrum";
static const char __pyx_k_point_etoile[] = "point_etoile";
static const char __pyx_k_point_milieu[] = "point_milieu";
static const char __pyx_k_poisson_icdf[] = "poisson_icdf";
static const char __pyx_k_pruefer_code[] = "pruefer_code";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_radical_axis[] = "radical_axis";
static const char __pyx_k_randbinomial[] = "randbinomial";
static const char __pyx_k_random_graph[] = "random_graph";
static const char __pyx_k_randweibulld[] = "randweibulld";
static const char __pyx_k_rationalroot[] = "rationalroot";
static const char __pyx_k_rmbreakpoint[] = "rmbreakpoint";
static const char __pyx_k_save_history[] = "save_history";
static const char __pyx_k_semi_augment[] = "semi_augment";
static const char __pyx_k_single_inter[] = "single_inter";
static const char __pyx_k_snedecor_cdf[] = "snedecor_cdf";
static const char __pyx_k_square_point[] = "square_point";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_student_icdf[] = "student_icdf";
static const char __pyx_k_symbol_array[] = "symbol_array";
static const char __pyx_k_total_degree[] = "total_degree";
static const char __pyx_k_trigsimplify[] = "trigsimplify";
static const char __pyx_k_tukey_window[] = "tukey_window";
static const char __pyx_k_uniform_icdf[] = "uniform_icdf";
static const char __pyx_k_uniformd_cdf[] = "uniformd_cdf";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_vertices_abc[] = "vertices_abc";
static const char __pyx_k_weibull_icdf[] = "weibull_icdf";
static const char __pyx_k_weibulld_cdf[] = "weibulld_cdf";
static const char __pyx_k_weight_decay[] = "weight_decay";
static const char __pyx_k_welch_window[] = "welch_window";
static const char __pyx_k_BlockDiagonal[] = "BlockDiagonal";
static const char __pyx_k_Giac_Settings[] = "Giac Settings";
static const char __pyx_k_Pyversioninfo[] = "Pyversioninfo";
static const char __pyx_k_ThreadedPygen[] = "ThreadedPygen";
static const char __pyx_k_baisse_crayon[] = "baisse_crayon";
static const char __pyx_k_bernoulli_mod[] = "bernoulli_mod";
static const char __pyx_k_binomial_icdf[] = "binomial_icdf";
static const char __pyx_k_bohman_window[] = "bohman_window";
static const char __pyx_k_cap_flat_line[] = "cap_flat_line";
static const char __pyx_k_centered_cube[] = "centered_cube";
static const char __pyx_k_chisquare_cdf[] = "chisquare_cdf";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_clique_number[] = "clique_number";
static const char __pyx_k_contract_edge[] = "contract_edge";
static const char __pyx_k_cosine_window[] = "cosine_window";
static const char __pyx_k_crationalroot[] = "crationalroot";
static const char __pyx_k_cross_entropy[] = "cross_entropy";
static const char __pyx_k_current_sheet[] = "current_sheet";
static const char __pyx_k_delete_vertex[] = "delete_vertex";
static const char __pyx_k_directevalued[] = "directevalued";
static const char __pyx_k_disque_centre[] = "disque_centre";
static const char __pyx_k_distanceatraw[] = "distanceatraw";
static const char __pyx_k_ecef2geodetic[] = "ecef2geodetic";
static const char __pyx_k_export_mathml[] = "export_mathml";
static const char __pyx_k_function_diff[] = "function_diff";
static const char __pyx_k_geodetic2ecef[] = "geodetic2ecef";
static const char __pyx_k_geometric_cdf[] = "geometric_cdf";
static const char __pyx_k_giac_line_163[] = "giac (line 163)";
static const char __pyx_k_giacpy_giacpy[] = "giacpy.giacpy";
static const char __pyx_k_gl_quaternion[] = "gl_quaternion";
static const char __pyx_k_greedy_clique[] = "greedy_clique";
static const char __pyx_k_hybrid_solver[] = "hybrid_solver";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_is_isomorphic[] = "is_isomorphic";
static const char __pyx_k_is_orthogonal[] = "is_orthogonal";
static const char __pyx_k_is_tournament[] = "is_tournament";
static const char __pyx_k_isobarycenter[] = "isobarycenter";
static const char __pyx_k_jacobi_symbol[] = "jacobi_symbol";
static const char __pyx_k_johnson_graph[] = "johnson_graph";
static const char __pyx_k_learning_rate[] = "learning_rate";
static const char __pyx_k_line_segments[] = "line_segments";
static const char __pyx_k_lp_depthfirst[] = "lp_depthfirst";
static const char __pyx_k_lp_depthlimit[] = "lp_depthlimit";
static const char __pyx_k_lp_nodeselect[] = "lp_nodeselect";
static const char __pyx_k_lp_pseudocost[] = "lp_pseudocost";
static const char __pyx_k_make_directed[] = "make_directed";
static const char __pyx_k_make_weighted[] = "make_weighted";
static const char __pyx_k_montre_tortue[] = "montre_tortue";
static const char __pyx_k_newton_solver[] = "newton_solver";
static const char __pyx_k_nlp_nonnegint[] = "nlp_nonnegint";
static const char __pyx_k_nlp_precision[] = "nlp_precision";
static const char __pyx_k_nlp_tolerance[] = "nlp_tolerance";
static const char __pyx_k_normalvariate[] = "normalvariate";
static const char __pyx_k_parallelogram[] = "parallelogram";
static const char __pyx_k_parzen_window[] = "parzen_window";
static const char __pyx_k_perpendicular[] = "perpendicular";
static const char __pyx_k_point_losange[] = "point_losange";
static const char __pyx_k_point_polaire[] = "point_polaire";
static const char __pyx_k_point_width_1[] = "point_width_1";
static const char __pyx_k_point_width_2[] = "point_width_2";
static const char __pyx_k_point_width_3[] = "point_width_3";
static const char __pyx_k_point_width_4[] = "point_width_4";
static const char __pyx_k_point_width_5[] = "point_width_5";
static const char __pyx_k_point_width_6[] = "point_width_6";
static const char __pyx_k_point_width_7[] = "point_width_7";
static const char __pyx_k_python_compat[] = "python_compat";
static const char __pyx_k_quadrilateral[] = "quadrilateral";
static const char __pyx_k_randchisquare[] = "randchisquare";
static const char __pyx_k_randgeometric[] = "randgeometric";
static const char __pyx_k_reciprocation[] = "reciprocation";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_reduced_conic[] = "reduced_conic";
static const char __pyx_k_reverse_graph[] = "reverse_graph";
static const char __pyx_k_rhombus_point[] = "rhombus_point";
static const char __pyx_k_saisir_chaine[] = "saisir_chaine";
static const char __pyx_k_scalarProduct[] = "scalarProduct";
static const char __pyx_k_secant_solver[] = "secant_solver";
static const char __pyx_k_seidel_switch[] = "seidel_switch";
static const char __pyx_k_shortest_path[] = "shortest_path";
static const char __pyx_k_simplifyDirac[] = "simplifyDirac";
static const char __pyx_k_snedecor_icdf[] = "snedecor_icdf";
static const char __pyx_k_snedecord_cdf[] = "snedecord_cdf";
static const char __pyx_k_spanning_tree[] = "spanning_tree";
static const char __pyx_k_tourne_droite[] = "tourne_droite";
static const char __pyx_k_tourne_gauche[] = "tourne_gauche";
static const char __pyx_k_uniformd_icdf[] = "uniformd_icdf";
static const char __pyx_k_user_operator[] = "user_operator";
static const char __pyx_k_vertex_degree[] = "vertex_degree";
static const char __pyx_k_vertices_abca[] = "vertices_abca";
static const char __pyx_k_weibulld_icdf[] = "weibulld_icdf";
static const char __pyx_k_weight_matrix[] = "weight_matrix";
static const char __pyx_k_Heaviside2sign[] = "Heaviside2sign";
static const char __pyx_k_Pygen_htmlhelp[] = "Pygen.htmlhelp";
static const char __pyx_k_PythonVersion3[] = "PythonVersion3";
static const char __pyx_k_add_language_1[] = "add_language(1)";
static const char __pyx_k_adjoint_matrix[] = "adjoint_matrix";
static const char __pyx_k_as_function_of[] = "as_function_of";
static const char __pyx_k_bezout_entiers[] = "bezout_entiers";
static const char __pyx_k_canonical_form[] = "canonical_form";
static const char __pyx_k_cap_round_line[] = "cap_round_line";
static const char __pyx_k_chisquare_icdf[] = "chisquare_icdf";
static const char __pyx_k_chisquared_cdf[] = "chisquared_cdf";
static const char __pyx_k_complete_graph[] = "complete_graph";
static const char __pyx_k_courbe_polaire[] = "courbe_polaire";
static const char __pyx_k_dessine_tortue[] = "dessine_tortue";
static const char __pyx_k_disjoint_union[] = "disjoint_union";
static const char __pyx_k_division_point[] = "division_point";
static const char __pyx_k_dnewton_solver[] = "dnewton_solver";
static const char __pyx_k_draw_rectangle[] = "draw_rectangle";
static const char __pyx_k_est_cocyclique[] = "est_cocyclique";
static const char __pyx_k_euler_lagrange[] = "euler_lagrange";
static const char __pyx_k_float2rational[] = "float2rational";
static const char __pyx_k_frobenius_norm[] = "frobenius_norm";
static const char __pyx_k_geometric_icdf[] = "geometric_icdf";
static const char __pyx_k_gl_x_axis_name[] = "gl_x_axis_name";
static const char __pyx_k_gl_x_axis_unit[] = "gl_x_axis_unit";
static const char __pyx_k_gl_y_axis_name[] = "gl_y_axis_name";
static const char __pyx_k_gl_y_axis_unit[] = "gl_y_axis_unit";
static const char __pyx_k_gl_z_axis_name[] = "gl_z_axis_name";
static const char __pyx_k_gl_z_axis_unit[] = "gl_z_axis_unit";
static const char __pyx_k_goldberg_snark[] = "goldberg_snark";
static const char __pyx_k_graph_charpoly[] = "graph_charpoly";
static const char __pyx_k_graph_diameter[] = "graph_diameter";
static const char __pyx_k_graph_spectrum[] = "graph_spectrum";
static const char __pyx_k_graph_vertices[] = "graph_vertices";
static const char __pyx_k_hamming_window[] = "hamming_window";
static const char __pyx_k_hybridj_solver[] = "hybridj_solver";
static const char __pyx_k_hybrids_solver[] = "hybrids_solver";
static const char __pyx_k_identify_graph[] = "identify_graph";
static const char __pyx_k_incident_edges[] = "incident_edges";
static const char __pyx_k_inequationplot[] = "inequationplot";
static const char __pyx_k_interval_graph[] = "interval_graph";
static const char __pyx_k_is_biconnected[] = "is_biconnected";
static const char __pyx_k_is_cospherical[] = "is_cospherical";
static const char __pyx_k_is_equilateral[] = "is_equilateral";
static const char __pyx_k_is_hamiltonian[] = "is_hamiltonian";
static const char __pyx_k_is_irreducible[] = "is_irreducible";
static const char __pyx_k_is_pseudoprime[] = "is_pseudoprime";
static const char __pyx_k_is_split_graph[] = "is_split_graph";
static const char __pyx_k_kernel_density[] = "kernel_density";
static const char __pyx_k_killing_thread[] = "killing thread";
static const char __pyx_k_left_rectangle[] = "left_rectangle";
static const char __pyx_k_lp_nonnegative[] = "lp_nonnegative";
static const char __pyx_k_maple_ifactors[] = "maple_ifactors";
static const char __pyx_k_maximum_clique[] = "maximum_clique";
static const char __pyx_k_maximum_degree[] = "maximum_degree";
static const char __pyx_k_minimum_degree[] = "minimum_degree";
static const char __pyx_k_moving_average[] = "moving_average";
static const char __pyx_k_mult_conjugate[] = "mult_conjugate";
static const char __pyx_k_neural_network[] = "neural_network";
static const char __pyx_k_newtonj_solver[] = "newtonj_solver";
static const char __pyx_k_parallelepiped[] = "parallelepiped";
static const char __pyx_k_perimeteratraw[] = "perimeteratraw";
static const char __pyx_k_petersen_graph[] = "petersen_graph";
static const char __pyx_k_plotinequation[] = "plotinequation";
static const char __pyx_k_point_triangle[] = "point_triangle";
static const char __pyx_k_poisson_window[] = "poisson_window";
static const char __pyx_k_qcas_line_1879[] = "qcas (line 1879)";
static const char __pyx_k_random_digraph[] = "random_digraph";
static const char __pyx_k_random_network[] = "random_network";
static const char __pyx_k_reverse_rsolve[] = "reverse_rsolve";
static const char __pyx_k_riemann_window[] = "riemann_window";
static const char __pyx_k_right_triangle[] = "right_triangle";
static const char __pyx_k_scalar_product[] = "scalar_product";
static const char __pyx_k_sequence_graph[] = "sequence_graph";
static const char __pyx_k_sign2Heaviside[] = "sign2Heaviside";
static const char __pyx_k_simplex_reduce[] = "simplex_reduce";
static const char __pyx_k_snedecord_icdf[] = "snedecord_icdf";
static const char __pyx_k_tensor_product[] = "tensor_product";
static const char __pyx_k_topologic_sort[] = "topologic_sort";
static const char __pyx_k_triangle_paper[] = "triangle_paper";
static const char __pyx_k_triangle_plein[] = "triangle_plein";
static const char __pyx_k_triangle_point[] = "triangle_point";
static const char __pyx_k_truncate_graph[] = "truncate_graph";
static const char __pyx_k_using_sendtext[] = "\"using sendtext\"";
static const char __pyx_k_weibullvariate[] = "weibullvariate";
static const char __pyx_k_wwwbrowseropen[] = "wwwbrowseropen";
static const char __pyx_k_wz_certificate[] = "wz_certificate";
static const char __pyx_k_Pygen_cas_setup[] = "Pygen.cas_setup";
static const char __pyx_k_antiprism_graph[] = "antiprism_graph";
static const char __pyx_k_blackman_window[] = "blackman_window";
static const char __pyx_k_box_constraints[] = "box_constraints";
static const char __pyx_k_cap_square_line[] = "cap_square_line";
static const char __pyx_k_center2interval[] = "center2interval";
static const char __pyx_k_chisquared_icdf[] = "chisquared_icdf";
static const char __pyx_k_chromatic_index[] = "chromatic_index";
static const char __pyx_k_dashdotdot_line[] = "dashdotdot_line";
static const char __pyx_k_degree_sequence[] = "degree_sequence";
static const char __pyx_k_droite_tangente[] = "droite_tangente";
static const char __pyx_k_exponential_cdf[] = "exponential_cdf";
static const char __pyx_k_extract_measure[] = "extract_measure";
static const char __pyx_k_falsepos_solver[] = "falsepos_solver";
static const char __pyx_k_flow_polynomial[] = "flow_polynomial";
static const char __pyx_k_gaussian_window[] = "gaussian_window";
static const char __pyx_k_gbasis_reinject[] = "gbasis_reinject";
static const char __pyx_k_get_edge_weight[] = "get_edge_weight";
static const char __pyx_k_gl_x_axis_color[] = "gl_x_axis_color";
static const char __pyx_k_gl_y_axis_color[] = "gl_y_axis_color";
static const char __pyx_k_gl_z_axis_color[] = "gl_z_axis_color";
static const char __pyx_k_halftan_hyp2exp[] = "halftan_hyp2exp";
static const char __pyx_k_highlight_edges[] = "highlight_edges";
static const char __pyx_k_highlight_trail[] = "highlight_trail";
static const char __pyx_k_hybridsj_solver[] = "hybridsj_solver";
static const char __pyx_k_hypercube_graph[] = "hypercube_graph";
static const char __pyx_k_interval2center[] = "interval2center";
static const char __pyx_k_invisible_point[] = "invisible_point";
static const char __pyx_k_is_arborescence[] = "is_arborescence";
static const char __pyx_k_is_triconnected[] = "is_triconnected";
static const char __pyx_k_isomorphic_copy[] = "isomorphic_copy";
static const char __pyx_k_jacobi_equation[] = "jacobi_equation";
static const char __pyx_k_jacobi_linsolve[] = "jacobi_linsolve";
static const char __pyx_k_katz_centrality[] = "katz_centrality";
static const char __pyx_k_legendre_symbol[] = "legendre_symbol";
static const char __pyx_k_lp_breadthfirst[] = "lp_breadthfirst";
static const char __pyx_k_lp_gaptolerance[] = "lp_gaptolerance";
static const char __pyx_k_negbinomial_cdf[] = "negbinomial_cdf";
static const char __pyx_k_nlp_nonnegative[] = "nlp_nonnegative";
static const char __pyx_k_number_of_edges[] = "number_of_edges";
static const char __pyx_k_pcar_hessenberg[] = "pcar_hessenberg";
static const char __pyx_k_perpen_bisector[] = "perpen_bisector";
static const char __pyx_k_point_invisible[] = "point_invisible";
static const char __pyx_k_polygone_rempli[] = "polygone_rempli";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_randmultinomial[] = "randmultinomial";
static const char __pyx_k_random_variable[] = "random_variable";
static const char __pyx_k_rectangle_droit[] = "rectangle_droit";
static const char __pyx_k_rectangle_plein[] = "rectangle_plein";
static const char __pyx_k_reduced_quadric[] = "reduced_quadric";
static const char __pyx_k_resoudre_dans_C[] = "resoudre_dans_C";
static const char __pyx_k_right_rectangle[] = "right_rectangle";
static const char __pyx_k_sans_factoriser[] = "sans_factoriser";
static const char __pyx_k_seidel_spectrum[] = "seidel_spectrum";
static const char __pyx_k_set_edge_weight[] = "set_edge_weight";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_subdivide_edges[] = "subdivide_edges";
static const char __pyx_k_triangle_window[] = "triangle_window";
static const char __pyx_k_vertex_distance[] = "vertex_distance";
static const char __pyx_k_GiacFunction_int[] = "GiacFunction.int";
static const char __pyx_k_GiacMethods_base[] = "GiacMethods_base";
static const char __pyx_k_Pygen__repr_html[] = "Pygen._repr_html_";
static const char __pyx_k_Pygen_threadeval[] = "Pygen.threadeval";
static const char __pyx_k_adjacency_matrix[] = "adjacency_matrix";
static const char __pyx_k_auto_correlation[] = "auto_correlation";
static const char __pyx_k_berlekamp_massey[] = "berlekamp_massey";
static const char __pyx_k_bisection_solver[] = "bisection_solver";
static const char __pyx_k_chromatic_number[] = "chromatic_number";
static const char __pyx_k_exponential_icdf[] = "exponential_icdf";
static const char __pyx_k_exponentiald_cdf[] = "exponentiald_cdf";
static const char __pyx_k_factoriser_sur_C[] = "factoriser_sur_C";
static const char __pyx_k_fonction_derivee[] = "fonction_derivee";
static const char __pyx_k_from_giac_s_help[] = "(from giac's help:)";
static const char __pyx_k_gbasis_max_pairs[] = "gbasis_max_pairs";
static const char __pyx_k_graph_complement[] = "graph_complement";
static const char __pyx_k_highlight_vertex[] = "highlight_vertex";
static const char __pyx_k_incidence_matrix[] = "incidence_matrix";
static const char __pyx_k_increasing_power[] = "increasing_power";
static const char __pyx_k_induced_subgraph[] = "induced_subgraph";
static const char __pyx_k_is_integer_graph[] = "is_integer_graph";
static const char __pyx_k_is_parallelogram[] = "is_parallelogram";
static const char __pyx_k_is_perpendicular[] = "is_perpendicular";
static const char __pyx_k_laplacian_matrix[] = "laplacian_matrix";
static const char __pyx_k_ligne_polygonale[] = "ligne_polygonale";
static const char __pyx_k_lineariser_trigo[] = "lineariser_trigo";
static const char __pyx_k_lp_interiorpoint[] = "lp_interiorpoint";
static const char __pyx_k_maximum_matching[] = "maximum_matching";
static const char __pyx_k_mult_c_conjugate[] = "mult_c_conjugate";
static const char __pyx_k_negbinomial_icdf[] = "negbinomial_icdf";
static const char __pyx_k_nlp_initialpoint[] = "nlp_initialpoint";
static const char __pyx_k_permute_vertices[] = "permute_vertices";
static const char __pyx_k_power_regression[] = "power_regression";
static const char __pyx_k_rassembler_trigo[] = "rassembler_trigo";
static const char __pyx_k_rectangle_gauche[] = "rectangle_gauche";
static const char __pyx_k_relabel_vertices[] = "relabel_vertices";
static const char __pyx_k_set_channel_data[] = "set_channel_data";
static const char __pyx_k_sierpinski_graph[] = "sierpinski_graph";
static const char __pyx_k_topological_sort[] = "topological_sort";
static const char __pyx_k_torus_grid_graph[] = "torus_grid_graph";
static const char __pyx_k_tutte_polynomial[] = "tutte_polynomial";
static const char __pyx_k_underlying_graph[] = "underlying_graph";
static const char __pyx_k_vertex_in_degree[] = "vertex_in_degree";
static const char __pyx_k_GiacFunction_diff[] = "GiacFunction.diff";
static const char __pyx_k_GiacFunction_plot[] = "GiacFunction.plot";
static const char __pyx_k_KeyboardInterrupt[] = "KeyboardInterrupt";
static const char __pyx_k_Ox_2d_unit_vector[] = "Ox_2d_unit_vector";
static const char __pyx_k_Ox_3d_unit_vector[] = "Ox_3d_unit_vector";
static const char __pyx_k_Oy_2d_unit_vector[] = "Oy_2d_unit_vector";
static const char __pyx_k_Oy_3d_unit_vector[] = "Oy_3d_unit_vector";
static const char __pyx_k_Oz_3d_unit_vector[] = "Oz_3d_unit_vector";
static const char __pyx_k_Pygen__repr_latex[] = "Pygen._repr_latex_";
static const char __pyx_k_allpairs_distance[] = "allpairs_distance";
static const char __pyx_k_cartesian_product[] = "cartesian_product";
static const char __pyx_k_complex_variables[] = "complex_variables";
static const char __pyx_k_contract_subgraph[] = "contract_subgraph";
static const char __pyx_k_cross_correlation[] = "cross_correlation";
static const char __pyx_k_degree_centrality[] = "degree_centrality";
static const char __pyx_k_edge_connectivity[] = "edge_connectivity";
static const char __pyx_k_epaisseur_ligne_1[] = "epaisseur_ligne_1";
static const char __pyx_k_epaisseur_ligne_2[] = "epaisseur_ligne_2";
static const char __pyx_k_epaisseur_ligne_3[] = "epaisseur_ligne_3";
static const char __pyx_k_epaisseur_ligne_4[] = "epaisseur_ligne_4";
static const char __pyx_k_epaisseur_ligne_5[] = "epaisseur_ligne_5";
static const char __pyx_k_epaisseur_ligne_6[] = "epaisseur_ligne_6";
static const char __pyx_k_epaisseur_ligne_7[] = "epaisseur_ligne_7";
static const char __pyx_k_epaisseur_point_1[] = "epaisseur_point_1";
static const char __pyx_k_epaisseur_point_2[] = "epaisseur_point_2";
static const char __pyx_k_epaisseur_point_3[] = "epaisseur_point_3";
static const char __pyx_k_epaisseur_point_4[] = "epaisseur_point_4";
static const char __pyx_k_epaisseur_point_5[] = "epaisseur_point_5";
static const char __pyx_k_epaisseur_point_6[] = "epaisseur_point_6";
static const char __pyx_k_epaisseur_point_7[] = "epaisseur_point_7";
static const char __pyx_k_exponentiald_icdf[] = "exponentiald_icdf";
static const char __pyx_k_facteurs_premiers[] = "facteurs_premiers";
static const char __pyx_k_factoriser_entier[] = "factoriser_entier";
static const char __pyx_k_find_vertex_cover[] = "find_vertex_cover";
static const char __pyx_k_fundamental_cycle[] = "fundamental_cycle";
static const char __pyx_k_giacpy_giacpy_pyx[] = "giacpy/giacpy.pyx";
static const char __pyx_k_harmonic_division[] = "harmonic_division";
static const char __pyx_k_ligne_tiret_point[] = "ligne_tiret_point";
static const char __pyx_k_ligne_trait_plein[] = "ligne_trait_plein";
static const char __pyx_k_linear_regression[] = "linear_regression";
static const char __pyx_k_lp_bestlocalbound[] = "lp_bestlocalbound";
static const char __pyx_k_lp_bestprojection[] = "lp_bestprojection";
static const char __pyx_k_lp_iterationlimit[] = "lp_iterationlimit";
static const char __pyx_k_lp_lastfractional[] = "lp_lastfractional";
static const char __pyx_k_lp_mostfractional[] = "lp_mostfractional";
static const char __pyx_k_osculating_circle[] = "osculating_circle";
static const char __pyx_k_polar_coordinates[] = "polar_coordinates";
static const char __pyx_k_random_tournament[] = "random_tournament";
static const char __pyx_k_steffenson_solver[] = "steffenson_solver";
static const char __pyx_k_vertex_out_degree[] = "vertex_out_degree";
static const char __pyx_k_Celsius2Fahrenheit[] = "Celsius2Fahrenheit";
static const char __pyx_k_Fahrenheit2Celsius[] = "Fahrenheit2Celsius";
static const char __pyx_k_GiacFunction___add[] = "GiacFunction.__add__";
static const char __pyx_k_GiacFunction___div[] = "GiacFunction.__div__";
static const char __pyx_k_GiacFunction___mul[] = "GiacFunction.__mul__";
static const char __pyx_k_GiacFunction___neg[] = "GiacFunction.__neg__";
static const char __pyx_k_GiacFunction___pow[] = "GiacFunction.__pow__";
static const char __pyx_k_GiacFunction___str[] = "GiacFunction.__str__";
static const char __pyx_k_GiacFunction___sub[] = "GiacFunction.__sub__";
static const char __pyx_k_GiacMethods_base_e[] = "GiacMethods_base.e";
static const char __pyx_k_all_trig_solutions[] = "all_trig_solutions";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_bipartite_matching[] = "bipartite_matching";
static const char __pyx_k_canonical_labeling[] = "canonical_labeling";
static const char __pyx_k_cas_monitor_status[] = "cas monitor status:";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_complete_kary_tree[] = "complete_kary_tree";
static const char __pyx_k_conjugate_equation[] = "conjugate_equation";
static const char __pyx_k_conjugate_gradient[] = "conjugate_gradient";
static const char __pyx_k_fin_enregistrement[] = "fin_enregistrement";
static const char __pyx_k_get_edge_attribute[] = "get_edge_attribute";
static const char __pyx_k_harmonic_conjugate[] = "harmonic_conjugate";
static const char __pyx_k_highlight_subgraph[] = "highlight_subgraph";
static const char __pyx_k_htmlhelp_line_1849[] = "htmlhelp (line 1849)";
static const char __pyx_k_isosceles_triangle[] = "isosceles_triangle";
static const char __pyx_k_ligne_chapeau_plat[] = "ligne_chapeau_plat";
static const char __pyx_k_ligne_chapeau_rond[] = "ligne_chapeau_rond";
static const char __pyx_k_linear_interpolate[] = "linear_interpolate";
static const char __pyx_k_lp_binaryvariables[] = "lp_binaryvariables";
static const char __pyx_k_lp_firstfractional[] = "lp_firstfractional";
static const char __pyx_k_nlp_iterationlimit[] = "nlp_iterationlimit";
static const char __pyx_k_number_of_vertices[] = "number_of_vertices";
static const char __pyx_k_polygonscatterplot[] = "polygonscatterplot";
static const char __pyx_k_set_edge_attribute[] = "set_edge_attribute";
static const char __pyx_k_taux_accroissement[] = "taux_accroissement";
static const char __pyx_k_transitive_closure[] = "transitive_closure";
static const char __pyx_k_traveling_salesman[] = "traveling_salesman";
static const char __pyx_k_GiacFunction___call[] = "GiacFunction.__call__";
static const char __pyx_k_GiacFunction___init[] = "GiacFunction.__init__";
static const char __pyx_k_GiacFunction___repr[] = "GiacFunction.__repr__";
static const char __pyx_k_GiacMethods_base_Ci[] = "GiacMethods_base.Ci";
static const char __pyx_k_GiacMethods_base_Ei[] = "GiacMethods_base.Ei";
static const char __pyx_k_GiacMethods_base_GF[] = "GiacMethods_base.GF";
static const char __pyx_k_GiacMethods_base_LU[] = "GiacMethods_base.LU";
static const char __pyx_k_GiacMethods_base_Li[] = "GiacMethods_base.Li";
static const char __pyx_k_GiacMethods_base_Pi[] = "GiacMethods_base.Pi";
static const char __pyx_k_GiacMethods_base_QR[] = "GiacMethods_base.QR";
static const char __pyx_k_GiacMethods_base_at[] = "GiacMethods_base.at";
static const char __pyx_k_GiacMethods_base_id[] = "GiacMethods_base.id";
static const char __pyx_k_GiacMethods_base_im[] = "GiacMethods_base.im";
static const char __pyx_k_GiacMethods_base_ln[] = "GiacMethods_base.ln";
static const char __pyx_k_GiacMethods_base_lu[] = "GiacMethods_base.lu";
static const char __pyx_k_GiacMethods_base_op[] = "GiacMethods_base.op";
static const char __pyx_k_GiacMethods_base_pi[] = "GiacMethods_base.pi";
static const char __pyx_k_GiacMethods_base_qr[] = "GiacMethods_base.qr";
static const char __pyx_k_GiacMethods_base_re[] = "GiacMethods_base.re";
static const char __pyx_k_GiacMethods_base_sq[] = "GiacMethods_base.sq";
static const char __pyx_k_articulation_points[] = "articulation_points";
static const char __pyx_k_assign_edge_weights[] = "assign_edge_weights";
static const char __pyx_k_clique_cover_number[] = "clique_cover_number";
static const char __pyx_k_courbe_parametrique[] = "courbe_parametrique";
static const char __pyx_k_get_graph_attribute[] = "get_graph_attribute";
static const char __pyx_k_graph_automorphisms[] = "graph_automorphisms";
static const char __pyx_k_graphe_probabiliste[] = "graphe_probabiliste";
static const char __pyx_k_hann_poisson_window[] = "hann_poisson_window";
static const char __pyx_k_harmonic_centrality[] = "harmonic_centrality";
static const char __pyx_k_independence_number[] = "independence_number";
static const char __pyx_k_interactive_odeplot[] = "interactive_odeplot";
static const char __pyx_k_interactive_plotode[] = "interactive_plotode";
static const char __pyx_k_is_graphic_sequence[] = "is_graphic_sequence";
static const char __pyx_k_is_strongly_regular[] = "is_strongly_regular";
static const char __pyx_k_is_vertex_colorable[] = "is_vertex_colorable";
static const char __pyx_k_ligne_chapeau_carre[] = "ligne_chapeau_carre";
static const char __pyx_k_logistic_regression[] = "logistic_regression";
static const char __pyx_k_lp_integervariables[] = "lp_integervariables";
static const char __pyx_k_moretests_line_2061[] = "moretests (line 2061)";
static const char __pyx_k_multiplier_conjugue[] = "multiplier_conjugue";
static const char __pyx_k_nlp_binaryvariables[] = "nlp_binaryvariables";
static const char __pyx_k_number_of_triangles[] = "number_of_triangles";
static const char __pyx_k_random_planar_graph[] = "random_planar_graph";
static const char __pyx_k_set_graph_attribute[] = "set_graph_attribute";
static const char __pyx_k_simplicial_vertices[] = "simplicial_vertices";
static const char __pyx_k_simulated_annealing[] = "simulated_annealing";
static const char __pyx_k_variables_are_files[] = "variables_are_files";
static const char __pyx_k_vertex_connectivity[] = "vertex_connectivity";
static const char __pyx_k_vertex_cover_number[] = "vertex_cover_number";
static const char __pyx_k_GiacMethods_base_Col[] = "GiacMethods_base.Col";
static const char __pyx_k_GiacMethods_base_MSE[] = "GiacMethods_base.MSE";
static const char __pyx_k_GiacMethods_base_Phi[] = "GiacMethods_base.Phi";
static const char __pyx_k_GiacMethods_base_Psi[] = "GiacMethods_base.Psi";
static const char __pyx_k_GiacMethods_base_Row[] = "GiacMethods_base.Row";
static const char __pyx_k_GiacMethods_base_VAS[] = "GiacMethods_base.VAS";
static const char __pyx_k_GiacMethods_base_a2q[] = "GiacMethods_base.a2q";
static const char __pyx_k_GiacMethods_base_abs[] = "GiacMethods_base.abs";
static const char __pyx_k_GiacMethods_base_add[] = "GiacMethods_base.add";
static const char __pyx_k_GiacMethods_base_ans[] = "GiacMethods_base.ans";
static const char __pyx_k_GiacMethods_base_arc[] = "GiacMethods_base.arc";
static const char __pyx_k_GiacMethods_base_arg[] = "GiacMethods_base.arg";
static const char __pyx_k_GiacMethods_base_cdf[] = "GiacMethods_base.cdf";
static const char __pyx_k_GiacMethods_base_chr[] = "GiacMethods_base.chr";
static const char __pyx_k_GiacMethods_base_col[] = "GiacMethods_base.col";
static const char __pyx_k_GiacMethods_base_cos[] = "GiacMethods_base.cos";
static const char __pyx_k_GiacMethods_base_cot[] = "GiacMethods_base.cot";
static const char __pyx_k_GiacMethods_base_csc[] = "GiacMethods_base.csc";
static const char __pyx_k_GiacMethods_base_det[] = "GiacMethods_base.det";
static const char __pyx_k_GiacMethods_base_dfc[] = "GiacMethods_base.dfc";
static const char __pyx_k_GiacMethods_base_dim[] = "GiacMethods_base.dim";
static const char __pyx_k_GiacMethods_base_dot[] = "GiacMethods_base.dot";
static const char __pyx_k_GiacMethods_base_dwt[] = "GiacMethods_base.dwt";
static const char __pyx_k_GiacMethods_base_e2r[] = "GiacMethods_base.e2r";
static const char __pyx_k_GiacMethods_base_egv[] = "GiacMethods_base.egv";
static const char __pyx_k_GiacMethods_base_emd[] = "GiacMethods_base.emd";
static const char __pyx_k_GiacMethods_base_erf[] = "GiacMethods_base.erf";
static const char __pyx_k_GiacMethods_base_exp[] = "GiacMethods_base.exp";
static const char __pyx_k_GiacMethods_base_fft[] = "GiacMethods_base.fft";
static const char __pyx_k_GiacMethods_base_gcd[] = "GiacMethods_base.gcd";
static const char __pyx_k_GiacMethods_base_has[] = "GiacMethods_base.has";
static const char __pyx_k_GiacMethods_base_hht[] = "GiacMethods_base.hht";
static const char __pyx_k_GiacMethods_base_hsv[] = "GiacMethods_base.hsv";
static const char __pyx_k_GiacMethods_base_idn[] = "GiacMethods_base.idn";
static const char __pyx_k_GiacMethods_base_inf[] = "GiacMethods_base.inf";
static const char __pyx_k_GiacMethods_base_int[] = "GiacMethods_base.int";
static const char __pyx_k_GiacMethods_base_inv[] = "GiacMethods_base.inv";
static const char __pyx_k_GiacMethods_base_kde[] = "GiacMethods_base.kde";
static const char __pyx_k_GiacMethods_base_ker[] = "GiacMethods_base.ker";
static const char __pyx_k_GiacMethods_base_lcm[] = "GiacMethods_base.lcm";
static const char __pyx_k_GiacMethods_base_ldl[] = "GiacMethods_base.ldl";
static const char __pyx_k_GiacMethods_base_lhs[] = "GiacMethods_base.lhs";
static const char __pyx_k_GiacMethods_base_lin[] = "GiacMethods_base.lin";
static const char __pyx_k_GiacMethods_base_lll[] = "GiacMethods_base.lll";
static const char __pyx_k_GiacMethods_base_log[] = "GiacMethods_base.log";
static const char __pyx_k_GiacMethods_base_lsq[] = "GiacMethods_base.lsq";
static const char __pyx_k_GiacMethods_base_map[] = "GiacMethods_base.map";
static const char __pyx_k_GiacMethods_base_max[] = "GiacMethods_base.max";
static const char __pyx_k_GiacMethods_base_mgf[] = "GiacMethods_base.mgf";
static const char __pyx_k_GiacMethods_base_mid[] = "GiacMethods_base.mid";
static const char __pyx_k_GiacMethods_base_min[] = "GiacMethods_base.min";
static const char __pyx_k_GiacMethods_base_mul[] = "GiacMethods_base.mul";
static const char __pyx_k_GiacMethods_base_nCr[] = "GiacMethods_base.nCr";
static const char __pyx_k_GiacMethods_base_nPr[] = "GiacMethods_base.nPr";
static const char __pyx_k_GiacMethods_base_nop[] = "GiacMethods_base.nop";
static const char __pyx_k_GiacMethods_base_odd[] = "GiacMethods_base.odd";
static const char __pyx_k_GiacMethods_base_ord[] = "GiacMethods_base.ord";
static const char __pyx_k_GiacMethods_base_pie[] = "GiacMethods_base.pie";
static const char __pyx_k_GiacMethods_base_pwd[] = "GiacMethods_base.pwd";
static const char __pyx_k_GiacMethods_base_q2a[] = "GiacMethods_base.q2a";
static const char __pyx_k_GiacMethods_base_quo[] = "GiacMethods_base.quo";
static const char __pyx_k_GiacMethods_base_r2e[] = "GiacMethods_base.r2e";
static const char __pyx_k_GiacMethods_base_red[] = "GiacMethods_base.red";
static const char __pyx_k_GiacMethods_base_ref[] = "GiacMethods_base.ref";
static const char __pyx_k_GiacMethods_base_rem[] = "GiacMethods_base.rem";
static const char __pyx_k_GiacMethods_base_rgb[] = "GiacMethods_base.rgb";
static const char __pyx_k_GiacMethods_base_rhs[] = "GiacMethods_base.rhs";
static const char __pyx_k_GiacMethods_base_rms[] = "GiacMethods_base.rms";
static const char __pyx_k_GiacMethods_base_row[] = "GiacMethods_base.row";
static const char __pyx_k_GiacMethods_base_rur[] = "GiacMethods_base.rur";
static const char __pyx_k_GiacMethods_base_sec[] = "GiacMethods_base.sec";
static const char __pyx_k_GiacMethods_base_seq[] = "GiacMethods_base.seq";
static const char __pyx_k_GiacMethods_base_sin[] = "GiacMethods_base.sin";
static const char __pyx_k_GiacMethods_base_sst[] = "GiacMethods_base.sst";
static const char __pyx_k_GiacMethods_base_str[] = "GiacMethods_base.str";
static const char __pyx_k_GiacMethods_base_sum[] = "GiacMethods_base.sum";
static const char __pyx_k_GiacMethods_base_svd[] = "GiacMethods_base.svd";
static const char __pyx_k_GiacMethods_base_tan[] = "GiacMethods_base.tan";
static const char __pyx_k_GiacMethods_base_tar[] = "GiacMethods_base.tar";
static const char __pyx_k_GiacMethods_base_tri[] = "GiacMethods_base.tri";
static const char __pyx_k_GiacMethods_base_trn[] = "GiacMethods_base.trn";
static const char __pyx_k_GiacMethods_base_zip[] = "GiacMethods_base.zip";
static const char __pyx_k_Pygen_qcas_line_1552[] = "Pygen.qcas (line 1552)";
static const char __pyx_k_Pygen_save_line_1469[] = "Pygen.save (line 1469)";
static const char __pyx_k_ThreadedPygen___call[] = "ThreadedPygen.__call__";
static const char __pyx_k_accumulate_head_tail[] = "accumulate_head_tail";
static const char __pyx_k_bartlett_hann_window[] = "bartlett_hann_window";
static const char __pyx_k_centered_tetrahedron[] = "centered_tetrahedron";
static const char __pyx_k_chromatic_polynomial[] = "chromatic_polynomial";
static const char __pyx_k_closeness_centrality[] = "closeness_centrality";
static const char __pyx_k_common_perpendicular[] = "common_perpendicular";
static const char __pyx_k_complete_binary_tree[] = "complete_binary_tree";
static const char __pyx_k_connected_components[] = "connected_components";
static const char __pyx_k_debut_enregistrement[] = "debut_enregistrement";
static const char __pyx_k_equilateral_triangle[] = "equilateral_triangle";
static const char __pyx_k_gbasis_simult_primes[] = "gbasis_simult_primes";
static const char __pyx_k_get_vertex_attribute[] = "get_vertex_attribute";
static const char __pyx_k_list_edge_attributes[] = "list_edge_attributes";
static const char __pyx_k_minimum_vertex_cover[] = "minimum_vertex_cover";
static const char __pyx_k_network_transitivity[] = "network_transitivity";
static const char __pyx_k_nlp_integervariables[] = "nlp_integervariables";
static const char __pyx_k_non_recursive_normal[] = "non_recursive_normal";
static const char __pyx_k_random_regular_graph[] = "random_regular_graph";
static const char __pyx_k_set_vertex_attribute[] = "set_vertex_attribute";
static const char __pyx_k_set_vertex_positions[] = "set_vertex_positions";
static const char __pyx_k_GiacFunction_htmlhelp[] = "GiacFunction.htmlhelp";
static const char __pyx_k_GiacMethods_base_Beta[] = "GiacMethods_base.Beta";
static const char __pyx_k_GiacMethods_base_Line[] = "GiacMethods_base.Line";
static const char __pyx_k_GiacMethods_base_ReLU[] = "GiacMethods_base.ReLU";
static const char __pyx_k_GiacMethods_base_UTPC[] = "GiacMethods_base.UTPC";
static const char __pyx_k_GiacMethods_base_UTPF[] = "GiacMethods_base.UTPF";
static const char __pyx_k_GiacMethods_base_UTPN[] = "GiacMethods_base.UTPN";
static const char __pyx_k_GiacMethods_base_UTPT[] = "GiacMethods_base.UTPT";
static const char __pyx_k_GiacMethods_base_VARS[] = "GiacMethods_base.VARS";
static const char __pyx_k_GiacMethods_base_Zeta[] = "GiacMethods_base.Zeta";
static const char __pyx_k_GiacMethods_base_acos[] = "GiacMethods_base.acos";
static const char __pyx_k_GiacMethods_base_acot[] = "GiacMethods_base.acot";
static const char __pyx_k_GiacMethods_base_acsc[] = "GiacMethods_base.acsc";
static const char __pyx_k_GiacMethods_base_area[] = "GiacMethods_base.area";
static const char __pyx_k_GiacMethods_base_asin[] = "GiacMethods_base.asin";
static const char __pyx_k_GiacMethods_base_atan[] = "GiacMethods_base.atan";
static const char __pyx_k_GiacMethods_base_axes[] = "GiacMethods_base.axes";
static const char __pyx_k_GiacMethods_base_axis[] = "GiacMethods_base.axis";
static const char __pyx_k_GiacMethods_base_back[] = "GiacMethods_base.back";
static const char __pyx_k_GiacMethods_base_base[] = "GiacMethods_base.base";
static const char __pyx_k_GiacMethods_base_bins[] = "GiacMethods_base.bins";
static const char __pyx_k_GiacMethods_base_ceil[] = "GiacMethods_base.ceil";
static const char __pyx_k_GiacMethods_base_char[] = "GiacMethods_base.char";
static const char __pyx_k_GiacMethods_base_comb[] = "GiacMethods_base.comb";
static const char __pyx_k_GiacMethods_base_cond[] = "GiacMethods_base.cond";
static const char __pyx_k_GiacMethods_base_cone[] = "GiacMethods_base.cone";
static const char __pyx_k_GiacMethods_base_conj[] = "GiacMethods_base.conj";
static const char __pyx_k_GiacMethods_base_cont[] = "GiacMethods_base.cont";
static const char __pyx_k_GiacMethods_base_copy[] = "GiacMethods_base.copy";
static const char __pyx_k_GiacMethods_base_cosh[] = "GiacMethods_base.cosh";
static const char __pyx_k_GiacMethods_base_cote[] = "GiacMethods_base.cote";
static const char __pyx_k_GiacMethods_base_cube[] = "GiacMethods_base.cube";
static const char __pyx_k_GiacMethods_base_curl[] = "GiacMethods_base.curl";
static const char __pyx_k_GiacMethods_base_cyan[] = "GiacMethods_base.cyan";
static const char __pyx_k_GiacMethods_base_diag[] = "GiacMethods_base.diag";
static const char __pyx_k_GiacMethods_base_diff[] = "GiacMethods_base.diff";
static const char __pyx_k_GiacMethods_base_dotP[] = "GiacMethods_base.dotP";
static const char __pyx_k_GiacMethods_base_egcd[] = "GiacMethods_base.egcd";
static const char __pyx_k_GiacMethods_base_egvl[] = "GiacMethods_base.egvl";
static const char __pyx_k_GiacMethods_base_erfc[] = "GiacMethods_base.erfc";
static const char __pyx_k_GiacMethods_base_even[] = "GiacMethods_base.even";
static const char __pyx_k_GiacMethods_base_expr[] = "GiacMethods_base.expr";
static const char __pyx_k_GiacMethods_base_f2nd[] = "GiacMethods_base.f2nd";
static const char __pyx_k_GiacMethods_base_fMax[] = "GiacMethods_base.fMax";
static const char __pyx_k_GiacMethods_base_fMin[] = "GiacMethods_base.fMin";
static const char __pyx_k_GiacMethods_base_find[] = "GiacMethods_base.find";
static const char __pyx_k_GiacMethods_base_fmod[] = "GiacMethods_base.fmod";
static const char __pyx_k_GiacMethods_base_frac[] = "GiacMethods_base.frac";
static const char __pyx_k_GiacMethods_base_fxnd[] = "GiacMethods_base.fxnd";
static const char __pyx_k_GiacMethods_base_gold[] = "GiacMethods_base.gold";
static const char __pyx_k_GiacMethods_base_grad[] = "GiacMethods_base.grad";
static const char __pyx_k_GiacMethods_base_grey[] = "GiacMethods_base.grey";
static const char __pyx_k_GiacMethods_base_halt[] = "GiacMethods_base.halt";
static const char __pyx_k_GiacMethods_base_head[] = "GiacMethods_base.head";
static const char __pyx_k_GiacMethods_base_hold[] = "GiacMethods_base.hold";
static const char __pyx_k_GiacMethods_base_ibpu[] = "GiacMethods_base.ibpu";
static const char __pyx_k_GiacMethods_base_icdf[] = "GiacMethods_base.icdf";
static const char __pyx_k_GiacMethods_base_idwt[] = "GiacMethods_base.idwt";
static const char __pyx_k_GiacMethods_base_igcd[] = "GiacMethods_base.igcd";
static const char __pyx_k_GiacMethods_base_imag[] = "GiacMethods_base.imag";
static const char __pyx_k_GiacMethods_base_iquo[] = "GiacMethods_base.iquo";
static const char __pyx_k_GiacMethods_base_irem[] = "GiacMethods_base.irem";
static const char __pyx_k_GiacMethods_base_isom[] = "GiacMethods_base.isom";
static const char __pyx_k_GiacMethods_base_join[] = "GiacMethods_base.join";
static const char __pyx_k_GiacMethods_base_left[] = "GiacMethods_base.left";
static const char __pyx_k_GiacMethods_base_lgcd[] = "GiacMethods_base.lgcd";
static const char __pyx_k_GiacMethods_base_line[] = "GiacMethods_base.line";
static const char __pyx_k_GiacMethods_base_log2[] = "GiacMethods_base.log2";
static const char __pyx_k_GiacMethods_base_logb[] = "GiacMethods_base.logb";
static const char __pyx_k_GiacMethods_base_lvar[] = "GiacMethods_base.lvar";
static const char __pyx_k_GiacMethods_base_mRow[] = "GiacMethods_base.mRow";
static const char __pyx_k_GiacMethods_base_mean[] = "GiacMethods_base.mean";
static const char __pyx_k_GiacMethods_base_mksa[] = "GiacMethods_base.mksa";
static const char __pyx_k_GiacMethods_base_modf[] = "GiacMethods_base.modf";
static const char __pyx_k_GiacMethods_base_mods[] = "GiacMethods_base.mods";
static const char __pyx_k_GiacMethods_base_nInt[] = "GiacMethods_base.nInt";
static const char __pyx_k_GiacMethods_base_navy[] = "GiacMethods_base.navy";
static const char __pyx_k_GiacMethods_base_nops[] = "GiacMethods_base.nops";
static const char __pyx_k_GiacMethods_base_norm[] = "GiacMethods_base.norm";
static const char __pyx_k_GiacMethods_base_pade[] = "GiacMethods_base.pade";
static const char __pyx_k_GiacMethods_base_pari[] = "GiacMethods_base.pari";
static const char __pyx_k_GiacMethods_base_part[] = "GiacMethods_base.part";
static const char __pyx_k_GiacMethods_base_pcar[] = "GiacMethods_base.pcar";
static const char __pyx_k_GiacMethods_base_perm[] = "GiacMethods_base.perm";
static const char __pyx_k_GiacMethods_base_pink[] = "GiacMethods_base.pink";
static const char __pyx_k_GiacMethods_base_plex[] = "GiacMethods_base.plex";
static const char __pyx_k_GiacMethods_base_plot[] = "GiacMethods_base.plot";
static const char __pyx_k_GiacMethods_base_pmin[] = "GiacMethods_base.pmin";
static const char __pyx_k_GiacMethods_base_pole[] = "GiacMethods_base.pole";
static const char __pyx_k_GiacMethods_base_rand[] = "GiacMethods_base.rand";
static const char __pyx_k_GiacMethods_base_rank[] = "GiacMethods_base.rank";
static const char __pyx_k_GiacMethods_base_ranm[] = "GiacMethods_base.ranm";
static const char __pyx_k_GiacMethods_base_ranv[] = "GiacMethods_base.ranv";
static const char __pyx_k_GiacMethods_base_rdiv[] = "GiacMethods_base.rdiv";
static const char __pyx_k_GiacMethods_base_read[] = "GiacMethods_base.read";
static const char __pyx_k_GiacMethods_base_real[] = "GiacMethods_base.real";
static const char __pyx_k_GiacMethods_base_rect[] = "GiacMethods_base.rect";
static const char __pyx_k_GiacMethods_base_rond[] = "GiacMethods_base.rond";
static const char __pyx_k_GiacMethods_base_root[] = "GiacMethods_base.root";
static const char __pyx_k_GiacMethods_base_rref[] = "GiacMethods_base.rref";
static const char __pyx_k_GiacMethods_base_same[] = "GiacMethods_base.same";
static const char __pyx_k_GiacMethods_base_sign[] = "GiacMethods_base.sign";
static const char __pyx_k_GiacMethods_base_sinc[] = "GiacMethods_base.sinc";
static const char __pyx_k_GiacMethods_base_sinh[] = "GiacMethods_base.sinh";
static const char __pyx_k_GiacMethods_base_smod[] = "GiacMethods_base.smod";
static const char __pyx_k_GiacMethods_base_sort[] = "GiacMethods_base.sort";
static const char __pyx_k_GiacMethods_base_sqrt[] = "GiacMethods_base.sqrt";
static const char __pyx_k_GiacMethods_base_stft[] = "GiacMethods_base.stft";
static const char __pyx_k_GiacMethods_base_subs[] = "GiacMethods_base.subs";
static const char __pyx_k_GiacMethods_base_surd[] = "GiacMethods_base.surd";
static const char __pyx_k_GiacMethods_base_tail[] = "GiacMethods_base.tail";
static const char __pyx_k_GiacMethods_base_tanh[] = "GiacMethods_base.tanh";
static const char __pyx_k_GiacMethods_base_tdeg[] = "GiacMethods_base.tdeg";
static const char __pyx_k_GiacMethods_base_teal[] = "GiacMethods_base.teal";
static const char __pyx_k_GiacMethods_base_tlin[] = "GiacMethods_base.tlin";
static const char __pyx_k_GiacMethods_base_tran[] = "GiacMethods_base.tran";
static const char __pyx_k_GiacMethods_base_tree[] = "GiacMethods_base.tree";
static const char __pyx_k_GiacMethods_base_trim[] = "GiacMethods_base.trim";
static const char __pyx_k_GiacMethods_base_true[] = "GiacMethods_base.true";
static const char __pyx_k_GiacMethods_base_tuer[] = "GiacMethods_base.tuer";
static const char __pyx_k_GiacMethods_base_type[] = "GiacMethods_base.type";
static const char __pyx_k_Pygen___reduce_cython[] = "Pygen.__reduce_cython__";
static const char __pyx_k_Pygen_redim_line_1526[] = "Pygen.redim (line 1526)";
static const char __pyx_k_cumulated_frequencies[] = "cumulated_frequencies";
static const char __pyx_k_ecart_type_population[] = "ecart_type_population";
static const char __pyx_k_gauss_seidel_linsolve[] = "gauss_seidel_linsolve";
static const char __pyx_k_is_strongly_connected[] = "is_strongly_connected";
static const char __pyx_k_is_two_edge_connected[] = "is_two_edge_connected";
static const char __pyx_k_list_graph_attributes[] = "list_graph_attributes";
static const char __pyx_k_loadgiacgen_line_2106[] = "loadgiacgen (line 2106)";
static const char __pyx_k_minimal_edge_coloring[] = "minimal_edge_coloring";
static const char __pyx_k_minimal_spanning_tree[] = "minimal_spanning_tree";
static const char __pyx_k_polynomial_regression[] = "polynomial_regression";
static const char __pyx_k_power_regression_plot[] = "power_regression_plot";
static const char __pyx_k_random_sequence_graph[] = "random_sequence_graph";
static const char __pyx_k_GiacFunction___truediv[] = "GiacFunction.__truediv__";
static const char __pyx_k_GiacMethods_base_Dirac[] = "GiacMethods_base.Dirac";
static const char __pyx_k_GiacMethods_base_Gamma[] = "GiacMethods_base.Gamma";
static const char __pyx_k_GiacMethods_base_SortA[] = "GiacMethods_base.SortA";
static const char __pyx_k_GiacMethods_base_SortD[] = "GiacMethods_base.SortD";
static const char __pyx_k_GiacMethods_base_abcuv[] = "GiacMethods_base.abcuv";
static const char __pyx_k_GiacMethods_base_about[] = "GiacMethods_base.about";
static const char __pyx_k_GiacMethods_base_acosh[] = "GiacMethods_base.acosh";
static const char __pyx_k_GiacMethods_base_affix[] = "GiacMethods_base.affix";
static const char __pyx_k_GiacMethods_base_angle[] = "GiacMethods_base.angle";
static const char __pyx_k_GiacMethods_base_apply[] = "GiacMethods_base.apply";
static const char __pyx_k_GiacMethods_base_array[] = "GiacMethods_base.array";
static const char __pyx_k_GiacMethods_base_asinh[] = "GiacMethods_base.asinh";
static const char __pyx_k_GiacMethods_base_atan2[] = "GiacMethods_base.atan2";
static const char __pyx_k_GiacMethods_base_atanh[] = "GiacMethods_base.atanh";
static const char __pyx_k_GiacMethods_base_avgRC[] = "GiacMethods_base.avgRC";
static const char __pyx_k_GiacMethods_base_basis[] = "GiacMethods_base.basis";
static const char __pyx_k_GiacMethods_base_betad[] = "GiacMethods_base.betad";
static const char __pyx_k_GiacMethods_base_bitor[] = "GiacMethods_base.bitor";
static const char __pyx_k_GiacMethods_base_brown[] = "GiacMethods_base.brown";
static const char __pyx_k_GiacMethods_base_chrem[] = "GiacMethods_base.chrem";
static const char __pyx_k_GiacMethods_base_clear[] = "GiacMethods_base.clear";
static const char __pyx_k_GiacMethods_base_coeff[] = "GiacMethods_base.coeff";
static const char __pyx_k_GiacMethods_base_color[] = "GiacMethods_base.color";
static const char __pyx_k_GiacMethods_base_conic[] = "GiacMethods_base.conic";
static const char __pyx_k_GiacMethods_base_count[] = "GiacMethods_base.count";
static const char __pyx_k_GiacMethods_base_cross[] = "GiacMethods_base.cross";
static const char __pyx_k_GiacMethods_base_curve[] = "GiacMethods_base.curve";
static const char __pyx_k_GiacMethods_base_denom[] = "GiacMethods_base.denom";
static const char __pyx_k_GiacMethods_base_dfc2f[] = "GiacMethods_base.dfc2f";
static const char __pyx_k_GiacMethods_base_divis[] = "GiacMethods_base.divis";
static const char __pyx_k_GiacMethods_base_divpc[] = "GiacMethods_base.divpc";
static const char __pyx_k_GiacMethods_base_droit[] = "GiacMethods_base.droit";
static const char __pyx_k_GiacMethods_base_edges[] = "GiacMethods_base.edges";
static const char __pyx_k_GiacMethods_base_eigVc[] = "GiacMethods_base.eigVc";
static const char __pyx_k_GiacMethods_base_eigVl[] = "GiacMethods_base.eigVl";
static const char __pyx_k_GiacMethods_base_entry[] = "GiacMethods_base.entry";
static const char __pyx_k_GiacMethods_base_equal[] = "GiacMethods_base.equal";
static const char __pyx_k_GiacMethods_base_error[] = "GiacMethods_base.error";
static const char __pyx_k_GiacMethods_base_euler[] = "GiacMethods_base.euler";
static const char __pyx_k_GiacMethods_base_evala[] = "GiacMethods_base.evala";
static const char __pyx_k_GiacMethods_base_evalb[] = "GiacMethods_base.evalb";
static const char __pyx_k_GiacMethods_base_evalc[] = "GiacMethods_base.evalc";
static const char __pyx_k_GiacMethods_base_evalf[] = "GiacMethods_base.evalf";
static const char __pyx_k_GiacMethods_base_evalm[] = "GiacMethods_base.evalm";
static const char __pyx_k_GiacMethods_base_exact[] = "GiacMethods_base.exact";
static const char __pyx_k_GiacMethods_base_expln[] = "GiacMethods_base.expln";
static const char __pyx_k_GiacMethods_base_ezgcd[] = "GiacMethods_base.ezgcd";
static const char __pyx_k_GiacMethods_base_fPart[] = "GiacMethods_base.fPart";
static const char __pyx_k_GiacMethods_base_faces[] = "GiacMethods_base.faces";
static const char __pyx_k_GiacMethods_base_false[] = "GiacMethods_base.false";
static const char __pyx_k_GiacMethods_base_floor[] = "GiacMethods_base.floor";
static const char __pyx_k_GiacMethods_base_foldl[] = "GiacMethods_base.foldl";
static const char __pyx_k_GiacMethods_base_foldr[] = "GiacMethods_base.foldr";
static const char __pyx_k_GiacMethods_base_froot[] = "GiacMethods_base.froot";
static const char __pyx_k_GiacMethods_base_gauss[] = "GiacMethods_base.gauss";
static const char __pyx_k_GiacMethods_base_gcdex[] = "GiacMethods_base.gcdex";
static const char __pyx_k_GiacMethods_base_girth[] = "GiacMethods_base.girth";
static const char __pyx_k_GiacMethods_base_graph[] = "GiacMethods_base.graph";
static const char __pyx_k_GiacMethods_base_iPart[] = "GiacMethods_base.iPart";
static const char __pyx_k_GiacMethods_base_ibpdv[] = "GiacMethods_base.ibpdv";
static const char __pyx_k_GiacMethods_base_icomp[] = "GiacMethods_base.icomp";
static const char __pyx_k_GiacMethods_base_iegcd[] = "GiacMethods_base.iegcd";
static const char __pyx_k_GiacMethods_base_image[] = "GiacMethods_base.image";
static const char __pyx_k_GiacMethods_base_index[] = "GiacMethods_base.index";
static const char __pyx_k_GiacMethods_base_inter[] = "GiacMethods_base.inter";
static const char __pyx_k_GiacMethods_base_isinf[] = "GiacMethods_base.isinf";
static const char __pyx_k_GiacMethods_base_isnan[] = "GiacMethods_base.isnan";
static const char __pyx_k_GiacMethods_base_istft[] = "GiacMethods_base.istft";
static const char __pyx_k_GiacMethods_base_latex[] = "GiacMethods_base.latex";
static const char __pyx_k_GiacMethods_base_limit[] = "GiacMethods_base.limit";
static const char __pyx_k_GiacMethods_base_lname[] = "GiacMethods_base.lname";
static const char __pyx_k_GiacMethods_base_locus[] = "GiacMethods_base.locus";
static const char __pyx_k_GiacMethods_base_log10[] = "GiacMethods_base.log10";
static const char __pyx_k_GiacMethods_base_lower[] = "GiacMethods_base.lower";
static const char __pyx_k_GiacMethods_base_lsmod[] = "GiacMethods_base.lsmod";
static const char __pyx_k_GiacMethods_base_moyal[] = "GiacMethods_base.moyal";
static const char __pyx_k_GiacMethods_base_ncols[] = "GiacMethods_base.ncols";
static const char __pyx_k_GiacMethods_base_nrows[] = "GiacMethods_base.nrows";
static const char __pyx_k_GiacMethods_base_nstep[] = "GiacMethods_base.nstep";
static const char __pyx_k_GiacMethods_base_numer[] = "GiacMethods_base.numer";
static const char __pyx_k_GiacMethods_base_olive[] = "GiacMethods_base.olive";
static const char __pyx_k_GiacMethods_base_order[] = "GiacMethods_base.order";
static const char __pyx_k_GiacMethods_base_p1oc2[] = "GiacMethods_base.p1oc2";
static const char __pyx_k_GiacMethods_base_p1op2[] = "GiacMethods_base.p1op2";
static const char __pyx_k_GiacMethods_base_pa2b2[] = "GiacMethods_base.pa2b2";
static const char __pyx_k_GiacMethods_base_pcoef[] = "GiacMethods_base.pcoef";
static const char __pyx_k_GiacMethods_base_penup[] = "GiacMethods_base.penup";
static const char __pyx_k_GiacMethods_base_peval[] = "GiacMethods_base.peval";
static const char __pyx_k_GiacMethods_base_pivot[] = "GiacMethods_base.pivot";
static const char __pyx_k_GiacMethods_base_pixon[] = "GiacMethods_base.pixon";
static const char __pyx_k_GiacMethods_base_plane[] = "GiacMethods_base.plane";
static const char __pyx_k_GiacMethods_base_point[] = "GiacMethods_base.point";
static const char __pyx_k_GiacMethods_base_polar[] = "GiacMethods_base.polar";
static const char __pyx_k_GiacMethods_base_prism[] = "GiacMethods_base.prism";
static const char __pyx_k_GiacMethods_base_proot[] = "GiacMethods_base.proot";
static const char __pyx_k_GiacMethods_base_ptayl[] = "GiacMethods_base.ptayl";
static const char __pyx_k_GiacMethods_base_purge[] = "GiacMethods_base.purge";
static const char __pyx_k_GiacMethods_base_quest[] = "GiacMethods_base.quest";
static const char __pyx_k_GiacMethods_base_quote[] = "GiacMethods_base.quote";
static const char __pyx_k_GiacMethods_base_right[] = "GiacMethods_base.right";
static const char __pyx_k_GiacMethods_base_risch[] = "GiacMethods_base.risch";
static const char __pyx_k_GiacMethods_base_rmmod[] = "GiacMethods_base.rmmod";
static const char __pyx_k_GiacMethods_base_roots[] = "GiacMethods_base.roots";
static const char __pyx_k_GiacMethods_base_round[] = "GiacMethods_base.round";
static const char __pyx_k_GiacMethods_base_saute[] = "GiacMethods_base.saute";
static const char __pyx_k_GiacMethods_base_schur[] = "GiacMethods_base.schur";
static const char __pyx_k_GiacMethods_base_shift[] = "GiacMethods_base.shift";
static const char __pyx_k_GiacMethods_base_signe[] = "GiacMethods_base.signe";
static const char __pyx_k_GiacMethods_base_simp2[] = "GiacMethods_base.simp2";
static const char __pyx_k_GiacMethods_base_sizes[] = "GiacMethods_base.sizes";
static const char __pyx_k_GiacMethods_base_slope[] = "GiacMethods_base.slope";
static const char __pyx_k_GiacMethods_base_smith[] = "GiacMethods_base.smith";
static const char __pyx_k_GiacMethods_base_solve[] = "GiacMethods_base.solve";
static const char __pyx_k_GiacMethods_base_somme[] = "GiacMethods_base.somme";
static const char __pyx_k_GiacMethods_base_sorta[] = "GiacMethods_base.sorta";
static const char __pyx_k_GiacMethods_base_sortd[] = "GiacMethods_base.sortd";
static const char __pyx_k_GiacMethods_base_split[] = "GiacMethods_base.split";
static const char __pyx_k_GiacMethods_base_srand[] = "GiacMethods_base.srand";
static const char __pyx_k_GiacMethods_base_strip[] = "GiacMethods_base.strip";
static const char __pyx_k_GiacMethods_base_sturm[] = "GiacMethods_base.sturm";
static const char __pyx_k_GiacMethods_base_style[] = "GiacMethods_base.style";
static const char __pyx_k_GiacMethods_base_subst[] = "GiacMethods_base.subst";
static const char __pyx_k_GiacMethods_base_table[] = "GiacMethods_base.table";
static const char __pyx_k_GiacMethods_base_throw[] = "GiacMethods_base.throw";
static const char __pyx_k_GiacMethods_base_title[] = "GiacMethods_base.title";
static const char __pyx_k_GiacMethods_base_titre[] = "GiacMethods_base.titre";
static const char __pyx_k_GiacMethods_base_trace[] = "GiacMethods_base.trace";
static const char __pyx_k_GiacMethods_base_trail[] = "GiacMethods_base.trail";
static const char __pyx_k_GiacMethods_base_train[] = "GiacMethods_base.train";
static const char __pyx_k_GiacMethods_base_trunc[] = "GiacMethods_base.trunc";
static const char __pyx_k_GiacMethods_base_tstep[] = "GiacMethods_base.tstep";
static const char __pyx_k_GiacMethods_base_undef[] = "GiacMethods_base.undef";
static const char __pyx_k_GiacMethods_base_unitV[] = "GiacMethods_base.unitV";
static const char __pyx_k_GiacMethods_base_upper[] = "GiacMethods_base.upper";
static const char __pyx_k_GiacMethods_base_ustep[] = "GiacMethods_base.ustep";
static const char __pyx_k_GiacMethods_base_vstep[] = "GiacMethods_base.vstep";
static const char __pyx_k_GiacMethods_base_xstep[] = "GiacMethods_base.xstep";
static const char __pyx_k_GiacMethods_base_ystep[] = "GiacMethods_base.ystep";
static const char __pyx_k_GiacMethods_base_zeros[] = "GiacMethods_base.zeros";
static const char __pyx_k_GiacMethods_base_zstep[] = "GiacMethods_base.zstep";
static const char __pyx_k_betweenness_centrality[] = "betweenness_centrality";
static const char __pyx_k_biconnected_components[] = "biconnected_components";
static const char __pyx_k_blackman_harris_window[] = "blackman_harris_window";
static const char __pyx_k_clustering_coefficient[] = "clustering_coefficient";
static const char __pyx_k_covariance_correlation[] = "covariance_correlation";
static const char __pyx_k_discard_edge_attribute[] = "discard_edge_attribute";
static const char __pyx_k_exponential_regression[] = "exponential_regression";
static const char __pyx_k_greedy_independent_set[] = "greedy_independent_set";
static const char __pyx_k_information_centrality[] = "information_centrality";
static const char __pyx_k_is_subgraph_isomorphic[] = "is_subgraph_isomorphic";
static const char __pyx_k_ligne_tiret_pointpoint[] = "ligne_tiret_pointpoint";
static const char __pyx_k_linear_regression_plot[] = "linear_regression_plot";
static const char __pyx_k_list_vertex_attributes[] = "list_vertex_attributes";
static const char __pyx_k_logarithmic_regression[] = "logarithmic_regression";
static const char __pyx_k_lowest_common_ancestor[] = "lowest_common_ancestor";
static const char __pyx_k_random_bipartite_graph[] = "random_bipartite_graph";
static const char __pyx_k_reliability_polynomial[] = "reliability_polynomial";
static const char __pyx_k_warning_Killing_thread[] = "warning: Killing thread";
static const char __pyx_k_GiacMethods_base_Circle[] = "GiacMethods_base.Circle";
static const char __pyx_k_GiacMethods_base_Factor[] = "GiacMethods_base.Factor";
static const char __pyx_k_GiacMethods_base_algvar[] = "GiacMethods_base.algvar";
static const char __pyx_k_GiacMethods_base_alog10[] = "GiacMethods_base.alog10";
static const char __pyx_k_GiacMethods_base_append[] = "GiacMethods_base.append";
static const char __pyx_k_GiacMethods_base_approx[] = "GiacMethods_base.approx";
static const char __pyx_k_GiacMethods_base_arcLen[] = "GiacMethods_base.arcLen";
static const char __pyx_k_GiacMethods_base_arccos[] = "GiacMethods_base.arccos";
static const char __pyx_k_GiacMethods_base_arclen[] = "GiacMethods_base.arclen";
static const char __pyx_k_GiacMethods_base_arcsin[] = "GiacMethods_base.arcsin";
static const char __pyx_k_GiacMethods_base_arctan[] = "GiacMethods_base.arctan";
static const char __pyx_k_GiacMethods_base_areaat[] = "GiacMethods_base.areaat";
static const char __pyx_k_GiacMethods_base_assume[] = "GiacMethods_base.assume";
static const char __pyx_k_GiacMethods_base_avance[] = "GiacMethods_base.avance";
static const char __pyx_k_GiacMethods_base_batons[] = "GiacMethods_base.batons";
static const char __pyx_k_GiacMethods_base_bezier[] = "GiacMethods_base.bezier";
static const char __pyx_k_GiacMethods_base_bitand[] = "GiacMethods_base.bitand";
static const char __pyx_k_GiacMethods_base_bitxor[] = "GiacMethods_base.bitxor";
static const char __pyx_k_GiacMethods_base_border[] = "GiacMethods_base.border";
static const char __pyx_k_GiacMethods_base_boxcar[] = "GiacMethods_base.boxcar";
static const char __pyx_k_GiacMethods_base_cSolve[] = "GiacMethods_base.cSolve";
static const char __pyx_k_GiacMethods_base_cZeros[] = "GiacMethods_base.cZeros";
static const char __pyx_k_GiacMethods_base_cauchy[] = "GiacMethods_base.cauchy";
static const char __pyx_k_GiacMethods_base_center[] = "GiacMethods_base.center";
static const char __pyx_k_GiacMethods_base_choice[] = "GiacMethods_base.choice";
static const char __pyx_k_GiacMethods_base_circle[] = "GiacMethods_base.circle";
static const char __pyx_k_GiacMethods_base_coeffs[] = "GiacMethods_base.coeffs";
static const char __pyx_k_GiacMethods_base_colDim[] = "GiacMethods_base.colDim";
static const char __pyx_k_GiacMethods_base_coldim[] = "GiacMethods_base.coldim";
static const char __pyx_k_GiacMethods_base_concat[] = "GiacMethods_base.concat";
static const char __pyx_k_GiacMethods_base_convex[] = "GiacMethods_base.convex";
static const char __pyx_k_GiacMethods_base_crayon[] = "GiacMethods_base.crayon";
static const char __pyx_k_GiacMethods_base_crossP[] = "GiacMethods_base.crossP";
static const char __pyx_k_GiacMethods_base_csolve[] = "GiacMethods_base.csolve";
static const char __pyx_k_GiacMethods_base_cumSum[] = "GiacMethods_base.cumSum";
static const char __pyx_k_GiacMethods_base_cumsum[] = "GiacMethods_base.cumsum";
static const char __pyx_k_GiacMethods_base_degree[] = "GiacMethods_base.degree";
static const char __pyx_k_GiacMethods_base_derive[] = "GiacMethods_base.derive";
static const char __pyx_k_GiacMethods_base_disque[] = "GiacMethods_base.disque";
static const char __pyx_k_GiacMethods_base_divide[] = "GiacMethods_base.divide";
static const char __pyx_k_GiacMethods_base_divmod[] = "GiacMethods_base.divmod";
static const char __pyx_k_GiacMethods_base_domain[] = "GiacMethods_base.domain";
static const char __pyx_k_GiacMethods_base_dsolve[] = "GiacMethods_base.dsolve";
static const char __pyx_k_GiacMethods_base_expand[] = "GiacMethods_base.expand";
static const char __pyx_k_GiacMethods_base_extend[] = "GiacMethods_base.extend";
static const char __pyx_k_GiacMethods_base_factor[] = "GiacMethods_base.factor";
static const char __pyx_k_GiacMethods_base_fadeev[] = "GiacMethods_base.fadeev";
static const char __pyx_k_GiacMethods_base_fclose[] = "GiacMethods_base.fclose";
static const char __pyx_k_GiacMethods_base_fcoeff[] = "GiacMethods_base.fcoeff";
static const char __pyx_k_GiacMethods_base_fisher[] = "GiacMethods_base.fisher";
static const char __pyx_k_GiacMethods_base_fprint[] = "GiacMethods_base.fprint";
static const char __pyx_k_GiacMethods_base_fsolve[] = "GiacMethods_base.fsolve";
static const char __pyx_k_GiacMethods_base_gammad[] = "GiacMethods_base.gammad";
static const char __pyx_k_GiacMethods_base_gbasis[] = "GiacMethods_base.gbasis";
static const char __pyx_k_GiacMethods_base_getKey[] = "GiacMethods_base.getKey";
static const char __pyx_k_GiacMethods_base_getNum[] = "GiacMethods_base.getNum";
static const char __pyx_k_GiacMethods_base_hasard[] = "GiacMethods_base.hasard";
static const char __pyx_k_GiacMethods_base_heugcd[] = "GiacMethods_base.heugcd";
static const char __pyx_k_GiacMethods_base_horner[] = "GiacMethods_base.horner";
static const char __pyx_k_GiacMethods_base_iabcuv[] = "GiacMethods_base.iabcuv";
static const char __pyx_k_GiacMethods_base_ibasis[] = "GiacMethods_base.ibasis";
static const char __pyx_k_GiacMethods_base_ichrem[] = "GiacMethods_base.ichrem";
static const char __pyx_k_GiacMethods_base_idivis[] = "GiacMethods_base.idivis";
static const char __pyx_k_GiacMethods_base_igamma[] = "GiacMethods_base.igamma";
static const char __pyx_k_GiacMethods_base_igcdex[] = "GiacMethods_base.igcdex";
static const char __pyx_k_GiacMethods_base_indets[] = "GiacMethods_base.indets";
static const char __pyx_k_GiacMethods_base_insert[] = "GiacMethods_base.insert";
static const char __pyx_k_GiacMethods_base_insmod[] = "GiacMethods_base.insmod";
static const char __pyx_k_GiacMethods_base_intDiv[] = "GiacMethods_base.intDiv";
static const char __pyx_k_GiacMethods_base_interp[] = "GiacMethods_base.interp";
static const char __pyx_k_GiacMethods_base_ismith[] = "GiacMethods_base.ismith";
static const char __pyx_k_GiacMethods_base_isolve[] = "GiacMethods_base.isolve";
static const char __pyx_k_GiacMethods_base_jordan[] = "GiacMethods_base.jordan";
static const char __pyx_k_GiacMethods_base_kernel[] = "GiacMethods_base.kernel";
static const char __pyx_k_GiacMethods_base_kmeans[] = "GiacMethods_base.kmeans";
static const char __pyx_k_GiacMethods_base_l1norm[] = "GiacMethods_base.l1norm";
static const char __pyx_k_GiacMethods_base_l2norm[] = "GiacMethods_base.l2norm";
static const char __pyx_k_GiacMethods_base_lcoeff[] = "GiacMethods_base.lcoeff";
static const char __pyx_k_GiacMethods_base_legend[] = "GiacMethods_base.legend";
static const char __pyx_k_GiacMethods_base_length[] = "GiacMethods_base.length";
static const char __pyx_k_GiacMethods_base_limite[] = "GiacMethods_base.limite";
static const char __pyx_k_GiacMethods_base_linabs[] = "GiacMethods_base.linabs";
static const char __pyx_k_GiacMethods_base_markov[] = "GiacMethods_base.markov";
static const char __pyx_k_GiacMethods_base_mathml[] = "GiacMethods_base.mathml";
static const char __pyx_k_GiacMethods_base_matpow[] = "GiacMethods_base.matpow";
static const char __pyx_k_GiacMethods_base_matrix[] = "GiacMethods_base.matrix";
static const char __pyx_k_GiacMethods_base_median[] = "GiacMethods_base.median";
static const char __pyx_k_GiacMethods_base_member[] = "GiacMethods_base.member";
static const char __pyx_k_GiacMethods_base_mkisom[] = "GiacMethods_base.mkisom";
static const char __pyx_k_GiacMethods_base_modgcd[] = "GiacMethods_base.modgcd";
static const char __pyx_k_GiacMethods_base_nDeriv[] = "GiacMethods_base.nDeriv";
static const char __pyx_k_GiacMethods_base_nSolve[] = "GiacMethods_base.nSolve";
static const char __pyx_k_GiacMethods_base_newMat[] = "GiacMethods_base.newMat";
static const char __pyx_k_GiacMethods_base_newton[] = "GiacMethods_base.newton";
static const char __pyx_k_GiacMethods_base_nodisp[] = "GiacMethods_base.nodisp";
static const char __pyx_k_GiacMethods_base_normal[] = "GiacMethods_base.normal";
static const char __pyx_k_GiacMethods_base_orange[] = "GiacMethods_base.orange";
static const char __pyx_k_GiacMethods_base_pcoeff[] = "GiacMethods_base.pcoeff";
static const char __pyx_k_GiacMethods_base_period[] = "GiacMethods_base.period";
static const char __pyx_k_GiacMethods_base_pixoff[] = "GiacMethods_base.pixoff";
static const char __pyx_k_GiacMethods_base_planar[] = "GiacMethods_base.planar";
static const char __pyx_k_GiacMethods_base_plot3d[] = "GiacMethods_base.plot3d";
static const char __pyx_k_GiacMethods_base_powmod[] = "GiacMethods_base.powmod";
static const char __pyx_k_GiacMethods_base_preval[] = "GiacMethods_base.preval";
static const char __pyx_k_GiacMethods_base_printf[] = "GiacMethods_base.printf";
static const char __pyx_k_GiacMethods_base_psrgcd[] = "GiacMethods_base.psrgcd";
static const char __pyx_k_GiacMethods_base_purple[] = "GiacMethods_base.purple";
static const char __pyx_k_GiacMethods_base_quorem[] = "GiacMethods_base.quorem";
static const char __pyx_k_GiacMethods_base_radius[] = "GiacMethods_base.radius";
static const char __pyx_k_GiacMethods_base_ramene[] = "GiacMethods_base.ramene";
static const char __pyx_k_GiacMethods_base_random[] = "GiacMethods_base.random";
static const char __pyx_k_GiacMethods_base_recule[] = "GiacMethods_base.recule";
static const char __pyx_k_GiacMethods_base_remain[] = "GiacMethods_base.remain";
static const char __pyx_k_GiacMethods_base_remove[] = "GiacMethods_base.remove";
static const char __pyx_k_GiacMethods_base_revert[] = "GiacMethods_base.revert";
static const char __pyx_k_GiacMethods_base_revlex[] = "GiacMethods_base.revlex";
static const char __pyx_k_GiacMethods_base_rm_a_z[] = "GiacMethods_base.rm_a_z";
static const char __pyx_k_GiacMethods_base_rootof[] = "GiacMethods_base.rootof";
static const char __pyx_k_GiacMethods_base_rotate[] = "GiacMethods_base.rotate";
static const char __pyx_k_GiacMethods_base_rowAdd[] = "GiacMethods_base.rowAdd";
static const char __pyx_k_GiacMethods_base_rowDim[] = "GiacMethods_base.rowDim";
static const char __pyx_k_GiacMethods_base_rowdim[] = "GiacMethods_base.rowdim";
static const char __pyx_k_GiacMethods_base_rsolve[] = "GiacMethods_base.rsolve";
static const char __pyx_k_GiacMethods_base_sample[] = "GiacMethods_base.sample";
static const char __pyx_k_GiacMethods_base_select[] = "GiacMethods_base.select";
static const char __pyx_k_GiacMethods_base_series[] = "GiacMethods_base.series";
static const char __pyx_k_GiacMethods_base_simult[] = "GiacMethods_base.simult";
static const char __pyx_k_GiacMethods_base_sincos[] = "GiacMethods_base.sincos";
static const char __pyx_k_GiacMethods_base_sommet[] = "GiacMethods_base.sommet";
static const char __pyx_k_GiacMethods_base_sorted[] = "GiacMethods_base.sorted";
static const char __pyx_k_GiacMethods_base_sphere[] = "GiacMethods_base.sphere";
static const char __pyx_k_GiacMethods_base_splice[] = "GiacMethods_base.splice";
static const char __pyx_k_GiacMethods_base_spline[] = "GiacMethods_base.spline";
static const char __pyx_k_GiacMethods_base_spring[] = "GiacMethods_base.spring";
static const char __pyx_k_GiacMethods_base_square[] = "GiacMethods_base.square";
static const char __pyx_k_GiacMethods_base_sst_in[] = "GiacMethods_base.sst_in";
static const char __pyx_k_GiacMethods_base_stdDev[] = "GiacMethods_base.stdDev";
static const char __pyx_k_GiacMethods_base_stddev[] = "GiacMethods_base.stddev";
static const char __pyx_k_GiacMethods_base_subMat[] = "GiacMethods_base.subMat";
static const char __pyx_k_GiacMethods_base_subsop[] = "GiacMethods_base.subsop";
static const char __pyx_k_GiacMethods_base_symbol[] = "GiacMethods_base.symbol";
static const char __pyx_k_GiacMethods_base_tabvar[] = "GiacMethods_base.tabvar";
static const char __pyx_k_GiacMethods_base_taylor[] = "GiacMethods_base.taylor";
static const char __pyx_k_GiacMethods_base_tcoeff[] = "GiacMethods_base.tcoeff";
static const char __pyx_k_GiacMethods_base_trames[] = "GiacMethods_base.trames";
static const char __pyx_k_GiacMethods_base_ugamma[] = "GiacMethods_base.ugamma";
static const char __pyx_k_GiacMethods_base_violet[] = "GiacMethods_base.violet";
static const char __pyx_k_GiacMethods_base_ztrans[] = "GiacMethods_base.ztrans";
static const char __pyx_k_Pygen___int___line_1059[] = "Pygen.__int__ (line 1059)";
static const char __pyx_k_Pygen___repr___line_877[] = "Pygen.__repr__ (line 877)";
static const char __pyx_k_Pygen___setstate_cython[] = "Pygen.__setstate_cython__";
static const char __pyx_k_developper_transcendant[] = "developper_transcendant";
static const char __pyx_k_discard_graph_attribute[] = "discard_graph_attribute";
static const char __pyx_k_giac_docs_dir_not_found[] = "giac docs dir not found";
static const char __pyx_k_giacpy_auto_methods_pxi[] = "giacpy/auto-methods.pxi";
static const char __pyx_k_is_harmonic_line_bundle[] = "is_harmonic_line_bundle";
static const char __pyx_k_maximal_independent_set[] = "maximal_independent_set";
static const char __pyx_k_maximum_independent_set[] = "maximum_independent_set";
static const char __pyx_k_minimal_vertex_coloring[] = "minimal_vertex_coloring";
static const char __pyx_k_rectangular_coordinates[] = "rectangular_coordinates";
static const char __pyx_k_self_is_not_a_giac_List[] = "self is not a giac List";
static const char __pyx_k_self_is_not_a_giac_real[] = "self is not a giac real";
static const char __pyx_k_Failed_to_start_a_thread[] = "Failed to start a thread";
static const char __pyx_k_GiacMethods_base_Airy_Ai[] = "GiacMethods_base.Airy_Ai";
static const char __pyx_k_GiacMethods_base_Airy_Bi[] = "GiacMethods_base.Airy_Bi";
static const char __pyx_k_GiacMethods_base_Archive[] = "GiacMethods_base.Archive";
static const char __pyx_k_GiacMethods_base_BesselJ[] = "GiacMethods_base.BesselJ";
static const char __pyx_k_GiacMethods_base_BesselY[] = "GiacMethods_base.BesselY";
static const char __pyx_k_GiacMethods_base_CopyVar[] = "GiacMethods_base.CopyVar";
static const char __pyx_k_GiacMethods_base_Fourier[] = "GiacMethods_base.Fourier";
static const char __pyx_k_GiacMethods_base_Hilbert[] = "GiacMethods_base.Hilbert";
static const char __pyx_k_GiacMethods_base_LineTan[] = "GiacMethods_base.LineTan";
static const char __pyx_k_GiacMethods_base_acyclic[] = "GiacMethods_base.acyclic";
static const char __pyx_k_GiacMethods_base_add_arc[] = "GiacMethods_base.add_arc";
static const char __pyx_k_GiacMethods_base_algsubs[] = "GiacMethods_base.algsubs";
static const char __pyx_k_GiacMethods_base_angleat[] = "GiacMethods_base.angleat";
static const char __pyx_k_GiacMethods_base_arccosh[] = "GiacMethods_base.arccosh";
static const char __pyx_k_GiacMethods_base_arcsinh[] = "GiacMethods_base.arcsinh";
static const char __pyx_k_GiacMethods_base_arctanh[] = "GiacMethods_base.arctanh";
static const char __pyx_k_GiacMethods_base_augment[] = "GiacMethods_base.augment";
static const char __pyx_k_GiacMethods_base_barplot[] = "GiacMethods_base.barplot";
static const char __pyx_k_GiacMethods_base_besselJ[] = "GiacMethods_base.besselJ";
static const char __pyx_k_GiacMethods_base_besselY[] = "GiacMethods_base.besselY";
static const char __pyx_k_GiacMethods_base_bspline[] = "GiacMethods_base.bspline";
static const char __pyx_k_GiacMethods_base_cFactor[] = "GiacMethods_base.cFactor";
static const char __pyx_k_GiacMethods_base_cauchyd[] = "GiacMethods_base.cauchyd";
static const char __pyx_k_GiacMethods_base_ceiling[] = "GiacMethods_base.ceiling";
static const char __pyx_k_GiacMethods_base_cfactor[] = "GiacMethods_base.cfactor";
static const char __pyx_k_GiacMethods_base_cfsolve[] = "GiacMethods_base.cfsolve";
static const char __pyx_k_GiacMethods_base_chinrem[] = "GiacMethods_base.chinrem";
static const char __pyx_k_GiacMethods_base_classes[] = "GiacMethods_base.classes";
static const char __pyx_k_GiacMethods_base_cluster[] = "GiacMethods_base.cluster";
static const char __pyx_k_GiacMethods_base_colNorm[] = "GiacMethods_base.colNorm";
static const char __pyx_k_GiacMethods_base_colSwap[] = "GiacMethods_base.colSwap";
static const char __pyx_k_GiacMethods_base_collect[] = "GiacMethods_base.collect";
static const char __pyx_k_GiacMethods_base_colnorm[] = "GiacMethods_base.colnorm";
static const char __pyx_k_GiacMethods_base_colswap[] = "GiacMethods_base.colswap";
static const char __pyx_k_GiacMethods_base_combine[] = "GiacMethods_base.combine";
static const char __pyx_k_GiacMethods_base_comment[] = "GiacMethods_base.comment";
static const char __pyx_k_GiacMethods_base_compare[] = "GiacMethods_base.compare";
static const char __pyx_k_GiacMethods_base_complex[] = "GiacMethods_base.complex";
static const char __pyx_k_GiacMethods_base_confrac[] = "GiacMethods_base.confrac";
static const char __pyx_k_GiacMethods_base_content[] = "GiacMethods_base.content";
static const char __pyx_k_GiacMethods_base_convert[] = "GiacMethods_base.convert";
static const char __pyx_k_GiacMethods_base_csv2gen[] = "GiacMethods_base.csv2gen";
static const char __pyx_k_GiacMethods_base_deSolve[] = "GiacMethods_base.deSolve";
static const char __pyx_k_GiacMethods_base_degrees[] = "GiacMethods_base.degrees";
static const char __pyx_k_GiacMethods_base_delcols[] = "GiacMethods_base.delcols";
static const char __pyx_k_GiacMethods_base_delrows[] = "GiacMethods_base.delrows";
static const char __pyx_k_GiacMethods_base_deriver[] = "GiacMethods_base.deriver";
static const char __pyx_k_GiacMethods_base_desolve[] = "GiacMethods_base.desolve";
static const char __pyx_k_GiacMethods_base_digraph[] = "GiacMethods_base.digraph";
static const char __pyx_k_GiacMethods_base_display[] = "GiacMethods_base.display";
static const char __pyx_k_GiacMethods_base_dotprod[] = "GiacMethods_base.dotprod";
static const char __pyx_k_GiacMethods_base_element[] = "GiacMethods_base.element";
static const char __pyx_k_GiacMethods_base_ellipse[] = "GiacMethods_base.ellipse";
static const char __pyx_k_GiacMethods_base_epsilon[] = "GiacMethods_base.epsilon";
static const char __pyx_k_GiacMethods_base_evolute[] = "GiacMethods_base.evolute";
static const char __pyx_k_GiacMethods_base_execute[] = "GiacMethods_base.execute";
static const char __pyx_k_GiacMethods_base_exp2pow[] = "GiacMethods_base.exp2pow";
static const char __pyx_k_GiacMethods_base_extrema[] = "GiacMethods_base.extrema";
static const char __pyx_k_GiacMethods_base_factors[] = "GiacMethods_base.factors";
static const char __pyx_k_GiacMethods_base_fisherd[] = "GiacMethods_base.fisherd";
static const char __pyx_k_GiacMethods_base_fitpoly[] = "GiacMethods_base.fitpoly";
static const char __pyx_k_GiacMethods_base_flatten[] = "GiacMethods_base.flatten";
static const char __pyx_k_GiacMethods_base_forward[] = "GiacMethods_base.forward";
static const char __pyx_k_GiacMethods_base_fourier[] = "GiacMethods_base.fourier";
static const char __pyx_k_GiacMethods_base_fracmod[] = "GiacMethods_base.fracmod";
static const char __pyx_k_GiacMethods_base_gauss15[] = "GiacMethods_base.gauss15";
static const char __pyx_k_GiacMethods_base_genpoly[] = "GiacMethods_base.genpoly";
static const char __pyx_k_GiacMethods_base_getType[] = "GiacMethods_base.getType";
static const char __pyx_k_GiacMethods_base_greduce[] = "GiacMethods_base.greduce";
static const char __pyx_k_GiacMethods_base_halftan[] = "GiacMethods_base.halftan";
static const char __pyx_k_GiacMethods_base_hamdist[] = "GiacMethods_base.hamdist";
static const char __pyx_k_GiacMethods_base_hamming[] = "GiacMethods_base.hamming";
static const char __pyx_k_GiacMethods_base_has_arc[] = "GiacMethods_base.has_arc";
static const char __pyx_k_GiacMethods_base_heading[] = "GiacMethods_base.heading";
static const char __pyx_k_GiacMethods_base_heapify[] = "GiacMethods_base.heapify";
static const char __pyx_k_GiacMethods_base_heappop[] = "GiacMethods_base.heappop";
static const char __pyx_k_GiacMethods_base_hermite[] = "GiacMethods_base.hermite";
static const char __pyx_k_GiacMethods_base_hessian[] = "GiacMethods_base.hessian";
static const char __pyx_k_GiacMethods_base_hexagon[] = "GiacMethods_base.hexagon";
static const char __pyx_k_GiacMethods_base_hilbert[] = "GiacMethods_base.hilbert";
static const char __pyx_k_GiacMethods_base_hsv2rgb[] = "GiacMethods_base.hsv2rgb";
static const char __pyx_k_GiacMethods_base_hyp2exp[] = "GiacMethods_base.hyp2exp";
static const char __pyx_k_GiacMethods_base_ifactor[] = "GiacMethods_base.ifactor";
static const char __pyx_k_GiacMethods_base_imfplot[] = "GiacMethods_base.imfplot";
static const char __pyx_k_GiacMethods_base_inertia[] = "GiacMethods_base.inertia";
static const char __pyx_k_GiacMethods_base_integer[] = "GiacMethods_base.integer";
static const char __pyx_k_GiacMethods_base_inverse[] = "GiacMethods_base.inverse";
static const char __pyx_k_GiacMethods_base_iquorem[] = "GiacMethods_base.iquorem";
static const char __pyx_k_GiacMethods_base_isPrime[] = "GiacMethods_base.isPrime";
static const char __pyx_k_GiacMethods_base_is_tree[] = "GiacMethods_base.is_tree";
static const char __pyx_k_GiacMethods_base_isprime[] = "GiacMethods_base.isprime";
static const char __pyx_k_GiacMethods_base_kspaths[] = "GiacMethods_base.kspaths";
static const char __pyx_k_GiacMethods_base_laplace[] = "GiacMethods_base.laplace";
static const char __pyx_k_GiacMethods_base_ldegree[] = "GiacMethods_base.ldegree";
static const char __pyx_k_GiacMethods_base_linstep[] = "GiacMethods_base.linstep";
static const char __pyx_k_GiacMethods_base_lowpass[] = "GiacMethods_base.lowpass";
static const char __pyx_k_GiacMethods_base_lpsolve[] = "GiacMethods_base.lpsolve";
static const char __pyx_k_GiacMethods_base_mRowAdd[] = "GiacMethods_base.mRowAdd";
static const char __pyx_k_GiacMethods_base_magenta[] = "GiacMethods_base.magenta";
static const char __pyx_k_GiacMethods_base_makemat[] = "GiacMethods_base.makemat";
static const char __pyx_k_GiacMethods_base_maxflow[] = "GiacMethods_base.maxflow";
static const char __pyx_k_GiacMethods_base_maxnorm[] = "GiacMethods_base.maxnorm";
static const char __pyx_k_GiacMethods_base_minimax[] = "GiacMethods_base.minimax";
static const char __pyx_k_GiacMethods_base_mixdown[] = "GiacMethods_base.mixdown";
static const char __pyx_k_GiacMethods_base_moyenne[] = "GiacMethods_base.moyenne";
static const char __pyx_k_GiacMethods_base_newList[] = "GiacMethods_base.newList";
static const char __pyx_k_GiacMethods_base_normald[] = "GiacMethods_base.normald";
static const char __pyx_k_GiacMethods_base_normalt[] = "GiacMethods_base.normalt";
static const char __pyx_k_GiacMethods_base_nprimes[] = "GiacMethods_base.nprimes";
static const char __pyx_k_GiacMethods_base_numdiff[] = "GiacMethods_base.numdiff";
static const char __pyx_k_GiacMethods_base_odeplot[] = "GiacMethods_base.odeplot";
static const char __pyx_k_GiacMethods_base_parameq[] = "GiacMethods_base.parameq";
static const char __pyx_k_GiacMethods_base_parfrac[] = "GiacMethods_base.parfrac";
static const char __pyx_k_GiacMethods_base_pendown[] = "GiacMethods_base.pendown";
static const char __pyx_k_GiacMethods_base_perminv[] = "GiacMethods_base.perminv";
static const char __pyx_k_GiacMethods_base_playsnd[] = "GiacMethods_base.playsnd";
static const char __pyx_k_GiacMethods_base_plotcdf[] = "GiacMethods_base.plotcdf";
static const char __pyx_k_GiacMethods_base_plotimf[] = "GiacMethods_base.plotimf";
static const char __pyx_k_GiacMethods_base_plotode[] = "GiacMethods_base.plotode";
static const char __pyx_k_GiacMethods_base_plotseq[] = "GiacMethods_base.plotseq";
static const char __pyx_k_GiacMethods_base_plotwav[] = "GiacMethods_base.plotwav";
static const char __pyx_k_GiacMethods_base_point2d[] = "GiacMethods_base.point2d";
static const char __pyx_k_GiacMethods_base_point3d[] = "GiacMethods_base.point3d";
static const char __pyx_k_GiacMethods_base_poisson[] = "GiacMethods_base.poisson";
static const char __pyx_k_GiacMethods_base_polygon[] = "GiacMethods_base.polygon";
static const char __pyx_k_GiacMethods_base_polynom[] = "GiacMethods_base.polynom";
static const char __pyx_k_GiacMethods_base_pow2exp[] = "GiacMethods_base.pow2exp";
static const char __pyx_k_GiacMethods_base_powerpc[] = "GiacMethods_base.powerpc";
static const char __pyx_k_GiacMethods_base_prepend[] = "GiacMethods_base.prepend";
static const char __pyx_k_GiacMethods_base_product[] = "GiacMethods_base.product";
static const char __pyx_k_GiacMethods_base_pyramid[] = "GiacMethods_base.pyramid";
static const char __pyx_k_GiacMethods_base_quadric[] = "GiacMethods_base.quadric";
static const char __pyx_k_GiacMethods_base_radians[] = "GiacMethods_base.radians";
static const char __pyx_k_GiacMethods_base_randMat[] = "GiacMethods_base.randMat";
static const char __pyx_k_GiacMethods_base_randexp[] = "GiacMethods_base.randexp";
static const char __pyx_k_GiacMethods_base_randint[] = "GiacMethods_base.randint";
static const char __pyx_k_GiacMethods_base_randvar[] = "GiacMethods_base.randvar";
static const char __pyx_k_GiacMethods_base_readrgb[] = "GiacMethods_base.readrgb";
static const char __pyx_k_GiacMethods_base_readwav[] = "GiacMethods_base.readwav";
static const char __pyx_k_GiacMethods_base_regroup[] = "GiacMethods_base.regroup";
static const char __pyx_k_GiacMethods_base_reorder[] = "GiacMethods_base.reorder";
static const char __pyx_k_GiacMethods_base_residue[] = "GiacMethods_base.residue";
static const char __pyx_k_GiacMethods_base_reverse[] = "GiacMethods_base.reverse";
static const char __pyx_k_GiacMethods_base_revlist[] = "GiacMethods_base.revlist";
static const char __pyx_k_GiacMethods_base_rgb2hsv[] = "GiacMethods_base.rgb2hsv";
static const char __pyx_k_GiacMethods_base_rgb2xyz[] = "GiacMethods_base.rgb2xyz";
static const char __pyx_k_GiacMethods_base_rhombus[] = "GiacMethods_base.rhombus";
static const char __pyx_k_GiacMethods_base_rmwatch[] = "GiacMethods_base.rmwatch";
static const char __pyx_k_GiacMethods_base_romberg[] = "GiacMethods_base.romberg";
static const char __pyx_k_GiacMethods_base_rowNorm[] = "GiacMethods_base.rowNorm";
static const char __pyx_k_GiacMethods_base_rowSwap[] = "GiacMethods_base.rowSwap";
static const char __pyx_k_GiacMethods_base_rownorm[] = "GiacMethods_base.rownorm";
static const char __pyx_k_GiacMethods_base_rowswap[] = "GiacMethods_base.rowswap";
static const char __pyx_k_GiacMethods_base_segment[] = "GiacMethods_base.segment";
static const char __pyx_k_GiacMethods_base_seqplot[] = "GiacMethods_base.seqplot";
static const char __pyx_k_GiacMethods_base_shuffle[] = "GiacMethods_base.shuffle";
static const char __pyx_k_GiacMethods_base_simpson[] = "GiacMethods_base.simpson";
static const char __pyx_k_GiacMethods_base_slopeat[] = "GiacMethods_base.slopeat";
static const char __pyx_k_GiacMethods_base_sqrfree[] = "GiacMethods_base.sqrfree";
static const char __pyx_k_GiacMethods_base_stddevp[] = "GiacMethods_base.stddevp";
static const char __pyx_k_GiacMethods_base_student[] = "GiacMethods_base.student";
static const char __pyx_k_GiacMethods_base_sturmab[] = "GiacMethods_base.sturmab";
static const char __pyx_k_GiacMethods_base_subtype[] = "GiacMethods_base.subtype";
static const char __pyx_k_GiacMethods_base_swapcol[] = "GiacMethods_base.swapcol";
static const char __pyx_k_GiacMethods_base_swaprow[] = "GiacMethods_base.swaprow";
static const char __pyx_k_GiacMethods_base_tExpand[] = "GiacMethods_base.tExpand";
static const char __pyx_k_GiacMethods_base_tabsign[] = "GiacMethods_base.tabsign";
static const char __pyx_k_GiacMethods_base_tangent[] = "GiacMethods_base.tangent";
static const char __pyx_k_GiacMethods_base_texpand[] = "GiacMethods_base.texpand";
static const char __pyx_k_GiacMethods_base_tonnetz[] = "GiacMethods_base.tonnetz";
static const char __pyx_k_GiacMethods_base_tpsolve[] = "GiacMethods_base.tpsolve";
static const char __pyx_k_GiacMethods_base_trapeze[] = "GiacMethods_base.trapeze";
static const char __pyx_k_GiacMethods_base_trigcos[] = "GiacMethods_base.trigcos";
static const char __pyx_k_GiacMethods_base_trigsin[] = "GiacMethods_base.trigsin";
static const char __pyx_k_GiacMethods_base_trigtan[] = "GiacMethods_base.trigtan";
static const char __pyx_k_GiacMethods_base_ufactor[] = "GiacMethods_base.ufactor";
static const char __pyx_k_GiacMethods_base_unapply[] = "GiacMethods_base.unapply";
static const char __pyx_k_GiacMethods_base_uniform[] = "GiacMethods_base.uniform";
static const char __pyx_k_GiacMethods_base_unquote[] = "GiacMethods_base.unquote";
static const char __pyx_k_GiacMethods_base_version[] = "GiacMethods_base.version";
static const char __pyx_k_GiacMethods_base_weibull[] = "GiacMethods_base.weibull";
static const char __pyx_k_GiacMethods_base_weights[] = "GiacMethods_base.weights";
static const char __pyx_k_GiacMethods_base_xyz2rgb[] = "GiacMethods_base.xyz2rgb";
static const char __pyx_k_GiacMethods_base_znorder[] = "GiacMethods_base.znorder";
static const char __pyx_k_Pygen___iter___line_1035[] = "Pygen.__iter__ (line 1035)";
static const char __pyx_k_Pygen___radd___line_1192[] = "Pygen.__radd__ (line 1192)";
static const char __pyx_k_Pygen___rmod___line_1410[] = "Pygen.__rmod__ (line 1410)";
static const char __pyx_k_Pygen___rmul___line_1286[] = "Pygen.__rmul__ (line 1286)";
static const char __pyx_k_Pygen___rpow___line_1372[] = "Pygen.__rpow__ (line 1372)";
static const char __pyx_k_Pygen___rsub___line_1248[] = "Pygen.__rsub__ (line 1248)";
static const char __pyx_k_Pygen_htmlhelp_line_1498[] = "Pygen.htmlhelp (line 1498)";
static const char __pyx_k_discard_vertex_attribute[] = "discard_vertex_attribute";
static const char __pyx_k_ligne_polygonale_pointee[] = "ligne_polygonale_pointee";
static const char __pyx_k_logistic_regression_plot[] = "logistic_regression_plot";
static const char __pyx_k_number_of_spanning_trees[] = "number_of_spanning_trees";
static const char __pyx_k_GiacMethods_base_LambertW[] = "GiacMethods_base.LambertW";
static const char __pyx_k_GiacMethods_base_LineHorz[] = "GiacMethods_base.LineHorz";
static const char __pyx_k_GiacMethods_base_LineVert[] = "GiacMethods_base.LineVert";
static const char __pyx_k_GiacMethods_base_RandSeed[] = "GiacMethods_base.RandSeed";
static const char __pyx_k_GiacMethods_base_abscissa[] = "GiacMethods_base.abscissa";
static const char __pyx_k_GiacMethods_base_adaptive[] = "GiacMethods_base.adaptive";
static const char __pyx_k_GiacMethods_base_add_edge[] = "GiacMethods_base.add_edge";
static const char __pyx_k_GiacMethods_base_addtable[] = "GiacMethods_base.addtable";
static const char __pyx_k_GiacMethods_base_altitude[] = "GiacMethods_base.altitude";
static const char __pyx_k_GiacMethods_base_areaplot[] = "GiacMethods_base.areaplot";
static const char __pyx_k_GiacMethods_base_arrivals[] = "GiacMethods_base.arrivals";
static const char __pyx_k_GiacMethods_base_atrig2ln[] = "GiacMethods_base.atrig2ln";
static const char __pyx_k_GiacMethods_base_backward[] = "GiacMethods_base.backward";
static const char __pyx_k_GiacMethods_base_bar_plot[] = "GiacMethods_base.bar_plot";
static const char __pyx_k_GiacMethods_base_binomial[] = "GiacMethods_base.binomial";
static const char __pyx_k_GiacMethods_base_bisector[] = "GiacMethods_base.bisector";
static const char __pyx_k_GiacMethods_base_bvpsolve[] = "GiacMethods_base.bvpsolve";
static const char __pyx_k_GiacMethods_base_channels[] = "GiacMethods_base.channels";
static const char __pyx_k_GiacMethods_base_charpoly[] = "GiacMethods_base.charpoly";
static const char __pyx_k_GiacMethods_base_cholesky[] = "GiacMethods_base.cholesky";
static const char __pyx_k_GiacMethods_base_colormap[] = "GiacMethods_base.colormap";
static const char __pyx_k_GiacMethods_base_colspace[] = "GiacMethods_base.colspace";
static const char __pyx_k_GiacMethods_base_comDenom[] = "GiacMethods_base.comDenom";
static const char __pyx_k_GiacMethods_base_contains[] = "GiacMethods_base.contains";
static const char __pyx_k_GiacMethods_base_count_eq[] = "GiacMethods_base.count_eq";
static const char __pyx_k_GiacMethods_base_cycleinv[] = "GiacMethods_base.cycleinv";
static const char __pyx_k_GiacMethods_base_cylinder[] = "GiacMethods_base.cylinder";
static const char __pyx_k_GiacMethods_base_dijkstra[] = "GiacMethods_base.dijkstra";
static const char __pyx_k_GiacMethods_base_directed[] = "GiacMethods_base.directed";
static const char __pyx_k_GiacMethods_base_distance[] = "GiacMethods_base.distance";
static const char __pyx_k_GiacMethods_base_divisors[] = "GiacMethods_base.divisors";
static const char __pyx_k_GiacMethods_base_draw_arc[] = "GiacMethods_base.draw_arc";
static const char __pyx_k_GiacMethods_base_duration[] = "GiacMethods_base.duration";
static const char __pyx_k_GiacMethods_base_envelope[] = "GiacMethods_base.envelope";
static const char __pyx_k_GiacMethods_base_equation[] = "GiacMethods_base.equation";
static const char __pyx_k_GiacMethods_base_excircle[] = "GiacMethods_base.excircle";
static const char __pyx_k_GiacMethods_base_exp2list[] = "GiacMethods_base.exp2list";
static const char __pyx_k_GiacMethods_base_exp2trig[] = "GiacMethods_base.exp2trig";
static const char __pyx_k_GiacMethods_base_fdistrib[] = "GiacMethods_base.fdistrib";
static const char __pyx_k_GiacMethods_base_findhelp[] = "GiacMethods_base.findhelp";
static const char __pyx_k_GiacMethods_base_fitdistr[] = "GiacMethods_base.fitdistr";
static const char __pyx_k_GiacMethods_base_frame_2d[] = "GiacMethods_base.frame_2d";
static const char __pyx_k_GiacMethods_base_funcplot[] = "GiacMethods_base.funcplot";
static const char __pyx_k_GiacMethods_base_getDenom[] = "GiacMethods_base.getDenom";
static const char __pyx_k_GiacMethods_base_hadamard[] = "GiacMethods_base.hadamard";
static const char __pyx_k_GiacMethods_base_has_edge[] = "GiacMethods_base.has_edge";
static const char __pyx_k_GiacMethods_base_heappush[] = "GiacMethods_base.heappush";
static const char __pyx_k_GiacMethods_base_highpass[] = "GiacMethods_base.highpass";
static const char __pyx_k_GiacMethods_base_ichinrem[] = "GiacMethods_base.ichinrem";
static const char __pyx_k_GiacMethods_base_icontent[] = "GiacMethods_base.icontent";
static const char __pyx_k_GiacMethods_base_identity[] = "GiacMethods_base.identity";
static const char __pyx_k_GiacMethods_base_ifactors[] = "GiacMethods_base.ifactors";
static const char __pyx_k_GiacMethods_base_ifourier[] = "GiacMethods_base.ifourier";
static const char __pyx_k_GiacMethods_base_ihermite[] = "GiacMethods_base.ihermite";
static const char __pyx_k_GiacMethods_base_ilaplace[] = "GiacMethods_base.ilaplace";
static const char __pyx_k_GiacMethods_base_inString[] = "GiacMethods_base.inString";
static const char __pyx_k_GiacMethods_base_in_ideal[] = "GiacMethods_base.in_ideal";
static const char __pyx_k_GiacMethods_base_incircle[] = "GiacMethods_base.incircle";
static const char __pyx_k_GiacMethods_base_infinity[] = "GiacMethods_base.infinity";
static const char __pyx_k_GiacMethods_base_instfreq[] = "GiacMethods_base.instfreq";
static const char __pyx_k_GiacMethods_base_integrer[] = "GiacMethods_base.integrer";
static const char __pyx_k_GiacMethods_base_interval[] = "GiacMethods_base.interval";
static const char __pyx_k_GiacMethods_base_is_cycle[] = "GiacMethods_base.is_cycle";
static const char __pyx_k_GiacMethods_base_is_permu[] = "GiacMethods_base.is_permu";
static const char __pyx_k_GiacMethods_base_is_prime[] = "GiacMethods_base.is_prime";
static const char __pyx_k_GiacMethods_base_isposdef[] = "GiacMethods_base.isposdef";
static const char __pyx_k_GiacMethods_base_ithprime[] = "GiacMethods_base.ithprime";
static const char __pyx_k_GiacMethods_base_lagrange[] = "GiacMethods_base.lagrange";
static const char __pyx_k_GiacMethods_base_laguerre[] = "GiacMethods_base.laguerre";
static const char __pyx_k_GiacMethods_base_legendre[] = "GiacMethods_base.legendre";
static const char __pyx_k_GiacMethods_base_linfnorm[] = "GiacMethods_base.linfnorm";
static const char __pyx_k_GiacMethods_base_linsolve[] = "GiacMethods_base.linsolve";
static const char __pyx_k_GiacMethods_base_linspace[] = "GiacMethods_base.linspace";
static const char __pyx_k_GiacMethods_base_list2exp[] = "GiacMethods_base.list2exp";
static const char __pyx_k_GiacMethods_base_list2mat[] = "GiacMethods_base.list2mat";
static const char __pyx_k_GiacMethods_base_listplot[] = "GiacMethods_base.listplot";
static const char __pyx_k_GiacMethods_base_lnexpand[] = "GiacMethods_base.lnexpand";
static const char __pyx_k_GiacMethods_base_log_loss[] = "GiacMethods_base.log_loss";
static const char __pyx_k_GiacMethods_base_logistic[] = "GiacMethods_base.logistic";
static const char __pyx_k_GiacMethods_base_makelist[] = "GiacMethods_base.makelist";
static const char __pyx_k_GiacMethods_base_mat2list[] = "GiacMethods_base.mat2list";
static const char __pyx_k_GiacMethods_base_maximize[] = "GiacMethods_base.maximize";
static const char __pyx_k_GiacMethods_base_midpoint[] = "GiacMethods_base.midpoint";
static const char __pyx_k_GiacMethods_base_minimize[] = "GiacMethods_base.minimize";
static const char __pyx_k_GiacMethods_base_momentum[] = "GiacMethods_base.momentum";
static const char __pyx_k_GiacMethods_base_multiply[] = "GiacMethods_base.multiply";
static const char __pyx_k_GiacMethods_base_nextperm[] = "GiacMethods_base.nextperm";
static const char __pyx_k_GiacMethods_base_nlpsolve[] = "GiacMethods_base.nlpsolve";
static const char __pyx_k_GiacMethods_base_odesolve[] = "GiacMethods_base.odesolve";
static const char __pyx_k_GiacMethods_base_ordinate[] = "GiacMethods_base.ordinate";
static const char __pyx_k_GiacMethods_base_parabola[] = "GiacMethods_base.parabola";
static const char __pyx_k_GiacMethods_base_parallel[] = "GiacMethods_base.parallel";
static const char __pyx_k_GiacMethods_base_partfrac[] = "GiacMethods_base.partfrac";
static const char __pyx_k_GiacMethods_base_pencolor[] = "GiacMethods_base.pencolor";
static const char __pyx_k_GiacMethods_base_periodic[] = "GiacMethods_base.periodic";
static const char __pyx_k_GiacMethods_base_plotarea[] = "GiacMethods_base.plotarea";
static const char __pyx_k_GiacMethods_base_plotfunc[] = "GiacMethods_base.plotfunc";
static const char __pyx_k_GiacMethods_base_plotlist[] = "GiacMethods_base.plotlist";
static const char __pyx_k_GiacMethods_base_polyEval[] = "GiacMethods_base.polyEval";
static const char __pyx_k_GiacMethods_base_position[] = "GiacMethods_base.position";
static const char __pyx_k_GiacMethods_base_posubLMQ[] = "GiacMethods_base.posubLMQ";
static const char __pyx_k_GiacMethods_base_powermod[] = "GiacMethods_base.powermod";
static const char __pyx_k_GiacMethods_base_prevperm[] = "GiacMethods_base.prevperm";
static const char __pyx_k_GiacMethods_base_primpart[] = "GiacMethods_base.primpart";
static const char __pyx_k_GiacMethods_base_propFrac[] = "GiacMethods_base.propFrac";
static const char __pyx_k_GiacMethods_base_propfrac[] = "GiacMethods_base.propfrac";
static const char __pyx_k_GiacMethods_base_quantile[] = "GiacMethods_base.quantile";
static const char __pyx_k_GiacMethods_base_randNorm[] = "GiacMethods_base.randNorm";
static const char __pyx_k_GiacMethods_base_randPoly[] = "GiacMethods_base.randPoly";
static const char __pyx_k_GiacMethods_base_randnorm[] = "GiacMethods_base.randnorm";
static const char __pyx_k_GiacMethods_base_randperm[] = "GiacMethods_base.randperm";
static const char __pyx_k_GiacMethods_base_randpoly[] = "GiacMethods_base.randpoly";
static const char __pyx_k_GiacMethods_base_randseed[] = "GiacMethods_base.randseed";
static const char __pyx_k_GiacMethods_base_rational[] = "GiacMethods_base.rational";
static const char __pyx_k_GiacMethods_base_realroot[] = "GiacMethods_base.realroot";
static const char __pyx_k_GiacMethods_base_resample[] = "GiacMethods_base.resample";
static const char __pyx_k_GiacMethods_base_resoudre[] = "GiacMethods_base.resoudre";
static const char __pyx_k_GiacMethods_base_rombergm[] = "GiacMethods_base.rombergm";
static const char __pyx_k_GiacMethods_base_rombergt[] = "GiacMethods_base.rombergt";
static const char __pyx_k_GiacMethods_base_rotation[] = "GiacMethods_base.rotation";
static const char __pyx_k_GiacMethods_base_rowspace[] = "GiacMethods_base.rowspace";
static const char __pyx_k_GiacMethods_base_seqsolve[] = "GiacMethods_base.seqsolve";
static const char __pyx_k_GiacMethods_base_simplify[] = "GiacMethods_base.simplify";
static const char __pyx_k_GiacMethods_base_snedecor[] = "GiacMethods_base.snedecor";
static const char __pyx_k_GiacMethods_base_sortperm[] = "GiacMethods_base.sortperm";
static const char __pyx_k_GiacMethods_base_soundsec[] = "GiacMethods_base.soundsec";
static const char __pyx_k_GiacMethods_base_studentd[] = "GiacMethods_base.studentd";
static const char __pyx_k_GiacMethods_base_studentt[] = "GiacMethods_base.studentt";
static const char __pyx_k_GiacMethods_base_sturmseq[] = "GiacMethods_base.sturmseq";
static const char __pyx_k_GiacMethods_base_subgraph[] = "GiacMethods_base.subgraph";
static const char __pyx_k_GiacMethods_base_suppress[] = "GiacMethods_base.suppress";
static const char __pyx_k_GiacMethods_base_syst2mat[] = "GiacMethods_base.syst2mat";
static const char __pyx_k_GiacMethods_base_tCollect[] = "GiacMethods_base.tCollect";
static const char __pyx_k_GiacMethods_base_tableseq[] = "GiacMethods_base.tableseq";
static const char __pyx_k_GiacMethods_base_tangente[] = "GiacMethods_base.tangente";
static const char __pyx_k_GiacMethods_base_tcollect[] = "GiacMethods_base.tcollect";
static const char __pyx_k_GiacMethods_base_topology[] = "GiacMethods_base.topology";
static const char __pyx_k_GiacMethods_base_triangle[] = "GiacMethods_base.triangle";
static const char __pyx_k_GiacMethods_base_trig2exp[] = "GiacMethods_base.trig2exp";
static const char __pyx_k_GiacMethods_base_truncate[] = "GiacMethods_base.truncate";
static const char __pyx_k_GiacMethods_base_uniformd[] = "GiacMethods_base.uniformd";
static const char __pyx_k_GiacMethods_base_variance[] = "GiacMethods_base.variance";
static const char __pyx_k_GiacMethods_base_vertices[] = "GiacMethods_base.vertices";
static const char __pyx_k_GiacMethods_base_weibulld[] = "GiacMethods_base.weibulld";
static const char __pyx_k_GiacMethods_base_weighted[] = "GiacMethods_base.weighted";
static const char __pyx_k_GiacMethods_base_writergb[] = "GiacMethods_base.writergb";
static const char __pyx_k_GiacMethods_base_writewav[] = "GiacMethods_base.writewav";
static const char __pyx_k_Pygen___float___line_1078[] = "Pygen.__float__ (line 1078)";
static const char __pyx_k_is_harmonic_circle_bundle[] = "is_harmonic_circle_bundle";
static const char __pyx_k_list_index_s_out_of_range[] = "list index %s out of range";
static const char __pyx_k_resoudre_systeme_lineaire[] = "resoudre_systeme_lineaire";
static const char __pyx_k_GiacMethods_base_Heaviside[] = "GiacMethods_base.Heaviside";
static const char __pyx_k_GiacMethods_base_acos2asin[] = "GiacMethods_base.acos2asin";
static const char __pyx_k_GiacMethods_base_acos2atan[] = "GiacMethods_base.acos2atan";
static const char __pyx_k_GiacMethods_base_areaatraw[] = "GiacMethods_base.areaatraw";
static const char __pyx_k_GiacMethods_base_asin2acos[] = "GiacMethods_base.asin2acos";
static const char __pyx_k_GiacMethods_base_asin2atan[] = "GiacMethods_base.asin2atan";
static const char __pyx_k_GiacMethods_base_atan2acos[] = "GiacMethods_base.atan2acos";
static const char __pyx_k_GiacMethods_base_atan2asin[] = "GiacMethods_base.atan2asin";
static const char __pyx_k_GiacMethods_base_bandwidth[] = "GiacMethods_base.bandwidth";
static const char __pyx_k_GiacMethods_base_bernoulli[] = "GiacMethods_base.bernoulli";
static const char __pyx_k_GiacMethods_base_betad_cdf[] = "GiacMethods_base.betad_cdf";
static const char __pyx_k_GiacMethods_base_bezoutian[] = "GiacMethods_base.bezoutian";
static const char __pyx_k_GiacMethods_base_bipartite[] = "GiacMethods_base.bipartite";
static const char __pyx_k_GiacMethods_base_bit_depth[] = "GiacMethods_base.bit_depth";
static const char __pyx_k_GiacMethods_base_camembert[] = "GiacMethods_base.camembert";
static const char __pyx_k_GiacMethods_base_chisquare[] = "GiacMethods_base.chisquare";
static const char __pyx_k_GiacMethods_base_companion[] = "GiacMethods_base.companion";
static const char __pyx_k_GiacMethods_base_connected[] = "GiacMethods_base.connected";
static const char __pyx_k_GiacMethods_base_convertir[] = "GiacMethods_base.convertir";
static const char __pyx_k_GiacMethods_base_count_inf[] = "GiacMethods_base.count_inf";
static const char __pyx_k_GiacMethods_base_count_sup[] = "GiacMethods_base.count_sup";
static const char __pyx_k_GiacMethods_base_cpartfrac[] = "GiacMethods_base.cpartfrac";
static const char __pyx_k_GiacMethods_base_createwav[] = "GiacMethods_base.createwav";
static const char __pyx_k_GiacMethods_base_curvature[] = "GiacMethods_base.curvature";
static const char __pyx_k_GiacMethods_base_dash_line[] = "GiacMethods_base.dash_line";
static const char __pyx_k_GiacMethods_base_dayofweek[] = "GiacMethods_base.dayofweek";
static const char __pyx_k_GiacMethods_base_deltalist[] = "GiacMethods_base.deltalist";
static const char __pyx_k_GiacMethods_base_det_minor[] = "GiacMethods_base.det_minor";
static const char __pyx_k_GiacMethods_base_distance2[] = "GiacMethods_base.distance2";
static const char __pyx_k_GiacMethods_base_dot_paper[] = "GiacMethods_base.dot_paper";
static const char __pyx_k_GiacMethods_base_draw_line[] = "GiacMethods_base.draw_line";
static const char __pyx_k_GiacMethods_base_eigenvals[] = "GiacMethods_base.eigenvals";
static const char __pyx_k_GiacMethods_base_eliminate[] = "GiacMethods_base.eliminate";
static const char __pyx_k_GiacMethods_base_est_permu[] = "GiacMethods_base.est_permu";
static const char __pyx_k_GiacMethods_base_expexpand[] = "GiacMethods_base.expexpand";
static const char __pyx_k_GiacMethods_base_factor_xn[] = "GiacMethods_base.factor_xn";
static const char __pyx_k_GiacMethods_base_factorial[] = "GiacMethods_base.factorial";
static const char __pyx_k_GiacMethods_base_fieldplot[] = "GiacMethods_base.fieldplot";
static const char __pyx_k_GiacMethods_base_fitspline[] = "GiacMethods_base.fitspline";
static const char __pyx_k_GiacMethods_base_gaussjord[] = "GiacMethods_base.gaussjord";
static const char __pyx_k_GiacMethods_base_gaussquad[] = "GiacMethods_base.gaussquad";
static const char __pyx_k_GiacMethods_base_geometric[] = "GiacMethods_base.geometric";
static const char __pyx_k_GiacMethods_base_groupermu[] = "GiacMethods_base.groupermu";
static const char __pyx_k_GiacMethods_base_half_cone[] = "GiacMethods_base.half_cone";
static const char __pyx_k_GiacMethods_base_half_line[] = "GiacMethods_base.half_line";
static const char __pyx_k_GiacMethods_base_histogram[] = "GiacMethods_base.histogram";
static const char __pyx_k_GiacMethods_base_homothety[] = "GiacMethods_base.homothety";
static const char __pyx_k_GiacMethods_base_hyperbola[] = "GiacMethods_base.hyperbola";
static const char __pyx_k_GiacMethods_base_instphase[] = "GiacMethods_base.instphase";
static const char __pyx_k_GiacMethods_base_integrate[] = "GiacMethods_base.integrate";
static const char __pyx_k_GiacMethods_base_inversion[] = "GiacMethods_base.inversion";
static const char __pyx_k_GiacMethods_base_invztrans[] = "GiacMethods_base.invztrans";
static const char __pyx_k_GiacMethods_base_iratrecon[] = "GiacMethods_base.iratrecon";
static const char __pyx_k_GiacMethods_base_is_clique[] = "GiacMethods_base.is_clique";
static const char __pyx_k_GiacMethods_base_is_forest[] = "GiacMethods_base.is_forest";
static const char __pyx_k_GiacMethods_base_is_inside[] = "GiacMethods_base.is_inside";
static const char __pyx_k_GiacMethods_base_is_planar[] = "GiacMethods_base.is_planar";
static const char __pyx_k_GiacMethods_base_is_square[] = "GiacMethods_base.is_square";
static const char __pyx_k_GiacMethods_base_laplacian[] = "GiacMethods_base.laplacian";
static const char __pyx_k_GiacMethods_base_lcf_graph[] = "GiacMethods_base.lcf_graph";
static const char __pyx_k_GiacMethods_base_lncollect[] = "GiacMethods_base.lncollect";
static const char __pyx_k_GiacMethods_base_lp_assume[] = "GiacMethods_base.lp_assume";
static const char __pyx_k_GiacMethods_base_lp_binary[] = "GiacMethods_base.lp_binary";
static const char __pyx_k_GiacMethods_base_lp_hybrid[] = "GiacMethods_base.lp_hybrid";
static const char __pyx_k_GiacMethods_base_lp_method[] = "GiacMethods_base.lp_method";
static const char __pyx_k_GiacMethods_base_makesuite[] = "GiacMethods_base.makesuite";
static const char __pyx_k_GiacMethods_base_monotonic[] = "GiacMethods_base.monotonic";
static const char __pyx_k_GiacMethods_base_moustache[] = "GiacMethods_base.moustache";
static const char __pyx_k_GiacMethods_base_mycielski[] = "GiacMethods_base.mycielski";
static const char __pyx_k_GiacMethods_base_neighbors[] = "GiacMethods_base.neighbors";
static const char __pyx_k_GiacMethods_base_nextprime[] = "GiacMethods_base.nextprime";
static const char __pyx_k_GiacMethods_base_nonnegint[] = "GiacMethods_base.nonnegint";
static const char __pyx_k_GiacMethods_base_normalize[] = "GiacMethods_base.normalize";
static const char __pyx_k_GiacMethods_base_nullspace[] = "GiacMethods_base.nullspace";
static const char __pyx_k_GiacMethods_base_odd_girth[] = "GiacMethods_base.odd_girth";
static const char __pyx_k_GiacMethods_base_odd_graph[] = "GiacMethods_base.odd_graph";
static const char __pyx_k_GiacMethods_base_parameter[] = "GiacMethods_base.parameter";
static const char __pyx_k_GiacMethods_base_paramplot[] = "GiacMethods_base.paramplot";
static const char __pyx_k_GiacMethods_base_perimeter[] = "GiacMethods_base.perimeter";
static const char __pyx_k_GiacMethods_base_permu2mat[] = "GiacMethods_base.permu2mat";
static const char __pyx_k_GiacMethods_base_piecewise[] = "GiacMethods_base.piecewise";
static const char __pyx_k_GiacMethods_base_plotfield[] = "GiacMethods_base.plotfield";
static const char __pyx_k_GiacMethods_base_plotparam[] = "GiacMethods_base.plotparam";
static const char __pyx_k_GiacMethods_base_plotpolar[] = "GiacMethods_base.plotpolar";
static const char __pyx_k_GiacMethods_base_plotproba[] = "GiacMethods_base.plotproba";
static const char __pyx_k_GiacMethods_base_polarplot[] = "GiacMethods_base.polarplot";
static const char __pyx_k_GiacMethods_base_poly2symb[] = "GiacMethods_base.poly2symb";
static const char __pyx_k_GiacMethods_base_poslbdLMQ[] = "GiacMethods_base.poslbdLMQ";
static const char __pyx_k_GiacMethods_base_potential[] = "GiacMethods_base.potential";
static const char __pyx_k_GiacMethods_base_powexpand[] = "GiacMethods_base.powexpand";
static const char __pyx_k_GiacMethods_base_prevprime[] = "GiacMethods_base.prevprime";
static const char __pyx_k_GiacMethods_base_quartile1[] = "GiacMethods_base.quartile1";
static const char __pyx_k_GiacMethods_base_quartile3[] = "GiacMethods_base.quartile3";
static const char __pyx_k_GiacMethods_base_quartiles[] = "GiacMethods_base.quartiles";
static const char __pyx_k_GiacMethods_base_randbetad[] = "GiacMethods_base.randbetad";
static const char __pyx_k_GiacMethods_base_ratinterp[] = "GiacMethods_base.ratinterp";
static const char __pyx_k_GiacMethods_base_ratnormal[] = "GiacMethods_base.ratnormal";
static const char __pyx_k_GiacMethods_base_reachable[] = "GiacMethods_base.reachable";
static const char __pyx_k_GiacMethods_base_rectangle[] = "GiacMethods_base.rectangle";
static const char __pyx_k_GiacMethods_base_resultant[] = "GiacMethods_base.resultant";
static const char __pyx_k_GiacMethods_base_set_pixel[] = "GiacMethods_base.set_pixel";
static const char __pyx_k_GiacMethods_base_signature[] = "GiacMethods_base.signature";
static const char __pyx_k_GiacMethods_base_snedecord[] = "GiacMethods_base.snedecord";
static const char __pyx_k_GiacMethods_base_sylvester[] = "GiacMethods_base.sylvester";
static const char __pyx_k_GiacMethods_base_symb2poly[] = "GiacMethods_base.symb2poly";
static const char __pyx_k_GiacMethods_base_tablefunc[] = "GiacMethods_base.tablefunc";
static const char __pyx_k_GiacMethods_base_thickness[] = "GiacMethods_base.thickness";
static const char __pyx_k_GiacMethods_base_threshold[] = "GiacMethods_base.threshold";
static const char __pyx_k_GiacMethods_base_transpose[] = "GiacMethods_base.transpose";
static const char __pyx_k_GiacMethods_base_trapezoid[] = "GiacMethods_base.trapezoid";
static const char __pyx_k_GiacMethods_base_tsimplify[] = "GiacMethods_base.tsimplify";
static const char __pyx_k_GiacMethods_base_unarchive[] = "GiacMethods_base.unarchive";
static const char __pyx_k_GiacMethods_base_usimplify[] = "GiacMethods_base.usimplify";
static const char __pyx_k_GiacMethods_base_valuation[] = "GiacMethods_base.valuation";
static const char __pyx_k_GiacMethods_base_web_graph[] = "GiacMethods_base.web_graph";
static const char __pyx_k_GiacMethods_base_wilcoxonp[] = "GiacMethods_base.wilcoxonp";
static const char __pyx_k_GiacMethods_base_wilcoxons[] = "GiacMethods_base.wilcoxons";
static const char __pyx_k_GiacMethods_base_wilcoxont[] = "GiacMethods_base.wilcoxont";
static const char __pyx_k_GiacMethods_base_xcas_mode[] = "GiacMethods_base.xcas_mode";
static const char __pyx_k_GiacMethods_base_xml_print[] = "GiacMethods_base.xml_print";
static const char __pyx_k_GiacMethods_base_xyztrange[] = "GiacMethods_base.xyztrange";
static const char __pyx_k_Pygen___getitem___line_913[] = "Pygen.__getitem__ (line 913)";
static const char __pyx_k_Pygen___setitem___line_986[] = "Pygen.__setitem__ (line 986)";
static const char __pyx_k_polynomial_regression_plot[] = "polynomial_regression_plot";
static const char __pyx_k_self_is_not_a_giac_integer[] = "self is not a giac integer";
static const char __pyx_k_GiacMethods_base_add_vertex[] = "GiacMethods_base.add_vertex";
static const char __pyx_k_GiacMethods_base_angleatraw[] = "GiacMethods_base.angleatraw";
static const char __pyx_k_GiacMethods_base_barycenter[] = "GiacMethods_base.barycenter";
static const char __pyx_k_GiacMethods_base_betad_icdf[] = "GiacMethods_base.betad_icdf";
static const char __pyx_k_GiacMethods_base_block_size[] = "GiacMethods_base.block_size";
static const char __pyx_k_GiacMethods_base_boxwhisker[] = "GiacMethods_base.boxwhisker";
static const char __pyx_k_GiacMethods_base_cauchy_cdf[] = "GiacMethods_base.cauchy_cdf";
static const char __pyx_k_GiacMethods_base_changebase[] = "GiacMethods_base.changebase";
static const char __pyx_k_GiacMethods_base_chisquared[] = "GiacMethods_base.chisquared";
static const char __pyx_k_GiacMethods_base_chisquaret[] = "GiacMethods_base.chisquaret";
static const char __pyx_k_GiacMethods_base_convexhull[] = "GiacMethods_base.convexhull";
static const char __pyx_k_GiacMethods_base_cos2sintan[] = "GiacMethods_base.cos2sintan";
static const char __pyx_k_GiacMethods_base_covariance[] = "GiacMethods_base.covariance";
static const char __pyx_k_GiacMethods_base_cycle2perm[] = "GiacMethods_base.cycle2perm";
static const char __pyx_k_GiacMethods_base_cyclotomic[] = "GiacMethods_base.cyclotomic";
static const char __pyx_k_GiacMethods_base_delete_arc[] = "GiacMethods_base.delete_arc";
static const char __pyx_k_GiacMethods_base_departures[] = "GiacMethods_base.departures";
static const char __pyx_k_GiacMethods_base_developper[] = "GiacMethods_base.developper";
static const char __pyx_k_GiacMethods_base_distanceat[] = "GiacMethods_base.distanceat";
static const char __pyx_k_GiacMethods_base_divergence[] = "GiacMethods_base.divergence";
static const char __pyx_k_GiacMethods_base_draw_graph[] = "GiacMethods_base.draw_graph";
static const char __pyx_k_GiacMethods_base_draw_pixel[] = "GiacMethods_base.draw_pixel";
static const char __pyx_k_GiacMethods_base_ecart_type[] = "GiacMethods_base.ecart_type";
static const char __pyx_k_GiacMethods_base_ecm_factor[] = "GiacMethods_base.ecm_factor";
static const char __pyx_k_GiacMethods_base_eigenvects[] = "GiacMethods_base.eigenvects";
static const char __pyx_k_GiacMethods_base_equal2diff[] = "GiacMethods_base.equal2diff";
static const char __pyx_k_GiacMethods_base_equal2list[] = "GiacMethods_base.equal2list";
static const char __pyx_k_GiacMethods_base_eval_level[] = "GiacMethods_base.eval_level";
static const char __pyx_k_GiacMethods_base_exbisector[] = "GiacMethods_base.exbisector";
static const char __pyx_k_GiacMethods_base_factoriser[] = "GiacMethods_base.factoriser";
static const char __pyx_k_GiacMethods_base_fisher_cdf[] = "GiacMethods_base.fisher_cdf";
static const char __pyx_k_GiacMethods_base_fourier_an[] = "GiacMethods_base.fourier_an";
static const char __pyx_k_GiacMethods_base_fourier_bn[] = "GiacMethods_base.fourier_bn";
static const char __pyx_k_GiacMethods_base_fourier_cn[] = "GiacMethods_base.fourier_cn";
static const char __pyx_k_GiacMethods_base_gammad_cdf[] = "GiacMethods_base.gammad_cdf";
static const char __pyx_k_GiacMethods_base_graph_join[] = "GiacMethods_base.graph_join";
static const char __pyx_k_GiacMethods_base_graph_rank[] = "GiacMethods_base.graph_rank";
static const char __pyx_k_GiacMethods_base_grid_graph[] = "GiacMethods_base.grid_graph";
static const char __pyx_k_GiacMethods_base_haar_graph[] = "GiacMethods_base.haar_graph";
static const char __pyx_k_GiacMethods_base_hessenberg[] = "GiacMethods_base.hessenberg";
static const char __pyx_k_GiacMethods_base_invlaplace[] = "GiacMethods_base.invlaplace";
static const char __pyx_k_GiacMethods_base_is_acyclic[] = "GiacMethods_base.is_acyclic";
static const char __pyx_k_GiacMethods_base_is_cut_set[] = "GiacMethods_base.is_cut_set";
static const char __pyx_k_GiacMethods_base_is_element[] = "GiacMethods_base.is_element";
static const char __pyx_k_GiacMethods_base_is_network[] = "GiacMethods_base.is_network";
static const char __pyx_k_GiacMethods_base_is_regular[] = "GiacMethods_base.is_regular";
static const char __pyx_k_GiacMethods_base_is_rhombus[] = "GiacMethods_base.is_rhombus";
static const char __pyx_k_GiacMethods_base_isopolygon[] = "GiacMethods_base.isopolygon";
static const char __pyx_k_GiacMethods_base_keep_pivot[] = "GiacMethods_base.keep_pivot";
static const char __pyx_k_GiacMethods_base_line_graph[] = "GiacMethods_base.line_graph";
static const char __pyx_k_GiacMethods_base_line_inter[] = "GiacMethods_base.line_inter";
static const char __pyx_k_GiacMethods_base_line_paper[] = "GiacMethods_base.line_paper";
static const char __pyx_k_GiacMethods_base_lineariser[] = "GiacMethods_base.lineariser";
static const char __pyx_k_GiacMethods_base_lis_phrase[] = "GiacMethods_base.lis_phrase";
static const char __pyx_k_GiacMethods_base_lp_integer[] = "GiacMethods_base.lp_integer";
static const char __pyx_k_GiacMethods_base_lp_maxcuts[] = "GiacMethods_base.lp_maxcuts";
static const char __pyx_k_GiacMethods_base_lp_simplex[] = "GiacMethods_base.lp_simplex";
static const char __pyx_k_GiacMethods_base_lp_verbose[] = "GiacMethods_base.lp_verbose";
static const char __pyx_k_GiacMethods_base_makevector[] = "GiacMethods_base.makevector";
static const char __pyx_k_GiacMethods_base_maple2xcas[] = "GiacMethods_base.maple2xcas";
static const char __pyx_k_GiacMethods_base_maple_mode[] = "GiacMethods_base.maple_mode";
static const char __pyx_k_GiacMethods_base_mupad2xcas[] = "GiacMethods_base.mupad2xcas";
static const char __pyx_k_GiacMethods_base_nlp_binary[] = "GiacMethods_base.nlp_binary";
static const char __pyx_k_GiacMethods_base_nlp_method[] = "GiacMethods_base.nlp_method";
static const char __pyx_k_GiacMethods_base_normal_cdf[] = "GiacMethods_base.normal_cdf";
static const char __pyx_k_GiacMethods_base_octahedron[] = "GiacMethods_base.octahedron";
static const char __pyx_k_GiacMethods_base_order_size[] = "GiacMethods_base.order_size";
static const char __pyx_k_GiacMethods_base_orthogonal[] = "GiacMethods_base.orthogonal";
static const char __pyx_k_GiacMethods_base_path_graph[] = "GiacMethods_base.path_graph";
static const char __pyx_k_GiacMethods_base_permuorder[] = "GiacMethods_base.permuorder";
static const char __pyx_k_GiacMethods_base_plane_dual[] = "GiacMethods_base.plane_dual";
static const char __pyx_k_GiacMethods_base_plus_point[] = "GiacMethods_base.plus_point";
static const char __pyx_k_GiacMethods_base_polyhedron[] = "GiacMethods_base.polyhedron";
static const char __pyx_k_GiacMethods_base_projection[] = "GiacMethods_base.projection";
static const char __pyx_k_GiacMethods_base_randfisher[] = "GiacMethods_base.randfisher";
static const char __pyx_k_GiacMethods_base_randgammad[] = "GiacMethods_base.randgammad";
static const char __pyx_k_GiacMethods_base_randmarkov[] = "GiacMethods_base.randmarkov";
static const char __pyx_k_GiacMethods_base_randmatrix[] = "GiacMethods_base.randmatrix";
static const char __pyx_k_GiacMethods_base_randvector[] = "GiacMethods_base.randvector";
static const char __pyx_k_GiacMethods_base_rat_jordan[] = "GiacMethods_base.rat_jordan";
static const char __pyx_k_GiacMethods_base_reflection[] = "GiacMethods_base.reflection";
static const char __pyx_k_GiacMethods_base_rur_gbasis[] = "GiacMethods_base.rur_gbasis";
static const char __pyx_k_GiacMethods_base_samplerate[] = "GiacMethods_base.samplerate";
static const char __pyx_k_GiacMethods_base_set_screen[] = "GiacMethods_base.set_screen";
static const char __pyx_k_GiacMethods_base_similarity[] = "GiacMethods_base.similarity";
static const char __pyx_k_GiacMethods_base_simplifier[] = "GiacMethods_base.simplifier";
static const char __pyx_k_GiacMethods_base_sin2costan[] = "GiacMethods_base.sin2costan";
static const char __pyx_k_GiacMethods_base_slopeatraw[] = "GiacMethods_base.slopeatraw";
static const char __pyx_k_GiacMethods_base_solid_line[] = "GiacMethods_base.solid_line";
static const char __pyx_k_GiacMethods_base_star_graph[] = "GiacMethods_base.star_graph";
static const char __pyx_k_GiacMethods_base_star_point[] = "GiacMethods_base.star_point";
static const char __pyx_k_GiacMethods_base_substituer[] = "GiacMethods_base.substituer";
static const char __pyx_k_GiacMethods_base_tan2sincos[] = "GiacMethods_base.tan2sincos";
static const char __pyx_k_GiacMethods_base_trigexpand[] = "GiacMethods_base.trigexpand";
static const char __pyx_k_GiacMethods_base_triginterp[] = "GiacMethods_base.triginterp";
static const char __pyx_k_GiacMethods_base_unfactored[] = "GiacMethods_base.unfactored";
static const char __pyx_k_GiacMethods_base_vpotential[] = "GiacMethods_base.vpotential";
static const char __pyx_k_GiacMethods_base_znprimroot[] = "GiacMethods_base.znprimroot";
static const char __pyx_k_GiacSetting___reduce_cython[] = "GiacSetting.__reduce_cython__";
static const char __pyx_k_exponential_regression_plot[] = "exponential_regression_plot";
static const char __pyx_k_logarithmic_regression_plot[] = "logarithmic_regression_plot";
static const char __pyx_k_GiacMethods_base_JordanBlock[] = "GiacMethods_base.JordanBlock";
static const char __pyx_k_GiacMethods_base_betavariate[] = "GiacMethods_base.betavariate";
static const char __pyx_k_GiacMethods_base_blockmatrix[] = "GiacMethods_base.blockmatrix";
static const char __pyx_k_GiacMethods_base_cauchy_icdf[] = "GiacMethods_base.cauchy_icdf";
static const char __pyx_k_GiacMethods_base_cauchyd_cdf[] = "GiacMethods_base.cauchyd_cdf";
static const char __pyx_k_GiacMethods_base_complexroot[] = "GiacMethods_base.complexroot";
static const char __pyx_k_GiacMethods_base_contourplot[] = "GiacMethods_base.contourplot";
static const char __pyx_k_GiacMethods_base_convolution[] = "GiacMethods_base.convolution";
static const char __pyx_k_GiacMethods_base_coordinates[] = "GiacMethods_base.coordinates";
static const char __pyx_k_GiacMethods_base_correlation[] = "GiacMethods_base.correlation";
static const char __pyx_k_GiacMethods_base_cross_point[] = "GiacMethods_base.cross_point";
static const char __pyx_k_GiacMethods_base_cross_ratio[] = "GiacMethods_base.cross_ratio";
static const char __pyx_k_GiacMethods_base_cycle_basis[] = "GiacMethods_base.cycle_basis";
static const char __pyx_k_GiacMethods_base_cycle_graph[] = "GiacMethods_base.cycle_graph";
static const char __pyx_k_GiacMethods_base_delete_edge[] = "GiacMethods_base.delete_edge";
static const char __pyx_k_GiacMethods_base_densityplot[] = "GiacMethods_base.densityplot";
static const char __pyx_k_GiacMethods_base_draw_circle[] = "GiacMethods_base.draw_circle";
static const char __pyx_k_GiacMethods_base_eigenvalues[] = "GiacMethods_base.eigenvalues";
static const char __pyx_k_GiacMethods_base_euler_gamma[] = "GiacMethods_base.euler_gamma";
static const char __pyx_k_GiacMethods_base_exponential[] = "GiacMethods_base.exponential";
static const char __pyx_k_GiacMethods_base_expovariate[] = "GiacMethods_base.expovariate";
static const char __pyx_k_GiacMethods_base_find_cycles[] = "GiacMethods_base.find_cycles";
static const char __pyx_k_GiacMethods_base_fisher_icdf[] = "GiacMethods_base.fisher_icdf";
static const char __pyx_k_GiacMethods_base_fisherd_cdf[] = "GiacMethods_base.fisherd_cdf";
static const char __pyx_k_GiacMethods_base_frank_wolfe[] = "GiacMethods_base.frank_wolfe";
static const char __pyx_k_GiacMethods_base_frequencies[] = "GiacMethods_base.frequencies";
static const char __pyx_k_GiacMethods_base_fullparfrac[] = "GiacMethods_base.fullparfrac";
static const char __pyx_k_GiacMethods_base_gammad_icdf[] = "GiacMethods_base.gammad_icdf";
static const char __pyx_k_GiacMethods_base_gl_showaxes[] = "GiacMethods_base.gl_showaxes";
static const char __pyx_k_GiacMethods_base_gramschmidt[] = "GiacMethods_base.gramschmidt";
static const char __pyx_k_GiacMethods_base_graph_equal[] = "GiacMethods_base.graph_equal";
static const char __pyx_k_GiacMethods_base_graph_power[] = "GiacMethods_base.graph_power";
static const char __pyx_k_GiacMethods_base_graph_union[] = "GiacMethods_base.graph_union";
static const char __pyx_k_GiacMethods_base_hann_window[] = "GiacMethods_base.hann_window";
static const char __pyx_k_GiacMethods_base_homogeneize[] = "GiacMethods_base.homogeneize";
static const char __pyx_k_GiacMethods_base_icosahedron[] = "GiacMethods_base.icosahedron";
static const char __pyx_k_GiacMethods_base_is_coplanar[] = "GiacMethods_base.is_coplanar";
static const char __pyx_k_GiacMethods_base_is_directed[] = "GiacMethods_base.is_directed";
static const char __pyx_k_GiacMethods_base_is_eulerian[] = "GiacMethods_base.is_eulerian";
static const char __pyx_k_GiacMethods_base_is_harmonic[] = "GiacMethods_base.is_harmonic";
static const char __pyx_k_GiacMethods_base_is_parallel[] = "GiacMethods_base.is_parallel";
static const char __pyx_k_GiacMethods_base_is_weighted[] = "GiacMethods_base.is_weighted";
static const char __pyx_k_GiacMethods_base_kolmogorovd[] = "GiacMethods_base.kolmogorovd";
static const char __pyx_k_GiacMethods_base_kolmogorovt[] = "GiacMethods_base.kolmogorovt";
static const char __pyx_k_GiacMethods_base_kovacicsols[] = "GiacMethods_base.kovacicsols";
static const char __pyx_k_GiacMethods_base_levenshtein[] = "GiacMethods_base.levenshtein";
static const char __pyx_k_GiacMethods_base_ligne_tiret[] = "GiacMethods_base.ligne_tiret";
static const char __pyx_k_GiacMethods_base_lp_maximize[] = "GiacMethods_base.lp_maximize";
static const char __pyx_k_GiacMethods_base_lp_presolve[] = "GiacMethods_base.lp_presolve";
static const char __pyx_k_GiacMethods_base_make_symbol[] = "GiacMethods_base.make_symbol";
static const char __pyx_k_GiacMethods_base_maple2mupad[] = "GiacMethods_base.maple2mupad";
static const char __pyx_k_GiacMethods_base_matrix_norm[] = "GiacMethods_base.matrix_norm";
static const char __pyx_k_GiacMethods_base_median_line[] = "GiacMethods_base.median_line";
static const char __pyx_k_GiacMethods_base_minimum_cut[] = "GiacMethods_base.minimum_cut";
static const char __pyx_k_GiacMethods_base_multinomial[] = "GiacMethods_base.multinomial";
static const char __pyx_k_GiacMethods_base_mupad2maple[] = "GiacMethods_base.mupad2maple";
static const char __pyx_k_GiacMethods_base_negbinomial[] = "GiacMethods_base.negbinomial";
static const char __pyx_k_GiacMethods_base_nlp_integer[] = "GiacMethods_base.nlp_integer";
static const char __pyx_k_GiacMethods_base_nlp_verbose[] = "GiacMethods_base.nlp_verbose";
static const char __pyx_k_GiacMethods_base_normal_icdf[] = "GiacMethods_base.normal_icdf";
static const char __pyx_k_GiacMethods_base_normald_cdf[] = "GiacMethods_base.normald_cdf";
static const char __pyx_k_GiacMethods_base_orthocenter[] = "GiacMethods_base.orthocenter";
static const char __pyx_k_GiacMethods_base_paley_graph[] = "GiacMethods_base.paley_graph";
static const char __pyx_k_GiacMethods_base_pas_de_cote[] = "GiacMethods_base.pas_de_cote";
static const char __pyx_k_GiacMethods_base_perimeterat[] = "GiacMethods_base.perimeterat";
static const char __pyx_k_GiacMethods_base_plotcontour[] = "GiacMethods_base.plotcontour";
static const char __pyx_k_GiacMethods_base_plotdensity[] = "GiacMethods_base.plotdensity";
static const char __pyx_k_GiacMethods_base_poisson_cdf[] = "GiacMethods_base.poisson_cdf";
static const char __pyx_k_GiacMethods_base_polar_point[] = "GiacMethods_base.polar_point";
static const char __pyx_k_GiacMethods_base_polygonplot[] = "GiacMethods_base.polygonplot";
static const char __pyx_k_GiacMethods_base_prism_graph[] = "GiacMethods_base.prism_graph";
static const char __pyx_k_GiacMethods_base_random_tree[] = "GiacMethods_base.random_tree";
static const char __pyx_k_GiacMethods_base_randpoisson[] = "GiacMethods_base.randpoisson";
static const char __pyx_k_GiacMethods_base_randstudent[] = "GiacMethods_base.randstudent";
static const char __pyx_k_GiacMethods_base_rm_all_vars[] = "GiacMethods_base.rm_all_vars";
static const char __pyx_k_GiacMethods_base_rur_certify[] = "GiacMethods_base.rur_certify";
static const char __pyx_k_GiacMethods_base_scatterplot[] = "GiacMethods_base.scatterplot";
static const char __pyx_k_GiacMethods_base_shift_phase[] = "GiacMethods_base.shift_phase";
static const char __pyx_k_GiacMethods_base_show_pixels[] = "GiacMethods_base.show_pixels";
static const char __pyx_k_GiacMethods_base_st_ordering[] = "GiacMethods_base.st_ordering";
static const char __pyx_k_GiacMethods_base_stereo2mono[] = "GiacMethods_base.stereo2mono";
static const char __pyx_k_GiacMethods_base_student_cdf[] = "GiacMethods_base.student_cdf";
static const char __pyx_k_GiacMethods_base_sum_riemann[] = "GiacMethods_base.sum_riemann";
static const char __pyx_k_GiacMethods_base_switch_axes[] = "GiacMethods_base.switch_axes";
static const char __pyx_k_GiacMethods_base_tan2cossin2[] = "GiacMethods_base.tan2cossin2";
static const char __pyx_k_GiacMethods_base_tan2sincos2[] = "GiacMethods_base.tan2sincos2";
static const char __pyx_k_GiacMethods_base_tchebyshev1[] = "GiacMethods_base.tchebyshev1";
static const char __pyx_k_GiacMethods_base_tchebyshev2[] = "GiacMethods_base.tchebyshev2";
static const char __pyx_k_GiacMethods_base_tetrahedron[] = "GiacMethods_base.tetrahedron";
static const char __pyx_k_GiacMethods_base_trail2edges[] = "GiacMethods_base.trail2edges";
static const char __pyx_k_GiacMethods_base_translation[] = "GiacMethods_base.translation";
static const char __pyx_k_GiacMethods_base_tree_height[] = "GiacMethods_base.tree_height";
static const char __pyx_k_GiacMethods_base_uniform_cdf[] = "GiacMethods_base.uniform_cdf";
static const char __pyx_k_GiacMethods_base_vandermonde[] = "GiacMethods_base.vandermonde";
static const char __pyx_k_GiacMethods_base_weibull_cdf[] = "GiacMethods_base.weibull_cdf";
static const char __pyx_k_GiacMethods_base_wheel_graph[] = "GiacMethods_base.wheel_graph";
static const char __pyx_k_GiacMethods_base_widget_size[] = "GiacMethods_base.widget_size";
static const char __pyx_k_Pygen___rtruediv___line_1337[] = "Pygen.__rtruediv__ (line 1337)";
static const char __pyx_k_multiplier_conjugue_complexe[] = "multiplier_conjugue_complexe";
static const char __pyx_k_GiacMethods_base_VAS_positive[] = "GiacMethods_base.VAS_positive";
static const char __pyx_k_GiacMethods_base_additionally[] = "GiacMethods_base.additionally";
static const char __pyx_k_GiacMethods_base_angle_radian[] = "GiacMethods_base.angle_radian";
static const char __pyx_k_GiacMethods_base_autosimplify[] = "GiacMethods_base.autosimplify";
static const char __pyx_k_GiacMethods_base_bellman_ford[] = "GiacMethods_base.bellman_ford";
static const char __pyx_k_GiacMethods_base_binomial_cdf[] = "GiacMethods_base.binomial_cdf";
static const char __pyx_k_GiacMethods_base_brent_solver[] = "GiacMethods_base.brent_solver";
static const char __pyx_k_GiacMethods_base_cauchyd_icdf[] = "GiacMethods_base.cauchyd_icdf";
static const char __pyx_k_GiacMethods_base_channel_data[] = "GiacMethods_base.channel_data";
static const char __pyx_k_GiacMethods_base_circumcircle[] = "GiacMethods_base.circumcircle";
static const char __pyx_k_GiacMethods_base_clique_cover[] = "GiacMethods_base.clique_cover";
static const char __pyx_k_GiacMethods_base_condensation[] = "GiacMethods_base.condensation";
static const char __pyx_k_GiacMethods_base_crossproduct[] = "GiacMethods_base.crossproduct";
static const char __pyx_k_GiacMethods_base_cycles2permu[] = "GiacMethods_base.cycles2permu";
static const char __pyx_k_GiacMethods_base_dashdot_line[] = "GiacMethods_base.dashdot_line";
static const char __pyx_k_GiacMethods_base_dodecahedron[] = "GiacMethods_base.dodecahedron";
static const char __pyx_k_GiacMethods_base_draw_polygon[] = "GiacMethods_base.draw_polygon";
static const char __pyx_k_GiacMethods_base_eigenvectors[] = "GiacMethods_base.eigenvectors";
static const char __pyx_k_GiacMethods_base_epsilon2zero[] = "GiacMethods_base.epsilon2zero";
static const char __pyx_k_GiacMethods_base_exponentiald[] = "GiacMethods_base.exponentiald";
static const char __pyx_k_GiacMethods_base_export_graph[] = "GiacMethods_base.export_graph";
static const char __pyx_k_GiacMethods_base_find_cliques[] = "GiacMethods_base.find_cliques";
static const char __pyx_k_GiacMethods_base_find_minimum[] = "GiacMethods_base.find_minimum";
static const char __pyx_k_GiacMethods_base_fisherd_icdf[] = "GiacMethods_base.fisherd_icdf";
static const char __pyx_k_GiacMethods_base_flower_snark[] = "GiacMethods_base.flower_snark";
static const char __pyx_k_GiacMethods_base_gammavariate[] = "GiacMethods_base.gammavariate";
static const char __pyx_k_GiacMethods_base_greedy_color[] = "GiacMethods_base.greedy_color";
static const char __pyx_k_GiacMethods_base_implicitdiff[] = "GiacMethods_base.implicitdiff";
static const char __pyx_k_GiacMethods_base_implicitplot[] = "GiacMethods_base.implicitplot";
static const char __pyx_k_GiacMethods_base_import_graph[] = "GiacMethods_base.import_graph";
static const char __pyx_k_GiacMethods_base_is_bipartite[] = "GiacMethods_base.is_bipartite";
static const char __pyx_k_GiacMethods_base_is_collinear[] = "GiacMethods_base.is_collinear";
static const char __pyx_k_GiacMethods_base_is_concyclic[] = "GiacMethods_base.is_concyclic";
static const char __pyx_k_GiacMethods_base_is_conjugate[] = "GiacMethods_base.is_conjugate";
static const char __pyx_k_GiacMethods_base_is_connected[] = "GiacMethods_base.is_connected";
static const char __pyx_k_GiacMethods_base_is_isosceles[] = "GiacMethods_base.is_isosceles";
static const char __pyx_k_GiacMethods_base_is_reachable[] = "GiacMethods_base.is_reachable";
static const char __pyx_k_GiacMethods_base_is_rectangle[] = "GiacMethods_base.is_rectangle";
static const char __pyx_k_GiacMethods_base_kneser_graph[] = "GiacMethods_base.kneser_graph";
static const char __pyx_k_GiacMethods_base_lp_heuristic[] = "GiacMethods_base.lp_heuristic";
static const char __pyx_k_GiacMethods_base_lp_nodelimit[] = "GiacMethods_base.lp_nodelimit";
static const char __pyx_k_GiacMethods_base_lp_nonnegint[] = "GiacMethods_base.lp_nonnegint";
static const char __pyx_k_GiacMethods_base_lp_timelimit[] = "GiacMethods_base.lp_timelimit";
static const char __pyx_k_GiacMethods_base_lp_varselect[] = "GiacMethods_base.lp_varselect";
static const char __pyx_k_GiacMethods_base_middle_point[] = "GiacMethods_base.middle_point";
static const char __pyx_k_GiacMethods_base_nlp_maximize[] = "GiacMethods_base.nlp_maximize";
static const char __pyx_k_GiacMethods_base_nlp_presolve[] = "GiacMethods_base.nlp_presolve";
static const char __pyx_k_GiacMethods_base_normald_icdf[] = "GiacMethods_base.normald_icdf";
static const char __pyx_k_GiacMethods_base_nuage_points[] = "GiacMethods_base.nuage_points";
static const char __pyx_k_GiacMethods_base_open_polygon[] = "GiacMethods_base.open_polygon";
static const char __pyx_k_GiacMethods_base_permu2cycles[] = "GiacMethods_base.permu2cycles";
static const char __pyx_k_GiacMethods_base_plotimplicit[] = "GiacMethods_base.plotimplicit";
static const char __pyx_k_GiacMethods_base_plotspectrum[] = "GiacMethods_base.plotspectrum";
static const char __pyx_k_GiacMethods_base_poisson_icdf[] = "GiacMethods_base.poisson_icdf";
static const char __pyx_k_GiacMethods_base_pruefer_code[] = "GiacMethods_base.pruefer_code";
static const char __pyx_k_GiacMethods_base_radical_axis[] = "GiacMethods_base.radical_axis";
static const char __pyx_k_GiacMethods_base_randbinomial[] = "GiacMethods_base.randbinomial";
static const char __pyx_k_GiacMethods_base_random_graph[] = "GiacMethods_base.random_graph";
static const char __pyx_k_GiacMethods_base_randweibulld[] = "GiacMethods_base.randweibulld";
static const char __pyx_k_GiacMethods_base_rationalroot[] = "GiacMethods_base.rationalroot";
static const char __pyx_k_GiacMethods_base_rmbreakpoint[] = "GiacMethods_base.rmbreakpoint";
static const char __pyx_k_GiacMethods_base_semi_augment[] = "GiacMethods_base.semi_augment";
static const char __pyx_k_GiacMethods_base_single_inter[] = "GiacMethods_base.single_inter";
static const char __pyx_k_GiacMethods_base_snedecor_cdf[] = "GiacMethods_base.snedecor_cdf";
static const char __pyx_k_GiacMethods_base_square_point[] = "GiacMethods_base.square_point";
static const char __pyx_k_GiacMethods_base_student_icdf[] = "GiacMethods_base.student_icdf";
static const char __pyx_k_GiacMethods_base_symbol_array[] = "GiacMethods_base.symbol_array";
static const char __pyx_k_GiacMethods_base_total_degree[] = "GiacMethods_base.total_degree";
static const char __pyx_k_GiacMethods_base_trigsimplify[] = "GiacMethods_base.trigsimplify";
static const char __pyx_k_GiacMethods_base_tukey_window[] = "GiacMethods_base.tukey_window";
static const char __pyx_k_GiacMethods_base_uniform_icdf[] = "GiacMethods_base.uniform_icdf";
static const char __pyx_k_GiacMethods_base_uniformd_cdf[] = "GiacMethods_base.uniformd_cdf";
static const char __pyx_k_GiacMethods_base_vertices_abc[] = "GiacMethods_base.vertices_abc";
static const char __pyx_k_GiacMethods_base_weibull_icdf[] = "GiacMethods_base.weibull_icdf";
static const char __pyx_k_GiacMethods_base_weibulld_cdf[] = "GiacMethods_base.weibulld_cdf";
static const char __pyx_k_GiacMethods_base_weight_decay[] = "GiacMethods_base.weight_decay";
static const char __pyx_k_GiacMethods_base_welch_window[] = "GiacMethods_base.welch_window";
static const char __pyx_k_GiacSetting___setstate_cython[] = "GiacSetting.__setstate_cython__";
static const char __pyx_k_Interrupted_by_a_ctrl_c_event[] = "Interrupted by a ctrl-c event";
static const char __pyx_k_pyx_unpickle_GiacMethods_base[] = "__pyx_unpickle_GiacMethods_base";
static const char __pyx_k_strongly_connected_components[] = "strongly_connected_components";
static const char __pyx_k_two_edge_connected_components[] = "two_edge_connected_components";
static const char __pyx_k_GiacMethods_base_BlockDiagonal[] = "GiacMethods_base.BlockDiagonal";
static const char __pyx_k_GiacMethods_base_baisse_crayon[] = "GiacMethods_base.baisse_crayon";
static const char __pyx_k_GiacMethods_base_bernoulli_mod[] = "GiacMethods_base.bernoulli_mod";
static const char __pyx_k_GiacMethods_base_binomial_icdf[] = "GiacMethods_base.binomial_icdf";
static const char __pyx_k_GiacMethods_base_bohman_window[] = "GiacMethods_base.bohman_window";
static const char __pyx_k_GiacMethods_base_centered_cube[] = "GiacMethods_base.centered_cube";
static const char __pyx_k_GiacMethods_base_chisquare_cdf[] = "GiacMethods_base.chisquare_cdf";
static const char __pyx_k_GiacMethods_base_clique_number[] = "GiacMethods_base.clique_number";
static const char __pyx_k_GiacMethods_base_contract_edge[] = "GiacMethods_base.contract_edge";
static const char __pyx_k_GiacMethods_base_cosine_window[] = "GiacMethods_base.cosine_window";
static const char __pyx_k_GiacMethods_base_crationalroot[] = "GiacMethods_base.crationalroot";
static const char __pyx_k_GiacMethods_base_cross_entropy[] = "GiacMethods_base.cross_entropy";
static const char __pyx_k_GiacMethods_base_current_sheet[] = "GiacMethods_base.current_sheet";
static const char __pyx_k_GiacMethods_base_delete_vertex[] = "GiacMethods_base.delete_vertex";
static const char __pyx_k_GiacMethods_base_disque_centre[] = "GiacMethods_base.disque_centre";
static const char __pyx_k_GiacMethods_base_distanceatraw[] = "GiacMethods_base.distanceatraw";
static const char __pyx_k_GiacMethods_base_ecef2geodetic[] = "GiacMethods_base.ecef2geodetic";
static const char __pyx_k_GiacMethods_base_export_mathml[] = "GiacMethods_base.export_mathml";
static const char __pyx_k_GiacMethods_base_function_diff[] = "GiacMethods_base.function_diff";
static const char __pyx_k_GiacMethods_base_geodetic2ecef[] = "GiacMethods_base.geodetic2ecef";
static const char __pyx_k_GiacMethods_base_geometric_cdf[] = "GiacMethods_base.geometric_cdf";
static const char __pyx_k_GiacMethods_base_greedy_clique[] = "GiacMethods_base.greedy_clique";
static const char __pyx_k_GiacMethods_base_hybrid_solver[] = "GiacMethods_base.hybrid_solver";
static const char __pyx_k_GiacMethods_base_is_isomorphic[] = "GiacMethods_base.is_isomorphic";
static const char __pyx_k_GiacMethods_base_is_orthogonal[] = "GiacMethods_base.is_orthogonal";
static const char __pyx_k_GiacMethods_base_is_tournament[] = "GiacMethods_base.is_tournament";
static const char __pyx_k_GiacMethods_base_isobarycenter[] = "GiacMethods_base.isobarycenter";
static const char __pyx_k_GiacMethods_base_jacobi_symbol[] = "GiacMethods_base.jacobi_symbol";
static const char __pyx_k_GiacMethods_base_johnson_graph[] = "GiacMethods_base.johnson_graph";
static const char __pyx_k_GiacMethods_base_learning_rate[] = "GiacMethods_base.learning_rate";
static const char __pyx_k_GiacMethods_base_line_segments[] = "GiacMethods_base.line_segments";
static const char __pyx_k_GiacMethods_base_lp_depthfirst[] = "GiacMethods_base.lp_depthfirst";
static const char __pyx_k_GiacMethods_base_lp_depthlimit[] = "GiacMethods_base.lp_depthlimit";
static const char __pyx_k_GiacMethods_base_lp_nodeselect[] = "GiacMethods_base.lp_nodeselect";
static const char __pyx_k_GiacMethods_base_lp_pseudocost[] = "GiacMethods_base.lp_pseudocost";
static const char __pyx_k_GiacMethods_base_make_directed[] = "GiacMethods_base.make_directed";
static const char __pyx_k_GiacMethods_base_make_weighted[] = "GiacMethods_base.make_weighted";
static const char __pyx_k_GiacMethods_base_montre_tortue[] = "GiacMethods_base.montre_tortue";
static const char __pyx_k_GiacMethods_base_newton_solver[] = "GiacMethods_base.newton_solver";
static const char __pyx_k_GiacMethods_base_nlp_nonnegint[] = "GiacMethods_base.nlp_nonnegint";
static const char __pyx_k_GiacMethods_base_nlp_precision[] = "GiacMethods_base.nlp_precision";
static const char __pyx_k_GiacMethods_base_nlp_tolerance[] = "GiacMethods_base.nlp_tolerance";
static const char __pyx_k_GiacMethods_base_normalvariate[] = "GiacMethods_base.normalvariate";
static const char __pyx_k_GiacMethods_base_parallelogram[] = "GiacMethods_base.parallelogram";
static const char __pyx_k_GiacMethods_base_parzen_window[] = "GiacMethods_base.parzen_window";
static const char __pyx_k_GiacMethods_base_perpendicular[] = "GiacMethods_base.perpendicular";
static const char __pyx_k_GiacMethods_base_python_compat[] = "GiacMethods_base.python_compat";
static const char __pyx_k_GiacMethods_base_quadrilateral[] = "GiacMethods_base.quadrilateral";
static const char __pyx_k_GiacMethods_base_randchisquare[] = "GiacMethods_base.randchisquare";
static const char __pyx_k_GiacMethods_base_randgeometric[] = "GiacMethods_base.randgeometric";
static const char __pyx_k_GiacMethods_base_reciprocation[] = "GiacMethods_base.reciprocation";
static const char __pyx_k_GiacMethods_base_reduced_conic[] = "GiacMethods_base.reduced_conic";
static const char __pyx_k_GiacMethods_base_reverse_graph[] = "GiacMethods_base.reverse_graph";
static const char __pyx_k_GiacMethods_base_rhombus_point[] = "GiacMethods_base.rhombus_point";
static const char __pyx_k_GiacMethods_base_scalarProduct[] = "GiacMethods_base.scalarProduct";
static const char __pyx_k_GiacMethods_base_secant_solver[] = "GiacMethods_base.secant_solver";
static const char __pyx_k_GiacMethods_base_seidel_switch[] = "GiacMethods_base.seidel_switch";
static const char __pyx_k_GiacMethods_base_shortest_path[] = "GiacMethods_base.shortest_path";
static const char __pyx_k_GiacMethods_base_simplifyDirac[] = "GiacMethods_base.simplifyDirac";
static const char __pyx_k_GiacMethods_base_snedecor_icdf[] = "GiacMethods_base.snedecor_icdf";
static const char __pyx_k_GiacMethods_base_snedecord_cdf[] = "GiacMethods_base.snedecord_cdf";
static const char __pyx_k_GiacMethods_base_spanning_tree[] = "GiacMethods_base.spanning_tree";
static const char __pyx_k_GiacMethods_base_tourne_droite[] = "GiacMethods_base.tourne_droite";
static const char __pyx_k_GiacMethods_base_tourne_gauche[] = "GiacMethods_base.tourne_gauche";
static const char __pyx_k_GiacMethods_base_uniformd_icdf[] = "GiacMethods_base.uniformd_icdf";
static const char __pyx_k_GiacMethods_base_user_operator[] = "GiacMethods_base.user_operator";
static const char __pyx_k_GiacMethods_base_vertex_degree[] = "GiacMethods_base.vertex_degree";
static const char __pyx_k_GiacMethods_base_vertices_abca[] = "GiacMethods_base.vertices_abca";
static const char __pyx_k_GiacMethods_base_weibulld_icdf[] = "GiacMethods_base.weibulld_icdf";
static const char __pyx_k_GiacMethods_base_weight_matrix[] = "GiacMethods_base.weight_matrix";
static const char __pyx_k_Open_a_file_in_giac_compressed[] = "\n          Open a file in giac compressed format to create a Pygen element.\n\n          Use the save method from Pygen elements to create such files.\n\n          In C++ these files can be opened with giac::unarchive and created with\n          giac::archive\n\n            >>> from giacpy import *\n            >>> g=texpand('tan(10*a+3*b)')\n            >>> g.save(\"fichiertest\")           #  doctest: +SKIP\n            >>> a=loadgiacgen(\"fichiertest\")    #  doctest: +SKIP\n\n        ";
static const char __pyx_k_Send_a_giac_graphic_to_qcas_3D[] = "\n       * Send a giac graphic to qcas. (3D is currently not supported in qcas)\n\n        >>> d1=giac('plot(x*sin(x))')\n        >>> d1.qcas()    # doctest: +SKIP\n        >>> l=giac([(d1.homothety(0,t*0.1)).color(t) for t in range(10)])\n        >>> l.qcas()     # doctest: +SKIP\n\n       ";
static const char __pyx_k_Set_the_value_of_a_coefficient[] = "\n        Set the value of a coefficient of a giac vector or matrix or list.\n           Warning: It is an in place affectation.\n\n\n        >>> A=giac([ [ j+2*i for i in range(3)] for j in range(3)]); A\n        [[0,2,4],[1,3,5],[2,4,6]]\n        >>> A[1,2]=44;A\n        [[0,2,4],[1,3,44],[2,4,6]]\n        >>> A[2][2]=giac(1)/3;A\n        [[0,2,4],[1,3,44],[2,4,1/3]]\n        >>> x=giac('x')\n        >>> A[0,0]=x+1/x; A\n        [[x+1/x,2,4],[1,3,44],[2,4,1/3]]\n        >>> A[0]=[-1,-2,-3]; A\n        [[-1,-2,-3],[1,3,44],[2,4,1/3]]\n        >>> B=A; A[2,2]\n        1/3\n        >>> B[2,2]=6    # in place affectation\n        >>> A[2,2]      # so A is also modified\n        6\n        >>> A.pcar(x)\n        x**3-8*x**2-159*x\n\n\n        NB: For Large matrix it seems that the syntax A[i][j]= is faster that A[i,j]=\n\n        >>> import giacpy\n        >>> from time import time\n        >>> A=giacpy.ranm(4000,4000)\n        >>> t1=time(); A[500][500]=12345;t1=time()-t1\n        >>> t2=time(); A[501,501]=54321;t2=time()-t2\n        >>> t1,t2 # doctest: +SKIP\n        (0.0002014636993408203, 0.05124521255493164)\n        >>> A[500,500],A[501][501]\n        (12345, 54321)\n\n        ";
static const char __pyx_k_from_giacpy_import_giac_giac_3[] = "\n     >>> from giacpy import giac\n     >>> giac(3**100)\n     515377520732011331036461129765621272702107522001\n     >>> giac(-3**100)\n     -515377520732011331036461129765621272702107522001\n     >>> giac(-11**1000)\n     -2469932918005826334124088385085221477709733385238396234869182951830739390375433175367866116456946191973803561189036523363533798726571008961243792655536655282201820357872673322901148243453211756020067624545609411212063417307681204817377763465511222635167942816318177424600927358163388910854695041070577642045540560963004207926938348086979035423732739933235077042750354729095729602516751896320598857608367865475244863114521391548985943858154775884418927768284663678512441565517194156946312753546771163991252528017732162399536497445066348868438762510366191040118080751580689254476068034620047646422315123643119627205531371694188794408120267120500325775293645416335230014278578281272863450085145349124727476223298887655183167465713337723258182649072572861625150703747030550736347589416285606367521524529665763903537989935510874657420361426804068643262800901916285076966174176854351055183740078763891951775452021781225066361670593917001215032839838911476044840388663443684517735022039957481918726697789827894303408292584258328090724141496484460001\n    >>> v=[1,58,1387,17715,131260,578697,1538013,2648041,3687447,4993299,5858116,5979221,5239798,4098561,3176188,1660466,705432]\n    >>> giac(v)*v\n    175925584603774\n    >>> giac([v])*(giac([v]).transpose())\n    matrix[[175925584603774]]\n    >>> v=giac('pari()')\n    >>> if len(v)>200:\n    ...    giac('pari(18446744073709551616)')\n    ... else:\n    ...    giac('2^64')\n    18446744073709551616\n\n    Testing substraction of table/sparse matrix\n    >>> A=giacpy.table(())\n    >>> B=giacpy.table([[1]])\n    >>> A-B\n    table(\n    (0,0) = -1\n    )\n\n    Testing randseed\n    >>> from giacpy import randvector,randseed,srand\n    >>> a=randvector(50)\n    >>> randseed(10)\n    10\n    >>> a=randvector(50)\n    >"">> srand(10)\n    10\n    >>> a==randvector(50)\n    True\n \n   ";
static const char __pyx_k_Archive_a_Pygen_element_to_a_fi[] = "\n          Archive a Pygen element to a file in giac compressed format.\n\n          Use the loadgiacgen command to get back the Pygen from the file.\n\n          In C++ these files can be opened with giac::unarchive\n\n            >>> from giacpy import *\n            >>> f=giac('(x+y+z+2)**10'); g=f.normal()\n            >>> g.save(\"fichiertest\")           #  doctest: +SKIP\n            >>> a=loadgiacgen(\"fichiertest\")    #  doctest: +SKIP\n            >>> from tempfile import NamedTemporaryFile\n            >>> F=NamedTemporaryFile()   # chose a temporary file for a test\n            >>> Fname=F.name; F.close()  # so Fname can be our filename  \n            >>> g.save(Fname)\n            >>> a=loadgiacgen(Fname)\n            >>> a.factor()\n            (x+y+z+2)**10\n            >>> F.close()\n\n        ";
static const char __pyx_k_Convert_a_giac_integer_type_Pyg[] = "\n          Convert a giac integer (type Pygen in python) to  a Python <int>\n\n            >>> a=giac('2*pi')\n            >>> list(range((a.floor()).__int__()))\n            [0, 1, 2, 3, 4, 5]\n\n        ";
static const char __pyx_k_Convert_a_giac_real_to_a_Python[] = "\n           Convert a giac real to a Python <float>\n\n             >>> a=giac('pi/4.0')\n             >>> import math\n             >>> math.sin(a)    # doctest: +SKIP\n             0.70710678118654...\n             >>> a=giac(2)\n             >>> math.sqrt(a) == math.sqrt(2)\n             True\n\n        ";
static const char __pyx_k_EXPERIMENTAL_Send_a_giac_comman[] = "\n   * EXPERIMENTAL: Send a giac command to an  interactive 2D geometry display in qcas.\n     Current state: Geometric objects will be displayed, but only geometric objects STORED in a giac variable can be used for interactive geometric constructions in qcas.\n\n    >>> d1='A:=point(1+i);t:=element(10..100,1,10);C:=circle(A,t*0.05);M:=element(C);'\n    >>> qcas(d1)    # doctest: +SKIP\n\n   ";
static const char __pyx_k_GiacMethods_base_Heaviside2sign[] = "GiacMethods_base.Heaviside2sign";
static const char __pyx_k_GiacMethods_base_adjoint_matrix[] = "GiacMethods_base.adjoint_matrix";
static const char __pyx_k_GiacMethods_base_bezout_entiers[] = "GiacMethods_base.bezout_entiers";
static const char __pyx_k_GiacMethods_base_canonical_form[] = "GiacMethods_base.canonical_form";
static const char __pyx_k_GiacMethods_base_chisquare_icdf[] = "GiacMethods_base.chisquare_icdf";
static const char __pyx_k_GiacMethods_base_chisquared_cdf[] = "GiacMethods_base.chisquared_cdf";
static const char __pyx_k_GiacMethods_base_complete_graph[] = "GiacMethods_base.complete_graph";
static const char __pyx_k_GiacMethods_base_courbe_polaire[] = "GiacMethods_base.courbe_polaire";
static const char __pyx_k_GiacMethods_base_dessine_tortue[] = "GiacMethods_base.dessine_tortue";
static const char __pyx_k_GiacMethods_base_discard_vertex[] = "GiacMethods_base.discard_vertex_attribute";
static const char __pyx_k_GiacMethods_base_disjoint_union[] = "GiacMethods_base.disjoint_union";
static const char __pyx_k_GiacMethods_base_division_point[] = "GiacMethods_base.division_point";
static const char __pyx_k_GiacMethods_base_dnewton_solver[] = "GiacMethods_base.dnewton_solver";
static const char __pyx_k_GiacMethods_base_draw_rectangle[] = "GiacMethods_base.draw_rectangle";
static const char __pyx_k_GiacMethods_base_euler_lagrange[] = "GiacMethods_base.euler_lagrange";
static const char __pyx_k_GiacMethods_base_factoriser_sur[] = "GiacMethods_base.factoriser_sur_C";
static const char __pyx_k_GiacMethods_base_float2rational[] = "GiacMethods_base.float2rational";
static const char __pyx_k_GiacMethods_base_frobenius_norm[] = "GiacMethods_base.frobenius_norm";
static const char __pyx_k_GiacMethods_base_geometric_icdf[] = "GiacMethods_base.geometric_icdf";
static const char __pyx_k_GiacMethods_base_goldberg_snark[] = "GiacMethods_base.goldberg_snark";
static const char __pyx_k_GiacMethods_base_graph_charpoly[] = "GiacMethods_base.graph_charpoly";
static const char __pyx_k_GiacMethods_base_graph_diameter[] = "GiacMethods_base.graph_diameter";
static const char __pyx_k_GiacMethods_base_graph_spectrum[] = "GiacMethods_base.graph_spectrum";
static const char __pyx_k_GiacMethods_base_graph_vertices[] = "GiacMethods_base.graph_vertices";
static const char __pyx_k_GiacMethods_base_hamming_window[] = "GiacMethods_base.hamming_window";
static const char __pyx_k_GiacMethods_base_hybridj_solver[] = "GiacMethods_base.hybridj_solver";
static const char __pyx_k_GiacMethods_base_hybrids_solver[] = "GiacMethods_base.hybrids_solver";
static const char __pyx_k_GiacMethods_base_identify_graph[] = "GiacMethods_base.identify_graph";
static const char __pyx_k_GiacMethods_base_incident_edges[] = "GiacMethods_base.incident_edges";
static const char __pyx_k_GiacMethods_base_inequationplot[] = "GiacMethods_base.inequationplot";
static const char __pyx_k_GiacMethods_base_interval_graph[] = "GiacMethods_base.interval_graph";
static const char __pyx_k_GiacMethods_base_is_biconnected[] = "GiacMethods_base.is_biconnected";
static const char __pyx_k_GiacMethods_base_is_cospherical[] = "GiacMethods_base.is_cospherical";
static const char __pyx_k_GiacMethods_base_is_equilateral[] = "GiacMethods_base.is_equilateral";
static const char __pyx_k_GiacMethods_base_is_hamiltonian[] = "GiacMethods_base.is_hamiltonian";
static const char __pyx_k_GiacMethods_base_is_irreducible[] = "GiacMethods_base.is_irreducible";
static const char __pyx_k_GiacMethods_base_is_pseudoprime[] = "GiacMethods_base.is_pseudoprime";
static const char __pyx_k_GiacMethods_base_is_split_graph[] = "GiacMethods_base.is_split_graph";
static const char __pyx_k_GiacMethods_base_kernel_density[] = "GiacMethods_base.kernel_density";
static const char __pyx_k_GiacMethods_base_left_rectangle[] = "GiacMethods_base.left_rectangle";
static const char __pyx_k_GiacMethods_base_lp_nonnegative[] = "GiacMethods_base.lp_nonnegative";
static const char __pyx_k_GiacMethods_base_maple_ifactors[] = "GiacMethods_base.maple_ifactors";
static const char __pyx_k_GiacMethods_base_maximum_clique[] = "GiacMethods_base.maximum_clique";
static const char __pyx_k_GiacMethods_base_maximum_degree[] = "GiacMethods_base.maximum_degree";
static const char __pyx_k_GiacMethods_base_minimal_vertex[] = "GiacMethods_base.minimal_vertex_coloring";
static const char __pyx_k_GiacMethods_base_minimum_degree[] = "GiacMethods_base.minimum_degree";
static const char __pyx_k_GiacMethods_base_minimum_vertex[] = "GiacMethods_base.minimum_vertex_cover";
static const char __pyx_k_GiacMethods_base_moving_average[] = "GiacMethods_base.moving_average";
static const char __pyx_k_GiacMethods_base_mult_conjugate[] = "GiacMethods_base.mult_conjugate";
static const char __pyx_k_GiacMethods_base_neural_network[] = "GiacMethods_base.neural_network";
static const char __pyx_k_GiacMethods_base_newtonj_solver[] = "GiacMethods_base.newtonj_solver";
static const char __pyx_k_GiacMethods_base_parallelepiped[] = "GiacMethods_base.parallelepiped";
static const char __pyx_k_GiacMethods_base_perimeteratraw[] = "GiacMethods_base.perimeteratraw";
static const char __pyx_k_GiacMethods_base_petersen_graph[] = "GiacMethods_base.petersen_graph";
static const char __pyx_k_GiacMethods_base_plotinequation[] = "GiacMethods_base.plotinequation";
static const char __pyx_k_GiacMethods_base_poisson_window[] = "GiacMethods_base.poisson_window";
static const char __pyx_k_GiacMethods_base_random_digraph[] = "GiacMethods_base.random_digraph";
static const char __pyx_k_GiacMethods_base_random_network[] = "GiacMethods_base.random_network";
static const char __pyx_k_GiacMethods_base_random_regular[] = "GiacMethods_base.random_regular_graph";
static const char __pyx_k_GiacMethods_base_reverse_rsolve[] = "GiacMethods_base.reverse_rsolve";
static const char __pyx_k_GiacMethods_base_riemann_window[] = "GiacMethods_base.riemann_window";
static const char __pyx_k_GiacMethods_base_right_triangle[] = "GiacMethods_base.right_triangle";
static const char __pyx_k_GiacMethods_base_scalar_product[] = "GiacMethods_base.scalar_product";
static const char __pyx_k_GiacMethods_base_sequence_graph[] = "GiacMethods_base.sequence_graph";
static const char __pyx_k_GiacMethods_base_sign2Heaviside[] = "GiacMethods_base.sign2Heaviside";
static const char __pyx_k_GiacMethods_base_simplex_reduce[] = "GiacMethods_base.simplex_reduce";
static const char __pyx_k_GiacMethods_base_snedecord_icdf[] = "GiacMethods_base.snedecord_icdf";
static const char __pyx_k_GiacMethods_base_tensor_product[] = "GiacMethods_base.tensor_product";
static const char __pyx_k_GiacMethods_base_topologic_sort[] = "GiacMethods_base.topologic_sort";
static const char __pyx_k_GiacMethods_base_triangle_paper[] = "GiacMethods_base.triangle_paper";
static const char __pyx_k_GiacMethods_base_triangle_plein[] = "GiacMethods_base.triangle_plein";
static const char __pyx_k_GiacMethods_base_triangle_point[] = "GiacMethods_base.triangle_point";
static const char __pyx_k_GiacMethods_base_truncate_graph[] = "GiacMethods_base.truncate_graph";
static const char __pyx_k_GiacMethods_base_weibullvariate[] = "GiacMethods_base.weibullvariate";
static const char __pyx_k_Increase_the_size_of_a_matrix_w[] = "\n        * Increase the size of a matrix when possible, otherwise return self.\n\n        >>> C=giac([[1,2]])\n        >>> C.redim(2,3)\n        [[1,2,0],[0,0,0]]\n        >>> C.redim(2,1)\n        [[1,2]]\n\n        ";
static const char __pyx_k_Lists_of_10_6_integers_should_b[] = "\n         Lists of 10**6 integers should be translated to giac easily\n\n           >>> l=giac(list(range(10**6)));l[5]   #python3\n           5\n           >>> l[35:50:7]\n           [35,42,49]\n           >>> t=giac(tuple(range(10)))\n           >>> t[:4:-1]\n           9,8,7,6,5\n           >>> x=giac('x'); sum([ x[i] for i in range(5)])**3\n           (x[0]+x[1]+x[2]+x[3]+x[4])**3\n           >>> import giacpy\n           >>> A=giacpy.ranm(5,10); A[3,7]-A[3][7]\n           0\n           >>> A.transpose()[8,2]-A[2][8]\n           0\n           >>> A=giac('[ranm(5,5),ranm(5,5)]')\n           >>> A[1,2,3]-A[1][2][3]\n           0\n\n        Crash test:\n\n           >>> l=Pygen()\n           >>> l[0]      # doctest: +SKIP\n           Traceback (most recent call last):\n           ...\n           RuntimeError\n\n        ";
static const char __pyx_k_Open_the_giac_html_detailled_he[] = "\n         Open the giac  html  detailled help about self in an external  browser\n\n         There are currently 3 supported languages: 'en', 'fr', 'el'\n\n          >>> from giacpy import gcd\n          >>> gcd.htmlhelp('fr')           # doctest: +SKIP\n\n         ";
static const char __pyx_k_Pygen_lists_of_10_6_elements_sh[] = "\n         Pygen lists of 10**6 elements should be yield\n\n           >>> from time import time\n           >>> l=giac(range(10**6))\n           >>> t=time();l1=[ i for i in l ];t1=time()-t;'time for a list of 10**6  i ',t1        # doctest: +ELLIPSIS\n           ('time for a list of 10**6  i ', ...)\n           >>> t=time();l1=[ i+i for i in l ];t2=time()-t;'time for a list of 10**6  i+i ',t2    # doctest: +ELLIPSIS\n           ('time for a list of 10**6  i+i ', ...)\n           >>> t=time();l1=[ 1+i for i in l ];t3=time()-t;\"time for a list of 10**6  1+i \",t3    # doctest: +ELLIPSIS\n           ('time for a list of 10**6  1+i ', ...)\n           >>> t=time();l1=[ i+1 for i in l ];t4=time()-t;\"time for a list of 10**6  i+1 \",t4    # doctest: +ELLIPSIS\n           ('time for a list of 10**6  i+1 ', ...)\n\n       ";
static const char __pyx_k_Result_is_too_big_for_Display_I[] = "\nResult is too big for Display. If you really want to see it use print";
static const char __pyx_k_Reverse_operator_7_giac_3_Calle[] = "\n            Reverse operator\n\n                >>> 7%giac(3)   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                1 % 3\n\n         ";
static const char __pyx_k_Reverse_operator_d_giac_d_1_d_C[] = "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 1+d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                1+d\n\n         ";
static const char __pyx_k_Reverse_operator_d_giac_d_2_d_C[] = "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 2-d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                2-d\n\n         ";
static const char __pyx_k_Reverse_operator_d_giac_d_7_d_C[] = "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 7*d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                7*d\n\n         ";
static const char __pyx_k_This_function_evaluate_a_python[] = "\n    This function evaluate a python object with the giac library.\n\n    * It creates in python a Pygen element and evaluate it with giac. For instance to compute a trigonometric expansion of cos(x+2y) where x and y are just formal symbols  we can do:\n\n     >>> from giacpy import giac,pi\n     >>> x,y=giac('x,y')\n     >>> (x+2*y).cos().texpand()\n     cos(x)*(2*cos(y)**2-1)-sin(x)*2*cos(y)*sin(y)\n\n\n   Coercion, Pygen and internal giac variables:\n   --------------------------------------------\n\n   * The most usefull objects will be the Python object of type Pygen. In the following example, we start by defining symbols x,y,z and do some formal computations\n\n    >>> from giacpy import *\n    >>> x,y,z=giac('x,y,z')\n    >>> ((x+2*y/z)*(y+1)**2).diff(y)  # compute the partial derivative with respect to y\n    2/z*(y+1)**2+(x+2*y/z)*2*(y+1)\n\n    In the next example x was previously defined as a symbol so x[i] is just another symbol. So we can use the symbols x[i] to work with polynomial in several variables as we do with theother symbols x,y,z.\n\n    For instance to compute the coefficient of x[0]^12 in (x[0]+x[1]+x[2]+x[3]+x[4])^15/(y+z) we just do the following\n    >>> f=sum([x[i] for i in range(5)])**15/(y+z);f.coeff(x[0],12)\n    (455*(x[1])**3+1365*(x[1])**2*x[2]+1365*(x[1])**2*x[3]+1365*(x[1])**2*x[4]+1365*x[1]*(x[2])**2+2730*x[1]*x[2]*x[3]+2730*x[1]*x[2]*x[4]+1365*x[1]*(x[3])**2+2730*x[1]*x[3]*x[4]+1365*x[1]*(x[4])**2+455*(x[2])**3+1365*(x[2])**2*x[3]+1365*(x[2])**2*x[4]+1365*x[2]*(x[3])**2+2730*x[2]*x[3]*x[4]+1365*x[2]*(x[4])**2+455*(x[3])**3+1365*(x[3])**2*x[4]+1365*x[3]*(x[4])**2+455*(x[4])**3)/(y+z)\n\n      Warning: The complex number sqrt(-1) is exported in python as I. (But it may appears as i)\n\n    >>> ((1+I*sqrt(3))**3).normal(); 1+I\n    -8\n    1+i\n\n   * Python integers and reals can be directly converted to giac.\n\n    >>> a=giac(2**1024);a.nextprime();(giac(1.234567)).erf().approx(10)\n    1797693134862315907729305190789024733617""97697894230657273430081157732675805500963132708477322407536021120113879871393357658789768814416622492847430639474124377767893424865485276302219601246094119453082952085005768838150682342462881473913110540827237163350510684586298239947245938479716304835356329624224137859\n    0.9191788641\n\n\n   * There are some natural coercion to Pygen elements:\n\n    >>> pi>3.14 ; pi >3.15 ; giac(3)==3\n    True\n    False\n    True\n\n   But sometimes you need to prevent Python from doing a computation before the conversion. For example if 1/3 is done in Python2 you will obtain 0 while in Python3 0.33333 so to create: x+1/3:\n   >>> x+'1/3'\n   x+1/3\n   >>> x+giac(1)/3\n   x+1/3\n\n   while to create x/(1+x) or x+x/3 you don't need quotes because at each step one of the two object is a Pygen.\n   >>> x/(1+x)\n   x/(1+x)\n   >>> (x+x/3).factor()\n   4*x/3\n\n\n   * The Python object y defined above is of type Pygen. It is not an internal giac variable. (Most of the time you won't need to use internal giac variables).\n\n    >>> yyyy=2;giac('yyyy:=1');yyyy\n    1\n    2\n\n\n   Linear Algebra:\n   ---------------\n\n   * In Giac/Xcas vectors are just lists and matrices are lists of list.\n\n    >>> x,y=giac('x,y')\n    >>> A=giac([[1,2],[3,4]])  # we create a giac matrix from it lines\n    >>> v=giac([x,y]); v   # a giac vector\n    [x,y]\n    >>> A*v # matrix product with a vector outputs a vector\n    [x+2*y,3*x+4*y]\n    >>> v*v  # dot product\n    x*x+y*y\n\n    Remark that w=giac([[x],[y]]) is a matrix of 1 column and 2 rows. It is not a vector    so w*w doesn't make sense.\n    >>> w=giac([[x],[y]])\n    >>> w.transpose()*w   # this matrix product makes sense and output a 1x1 matrix.\n    matrix[[x*x+y*y]]\n\n   * In Python affectation doesn't create a new matrix. (cf. pointers) see also  the doc of  'giacpy.Pygen.__setitem__'\n\n    >>> B1=A;\n    >>> B1[0,0]=43; B1 # in place affectation changes both B1 and A\n    [[43,2],[3,4]]\n    >>> A\n    [[43,2],[3,4]]\n    >>> A[0""][0]=A[0][0]+1; A  # similar as A[0,0]=A[0,0]+1\n    [[44,2],[3,4]]\n    >>> A.pcar(x)  # compute the characteristic polynomial of A\n    x**2-48*x+170\n    >>> B2=A.copy() # use copy to create another object\n    >>> B2[0,0]=55; B2  # here A is not modified\n    [[55,2],[3,4]]\n    >>> A\n    [[44,2],[3,4]]\n\n\n\n   * Sparse Matrices are avaible via the table function.\n    >>> import giacpy\n    >>> A=giacpy.table(()); A  # create an empty giac table\n    table(\n    )\n    >>> A[2,3]=33; A[0,2]='2/7' # set non zero entries of the sparse matrix\n    >>> A*A  # basic matrix operation are supported with sparse matrices\n    table(\n    (0,3) = 66/7\n    )\n    >>> D=giacpy.diag([22,3,'1/7']); D  # some diagonal matrix\n    [[22,0,0],[0,3,0],[0,0,1/7]]\n    >>> giacpy.table(D)    # to create a sparse matrix from an ordinary one\n    table(\n    (0,0) = 22,\n    (1,1) = 3,\n    (2,2) = 1/7\n    )\n\n\n     But many matrix functions apply only with ordinary matrices so need conversions\n\n    >>> B1=A.matrix(); B1 # convert the sparse matrix to a matrix, but the size is minimal\n    [[0,0,2/7,0],[0,0,0,0],[0,0,0,33]]\n    >>> B2=B1.redim(4,4); B2.pmin(x)  # so we may need to resize B1\n    x**3\n\n\n   Lists of Pygen and Giac lists:\n   ------------------------------\n\n   * Here l1 is a giac list and l2 is a python list of Pygen type objects.\n\n    >>> l1=giac(range(10)); l2=[1/(i**2+1) for i in l1]\n    >>> sum(l2)\n    33054527/16762850\n\n    So l1+l1 is done in giac and means a vector addition. But l2+l2 is done in Python so it is the list concatenation.\n\n    >>> l1+l1\n    [0,2,4,6,8,10,12,14,16,18]\n\n    >>> l2+l2\n    [1, 1/2, 1/5, 1/10, 1/17, 1/26, 1/37, 1/50, 1/65, 1/82, 1, 1/2, 1/5, 1/10, 1/17, 1/26, 1/37, 1/50, 1/65, 1/82]\n\n\n   * Here V is not a Pygen element. We need to push it to giac to use a giac method like dim, or we need to use an imported function.\n\n    >>> V=[ [x[i]**j for i in range(8)] for j in range(8)]\n\n    >>> giac(V).dim()\n    [8"",8]\n\n    >>> dt=det_minor(V).factor(); dt.nops()  # 28 factors\n    28\n\n    >>> sort(list(dt.op()))\n    [x[1]-(x[2]),x[1]-(x[3]),x[1]-(x[4]),x[1]-(x[5]),x[1]-(x[6]),x[1]-(x[7]),x[2]-(x[3]),x[2]-(x[4]),x[2]-(x[5]),x[2]-(x[6]),x[2]-(x[7]),x[3]-(x[4]),x[3]-(x[5]),x[3]-(x[6]),x[3]-(x[7]),x[4]-(x[5]),x[4]-(x[6]),x[4]-(x[7]),x[5]-(x[6]),x[5]-(x[7]),x[6]-(x[7]),x[0]-(x[1]),x[0]-(x[2]),x[0]-(x[3]),x[0]-(x[4]),x[0]-(x[5]),x[0]-(x[6]),x[0]-(x[7])]\n\n\n   * Modular objects with %\n\n    >>> V=ranm(5,6) % 2;\n\n    >>> ker(V).rowdim()+V.rank()\n    6\n\n    >>> a=giac(7)%3;a;a%0;7%3\n    1 % 3\n    1\n    1\n\n   Do not confuse with the  python integers:\n\n    >>> type(7%3)==type(a);type(a)==type(7%3)\n    False\n    False\n\n   Syntaxes with reserved or unknown Python symbols:\n   -------------------------------------------------\n\n   * In general equations needs symbols such as = < > or that have another meaning in Python. So those objects must be quoted.\n\n ::\n\n    >>> from giacpy import *\n\n    >>> x=giac('x')\n\n    >>> (1+2*sin(3*x)).solve(x).simplify()\n    list[-pi/18,7*pi/18]\n\n    >>> solve('sin(3*x)>2*sin(x)',x) # doctest: +SKIP \n    \"Unable to find numeric values solving equation. For trigonometric equations this may be solved using assumptions, e.g. assume(x>-pi && x<pi) Error: Bad Argument Value\"\n\n\n   * You can also add some hypothesis to a giac symbol:\n\n    >>> assume('x>-pi && x<pi')\n    x\n    >>> solve('sin(3*x)>2*sin(x)',x)\n    list[((x>(-5*pi/6)) and (x<(-pi/6))),((x>0) and (x<(pi/6))),((x>(5*pi/6)) and (x<pi))]\n\n   * To remove those hypothesis use the giac function: purge\n\n    >>> purge('x')\n    assume[[],[line[-pi,pi]],[-pi,pi]]\n    >>> solve('x>0')\n    list[x>0]\n\n ::\n\n   * Same problems with the ..\n\n    >>> from giacpy import *\n\n    >>> x=giac('x')\n\n    >>> f=1/(5+cos(4*x));f.int(x)\n    1/2/(2*sqrt(6))*(atan((-sqrt(6)*sin(4*x)+2*sin(4*x))/(sqrt(6)*cos(4*x)+sqrt(6)-2*cos(4*x)+2))+4*x/2)\n    >>> fMax(f,'x=-0..pi').s""implify()\n    pi/4,3*pi/4\n    >>> fMax.help()    # doctest: +SKIP\n    \"Returns the abscissa of the maximum of the expression.\n    Expr,[Var]\n    fMax(-x^2+2*x+1,x)\n    fMin\"\n    >>> sum(1/(1+x**2),'x=0..infinity').simplify()\n    (pi*exp(pi)**2+pi+exp(pi)**2-1)/(2*exp(pi)**2-2)\n\n\n   MEMENTO of usual GIAC functions:\n   ===============================\n\n   * Expand with simplification\n\n         - ``ratnormal``, ``normal``, ``simplify``   (from the fastest to the most sophisticated)\n\n         -  NB: ``expand`` function doesn't regroup nor cancel terms, so it could be slow. (pedagogical purpose only?)\n\n   * Factor/Regroup\n\n         - ``factor``, ``factors``, ``regroup``, ``cfactor``, ``ifactor``\n\n   * Misc\n\n         - ``unapply``, ``op``, ``subst``\n\n   * Polynomials/Fractions\n\n         - ``coeff``,  ``gbasis``, ``greduce``, ``lcoeff``, ``pcoeff``, ``canonical_form``,\n\n         - ``proot``,  ``poly2symb``,  ``symb2poly``, ``posubLMQ``, ``poslbdLMQ``, ``VAS``, ``tcoeff``,  ``valuation``\n\n         - ``gcd``, ``egcd``, ``lcm``, ``quo``, ``rem``, ``quorem``, ``abcuv``, ``chinrem``,\n\n         - ``peval``, ``horner``, ``lagrange``, ``ptayl``, ``spline``,  ``sturm``,  ``sturmab``\n\n         - ``partfrac``, ``cpartfrac``\n\n   * Memory/Variables\n\n         * ``assume``, ``about``, ``purge``, ``ans``\n\n   * Calculus/Exact\n\n         - ``linsolve``,  ``solve``,  ``csolve``,  ``desolve``,  ``seqsolve``, ``reverse_rsolve``, ``matpow``\n\n         - ``limit``, ``series``, ``sum``, ``diff``, ``fMax``, ``fMin``,\n\n         - ``integrate``, ``subst``, ``ibpdv``, ``ibpu``, ``preval``\n\n   * Calculus/Exp, Log, powers\n\n         - ``exp2pow``, ``hyp2exp``, ``expexpand``, ``lin``, ``lncollect``, ``lnexpand``, ``powexpand``, ``pow2exp``\n\n   * Trigo\n\n         - ``trigexpand``, ``tsimplify``, ``tlin``, ``tcollect``,\n\n         - ``halftan``, ``cos2sintan``, ``sin2costan``, ``tan2sincos``, ``tan2cossin2``, ``tan2sincos2``, ``trigcos``, ``trigsin``"", ``trigtan``, ``shift_phase``\n\n         - ``exp2trig``, ``trig2exp``\n\n         - ``atrig2ln``, ``acos2asin``, ``acos2atan``, ``asin2acos``, ``asin2atan``, ``atan2acos``, ``atan2asin``\n\n   * Linear Algebra\n\n         - ``identity``, ``matrix``, ``makemat``, ``syst2mat``, ``matpow``, ``table``,  ``redim``\n\n         - ``det``,  ``det_minor``, ``rank``, ``ker``, ``image``, ``rref``, ``simplex_reduce``,\n\n         - ``egv``, ``egvl``,  ``eigenvalues``, ``pcar``, ``pcar_hessenberg``, ``pmin``,\n\n         - ``jordan``, ``adjoint_matrix``, ``companion``, ``hessenberg``, ``transpose``,\n\n         - ``cholesky``, ``lll``,  ``lu``, ``qr``, ``svd``, ``a2q``, ``gauss``, ``gramschmidt``,\n           ``q2a``, ``isom``, ``mkisom``\n\n\n   * Finite Fieds\n\n         - ``%``, ``% 0``, ``mod``, ``GF``, ``powmod``\n\n\n   * Integers\n\n         - ``gcd``, ``iabcuv``, ``ichinrem``, ``idivis``, ``iegcd``,\n\n         - ``ifactor``, ``ifactors``, ``iquo``, ``iquorem``, ``irem``,\n\n         - ``is_prime, is_pseudoprime``, ``lcm``, ``mod``, ``nextprime``, ``pa2b2``, ``prevprime``,\n           ``smod``, ``euler``, ``fracmod``\n\n   * List\n\n         - ``append``, ``accumulate_head_tail``, ``concat``, ``head``, ``makelist``, ``member``, ``mid``, ``revlist``, ``rotate``, ``shift``, ``size``, ``sizes``, ``sort``, ``suppress``, ``tail``\n\n   * Set\n\n         - ``intersect``, ``minus``, ``union``, ``is_element``, ``is_included``\n\n\n  ";
static const char __pyx_k_Use_this_subclass_of_to_call_yo[] = "\n   Use this subclass of to call your objects with the threadeval method.\n   It is usefull to interupt a computation with control C with many python front ends.\n   This class is used by GiacFunction\n   ";
static const char __pyx_k_giacpy_Interface_to_the_C_libra[] = "\ngiacpy: Interface to the C++ library giac (Computer Algebra System).\n\n\nGiac is a general computer algebra system created by Bernard Parisse. It is used in Xcas.\n\nHomepage http://www-fourier.ujf-grenoble.fr/~parisse/giac.html\n\n\nThe natural way to use giacpy is through the giac function. This function creates a Pygen object and evaluate it with the giac C++ library.\n\nThe initialisation of a Pygen just create an object in the C++ library giac, but the mathematical computation  is not done. This class is mainly usefull for cython users.\n\n\nEXAMPLES::\n\n    >>> from giacpy import giac\n    >>> x,y,z=giac('x,y,z');  # define some basic giac objects\n    >>> f=(x+3*y)/(x+z+1)**2 -(x+z+1)**2/(x+3*y)  # then we can compute\n    >>> f.factor()\n    (3*y-x**2-2*x*z-x-z**2-2*z-1)*(3*y+x**2+2*x*z+3*x+z**2+2*z+1)/((x+z+1)**2*(3*y+x))\n    >>> f.normal()\n    (-x**4-4*x**3*z-4*x**3-6*x**2*z**2-12*x**2*z-5*x**2+6*x*y-4*x*z**3-12*x*z**2-12*x*z-4*x+9*y**2-z**4-4*z**3-6*z**2-4*z-1)/(x**3+3*x**2*y+2*x**2*z+2*x**2+6*x*y*z+6*x*y+x*z**2+2*x*z+x+3*y*z**2+6*y*z+3*y)\n\n. To obtain more hints on giacpy consider the help of the giac function.\n\n    >>> help(giac)             # doctest: +SKIP\n\nGETTING HELP::\n\n#. To obtain some help on a giac keyword use the help() method. To open the more detailled (local) html documentation in an external browser, use:  htmlhelp()\n\n    >>> from giacpy import *\n    >>> gcd.help()              # doctest: +SKIP\n    \"Returns the greatest common divisor of 2 polynomials of several variables or of 2 integers or of 2 rationals.\n    (Intg or Poly),(Intg or Poly)\n    gcd(45,75);gcd(15/7,50/9);gcd(x^2-2*x+1,x^3-1);gcd(t^2-2*t+1,t^2+t-2);gcd((x^2-1)*(y^2-1)*z^2,x^3*y^3*z+(-(y^3))*z+x^3*z-z)\n    lcm,euler,modgcd,ezgcd,psrgcd,heugcd,Gcd\"\n    >>> gcd.htmlhelp('fr')          # doctest: +SKIP\n\n#. You can find full html documentation in several languages (en, fr, el) at:\n\n   http://www-fourier.ujf-grenoble.fr/~parisse/giac/doc/en/cascmd_en/""\n\n   or you can try to open its local copy with the command:\n\n    >>> from giacpy import htmlhelp\n    >>> htmlhelp()        # doctest: +SKIP\n    >>> htmlhelp('fr')    # doctest: +SKIP\n\n#. You can import more giac/xcas keywords to work in a symbolic ring.\n\nEXAMPLES::\n\n    >>> from giacpy import *\n    >>> x=giac('x');f=1/(2+sin(5*x))\n    >>> f.int()\n    2/5/sqrt(3)*(atan((-sqrt(3)*sin(5*x)+cos(5*x)+2*sin(5*x)+1)/(sqrt(3)*cos(5*x)+sqrt(3)-2*cos(5*x)+sin(5*x)+2))+5*x/2)\n    >>> f.series(x,0,3)\n    1/2-5/4*x+25/8*x**2-125/48*x**3+x**4*order_size(x)\n    >>> (sqrt(5)+pi).approx(100)\n    5.377660631089582934871817052010779119637787758986631545245841837718337331924013898042449233720899343\n\n#. Cas Settings. Some convenient settings are obtained from: giacsettings:\n\n    >>> from giacpy import giacsettings\n\n\n#. Graphics 2D Output. If your version of giacpy has built giacpy2qcas, you can send graphics to qcas. For experimental interactive geometry see: help(qcas)\n\nEXAMPLES::\n\n    >>> from giacpy import *\n    >>> C=giac('plot(x*sin(x)),x=-3*pi,3*pi')\n    >>> C.qcas()             # doctest: +SKIP\n    >>> l=[(C.homothety(0,t*0.1)).color(t) for t in range(10)]\n    >>> giac(l).qcas)        # doctest: +SKIP\n    >>> A=randvector(200)\n    >>> (histogram(classes(A,0,10))).qcas()         # doctest: +SKIP\n    >>> C=giac('plot(sin(x)/x),x=-3*pi,3*pi')\n    >>> C.qcas()             # doctest: +SKIP\n    >>> l=[(C.homothety(0,t*0.1)).color(t) for t in range(10)]\n    >>> giac(l).qcas()       # doctest: +SKIP\n\n\n";
static const char __pyx_k_vide_Pygen_giac_version_dpt_eit[] = "\n         >>> vide=Pygen()\n         >>> \"giac version dpt: either NULL or seq[]\", vide    # doctest: +ELLIPSIS\n         ('giac version dpt: either NULL or seq[]', ...)\n\n        ";
static const char __pyx_k_Error_executing_code_in_Giac_COD[] = "Error executing code in Giac\nCODE:\n\t%s\nGiac ERROR:\n\t%s";
static const char __pyx_k_GIACPY_TMP_NAME05026807096929010[] = "GIACPY_TMP_NAME050268070969290100291003";
static const char __pyx_k_GiacMethods_base___reduce_cython[] = "GiacMethods_base.__reduce_cython__";
static const char __pyx_k_GiacMethods_base___setstate_cyth[] = "GiacMethods_base.__setstate_cython__";
static const char __pyx_k_GiacMethods_base_accumulate_head[] = "GiacMethods_base.accumulate_head_tail";
static const char __pyx_k_GiacMethods_base_adjacency_matri[] = "GiacMethods_base.adjacency_matrix";
static const char __pyx_k_GiacMethods_base_all_trig_soluti[] = "GiacMethods_base.all_trig_solutions";
static const char __pyx_k_GiacMethods_base_allpairs_distan[] = "GiacMethods_base.allpairs_distance";
static const char __pyx_k_GiacMethods_base_antiprism_graph[] = "GiacMethods_base.antiprism_graph";
static const char __pyx_k_GiacMethods_base_articulation_po[] = "GiacMethods_base.articulation_points";
static const char __pyx_k_GiacMethods_base_assign_edge_wei[] = "GiacMethods_base.assign_edge_weights";
static const char __pyx_k_GiacMethods_base_auto_correlatio[] = "GiacMethods_base.auto_correlation";
static const char __pyx_k_GiacMethods_base_bartlett_hann_w[] = "GiacMethods_base.bartlett_hann_window";
static const char __pyx_k_GiacMethods_base_berlekamp_masse[] = "GiacMethods_base.berlekamp_massey";
static const char __pyx_k_GiacMethods_base_betweenness_cen[] = "GiacMethods_base.betweenness_centrality";
static const char __pyx_k_GiacMethods_base_biconnected_com[] = "GiacMethods_base.biconnected_components";
static const char __pyx_k_GiacMethods_base_bipartite_match[] = "GiacMethods_base.bipartite_matching";
static const char __pyx_k_GiacMethods_base_bisection_solve[] = "GiacMethods_base.bisection_solver";
static const char __pyx_k_GiacMethods_base_blackman_harris[] = "GiacMethods_base.blackman_harris_window";
static const char __pyx_k_GiacMethods_base_blackman_window[] = "GiacMethods_base.blackman_window";
static const char __pyx_k_GiacMethods_base_box_constraints[] = "GiacMethods_base.box_constraints";
static const char __pyx_k_GiacMethods_base_canonical_label[] = "GiacMethods_base.canonical_labeling";
static const char __pyx_k_GiacMethods_base_cartesian_produ[] = "GiacMethods_base.cartesian_product";
static const char __pyx_k_GiacMethods_base_center2interval[] = "GiacMethods_base.center2interval";
static const char __pyx_k_GiacMethods_base_centered_tetrah[] = "GiacMethods_base.centered_tetrahedron";
static const char __pyx_k_GiacMethods_base_chisquared_icdf[] = "GiacMethods_base.chisquared_icdf";
static const char __pyx_k_GiacMethods_base_chromatic_index[] = "GiacMethods_base.chromatic_index";
static const char __pyx_k_GiacMethods_base_chromatic_numbe[] = "GiacMethods_base.chromatic_number";
static const char __pyx_k_GiacMethods_base_chromatic_polyn[] = "GiacMethods_base.chromatic_polynomial";
static const char __pyx_k_GiacMethods_base_clique_cover_nu[] = "GiacMethods_base.clique_cover_number";
static const char __pyx_k_GiacMethods_base_closeness_centr[] = "GiacMethods_base.closeness_centrality";
static const char __pyx_k_GiacMethods_base_clustering_coef[] = "GiacMethods_base.clustering_coefficient";
static const char __pyx_k_GiacMethods_base_common_perpendi[] = "GiacMethods_base.common_perpendicular";
static const char __pyx_k_GiacMethods_base_complete_binary[] = "GiacMethods_base.complete_binary_tree";
static const char __pyx_k_GiacMethods_base_complete_kary_t[] = "GiacMethods_base.complete_kary_tree";
static const char __pyx_k_GiacMethods_base_complex_variabl[] = "GiacMethods_base.complex_variables";
static const char __pyx_k_GiacMethods_base_conjugate_equat[] = "GiacMethods_base.conjugate_equation";
static const char __pyx_k_GiacMethods_base_conjugate_gradi[] = "GiacMethods_base.conjugate_gradient";
static const char __pyx_k_GiacMethods_base_connected_compo[] = "GiacMethods_base.connected_components";
static const char __pyx_k_GiacMethods_base_contract_subgra[] = "GiacMethods_base.contract_subgraph";
static const char __pyx_k_GiacMethods_base_courbe_parametr[] = "GiacMethods_base.courbe_parametrique";
static const char __pyx_k_GiacMethods_base_covariance_corr[] = "GiacMethods_base.covariance_correlation";
static const char __pyx_k_GiacMethods_base_cross_correlati[] = "GiacMethods_base.cross_correlation";
static const char __pyx_k_GiacMethods_base_cumulated_frequ[] = "GiacMethods_base.cumulated_frequencies";
static const char __pyx_k_GiacMethods_base_dashdotdot_line[] = "GiacMethods_base.dashdotdot_line";
static const char __pyx_k_GiacMethods_base_debut_enregistr[] = "GiacMethods_base.debut_enregistrement";
static const char __pyx_k_GiacMethods_base_degree_centrali[] = "GiacMethods_base.degree_centrality";
static const char __pyx_k_GiacMethods_base_degree_sequence[] = "GiacMethods_base.degree_sequence";
static const char __pyx_k_GiacMethods_base_developper_tran[] = "GiacMethods_base.developper_transcendant";
static const char __pyx_k_GiacMethods_base_discard_edge_at[] = "GiacMethods_base.discard_edge_attribute";
static const char __pyx_k_GiacMethods_base_discard_graph_a[] = "GiacMethods_base.discard_graph_attribute";
static const char __pyx_k_GiacMethods_base_droite_tangente[] = "GiacMethods_base.droite_tangente";
static const char __pyx_k_GiacMethods_base_ecart_type_popu[] = "GiacMethods_base.ecart_type_population";
static const char __pyx_k_GiacMethods_base_edge_connectivi[] = "GiacMethods_base.edge_connectivity";
static const char __pyx_k_GiacMethods_base_equilateral_tri[] = "GiacMethods_base.equilateral_triangle";
static const char __pyx_k_GiacMethods_base_exponential_cdf[] = "GiacMethods_base.exponential_cdf";
static const char __pyx_k_GiacMethods_base_exponential_icd[] = "GiacMethods_base.exponential_icdf";
static const char __pyx_k_GiacMethods_base_exponential_reg[] = "GiacMethods_base.exponential_regression";
static const char __pyx_k_GiacMethods_base_exponentiald_cd[] = "GiacMethods_base.exponentiald_cdf";
static const char __pyx_k_GiacMethods_base_exponentiald_ic[] = "GiacMethods_base.exponentiald_icdf";
static const char __pyx_k_GiacMethods_base_extract_measure[] = "GiacMethods_base.extract_measure";
static const char __pyx_k_GiacMethods_base_facteurs_premie[] = "GiacMethods_base.facteurs_premiers";
static const char __pyx_k_GiacMethods_base_factoriser_enti[] = "GiacMethods_base.factoriser_entier";
static const char __pyx_k_GiacMethods_base_falsepos_solver[] = "GiacMethods_base.falsepos_solver";
static const char __pyx_k_GiacMethods_base_find_vertex_cov[] = "GiacMethods_base.find_vertex_cover";
static const char __pyx_k_GiacMethods_base_flow_polynomial[] = "GiacMethods_base.flow_polynomial";
static const char __pyx_k_GiacMethods_base_fonction_derive[] = "GiacMethods_base.fonction_derivee";
static const char __pyx_k_GiacMethods_base_fundamental_cyc[] = "GiacMethods_base.fundamental_cycle";
static const char __pyx_k_GiacMethods_base_gauss_seidel_li[] = "GiacMethods_base.gauss_seidel_linsolve";
static const char __pyx_k_GiacMethods_base_gaussian_window[] = "GiacMethods_base.gaussian_window";
static const char __pyx_k_GiacMethods_base_gbasis_max_pair[] = "GiacMethods_base.gbasis_max_pairs";
static const char __pyx_k_GiacMethods_base_gbasis_reinject[] = "GiacMethods_base.gbasis_reinject";
static const char __pyx_k_GiacMethods_base_gbasis_simult_p[] = "GiacMethods_base.gbasis_simult_primes";
static const char __pyx_k_GiacMethods_base_get_edge_attrib[] = "GiacMethods_base.get_edge_attribute";
static const char __pyx_k_GiacMethods_base_get_edge_weight[] = "GiacMethods_base.get_edge_weight";
static const char __pyx_k_GiacMethods_base_get_graph_attri[] = "GiacMethods_base.get_graph_attribute";
static const char __pyx_k_GiacMethods_base_get_vertex_attr[] = "GiacMethods_base.get_vertex_attribute";
static const char __pyx_k_GiacMethods_base_graph_automorph[] = "GiacMethods_base.graph_automorphisms";
static const char __pyx_k_GiacMethods_base_graph_complemen[] = "GiacMethods_base.graph_complement";
static const char __pyx_k_GiacMethods_base_greedy_independ[] = "GiacMethods_base.greedy_independent_set";
static const char __pyx_k_GiacMethods_base_halftan_hyp2exp[] = "GiacMethods_base.halftan_hyp2exp";
static const char __pyx_k_GiacMethods_base_hann_poisson_wi[] = "GiacMethods_base.hann_poisson_window";
static const char __pyx_k_GiacMethods_base_harmonic_centra[] = "GiacMethods_base.harmonic_centrality";
static const char __pyx_k_GiacMethods_base_harmonic_conjug[] = "GiacMethods_base.harmonic_conjugate";
static const char __pyx_k_GiacMethods_base_harmonic_divisi[] = "GiacMethods_base.harmonic_division";
static const char __pyx_k_GiacMethods_base_highlight_edges[] = "GiacMethods_base.highlight_edges";
static const char __pyx_k_GiacMethods_base_highlight_subgr[] = "GiacMethods_base.highlight_subgraph";
static const char __pyx_k_GiacMethods_base_highlight_trail[] = "GiacMethods_base.highlight_trail";
static const char __pyx_k_GiacMethods_base_highlight_verte[] = "GiacMethods_base.highlight_vertex";
static const char __pyx_k_GiacMethods_base_hybridsj_solver[] = "GiacMethods_base.hybridsj_solver";
static const char __pyx_k_GiacMethods_base_hypercube_graph[] = "GiacMethods_base.hypercube_graph";
static const char __pyx_k_GiacMethods_base_incidence_matri[] = "GiacMethods_base.incidence_matrix";
static const char __pyx_k_GiacMethods_base_increasing_powe[] = "GiacMethods_base.increasing_power";
static const char __pyx_k_GiacMethods_base_independence_nu[] = "GiacMethods_base.independence_number";
static const char __pyx_k_GiacMethods_base_induced_subgrap[] = "GiacMethods_base.induced_subgraph";
static const char __pyx_k_GiacMethods_base_information_cen[] = "GiacMethods_base.information_centrality";
static const char __pyx_k_GiacMethods_base_interactive_ode[] = "GiacMethods_base.interactive_odeplot";
static const char __pyx_k_GiacMethods_base_interactive_plo[] = "GiacMethods_base.interactive_plotode";
static const char __pyx_k_GiacMethods_base_interval2center[] = "GiacMethods_base.interval2center";
static const char __pyx_k_GiacMethods_base_invisible_point[] = "GiacMethods_base.invisible_point";
static const char __pyx_k_GiacMethods_base_is_arborescence[] = "GiacMethods_base.is_arborescence";
static const char __pyx_k_GiacMethods_base_is_graphic_sequ[] = "GiacMethods_base.is_graphic_sequence";
static const char __pyx_k_GiacMethods_base_is_harmonic_cir[] = "GiacMethods_base.is_harmonic_circle_bundle";
static const char __pyx_k_GiacMethods_base_is_harmonic_lin[] = "GiacMethods_base.is_harmonic_line_bundle";
static const char __pyx_k_GiacMethods_base_is_integer_grap[] = "GiacMethods_base.is_integer_graph";
static const char __pyx_k_GiacMethods_base_is_parallelogra[] = "GiacMethods_base.is_parallelogram";
static const char __pyx_k_GiacMethods_base_is_perpendicula[] = "GiacMethods_base.is_perpendicular";
static const char __pyx_k_GiacMethods_base_is_strongly_con[] = "GiacMethods_base.is_strongly_connected";
static const char __pyx_k_GiacMethods_base_is_strongly_reg[] = "GiacMethods_base.is_strongly_regular";
static const char __pyx_k_GiacMethods_base_is_subgraph_iso[] = "GiacMethods_base.is_subgraph_isomorphic";
static const char __pyx_k_GiacMethods_base_is_triconnected[] = "GiacMethods_base.is_triconnected";
static const char __pyx_k_GiacMethods_base_is_two_edge_con[] = "GiacMethods_base.is_two_edge_connected";
static const char __pyx_k_GiacMethods_base_is_vertex_color[] = "GiacMethods_base.is_vertex_colorable";
static const char __pyx_k_GiacMethods_base_isomorphic_copy[] = "GiacMethods_base.isomorphic_copy";
static const char __pyx_k_GiacMethods_base_isosceles_trian[] = "GiacMethods_base.isosceles_triangle";
static const char __pyx_k_GiacMethods_base_jacobi_equation[] = "GiacMethods_base.jacobi_equation";
static const char __pyx_k_GiacMethods_base_jacobi_linsolve[] = "GiacMethods_base.jacobi_linsolve";
static const char __pyx_k_GiacMethods_base_katz_centrality[] = "GiacMethods_base.katz_centrality";
static const char __pyx_k_GiacMethods_base_laplacian_matri[] = "GiacMethods_base.laplacian_matrix";
static const char __pyx_k_GiacMethods_base_legendre_symbol[] = "GiacMethods_base.legendre_symbol";
static const char __pyx_k_GiacMethods_base_ligne_chapeau_c[] = "GiacMethods_base.ligne_chapeau_carre";
static const char __pyx_k_GiacMethods_base_ligne_chapeau_p[] = "GiacMethods_base.ligne_chapeau_plat";
static const char __pyx_k_GiacMethods_base_ligne_chapeau_r[] = "GiacMethods_base.ligne_chapeau_rond";
static const char __pyx_k_GiacMethods_base_ligne_polygonal[] = "GiacMethods_base.ligne_polygonale";
static const char __pyx_k_GiacMethods_base_ligne_tiret_poi[] = "GiacMethods_base.ligne_tiret_point";
static const char __pyx_k_GiacMethods_base_ligne_trait_ple[] = "GiacMethods_base.ligne_trait_plein";
static const char __pyx_k_GiacMethods_base_linear_interpol[] = "GiacMethods_base.linear_interpolate";
static const char __pyx_k_GiacMethods_base_linear_regressi[] = "GiacMethods_base.linear_regression";
static const char __pyx_k_GiacMethods_base_lineariser_trig[] = "GiacMethods_base.lineariser_trigo";
static const char __pyx_k_GiacMethods_base_list_edge_attri[] = "GiacMethods_base.list_edge_attributes";
static const char __pyx_k_GiacMethods_base_list_graph_attr[] = "GiacMethods_base.list_graph_attributes";
static const char __pyx_k_GiacMethods_base_list_vertex_att[] = "GiacMethods_base.list_vertex_attributes";
static const char __pyx_k_GiacMethods_base_logarithmic_reg[] = "GiacMethods_base.logarithmic_regression";
static const char __pyx_k_GiacMethods_base_logistic_regres[] = "GiacMethods_base.logistic_regression";
static const char __pyx_k_GiacMethods_base_lowest_common_a[] = "GiacMethods_base.lowest_common_ancestor";
static const char __pyx_k_GiacMethods_base_lp_bestlocalbou[] = "GiacMethods_base.lp_bestlocalbound";
static const char __pyx_k_GiacMethods_base_lp_bestprojecti[] = "GiacMethods_base.lp_bestprojection";
static const char __pyx_k_GiacMethods_base_lp_binaryvariab[] = "GiacMethods_base.lp_binaryvariables";
static const char __pyx_k_GiacMethods_base_lp_breadthfirst[] = "GiacMethods_base.lp_breadthfirst";
static const char __pyx_k_GiacMethods_base_lp_firstfractio[] = "GiacMethods_base.lp_firstfractional";
static const char __pyx_k_GiacMethods_base_lp_gaptolerance[] = "GiacMethods_base.lp_gaptolerance";
static const char __pyx_k_GiacMethods_base_lp_integervaria[] = "GiacMethods_base.lp_integervariables";
static const char __pyx_k_GiacMethods_base_lp_interiorpoin[] = "GiacMethods_base.lp_interiorpoint";
static const char __pyx_k_GiacMethods_base_lp_iterationlim[] = "GiacMethods_base.lp_iterationlimit";
static const char __pyx_k_GiacMethods_base_lp_lastfraction[] = "GiacMethods_base.lp_lastfractional";
static const char __pyx_k_GiacMethods_base_lp_mostfraction[] = "GiacMethods_base.lp_mostfractional";
static const char __pyx_k_GiacMethods_base_maximal_indepen[] = "GiacMethods_base.maximal_independent_set";
static const char __pyx_k_GiacMethods_base_maximum_indepen[] = "GiacMethods_base.maximum_independent_set";
static const char __pyx_k_GiacMethods_base_maximum_matchin[] = "GiacMethods_base.maximum_matching";
static const char __pyx_k_GiacMethods_base_minimal_edge_co[] = "GiacMethods_base.minimal_edge_coloring";
static const char __pyx_k_GiacMethods_base_minimal_spannin[] = "GiacMethods_base.minimal_spanning_tree";
static const char __pyx_k_GiacMethods_base_mult_c_conjugat[] = "GiacMethods_base.mult_c_conjugate";
static const char __pyx_k_GiacMethods_base_multiplier_conj[] = "GiacMethods_base.multiplier_conjugue";
static const char __pyx_k_GiacMethods_base_negbinomial_cdf[] = "GiacMethods_base.negbinomial_cdf";
static const char __pyx_k_GiacMethods_base_negbinomial_icd[] = "GiacMethods_base.negbinomial_icdf";
static const char __pyx_k_GiacMethods_base_network_transit[] = "GiacMethods_base.network_transitivity";
static const char __pyx_k_GiacMethods_base_nlp_binaryvaria[] = "GiacMethods_base.nlp_binaryvariables";
static const char __pyx_k_GiacMethods_base_nlp_initialpoin[] = "GiacMethods_base.nlp_initialpoint";
static const char __pyx_k_GiacMethods_base_nlp_integervari[] = "GiacMethods_base.nlp_integervariables";
static const char __pyx_k_GiacMethods_base_nlp_iterationli[] = "GiacMethods_base.nlp_iterationlimit";
static const char __pyx_k_GiacMethods_base_nlp_nonnegative[] = "GiacMethods_base.nlp_nonnegative";
static const char __pyx_k_GiacMethods_base_non_recursive_n[] = "GiacMethods_base.non_recursive_normal";
static const char __pyx_k_GiacMethods_base_number_of_edges[] = "GiacMethods_base.number_of_edges";
static const char __pyx_k_GiacMethods_base_number_of_spann[] = "GiacMethods_base.number_of_spanning_trees";
static const char __pyx_k_GiacMethods_base_number_of_trian[] = "GiacMethods_base.number_of_triangles";
static const char __pyx_k_GiacMethods_base_number_of_verti[] = "GiacMethods_base.number_of_vertices";
static const char __pyx_k_GiacMethods_base_osculating_circ[] = "GiacMethods_base.osculating_circle";
static const char __pyx_k_GiacMethods_base_pcar_hessenberg[] = "GiacMethods_base.pcar_hessenberg";
static const char __pyx_k_GiacMethods_base_permute_vertice[] = "GiacMethods_base.permute_vertices";
static const char __pyx_k_GiacMethods_base_perpen_bisector[] = "GiacMethods_base.perpen_bisector";
static const char __pyx_k_GiacMethods_base_polar_coordinat[] = "GiacMethods_base.polar_coordinates";
static const char __pyx_k_GiacMethods_base_polygone_rempli[] = "GiacMethods_base.polygone_rempli";
static const char __pyx_k_GiacMethods_base_polygonscatterp[] = "GiacMethods_base.polygonscatterplot";
static const char __pyx_k_GiacMethods_base_polynomial_regr[] = "GiacMethods_base.polynomial_regression";
static const char __pyx_k_GiacMethods_base_power_regressio[] = "GiacMethods_base.power_regression";
static const char __pyx_k_GiacMethods_base_randmultinomial[] = "GiacMethods_base.randmultinomial";
static const char __pyx_k_GiacMethods_base_random_bipartit[] = "GiacMethods_base.random_bipartite_graph";
static const char __pyx_k_GiacMethods_base_random_planar_g[] = "GiacMethods_base.random_planar_graph";
static const char __pyx_k_GiacMethods_base_random_sequence[] = "GiacMethods_base.random_sequence_graph";
static const char __pyx_k_GiacMethods_base_random_tourname[] = "GiacMethods_base.random_tournament";
static const char __pyx_k_GiacMethods_base_random_variable[] = "GiacMethods_base.random_variable";
static const char __pyx_k_GiacMethods_base_rassembler_trig[] = "GiacMethods_base.rassembler_trigo";
static const char __pyx_k_GiacMethods_base_rectangle_droit[] = "GiacMethods_base.rectangle_droit";
static const char __pyx_k_GiacMethods_base_rectangle_gauch[] = "GiacMethods_base.rectangle_gauche";
static const char __pyx_k_GiacMethods_base_rectangle_plein[] = "GiacMethods_base.rectangle_plein";
static const char __pyx_k_GiacMethods_base_rectangular_coo[] = "GiacMethods_base.rectangular_coordinates";
static const char __pyx_k_GiacMethods_base_reduced_quadric[] = "GiacMethods_base.reduced_quadric";
static const char __pyx_k_GiacMethods_base_relabel_vertice[] = "GiacMethods_base.relabel_vertices";
static const char __pyx_k_GiacMethods_base_reliability_pol[] = "GiacMethods_base.reliability_polynomial";
static const char __pyx_k_GiacMethods_base_resoudre_dans_C[] = "GiacMethods_base.resoudre_dans_C";
static const char __pyx_k_GiacMethods_base_resoudre_system[] = "GiacMethods_base.resoudre_systeme_lineaire";
static const char __pyx_k_GiacMethods_base_right_rectangle[] = "GiacMethods_base.right_rectangle";
static const char __pyx_k_GiacMethods_base_sans_factoriser[] = "GiacMethods_base.sans_factoriser";
static const char __pyx_k_GiacMethods_base_seidel_spectrum[] = "GiacMethods_base.seidel_spectrum";
static const char __pyx_k_GiacMethods_base_set_channel_dat[] = "GiacMethods_base.set_channel_data";
static const char __pyx_k_GiacMethods_base_set_edge_attrib[] = "GiacMethods_base.set_edge_attribute";
static const char __pyx_k_GiacMethods_base_set_edge_weight[] = "GiacMethods_base.set_edge_weight";
static const char __pyx_k_GiacMethods_base_set_graph_attri[] = "GiacMethods_base.set_graph_attribute";
static const char __pyx_k_GiacMethods_base_set_vertex_attr[] = "GiacMethods_base.set_vertex_attribute";
static const char __pyx_k_GiacMethods_base_set_vertex_posi[] = "GiacMethods_base.set_vertex_positions";
static const char __pyx_k_GiacMethods_base_sierpinski_grap[] = "GiacMethods_base.sierpinski_graph";
static const char __pyx_k_GiacMethods_base_simplicial_vert[] = "GiacMethods_base.simplicial_vertices";
static const char __pyx_k_GiacMethods_base_simulated_annea[] = "GiacMethods_base.simulated_annealing";
static const char __pyx_k_GiacMethods_base_steffenson_solv[] = "GiacMethods_base.steffenson_solver";
static const char __pyx_k_GiacMethods_base_strongly_connec[] = "GiacMethods_base.strongly_connected_components";
static const char __pyx_k_GiacMethods_base_subdivide_edges[] = "GiacMethods_base.subdivide_edges";
static const char __pyx_k_GiacMethods_base_taux_accroissem[] = "GiacMethods_base.taux_accroissement";
static const char __pyx_k_GiacMethods_base_topological_sor[] = "GiacMethods_base.topological_sort";
static const char __pyx_k_GiacMethods_base_torus_grid_grap[] = "GiacMethods_base.torus_grid_graph";
static const char __pyx_k_GiacMethods_base_transitive_clos[] = "GiacMethods_base.transitive_closure";
static const char __pyx_k_GiacMethods_base_traveling_sales[] = "GiacMethods_base.traveling_salesman";
static const char __pyx_k_GiacMethods_base_triangle_window[] = "GiacMethods_base.triangle_window";
static const char __pyx_k_GiacMethods_base_tutte_polynomia[] = "GiacMethods_base.tutte_polynomial";
static const char __pyx_k_GiacMethods_base_two_edge_connec[] = "GiacMethods_base.two_edge_connected_components";
static const char __pyx_k_GiacMethods_base_underlying_grap[] = "GiacMethods_base.underlying_graph";
static const char __pyx_k_GiacMethods_base_variables_are_f[] = "GiacMethods_base.variables_are_files";
static const char __pyx_k_GiacMethods_base_vertex_connecti[] = "GiacMethods_base.vertex_connectivity";
static const char __pyx_k_GiacMethods_base_vertex_cover_nu[] = "GiacMethods_base.vertex_cover_number";
static const char __pyx_k_GiacMethods_base_vertex_distance[] = "GiacMethods_base.vertex_distance";
static const char __pyx_k_GiacMethods_base_vertex_in_degre[] = "GiacMethods_base.vertex_in_degree";
static const char __pyx_k_GiacMethods_base_vertex_out_degr[] = "GiacMethods_base.vertex_out_degree";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())";
static const char __pyx_k_argument_must_be_a_Pygen_list_an[] = "argument must be a Pygen list and a slice";
static const char __pyx_k_argument_must_be_a_tuple_or_a_li[] = "argument must be a tuple or a list";
static const char __pyx_k_cas_monitor_status_after_killing[] = "cas monitor status after killing thread:";
static const char __pyx_k_failed_to_init_doc_from_giac_s_d[] = "failed to init doc from giac's doc";
static const char __pyx_k_gen_indexes_are_not_yet_implemen[] = "gen indexes are not yet implemented";
static const char __pyx_k_http_www_fourier_ujf_grenoble_fr[] = "http://www-fourier.ujf-grenoble.fr/~parisse/giac/";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_purge_GIACPY_TMP_NAME05026807096[] = "purge(GIACPY_TMP_NAME050268070969290100291003):;";
static const char __pyx_k_trying_soft_interruption_wait_2s[] = "trying soft interruption (wait 2s)";
static const char __pyx_k_Open_the_giac_html_detailled_he_2[] = "\n   Open the giac html detailled help in an external  browser\n\n   There are currently 3 supported lanquages: 'en', 'fr', 'el'\n    >>> htmlhelp('fr')         # doctest: +SKIP\n    >>> htmlhelp()             # doctest: +SKIP\n\n   ";
static const char __pyx_k_Reverse_operator_d_giac_d_7_d_C_2[] = "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 7/d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                7/d\n\n         ";
static const char __pyx_k_Reverse_operator_d_giac_d_7_d_C_3[] = "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> (7**d)   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                7**d\n\n         ";
static const char __pyx_k_GIACPY_TMP_NAME05026807096929010_2[] = "GIACPY_TMP_NAME050268070969290100291003[%s]";
static const char __pyx_k_GiacMethods_base_exponential_reg_2[] = "GiacMethods_base.exponential_regression_plot";
static const char __pyx_k_GiacMethods_base_ligne_polygonal_2[] = "GiacMethods_base.ligne_polygonale_pointee";
static const char __pyx_k_GiacMethods_base_ligne_tiret_poi_2[] = "GiacMethods_base.ligne_tiret_pointpoint";
static const char __pyx_k_GiacMethods_base_linear_regressi_2[] = "GiacMethods_base.linear_regression_plot";
static const char __pyx_k_GiacMethods_base_logarithmic_reg_2[] = "GiacMethods_base.logarithmic_regression_plot";
static const char __pyx_k_GiacMethods_base_logistic_regres_2[] = "GiacMethods_base.logistic_regression_plot";
static const char __pyx_k_GiacMethods_base_multiplier_conj_2[] = "GiacMethods_base.multiplier_conjugue_complexe";
static const char __pyx_k_GiacMethods_base_polynomial_regr_2[] = "GiacMethods_base.polynomial_regression_plot";
static const char __pyx_k_GiacMethods_base_power_regressio_2[] = "GiacMethods_base.power_regression_plot";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_6giacpy_6giacpy_decstring23(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_2encstring23(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_4giac(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting___repr__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_6digits___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_6digits_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_8sqrtflag___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_8sqrtflag_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_11complexflag___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_11complexflag_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_10eval_level___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_10eval_level_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_13proba_epsilon___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_7epsilon___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_7epsilon_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_7threads___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_7threads_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_Airy_Ai(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2Airy_Bi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_4Archive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_6BesselJ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_8BesselY(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_10Beta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_12BlockDiagonal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_14Ci(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_16Circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_18Col(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_20CopyVar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_22Dirac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_24Ei(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_26Factor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_28Fourier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_30GF(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_32Gamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_34Heaviside(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_36Heaviside2sign(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_38Hilbert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_40JordanBlock(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_42LU(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_44LambertW(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_46Li(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_48Line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_50LineHorz(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_52LineTan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_54LineVert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_56MSE(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_58Phi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_60Pi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_62Psi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_64QR(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_66RandSeed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_68ReLU(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_70Row(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_72SortA(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_74SortD(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_76UTPC(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_78UTPF(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_80UTPN(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_82UTPT(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_84VARS(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_86VAS(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_88VAS_positive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_90Zeta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_92a2q(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_94abcuv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_96about(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_98abs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_100abscissa(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_102accumulate_head_tail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_104acos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_106acos2asin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_108acos2atan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_110acosh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_112acot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_114acsc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_116acyclic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_118adaptive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_120add(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_122add_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_124add_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_126add_vertex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_128additionally(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_130addtable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_132adjacency_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_134adjoint_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_136affix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_138algsubs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_140algvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_142all_trig_solutions(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_144allpairs_distance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_146alog10(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_148altitude(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_150angle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_152angle_radian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_154angleat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_156angleatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_158ans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_160antiprism_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_162append(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_164apply(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_166approx(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_168arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_170arcLen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_172arccos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_174arccosh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_176arclen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_178arcsin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_180arcsinh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_182arctan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_184arctanh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_186area(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_188areaat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_190areaatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_192areaplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_194arg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_196array(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_198arrivals(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_200articulation_points(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_202asin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_204asin2acos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_206asin2atan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_208asinh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_210assign_edge_weights(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_212assume(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_214at(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_216atan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_218atan2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_220atan2acos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_222atan2asin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_224atanh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_226atrig2ln(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_228augment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_230auto_correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_232autosimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_234avance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_236avgRC(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_238axes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_240axis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_242back(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_244backward(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_246baisse_crayon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_248bandwidth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_250bar_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_252barplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_254bartlett_hann_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_256barycenter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_258base(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_260basis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_262batons(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_264bellman_ford(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_266berlekamp_massey(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_268bernoulli(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_270bernoulli_mod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_272besselJ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_274besselY(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_276betad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_278betad_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_280betad_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_282betavariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_284betweenness_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_286bezier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_288bezout_entiers(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_290bezoutian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_292biconnected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_294binomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_296binomial_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_298binomial_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_300bins(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_302bipartite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_304bipartite_matching(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_306bisection_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_308bisector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_310bit_depth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_312bitand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_314bitor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_316bitxor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_318blackman_harris_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_320blackman_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_322block_size(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_324blockmatrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_326bohman_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_328border(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_330box_constraints(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_332boxcar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_334boxwhisker(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_336brent_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_338brown(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_340bspline(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_342bvpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_344cFactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_346cSolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_348cZeros(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_350camembert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_352canonical_form(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_354canonical_labeling(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_356cartesian_product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_358cauchy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_360cauchy_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_362cauchy_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_364cauchyd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_366cauchyd_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_368cauchyd_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_370cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_372ceil(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_374ceiling(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_376center(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_378center2interval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_380centered_cube(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_382centered_tetrahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_384cfactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_386cfsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_388changebase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_390channel_data(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_392channels(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_394char(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_396charpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_398chinrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_400chisquare(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_402chisquare_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_404chisquare_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_406chisquared(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_408chisquared_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_410chisquared_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_412chisquaret(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_414choice(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_416cholesky(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_418chr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_420chrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_422chromatic_index(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_424chromatic_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_426chromatic_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_428circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_430circumcircle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_432classes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_434clear(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_436clique_cover(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_438clique_cover_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_440clique_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_442closeness_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_444cluster(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_446clustering_coefficient(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_448coeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_450coeffs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_452col(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_454colDim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_456colNorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_458colSwap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_460coldim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_462collect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_464colnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_466color(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_468colormap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_470colspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_472colswap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_474comDenom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_476comb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_478combine(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_480comment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_482common_perpendicular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_484companion(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_486compare(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_488complete_binary_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_490complete_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_492complete_kary_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_494complex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_496complex_variables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_498complexroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_500concat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_502cond(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_504condensation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_506cone(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_508confrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_510conic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_512conj(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_514conjugate_equation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_516conjugate_gradient(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_518connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_520connected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_522cont(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_524contains(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_526content(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_528contourplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_530contract_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_532contract_subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_534convert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_536convertir(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_538convex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_540convexhull(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_542convolution(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_544coordinates(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_546copy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_548correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_550cos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_552cos2sintan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_554cosh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_556cosine_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_558cot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_560cote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_562count(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_564count_eq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_566count_inf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_568count_sup(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_570courbe_parametrique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_572courbe_polaire(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_574covariance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_576covariance_correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_578cpartfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_580crationalroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_582crayon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_584createwav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_586cross(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_588crossP(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_590cross_correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_592cross_entropy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_594cross_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_596cross_ratio(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_598crossproduct(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_600csc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_602csolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_604csv2gen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_606cube(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_608cumSum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_610cumsum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_612cumulated_frequencies(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_614curl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_616current_sheet(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_618curvature(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_620curve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_622cyan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_624cycle2perm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_626cycle_basis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_628cycle_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_630cycleinv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_632cycles2permu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_634cyclotomic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_636cylinder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_638dash_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_640dashdot_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_642dashdotdot_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_644dayofweek(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_646deSolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_648debut_enregistrement(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_650degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_652degree_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_654degree_sequence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_656degrees(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_658delcols(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_660delete_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_662delete_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_664delete_vertex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_666delrows(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_668deltalist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_670denom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_672densityplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_674departures(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_676derive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_678deriver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_680desolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_682dessine_tortue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_684det(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_686det_minor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_688developper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_690developper_transcendant(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_692dfc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_694dfc2f(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_696diag(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_698diff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_700digraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_702dijkstra(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_704dim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_706directed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_708discard_edge_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_710discard_graph_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_712discard_vertex_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_714disjoint_union(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_716display(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_718disque(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_720disque_centre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_722distance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_724distance2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_726distanceat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_728distanceatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_730divergence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_732divide(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_734divis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_736division_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_738divisors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_740divmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_742divpc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_744dnewton_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_746dodecahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_748domain(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_750dot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_752dotP(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_754dot_paper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_756dotprod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_758draw_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_760draw_circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_762draw_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_764draw_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_766draw_pixel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_768draw_polygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_770draw_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_772droit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_774droite_tangente(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_776dsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_778duration(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_780dwt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_782e(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_784e2r(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_786ecart_type(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_788ecart_type_population(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_790ecef2geodetic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_792ecm_factor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_794edge_connectivity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_796edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_798egcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_800egv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_802egvl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_804eigVc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_806eigVl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_808eigenvals(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_810eigenvalues(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_812eigenvectors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_814eigenvects(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_816element(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_818eliminate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_820ellipse(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_822emd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_824entry(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_826envelope(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_828epsilon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_830epsilon2zero(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_832equal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_834equal2diff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_836equal2list(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_838equation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_840equilateral_triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_842erf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_844erfc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_846error(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_848est_permu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_850euler(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_852euler_gamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_854euler_lagrange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_856eval_level(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_858evala(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_860evalb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_862evalc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_864evalf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_866evalm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_868even(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_870evolute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_872exact(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_874exbisector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_876excircle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_878execute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_880exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_882exp2list(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_884exp2pow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_886exp2trig(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_888expand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_890expexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_892expln(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_894exponential(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_896exponential_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_898exponential_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_900exponential_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_902exponential_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_904exponentiald(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_906exponentiald_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_908exponentiald_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_910export_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_912export_mathml(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_914expovariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_916expr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_918extend(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_920extract_measure(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_922extrema(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_924ezgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_926f2nd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_928fMax(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_930fMin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_932fPart(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_934faces(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_936facteurs_premiers(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_938factor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_940factor_xn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_942factorial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_944factoriser(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_946factoriser_entier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_948factoriser_sur_C(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_950factors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_952fadeev(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_954false(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_956falsepos_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_958fclose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_960fcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_962fdistrib(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_964fft(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_966fieldplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_968find(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_970find_cliques(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_972find_cycles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_974find_minimum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_976find_vertex_cover(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_978findhelp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_980fisher(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_982fisher_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_984fisher_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_986fisherd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_988fisherd_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_990fisherd_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_992fitdistr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_994fitpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_996fitspline(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_998flatten(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1000float2rational(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1002floor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1004flow_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1006flower_snark(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1008fmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1010foldl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1012foldr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1014fonction_derivee(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1016forward(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1018fourier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1020fourier_an(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1022fourier_bn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1024fourier_cn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1026fprint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1028frac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1030fracmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1032frame_2d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1034frank_wolfe(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1036frequencies(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1038frobenius_norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1040froot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1042fsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1044fullparfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1046funcplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1048function_diff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1050fundamental_cycle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1052fxnd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1054gammad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1056gammad_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1058gammad_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1060gammavariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1062gauss(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1064gauss15(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1066gauss_seidel_linsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1068gaussian_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1070gaussjord(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1072gaussquad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1074gbasis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1076gbasis_max_pairs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1078gbasis_reinject(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1080gbasis_simult_primes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1082gcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1084gcdex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1086genpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1088geodetic2ecef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1090geometric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1092geometric_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1094geometric_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1096getDenom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1098getKey(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1100getNum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1102getType(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1104get_edge_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1106get_edge_weight(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1108get_graph_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1110get_vertex_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1112girth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1114gl_showaxes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1116gold(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1118goldberg_snark(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1120grad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1122gramschmidt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1124graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1126graph_automorphisms(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1128graph_charpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1130graph_complement(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1132graph_diameter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1134graph_equal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1136graph_join(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1138graph_power(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1140graph_rank(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1142graph_spectrum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1144graph_union(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1146graph_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1148greduce(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1150greedy_clique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1152greedy_color(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1154greedy_independent_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1156grey(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1158grid_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1160groupermu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1162haar_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1164hadamard(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1166half_cone(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1168half_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1170halftan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1172halftan_hyp2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1174halt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1176hamdist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1178hamming(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1180hamming_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1182hann_poisson_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1184hann_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1186harmonic_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1188harmonic_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1190harmonic_division(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1192has(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1194has_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1196has_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1198hasard(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1200head(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1202heading(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1204heapify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1206heappop(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1208heappush(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1210hermite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1212hessenberg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1214hessian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1216heugcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1218hexagon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1220hht(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1222highlight_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1224highlight_subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1226highlight_trail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1228highlight_vertex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1230highpass(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1232hilbert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1234histogram(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1236hold(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1238homogeneize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1240homothety(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1242horner(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1244hsv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1246hsv2rgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1248hybrid_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1250hybridj_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1252hybrids_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1254hybridsj_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1256hyp2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1258hyperbola(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1260hypercube_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1262iPart(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1264iabcuv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1266ibasis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1268ibpdv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1270ibpu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1272icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1274ichinrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1276ichrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1278icomp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1280icontent(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1282icosahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1284id(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1286identify_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1288identity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1290idivis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1292idn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1294idwt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1296iegcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1298ifactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1300ifactors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1302ifourier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1304igamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1306igcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1308igcdex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1310ihermite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1312ilaplace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1314im(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1316imag(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1318image(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1320imfplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1322implicitdiff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1324implicitplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1326import_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1328inString(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1330in_ideal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1332incidence_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1334incident_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1336incircle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1338increasing_power(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1340independence_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1342indets(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1344index(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1346induced_subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1348inequationplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1350inertia(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1352inf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1354infinity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1356information_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1358insert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1360insmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1362instfreq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1364instphase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1366int(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1368intDiv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1370integer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1372integrate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1374integrer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1376inter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1378interactive_odeplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1380interactive_plotode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1382interp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1384interval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1386interval2center(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1388interval_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1390inv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1392inverse(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1394inversion(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1396invisible_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1398invlaplace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1400invztrans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1402iquo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1404iquorem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1406iratrecon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1408irem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1410isPrime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1412is_acyclic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1414is_arborescence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1416is_biconnected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1418is_bipartite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1420is_clique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1422is_collinear(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1424is_concyclic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1426is_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1428is_connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1430is_coplanar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1432is_cospherical(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1434is_cut_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1436is_cycle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1438is_directed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1440is_element(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1442is_equilateral(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1444is_eulerian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1446is_forest(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1448is_graphic_sequence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1450is_hamiltonian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1452is_harmonic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1454is_harmonic_circle_bundle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1456is_harmonic_line_bundle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1458is_inside(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1460is_integer_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1462is_irreducible(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1464is_isomorphic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1466is_isosceles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1468is_network(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1470is_orthogonal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1472is_parallel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1474is_parallelogram(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1476is_permu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1478is_perpendicular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1480is_planar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1482is_prime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1484is_pseudoprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1486is_reachable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1488is_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1490is_regular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1492is_rhombus(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1494is_split_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1496is_square(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1498is_strongly_connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1500is_strongly_regular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1502is_subgraph_isomorphic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1504is_tournament(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1506is_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1508is_triconnected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1510is_two_edge_connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1512is_vertex_colorable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1514is_weighted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1516isinf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1518ismith(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1520isnan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1522isobarycenter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1524isolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1526isom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1528isomorphic_copy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1530isopolygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1532isosceles_triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1534isposdef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1536isprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1538istft(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1540ithprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1542jacobi_equation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1544jacobi_linsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1546jacobi_symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1548johnson_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1550join(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1552jordan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1554katz_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1556kde(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1558keep_pivot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1560ker(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1562kernel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1564kernel_density(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1566kmeans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1568kneser_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1570kolmogorovd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1572kolmogorovt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1574kovacicsols(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1576kspaths(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1578l1norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1580l2norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1582lagrange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1584laguerre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1586laplace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1588laplacian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1590laplacian_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1592latex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1594lcf_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1596lcm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1598lcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1600ldegree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1602ldl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1604learning_rate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1606left(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1608left_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1610legend(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1612legendre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1614legendre_symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1616length(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1618levenshtein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1620lgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1622lhs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1624ligne_chapeau_carre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1626ligne_chapeau_plat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1628ligne_chapeau_rond(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1630ligne_polygonale(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1632ligne_polygonale_pointee(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1634ligne_tiret(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1636ligne_tiret_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1638ligne_tiret_pointpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1640ligne_trait_plein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1642limit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1644limite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1646lin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1648linabs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1650line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1652line_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1654line_inter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1656line_paper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1658line_segments(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1660linear_interpolate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1662linear_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1664linear_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1666lineariser(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1668lineariser_trigo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1670linfnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1672linsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1674linspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1676linstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1678lis_phrase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1680list2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1682list2mat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1684list_edge_attributes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1686list_graph_attributes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1688list_vertex_attributes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1690listplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1692lll(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1694ln(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1696lname(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1698lncollect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1700lnexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1702locus(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1704log(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1706log10(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1708log2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1710log_loss(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1712logarithmic_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1714logarithmic_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1716logb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1718logistic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1720logistic_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1722logistic_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1724lower(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1726lowest_common_ancestor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1728lowpass(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1730lp_assume(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1732lp_bestlocalbound(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1734lp_bestprojection(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1736lp_binary(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1738lp_binaryvariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1740lp_breadthfirst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1742lp_depthfirst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1744lp_depthlimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1746lp_firstfractional(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1748lp_gaptolerance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1750lp_heuristic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1752lp_hybrid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1754lp_integer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1756lp_integervariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1758lp_interiorpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1760lp_iterationlimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1762lp_lastfractional(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1764lp_maxcuts(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1766lp_maximize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1768lp_method(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1770lp_mostfractional(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1772lp_nodelimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1774lp_nodeselect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1776lp_nonnegative(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1778lp_nonnegint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1780lp_presolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1782lp_pseudocost(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1784lp_simplex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1786lp_timelimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1788lp_varselect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1790lp_verbose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1792lpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1794lsmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1796lsq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1798lu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1800lvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1802mRow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1804mRowAdd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1806magenta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1808make_directed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1810make_symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1812make_weighted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1814makelist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1816makemat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1818makesuite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1820makevector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1822map(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1824maple2mupad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1826maple2xcas(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1828maple_ifactors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1830maple_mode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1832markov(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1834mat2list(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1836mathml(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1838matpow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1840matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1842matrix_norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1844max(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1846maxflow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1848maximal_independent_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1850maximize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1852maximum_clique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1854maximum_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1856maximum_independent_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1858maximum_matching(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1860maxnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1862mean(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1864median(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1866median_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1868member(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1870mgf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1872mid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1874middle_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1876midpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1878min(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1880minimal_edge_coloring(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1882minimal_spanning_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1884minimal_vertex_coloring(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1886minimax(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1888minimize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1890minimum_cut(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1892minimum_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1894minimum_vertex_cover(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1896mixdown(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1898mkisom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1900mksa(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1902modf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1904modgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1906mods(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1908momentum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1910monotonic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1912montre_tortue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1914moustache(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1916moving_average(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1918moyal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1920moyenne(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1922mul(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1924mult_c_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1926mult_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1928multinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1930multiplier_conjugue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1932multiplier_conjugue_complexe(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1934multiply(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1936mupad2maple(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1938mupad2xcas(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1940mycielski(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1942nCr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1944nDeriv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1946nInt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1948nPr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1950nSolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1952navy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1954ncols(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1956negbinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1958negbinomial_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1960negbinomial_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1962neighbors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1964network_transitivity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1966neural_network(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1968newList(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1970newMat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1972newton(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1974newton_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1976newtonj_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1978nextperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1980nextprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1982nlp_binary(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1984nlp_binaryvariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1986nlp_initialpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1988nlp_integer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1990nlp_integervariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1992nlp_iterationlimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1994nlp_maximize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1996nlp_method(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1998nlp_nonnegative(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2000nlp_nonnegint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2002nlp_precision(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2004nlp_presolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2006nlp_tolerance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2008nlp_verbose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2010nlpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2012nodisp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2014non_recursive_normal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2016nonnegint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2018nop(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2020nops(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2022norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2024normal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2026normal_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2028normal_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2030normald(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2032normald_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2034normald_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2036normalize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2038normalt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2040normalvariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2042nprimes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2044nrows(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2046nstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2048nuage_points(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2050nullspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2052number_of_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2054number_of_spanning_trees(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2056number_of_triangles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2058number_of_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2060numdiff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2062numer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2064octahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2066odd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2068odd_girth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2070odd_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2072odeplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2074odesolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2076olive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2078op(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2080open_polygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2082orange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2084ord(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2086order(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2088order_size(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2090ordinate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2092orthocenter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2094orthogonal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2096osculating_circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2098p1oc2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2100p1op2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2102pa2b2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2104pade(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2106paley_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2108parabola(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2110parallel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2112parallelepiped(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2114parallelogram(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2116parameq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2118parameter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2120paramplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2122parfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2124pari(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2126part(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2128partfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2130parzen_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2132pas_de_cote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2134path_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2136pcar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2138pcar_hessenberg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2140pcoef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2142pcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2144pencolor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2146pendown(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2148penup(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2150perimeter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2152perimeterat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2154perimeteratraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2156period(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2158periodic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2160perm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2162perminv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2164permu2cycles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2166permu2mat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2168permuorder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2170permute_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2172perpen_bisector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2174perpendicular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2176petersen_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2178peval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2180pi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2182pie(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2184piecewise(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2186pink(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2188pivot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2190pixoff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2192pixon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2194planar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2196plane(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2198plane_dual(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2200playsnd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2202plex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2204plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2206plot3d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2208plotarea(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2210plotcdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2212plotcontour(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2214plotdensity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2216plotfield(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2218plotfunc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2220plotimf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2222plotimplicit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2224plotinequation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2226plotlist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2228plotode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2230plotparam(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2232plotpolar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2234plotproba(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2236plotseq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2238plotspectrum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2240plotwav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2242plus_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2244pmin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2246point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2248point2d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2250point3d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2252poisson(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2254poisson_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2256poisson_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2258poisson_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2260polar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2262polar_coordinates(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2264polar_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2266polarplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2268pole(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2270poly2symb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2272polyEval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2274polygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2276polygone_rempli(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2278polygonplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2280polygonscatterplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2282polyhedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2284polynom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2286polynomial_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2288polynomial_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2290position(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2292poslbdLMQ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2294posubLMQ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2296potential(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2298pow2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2300power_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2302power_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2304powermod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2306powerpc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2308powexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2310powmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2312prepend(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2314preval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2316prevperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2318prevprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2320primpart(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2322printf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2324prism(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2326prism_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2328product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2330projection(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2332proot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2334propFrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2336propfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2338pruefer_code(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2340psrgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2342ptayl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2344purge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2346purple(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2348pwd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2350pyramid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2352python_compat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2354q2a(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2356qr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2358quadric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2360quadrilateral(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2362quantile(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2364quartile1(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2366quartile3(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2368quartiles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2370quest(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2372quo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2374quorem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2376quote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2378r2e(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2380radians(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2382radical_axis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2384radius(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2386ramene(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2388rand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2390randMat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2392randNorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2394randPoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2396randbetad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2398randbinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2400randchisquare(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2402randexp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2404randfisher(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2406randgammad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2408randgeometric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2410randint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2412randmarkov(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2414randmatrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2416randmultinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2418randnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2420random(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2422random_bipartite_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2424random_digraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2426random_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2428random_network(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2430random_planar_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2432random_regular_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2434random_sequence_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2436random_tournament(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2438random_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2440random_variable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2442randperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2444randpoisson(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2446randpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2448randseed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2450randstudent(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2452randvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2454randvector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2456randweibulld(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2458rank(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2460ranm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2462ranv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2464rassembler_trigo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2466rat_jordan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2468ratinterp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2470rational(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2472rationalroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2474ratnormal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2476rdiv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2478re(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2480reachable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2482read(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2484readrgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2486readwav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2488real(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2490realroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2492reciprocation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2494rect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2496rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2498rectangle_droit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2500rectangle_gauche(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2502rectangle_plein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2504rectangular_coordinates(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2506recule(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2508red(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2510reduced_conic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2512reduced_quadric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2514ref(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2516reflection(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2518regroup(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2520relabel_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2522reliability_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2524rem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2526remain(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2528remove(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2530reorder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2532resample(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2534residue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2536resoudre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2538resoudre_dans_C(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2540resoudre_systeme_lineaire(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2542resultant(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2544reverse(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2546reverse_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2548reverse_rsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2550revert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2552revlex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2554revlist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2556rgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2558rgb2hsv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2560rgb2xyz(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2562rhombus(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2564rhombus_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2566rhs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2568riemann_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2570right(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2572right_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2574right_triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2576risch(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2578rm_a_z(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2580rm_all_vars(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2582rmbreakpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2584rmmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2586rms(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2588rmwatch(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2590romberg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2592rombergm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2594rombergt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2596rond(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2598root(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2600rootof(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2602roots(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2604rotate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2606rotation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2608round(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2610row(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2612rowAdd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2614rowDim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2616rowNorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2618rowSwap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2620rowdim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2622rownorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2624rowspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2626rowswap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2628rref(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2630rsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2632rur(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2634rur_certify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2636rur_gbasis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2638same(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2640sample(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2642samplerate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2644sans_factoriser(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2646saute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2648scalarProduct(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2650scalar_product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2652scatterplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2654schur(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2656sec(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2658secant_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2660segment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2662seidel_spectrum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2664seidel_switch(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2666select(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2668semi_augment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2670seq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2672seqplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2674seqsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2676sequence_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2678series(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2680set_channel_data(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2682set_edge_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2684set_edge_weight(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2686set_graph_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2688set_pixel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2690set_screen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2692set_vertex_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2694set_vertex_positions(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2696shift(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2698shift_phase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2700shortest_path(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2702show_pixels(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2704shuffle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2706sierpinski_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2708sign(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2710sign2Heaviside(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2712signature(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2714signe(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2716similarity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2718simp2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2720simplex_reduce(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2722simplicial_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2724simplifier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2726simplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2728simplifyDirac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2730simpson(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2732simulated_annealing(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2734simult(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2736sin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2738sin2costan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2740sinc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2742sincos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2744single_inter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2746sinh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2748sizes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2750slope(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2752slopeat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2754slopeatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2756smith(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2758smod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2760snedecor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2762snedecor_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2764snedecor_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2766snedecord(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2768snedecord_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2770snedecord_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2772solid_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2774solve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2776somme(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2778sommet(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2780sort(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2782sorta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2784sortd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2786sorted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2788sortperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2790soundsec(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2792spanning_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2794sphere(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2796splice(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2798spline(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2800split(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2802spring(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2804sq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2806sqrfree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2808sqrt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2810square(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2812square_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2814srand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2816sst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2818sst_in(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2820st_ordering(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2822star_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2824star_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2826stdDev(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2828stddev(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2830stddevp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2832steffenson_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2834stereo2mono(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2836stft(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2838str(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2840strip(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2842strongly_connected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2844student(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2846student_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2848student_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2850studentd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2852studentt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2854sturm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2856sturmab(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2858sturmseq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2860style(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2862subMat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2864subdivide_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2866subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2868subs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2870subsop(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2872subst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2874substituer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2876subtype(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2878sum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2880sum_riemann(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2882suppress(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2884surd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2886svd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2888swapcol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2890swaprow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2892switch_axes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2894sylvester(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2896symb2poly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2898symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2900symbol_array(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2902syst2mat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2904tCollect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2906tExpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2908table(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2910tablefunc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2912tableseq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2914tabsign(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2916tabvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2918tail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2920tan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2922tan2cossin2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2924tan2sincos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2926tan2sincos2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2928tangent(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2930tangente(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2932tanh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2934tar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2936taux_accroissement(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2938taylor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2940tchebyshev1(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2942tchebyshev2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2944tcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2946tcollect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2948tdeg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2950teal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2952tensor_product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2954tetrahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2956texpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2958thickness(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2960threshold(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2962throw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2964title(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2966titre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2968tlin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2970tonnetz(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2972topologic_sort(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2974topological_sort(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2976topology(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2978torus_grid_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2980total_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2982tourne_droite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2984tourne_gauche(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2986tpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2988trace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2990trail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2992trail2edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2994train(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2996trames(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2998tran(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3000transitive_closure(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3002translation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3004transpose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3006trapeze(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3008trapezoid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3010traveling_salesman(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3012tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3014tree_height(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3016tri(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3018triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3020triangle_paper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3022triangle_plein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3024triangle_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3026triangle_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3028trig2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3030trigcos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3032trigexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3034triginterp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3036trigsimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3038trigsin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3040trigtan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3042trim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3044trn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3046true(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3048trunc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3050truncate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3052truncate_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3054tsimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3056tstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3058tuer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3060tukey_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3062tutte_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3064two_edge_connected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3066ufactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3068ugamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3070unapply(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3072unarchive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3074undef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3076underlying_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3078unfactored(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3080uniform(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3082uniform_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3084uniform_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3086uniformd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3088uniformd_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3090uniformd_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3092unitV(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3094unquote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3096upper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3098user_operator(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3100usimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3102ustep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3104valuation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3106vandermonde(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3108variables_are_files(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3110variance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3112version(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3114vertex_connectivity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3116vertex_cover_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3118vertex_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3120vertex_distance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3122vertex_in_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3124vertex_out_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3126vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3128vertices_abc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3130vertices_abca(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3132violet(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3134vpotential(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3136vstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3138web_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3140weibull(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3142weibull_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3144weibull_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3146weibulld(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3148weibulld_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3150weibulld_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3152weibullvariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3154weight_decay(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3156weight_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3158weighted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3160weights(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3162welch_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3164wheel_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3166widget_size(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3168wilcoxonp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3170wilcoxons(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3172wilcoxont(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3174writergb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3176writewav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3178xcas_mode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3180xml_print(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3182xstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3184xyz2rgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3186xyztrange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3188ystep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3190zeros(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3192znorder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3194znprimroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3196zstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3198ztrans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3200type(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3202zip(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3204__reduce_cython__(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3206__setstate_cython__(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6giacpy_6giacpy_5Pygen___cinit__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_s); /* proto */
static void __pyx_pf_6giacpy_6giacpy_5Pygen_2__dealloc__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_4__repr__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_6__str__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6giacpy_6giacpy_5Pygen_8__len__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_10__getitem__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_i); /* proto */
static int __pyx_pf_6giacpy_6giacpy_5Pygen_12__setitem__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_14__iter__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_17__int__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_19__float__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_21eval(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_23threadeval(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_25__add__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_27__radd__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_29__call__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_31__sub__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_33__rsub__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_35__mul__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_37__rmul__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
#if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_39__div__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
#endif
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_41__truediv__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_43__rtruediv__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_45__pow__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right, CYTHON_UNUSED PyObject *__pyx_v_ignored); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_47__rpow__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right, CYTHON_UNUSED PyObject *__pyx_v_ignored); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_49__mod__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_51__rmod__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_53__neg__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_55__pos__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_57cas_setup(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_59_repr_latex_(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_61_repr_html_(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_63save(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_filename); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_65htmlhelp(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_lang); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_67help(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_69redim(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_71qcas(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_73__richcmp__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_5_type___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_8_subtype___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_4_val___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_7_double___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_75__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_77__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_6htmlhelp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_8qcas(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_13ThreadedPygen___call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_8__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_10__sub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_12__mul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_14__div__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_16__truediv__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_18__pow__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right, CYTHON_UNUSED PyObject *__pyx_v_ignored); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_20__neg__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_22diff(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_24int(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_26plot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_28htmlhelp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lang); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_10moretests(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_12loadgiacgen(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_filename); /* proto */
static PyObject *__pyx_pf_6giacpy_6giacpy_14__pyx_unpickle_GiacMethods_base(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_6giacpy_6giacpy_GiacMethods_base(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6giacpy_6giacpy_Pygen(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6giacpy_6giacpy___pyx_scope_struct____iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PySlice_Type_indices = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_6giacpy_6giacpy_GiacMethods_base;
  PyObject *__pyx_type_6giacpy_6giacpy_Pygen;
  PyObject *__pyx_type_6giacpy_6giacpy_GiacSetting;
  PyObject *__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__;
  #endif
  PyTypeObject *__pyx_ptype_6giacpy_6giacpy_GiacMethods_base;
  PyTypeObject *__pyx_ptype_6giacpy_6giacpy_Pygen;
  PyTypeObject *__pyx_ptype_6giacpy_6giacpy_GiacSetting;
  PyTypeObject *__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__;
  PyObject *__pyx_n_s_A;
  PyObject *__pyx_n_s_ACOSH;
  PyObject *__pyx_n_s_ACOT;
  PyObject *__pyx_n_s_ACSC;
  PyObject *__pyx_n_s_ASEC;
  PyObject *__pyx_n_s_ASIN;
  PyObject *__pyx_n_s_ASINH;
  PyObject *__pyx_n_s_ATAN;
  PyObject *__pyx_n_s_ATANH;
  PyObject *__pyx_n_s_A_2;
  PyObject *__pyx_n_s_Airy_Ai;
  PyObject *__pyx_n_s_Airy_Bi;
  PyObject *__pyx_n_s_Angstrom;
  PyObject *__pyx_n_s_Archive;
  PyObject *__pyx_kp_u_Archive_a_Pygen_element_to_a_fi;
  PyObject *__pyx_n_s_BesselJ;
  PyObject *__pyx_n_s_BesselY;
  PyObject *__pyx_n_s_Beta;
  PyObject *__pyx_n_s_BlockDiagonal;
  PyObject *__pyx_n_s_Bq;
  PyObject *__pyx_n_s_Btu;
  PyObject *__pyx_n_s_COND;
  PyObject *__pyx_n_s_COS;
  PyObject *__pyx_n_s_COSH;
  PyObject *__pyx_n_s_COT;
  PyObject *__pyx_n_s_CSC;
  PyObject *__pyx_n_s_CST;
  PyObject *__pyx_n_s_Celsius2Fahrenheit;
  PyObject *__pyx_n_s_Ci;
  PyObject *__pyx_n_s_Ci_2;
  PyObject *__pyx_n_s_Circle;
  PyObject *__pyx_n_s_ClrDraw;
  PyObject *__pyx_n_s_ClrGraph;
  PyObject *__pyx_n_s_ClrIO;
  PyObject *__pyx_n_s_Col;
  PyObject *__pyx_kp_u_Convert_a_giac_integer_type_Pyg;
  PyObject *__pyx_kp_u_Convert_a_giac_real_to_a_Python;
  PyObject *__pyx_n_s_CopyVar;
  PyObject *__pyx_n_s_CyclePic;
  PyObject *__pyx_n_s_DIGITS;
  PyObject *__pyx_n_s_DOM_COMPLEX;
  PyObject *__pyx_n_s_DOM_FLOAT;
  PyObject *__pyx_n_s_DOM_FUNC;
  PyObject *__pyx_n_s_DOM_IDENT;
  PyObject *__pyx_n_s_DOM_INT;
  PyObject *__pyx_n_s_DOM_LIST;
  PyObject *__pyx_n_s_DOM_RAT;
  PyObject *__pyx_n_s_DOM_STRING;
  PyObject *__pyx_n_s_DOM_SYMBOLIC;
  PyObject *__pyx_n_s_DOM_int;
  PyObject *__pyx_n_s_DelFold;
  PyObject *__pyx_n_s_DelVar;
  PyObject *__pyx_n_s_Det;
  PyObject *__pyx_n_s_Dialog;
  PyObject *__pyx_n_s_Digits;
  PyObject *__pyx_n_s_Dirac;
  PyObject *__pyx_n_s_Disp;
  PyObject *__pyx_n_s_DispG;
  PyObject *__pyx_n_s_DispHome;
  PyObject *__pyx_n_s_DrawFunc;
  PyObject *__pyx_n_s_DrawInv;
  PyObject *__pyx_n_s_DrawParm;
  PyObject *__pyx_n_s_DrawPol;
  PyObject *__pyx_n_s_DrawSlp;
  PyObject *__pyx_n_s_DropDown;
  PyObject *__pyx_n_s_DrwCtour;
  PyObject *__pyx_n_s_ERROR;
  PyObject *__pyx_n_s_EXP;
  PyObject *__pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman;
  PyObject *__pyx_n_s_Ei;
  PyObject *__pyx_n_s_EndDlog;
  PyObject *__pyx_kp_s_Error_executing_code_in_Giac_COD;
  PyObject *__pyx_n_s_F;
  PyObject *__pyx_n_s_FALSE;
  PyObject *__pyx_n_s_F_2;
  PyObject *__pyx_n_s_F_OK;
  PyObject *__pyx_n_s_Factor;
  PyObject *__pyx_n_s_Fahrenheit2Celsius;
  PyObject *__pyx_kp_s_Failed_to_start_a_thread;
  PyObject *__pyx_n_s_False;
  PyObject *__pyx_n_s_Fdy;
  PyObject *__pyx_n_s_Fill;
  PyObject *__pyx_n_s_Fourier;
  PyObject *__pyx_n_s_G;
  PyObject *__pyx_n_s_GF;
  PyObject *__pyx_n_s_GIACNULL;
  PyObject *__pyx_n_s_GIACPY_TMP_NAME05026807096929010;
  PyObject *__pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2;
  PyObject *__pyx_n_s_Gal;
  PyObject *__pyx_n_s_Gamma;
  PyObject *__pyx_n_s_Gcd;
  PyObject *__pyx_n_s_GetFold;
  PyObject *__pyx_n_s_GiacFunction;
  PyObject *__pyx_n_s_GiacFunction___add;
  PyObject *__pyx_n_s_GiacFunction___call;
  PyObject *__pyx_n_s_GiacFunction___div;
  PyObject *__pyx_n_s_GiacFunction___init;
  PyObject *__pyx_n_s_GiacFunction___mul;
  PyObject *__pyx_n_s_GiacFunction___neg;
  PyObject *__pyx_n_s_GiacFunction___pow;
  PyObject *__pyx_n_s_GiacFunction___repr;
  PyObject *__pyx_n_s_GiacFunction___str;
  PyObject *__pyx_n_s_GiacFunction___sub;
  PyObject *__pyx_n_s_GiacFunction___truediv;
  PyObject *__pyx_n_s_GiacFunction_diff;
  PyObject *__pyx_n_s_GiacFunction_htmlhelp;
  PyObject *__pyx_n_s_GiacFunction_int;
  PyObject *__pyx_n_s_GiacFunction_plot;
  PyObject *__pyx_n_s_GiacMethods;
  PyObject *__pyx_n_s_GiacMethods_base;
  PyObject *__pyx_n_s_GiacMethods_base_Airy_Ai;
  PyObject *__pyx_n_s_GiacMethods_base_Airy_Bi;
  PyObject *__pyx_n_s_GiacMethods_base_Archive;
  PyObject *__pyx_n_s_GiacMethods_base_BesselJ;
  PyObject *__pyx_n_s_GiacMethods_base_BesselY;
  PyObject *__pyx_n_s_GiacMethods_base_Beta;
  PyObject *__pyx_n_s_GiacMethods_base_BlockDiagonal;
  PyObject *__pyx_n_s_GiacMethods_base_Ci;
  PyObject *__pyx_n_s_GiacMethods_base_Circle;
  PyObject *__pyx_n_s_GiacMethods_base_Col;
  PyObject *__pyx_n_s_GiacMethods_base_CopyVar;
  PyObject *__pyx_n_s_GiacMethods_base_Dirac;
  PyObject *__pyx_n_s_GiacMethods_base_Ei;
  PyObject *__pyx_n_s_GiacMethods_base_Factor;
  PyObject *__pyx_n_s_GiacMethods_base_Fourier;
  PyObject *__pyx_n_s_GiacMethods_base_GF;
  PyObject *__pyx_n_s_GiacMethods_base_Gamma;
  PyObject *__pyx_n_s_GiacMethods_base_Heaviside;
  PyObject *__pyx_n_s_GiacMethods_base_Heaviside2sign;
  PyObject *__pyx_n_s_GiacMethods_base_Hilbert;
  PyObject *__pyx_n_s_GiacMethods_base_JordanBlock;
  PyObject *__pyx_n_s_GiacMethods_base_LU;
  PyObject *__pyx_n_s_GiacMethods_base_LambertW;
  PyObject *__pyx_n_s_GiacMethods_base_Li;
  PyObject *__pyx_n_s_GiacMethods_base_Line;
  PyObject *__pyx_n_s_GiacMethods_base_LineHorz;
  PyObject *__pyx_n_s_GiacMethods_base_LineTan;
  PyObject *__pyx_n_s_GiacMethods_base_LineVert;
  PyObject *__pyx_n_s_GiacMethods_base_MSE;
  PyObject *__pyx_n_s_GiacMethods_base_Phi;
  PyObject *__pyx_n_s_GiacMethods_base_Pi;
  PyObject *__pyx_n_s_GiacMethods_base_Psi;
  PyObject *__pyx_n_s_GiacMethods_base_QR;
  PyObject *__pyx_n_s_GiacMethods_base_RandSeed;
  PyObject *__pyx_n_s_GiacMethods_base_ReLU;
  PyObject *__pyx_n_s_GiacMethods_base_Row;
  PyObject *__pyx_n_s_GiacMethods_base_SortA;
  PyObject *__pyx_n_s_GiacMethods_base_SortD;
  PyObject *__pyx_n_s_GiacMethods_base_UTPC;
  PyObject *__pyx_n_s_GiacMethods_base_UTPF;
  PyObject *__pyx_n_s_GiacMethods_base_UTPN;
  PyObject *__pyx_n_s_GiacMethods_base_UTPT;
  PyObject *__pyx_n_s_GiacMethods_base_VARS;
  PyObject *__pyx_n_s_GiacMethods_base_VAS;
  PyObject *__pyx_n_s_GiacMethods_base_VAS_positive;
  PyObject *__pyx_n_s_GiacMethods_base_Zeta;
  PyObject *__pyx_n_s_GiacMethods_base___reduce_cython;
  PyObject *__pyx_n_s_GiacMethods_base___setstate_cyth;
  PyObject *__pyx_n_s_GiacMethods_base_a2q;
  PyObject *__pyx_n_s_GiacMethods_base_abcuv;
  PyObject *__pyx_n_s_GiacMethods_base_about;
  PyObject *__pyx_n_s_GiacMethods_base_abs;
  PyObject *__pyx_n_s_GiacMethods_base_abscissa;
  PyObject *__pyx_n_s_GiacMethods_base_accumulate_head;
  PyObject *__pyx_n_s_GiacMethods_base_acos;
  PyObject *__pyx_n_s_GiacMethods_base_acos2asin;
  PyObject *__pyx_n_s_GiacMethods_base_acos2atan;
  PyObject *__pyx_n_s_GiacMethods_base_acosh;
  PyObject *__pyx_n_s_GiacMethods_base_acot;
  PyObject *__pyx_n_s_GiacMethods_base_acsc;
  PyObject *__pyx_n_s_GiacMethods_base_acyclic;
  PyObject *__pyx_n_s_GiacMethods_base_adaptive;
  PyObject *__pyx_n_s_GiacMethods_base_add;
  PyObject *__pyx_n_s_GiacMethods_base_add_arc;
  PyObject *__pyx_n_s_GiacMethods_base_add_edge;
  PyObject *__pyx_n_s_GiacMethods_base_add_vertex;
  PyObject *__pyx_n_s_GiacMethods_base_additionally;
  PyObject *__pyx_n_s_GiacMethods_base_addtable;
  PyObject *__pyx_n_s_GiacMethods_base_adjacency_matri;
  PyObject *__pyx_n_s_GiacMethods_base_adjoint_matrix;
  PyObject *__pyx_n_s_GiacMethods_base_affix;
  PyObject *__pyx_n_s_GiacMethods_base_algsubs;
  PyObject *__pyx_n_s_GiacMethods_base_algvar;
  PyObject *__pyx_n_s_GiacMethods_base_all_trig_soluti;
  PyObject *__pyx_n_s_GiacMethods_base_allpairs_distan;
  PyObject *__pyx_n_s_GiacMethods_base_alog10;
  PyObject *__pyx_n_s_GiacMethods_base_altitude;
  PyObject *__pyx_n_s_GiacMethods_base_angle;
  PyObject *__pyx_n_s_GiacMethods_base_angle_radian;
  PyObject *__pyx_n_s_GiacMethods_base_angleat;
  PyObject *__pyx_n_s_GiacMethods_base_angleatraw;
  PyObject *__pyx_n_s_GiacMethods_base_ans;
  PyObject *__pyx_n_s_GiacMethods_base_antiprism_graph;
  PyObject *__pyx_n_s_GiacMethods_base_append;
  PyObject *__pyx_n_s_GiacMethods_base_apply;
  PyObject *__pyx_n_s_GiacMethods_base_approx;
  PyObject *__pyx_n_s_GiacMethods_base_arc;
  PyObject *__pyx_n_s_GiacMethods_base_arcLen;
  PyObject *__pyx_n_s_GiacMethods_base_arccos;
  PyObject *__pyx_n_s_GiacMethods_base_arccosh;
  PyObject *__pyx_n_s_GiacMethods_base_arclen;
  PyObject *__pyx_n_s_GiacMethods_base_arcsin;
  PyObject *__pyx_n_s_GiacMethods_base_arcsinh;
  PyObject *__pyx_n_s_GiacMethods_base_arctan;
  PyObject *__pyx_n_s_GiacMethods_base_arctanh;
  PyObject *__pyx_n_s_GiacMethods_base_area;
  PyObject *__pyx_n_s_GiacMethods_base_areaat;
  PyObject *__pyx_n_s_GiacMethods_base_areaatraw;
  PyObject *__pyx_n_s_GiacMethods_base_areaplot;
  PyObject *__pyx_n_s_GiacMethods_base_arg;
  PyObject *__pyx_n_s_GiacMethods_base_array;
  PyObject *__pyx_n_s_GiacMethods_base_arrivals;
  PyObject *__pyx_n_s_GiacMethods_base_articulation_po;
  PyObject *__pyx_n_s_GiacMethods_base_asin;
  PyObject *__pyx_n_s_GiacMethods_base_asin2acos;
  PyObject *__pyx_n_s_GiacMethods_base_asin2atan;
  PyObject *__pyx_n_s_GiacMethods_base_asinh;
  PyObject *__pyx_n_s_GiacMethods_base_assign_edge_wei;
  PyObject *__pyx_n_s_GiacMethods_base_assume;
  PyObject *__pyx_n_s_GiacMethods_base_at;
  PyObject *__pyx_n_s_GiacMethods_base_atan;
  PyObject *__pyx_n_s_GiacMethods_base_atan2;
  PyObject *__pyx_n_s_GiacMethods_base_atan2acos;
  PyObject *__pyx_n_s_GiacMethods_base_atan2asin;
  PyObject *__pyx_n_s_GiacMethods_base_atanh;
  PyObject *__pyx_n_s_GiacMethods_base_atrig2ln;
  PyObject *__pyx_n_s_GiacMethods_base_augment;
  PyObject *__pyx_n_s_GiacMethods_base_auto_correlatio;
  PyObject *__pyx_n_s_GiacMethods_base_autosimplify;
  PyObject *__pyx_n_s_GiacMethods_base_avance;
  PyObject *__pyx_n_s_GiacMethods_base_avgRC;
  PyObject *__pyx_n_s_GiacMethods_base_axes;
  PyObject *__pyx_n_s_GiacMethods_base_axis;
  PyObject *__pyx_n_s_GiacMethods_base_back;
  PyObject *__pyx_n_s_GiacMethods_base_backward;
  PyObject *__pyx_n_s_GiacMethods_base_baisse_crayon;
  PyObject *__pyx_n_s_GiacMethods_base_bandwidth;
  PyObject *__pyx_n_s_GiacMethods_base_bar_plot;
  PyObject *__pyx_n_s_GiacMethods_base_barplot;
  PyObject *__pyx_n_s_GiacMethods_base_bartlett_hann_w;
  PyObject *__pyx_n_s_GiacMethods_base_barycenter;
  PyObject *__pyx_n_s_GiacMethods_base_base;
  PyObject *__pyx_n_s_GiacMethods_base_basis;
  PyObject *__pyx_n_s_GiacMethods_base_batons;
  PyObject *__pyx_n_s_GiacMethods_base_bellman_ford;
  PyObject *__pyx_n_s_GiacMethods_base_berlekamp_masse;
  PyObject *__pyx_n_s_GiacMethods_base_bernoulli;
  PyObject *__pyx_n_s_GiacMethods_base_bernoulli_mod;
  PyObject *__pyx_n_s_GiacMethods_base_besselJ;
  PyObject *__pyx_n_s_GiacMethods_base_besselY;
  PyObject *__pyx_n_s_GiacMethods_base_betad;
  PyObject *__pyx_n_s_GiacMethods_base_betad_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_betad_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_betavariate;
  PyObject *__pyx_n_s_GiacMethods_base_betweenness_cen;
  PyObject *__pyx_n_s_GiacMethods_base_bezier;
  PyObject *__pyx_n_s_GiacMethods_base_bezout_entiers;
  PyObject *__pyx_n_s_GiacMethods_base_bezoutian;
  PyObject *__pyx_n_s_GiacMethods_base_biconnected_com;
  PyObject *__pyx_n_s_GiacMethods_base_binomial;
  PyObject *__pyx_n_s_GiacMethods_base_binomial_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_binomial_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_bins;
  PyObject *__pyx_n_s_GiacMethods_base_bipartite;
  PyObject *__pyx_n_s_GiacMethods_base_bipartite_match;
  PyObject *__pyx_n_s_GiacMethods_base_bisection_solve;
  PyObject *__pyx_n_s_GiacMethods_base_bisector;
  PyObject *__pyx_n_s_GiacMethods_base_bit_depth;
  PyObject *__pyx_n_s_GiacMethods_base_bitand;
  PyObject *__pyx_n_s_GiacMethods_base_bitor;
  PyObject *__pyx_n_s_GiacMethods_base_bitxor;
  PyObject *__pyx_n_s_GiacMethods_base_blackman_harris;
  PyObject *__pyx_n_s_GiacMethods_base_blackman_window;
  PyObject *__pyx_n_s_GiacMethods_base_block_size;
  PyObject *__pyx_n_s_GiacMethods_base_blockmatrix;
  PyObject *__pyx_n_s_GiacMethods_base_bohman_window;
  PyObject *__pyx_n_s_GiacMethods_base_border;
  PyObject *__pyx_n_s_GiacMethods_base_box_constraints;
  PyObject *__pyx_n_s_GiacMethods_base_boxcar;
  PyObject *__pyx_n_s_GiacMethods_base_boxwhisker;
  PyObject *__pyx_n_s_GiacMethods_base_brent_solver;
  PyObject *__pyx_n_s_GiacMethods_base_brown;
  PyObject *__pyx_n_s_GiacMethods_base_bspline;
  PyObject *__pyx_n_s_GiacMethods_base_bvpsolve;
  PyObject *__pyx_n_s_GiacMethods_base_cFactor;
  PyObject *__pyx_n_s_GiacMethods_base_cSolve;
  PyObject *__pyx_n_s_GiacMethods_base_cZeros;
  PyObject *__pyx_n_s_GiacMethods_base_camembert;
  PyObject *__pyx_n_s_GiacMethods_base_canonical_form;
  PyObject *__pyx_n_s_GiacMethods_base_canonical_label;
  PyObject *__pyx_n_s_GiacMethods_base_cartesian_produ;
  PyObject *__pyx_n_s_GiacMethods_base_cauchy;
  PyObject *__pyx_n_s_GiacMethods_base_cauchy_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_cauchy_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_cauchyd;
  PyObject *__pyx_n_s_GiacMethods_base_cauchyd_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_cauchyd_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_ceil;
  PyObject *__pyx_n_s_GiacMethods_base_ceiling;
  PyObject *__pyx_n_s_GiacMethods_base_center;
  PyObject *__pyx_n_s_GiacMethods_base_center2interval;
  PyObject *__pyx_n_s_GiacMethods_base_centered_cube;
  PyObject *__pyx_n_s_GiacMethods_base_centered_tetrah;
  PyObject *__pyx_n_s_GiacMethods_base_cfactor;
  PyObject *__pyx_n_s_GiacMethods_base_cfsolve;
  PyObject *__pyx_n_s_GiacMethods_base_changebase;
  PyObject *__pyx_n_s_GiacMethods_base_channel_data;
  PyObject *__pyx_n_s_GiacMethods_base_channels;
  PyObject *__pyx_n_s_GiacMethods_base_char;
  PyObject *__pyx_n_s_GiacMethods_base_charpoly;
  PyObject *__pyx_n_s_GiacMethods_base_chinrem;
  PyObject *__pyx_n_s_GiacMethods_base_chisquare;
  PyObject *__pyx_n_s_GiacMethods_base_chisquare_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_chisquare_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_chisquared;
  PyObject *__pyx_n_s_GiacMethods_base_chisquared_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_chisquared_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_chisquaret;
  PyObject *__pyx_n_s_GiacMethods_base_choice;
  PyObject *__pyx_n_s_GiacMethods_base_cholesky;
  PyObject *__pyx_n_s_GiacMethods_base_chr;
  PyObject *__pyx_n_s_GiacMethods_base_chrem;
  PyObject *__pyx_n_s_GiacMethods_base_chromatic_index;
  PyObject *__pyx_n_s_GiacMethods_base_chromatic_numbe;
  PyObject *__pyx_n_s_GiacMethods_base_chromatic_polyn;
  PyObject *__pyx_n_s_GiacMethods_base_circle;
  PyObject *__pyx_n_s_GiacMethods_base_circumcircle;
  PyObject *__pyx_n_s_GiacMethods_base_classes;
  PyObject *__pyx_n_s_GiacMethods_base_clear;
  PyObject *__pyx_n_s_GiacMethods_base_clique_cover;
  PyObject *__pyx_n_s_GiacMethods_base_clique_cover_nu;
  PyObject *__pyx_n_s_GiacMethods_base_clique_number;
  PyObject *__pyx_n_s_GiacMethods_base_closeness_centr;
  PyObject *__pyx_n_s_GiacMethods_base_cluster;
  PyObject *__pyx_n_s_GiacMethods_base_clustering_coef;
  PyObject *__pyx_n_s_GiacMethods_base_coeff;
  PyObject *__pyx_n_s_GiacMethods_base_coeffs;
  PyObject *__pyx_n_s_GiacMethods_base_col;
  PyObject *__pyx_n_s_GiacMethods_base_colDim;
  PyObject *__pyx_n_s_GiacMethods_base_colNorm;
  PyObject *__pyx_n_s_GiacMethods_base_colSwap;
  PyObject *__pyx_n_s_GiacMethods_base_coldim;
  PyObject *__pyx_n_s_GiacMethods_base_collect;
  PyObject *__pyx_n_s_GiacMethods_base_colnorm;
  PyObject *__pyx_n_s_GiacMethods_base_color;
  PyObject *__pyx_n_s_GiacMethods_base_colormap;
  PyObject *__pyx_n_s_GiacMethods_base_colspace;
  PyObject *__pyx_n_s_GiacMethods_base_colswap;
  PyObject *__pyx_n_s_GiacMethods_base_comDenom;
  PyObject *__pyx_n_s_GiacMethods_base_comb;
  PyObject *__pyx_n_s_GiacMethods_base_combine;
  PyObject *__pyx_n_s_GiacMethods_base_comment;
  PyObject *__pyx_n_s_GiacMethods_base_common_perpendi;
  PyObject *__pyx_n_s_GiacMethods_base_companion;
  PyObject *__pyx_n_s_GiacMethods_base_compare;
  PyObject *__pyx_n_s_GiacMethods_base_complete_binary;
  PyObject *__pyx_n_s_GiacMethods_base_complete_graph;
  PyObject *__pyx_n_s_GiacMethods_base_complete_kary_t;
  PyObject *__pyx_n_s_GiacMethods_base_complex;
  PyObject *__pyx_n_s_GiacMethods_base_complex_variabl;
  PyObject *__pyx_n_s_GiacMethods_base_complexroot;
  PyObject *__pyx_n_s_GiacMethods_base_concat;
  PyObject *__pyx_n_s_GiacMethods_base_cond;
  PyObject *__pyx_n_s_GiacMethods_base_condensation;
  PyObject *__pyx_n_s_GiacMethods_base_cone;
  PyObject *__pyx_n_s_GiacMethods_base_confrac;
  PyObject *__pyx_n_s_GiacMethods_base_conic;
  PyObject *__pyx_n_s_GiacMethods_base_conj;
  PyObject *__pyx_n_s_GiacMethods_base_conjugate_equat;
  PyObject *__pyx_n_s_GiacMethods_base_conjugate_gradi;
  PyObject *__pyx_n_s_GiacMethods_base_connected;
  PyObject *__pyx_n_s_GiacMethods_base_connected_compo;
  PyObject *__pyx_n_s_GiacMethods_base_cont;
  PyObject *__pyx_n_s_GiacMethods_base_contains;
  PyObject *__pyx_n_s_GiacMethods_base_content;
  PyObject *__pyx_n_s_GiacMethods_base_contourplot;
  PyObject *__pyx_n_s_GiacMethods_base_contract_edge;
  PyObject *__pyx_n_s_GiacMethods_base_contract_subgra;
  PyObject *__pyx_n_s_GiacMethods_base_convert;
  PyObject *__pyx_n_s_GiacMethods_base_convertir;
  PyObject *__pyx_n_s_GiacMethods_base_convex;
  PyObject *__pyx_n_s_GiacMethods_base_convexhull;
  PyObject *__pyx_n_s_GiacMethods_base_convolution;
  PyObject *__pyx_n_s_GiacMethods_base_coordinates;
  PyObject *__pyx_n_s_GiacMethods_base_copy;
  PyObject *__pyx_n_s_GiacMethods_base_correlation;
  PyObject *__pyx_n_s_GiacMethods_base_cos;
  PyObject *__pyx_n_s_GiacMethods_base_cos2sintan;
  PyObject *__pyx_n_s_GiacMethods_base_cosh;
  PyObject *__pyx_n_s_GiacMethods_base_cosine_window;
  PyObject *__pyx_n_s_GiacMethods_base_cot;
  PyObject *__pyx_n_s_GiacMethods_base_cote;
  PyObject *__pyx_n_s_GiacMethods_base_count;
  PyObject *__pyx_n_s_GiacMethods_base_count_eq;
  PyObject *__pyx_n_s_GiacMethods_base_count_inf;
  PyObject *__pyx_n_s_GiacMethods_base_count_sup;
  PyObject *__pyx_n_s_GiacMethods_base_courbe_parametr;
  PyObject *__pyx_n_s_GiacMethods_base_courbe_polaire;
  PyObject *__pyx_n_s_GiacMethods_base_covariance;
  PyObject *__pyx_n_s_GiacMethods_base_covariance_corr;
  PyObject *__pyx_n_s_GiacMethods_base_cpartfrac;
  PyObject *__pyx_n_s_GiacMethods_base_crationalroot;
  PyObject *__pyx_n_s_GiacMethods_base_crayon;
  PyObject *__pyx_n_s_GiacMethods_base_createwav;
  PyObject *__pyx_n_s_GiacMethods_base_cross;
  PyObject *__pyx_n_s_GiacMethods_base_crossP;
  PyObject *__pyx_n_s_GiacMethods_base_cross_correlati;
  PyObject *__pyx_n_s_GiacMethods_base_cross_entropy;
  PyObject *__pyx_n_s_GiacMethods_base_cross_point;
  PyObject *__pyx_n_s_GiacMethods_base_cross_ratio;
  PyObject *__pyx_n_s_GiacMethods_base_crossproduct;
  PyObject *__pyx_n_s_GiacMethods_base_csc;
  PyObject *__pyx_n_s_GiacMethods_base_csolve;
  PyObject *__pyx_n_s_GiacMethods_base_csv2gen;
  PyObject *__pyx_n_s_GiacMethods_base_cube;
  PyObject *__pyx_n_s_GiacMethods_base_cumSum;
  PyObject *__pyx_n_s_GiacMethods_base_cumsum;
  PyObject *__pyx_n_s_GiacMethods_base_cumulated_frequ;
  PyObject *__pyx_n_s_GiacMethods_base_curl;
  PyObject *__pyx_n_s_GiacMethods_base_current_sheet;
  PyObject *__pyx_n_s_GiacMethods_base_curvature;
  PyObject *__pyx_n_s_GiacMethods_base_curve;
  PyObject *__pyx_n_s_GiacMethods_base_cyan;
  PyObject *__pyx_n_s_GiacMethods_base_cycle2perm;
  PyObject *__pyx_n_s_GiacMethods_base_cycle_basis;
  PyObject *__pyx_n_s_GiacMethods_base_cycle_graph;
  PyObject *__pyx_n_s_GiacMethods_base_cycleinv;
  PyObject *__pyx_n_s_GiacMethods_base_cycles2permu;
  PyObject *__pyx_n_s_GiacMethods_base_cyclotomic;
  PyObject *__pyx_n_s_GiacMethods_base_cylinder;
  PyObject *__pyx_n_s_GiacMethods_base_dash_line;
  PyObject *__pyx_n_s_GiacMethods_base_dashdot_line;
  PyObject *__pyx_n_s_GiacMethods_base_dashdotdot_line;
  PyObject *__pyx_n_s_GiacMethods_base_dayofweek;
  PyObject *__pyx_n_s_GiacMethods_base_deSolve;
  PyObject *__pyx_n_s_GiacMethods_base_debut_enregistr;
  PyObject *__pyx_n_s_GiacMethods_base_degree;
  PyObject *__pyx_n_s_GiacMethods_base_degree_centrali;
  PyObject *__pyx_n_s_GiacMethods_base_degree_sequence;
  PyObject *__pyx_n_s_GiacMethods_base_degrees;
  PyObject *__pyx_n_s_GiacMethods_base_delcols;
  PyObject *__pyx_n_s_GiacMethods_base_delete_arc;
  PyObject *__pyx_n_s_GiacMethods_base_delete_edge;
  PyObject *__pyx_n_s_GiacMethods_base_delete_vertex;
  PyObject *__pyx_n_s_GiacMethods_base_delrows;
  PyObject *__pyx_n_s_GiacMethods_base_deltalist;
  PyObject *__pyx_n_s_GiacMethods_base_denom;
  PyObject *__pyx_n_s_GiacMethods_base_densityplot;
  PyObject *__pyx_n_s_GiacMethods_base_departures;
  PyObject *__pyx_n_s_GiacMethods_base_derive;
  PyObject *__pyx_n_s_GiacMethods_base_deriver;
  PyObject *__pyx_n_s_GiacMethods_base_desolve;
  PyObject *__pyx_n_s_GiacMethods_base_dessine_tortue;
  PyObject *__pyx_n_s_GiacMethods_base_det;
  PyObject *__pyx_n_s_GiacMethods_base_det_minor;
  PyObject *__pyx_n_s_GiacMethods_base_developper;
  PyObject *__pyx_n_s_GiacMethods_base_developper_tran;
  PyObject *__pyx_n_s_GiacMethods_base_dfc;
  PyObject *__pyx_n_s_GiacMethods_base_dfc2f;
  PyObject *__pyx_n_s_GiacMethods_base_diag;
  PyObject *__pyx_n_s_GiacMethods_base_diff;
  PyObject *__pyx_n_s_GiacMethods_base_digraph;
  PyObject *__pyx_n_s_GiacMethods_base_dijkstra;
  PyObject *__pyx_n_s_GiacMethods_base_dim;
  PyObject *__pyx_n_s_GiacMethods_base_directed;
  PyObject *__pyx_n_s_GiacMethods_base_discard_edge_at;
  PyObject *__pyx_n_s_GiacMethods_base_discard_graph_a;
  PyObject *__pyx_n_s_GiacMethods_base_discard_vertex;
  PyObject *__pyx_n_s_GiacMethods_base_disjoint_union;
  PyObject *__pyx_n_s_GiacMethods_base_display;
  PyObject *__pyx_n_s_GiacMethods_base_disque;
  PyObject *__pyx_n_s_GiacMethods_base_disque_centre;
  PyObject *__pyx_n_s_GiacMethods_base_distance;
  PyObject *__pyx_n_s_GiacMethods_base_distance2;
  PyObject *__pyx_n_s_GiacMethods_base_distanceat;
  PyObject *__pyx_n_s_GiacMethods_base_distanceatraw;
  PyObject *__pyx_n_s_GiacMethods_base_divergence;
  PyObject *__pyx_n_s_GiacMethods_base_divide;
  PyObject *__pyx_n_s_GiacMethods_base_divis;
  PyObject *__pyx_n_s_GiacMethods_base_division_point;
  PyObject *__pyx_n_s_GiacMethods_base_divisors;
  PyObject *__pyx_n_s_GiacMethods_base_divmod;
  PyObject *__pyx_n_s_GiacMethods_base_divpc;
  PyObject *__pyx_n_s_GiacMethods_base_dnewton_solver;
  PyObject *__pyx_n_s_GiacMethods_base_dodecahedron;
  PyObject *__pyx_n_s_GiacMethods_base_domain;
  PyObject *__pyx_n_s_GiacMethods_base_dot;
  PyObject *__pyx_n_s_GiacMethods_base_dotP;
  PyObject *__pyx_n_s_GiacMethods_base_dot_paper;
  PyObject *__pyx_n_s_GiacMethods_base_dotprod;
  PyObject *__pyx_n_s_GiacMethods_base_draw_arc;
  PyObject *__pyx_n_s_GiacMethods_base_draw_circle;
  PyObject *__pyx_n_s_GiacMethods_base_draw_graph;
  PyObject *__pyx_n_s_GiacMethods_base_draw_line;
  PyObject *__pyx_n_s_GiacMethods_base_draw_pixel;
  PyObject *__pyx_n_s_GiacMethods_base_draw_polygon;
  PyObject *__pyx_n_s_GiacMethods_base_draw_rectangle;
  PyObject *__pyx_n_s_GiacMethods_base_droit;
  PyObject *__pyx_n_s_GiacMethods_base_droite_tangente;
  PyObject *__pyx_n_s_GiacMethods_base_dsolve;
  PyObject *__pyx_n_s_GiacMethods_base_duration;
  PyObject *__pyx_n_s_GiacMethods_base_dwt;
  PyObject *__pyx_n_s_GiacMethods_base_e;
  PyObject *__pyx_n_s_GiacMethods_base_e2r;
  PyObject *__pyx_n_s_GiacMethods_base_ecart_type;
  PyObject *__pyx_n_s_GiacMethods_base_ecart_type_popu;
  PyObject *__pyx_n_s_GiacMethods_base_ecef2geodetic;
  PyObject *__pyx_n_s_GiacMethods_base_ecm_factor;
  PyObject *__pyx_n_s_GiacMethods_base_edge_connectivi;
  PyObject *__pyx_n_s_GiacMethods_base_edges;
  PyObject *__pyx_n_s_GiacMethods_base_egcd;
  PyObject *__pyx_n_s_GiacMethods_base_egv;
  PyObject *__pyx_n_s_GiacMethods_base_egvl;
  PyObject *__pyx_n_s_GiacMethods_base_eigVc;
  PyObject *__pyx_n_s_GiacMethods_base_eigVl;
  PyObject *__pyx_n_s_GiacMethods_base_eigenvals;
  PyObject *__pyx_n_s_GiacMethods_base_eigenvalues;
  PyObject *__pyx_n_s_GiacMethods_base_eigenvectors;
  PyObject *__pyx_n_s_GiacMethods_base_eigenvects;
  PyObject *__pyx_n_s_GiacMethods_base_element;
  PyObject *__pyx_n_s_GiacMethods_base_eliminate;
  PyObject *__pyx_n_s_GiacMethods_base_ellipse;
  PyObject *__pyx_n_s_GiacMethods_base_emd;
  PyObject *__pyx_n_s_GiacMethods_base_entry;
  PyObject *__pyx_n_s_GiacMethods_base_envelope;
  PyObject *__pyx_n_s_GiacMethods_base_epsilon;
  PyObject *__pyx_n_s_GiacMethods_base_epsilon2zero;
  PyObject *__pyx_n_s_GiacMethods_base_equal;
  PyObject *__pyx_n_s_GiacMethods_base_equal2diff;
  PyObject *__pyx_n_s_GiacMethods_base_equal2list;
  PyObject *__pyx_n_s_GiacMethods_base_equation;
  PyObject *__pyx_n_s_GiacMethods_base_equilateral_tri;
  PyObject *__pyx_n_s_GiacMethods_base_erf;
  PyObject *__pyx_n_s_GiacMethods_base_erfc;
  PyObject *__pyx_n_s_GiacMethods_base_error;
  PyObject *__pyx_n_s_GiacMethods_base_est_permu;
  PyObject *__pyx_n_s_GiacMethods_base_euler;
  PyObject *__pyx_n_s_GiacMethods_base_euler_gamma;
  PyObject *__pyx_n_s_GiacMethods_base_euler_lagrange;
  PyObject *__pyx_n_s_GiacMethods_base_eval_level;
  PyObject *__pyx_n_s_GiacMethods_base_evala;
  PyObject *__pyx_n_s_GiacMethods_base_evalb;
  PyObject *__pyx_n_s_GiacMethods_base_evalc;
  PyObject *__pyx_n_s_GiacMethods_base_evalf;
  PyObject *__pyx_n_s_GiacMethods_base_evalm;
  PyObject *__pyx_n_s_GiacMethods_base_even;
  PyObject *__pyx_n_s_GiacMethods_base_evolute;
  PyObject *__pyx_n_s_GiacMethods_base_exact;
  PyObject *__pyx_n_s_GiacMethods_base_exbisector;
  PyObject *__pyx_n_s_GiacMethods_base_excircle;
  PyObject *__pyx_n_s_GiacMethods_base_execute;
  PyObject *__pyx_n_s_GiacMethods_base_exp;
  PyObject *__pyx_n_s_GiacMethods_base_exp2list;
  PyObject *__pyx_n_s_GiacMethods_base_exp2pow;
  PyObject *__pyx_n_s_GiacMethods_base_exp2trig;
  PyObject *__pyx_n_s_GiacMethods_base_expand;
  PyObject *__pyx_n_s_GiacMethods_base_expexpand;
  PyObject *__pyx_n_s_GiacMethods_base_expln;
  PyObject *__pyx_n_s_GiacMethods_base_exponential;
  PyObject *__pyx_n_s_GiacMethods_base_exponential_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_exponential_icd;
  PyObject *__pyx_n_s_GiacMethods_base_exponential_reg;
  PyObject *__pyx_n_s_GiacMethods_base_exponential_reg_2;
  PyObject *__pyx_n_s_GiacMethods_base_exponentiald;
  PyObject *__pyx_n_s_GiacMethods_base_exponentiald_cd;
  PyObject *__pyx_n_s_GiacMethods_base_exponentiald_ic;
  PyObject *__pyx_n_s_GiacMethods_base_export_graph;
  PyObject *__pyx_n_s_GiacMethods_base_export_mathml;
  PyObject *__pyx_n_s_GiacMethods_base_expovariate;
  PyObject *__pyx_n_s_GiacMethods_base_expr;
  PyObject *__pyx_n_s_GiacMethods_base_extend;
  PyObject *__pyx_n_s_GiacMethods_base_extract_measure;
  PyObject *__pyx_n_s_GiacMethods_base_extrema;
  PyObject *__pyx_n_s_GiacMethods_base_ezgcd;
  PyObject *__pyx_n_s_GiacMethods_base_f2nd;
  PyObject *__pyx_n_s_GiacMethods_base_fMax;
  PyObject *__pyx_n_s_GiacMethods_base_fMin;
  PyObject *__pyx_n_s_GiacMethods_base_fPart;
  PyObject *__pyx_n_s_GiacMethods_base_faces;
  PyObject *__pyx_n_s_GiacMethods_base_facteurs_premie;
  PyObject *__pyx_n_s_GiacMethods_base_factor;
  PyObject *__pyx_n_s_GiacMethods_base_factor_xn;
  PyObject *__pyx_n_s_GiacMethods_base_factorial;
  PyObject *__pyx_n_s_GiacMethods_base_factoriser;
  PyObject *__pyx_n_s_GiacMethods_base_factoriser_enti;
  PyObject *__pyx_n_s_GiacMethods_base_factoriser_sur;
  PyObject *__pyx_n_s_GiacMethods_base_factors;
  PyObject *__pyx_n_s_GiacMethods_base_fadeev;
  PyObject *__pyx_n_s_GiacMethods_base_false;
  PyObject *__pyx_n_s_GiacMethods_base_falsepos_solver;
  PyObject *__pyx_n_s_GiacMethods_base_fclose;
  PyObject *__pyx_n_s_GiacMethods_base_fcoeff;
  PyObject *__pyx_n_s_GiacMethods_base_fdistrib;
  PyObject *__pyx_n_s_GiacMethods_base_fft;
  PyObject *__pyx_n_s_GiacMethods_base_fieldplot;
  PyObject *__pyx_n_s_GiacMethods_base_find;
  PyObject *__pyx_n_s_GiacMethods_base_find_cliques;
  PyObject *__pyx_n_s_GiacMethods_base_find_cycles;
  PyObject *__pyx_n_s_GiacMethods_base_find_minimum;
  PyObject *__pyx_n_s_GiacMethods_base_find_vertex_cov;
  PyObject *__pyx_n_s_GiacMethods_base_findhelp;
  PyObject *__pyx_n_s_GiacMethods_base_fisher;
  PyObject *__pyx_n_s_GiacMethods_base_fisher_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_fisher_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_fisherd;
  PyObject *__pyx_n_s_GiacMethods_base_fisherd_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_fisherd_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_fitdistr;
  PyObject *__pyx_n_s_GiacMethods_base_fitpoly;
  PyObject *__pyx_n_s_GiacMethods_base_fitspline;
  PyObject *__pyx_n_s_GiacMethods_base_flatten;
  PyObject *__pyx_n_s_GiacMethods_base_float2rational;
  PyObject *__pyx_n_s_GiacMethods_base_floor;
  PyObject *__pyx_n_s_GiacMethods_base_flow_polynomial;
  PyObject *__pyx_n_s_GiacMethods_base_flower_snark;
  PyObject *__pyx_n_s_GiacMethods_base_fmod;
  PyObject *__pyx_n_s_GiacMethods_base_foldl;
  PyObject *__pyx_n_s_GiacMethods_base_foldr;
  PyObject *__pyx_n_s_GiacMethods_base_fonction_derive;
  PyObject *__pyx_n_s_GiacMethods_base_forward;
  PyObject *__pyx_n_s_GiacMethods_base_fourier;
  PyObject *__pyx_n_s_GiacMethods_base_fourier_an;
  PyObject *__pyx_n_s_GiacMethods_base_fourier_bn;
  PyObject *__pyx_n_s_GiacMethods_base_fourier_cn;
  PyObject *__pyx_n_s_GiacMethods_base_fprint;
  PyObject *__pyx_n_s_GiacMethods_base_frac;
  PyObject *__pyx_n_s_GiacMethods_base_fracmod;
  PyObject *__pyx_n_s_GiacMethods_base_frame_2d;
  PyObject *__pyx_n_s_GiacMethods_base_frank_wolfe;
  PyObject *__pyx_n_s_GiacMethods_base_frequencies;
  PyObject *__pyx_n_s_GiacMethods_base_frobenius_norm;
  PyObject *__pyx_n_s_GiacMethods_base_froot;
  PyObject *__pyx_n_s_GiacMethods_base_fsolve;
  PyObject *__pyx_n_s_GiacMethods_base_fullparfrac;
  PyObject *__pyx_n_s_GiacMethods_base_funcplot;
  PyObject *__pyx_n_s_GiacMethods_base_function_diff;
  PyObject *__pyx_n_s_GiacMethods_base_fundamental_cyc;
  PyObject *__pyx_n_s_GiacMethods_base_fxnd;
  PyObject *__pyx_n_s_GiacMethods_base_gammad;
  PyObject *__pyx_n_s_GiacMethods_base_gammad_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_gammad_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_gammavariate;
  PyObject *__pyx_n_s_GiacMethods_base_gauss;
  PyObject *__pyx_n_s_GiacMethods_base_gauss15;
  PyObject *__pyx_n_s_GiacMethods_base_gauss_seidel_li;
  PyObject *__pyx_n_s_GiacMethods_base_gaussian_window;
  PyObject *__pyx_n_s_GiacMethods_base_gaussjord;
  PyObject *__pyx_n_s_GiacMethods_base_gaussquad;
  PyObject *__pyx_n_s_GiacMethods_base_gbasis;
  PyObject *__pyx_n_s_GiacMethods_base_gbasis_max_pair;
  PyObject *__pyx_n_s_GiacMethods_base_gbasis_reinject;
  PyObject *__pyx_n_s_GiacMethods_base_gbasis_simult_p;
  PyObject *__pyx_n_s_GiacMethods_base_gcd;
  PyObject *__pyx_n_s_GiacMethods_base_gcdex;
  PyObject *__pyx_n_s_GiacMethods_base_genpoly;
  PyObject *__pyx_n_s_GiacMethods_base_geodetic2ecef;
  PyObject *__pyx_n_s_GiacMethods_base_geometric;
  PyObject *__pyx_n_s_GiacMethods_base_geometric_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_geometric_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_getDenom;
  PyObject *__pyx_n_s_GiacMethods_base_getKey;
  PyObject *__pyx_n_s_GiacMethods_base_getNum;
  PyObject *__pyx_n_s_GiacMethods_base_getType;
  PyObject *__pyx_n_s_GiacMethods_base_get_edge_attrib;
  PyObject *__pyx_n_s_GiacMethods_base_get_edge_weight;
  PyObject *__pyx_n_s_GiacMethods_base_get_graph_attri;
  PyObject *__pyx_n_s_GiacMethods_base_get_vertex_attr;
  PyObject *__pyx_n_s_GiacMethods_base_girth;
  PyObject *__pyx_n_s_GiacMethods_base_gl_showaxes;
  PyObject *__pyx_n_s_GiacMethods_base_gold;
  PyObject *__pyx_n_s_GiacMethods_base_goldberg_snark;
  PyObject *__pyx_n_s_GiacMethods_base_grad;
  PyObject *__pyx_n_s_GiacMethods_base_gramschmidt;
  PyObject *__pyx_n_s_GiacMethods_base_graph;
  PyObject *__pyx_n_s_GiacMethods_base_graph_automorph;
  PyObject *__pyx_n_s_GiacMethods_base_graph_charpoly;
  PyObject *__pyx_n_s_GiacMethods_base_graph_complemen;
  PyObject *__pyx_n_s_GiacMethods_base_graph_diameter;
  PyObject *__pyx_n_s_GiacMethods_base_graph_equal;
  PyObject *__pyx_n_s_GiacMethods_base_graph_join;
  PyObject *__pyx_n_s_GiacMethods_base_graph_power;
  PyObject *__pyx_n_s_GiacMethods_base_graph_rank;
  PyObject *__pyx_n_s_GiacMethods_base_graph_spectrum;
  PyObject *__pyx_n_s_GiacMethods_base_graph_union;
  PyObject *__pyx_n_s_GiacMethods_base_graph_vertices;
  PyObject *__pyx_n_s_GiacMethods_base_greduce;
  PyObject *__pyx_n_s_GiacMethods_base_greedy_clique;
  PyObject *__pyx_n_s_GiacMethods_base_greedy_color;
  PyObject *__pyx_n_s_GiacMethods_base_greedy_independ;
  PyObject *__pyx_n_s_GiacMethods_base_grey;
  PyObject *__pyx_n_s_GiacMethods_base_grid_graph;
  PyObject *__pyx_n_s_GiacMethods_base_groupermu;
  PyObject *__pyx_n_s_GiacMethods_base_haar_graph;
  PyObject *__pyx_n_s_GiacMethods_base_hadamard;
  PyObject *__pyx_n_s_GiacMethods_base_half_cone;
  PyObject *__pyx_n_s_GiacMethods_base_half_line;
  PyObject *__pyx_n_s_GiacMethods_base_halftan;
  PyObject *__pyx_n_s_GiacMethods_base_halftan_hyp2exp;
  PyObject *__pyx_n_s_GiacMethods_base_halt;
  PyObject *__pyx_n_s_GiacMethods_base_hamdist;
  PyObject *__pyx_n_s_GiacMethods_base_hamming;
  PyObject *__pyx_n_s_GiacMethods_base_hamming_window;
  PyObject *__pyx_n_s_GiacMethods_base_hann_poisson_wi;
  PyObject *__pyx_n_s_GiacMethods_base_hann_window;
  PyObject *__pyx_n_s_GiacMethods_base_harmonic_centra;
  PyObject *__pyx_n_s_GiacMethods_base_harmonic_conjug;
  PyObject *__pyx_n_s_GiacMethods_base_harmonic_divisi;
  PyObject *__pyx_n_s_GiacMethods_base_has;
  PyObject *__pyx_n_s_GiacMethods_base_has_arc;
  PyObject *__pyx_n_s_GiacMethods_base_has_edge;
  PyObject *__pyx_n_s_GiacMethods_base_hasard;
  PyObject *__pyx_n_s_GiacMethods_base_head;
  PyObject *__pyx_n_s_GiacMethods_base_heading;
  PyObject *__pyx_n_s_GiacMethods_base_heapify;
  PyObject *__pyx_n_s_GiacMethods_base_heappop;
  PyObject *__pyx_n_s_GiacMethods_base_heappush;
  PyObject *__pyx_n_s_GiacMethods_base_hermite;
  PyObject *__pyx_n_s_GiacMethods_base_hessenberg;
  PyObject *__pyx_n_s_GiacMethods_base_hessian;
  PyObject *__pyx_n_s_GiacMethods_base_heugcd;
  PyObject *__pyx_n_s_GiacMethods_base_hexagon;
  PyObject *__pyx_n_s_GiacMethods_base_hht;
  PyObject *__pyx_n_s_GiacMethods_base_highlight_edges;
  PyObject *__pyx_n_s_GiacMethods_base_highlight_subgr;
  PyObject *__pyx_n_s_GiacMethods_base_highlight_trail;
  PyObject *__pyx_n_s_GiacMethods_base_highlight_verte;
  PyObject *__pyx_n_s_GiacMethods_base_highpass;
  PyObject *__pyx_n_s_GiacMethods_base_hilbert;
  PyObject *__pyx_n_s_GiacMethods_base_histogram;
  PyObject *__pyx_n_s_GiacMethods_base_hold;
  PyObject *__pyx_n_s_GiacMethods_base_homogeneize;
  PyObject *__pyx_n_s_GiacMethods_base_homothety;
  PyObject *__pyx_n_s_GiacMethods_base_horner;
  PyObject *__pyx_n_s_GiacMethods_base_hsv;
  PyObject *__pyx_n_s_GiacMethods_base_hsv2rgb;
  PyObject *__pyx_n_s_GiacMethods_base_hybrid_solver;
  PyObject *__pyx_n_s_GiacMethods_base_hybridj_solver;
  PyObject *__pyx_n_s_GiacMethods_base_hybrids_solver;
  PyObject *__pyx_n_s_GiacMethods_base_hybridsj_solver;
  PyObject *__pyx_n_s_GiacMethods_base_hyp2exp;
  PyObject *__pyx_n_s_GiacMethods_base_hyperbola;
  PyObject *__pyx_n_s_GiacMethods_base_hypercube_graph;
  PyObject *__pyx_n_s_GiacMethods_base_iPart;
  PyObject *__pyx_n_s_GiacMethods_base_iabcuv;
  PyObject *__pyx_n_s_GiacMethods_base_ibasis;
  PyObject *__pyx_n_s_GiacMethods_base_ibpdv;
  PyObject *__pyx_n_s_GiacMethods_base_ibpu;
  PyObject *__pyx_n_s_GiacMethods_base_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_ichinrem;
  PyObject *__pyx_n_s_GiacMethods_base_ichrem;
  PyObject *__pyx_n_s_GiacMethods_base_icomp;
  PyObject *__pyx_n_s_GiacMethods_base_icontent;
  PyObject *__pyx_n_s_GiacMethods_base_icosahedron;
  PyObject *__pyx_n_s_GiacMethods_base_id;
  PyObject *__pyx_n_s_GiacMethods_base_identify_graph;
  PyObject *__pyx_n_s_GiacMethods_base_identity;
  PyObject *__pyx_n_s_GiacMethods_base_idivis;
  PyObject *__pyx_n_s_GiacMethods_base_idn;
  PyObject *__pyx_n_s_GiacMethods_base_idwt;
  PyObject *__pyx_n_s_GiacMethods_base_iegcd;
  PyObject *__pyx_n_s_GiacMethods_base_ifactor;
  PyObject *__pyx_n_s_GiacMethods_base_ifactors;
  PyObject *__pyx_n_s_GiacMethods_base_ifourier;
  PyObject *__pyx_n_s_GiacMethods_base_igamma;
  PyObject *__pyx_n_s_GiacMethods_base_igcd;
  PyObject *__pyx_n_s_GiacMethods_base_igcdex;
  PyObject *__pyx_n_s_GiacMethods_base_ihermite;
  PyObject *__pyx_n_s_GiacMethods_base_ilaplace;
  PyObject *__pyx_n_s_GiacMethods_base_im;
  PyObject *__pyx_n_s_GiacMethods_base_imag;
  PyObject *__pyx_n_s_GiacMethods_base_image;
  PyObject *__pyx_n_s_GiacMethods_base_imfplot;
  PyObject *__pyx_n_s_GiacMethods_base_implicitdiff;
  PyObject *__pyx_n_s_GiacMethods_base_implicitplot;
  PyObject *__pyx_n_s_GiacMethods_base_import_graph;
  PyObject *__pyx_n_s_GiacMethods_base_inString;
  PyObject *__pyx_n_s_GiacMethods_base_in_ideal;
  PyObject *__pyx_n_s_GiacMethods_base_incidence_matri;
  PyObject *__pyx_n_s_GiacMethods_base_incident_edges;
  PyObject *__pyx_n_s_GiacMethods_base_incircle;
  PyObject *__pyx_n_s_GiacMethods_base_increasing_powe;
  PyObject *__pyx_n_s_GiacMethods_base_independence_nu;
  PyObject *__pyx_n_s_GiacMethods_base_indets;
  PyObject *__pyx_n_s_GiacMethods_base_index;
  PyObject *__pyx_n_s_GiacMethods_base_induced_subgrap;
  PyObject *__pyx_n_s_GiacMethods_base_inequationplot;
  PyObject *__pyx_n_s_GiacMethods_base_inertia;
  PyObject *__pyx_n_s_GiacMethods_base_inf;
  PyObject *__pyx_n_s_GiacMethods_base_infinity;
  PyObject *__pyx_n_s_GiacMethods_base_information_cen;
  PyObject *__pyx_n_s_GiacMethods_base_insert;
  PyObject *__pyx_n_s_GiacMethods_base_insmod;
  PyObject *__pyx_n_s_GiacMethods_base_instfreq;
  PyObject *__pyx_n_s_GiacMethods_base_instphase;
  PyObject *__pyx_n_s_GiacMethods_base_int;
  PyObject *__pyx_n_s_GiacMethods_base_intDiv;
  PyObject *__pyx_n_s_GiacMethods_base_integer;
  PyObject *__pyx_n_s_GiacMethods_base_integrate;
  PyObject *__pyx_n_s_GiacMethods_base_integrer;
  PyObject *__pyx_n_s_GiacMethods_base_inter;
  PyObject *__pyx_n_s_GiacMethods_base_interactive_ode;
  PyObject *__pyx_n_s_GiacMethods_base_interactive_plo;
  PyObject *__pyx_n_s_GiacMethods_base_interp;
  PyObject *__pyx_n_s_GiacMethods_base_interval;
  PyObject *__pyx_n_s_GiacMethods_base_interval2center;
  PyObject *__pyx_n_s_GiacMethods_base_interval_graph;
  PyObject *__pyx_n_s_GiacMethods_base_inv;
  PyObject *__pyx_n_s_GiacMethods_base_inverse;
  PyObject *__pyx_n_s_GiacMethods_base_inversion;
  PyObject *__pyx_n_s_GiacMethods_base_invisible_point;
  PyObject *__pyx_n_s_GiacMethods_base_invlaplace;
  PyObject *__pyx_n_s_GiacMethods_base_invztrans;
  PyObject *__pyx_n_s_GiacMethods_base_iquo;
  PyObject *__pyx_n_s_GiacMethods_base_iquorem;
  PyObject *__pyx_n_s_GiacMethods_base_iratrecon;
  PyObject *__pyx_n_s_GiacMethods_base_irem;
  PyObject *__pyx_n_s_GiacMethods_base_isPrime;
  PyObject *__pyx_n_s_GiacMethods_base_is_acyclic;
  PyObject *__pyx_n_s_GiacMethods_base_is_arborescence;
  PyObject *__pyx_n_s_GiacMethods_base_is_biconnected;
  PyObject *__pyx_n_s_GiacMethods_base_is_bipartite;
  PyObject *__pyx_n_s_GiacMethods_base_is_clique;
  PyObject *__pyx_n_s_GiacMethods_base_is_collinear;
  PyObject *__pyx_n_s_GiacMethods_base_is_concyclic;
  PyObject *__pyx_n_s_GiacMethods_base_is_conjugate;
  PyObject *__pyx_n_s_GiacMethods_base_is_connected;
  PyObject *__pyx_n_s_GiacMethods_base_is_coplanar;
  PyObject *__pyx_n_s_GiacMethods_base_is_cospherical;
  PyObject *__pyx_n_s_GiacMethods_base_is_cut_set;
  PyObject *__pyx_n_s_GiacMethods_base_is_cycle;
  PyObject *__pyx_n_s_GiacMethods_base_is_directed;
  PyObject *__pyx_n_s_GiacMethods_base_is_element;
  PyObject *__pyx_n_s_GiacMethods_base_is_equilateral;
  PyObject *__pyx_n_s_GiacMethods_base_is_eulerian;
  PyObject *__pyx_n_s_GiacMethods_base_is_forest;
  PyObject *__pyx_n_s_GiacMethods_base_is_graphic_sequ;
  PyObject *__pyx_n_s_GiacMethods_base_is_hamiltonian;
  PyObject *__pyx_n_s_GiacMethods_base_is_harmonic;
  PyObject *__pyx_n_s_GiacMethods_base_is_harmonic_cir;
  PyObject *__pyx_n_s_GiacMethods_base_is_harmonic_lin;
  PyObject *__pyx_n_s_GiacMethods_base_is_inside;
  PyObject *__pyx_n_s_GiacMethods_base_is_integer_grap;
  PyObject *__pyx_n_s_GiacMethods_base_is_irreducible;
  PyObject *__pyx_n_s_GiacMethods_base_is_isomorphic;
  PyObject *__pyx_n_s_GiacMethods_base_is_isosceles;
  PyObject *__pyx_n_s_GiacMethods_base_is_network;
  PyObject *__pyx_n_s_GiacMethods_base_is_orthogonal;
  PyObject *__pyx_n_s_GiacMethods_base_is_parallel;
  PyObject *__pyx_n_s_GiacMethods_base_is_parallelogra;
  PyObject *__pyx_n_s_GiacMethods_base_is_permu;
  PyObject *__pyx_n_s_GiacMethods_base_is_perpendicula;
  PyObject *__pyx_n_s_GiacMethods_base_is_planar;
  PyObject *__pyx_n_s_GiacMethods_base_is_prime;
  PyObject *__pyx_n_s_GiacMethods_base_is_pseudoprime;
  PyObject *__pyx_n_s_GiacMethods_base_is_reachable;
  PyObject *__pyx_n_s_GiacMethods_base_is_rectangle;
  PyObject *__pyx_n_s_GiacMethods_base_is_regular;
  PyObject *__pyx_n_s_GiacMethods_base_is_rhombus;
  PyObject *__pyx_n_s_GiacMethods_base_is_split_graph;
  PyObject *__pyx_n_s_GiacMethods_base_is_square;
  PyObject *__pyx_n_s_GiacMethods_base_is_strongly_con;
  PyObject *__pyx_n_s_GiacMethods_base_is_strongly_reg;
  PyObject *__pyx_n_s_GiacMethods_base_is_subgraph_iso;
  PyObject *__pyx_n_s_GiacMethods_base_is_tournament;
  PyObject *__pyx_n_s_GiacMethods_base_is_tree;
  PyObject *__pyx_n_s_GiacMethods_base_is_triconnected;
  PyObject *__pyx_n_s_GiacMethods_base_is_two_edge_con;
  PyObject *__pyx_n_s_GiacMethods_base_is_vertex_color;
  PyObject *__pyx_n_s_GiacMethods_base_is_weighted;
  PyObject *__pyx_n_s_GiacMethods_base_isinf;
  PyObject *__pyx_n_s_GiacMethods_base_ismith;
  PyObject *__pyx_n_s_GiacMethods_base_isnan;
  PyObject *__pyx_n_s_GiacMethods_base_isobarycenter;
  PyObject *__pyx_n_s_GiacMethods_base_isolve;
  PyObject *__pyx_n_s_GiacMethods_base_isom;
  PyObject *__pyx_n_s_GiacMethods_base_isomorphic_copy;
  PyObject *__pyx_n_s_GiacMethods_base_isopolygon;
  PyObject *__pyx_n_s_GiacMethods_base_isosceles_trian;
  PyObject *__pyx_n_s_GiacMethods_base_isposdef;
  PyObject *__pyx_n_s_GiacMethods_base_isprime;
  PyObject *__pyx_n_s_GiacMethods_base_istft;
  PyObject *__pyx_n_s_GiacMethods_base_ithprime;
  PyObject *__pyx_n_s_GiacMethods_base_jacobi_equation;
  PyObject *__pyx_n_s_GiacMethods_base_jacobi_linsolve;
  PyObject *__pyx_n_s_GiacMethods_base_jacobi_symbol;
  PyObject *__pyx_n_s_GiacMethods_base_johnson_graph;
  PyObject *__pyx_n_s_GiacMethods_base_join;
  PyObject *__pyx_n_s_GiacMethods_base_jordan;
  PyObject *__pyx_n_s_GiacMethods_base_katz_centrality;
  PyObject *__pyx_n_s_GiacMethods_base_kde;
  PyObject *__pyx_n_s_GiacMethods_base_keep_pivot;
  PyObject *__pyx_n_s_GiacMethods_base_ker;
  PyObject *__pyx_n_s_GiacMethods_base_kernel;
  PyObject *__pyx_n_s_GiacMethods_base_kernel_density;
  PyObject *__pyx_n_s_GiacMethods_base_kmeans;
  PyObject *__pyx_n_s_GiacMethods_base_kneser_graph;
  PyObject *__pyx_n_s_GiacMethods_base_kolmogorovd;
  PyObject *__pyx_n_s_GiacMethods_base_kolmogorovt;
  PyObject *__pyx_n_s_GiacMethods_base_kovacicsols;
  PyObject *__pyx_n_s_GiacMethods_base_kspaths;
  PyObject *__pyx_n_s_GiacMethods_base_l1norm;
  PyObject *__pyx_n_s_GiacMethods_base_l2norm;
  PyObject *__pyx_n_s_GiacMethods_base_lagrange;
  PyObject *__pyx_n_s_GiacMethods_base_laguerre;
  PyObject *__pyx_n_s_GiacMethods_base_laplace;
  PyObject *__pyx_n_s_GiacMethods_base_laplacian;
  PyObject *__pyx_n_s_GiacMethods_base_laplacian_matri;
  PyObject *__pyx_n_s_GiacMethods_base_latex;
  PyObject *__pyx_n_s_GiacMethods_base_lcf_graph;
  PyObject *__pyx_n_s_GiacMethods_base_lcm;
  PyObject *__pyx_n_s_GiacMethods_base_lcoeff;
  PyObject *__pyx_n_s_GiacMethods_base_ldegree;
  PyObject *__pyx_n_s_GiacMethods_base_ldl;
  PyObject *__pyx_n_s_GiacMethods_base_learning_rate;
  PyObject *__pyx_n_s_GiacMethods_base_left;
  PyObject *__pyx_n_s_GiacMethods_base_left_rectangle;
  PyObject *__pyx_n_s_GiacMethods_base_legend;
  PyObject *__pyx_n_s_GiacMethods_base_legendre;
  PyObject *__pyx_n_s_GiacMethods_base_legendre_symbol;
  PyObject *__pyx_n_s_GiacMethods_base_length;
  PyObject *__pyx_n_s_GiacMethods_base_levenshtein;
  PyObject *__pyx_n_s_GiacMethods_base_lgcd;
  PyObject *__pyx_n_s_GiacMethods_base_lhs;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_chapeau_c;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_chapeau_p;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_chapeau_r;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_polygonal;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_polygonal_2;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_tiret;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_tiret_poi;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_tiret_poi_2;
  PyObject *__pyx_n_s_GiacMethods_base_ligne_trait_ple;
  PyObject *__pyx_n_s_GiacMethods_base_limit;
  PyObject *__pyx_n_s_GiacMethods_base_limite;
  PyObject *__pyx_n_s_GiacMethods_base_lin;
  PyObject *__pyx_n_s_GiacMethods_base_linabs;
  PyObject *__pyx_n_s_GiacMethods_base_line;
  PyObject *__pyx_n_s_GiacMethods_base_line_graph;
  PyObject *__pyx_n_s_GiacMethods_base_line_inter;
  PyObject *__pyx_n_s_GiacMethods_base_line_paper;
  PyObject *__pyx_n_s_GiacMethods_base_line_segments;
  PyObject *__pyx_n_s_GiacMethods_base_linear_interpol;
  PyObject *__pyx_n_s_GiacMethods_base_linear_regressi;
  PyObject *__pyx_n_s_GiacMethods_base_linear_regressi_2;
  PyObject *__pyx_n_s_GiacMethods_base_lineariser;
  PyObject *__pyx_n_s_GiacMethods_base_lineariser_trig;
  PyObject *__pyx_n_s_GiacMethods_base_linfnorm;
  PyObject *__pyx_n_s_GiacMethods_base_linsolve;
  PyObject *__pyx_n_s_GiacMethods_base_linspace;
  PyObject *__pyx_n_s_GiacMethods_base_linstep;
  PyObject *__pyx_n_s_GiacMethods_base_lis_phrase;
  PyObject *__pyx_n_s_GiacMethods_base_list2exp;
  PyObject *__pyx_n_s_GiacMethods_base_list2mat;
  PyObject *__pyx_n_s_GiacMethods_base_list_edge_attri;
  PyObject *__pyx_n_s_GiacMethods_base_list_graph_attr;
  PyObject *__pyx_n_s_GiacMethods_base_list_vertex_att;
  PyObject *__pyx_n_s_GiacMethods_base_listplot;
  PyObject *__pyx_n_s_GiacMethods_base_lll;
  PyObject *__pyx_n_s_GiacMethods_base_ln;
  PyObject *__pyx_n_s_GiacMethods_base_lname;
  PyObject *__pyx_n_s_GiacMethods_base_lncollect;
  PyObject *__pyx_n_s_GiacMethods_base_lnexpand;
  PyObject *__pyx_n_s_GiacMethods_base_locus;
  PyObject *__pyx_n_s_GiacMethods_base_log;
  PyObject *__pyx_n_s_GiacMethods_base_log10;
  PyObject *__pyx_n_s_GiacMethods_base_log2;
  PyObject *__pyx_n_s_GiacMethods_base_log_loss;
  PyObject *__pyx_n_s_GiacMethods_base_logarithmic_reg;
  PyObject *__pyx_n_s_GiacMethods_base_logarithmic_reg_2;
  PyObject *__pyx_n_s_GiacMethods_base_logb;
  PyObject *__pyx_n_s_GiacMethods_base_logistic;
  PyObject *__pyx_n_s_GiacMethods_base_logistic_regres;
  PyObject *__pyx_n_s_GiacMethods_base_logistic_regres_2;
  PyObject *__pyx_n_s_GiacMethods_base_lower;
  PyObject *__pyx_n_s_GiacMethods_base_lowest_common_a;
  PyObject *__pyx_n_s_GiacMethods_base_lowpass;
  PyObject *__pyx_n_s_GiacMethods_base_lp_assume;
  PyObject *__pyx_n_s_GiacMethods_base_lp_bestlocalbou;
  PyObject *__pyx_n_s_GiacMethods_base_lp_bestprojecti;
  PyObject *__pyx_n_s_GiacMethods_base_lp_binary;
  PyObject *__pyx_n_s_GiacMethods_base_lp_binaryvariab;
  PyObject *__pyx_n_s_GiacMethods_base_lp_breadthfirst;
  PyObject *__pyx_n_s_GiacMethods_base_lp_depthfirst;
  PyObject *__pyx_n_s_GiacMethods_base_lp_depthlimit;
  PyObject *__pyx_n_s_GiacMethods_base_lp_firstfractio;
  PyObject *__pyx_n_s_GiacMethods_base_lp_gaptolerance;
  PyObject *__pyx_n_s_GiacMethods_base_lp_heuristic;
  PyObject *__pyx_n_s_GiacMethods_base_lp_hybrid;
  PyObject *__pyx_n_s_GiacMethods_base_lp_integer;
  PyObject *__pyx_n_s_GiacMethods_base_lp_integervaria;
  PyObject *__pyx_n_s_GiacMethods_base_lp_interiorpoin;
  PyObject *__pyx_n_s_GiacMethods_base_lp_iterationlim;
  PyObject *__pyx_n_s_GiacMethods_base_lp_lastfraction;
  PyObject *__pyx_n_s_GiacMethods_base_lp_maxcuts;
  PyObject *__pyx_n_s_GiacMethods_base_lp_maximize;
  PyObject *__pyx_n_s_GiacMethods_base_lp_method;
  PyObject *__pyx_n_s_GiacMethods_base_lp_mostfraction;
  PyObject *__pyx_n_s_GiacMethods_base_lp_nodelimit;
  PyObject *__pyx_n_s_GiacMethods_base_lp_nodeselect;
  PyObject *__pyx_n_s_GiacMethods_base_lp_nonnegative;
  PyObject *__pyx_n_s_GiacMethods_base_lp_nonnegint;
  PyObject *__pyx_n_s_GiacMethods_base_lp_presolve;
  PyObject *__pyx_n_s_GiacMethods_base_lp_pseudocost;
  PyObject *__pyx_n_s_GiacMethods_base_lp_simplex;
  PyObject *__pyx_n_s_GiacMethods_base_lp_timelimit;
  PyObject *__pyx_n_s_GiacMethods_base_lp_varselect;
  PyObject *__pyx_n_s_GiacMethods_base_lp_verbose;
  PyObject *__pyx_n_s_GiacMethods_base_lpsolve;
  PyObject *__pyx_n_s_GiacMethods_base_lsmod;
  PyObject *__pyx_n_s_GiacMethods_base_lsq;
  PyObject *__pyx_n_s_GiacMethods_base_lu;
  PyObject *__pyx_n_s_GiacMethods_base_lvar;
  PyObject *__pyx_n_s_GiacMethods_base_mRow;
  PyObject *__pyx_n_s_GiacMethods_base_mRowAdd;
  PyObject *__pyx_n_s_GiacMethods_base_magenta;
  PyObject *__pyx_n_s_GiacMethods_base_make_directed;
  PyObject *__pyx_n_s_GiacMethods_base_make_symbol;
  PyObject *__pyx_n_s_GiacMethods_base_make_weighted;
  PyObject *__pyx_n_s_GiacMethods_base_makelist;
  PyObject *__pyx_n_s_GiacMethods_base_makemat;
  PyObject *__pyx_n_s_GiacMethods_base_makesuite;
  PyObject *__pyx_n_s_GiacMethods_base_makevector;
  PyObject *__pyx_n_s_GiacMethods_base_map;
  PyObject *__pyx_n_s_GiacMethods_base_maple2mupad;
  PyObject *__pyx_n_s_GiacMethods_base_maple2xcas;
  PyObject *__pyx_n_s_GiacMethods_base_maple_ifactors;
  PyObject *__pyx_n_s_GiacMethods_base_maple_mode;
  PyObject *__pyx_n_s_GiacMethods_base_markov;
  PyObject *__pyx_n_s_GiacMethods_base_mat2list;
  PyObject *__pyx_n_s_GiacMethods_base_mathml;
  PyObject *__pyx_n_s_GiacMethods_base_matpow;
  PyObject *__pyx_n_s_GiacMethods_base_matrix;
  PyObject *__pyx_n_s_GiacMethods_base_matrix_norm;
  PyObject *__pyx_n_s_GiacMethods_base_max;
  PyObject *__pyx_n_s_GiacMethods_base_maxflow;
  PyObject *__pyx_n_s_GiacMethods_base_maximal_indepen;
  PyObject *__pyx_n_s_GiacMethods_base_maximize;
  PyObject *__pyx_n_s_GiacMethods_base_maximum_clique;
  PyObject *__pyx_n_s_GiacMethods_base_maximum_degree;
  PyObject *__pyx_n_s_GiacMethods_base_maximum_indepen;
  PyObject *__pyx_n_s_GiacMethods_base_maximum_matchin;
  PyObject *__pyx_n_s_GiacMethods_base_maxnorm;
  PyObject *__pyx_n_s_GiacMethods_base_mean;
  PyObject *__pyx_n_s_GiacMethods_base_median;
  PyObject *__pyx_n_s_GiacMethods_base_median_line;
  PyObject *__pyx_n_s_GiacMethods_base_member;
  PyObject *__pyx_n_s_GiacMethods_base_mgf;
  PyObject *__pyx_n_s_GiacMethods_base_mid;
  PyObject *__pyx_n_s_GiacMethods_base_middle_point;
  PyObject *__pyx_n_s_GiacMethods_base_midpoint;
  PyObject *__pyx_n_s_GiacMethods_base_min;
  PyObject *__pyx_n_s_GiacMethods_base_minimal_edge_co;
  PyObject *__pyx_n_s_GiacMethods_base_minimal_spannin;
  PyObject *__pyx_n_s_GiacMethods_base_minimal_vertex;
  PyObject *__pyx_n_s_GiacMethods_base_minimax;
  PyObject *__pyx_n_s_GiacMethods_base_minimize;
  PyObject *__pyx_n_s_GiacMethods_base_minimum_cut;
  PyObject *__pyx_n_s_GiacMethods_base_minimum_degree;
  PyObject *__pyx_n_s_GiacMethods_base_minimum_vertex;
  PyObject *__pyx_n_s_GiacMethods_base_mixdown;
  PyObject *__pyx_n_s_GiacMethods_base_mkisom;
  PyObject *__pyx_n_s_GiacMethods_base_mksa;
  PyObject *__pyx_n_s_GiacMethods_base_modf;
  PyObject *__pyx_n_s_GiacMethods_base_modgcd;
  PyObject *__pyx_n_s_GiacMethods_base_mods;
  PyObject *__pyx_n_s_GiacMethods_base_momentum;
  PyObject *__pyx_n_s_GiacMethods_base_monotonic;
  PyObject *__pyx_n_s_GiacMethods_base_montre_tortue;
  PyObject *__pyx_n_s_GiacMethods_base_moustache;
  PyObject *__pyx_n_s_GiacMethods_base_moving_average;
  PyObject *__pyx_n_s_GiacMethods_base_moyal;
  PyObject *__pyx_n_s_GiacMethods_base_moyenne;
  PyObject *__pyx_n_s_GiacMethods_base_mul;
  PyObject *__pyx_n_s_GiacMethods_base_mult_c_conjugat;
  PyObject *__pyx_n_s_GiacMethods_base_mult_conjugate;
  PyObject *__pyx_n_s_GiacMethods_base_multinomial;
  PyObject *__pyx_n_s_GiacMethods_base_multiplier_conj;
  PyObject *__pyx_n_s_GiacMethods_base_multiplier_conj_2;
  PyObject *__pyx_n_s_GiacMethods_base_multiply;
  PyObject *__pyx_n_s_GiacMethods_base_mupad2maple;
  PyObject *__pyx_n_s_GiacMethods_base_mupad2xcas;
  PyObject *__pyx_n_s_GiacMethods_base_mycielski;
  PyObject *__pyx_n_s_GiacMethods_base_nCr;
  PyObject *__pyx_n_s_GiacMethods_base_nDeriv;
  PyObject *__pyx_n_s_GiacMethods_base_nInt;
  PyObject *__pyx_n_s_GiacMethods_base_nPr;
  PyObject *__pyx_n_s_GiacMethods_base_nSolve;
  PyObject *__pyx_n_s_GiacMethods_base_navy;
  PyObject *__pyx_n_s_GiacMethods_base_ncols;
  PyObject *__pyx_n_s_GiacMethods_base_negbinomial;
  PyObject *__pyx_n_s_GiacMethods_base_negbinomial_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_negbinomial_icd;
  PyObject *__pyx_n_s_GiacMethods_base_neighbors;
  PyObject *__pyx_n_s_GiacMethods_base_network_transit;
  PyObject *__pyx_n_s_GiacMethods_base_neural_network;
  PyObject *__pyx_n_s_GiacMethods_base_newList;
  PyObject *__pyx_n_s_GiacMethods_base_newMat;
  PyObject *__pyx_n_s_GiacMethods_base_newton;
  PyObject *__pyx_n_s_GiacMethods_base_newton_solver;
  PyObject *__pyx_n_s_GiacMethods_base_newtonj_solver;
  PyObject *__pyx_n_s_GiacMethods_base_nextperm;
  PyObject *__pyx_n_s_GiacMethods_base_nextprime;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_binary;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_binaryvaria;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_initialpoin;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_integer;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_integervari;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_iterationli;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_maximize;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_method;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_nonnegative;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_nonnegint;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_precision;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_presolve;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_tolerance;
  PyObject *__pyx_n_s_GiacMethods_base_nlp_verbose;
  PyObject *__pyx_n_s_GiacMethods_base_nlpsolve;
  PyObject *__pyx_n_s_GiacMethods_base_nodisp;
  PyObject *__pyx_n_s_GiacMethods_base_non_recursive_n;
  PyObject *__pyx_n_s_GiacMethods_base_nonnegint;
  PyObject *__pyx_n_s_GiacMethods_base_nop;
  PyObject *__pyx_n_s_GiacMethods_base_nops;
  PyObject *__pyx_n_s_GiacMethods_base_norm;
  PyObject *__pyx_n_s_GiacMethods_base_normal;
  PyObject *__pyx_n_s_GiacMethods_base_normal_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_normal_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_normald;
  PyObject *__pyx_n_s_GiacMethods_base_normald_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_normald_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_normalize;
  PyObject *__pyx_n_s_GiacMethods_base_normalt;
  PyObject *__pyx_n_s_GiacMethods_base_normalvariate;
  PyObject *__pyx_n_s_GiacMethods_base_nprimes;
  PyObject *__pyx_n_s_GiacMethods_base_nrows;
  PyObject *__pyx_n_s_GiacMethods_base_nstep;
  PyObject *__pyx_n_s_GiacMethods_base_nuage_points;
  PyObject *__pyx_n_s_GiacMethods_base_nullspace;
  PyObject *__pyx_n_s_GiacMethods_base_number_of_edges;
  PyObject *__pyx_n_s_GiacMethods_base_number_of_spann;
  PyObject *__pyx_n_s_GiacMethods_base_number_of_trian;
  PyObject *__pyx_n_s_GiacMethods_base_number_of_verti;
  PyObject *__pyx_n_s_GiacMethods_base_numdiff;
  PyObject *__pyx_n_s_GiacMethods_base_numer;
  PyObject *__pyx_n_s_GiacMethods_base_octahedron;
  PyObject *__pyx_n_s_GiacMethods_base_odd;
  PyObject *__pyx_n_s_GiacMethods_base_odd_girth;
  PyObject *__pyx_n_s_GiacMethods_base_odd_graph;
  PyObject *__pyx_n_s_GiacMethods_base_odeplot;
  PyObject *__pyx_n_s_GiacMethods_base_odesolve;
  PyObject *__pyx_n_s_GiacMethods_base_olive;
  PyObject *__pyx_n_s_GiacMethods_base_op;
  PyObject *__pyx_n_s_GiacMethods_base_open_polygon;
  PyObject *__pyx_n_s_GiacMethods_base_orange;
  PyObject *__pyx_n_s_GiacMethods_base_ord;
  PyObject *__pyx_n_s_GiacMethods_base_order;
  PyObject *__pyx_n_s_GiacMethods_base_order_size;
  PyObject *__pyx_n_s_GiacMethods_base_ordinate;
  PyObject *__pyx_n_s_GiacMethods_base_orthocenter;
  PyObject *__pyx_n_s_GiacMethods_base_orthogonal;
  PyObject *__pyx_n_s_GiacMethods_base_osculating_circ;
  PyObject *__pyx_n_s_GiacMethods_base_p1oc2;
  PyObject *__pyx_n_s_GiacMethods_base_p1op2;
  PyObject *__pyx_n_s_GiacMethods_base_pa2b2;
  PyObject *__pyx_n_s_GiacMethods_base_pade;
  PyObject *__pyx_n_s_GiacMethods_base_paley_graph;
  PyObject *__pyx_n_s_GiacMethods_base_parabola;
  PyObject *__pyx_n_s_GiacMethods_base_parallel;
  PyObject *__pyx_n_s_GiacMethods_base_parallelepiped;
  PyObject *__pyx_n_s_GiacMethods_base_parallelogram;
  PyObject *__pyx_n_s_GiacMethods_base_parameq;
  PyObject *__pyx_n_s_GiacMethods_base_parameter;
  PyObject *__pyx_n_s_GiacMethods_base_paramplot;
  PyObject *__pyx_n_s_GiacMethods_base_parfrac;
  PyObject *__pyx_n_s_GiacMethods_base_pari;
  PyObject *__pyx_n_s_GiacMethods_base_part;
  PyObject *__pyx_n_s_GiacMethods_base_partfrac;
  PyObject *__pyx_n_s_GiacMethods_base_parzen_window;
  PyObject *__pyx_n_s_GiacMethods_base_pas_de_cote;
  PyObject *__pyx_n_s_GiacMethods_base_path_graph;
  PyObject *__pyx_n_s_GiacMethods_base_pcar;
  PyObject *__pyx_n_s_GiacMethods_base_pcar_hessenberg;
  PyObject *__pyx_n_s_GiacMethods_base_pcoef;
  PyObject *__pyx_n_s_GiacMethods_base_pcoeff;
  PyObject *__pyx_n_s_GiacMethods_base_pencolor;
  PyObject *__pyx_n_s_GiacMethods_base_pendown;
  PyObject *__pyx_n_s_GiacMethods_base_penup;
  PyObject *__pyx_n_s_GiacMethods_base_perimeter;
  PyObject *__pyx_n_s_GiacMethods_base_perimeterat;
  PyObject *__pyx_n_s_GiacMethods_base_perimeteratraw;
  PyObject *__pyx_n_s_GiacMethods_base_period;
  PyObject *__pyx_n_s_GiacMethods_base_periodic;
  PyObject *__pyx_n_s_GiacMethods_base_perm;
  PyObject *__pyx_n_s_GiacMethods_base_perminv;
  PyObject *__pyx_n_s_GiacMethods_base_permu2cycles;
  PyObject *__pyx_n_s_GiacMethods_base_permu2mat;
  PyObject *__pyx_n_s_GiacMethods_base_permuorder;
  PyObject *__pyx_n_s_GiacMethods_base_permute_vertice;
  PyObject *__pyx_n_s_GiacMethods_base_perpen_bisector;
  PyObject *__pyx_n_s_GiacMethods_base_perpendicular;
  PyObject *__pyx_n_s_GiacMethods_base_petersen_graph;
  PyObject *__pyx_n_s_GiacMethods_base_peval;
  PyObject *__pyx_n_s_GiacMethods_base_pi;
  PyObject *__pyx_n_s_GiacMethods_base_pie;
  PyObject *__pyx_n_s_GiacMethods_base_piecewise;
  PyObject *__pyx_n_s_GiacMethods_base_pink;
  PyObject *__pyx_n_s_GiacMethods_base_pivot;
  PyObject *__pyx_n_s_GiacMethods_base_pixoff;
  PyObject *__pyx_n_s_GiacMethods_base_pixon;
  PyObject *__pyx_n_s_GiacMethods_base_planar;
  PyObject *__pyx_n_s_GiacMethods_base_plane;
  PyObject *__pyx_n_s_GiacMethods_base_plane_dual;
  PyObject *__pyx_n_s_GiacMethods_base_playsnd;
  PyObject *__pyx_n_s_GiacMethods_base_plex;
  PyObject *__pyx_n_s_GiacMethods_base_plot;
  PyObject *__pyx_n_s_GiacMethods_base_plot3d;
  PyObject *__pyx_n_s_GiacMethods_base_plotarea;
  PyObject *__pyx_n_s_GiacMethods_base_plotcdf;
  PyObject *__pyx_n_s_GiacMethods_base_plotcontour;
  PyObject *__pyx_n_s_GiacMethods_base_plotdensity;
  PyObject *__pyx_n_s_GiacMethods_base_plotfield;
  PyObject *__pyx_n_s_GiacMethods_base_plotfunc;
  PyObject *__pyx_n_s_GiacMethods_base_plotimf;
  PyObject *__pyx_n_s_GiacMethods_base_plotimplicit;
  PyObject *__pyx_n_s_GiacMethods_base_plotinequation;
  PyObject *__pyx_n_s_GiacMethods_base_plotlist;
  PyObject *__pyx_n_s_GiacMethods_base_plotode;
  PyObject *__pyx_n_s_GiacMethods_base_plotparam;
  PyObject *__pyx_n_s_GiacMethods_base_plotpolar;
  PyObject *__pyx_n_s_GiacMethods_base_plotproba;
  PyObject *__pyx_n_s_GiacMethods_base_plotseq;
  PyObject *__pyx_n_s_GiacMethods_base_plotspectrum;
  PyObject *__pyx_n_s_GiacMethods_base_plotwav;
  PyObject *__pyx_n_s_GiacMethods_base_plus_point;
  PyObject *__pyx_n_s_GiacMethods_base_pmin;
  PyObject *__pyx_n_s_GiacMethods_base_point;
  PyObject *__pyx_n_s_GiacMethods_base_point2d;
  PyObject *__pyx_n_s_GiacMethods_base_point3d;
  PyObject *__pyx_n_s_GiacMethods_base_poisson;
  PyObject *__pyx_n_s_GiacMethods_base_poisson_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_poisson_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_poisson_window;
  PyObject *__pyx_n_s_GiacMethods_base_polar;
  PyObject *__pyx_n_s_GiacMethods_base_polar_coordinat;
  PyObject *__pyx_n_s_GiacMethods_base_polar_point;
  PyObject *__pyx_n_s_GiacMethods_base_polarplot;
  PyObject *__pyx_n_s_GiacMethods_base_pole;
  PyObject *__pyx_n_s_GiacMethods_base_poly2symb;
  PyObject *__pyx_n_s_GiacMethods_base_polyEval;
  PyObject *__pyx_n_s_GiacMethods_base_polygon;
  PyObject *__pyx_n_s_GiacMethods_base_polygone_rempli;
  PyObject *__pyx_n_s_GiacMethods_base_polygonplot;
  PyObject *__pyx_n_s_GiacMethods_base_polygonscatterp;
  PyObject *__pyx_n_s_GiacMethods_base_polyhedron;
  PyObject *__pyx_n_s_GiacMethods_base_polynom;
  PyObject *__pyx_n_s_GiacMethods_base_polynomial_regr;
  PyObject *__pyx_n_s_GiacMethods_base_polynomial_regr_2;
  PyObject *__pyx_n_s_GiacMethods_base_position;
  PyObject *__pyx_n_s_GiacMethods_base_poslbdLMQ;
  PyObject *__pyx_n_s_GiacMethods_base_posubLMQ;
  PyObject *__pyx_n_s_GiacMethods_base_potential;
  PyObject *__pyx_n_s_GiacMethods_base_pow2exp;
  PyObject *__pyx_n_s_GiacMethods_base_power_regressio;
  PyObject *__pyx_n_s_GiacMethods_base_power_regressio_2;
  PyObject *__pyx_n_s_GiacMethods_base_powermod;
  PyObject *__pyx_n_s_GiacMethods_base_powerpc;
  PyObject *__pyx_n_s_GiacMethods_base_powexpand;
  PyObject *__pyx_n_s_GiacMethods_base_powmod;
  PyObject *__pyx_n_s_GiacMethods_base_prepend;
  PyObject *__pyx_n_s_GiacMethods_base_preval;
  PyObject *__pyx_n_s_GiacMethods_base_prevperm;
  PyObject *__pyx_n_s_GiacMethods_base_prevprime;
  PyObject *__pyx_n_s_GiacMethods_base_primpart;
  PyObject *__pyx_n_s_GiacMethods_base_printf;
  PyObject *__pyx_n_s_GiacMethods_base_prism;
  PyObject *__pyx_n_s_GiacMethods_base_prism_graph;
  PyObject *__pyx_n_s_GiacMethods_base_product;
  PyObject *__pyx_n_s_GiacMethods_base_projection;
  PyObject *__pyx_n_s_GiacMethods_base_proot;
  PyObject *__pyx_n_s_GiacMethods_base_propFrac;
  PyObject *__pyx_n_s_GiacMethods_base_propfrac;
  PyObject *__pyx_n_s_GiacMethods_base_pruefer_code;
  PyObject *__pyx_n_s_GiacMethods_base_psrgcd;
  PyObject *__pyx_n_s_GiacMethods_base_ptayl;
  PyObject *__pyx_n_s_GiacMethods_base_purge;
  PyObject *__pyx_n_s_GiacMethods_base_purple;
  PyObject *__pyx_n_s_GiacMethods_base_pwd;
  PyObject *__pyx_n_s_GiacMethods_base_pyramid;
  PyObject *__pyx_n_s_GiacMethods_base_python_compat;
  PyObject *__pyx_n_s_GiacMethods_base_q2a;
  PyObject *__pyx_n_s_GiacMethods_base_qr;
  PyObject *__pyx_n_s_GiacMethods_base_quadric;
  PyObject *__pyx_n_s_GiacMethods_base_quadrilateral;
  PyObject *__pyx_n_s_GiacMethods_base_quantile;
  PyObject *__pyx_n_s_GiacMethods_base_quartile1;
  PyObject *__pyx_n_s_GiacMethods_base_quartile3;
  PyObject *__pyx_n_s_GiacMethods_base_quartiles;
  PyObject *__pyx_n_s_GiacMethods_base_quest;
  PyObject *__pyx_n_s_GiacMethods_base_quo;
  PyObject *__pyx_n_s_GiacMethods_base_quorem;
  PyObject *__pyx_n_s_GiacMethods_base_quote;
  PyObject *__pyx_n_s_GiacMethods_base_r2e;
  PyObject *__pyx_n_s_GiacMethods_base_radians;
  PyObject *__pyx_n_s_GiacMethods_base_radical_axis;
  PyObject *__pyx_n_s_GiacMethods_base_radius;
  PyObject *__pyx_n_s_GiacMethods_base_ramene;
  PyObject *__pyx_n_s_GiacMethods_base_rand;
  PyObject *__pyx_n_s_GiacMethods_base_randMat;
  PyObject *__pyx_n_s_GiacMethods_base_randNorm;
  PyObject *__pyx_n_s_GiacMethods_base_randPoly;
  PyObject *__pyx_n_s_GiacMethods_base_randbetad;
  PyObject *__pyx_n_s_GiacMethods_base_randbinomial;
  PyObject *__pyx_n_s_GiacMethods_base_randchisquare;
  PyObject *__pyx_n_s_GiacMethods_base_randexp;
  PyObject *__pyx_n_s_GiacMethods_base_randfisher;
  PyObject *__pyx_n_s_GiacMethods_base_randgammad;
  PyObject *__pyx_n_s_GiacMethods_base_randgeometric;
  PyObject *__pyx_n_s_GiacMethods_base_randint;
  PyObject *__pyx_n_s_GiacMethods_base_randmarkov;
  PyObject *__pyx_n_s_GiacMethods_base_randmatrix;
  PyObject *__pyx_n_s_GiacMethods_base_randmultinomial;
  PyObject *__pyx_n_s_GiacMethods_base_randnorm;
  PyObject *__pyx_n_s_GiacMethods_base_random;
  PyObject *__pyx_n_s_GiacMethods_base_random_bipartit;
  PyObject *__pyx_n_s_GiacMethods_base_random_digraph;
  PyObject *__pyx_n_s_GiacMethods_base_random_graph;
  PyObject *__pyx_n_s_GiacMethods_base_random_network;
  PyObject *__pyx_n_s_GiacMethods_base_random_planar_g;
  PyObject *__pyx_n_s_GiacMethods_base_random_regular;
  PyObject *__pyx_n_s_GiacMethods_base_random_sequence;
  PyObject *__pyx_n_s_GiacMethods_base_random_tourname;
  PyObject *__pyx_n_s_GiacMethods_base_random_tree;
  PyObject *__pyx_n_s_GiacMethods_base_random_variable;
  PyObject *__pyx_n_s_GiacMethods_base_randperm;
  PyObject *__pyx_n_s_GiacMethods_base_randpoisson;
  PyObject *__pyx_n_s_GiacMethods_base_randpoly;
  PyObject *__pyx_n_s_GiacMethods_base_randseed;
  PyObject *__pyx_n_s_GiacMethods_base_randstudent;
  PyObject *__pyx_n_s_GiacMethods_base_randvar;
  PyObject *__pyx_n_s_GiacMethods_base_randvector;
  PyObject *__pyx_n_s_GiacMethods_base_randweibulld;
  PyObject *__pyx_n_s_GiacMethods_base_rank;
  PyObject *__pyx_n_s_GiacMethods_base_ranm;
  PyObject *__pyx_n_s_GiacMethods_base_ranv;
  PyObject *__pyx_n_s_GiacMethods_base_rassembler_trig;
  PyObject *__pyx_n_s_GiacMethods_base_rat_jordan;
  PyObject *__pyx_n_s_GiacMethods_base_ratinterp;
  PyObject *__pyx_n_s_GiacMethods_base_rational;
  PyObject *__pyx_n_s_GiacMethods_base_rationalroot;
  PyObject *__pyx_n_s_GiacMethods_base_ratnormal;
  PyObject *__pyx_n_s_GiacMethods_base_rdiv;
  PyObject *__pyx_n_s_GiacMethods_base_re;
  PyObject *__pyx_n_s_GiacMethods_base_reachable;
  PyObject *__pyx_n_s_GiacMethods_base_read;
  PyObject *__pyx_n_s_GiacMethods_base_readrgb;
  PyObject *__pyx_n_s_GiacMethods_base_readwav;
  PyObject *__pyx_n_s_GiacMethods_base_real;
  PyObject *__pyx_n_s_GiacMethods_base_realroot;
  PyObject *__pyx_n_s_GiacMethods_base_reciprocation;
  PyObject *__pyx_n_s_GiacMethods_base_rect;
  PyObject *__pyx_n_s_GiacMethods_base_rectangle;
  PyObject *__pyx_n_s_GiacMethods_base_rectangle_droit;
  PyObject *__pyx_n_s_GiacMethods_base_rectangle_gauch;
  PyObject *__pyx_n_s_GiacMethods_base_rectangle_plein;
  PyObject *__pyx_n_s_GiacMethods_base_rectangular_coo;
  PyObject *__pyx_n_s_GiacMethods_base_recule;
  PyObject *__pyx_n_s_GiacMethods_base_red;
  PyObject *__pyx_n_s_GiacMethods_base_reduced_conic;
  PyObject *__pyx_n_s_GiacMethods_base_reduced_quadric;
  PyObject *__pyx_n_s_GiacMethods_base_ref;
  PyObject *__pyx_n_s_GiacMethods_base_reflection;
  PyObject *__pyx_n_s_GiacMethods_base_regroup;
  PyObject *__pyx_n_s_GiacMethods_base_relabel_vertice;
  PyObject *__pyx_n_s_GiacMethods_base_reliability_pol;
  PyObject *__pyx_n_s_GiacMethods_base_rem;
  PyObject *__pyx_n_s_GiacMethods_base_remain;
  PyObject *__pyx_n_s_GiacMethods_base_remove;
  PyObject *__pyx_n_s_GiacMethods_base_reorder;
  PyObject *__pyx_n_s_GiacMethods_base_resample;
  PyObject *__pyx_n_s_GiacMethods_base_residue;
  PyObject *__pyx_n_s_GiacMethods_base_resoudre;
  PyObject *__pyx_n_s_GiacMethods_base_resoudre_dans_C;
  PyObject *__pyx_n_s_GiacMethods_base_resoudre_system;
  PyObject *__pyx_n_s_GiacMethods_base_resultant;
  PyObject *__pyx_n_s_GiacMethods_base_reverse;
  PyObject *__pyx_n_s_GiacMethods_base_reverse_graph;
  PyObject *__pyx_n_s_GiacMethods_base_reverse_rsolve;
  PyObject *__pyx_n_s_GiacMethods_base_revert;
  PyObject *__pyx_n_s_GiacMethods_base_revlex;
  PyObject *__pyx_n_s_GiacMethods_base_revlist;
  PyObject *__pyx_n_s_GiacMethods_base_rgb;
  PyObject *__pyx_n_s_GiacMethods_base_rgb2hsv;
  PyObject *__pyx_n_s_GiacMethods_base_rgb2xyz;
  PyObject *__pyx_n_s_GiacMethods_base_rhombus;
  PyObject *__pyx_n_s_GiacMethods_base_rhombus_point;
  PyObject *__pyx_n_s_GiacMethods_base_rhs;
  PyObject *__pyx_n_s_GiacMethods_base_riemann_window;
  PyObject *__pyx_n_s_GiacMethods_base_right;
  PyObject *__pyx_n_s_GiacMethods_base_right_rectangle;
  PyObject *__pyx_n_s_GiacMethods_base_right_triangle;
  PyObject *__pyx_n_s_GiacMethods_base_risch;
  PyObject *__pyx_n_s_GiacMethods_base_rm_a_z;
  PyObject *__pyx_n_s_GiacMethods_base_rm_all_vars;
  PyObject *__pyx_n_s_GiacMethods_base_rmbreakpoint;
  PyObject *__pyx_n_s_GiacMethods_base_rmmod;
  PyObject *__pyx_n_s_GiacMethods_base_rms;
  PyObject *__pyx_n_s_GiacMethods_base_rmwatch;
  PyObject *__pyx_n_s_GiacMethods_base_romberg;
  PyObject *__pyx_n_s_GiacMethods_base_rombergm;
  PyObject *__pyx_n_s_GiacMethods_base_rombergt;
  PyObject *__pyx_n_s_GiacMethods_base_rond;
  PyObject *__pyx_n_s_GiacMethods_base_root;
  PyObject *__pyx_n_s_GiacMethods_base_rootof;
  PyObject *__pyx_n_s_GiacMethods_base_roots;
  PyObject *__pyx_n_s_GiacMethods_base_rotate;
  PyObject *__pyx_n_s_GiacMethods_base_rotation;
  PyObject *__pyx_n_s_GiacMethods_base_round;
  PyObject *__pyx_n_s_GiacMethods_base_row;
  PyObject *__pyx_n_s_GiacMethods_base_rowAdd;
  PyObject *__pyx_n_s_GiacMethods_base_rowDim;
  PyObject *__pyx_n_s_GiacMethods_base_rowNorm;
  PyObject *__pyx_n_s_GiacMethods_base_rowSwap;
  PyObject *__pyx_n_s_GiacMethods_base_rowdim;
  PyObject *__pyx_n_s_GiacMethods_base_rownorm;
  PyObject *__pyx_n_s_GiacMethods_base_rowspace;
  PyObject *__pyx_n_s_GiacMethods_base_rowswap;
  PyObject *__pyx_n_s_GiacMethods_base_rref;
  PyObject *__pyx_n_s_GiacMethods_base_rsolve;
  PyObject *__pyx_n_s_GiacMethods_base_rur;
  PyObject *__pyx_n_s_GiacMethods_base_rur_certify;
  PyObject *__pyx_n_s_GiacMethods_base_rur_gbasis;
  PyObject *__pyx_n_s_GiacMethods_base_same;
  PyObject *__pyx_n_s_GiacMethods_base_sample;
  PyObject *__pyx_n_s_GiacMethods_base_samplerate;
  PyObject *__pyx_n_s_GiacMethods_base_sans_factoriser;
  PyObject *__pyx_n_s_GiacMethods_base_saute;
  PyObject *__pyx_n_s_GiacMethods_base_scalarProduct;
  PyObject *__pyx_n_s_GiacMethods_base_scalar_product;
  PyObject *__pyx_n_s_GiacMethods_base_scatterplot;
  PyObject *__pyx_n_s_GiacMethods_base_schur;
  PyObject *__pyx_n_s_GiacMethods_base_sec;
  PyObject *__pyx_n_s_GiacMethods_base_secant_solver;
  PyObject *__pyx_n_s_GiacMethods_base_segment;
  PyObject *__pyx_n_s_GiacMethods_base_seidel_spectrum;
  PyObject *__pyx_n_s_GiacMethods_base_seidel_switch;
  PyObject *__pyx_n_s_GiacMethods_base_select;
  PyObject *__pyx_n_s_GiacMethods_base_semi_augment;
  PyObject *__pyx_n_s_GiacMethods_base_seq;
  PyObject *__pyx_n_s_GiacMethods_base_seqplot;
  PyObject *__pyx_n_s_GiacMethods_base_seqsolve;
  PyObject *__pyx_n_s_GiacMethods_base_sequence_graph;
  PyObject *__pyx_n_s_GiacMethods_base_series;
  PyObject *__pyx_n_s_GiacMethods_base_set_channel_dat;
  PyObject *__pyx_n_s_GiacMethods_base_set_edge_attrib;
  PyObject *__pyx_n_s_GiacMethods_base_set_edge_weight;
  PyObject *__pyx_n_s_GiacMethods_base_set_graph_attri;
  PyObject *__pyx_n_s_GiacMethods_base_set_pixel;
  PyObject *__pyx_n_s_GiacMethods_base_set_screen;
  PyObject *__pyx_n_s_GiacMethods_base_set_vertex_attr;
  PyObject *__pyx_n_s_GiacMethods_base_set_vertex_posi;
  PyObject *__pyx_n_s_GiacMethods_base_shift;
  PyObject *__pyx_n_s_GiacMethods_base_shift_phase;
  PyObject *__pyx_n_s_GiacMethods_base_shortest_path;
  PyObject *__pyx_n_s_GiacMethods_base_show_pixels;
  PyObject *__pyx_n_s_GiacMethods_base_shuffle;
  PyObject *__pyx_n_s_GiacMethods_base_sierpinski_grap;
  PyObject *__pyx_n_s_GiacMethods_base_sign;
  PyObject *__pyx_n_s_GiacMethods_base_sign2Heaviside;
  PyObject *__pyx_n_s_GiacMethods_base_signature;
  PyObject *__pyx_n_s_GiacMethods_base_signe;
  PyObject *__pyx_n_s_GiacMethods_base_similarity;
  PyObject *__pyx_n_s_GiacMethods_base_simp2;
  PyObject *__pyx_n_s_GiacMethods_base_simplex_reduce;
  PyObject *__pyx_n_s_GiacMethods_base_simplicial_vert;
  PyObject *__pyx_n_s_GiacMethods_base_simplifier;
  PyObject *__pyx_n_s_GiacMethods_base_simplify;
  PyObject *__pyx_n_s_GiacMethods_base_simplifyDirac;
  PyObject *__pyx_n_s_GiacMethods_base_simpson;
  PyObject *__pyx_n_s_GiacMethods_base_simulated_annea;
  PyObject *__pyx_n_s_GiacMethods_base_simult;
  PyObject *__pyx_n_s_GiacMethods_base_sin;
  PyObject *__pyx_n_s_GiacMethods_base_sin2costan;
  PyObject *__pyx_n_s_GiacMethods_base_sinc;
  PyObject *__pyx_n_s_GiacMethods_base_sincos;
  PyObject *__pyx_n_s_GiacMethods_base_single_inter;
  PyObject *__pyx_n_s_GiacMethods_base_sinh;
  PyObject *__pyx_n_s_GiacMethods_base_sizes;
  PyObject *__pyx_n_s_GiacMethods_base_slope;
  PyObject *__pyx_n_s_GiacMethods_base_slopeat;
  PyObject *__pyx_n_s_GiacMethods_base_slopeatraw;
  PyObject *__pyx_n_s_GiacMethods_base_smith;
  PyObject *__pyx_n_s_GiacMethods_base_smod;
  PyObject *__pyx_n_s_GiacMethods_base_snedecor;
  PyObject *__pyx_n_s_GiacMethods_base_snedecor_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_snedecor_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_snedecord;
  PyObject *__pyx_n_s_GiacMethods_base_snedecord_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_snedecord_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_solid_line;
  PyObject *__pyx_n_s_GiacMethods_base_solve;
  PyObject *__pyx_n_s_GiacMethods_base_somme;
  PyObject *__pyx_n_s_GiacMethods_base_sommet;
  PyObject *__pyx_n_s_GiacMethods_base_sort;
  PyObject *__pyx_n_s_GiacMethods_base_sorta;
  PyObject *__pyx_n_s_GiacMethods_base_sortd;
  PyObject *__pyx_n_s_GiacMethods_base_sorted;
  PyObject *__pyx_n_s_GiacMethods_base_sortperm;
  PyObject *__pyx_n_s_GiacMethods_base_soundsec;
  PyObject *__pyx_n_s_GiacMethods_base_spanning_tree;
  PyObject *__pyx_n_s_GiacMethods_base_sphere;
  PyObject *__pyx_n_s_GiacMethods_base_splice;
  PyObject *__pyx_n_s_GiacMethods_base_spline;
  PyObject *__pyx_n_s_GiacMethods_base_split;
  PyObject *__pyx_n_s_GiacMethods_base_spring;
  PyObject *__pyx_n_s_GiacMethods_base_sq;
  PyObject *__pyx_n_s_GiacMethods_base_sqrfree;
  PyObject *__pyx_n_s_GiacMethods_base_sqrt;
  PyObject *__pyx_n_s_GiacMethods_base_square;
  PyObject *__pyx_n_s_GiacMethods_base_square_point;
  PyObject *__pyx_n_s_GiacMethods_base_srand;
  PyObject *__pyx_n_s_GiacMethods_base_sst;
  PyObject *__pyx_n_s_GiacMethods_base_sst_in;
  PyObject *__pyx_n_s_GiacMethods_base_st_ordering;
  PyObject *__pyx_n_s_GiacMethods_base_star_graph;
  PyObject *__pyx_n_s_GiacMethods_base_star_point;
  PyObject *__pyx_n_s_GiacMethods_base_stdDev;
  PyObject *__pyx_n_s_GiacMethods_base_stddev;
  PyObject *__pyx_n_s_GiacMethods_base_stddevp;
  PyObject *__pyx_n_s_GiacMethods_base_steffenson_solv;
  PyObject *__pyx_n_s_GiacMethods_base_stereo2mono;
  PyObject *__pyx_n_s_GiacMethods_base_stft;
  PyObject *__pyx_n_s_GiacMethods_base_str;
  PyObject *__pyx_n_s_GiacMethods_base_strip;
  PyObject *__pyx_n_s_GiacMethods_base_strongly_connec;
  PyObject *__pyx_n_s_GiacMethods_base_student;
  PyObject *__pyx_n_s_GiacMethods_base_student_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_student_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_studentd;
  PyObject *__pyx_n_s_GiacMethods_base_studentt;
  PyObject *__pyx_n_s_GiacMethods_base_sturm;
  PyObject *__pyx_n_s_GiacMethods_base_sturmab;
  PyObject *__pyx_n_s_GiacMethods_base_sturmseq;
  PyObject *__pyx_n_s_GiacMethods_base_style;
  PyObject *__pyx_n_s_GiacMethods_base_subMat;
  PyObject *__pyx_n_s_GiacMethods_base_subdivide_edges;
  PyObject *__pyx_n_s_GiacMethods_base_subgraph;
  PyObject *__pyx_n_s_GiacMethods_base_subs;
  PyObject *__pyx_n_s_GiacMethods_base_subsop;
  PyObject *__pyx_n_s_GiacMethods_base_subst;
  PyObject *__pyx_n_s_GiacMethods_base_substituer;
  PyObject *__pyx_n_s_GiacMethods_base_subtype;
  PyObject *__pyx_n_s_GiacMethods_base_sum;
  PyObject *__pyx_n_s_GiacMethods_base_sum_riemann;
  PyObject *__pyx_n_s_GiacMethods_base_suppress;
  PyObject *__pyx_n_s_GiacMethods_base_surd;
  PyObject *__pyx_n_s_GiacMethods_base_svd;
  PyObject *__pyx_n_s_GiacMethods_base_swapcol;
  PyObject *__pyx_n_s_GiacMethods_base_swaprow;
  PyObject *__pyx_n_s_GiacMethods_base_switch_axes;
  PyObject *__pyx_n_s_GiacMethods_base_sylvester;
  PyObject *__pyx_n_s_GiacMethods_base_symb2poly;
  PyObject *__pyx_n_s_GiacMethods_base_symbol;
  PyObject *__pyx_n_s_GiacMethods_base_symbol_array;
  PyObject *__pyx_n_s_GiacMethods_base_syst2mat;
  PyObject *__pyx_n_s_GiacMethods_base_tCollect;
  PyObject *__pyx_n_s_GiacMethods_base_tExpand;
  PyObject *__pyx_n_s_GiacMethods_base_table;
  PyObject *__pyx_n_s_GiacMethods_base_tablefunc;
  PyObject *__pyx_n_s_GiacMethods_base_tableseq;
  PyObject *__pyx_n_s_GiacMethods_base_tabsign;
  PyObject *__pyx_n_s_GiacMethods_base_tabvar;
  PyObject *__pyx_n_s_GiacMethods_base_tail;
  PyObject *__pyx_n_s_GiacMethods_base_tan;
  PyObject *__pyx_n_s_GiacMethods_base_tan2cossin2;
  PyObject *__pyx_n_s_GiacMethods_base_tan2sincos;
  PyObject *__pyx_n_s_GiacMethods_base_tan2sincos2;
  PyObject *__pyx_n_s_GiacMethods_base_tangent;
  PyObject *__pyx_n_s_GiacMethods_base_tangente;
  PyObject *__pyx_n_s_GiacMethods_base_tanh;
  PyObject *__pyx_n_s_GiacMethods_base_tar;
  PyObject *__pyx_n_s_GiacMethods_base_taux_accroissem;
  PyObject *__pyx_n_s_GiacMethods_base_taylor;
  PyObject *__pyx_n_s_GiacMethods_base_tchebyshev1;
  PyObject *__pyx_n_s_GiacMethods_base_tchebyshev2;
  PyObject *__pyx_n_s_GiacMethods_base_tcoeff;
  PyObject *__pyx_n_s_GiacMethods_base_tcollect;
  PyObject *__pyx_n_s_GiacMethods_base_tdeg;
  PyObject *__pyx_n_s_GiacMethods_base_teal;
  PyObject *__pyx_n_s_GiacMethods_base_tensor_product;
  PyObject *__pyx_n_s_GiacMethods_base_tetrahedron;
  PyObject *__pyx_n_s_GiacMethods_base_texpand;
  PyObject *__pyx_n_s_GiacMethods_base_thickness;
  PyObject *__pyx_n_s_GiacMethods_base_threshold;
  PyObject *__pyx_n_s_GiacMethods_base_throw;
  PyObject *__pyx_n_s_GiacMethods_base_title;
  PyObject *__pyx_n_s_GiacMethods_base_titre;
  PyObject *__pyx_n_s_GiacMethods_base_tlin;
  PyObject *__pyx_n_s_GiacMethods_base_tonnetz;
  PyObject *__pyx_n_s_GiacMethods_base_topologic_sort;
  PyObject *__pyx_n_s_GiacMethods_base_topological_sor;
  PyObject *__pyx_n_s_GiacMethods_base_topology;
  PyObject *__pyx_n_s_GiacMethods_base_torus_grid_grap;
  PyObject *__pyx_n_s_GiacMethods_base_total_degree;
  PyObject *__pyx_n_s_GiacMethods_base_tourne_droite;
  PyObject *__pyx_n_s_GiacMethods_base_tourne_gauche;
  PyObject *__pyx_n_s_GiacMethods_base_tpsolve;
  PyObject *__pyx_n_s_GiacMethods_base_trace;
  PyObject *__pyx_n_s_GiacMethods_base_trail;
  PyObject *__pyx_n_s_GiacMethods_base_trail2edges;
  PyObject *__pyx_n_s_GiacMethods_base_train;
  PyObject *__pyx_n_s_GiacMethods_base_trames;
  PyObject *__pyx_n_s_GiacMethods_base_tran;
  PyObject *__pyx_n_s_GiacMethods_base_transitive_clos;
  PyObject *__pyx_n_s_GiacMethods_base_translation;
  PyObject *__pyx_n_s_GiacMethods_base_transpose;
  PyObject *__pyx_n_s_GiacMethods_base_trapeze;
  PyObject *__pyx_n_s_GiacMethods_base_trapezoid;
  PyObject *__pyx_n_s_GiacMethods_base_traveling_sales;
  PyObject *__pyx_n_s_GiacMethods_base_tree;
  PyObject *__pyx_n_s_GiacMethods_base_tree_height;
  PyObject *__pyx_n_s_GiacMethods_base_tri;
  PyObject *__pyx_n_s_GiacMethods_base_triangle;
  PyObject *__pyx_n_s_GiacMethods_base_triangle_paper;
  PyObject *__pyx_n_s_GiacMethods_base_triangle_plein;
  PyObject *__pyx_n_s_GiacMethods_base_triangle_point;
  PyObject *__pyx_n_s_GiacMethods_base_triangle_window;
  PyObject *__pyx_n_s_GiacMethods_base_trig2exp;
  PyObject *__pyx_n_s_GiacMethods_base_trigcos;
  PyObject *__pyx_n_s_GiacMethods_base_trigexpand;
  PyObject *__pyx_n_s_GiacMethods_base_triginterp;
  PyObject *__pyx_n_s_GiacMethods_base_trigsimplify;
  PyObject *__pyx_n_s_GiacMethods_base_trigsin;
  PyObject *__pyx_n_s_GiacMethods_base_trigtan;
  PyObject *__pyx_n_s_GiacMethods_base_trim;
  PyObject *__pyx_n_s_GiacMethods_base_trn;
  PyObject *__pyx_n_s_GiacMethods_base_true;
  PyObject *__pyx_n_s_GiacMethods_base_trunc;
  PyObject *__pyx_n_s_GiacMethods_base_truncate;
  PyObject *__pyx_n_s_GiacMethods_base_truncate_graph;
  PyObject *__pyx_n_s_GiacMethods_base_tsimplify;
  PyObject *__pyx_n_s_GiacMethods_base_tstep;
  PyObject *__pyx_n_s_GiacMethods_base_tuer;
  PyObject *__pyx_n_s_GiacMethods_base_tukey_window;
  PyObject *__pyx_n_s_GiacMethods_base_tutte_polynomia;
  PyObject *__pyx_n_s_GiacMethods_base_two_edge_connec;
  PyObject *__pyx_n_s_GiacMethods_base_type;
  PyObject *__pyx_n_s_GiacMethods_base_ufactor;
  PyObject *__pyx_n_s_GiacMethods_base_ugamma;
  PyObject *__pyx_n_s_GiacMethods_base_unapply;
  PyObject *__pyx_n_s_GiacMethods_base_unarchive;
  PyObject *__pyx_n_s_GiacMethods_base_undef;
  PyObject *__pyx_n_s_GiacMethods_base_underlying_grap;
  PyObject *__pyx_n_s_GiacMethods_base_unfactored;
  PyObject *__pyx_n_s_GiacMethods_base_uniform;
  PyObject *__pyx_n_s_GiacMethods_base_uniform_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_uniform_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_uniformd;
  PyObject *__pyx_n_s_GiacMethods_base_uniformd_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_uniformd_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_unitV;
  PyObject *__pyx_n_s_GiacMethods_base_unquote;
  PyObject *__pyx_n_s_GiacMethods_base_upper;
  PyObject *__pyx_n_s_GiacMethods_base_user_operator;
  PyObject *__pyx_n_s_GiacMethods_base_usimplify;
  PyObject *__pyx_n_s_GiacMethods_base_ustep;
  PyObject *__pyx_n_s_GiacMethods_base_valuation;
  PyObject *__pyx_n_s_GiacMethods_base_vandermonde;
  PyObject *__pyx_n_s_GiacMethods_base_variables_are_f;
  PyObject *__pyx_n_s_GiacMethods_base_variance;
  PyObject *__pyx_n_s_GiacMethods_base_version;
  PyObject *__pyx_n_s_GiacMethods_base_vertex_connecti;
  PyObject *__pyx_n_s_GiacMethods_base_vertex_cover_nu;
  PyObject *__pyx_n_s_GiacMethods_base_vertex_degree;
  PyObject *__pyx_n_s_GiacMethods_base_vertex_distance;
  PyObject *__pyx_n_s_GiacMethods_base_vertex_in_degre;
  PyObject *__pyx_n_s_GiacMethods_base_vertex_out_degr;
  PyObject *__pyx_n_s_GiacMethods_base_vertices;
  PyObject *__pyx_n_s_GiacMethods_base_vertices_abc;
  PyObject *__pyx_n_s_GiacMethods_base_vertices_abca;
  PyObject *__pyx_n_s_GiacMethods_base_violet;
  PyObject *__pyx_n_s_GiacMethods_base_vpotential;
  PyObject *__pyx_n_s_GiacMethods_base_vstep;
  PyObject *__pyx_n_s_GiacMethods_base_web_graph;
  PyObject *__pyx_n_s_GiacMethods_base_weibull;
  PyObject *__pyx_n_s_GiacMethods_base_weibull_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_weibull_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_weibulld;
  PyObject *__pyx_n_s_GiacMethods_base_weibulld_cdf;
  PyObject *__pyx_n_s_GiacMethods_base_weibulld_icdf;
  PyObject *__pyx_n_s_GiacMethods_base_weibullvariate;
  PyObject *__pyx_n_s_GiacMethods_base_weight_decay;
  PyObject *__pyx_n_s_GiacMethods_base_weight_matrix;
  PyObject *__pyx_n_s_GiacMethods_base_weighted;
  PyObject *__pyx_n_s_GiacMethods_base_weights;
  PyObject *__pyx_n_s_GiacMethods_base_welch_window;
  PyObject *__pyx_n_s_GiacMethods_base_wheel_graph;
  PyObject *__pyx_n_s_GiacMethods_base_widget_size;
  PyObject *__pyx_n_s_GiacMethods_base_wilcoxonp;
  PyObject *__pyx_n_s_GiacMethods_base_wilcoxons;
  PyObject *__pyx_n_s_GiacMethods_base_wilcoxont;
  PyObject *__pyx_n_s_GiacMethods_base_writergb;
  PyObject *__pyx_n_s_GiacMethods_base_writewav;
  PyObject *__pyx_n_s_GiacMethods_base_xcas_mode;
  PyObject *__pyx_n_s_GiacMethods_base_xml_print;
  PyObject *__pyx_n_s_GiacMethods_base_xstep;
  PyObject *__pyx_n_s_GiacMethods_base_xyz2rgb;
  PyObject *__pyx_n_s_GiacMethods_base_xyztrange;
  PyObject *__pyx_n_s_GiacMethods_base_ystep;
  PyObject *__pyx_n_s_GiacMethods_base_zeros;
  PyObject *__pyx_n_s_GiacMethods_base_zip;
  PyObject *__pyx_n_s_GiacMethods_base_znorder;
  PyObject *__pyx_n_s_GiacMethods_base_znprimroot;
  PyObject *__pyx_n_s_GiacMethods_base_zstep;
  PyObject *__pyx_n_s_GiacMethods_base_ztrans;
  PyObject *__pyx_n_s_GiacSetting;
  PyObject *__pyx_n_s_GiacSetting___reduce_cython;
  PyObject *__pyx_n_s_GiacSetting___setstate_cython;
  PyObject *__pyx_kp_s_Giac_Settings;
  PyObject *__pyx_n_s_Graph;
  PyObject *__pyx_n_s_Gy;
  PyObject *__pyx_n_s_H;
  PyObject *__pyx_n_s_Heaviside;
  PyObject *__pyx_n_s_Heaviside2sign;
  PyObject *__pyx_n_s_Hilbert;
  PyObject *__pyx_n_s_Hz;
  PyObject *__pyx_n_s_I;
  PyObject *__pyx_n_s_I0;
  PyObject *__pyx_n_s_IFTE;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_kp_u_Increase_the_size_of_a_matrix_w;
  PyObject *__pyx_n_s_IndexError;
  PyObject *__pyx_n_s_Input;
  PyObject *__pyx_n_s_InputStr;
  PyObject *__pyx_n_s_Int;
  PyObject *__pyx_kp_s_Interrupted_by_a_ctrl_c_event;
  PyObject *__pyx_n_s_Inverse;
  PyObject *__pyx_n_s_J;
  PyObject *__pyx_n_s_JordanBlock;
  PyObject *__pyx_n_s_K;
  PyObject *__pyx_n_s_Kcal;
  PyObject *__pyx_n_s_KeyboardInterrupt;
  PyObject *__pyx_n_s_LN;
  PyObject *__pyx_n_s_LQ;
  PyObject *__pyx_n_s_LSQ;
  PyObject *__pyx_n_s_LU;
  PyObject *__pyx_n_s_LambertW;
  PyObject *__pyx_n_s_Li;
  PyObject *__pyx_n_s_Line;
  PyObject *__pyx_n_s_LineHorz;
  PyObject *__pyx_n_s_LineTan;
  PyObject *__pyx_n_s_LineVert;
  PyObject *__pyx_kp_u_Lists_of_10_6_integers_should_b;
  PyObject *__pyx_n_s_MHz;
  PyObject *__pyx_n_s_MSE;
  PyObject *__pyx_n_s_MW;
  PyObject *__pyx_n_s_MeV;
  PyObject *__pyx_n_s_N;
  PyObject *__pyx_n_s_NA;
  PyObject *__pyx_n_s_NORMALD;
  PyObject *__pyx_n_s_NULL;
  PyObject *__pyx_n_s_NewFold;
  PyObject *__pyx_n_s_NewPic;
  PyObject *__pyx_n_s_Nullspace;
  PyObject *__pyx_n_s_Ohm;
  PyObject *__pyx_kp_u_Open_a_file_in_giac_compressed;
  PyObject *__pyx_kp_u_Open_the_giac_html_detailled_he;
  PyObject *__pyx_kp_u_Open_the_giac_html_detailled_he_2;
  PyObject *__pyx_n_s_Output;
  PyObject *__pyx_n_s_Ox_2d_unit_vector;
  PyObject *__pyx_n_s_Ox_3d_unit_vector;
  PyObject *__pyx_n_s_Oy_2d_unit_vector;
  PyObject *__pyx_n_s_Oy_3d_unit_vector;
  PyObject *__pyx_n_s_Oz_3d_unit_vector;
  PyObject *__pyx_n_s_P;
  PyObject *__pyx_n_s_PSun;
  PyObject *__pyx_n_s_Pa;
  PyObject *__pyx_n_s_Pause;
  PyObject *__pyx_n_s_Phi;
  PyObject *__pyx_n_s_Pi;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_s_PopUp;
  PyObject *__pyx_n_s_Psi;
  PyObject *__pyx_n_s_Pygen;
  PyObject *__pyx_kp_u_Pygen___float___line_1078;
  PyObject *__pyx_kp_u_Pygen___getitem___line_913;
  PyObject *__pyx_kp_u_Pygen___int___line_1059;
  PyObject *__pyx_n_s_Pygen___iter;
  PyObject *__pyx_kp_u_Pygen___iter___line_1035;
  PyObject *__pyx_kp_u_Pygen___radd___line_1192;
  PyObject *__pyx_n_s_Pygen___reduce_cython;
  PyObject *__pyx_kp_u_Pygen___repr___line_877;
  PyObject *__pyx_kp_u_Pygen___rmod___line_1410;
  PyObject *__pyx_kp_u_Pygen___rmul___line_1286;
  PyObject *__pyx_kp_u_Pygen___rpow___line_1372;
  PyObject *__pyx_kp_u_Pygen___rsub___line_1248;
  PyObject *__pyx_kp_u_Pygen___rtruediv___line_1337;
  PyObject *__pyx_kp_u_Pygen___setitem___line_986;
  PyObject *__pyx_n_s_Pygen___setstate_cython;
  PyObject *__pyx_n_s_Pygen__repr_html;
  PyObject *__pyx_n_s_Pygen__repr_latex;
  PyObject *__pyx_n_s_Pygen_cas_setup;
  PyObject *__pyx_n_s_Pygen_eval;
  PyObject *__pyx_n_s_Pygen_help;
  PyObject *__pyx_n_s_Pygen_htmlhelp;
  PyObject *__pyx_kp_u_Pygen_htmlhelp_line_1498;
  PyObject *__pyx_kp_u_Pygen_lists_of_10_6_elements_sh;
  PyObject *__pyx_n_s_Pygen_qcas;
  PyObject *__pyx_kp_u_Pygen_qcas_line_1552;
  PyObject *__pyx_n_s_Pygen_redim;
  PyObject *__pyx_kp_u_Pygen_redim_line_1526;
  PyObject *__pyx_n_s_Pygen_save;
  PyObject *__pyx_kp_u_Pygen_save_line_1469;
  PyObject *__pyx_n_s_Pygen_threadeval;
  PyObject *__pyx_n_s_Pymaxint;
  PyObject *__pyx_n_s_PythonVersion3;
  PyObject *__pyx_n_s_Pyversioninfo;
  PyObject *__pyx_n_s_QR;
  PyObject *__pyx_n_s_Quo;
  PyObject *__pyx_n_s_R;
  PyObject *__pyx_n_s_REDIM;
  PyObject *__pyx_n_s_REPLACE;
  PyObject *__pyx_n_s_REarth;
  PyObject *__pyx_n_s_RSun;
  PyObject *__pyx_n_s_R_2;
  PyObject *__pyx_n_s_RandSeed;
  PyObject *__pyx_n_s_Rankine;
  PyObject *__pyx_n_s_RclPic;
  PyObject *__pyx_n_s_ReLU;
  PyObject *__pyx_n_s_Rem;
  PyObject *__pyx_n_s_Request;
  PyObject *__pyx_kp_s_Result_is_too_big_for_Display_I;
  PyObject *__pyx_n_s_Resultant;
  PyObject *__pyx_kp_u_Reverse_operator_7_giac_3_Calle;
  PyObject *__pyx_kp_u_Reverse_operator_d_giac_d_1_d_C;
  PyObject *__pyx_kp_u_Reverse_operator_d_giac_d_2_d_C;
  PyObject *__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C;
  PyObject *__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2;
  PyObject *__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3;
  PyObject *__pyx_n_s_Rinfinity;
  PyObject *__pyx_n_s_Row;
  PyObject *__pyx_n_s_RplcPic;
  PyObject *__pyx_n_s_Rref;
  PyObject *__pyx_n_s_RuntimeError;
  PyObject *__pyx_n_s_S;
  PyObject *__pyx_n_s_SCALE;
  PyObject *__pyx_n_s_SCALEADD;
  PyObject *__pyx_n_s_SCHUR;
  PyObject *__pyx_n_s_SIN;
  PyObject *__pyx_n_s_SVD;
  PyObject *__pyx_n_s_SVL;
  PyObject *__pyx_n_s_SWAPCOL;
  PyObject *__pyx_n_s_SWAPROW;
  PyObject *__pyx_kp_u_Send_a_giac_graphic_to_qcas_3D;
  PyObject *__pyx_n_s_SetFold;
  PyObject *__pyx_kp_u_Set_the_value_of_a_coefficient;
  PyObject *__pyx_n_s_Si;
  PyObject *__pyx_n_s_SortA;
  PyObject *__pyx_n_s_SortD;
  PyObject *__pyx_n_s_St;
  PyObject *__pyx_n_s_StdP;
  PyObject *__pyx_n_s_StdT;
  PyObject *__pyx_n_s_StoPic;
  PyObject *__pyx_n_s_Store;
  PyObject *__pyx_n_s_Sv;
  PyObject *__pyx_n_s_T;
  PyObject *__pyx_n_s_TAN;
  PyObject *__pyx_n_s_TRUE;
  PyObject *__pyx_n_s_TeX;
  PyObject *__pyx_n_s_Text;
  PyObject *__pyx_kp_u_This_function_evaluate_a_python;
  PyObject *__pyx_n_s_ThreadedPygen;
  PyObject *__pyx_n_s_ThreadedPygen___call;
  PyObject *__pyx_n_s_Title;
  PyObject *__pyx_n_s_True;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_kp_s_UTF_8;
  PyObject *__pyx_n_s_UTPC;
  PyObject *__pyx_n_s_UTPF;
  PyObject *__pyx_n_s_UTPN;
  PyObject *__pyx_n_s_UTPT;
  PyObject *__pyx_n_s_Unarchiv;
  PyObject *__pyx_kp_s_Use_this_subclass_of_to_call_yo;
  PyObject *__pyx_n_s_V;
  PyObject *__pyx_n_s_VARS;
  PyObject *__pyx_n_s_VAS;
  PyObject *__pyx_n_s_VAS_positive;
  PyObject *__pyx_n_s_Vm;
  PyObject *__pyx_n_s_W;
  PyObject *__pyx_n_s_WAIT;
  PyObject *__pyx_n_s_Wb;
  PyObject *__pyx_n_s_Wh;
  PyObject *__pyx_n_s_Zeta;
  PyObject *__pyx_kp_s__10;
  PyObject *__pyx_kp_s__12;
  PyObject *__pyx_n_s__14;
  PyObject *__pyx_kp_s__1655;
  PyObject *__pyx_kp_s__1656;
  PyObject *__pyx_kp_s__1657;
  PyObject *__pyx_kp_s__1658;
  PyObject *__pyx_kp_s__1659;
  PyObject *__pyx_kp_s__1660;
  PyObject *__pyx_kp_s__1661;
  PyObject *__pyx_kp_s__1662;
  PyObject *__pyx_kp_s__1663;
  PyObject *__pyx_kp_s__1664;
  PyObject *__pyx_kp_s__1665;
  PyObject *__pyx_kp_s__1666;
  PyObject *__pyx_kp_s__1667;
  PyObject *__pyx_kp_s__1668;
  PyObject *__pyx_kp_s__1669;
  PyObject *__pyx_kp_s__1670;
  PyObject *__pyx_kp_s__1671;
  PyObject *__pyx_kp_s__1672;
  PyObject *__pyx_kp_s__1673;
  PyObject *__pyx_kp_s__1674;
  PyObject *__pyx_kp_s__1675;
  PyObject *__pyx_kp_s__1676;
  PyObject *__pyx_kp_s__1677;
  PyObject *__pyx_kp_s__1678;
  PyObject *__pyx_kp_s__1679;
  PyObject *__pyx_kp_s__1680;
  PyObject *__pyx_kp_s__1681;
  PyObject *__pyx_kp_s__1682;
  PyObject *__pyx_kp_s__1683;
  PyObject *__pyx_kp_s__1684;
  PyObject *__pyx_kp_s__1685;
  PyObject *__pyx_kp_s__1686;
  PyObject *__pyx_kp_s__1687;
  PyObject *__pyx_kp_s__1688;
  PyObject *__pyx_kp_s__1689;
  PyObject *__pyx_kp_s__1690;
  PyObject *__pyx_kp_s__1691;
  PyObject *__pyx_kp_s__1692;
  PyObject *__pyx_kp_s__1693;
  PyObject *__pyx_kp_s__1694;
  PyObject *__pyx_kp_s__1695;
  PyObject *__pyx_kp_s__1696;
  PyObject *__pyx_kp_s__1697;
  PyObject *__pyx_kp_s__1698;
  PyObject *__pyx_kp_s__1699;
  PyObject *__pyx_kp_s__1700;
  PyObject *__pyx_kp_u__8;
  PyObject *__pyx_n_s_a;
  PyObject *__pyx_n_s_a0;
  PyObject *__pyx_n_s_a2q;
  PyObject *__pyx_n_s_a_2;
  PyObject *__pyx_n_s_abcuv;
  PyObject *__pyx_n_s_about;
  PyObject *__pyx_n_s_abs;
  PyObject *__pyx_n_s_abscissa;
  PyObject *__pyx_n_s_access;
  PyObject *__pyx_n_s_accumulate_head_tail;
  PyObject *__pyx_n_s_acos;
  PyObject *__pyx_n_s_acos2asin;
  PyObject *__pyx_n_s_acos2atan;
  PyObject *__pyx_n_s_acosh;
  PyObject *__pyx_n_s_acot;
  PyObject *__pyx_n_s_acre;
  PyObject *__pyx_n_s_acsc;
  PyObject *__pyx_n_s_acyclic;
  PyObject *__pyx_n_s_adaptive;
  PyObject *__pyx_n_s_add;
  PyObject *__pyx_n_s_add_2;
  PyObject *__pyx_n_s_add_arc;
  PyObject *__pyx_n_s_add_edge;
  PyObject *__pyx_kp_s_add_language_1;
  PyObject *__pyx_n_s_add_vertex;
  PyObject *__pyx_n_s_additionally;
  PyObject *__pyx_n_s_addtable;
  PyObject *__pyx_n_s_adjacency_matrix;
  PyObject *__pyx_n_s_adjoint_matrix;
  PyObject *__pyx_n_s_affichage;
  PyObject *__pyx_n_s_affix;
  PyObject *__pyx_n_s_algsubs;
  PyObject *__pyx_n_s_algvar;
  PyObject *__pyx_n_s_all;
  PyObject *__pyx_n_s_all_trig_solutions;
  PyObject *__pyx_n_s_allpairs_distance;
  PyObject *__pyx_n_s_alog10;
  PyObject *__pyx_n_s_alors;
  PyObject *__pyx_n_s_alpha;
  PyObject *__pyx_n_s_altitude;
  PyObject *__pyx_n_s_and;
  PyObject *__pyx_n_s_angl;
  PyObject *__pyx_n_s_angle;
  PyObject *__pyx_n_s_angle_radian;
  PyObject *__pyx_n_s_angleat;
  PyObject *__pyx_n_s_angleatraw;
  PyObject *__pyx_n_s_animate;
  PyObject *__pyx_n_s_animate3d;
  PyObject *__pyx_n_s_animation;
  PyObject *__pyx_n_s_ans;
  PyObject *__pyx_n_s_antiprism_graph;
  PyObject *__pyx_n_s_append;
  PyObject *__pyx_n_s_apply;
  PyObject *__pyx_n_s_approx;
  PyObject *__pyx_n_s_approx_mode;
  PyObject *__pyx_n_s_arc;
  PyObject *__pyx_n_s_arcLen;
  PyObject *__pyx_n_s_arccos;
  PyObject *__pyx_n_s_arccosh;
  PyObject *__pyx_n_s_archive;
  PyObject *__pyx_n_s_arclen;
  PyObject *__pyx_n_s_arcmin;
  PyObject *__pyx_n_s_arcs;
  PyObject *__pyx_n_s_arcsin;
  PyObject *__pyx_n_s_arcsinh;
  PyObject *__pyx_n_s_arctan;
  PyObject *__pyx_n_s_arctanh;
  PyObject *__pyx_n_s_area;
  PyObject *__pyx_n_s_areaat;
  PyObject *__pyx_n_s_areaatraw;
  PyObject *__pyx_n_s_areaplot;
  PyObject *__pyx_n_s_arg;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_kp_s_argument_must_be_a_Pygen_list_an;
  PyObject *__pyx_kp_s_argument_must_be_a_tuple_or_a_li;
  PyObject *__pyx_n_s_array;
  PyObject *__pyx_n_s_arrivals;
  PyObject *__pyx_n_s_articulation_points;
  PyObject *__pyx_n_s_as_function_of;
  PyObject *__pyx_n_s_asc;
  PyObject *__pyx_n_s_asec;
  PyObject *__pyx_n_s_asin;
  PyObject *__pyx_n_s_asin2acos;
  PyObject *__pyx_n_s_asin2atan;
  PyObject *__pyx_n_s_asinh;
  PyObject *__pyx_n_s_assert;
  PyObject *__pyx_n_s_assign;
  PyObject *__pyx_n_s_assign_edge_weights;
  PyObject *__pyx_n_s_assume;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_at;
  PyObject *__pyx_n_s_atan;
  PyObject *__pyx_n_s_atan2;
  PyObject *__pyx_n_s_atan2acos;
  PyObject *__pyx_n_s_atan2asin;
  PyObject *__pyx_n_s_atanh;
  PyObject *__pyx_n_s_atm;
  PyObject *__pyx_n_s_atrig2ln;
  PyObject *__pyx_n_s_au;
  PyObject *__pyx_n_s_augment;
  PyObject *__pyx_n_s_auto_correlation;
  PyObject *__pyx_n_s_autosimplify;
  PyObject *__pyx_n_s_avance;
  PyObject *__pyx_n_s_avgRC;
  PyObject *__pyx_n_s_axes;
  PyObject *__pyx_n_s_axis;
  PyObject *__pyx_n_s_b;
  PyObject *__pyx_n_s_b_2;
  PyObject *__pyx_n_s_back;
  PyObject *__pyx_n_s_backquote;
  PyObject *__pyx_n_s_backward;
  PyObject *__pyx_n_s_baisse_crayon;
  PyObject *__pyx_n_s_bandwidth;
  PyObject *__pyx_n_s_bar;
  PyObject *__pyx_n_s_bar_plot;
  PyObject *__pyx_n_s_barplot;
  PyObject *__pyx_n_s_bartlett_hann_window;
  PyObject *__pyx_n_s_barycenter;
  PyObject *__pyx_n_s_base;
  PyObject *__pyx_n_s_basis;
  PyObject *__pyx_n_s_batons;
  PyObject *__pyx_n_s_bbl;
  PyObject *__pyx_n_s_bblep;
  PyObject *__pyx_n_s_begin;
  PyObject *__pyx_n_s_bellman_ford;
  PyObject *__pyx_n_s_berlekamp_massey;
  PyObject *__pyx_n_s_bernoulli;
  PyObject *__pyx_n_s_bernoulli_mod;
  PyObject *__pyx_n_s_besselJ;
  PyObject *__pyx_n_s_besselY;
  PyObject *__pyx_n_s_betad;
  PyObject *__pyx_n_s_betad_cdf;
  PyObject *__pyx_n_s_betad_icdf;
  PyObject *__pyx_n_s_betavariate;
  PyObject *__pyx_n_s_betweenness_centrality;
  PyObject *__pyx_n_s_bezier;
  PyObject *__pyx_n_s_bezout_entiers;
  PyObject *__pyx_n_s_bezoutian;
  PyObject *__pyx_n_s_biconnected_components;
  PyObject *__pyx_n_s_binomial;
  PyObject *__pyx_n_s_binomial_cdf;
  PyObject *__pyx_n_s_binomial_icdf;
  PyObject *__pyx_n_s_bins;
  PyObject *__pyx_n_s_bipartite;
  PyObject *__pyx_n_s_bipartite_matching;
  PyObject *__pyx_n_s_bisection_solver;
  PyObject *__pyx_n_s_bisector;
  PyObject *__pyx_n_s_bit_depth;
  PyObject *__pyx_n_s_bit_length;
  PyObject *__pyx_n_s_bitand;
  PyObject *__pyx_n_s_bitor;
  PyObject *__pyx_n_s_bitxor;
  PyObject *__pyx_n_s_black;
  PyObject *__pyx_n_s_blacklist;
  PyObject *__pyx_n_s_blackman_harris_window;
  PyObject *__pyx_n_s_blackman_window;
  PyObject *__pyx_n_s_blanc;
  PyObject *__pyx_n_s_bleu;
  PyObject *__pyx_n_s_bloc;
  PyObject *__pyx_n_s_block_size;
  PyObject *__pyx_n_s_blockmatrix;
  PyObject *__pyx_n_s_blue;
  PyObject *__pyx_n_s_bohman_window;
  PyObject *__pyx_n_s_border;
  PyObject *__pyx_n_s_box_constraints;
  PyObject *__pyx_n_s_boxcar;
  PyObject *__pyx_n_s_boxwhisker;
  PyObject *__pyx_n_s_break;
  PyObject *__pyx_n_s_breakpoint;
  PyObject *__pyx_n_s_brent_solver;
  PyObject *__pyx_n_s_brown;
  PyObject *__pyx_n_s_bspline;
  PyObject *__pyx_n_s_bu;
  PyObject *__pyx_n_s_buUS;
  PyObject *__pyx_n_s_builtins;
  PyObject *__pyx_n_s_bvpsolve;
  PyObject *__pyx_n_s_by;
  PyObject *__pyx_n_s_c;
  PyObject *__pyx_n_s_c1oc2;
  PyObject *__pyx_n_s_c1op2;
  PyObject *__pyx_n_s_c3;
  PyObject *__pyx_n_s_cFactor;
  PyObject *__pyx_n_s_cSolve;
  PyObject *__pyx_n_s_cZeros;
  PyObject *__pyx_n_s_cache_tortue;
  PyObject *__pyx_n_s_cal;
  PyObject *__pyx_n_s_call;
  PyObject *__pyx_n_s_camembert;
  PyObject *__pyx_n_s_canonical_form;
  PyObject *__pyx_n_s_canonical_labeling;
  PyObject *__pyx_n_s_cap;
  PyObject *__pyx_n_s_cap_flat_line;
  PyObject *__pyx_n_s_cap_round_line;
  PyObject *__pyx_n_s_cap_square_line;
  PyObject *__pyx_n_s_cartesian_product;
  PyObject *__pyx_kp_s_cas_monitor_status;
  PyObject *__pyx_kp_s_cas_monitor_status_after_killing;
  PyObject *__pyx_n_s_cas_setup;
  PyObject *__pyx_kp_s_cas_setup_2;
  PyObject *__pyx_kp_s_cas_setup_s;
  PyObject *__pyx_kp_s_cascmd;
  PyObject *__pyx_n_s_case;
  PyObject *__pyx_n_s_cat;
  PyObject *__pyx_n_s_catch;
  PyObject *__pyx_n_s_cauchy;
  PyObject *__pyx_n_s_cauchy_cdf;
  PyObject *__pyx_n_s_cauchy_icdf;
  PyObject *__pyx_n_s_cauchyd;
  PyObject *__pyx_n_s_cauchyd_cdf;
  PyObject *__pyx_n_s_cauchyd_icdf;
  PyObject *__pyx_n_s_cd;
  PyObject *__pyx_n_s_cd_2;
  PyObject *__pyx_n_s_cdf;
  PyObject *__pyx_n_s_ceil;
  PyObject *__pyx_n_s_ceiling;
  PyObject *__pyx_n_s_center;
  PyObject *__pyx_n_s_center2interval;
  PyObject *__pyx_n_s_centered_cube;
  PyObject *__pyx_n_s_centered_tetrahedron;
  PyObject *__pyx_n_s_cfactor;
  PyObject *__pyx_n_s_cfsolve;
  PyObject *__pyx_n_s_chain;
  PyObject *__pyx_n_s_changebase;
  PyObject *__pyx_n_s_channel_data;
  PyObject *__pyx_n_s_channels;
  PyObject *__pyx_n_s_char;
  PyObject *__pyx_n_s_charpoly;
  PyObject *__pyx_n_s_chinrem;
  PyObject *__pyx_n_s_chisquare;
  PyObject *__pyx_n_s_chisquare_cdf;
  PyObject *__pyx_n_s_chisquare_icdf;
  PyObject *__pyx_n_s_chisquared;
  PyObject *__pyx_n_s_chisquared_cdf;
  PyObject *__pyx_n_s_chisquared_icdf;
  PyObject *__pyx_n_s_chisquaret;
  PyObject *__pyx_n_s_choice;
  PyObject *__pyx_n_s_cholesky;
  PyObject *__pyx_n_s_choosebox;
  PyObject *__pyx_n_s_chr;
  PyObject *__pyx_n_s_chrem;
  PyObject *__pyx_n_s_chromatic_index;
  PyObject *__pyx_n_s_chromatic_number;
  PyObject *__pyx_n_s_chromatic_polynomial;
  PyObject *__pyx_n_s_circle;
  PyObject *__pyx_n_s_circumcircle;
  PyObject *__pyx_n_s_class;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_classes;
  PyObject *__pyx_n_s_clear;
  PyObject *__pyx_n_s_click;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_clique_cover;
  PyObject *__pyx_n_s_clique_cover_number;
  PyObject *__pyx_n_s_clique_number;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_closeness_centrality;
  PyObject *__pyx_n_s_cluster;
  PyObject *__pyx_n_s_clustering_coefficient;
  PyObject *__pyx_n_s_cm;
  PyObject *__pyx_kp_s_cm_2;
  PyObject *__pyx_kp_s_cm_3;
  PyObject *__pyx_kp_s_cm_s;
  PyObject *__pyx_n_s_coeff;
  PyObject *__pyx_n_s_coeffs;
  PyObject *__pyx_n_s_col;
  PyObject *__pyx_n_s_colDim;
  PyObject *__pyx_n_s_colNorm;
  PyObject *__pyx_n_s_colSwap;
  PyObject *__pyx_n_s_coldim;
  PyObject *__pyx_n_s_collect;
  PyObject *__pyx_n_s_colnorm;
  PyObject *__pyx_n_s_color;
  PyObject *__pyx_n_s_colormap;
  PyObject *__pyx_n_s_colspace;
  PyObject *__pyx_n_s_colswap;
  PyObject *__pyx_n_s_comDenom;
  PyObject *__pyx_n_s_comb;
  PyObject *__pyx_n_s_combine;
  PyObject *__pyx_n_s_comment;
  PyObject *__pyx_n_s_common_perpendicular;
  PyObject *__pyx_n_s_companion;
  PyObject *__pyx_n_s_compare;
  PyObject *__pyx_n_s_complete_binary_tree;
  PyObject *__pyx_n_s_complete_graph;
  PyObject *__pyx_n_s_complete_kary_tree;
  PyObject *__pyx_n_s_complex;
  PyObject *__pyx_n_s_complex_mode;
  PyObject *__pyx_n_s_complex_variables;
  PyObject *__pyx_n_s_complexroot;
  PyObject *__pyx_n_s_concat;
  PyObject *__pyx_n_s_cond;
  PyObject *__pyx_n_s_condensation;
  PyObject *__pyx_n_s_condi;
  PyObject *__pyx_n_s_cone;
  PyObject *__pyx_n_s_confrac;
  PyObject *__pyx_n_s_conic;
  PyObject *__pyx_n_s_conj;
  PyObject *__pyx_n_s_conjugate_equation;
  PyObject *__pyx_n_s_conjugate_gradient;
  PyObject *__pyx_n_s_connected;
  PyObject *__pyx_n_s_connected_components;
  PyObject *__pyx_n_s_cont;
  PyObject *__pyx_n_s_contains;
  PyObject *__pyx_n_s_content;
  PyObject *__pyx_n_s_context_ptr;
  PyObject *__pyx_n_s_continue;
  PyObject *__pyx_n_s_contourplot;
  PyObject *__pyx_n_s_contract_edge;
  PyObject *__pyx_n_s_contract_subgraph;
  PyObject *__pyx_n_s_convert;
  PyObject *__pyx_n_s_convertir;
  PyObject *__pyx_n_s_convex;
  PyObject *__pyx_n_s_convexhull;
  PyObject *__pyx_n_s_convolution;
  PyObject *__pyx_n_s_coordinates;
  PyObject *__pyx_n_s_copy;
  PyObject *__pyx_n_s_correlation;
  PyObject *__pyx_n_s_cos;
  PyObject *__pyx_n_s_cos2sintan;
  PyObject *__pyx_n_s_cosh;
  PyObject *__pyx_n_s_cosine_window;
  PyObject *__pyx_n_s_cot;
  PyObject *__pyx_n_s_cote;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_count_eq;
  PyObject *__pyx_n_s_count_inf;
  PyObject *__pyx_n_s_count_sup;
  PyObject *__pyx_n_s_courbe_parametrique;
  PyObject *__pyx_n_s_courbe_polaire;
  PyObject *__pyx_n_s_covariance;
  PyObject *__pyx_n_s_covariance_correlation;
  PyObject *__pyx_n_s_cpartfrac;
  PyObject *__pyx_n_s_crationalroot;
  PyObject *__pyx_n_s_crayon;
  PyObject *__pyx_n_s_createwav;
  PyObject *__pyx_n_s_cross;
  PyObject *__pyx_n_s_crossP;
  PyObject *__pyx_n_s_cross_correlation;
  PyObject *__pyx_n_s_cross_entropy;
  PyObject *__pyx_n_s_cross_point;
  PyObject *__pyx_n_s_cross_ratio;
  PyObject *__pyx_n_s_crossproduct;
  PyObject *__pyx_n_s_csc;
  PyObject *__pyx_n_s_csolve;
  PyObject *__pyx_n_s_csv2gen;
  PyObject *__pyx_n_s_ct;
  PyObject *__pyx_n_s_cu;
  PyObject *__pyx_n_s_cube;
  PyObject *__pyx_n_s_cumSum;
  PyObject *__pyx_n_s_cumsum;
  PyObject *__pyx_n_s_cumulated_frequencies;
  PyObject *__pyx_n_s_curl;
  PyObject *__pyx_n_s_current_sheet;
  PyObject *__pyx_n_s_curvature;
  PyObject *__pyx_n_s_curve;
  PyObject *__pyx_n_s_cyan;
  PyObject *__pyx_n_s_cycle2perm;
  PyObject *__pyx_n_s_cycle_basis;
  PyObject *__pyx_n_s_cycle_graph;
  PyObject *__pyx_n_s_cycleinv;
  PyObject *__pyx_n_s_cycles2permu;
  PyObject *__pyx_n_s_cyclotomic;
  PyObject *__pyx_n_s_cylinder;
  PyObject *__pyx_n_s_d;
  PyObject *__pyx_n_s_dB;
  PyObject *__pyx_n_s_d_2;
  PyObject *__pyx_n_s_dash_line;
  PyObject *__pyx_n_s_dashdot_line;
  PyObject *__pyx_n_s_dashdotdot_line;
  PyObject *__pyx_n_s_dayofweek;
  PyObject *__pyx_n_s_de;
  PyObject *__pyx_n_s_deSolve;
  PyObject *__pyx_n_s_debug;
  PyObject *__pyx_n_s_debut_enregistrement;
  PyObject *__pyx_n_s_decode;
  PyObject *__pyx_n_s_decstring23;
  PyObject *__pyx_n_s_default;
  PyObject *__pyx_n_s_deg;
  PyObject *__pyx_n_s_degree;
  PyObject *__pyx_n_s_degreeF;
  PyObject *__pyx_n_s_degree_centrality;
  PyObject *__pyx_n_s_degree_sequence;
  PyObject *__pyx_n_s_degrees;
  PyObject *__pyx_n_s_del;
  PyObject *__pyx_n_s_delcols;
  PyObject *__pyx_n_s_delete_arc;
  PyObject *__pyx_n_s_delete_edge;
  PyObject *__pyx_n_s_delete_vertex;
  PyObject *__pyx_n_s_delrows;
  PyObject *__pyx_n_s_deltalist;
  PyObject *__pyx_n_s_denom;
  PyObject *__pyx_n_s_densityplot;
  PyObject *__pyx_n_s_departures;
  PyObject *__pyx_n_s_derive;
  PyObject *__pyx_n_s_deriver;
  PyObject *__pyx_n_s_desolve;
  PyObject *__pyx_n_s_dessine_tortue;
  PyObject *__pyx_n_s_det;
  PyObject *__pyx_n_s_det_minor;
  PyObject *__pyx_n_s_developper;
  PyObject *__pyx_n_s_developper_transcendant;
  PyObject *__pyx_n_s_dfc;
  PyObject *__pyx_n_s_dfc2f;
  PyObject *__pyx_n_s_diag;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_n_s_diff;
  PyObject *__pyx_n_s_digraph;
  PyObject *__pyx_n_s_dijkstra;
  PyObject *__pyx_n_s_dim;
  PyObject *__pyx_n_s_directed;
  PyObject *__pyx_n_s_directevalued;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_discard_edge_attribute;
  PyObject *__pyx_n_s_discard_graph_attribute;
  PyObject *__pyx_n_s_discard_vertex_attribute;
  PyObject *__pyx_n_s_disjoint_union;
  PyObject *__pyx_n_s_display;
  PyObject *__pyx_n_s_disque;
  PyObject *__pyx_n_s_disque_centre;
  PyObject *__pyx_n_s_distance;
  PyObject *__pyx_n_s_distance2;
  PyObject *__pyx_n_s_distanceat;
  PyObject *__pyx_n_s_distanceatraw;
  PyObject *__pyx_n_s_div;
  PyObject *__pyx_n_s_div_2;
  PyObject *__pyx_n_s_divergence;
  PyObject *__pyx_n_s_divide;
  PyObject *__pyx_n_s_divis;
  PyObject *__pyx_n_s_division_point;
  PyObject *__pyx_n_s_divisors;
  PyObject *__pyx_n_s_divmod;
  PyObject *__pyx_n_s_divpc;
  PyObject *__pyx_n_s_dnewton_solver;
  PyObject *__pyx_n_s_do;
  PyObject *__pyx_kp_s_doc;
  PyObject *__pyx_n_s_doc_2;
  PyObject *__pyx_n_s_dodecahedron;
  PyObject *__pyx_n_s_domain;
  PyObject *__pyx_n_s_dot;
  PyObject *__pyx_n_s_dotP;
  PyObject *__pyx_n_s_dot_paper;
  PyObject *__pyx_n_s_dotprod;
  PyObject *__pyx_n_s_double;
  PyObject *__pyx_n_s_double_2;
  PyObject *__pyx_n_s_draw_arc;
  PyObject *__pyx_n_s_draw_circle;
  PyObject *__pyx_n_s_draw_graph;
  PyObject *__pyx_n_s_draw_line;
  PyObject *__pyx_n_s_draw_pixel;
  PyObject *__pyx_n_s_draw_polygon;
  PyObject *__pyx_n_s_draw_rectangle;
  PyObject *__pyx_n_s_droit;
  PyObject *__pyx_n_s_droite_tangente;
  PyObject *__pyx_n_s_dsolve;
  PyObject *__pyx_n_s_duration;
  PyObject *__pyx_n_s_dwt;
  PyObject *__pyx_n_s_dyn;
  PyObject *__pyx_n_s_e;
  PyObject *__pyx_n_s_e2r;
  PyObject *__pyx_n_s_eV;
  PyObject *__pyx_n_s_ecart_type;
  PyObject *__pyx_n_s_ecart_type_population;
  PyObject *__pyx_n_s_ecef2geodetic;
  PyObject *__pyx_n_s_ecm_factor;
  PyObject *__pyx_n_s_ecris;
  PyObject *__pyx_n_s_edge_connectivity;
  PyObject *__pyx_n_s_edges;
  PyObject *__pyx_n_s_efface;
  PyObject *__pyx_n_s_egcd;
  PyObject *__pyx_n_s_egv;
  PyObject *__pyx_n_s_egvl;
  PyObject *__pyx_n_s_eigVc;
  PyObject *__pyx_n_s_eigVl;
  PyObject *__pyx_n_s_eigenvals;
  PyObject *__pyx_n_s_eigenvalues;
  PyObject *__pyx_n_s_eigenvectors;
  PyObject *__pyx_n_s_eigenvects;
  PyObject *__pyx_n_s_el;
  PyObject *__pyx_n_s_element;
  PyObject *__pyx_n_s_elif;
  PyObject *__pyx_n_s_eliminate;
  PyObject *__pyx_n_s_ellipse;
  PyObject *__pyx_n_s_else;
  PyObject *__pyx_n_s_emd;
  PyObject *__pyx_n_s_en;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_encstring23;
  PyObject *__pyx_n_s_end;
  PyObject *__pyx_n_s_end_for;
  PyObject *__pyx_n_s_end_if;
  PyObject *__pyx_n_s_end_while;
  PyObject *__pyx_n_s_entry;
  PyObject *__pyx_n_s_envelope;
  PyObject *__pyx_n_s_epaisseur;
  PyObject *__pyx_n_s_epaisseur_ligne_1;
  PyObject *__pyx_n_s_epaisseur_ligne_2;
  PyObject *__pyx_n_s_epaisseur_ligne_3;
  PyObject *__pyx_n_s_epaisseur_ligne_4;
  PyObject *__pyx_n_s_epaisseur_ligne_5;
  PyObject *__pyx_n_s_epaisseur_ligne_6;
  PyObject *__pyx_n_s_epaisseur_ligne_7;
  PyObject *__pyx_n_s_epaisseur_point_1;
  PyObject *__pyx_n_s_epaisseur_point_2;
  PyObject *__pyx_n_s_epaisseur_point_3;
  PyObject *__pyx_n_s_epaisseur_point_4;
  PyObject *__pyx_n_s_epaisseur_point_5;
  PyObject *__pyx_n_s_epaisseur_point_6;
  PyObject *__pyx_n_s_epaisseur_point_7;
  PyObject *__pyx_n_s_epsilon;
  PyObject *__pyx_n_s_epsilon0;
  PyObject *__pyx_n_s_epsilon0q;
  PyObject *__pyx_n_s_epsilon2zero;
  PyObject *__pyx_n_s_epsilonox;
  PyObject *__pyx_n_s_epsilonsi;
  PyObject *__pyx_n_s_equal;
  PyObject *__pyx_n_s_equal2diff;
  PyObject *__pyx_n_s_equal2list;
  PyObject *__pyx_n_s_equation;
  PyObject *__pyx_n_s_equilateral_triangle;
  PyObject *__pyx_n_s_erase;
  PyObject *__pyx_n_s_erase3d;
  PyObject *__pyx_n_s_erf;
  PyObject *__pyx_n_s_erfc;
  PyObject *__pyx_n_s_erg;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_n_s_est_cocyclique;
  PyObject *__pyx_n_s_est_inclus;
  PyObject *__pyx_n_s_est_permu;
  PyObject *__pyx_n_s_et;
  PyObject *__pyx_n_s_euler;
  PyObject *__pyx_n_s_euler_gamma;
  PyObject *__pyx_n_s_euler_lagrange;
  PyObject *__pyx_n_s_eval;
  PyObject *__pyx_n_s_eval_level;
  PyObject *__pyx_n_s_evala;
  PyObject *__pyx_n_s_evalb;
  PyObject *__pyx_n_s_evalc;
  PyObject *__pyx_n_s_evalf;
  PyObject *__pyx_n_s_evalm;
  PyObject *__pyx_n_s_even;
  PyObject *__pyx_n_s_evolute;
  PyObject *__pyx_n_s_exact;
  PyObject *__pyx_n_s_exbisector;
  PyObject *__pyx_n_s_excircle;
  PyObject *__pyx_n_s_execute;
  PyObject *__pyx_n_s_exp;
  PyObject *__pyx_n_s_exp2list;
  PyObject *__pyx_n_s_exp2pow;
  PyObject *__pyx_n_s_exp2trig;
  PyObject *__pyx_n_s_expand;
  PyObject *__pyx_n_s_expexpand;
  PyObject *__pyx_n_s_expln;
  PyObject *__pyx_n_s_exponential;
  PyObject *__pyx_n_s_exponential_cdf;
  PyObject *__pyx_n_s_exponential_icdf;
  PyObject *__pyx_n_s_exponential_regression;
  PyObject *__pyx_n_s_exponential_regression_plot;
  PyObject *__pyx_n_s_exponentiald;
  PyObject *__pyx_n_s_exponentiald_cdf;
  PyObject *__pyx_n_s_exponentiald_icdf;
  PyObject *__pyx_n_s_export_graph;
  PyObject *__pyx_n_s_export_mathml;
  PyObject *__pyx_n_s_expovariate;
  PyObject *__pyx_n_s_expr;
  PyObject *__pyx_n_s_expression;
  PyObject *__pyx_n_s_extend;
  PyObject *__pyx_n_s_extract_measure;
  PyObject *__pyx_n_s_extrema;
  PyObject *__pyx_n_s_ezgcd;
  PyObject *__pyx_n_s_f0;
  PyObject *__pyx_n_s_f2nd;
  PyObject *__pyx_n_s_fMax;
  PyObject *__pyx_n_s_fMin;
  PyObject *__pyx_n_s_fPart;
  PyObject *__pyx_n_s_faces;
  PyObject *__pyx_n_s_facteurs_premiers;
  PyObject *__pyx_n_s_factor;
  PyObject *__pyx_n_s_factor_xn;
  PyObject *__pyx_n_s_factorial;
  PyObject *__pyx_n_s_factoriser;
  PyObject *__pyx_n_s_factoriser_entier;
  PyObject *__pyx_n_s_factoriser_sur_C;
  PyObject *__pyx_n_s_factors;
  PyObject *__pyx_n_s_fadeev;
  PyObject *__pyx_kp_s_failed_to_init_doc_from_giac_s_d;
  PyObject *__pyx_n_s_faire;
  PyObject *__pyx_n_s_false;
  PyObject *__pyx_n_s_falsepos_solver;
  PyObject *__pyx_n_s_fath;
  PyObject *__pyx_n_s_faux;
  PyObject *__pyx_n_s_fbm;
  PyObject *__pyx_n_s_fc;
  PyObject *__pyx_n_s_fclose;
  PyObject *__pyx_n_s_fcoeff;
  PyObject *__pyx_n_s_fdistrib;
  PyObject *__pyx_n_s_fermi;
  PyObject *__pyx_n_s_feuille;
  PyObject *__pyx_n_s_ffaire;
  PyObject *__pyx_n_s_ffonction;
  PyObject *__pyx_n_s_fft;
  PyObject *__pyx_n_s_ffunction;
  PyObject *__pyx_n_s_fi;
  PyObject *__pyx_n_s_fieldplot;
  PyObject *__pyx_kp_s_file;
  PyObject *__pyx_n_s_filename;
  PyObject *__pyx_n_s_filled;
  PyObject *__pyx_n_s_fin_enregistrement;
  PyObject *__pyx_n_s_find;
  PyObject *__pyx_n_s_find_cliques;
  PyObject *__pyx_n_s_find_cycles;
  PyObject *__pyx_n_s_find_minimum;
  PyObject *__pyx_n_s_find_vertex_cover;
  PyObject *__pyx_n_s_findhelp;
  PyObject *__pyx_n_s_fisher;
  PyObject *__pyx_n_s_fisher_cdf;
  PyObject *__pyx_n_s_fisher_icdf;
  PyObject *__pyx_n_s_fisherd;
  PyObject *__pyx_n_s_fisherd_cdf;
  PyObject *__pyx_n_s_fisherd_icdf;
  PyObject *__pyx_n_s_fitdistr;
  PyObject *__pyx_n_s_fitpoly;
  PyObject *__pyx_n_s_fitspline;
  PyObject *__pyx_n_s_flam;
  PyObject *__pyx_n_s_flatten;
  PyObject *__pyx_n_s_float;
  PyObject *__pyx_n_s_float2rational;
  PyObject *__pyx_n_s_floor;
  PyObject *__pyx_n_s_flow_polynomial;
  PyObject *__pyx_n_s_flower_snark;
  PyObject *__pyx_n_s_fm;
  PyObject *__pyx_n_s_fmod;
  PyObject *__pyx_n_s_foldl;
  PyObject *__pyx_n_s_foldr;
  PyObject *__pyx_n_s_fonction;
  PyObject *__pyx_n_s_fonction_derivee;
  PyObject *__pyx_n_s_fopen;
  PyObject *__pyx_n_s_for;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_forward;
  PyObject *__pyx_n_s_fourier;
  PyObject *__pyx_n_s_fourier_an;
  PyObject *__pyx_n_s_fourier_bn;
  PyObject *__pyx_n_s_fourier_cn;
  PyObject *__pyx_n_s_fpour;
  PyObject *__pyx_n_s_fprint;
  PyObject *__pyx_n_s_fr;
  PyObject *__pyx_n_s_frac;
  PyObject *__pyx_n_s_fracmod;
  PyObject *__pyx_n_s_frame_2d;
  PyObject *__pyx_n_s_frame_3d;
  PyObject *__pyx_n_s_frames;
  PyObject *__pyx_n_s_frank_wolfe;
  PyObject *__pyx_n_s_frequencies;
  PyObject *__pyx_n_s_frobenius_norm;
  PyObject *__pyx_n_s_from;
  PyObject *__pyx_kp_s_from_giac_s_help;
  PyObject *__pyx_kp_u_from_giacpy_import_giac_giac_3;
  PyObject *__pyx_n_s_froot;
  PyObject *__pyx_n_s_fsi;
  PyObject *__pyx_n_s_fsolve;
  PyObject *__pyx_n_s_ft;
  PyObject *__pyx_n_s_ftUS;
  PyObject *__pyx_kp_s_ft_2;
  PyObject *__pyx_kp_s_ft_3;
  PyObject *__pyx_kp_s_ft_lb;
  PyObject *__pyx_kp_s_ft_lb_2;
  PyObject *__pyx_kp_s_ft_s;
  PyObject *__pyx_n_s_ftantque;
  PyObject *__pyx_n_s_fullparfrac;
  PyObject *__pyx_n_s_func;
  PyObject *__pyx_n_s_funcplot;
  PyObject *__pyx_n_s_function;
  PyObject *__pyx_n_s_function_diff;
  PyObject *__pyx_n_s_fundamental_cycle;
  PyObject *__pyx_n_s_fxnd;
  PyObject *__pyx_n_s_g;
  PyObject *__pyx_n_s_g_2;
  PyObject *__pyx_n_s_ga;
  PyObject *__pyx_n_s_galC;
  PyObject *__pyx_n_s_galUK;
  PyObject *__pyx_n_s_galUS;
  PyObject *__pyx_n_s_gammad;
  PyObject *__pyx_n_s_gammad_cdf;
  PyObject *__pyx_n_s_gammad_icdf;
  PyObject *__pyx_n_s_gammavariate;
  PyObject *__pyx_n_s_gauche;
  PyObject *__pyx_n_s_gauss;
  PyObject *__pyx_n_s_gauss15;
  PyObject *__pyx_n_s_gauss_seidel_linsolve;
  PyObject *__pyx_n_s_gaussian_window;
  PyObject *__pyx_n_s_gaussjord;
  PyObject *__pyx_n_s_gaussquad;
  PyObject *__pyx_n_s_gbasis;
  PyObject *__pyx_n_s_gbasis_max_pairs;
  PyObject *__pyx_n_s_gbasis_reinject;
  PyObject *__pyx_n_s_gbasis_simult_primes;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_gcd;
  PyObject *__pyx_n_s_gcdex;
  PyObject *__pyx_kp_s_gen_indexes_are_not_yet_implemen;
  PyObject *__pyx_n_s_genpoly;
  PyObject *__pyx_n_s_geodetic2ecef;
  PyObject *__pyx_n_s_geometric;
  PyObject *__pyx_n_s_geometric_cdf;
  PyObject *__pyx_n_s_geometric_icdf;
  PyObject *__pyx_n_s_getDenom;
  PyObject *__pyx_n_s_getKey;
  PyObject *__pyx_n_s_getNum;
  PyObject *__pyx_n_s_getType;
  PyObject *__pyx_n_s_get_edge_attribute;
  PyObject *__pyx_n_s_get_edge_weight;
  PyObject *__pyx_n_s_get_graph_attribute;
  PyObject *__pyx_n_s_get_vertex_attribute;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_gf;
  PyObject *__pyx_n_s_giac;
  PyObject *__pyx_kp_s_giac_docs_dir_not_found;
  PyObject *__pyx_kp_u_giac_line_163;
  PyObject *__pyx_n_s_giacbasedir;
  PyObject *__pyx_n_s_giacpy2qcas;
  PyObject *__pyx_kp_s_giacpy_auto_methods_pxi;
  PyObject *__pyx_n_s_giacpy_giacpy;
  PyObject *__pyx_kp_s_giacpy_giacpy_pyx;
  PyObject *__pyx_n_s_giacsettings;
  PyObject *__pyx_n_s_girth;
  PyObject *__pyx_n_s_gl_ortho;
  PyObject *__pyx_n_s_gl_quaternion;
  PyObject *__pyx_n_s_gl_rotation;
  PyObject *__pyx_n_s_gl_showaxes;
  PyObject *__pyx_n_s_gl_shownames;
  PyObject *__pyx_n_s_gl_texture;
  PyObject *__pyx_n_s_gl_x;
  PyObject *__pyx_n_s_gl_x_axis_color;
  PyObject *__pyx_n_s_gl_x_axis_name;
  PyObject *__pyx_n_s_gl_x_axis_unit;
  PyObject *__pyx_n_s_gl_xtick;
  PyObject *__pyx_n_s_gl_y;
  PyObject *__pyx_n_s_gl_y_axis_color;
  PyObject *__pyx_n_s_gl_y_axis_name;
  PyObject *__pyx_n_s_gl_y_axis_unit;
  PyObject *__pyx_n_s_gl_ytick;
  PyObject *__pyx_n_s_gl_z;
  PyObject *__pyx_n_s_gl_z_axis_color;
  PyObject *__pyx_n_s_gl_z_axis_name;
  PyObject *__pyx_n_s_gl_z_axis_unit;
  PyObject *__pyx_n_s_gl_ztick;
  PyObject *__pyx_n_s_gmol;
  PyObject *__pyx_n_s_gnuplot;
  PyObject *__pyx_n_s_gold;
  PyObject *__pyx_n_s_goldberg_snark;
  PyObject *__pyx_n_s_gon;
  PyObject *__pyx_n_s_goto;
  PyObject *__pyx_n_s_grad;
  PyObject *__pyx_n_s_grad_2;
  PyObject *__pyx_n_s_grain;
  PyObject *__pyx_n_s_gramschmidt;
  PyObject *__pyx_n_s_graph;
  PyObject *__pyx_n_s_graph2tex;
  PyObject *__pyx_n_s_graph3d2tex;
  PyObject *__pyx_n_s_graph_automorphisms;
  PyObject *__pyx_n_s_graph_charpoly;
  PyObject *__pyx_n_s_graph_complement;
  PyObject *__pyx_n_s_graph_diameter;
  PyObject *__pyx_n_s_graph_equal;
  PyObject *__pyx_n_s_graph_join;
  PyObject *__pyx_n_s_graph_power;
  PyObject *__pyx_n_s_graph_rank;
  PyObject *__pyx_n_s_graph_spectrum;
  PyObject *__pyx_n_s_graph_union;
  PyObject *__pyx_n_s_graph_vertices;
  PyObject *__pyx_n_s_graphe;
  PyObject *__pyx_n_s_graphe3d;
  PyObject *__pyx_n_s_graphe_probabiliste;
  PyObject *__pyx_n_s_graphe_suite;
  PyObject *__pyx_n_s_greduce;
  PyObject *__pyx_n_s_greedy_clique;
  PyObject *__pyx_n_s_greedy_color;
  PyObject *__pyx_n_s_greedy_independent_set;
  PyObject *__pyx_n_s_green;
  PyObject *__pyx_n_s_grey;
  PyObject *__pyx_n_s_grid_graph;
  PyObject *__pyx_n_s_grid_paper;
  PyObject *__pyx_n_s_groupermu;
  PyObject *__pyx_n_s_h;
  PyObject *__pyx_n_s_h_2;
  PyObject *__pyx_n_s_ha;
  PyObject *__pyx_n_s_haar_graph;
  PyObject *__pyx_n_s_hadamard;
  PyObject *__pyx_n_s_half_cone;
  PyObject *__pyx_n_s_half_line;
  PyObject *__pyx_n_s_halftan;
  PyObject *__pyx_n_s_halftan_hyp2exp;
  PyObject *__pyx_n_s_halt;
  PyObject *__pyx_n_s_hamdist;
  PyObject *__pyx_n_s_hamming;
  PyObject *__pyx_n_s_hamming_window;
  PyObject *__pyx_n_s_hann_poisson_window;
  PyObject *__pyx_n_s_hann_window;
  PyObject *__pyx_n_s_harmonic_centrality;
  PyObject *__pyx_n_s_harmonic_conjugate;
  PyObject *__pyx_n_s_harmonic_division;
  PyObject *__pyx_n_s_has;
  PyObject *__pyx_n_s_has_arc;
  PyObject *__pyx_n_s_has_edge;
  PyObject *__pyx_n_s_hasard;
  PyObject *__pyx_n_s_hbar;
  PyObject *__pyx_n_s_head;
  PyObject *__pyx_n_s_heading;
  PyObject *__pyx_n_s_heapify;
  PyObject *__pyx_n_s_heappop;
  PyObject *__pyx_n_s_heappush;
  PyObject *__pyx_n_s_help;
  PyObject *__pyx_n_s_hermite;
  PyObject *__pyx_n_s_hessenberg;
  PyObject *__pyx_n_s_hessian;
  PyObject *__pyx_n_s_heugcd;
  PyObject *__pyx_n_s_hexagon;
  PyObject *__pyx_n_s_hht;
  PyObject *__pyx_n_s_hidden_name;
  PyObject *__pyx_n_s_highlight_edges;
  PyObject *__pyx_n_s_highlight_subgraph;
  PyObject *__pyx_n_s_highlight_trail;
  PyObject *__pyx_n_s_highlight_vertex;
  PyObject *__pyx_n_s_highpass;
  PyObject *__pyx_n_s_hilbert;
  PyObject *__pyx_n_s_histogram;
  PyObject *__pyx_n_s_hold;
  PyObject *__pyx_n_s_homogeneize;
  PyObject *__pyx_n_s_homothety;
  PyObject *__pyx_n_s_horner;
  PyObject *__pyx_n_s_hp;
  PyObject *__pyx_n_s_hsv;
  PyObject *__pyx_n_s_hsv2rgb;
  PyObject *__pyx_n_s_htmlhelp;
  PyObject *__pyx_kp_u_htmlhelp_line_1849;
  PyObject *__pyx_kp_s_http_www_fourier_ujf_grenoble_fr;
  PyObject *__pyx_n_s_hybrid_solver;
  PyObject *__pyx_n_s_hybridj_solver;
  PyObject *__pyx_n_s_hybrids_solver;
  PyObject *__pyx_n_s_hybridsj_solver;
  PyObject *__pyx_n_s_hyp2exp;
  PyObject *__pyx_n_s_hyperbola;
  PyObject *__pyx_n_s_hypercube_graph;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_iPart;
  PyObject *__pyx_kp_s_i_2;
  PyObject *__pyx_n_s_iabcuv;
  PyObject *__pyx_n_s_ibasis;
  PyObject *__pyx_n_s_ibpdv;
  PyObject *__pyx_n_s_ibpu;
  PyObject *__pyx_n_s_icdf;
  PyObject *__pyx_n_s_ichinrem;
  PyObject *__pyx_n_s_ichrem;
  PyObject *__pyx_n_s_icomp;
  PyObject *__pyx_n_s_icontent;
  PyObject *__pyx_n_s_icosahedron;
  PyObject *__pyx_n_s_id;
  PyObject *__pyx_n_s_identifier;
  PyObject *__pyx_n_s_identify_graph;
  PyObject *__pyx_n_s_identity;
  PyObject *__pyx_n_s_idivis;
  PyObject *__pyx_n_s_idn;
  PyObject *__pyx_n_s_idwt;
  PyObject *__pyx_n_s_iegcd;
  PyObject *__pyx_n_s_if;
  PyObject *__pyx_n_s_ifactor;
  PyObject *__pyx_n_s_ifactors;
  PyObject *__pyx_n_s_ifft;
  PyObject *__pyx_n_s_ifourier;
  PyObject *__pyx_n_s_ifte;
  PyObject *__pyx_n_s_igamma;
  PyObject *__pyx_n_s_igcd;
  PyObject *__pyx_n_s_igcdex;
  PyObject *__pyx_n_s_ignored;
  PyObject *__pyx_n_s_ihermite;
  PyObject *__pyx_n_s_ilaplace;
  PyObject *__pyx_n_s_im;
  PyObject *__pyx_n_s_imag;
  PyObject *__pyx_n_s_image;
  PyObject *__pyx_n_s_imfplot;
  PyObject *__pyx_n_s_implicitdiff;
  PyObject *__pyx_n_s_implicitplot;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_import_graph;
  PyObject *__pyx_n_s_in;
  PyObject *__pyx_n_s_inH20;
  PyObject *__pyx_n_s_inHg;
  PyObject *__pyx_n_s_inString;
  PyObject *__pyx_n_s_in_2;
  PyObject *__pyx_kp_s_in_2_2;
  PyObject *__pyx_kp_s_in_3;
  PyObject *__pyx_n_s_in_ideal;
  PyObject *__pyx_n_s_incidence_matrix;
  PyObject *__pyx_n_s_incident_edges;
  PyObject *__pyx_n_s_incircle;
  PyObject *__pyx_n_s_increasing_power;
  PyObject *__pyx_n_s_independence_number;
  PyObject *__pyx_n_s_indets;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_kp_s_index_html;
  PyObject *__pyx_n_s_indices;
  PyObject *__pyx_n_s_induced_subgraph;
  PyObject *__pyx_n_s_inequationplot;
  PyObject *__pyx_n_s_inertia;
  PyObject *__pyx_n_s_inf;
  PyObject *__pyx_n_s_infinity;
  PyObject *__pyx_kp_s_infinity_2;
  PyObject *__pyx_kp_s_infinity_3;
  PyObject *__pyx_n_s_information_centrality;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_input;
  PyObject *__pyx_n_s_inputform;
  PyObject *__pyx_n_s_insert;
  PyObject *__pyx_n_s_insmod;
  PyObject *__pyx_n_s_instfreq;
  PyObject *__pyx_n_s_instphase;
  PyObject *__pyx_n_s_int;
  PyObject *__pyx_n_s_intDiv;
  PyObject *__pyx_n_s_integer;
  PyObject *__pyx_n_s_integrate;
  PyObject *__pyx_n_s_integrer;
  PyObject *__pyx_n_s_inter;
  PyObject *__pyx_n_s_interactive_odeplot;
  PyObject *__pyx_n_s_interactive_plotode;
  PyObject *__pyx_n_s_interp;
  PyObject *__pyx_n_s_intersect;
  PyObject *__pyx_n_s_interval;
  PyObject *__pyx_n_s_interval2center;
  PyObject *__pyx_n_s_interval_graph;
  PyObject *__pyx_n_s_inv;
  PyObject *__pyx_n_s_inverse;
  PyObject *__pyx_n_s_inversion;
  PyObject *__pyx_n_s_invisible_point;
  PyObject *__pyx_n_s_invlaplace;
  PyObject *__pyx_n_s_invztrans;
  PyObject *__pyx_n_s_iquo;
  PyObject *__pyx_n_s_iquorem;
  PyObject *__pyx_n_s_iratrecon;
  PyObject *__pyx_n_s_irem;
  PyObject *__pyx_n_s_isPrime;
  PyObject *__pyx_n_s_is_acyclic;
  PyObject *__pyx_n_s_is_arborescence;
  PyObject *__pyx_n_s_is_biconnected;
  PyObject *__pyx_n_s_is_bipartite;
  PyObject *__pyx_n_s_is_clique;
  PyObject *__pyx_n_s_is_collinear;
  PyObject *__pyx_n_s_is_concyclic;
  PyObject *__pyx_n_s_is_conjugate;
  PyObject *__pyx_n_s_is_connected;
  PyObject *__pyx_n_s_is_coplanar;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_cospherical;
  PyObject *__pyx_n_s_is_cut_set;
  PyObject *__pyx_n_s_is_cycle;
  PyObject *__pyx_n_s_is_directed;
  PyObject *__pyx_n_s_is_element;
  PyObject *__pyx_n_s_is_equilateral;
  PyObject *__pyx_n_s_is_eulerian;
  PyObject *__pyx_n_s_is_forest;
  PyObject *__pyx_n_s_is_graphic_sequence;
  PyObject *__pyx_n_s_is_hamiltonian;
  PyObject *__pyx_n_s_is_harmonic;
  PyObject *__pyx_n_s_is_harmonic_circle_bundle;
  PyObject *__pyx_n_s_is_harmonic_line_bundle;
  PyObject *__pyx_n_s_is_included;
  PyObject *__pyx_n_s_is_inside;
  PyObject *__pyx_n_s_is_integer_graph;
  PyObject *__pyx_n_s_is_irreducible;
  PyObject *__pyx_n_s_is_isomorphic;
  PyObject *__pyx_n_s_is_isosceles;
  PyObject *__pyx_n_s_is_network;
  PyObject *__pyx_n_s_is_orthogonal;
  PyObject *__pyx_n_s_is_parallel;
  PyObject *__pyx_n_s_is_parallelogram;
  PyObject *__pyx_n_s_is_permu;
  PyObject *__pyx_n_s_is_perpendicular;
  PyObject *__pyx_n_s_is_planar;
  PyObject *__pyx_n_s_is_prime;
  PyObject *__pyx_n_s_is_pseudoprime;
  PyObject *__pyx_n_s_is_reachable;
  PyObject *__pyx_n_s_is_rectangle;
  PyObject *__pyx_n_s_is_regular;
  PyObject *__pyx_n_s_is_rhombus;
  PyObject *__pyx_n_s_is_split_graph;
  PyObject *__pyx_n_s_is_square;
  PyObject *__pyx_n_s_is_strongly_connected;
  PyObject *__pyx_n_s_is_strongly_regular;
  PyObject *__pyx_n_s_is_subgraph_isomorphic;
  PyObject *__pyx_n_s_is_tournament;
  PyObject *__pyx_n_s_is_tree;
  PyObject *__pyx_n_s_is_triconnected;
  PyObject *__pyx_n_s_is_two_edge_connected;
  PyObject *__pyx_n_s_is_vertex_colorable;
  PyObject *__pyx_n_s_is_weighted;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_isinf;
  PyObject *__pyx_n_s_ismith;
  PyObject *__pyx_n_s_isnan;
  PyObject *__pyx_n_s_isobarycenter;
  PyObject *__pyx_n_s_isolve;
  PyObject *__pyx_n_s_isom;
  PyObject *__pyx_n_s_isomorphic_copy;
  PyObject *__pyx_n_s_isopolygon;
  PyObject *__pyx_n_s_isosceles_triangle;
  PyObject *__pyx_n_s_isposdef;
  PyObject *__pyx_n_s_isprime;
  PyObject *__pyx_n_s_istft;
  PyObject *__pyx_n_s_iter;
  PyObject *__pyx_n_s_ithprime;
  PyObject *__pyx_n_s_j;
  PyObject *__pyx_n_s_jacobi_equation;
  PyObject *__pyx_n_s_jacobi_linsolve;
  PyObject *__pyx_n_s_jacobi_symbol;
  PyObject *__pyx_n_s_johnson_graph;
  PyObject *__pyx_n_s_join;
  PyObject *__pyx_n_s_jordan;
  PyObject *__pyx_n_s_jusqu_a;
  PyObject *__pyx_n_s_jusqua;
  PyObject *__pyx_n_s_jusque;
  PyObject *__pyx_n_s_k;
  PyObject *__pyx_n_s_kWh;
  PyObject *__pyx_n_s_katz_centrality;
  PyObject *__pyx_n_s_kde;
  PyObject *__pyx_n_s_keep_algext;
  PyObject *__pyx_n_s_keep_pivot;
  PyObject *__pyx_n_s_ker;
  PyObject *__pyx_n_s_kernel;
  PyObject *__pyx_n_s_kernel_density;
  PyObject *__pyx_n_s_kg;
  PyObject *__pyx_n_s_kill;
  PyObject *__pyx_kp_s_killing_thread;
  PyObject *__pyx_n_s_kip;
  PyObject *__pyx_n_s_km;
  PyObject *__pyx_kp_s_km_2;
  PyObject *__pyx_n_s_kmeans;
  PyObject *__pyx_n_s_kneser_graph;
  PyObject *__pyx_n_s_knot;
  PyObject *__pyx_n_s_kolmogorovd;
  PyObject *__pyx_n_s_kolmogorovt;
  PyObject *__pyx_n_s_kovacicsols;
  PyObject *__pyx_n_s_kph;
  PyObject *__pyx_n_s_kq;
  PyObject *__pyx_n_s_kspaths;
  PyObject *__pyx_n_s_l;
  PyObject *__pyx_n_s_l1norm;
  PyObject *__pyx_n_s_l2norm;
  PyObject *__pyx_n_s_l_2;
  PyObject *__pyx_n_s_label;
  PyObject *__pyx_n_s_labels;
  PyObject *__pyx_n_s_lagrange;
  PyObject *__pyx_n_s_laguerre;
  PyObject *__pyx_n_s_lam;
  PyObject *__pyx_n_s_lambda0;
  PyObject *__pyx_n_s_lambdac;
  PyObject *__pyx_n_s_lang;
  PyObject *__pyx_n_s_laplace;
  PyObject *__pyx_n_s_laplacian;
  PyObject *__pyx_n_s_laplacian_matrix;
  PyObject *__pyx_n_s_latex;
  PyObject *__pyx_n_s_lb;
  PyObject *__pyx_n_s_lbf;
  PyObject *__pyx_n_s_lbmol;
  PyObject *__pyx_n_s_lbt;
  PyObject *__pyx_n_s_lcf_graph;
  PyObject *__pyx_n_s_lcm;
  PyObject *__pyx_n_s_lcoeff;
  PyObject *__pyx_n_s_ldegree;
  PyObject *__pyx_n_s_ldl;
  PyObject *__pyx_n_s_learning_rate;
  PyObject *__pyx_n_s_left;
  PyObject *__pyx_n_s_left_rectangle;
  PyObject *__pyx_n_s_legend;
  PyObject *__pyx_n_s_legendre;
  PyObject *__pyx_n_s_legendre_symbol;
  PyObject *__pyx_n_s_len;
  PyObject *__pyx_n_s_length;
  PyObject *__pyx_n_s_lep;
  PyObject *__pyx_n_s_leve_crayon;
  PyObject *__pyx_n_s_levenshtein;
  PyObject *__pyx_n_s_lgcd;
  PyObject *__pyx_n_s_lhs;
  PyObject *__pyx_n_s_ligne_chapeau_carre;
  PyObject *__pyx_n_s_ligne_chapeau_plat;
  PyObject *__pyx_n_s_ligne_chapeau_rond;
  PyObject *__pyx_n_s_ligne_polygonale;
  PyObject *__pyx_n_s_ligne_polygonale_pointee;
  PyObject *__pyx_n_s_ligne_tiret;
  PyObject *__pyx_n_s_ligne_tiret_point;
  PyObject *__pyx_n_s_ligne_tiret_pointpoint;
  PyObject *__pyx_n_s_ligne_trait_plein;
  PyObject *__pyx_n_s_limit;
  PyObject *__pyx_n_s_limite;
  PyObject *__pyx_n_s_lin;
  PyObject *__pyx_n_s_linabs;
  PyObject *__pyx_n_s_line;
  PyObject *__pyx_n_s_line_graph;
  PyObject *__pyx_n_s_line_inter;
  PyObject *__pyx_n_s_line_paper;
  PyObject *__pyx_n_s_line_segments;
  PyObject *__pyx_n_s_line_width_1;
  PyObject *__pyx_n_s_line_width_2;
  PyObject *__pyx_n_s_line_width_3;
  PyObject *__pyx_n_s_line_width_4;
  PyObject *__pyx_n_s_line_width_5;
  PyObject *__pyx_n_s_line_width_6;
  PyObject *__pyx_n_s_line_width_7;
  PyObject *__pyx_n_s_linear_interpolate;
  PyObject *__pyx_n_s_linear_regression;
  PyObject *__pyx_n_s_linear_regression_plot;
  PyObject *__pyx_n_s_lineariser;
  PyObject *__pyx_n_s_lineariser_trigo;
  PyObject *__pyx_n_s_linfnorm;
  PyObject *__pyx_n_s_linsolve;
  PyObject *__pyx_n_s_linspace;
  PyObject *__pyx_n_s_linstep;
  PyObject *__pyx_n_s_liqpt;
  PyObject *__pyx_n_s_lis;
  PyObject *__pyx_n_s_lis_phrase;
  PyObject *__pyx_n_s_list;
  PyObject *__pyx_n_s_list2exp;
  PyObject *__pyx_n_s_list2mat;
  PyObject *__pyx_n_s_list_edge_attributes;
  PyObject *__pyx_n_s_list_graph_attributes;
  PyObject *__pyx_kp_s_list_index_s_out_of_range;
  PyObject *__pyx_n_s_list_vertex_attributes;
  PyObject *__pyx_n_s_listplot;
  PyObject *__pyx_n_s_listrange;
  PyObject *__pyx_n_s_lll;
  PyObject *__pyx_n_s_lm;
  PyObject *__pyx_n_s_ln;
  PyObject *__pyx_n_s_lname;
  PyObject *__pyx_n_s_lncollect;
  PyObject *__pyx_n_s_lnexpand;
  PyObject *__pyx_n_s_loadgiacgen;
  PyObject *__pyx_kp_u_loadgiacgen_line_2106;
  PyObject *__pyx_n_s_local;
  PyObject *__pyx_n_s_locus;
  PyObject *__pyx_n_s_log;
  PyObject *__pyx_n_s_log10;
  PyObject *__pyx_n_s_log2;
  PyObject *__pyx_n_s_log_loss;
  PyObject *__pyx_n_s_logarithmic_regression;
  PyObject *__pyx_n_s_logarithmic_regression_plot;
  PyObject *__pyx_n_s_logb;
  PyObject *__pyx_n_s_logistic;
  PyObject *__pyx_n_s_logistic_regression;
  PyObject *__pyx_n_s_logistic_regression_plot;
  PyObject *__pyx_n_s_long;
  PyObject *__pyx_n_s_lower;
  PyObject *__pyx_n_s_lowest_common_ancestor;
  PyObject *__pyx_n_s_lowpass;
  PyObject *__pyx_n_s_lp_assume;
  PyObject *__pyx_n_s_lp_bestlocalbound;
  PyObject *__pyx_n_s_lp_bestprojection;
  PyObject *__pyx_n_s_lp_binary;
  PyObject *__pyx_n_s_lp_binaryvariables;
  PyObject *__pyx_n_s_lp_breadthfirst;
  PyObject *__pyx_n_s_lp_depthfirst;
  PyObject *__pyx_n_s_lp_depthlimit;
  PyObject *__pyx_n_s_lp_firstfractional;
  PyObject *__pyx_n_s_lp_gaptolerance;
  PyObject *__pyx_n_s_lp_heuristic;
  PyObject *__pyx_n_s_lp_hybrid;
  PyObject *__pyx_n_s_lp_integer;
  PyObject *__pyx_n_s_lp_integervariables;
  PyObject *__pyx_n_s_lp_interiorpoint;
  PyObject *__pyx_n_s_lp_iterationlimit;
  PyObject *__pyx_n_s_lp_lastfractional;
  PyObject *__pyx_n_s_lp_maxcuts;
  PyObject *__pyx_n_s_lp_maximize;
  PyObject *__pyx_n_s_lp_method;
  PyObject *__pyx_n_s_lp_mostfractional;
  PyObject *__pyx_n_s_lp_nodelimit;
  PyObject *__pyx_n_s_lp_nodeselect;
  PyObject *__pyx_n_s_lp_nonnegative;
  PyObject *__pyx_n_s_lp_nonnegint;
  PyObject *__pyx_n_s_lp_presolve;
  PyObject *__pyx_n_s_lp_pseudocost;
  PyObject *__pyx_n_s_lp_simplex;
  PyObject *__pyx_n_s_lp_timelimit;
  PyObject *__pyx_n_s_lp_varselect;
  PyObject *__pyx_n_s_lp_verbose;
  PyObject *__pyx_n_s_lpsolve;
  PyObject *__pyx_n_s_lsmod;
  PyObject *__pyx_n_s_lsq;
  PyObject *__pyx_n_s_lu;
  PyObject *__pyx_n_s_lvar;
  PyObject *__pyx_n_s_lx;
  PyObject *__pyx_n_s_lyr;
  PyObject *__pyx_n_s_m;
  PyObject *__pyx_n_s_mEarth;
  PyObject *__pyx_n_s_mRow;
  PyObject *__pyx_n_s_mRowAdd;
  PyObject *__pyx_kp_s_m_2;
  PyObject *__pyx_kp_s_m_3;
  PyObject *__pyx_kp_s_m_s;
  PyObject *__pyx_kp_s_m_s_2;
  PyObject *__pyx_n_s_magenta;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_make_directed;
  PyObject *__pyx_n_s_make_symbol;
  PyObject *__pyx_n_s_make_weighted;
  PyObject *__pyx_n_s_makelist;
  PyObject *__pyx_n_s_makemat;
  PyObject *__pyx_n_s_makesuite;
  PyObject *__pyx_n_s_makevector;
  PyObject *__pyx_n_s_map;
  PyObject *__pyx_n_s_maple2mupad;
  PyObject *__pyx_n_s_maple2xcas;
  PyObject *__pyx_n_s_maple_ifactors;
  PyObject *__pyx_n_s_maple_mode;
  PyObject *__pyx_n_s_markov;
  PyObject *__pyx_n_s_mat2list;
  PyObject *__pyx_n_s_math;
  PyObject *__pyx_n_s_mathml;
  PyObject *__pyx_n_s_matpow;
  PyObject *__pyx_n_s_matrix;
  PyObject *__pyx_n_s_matrix_norm;
  PyObject *__pyx_n_s_max;
  PyObject *__pyx_n_s_maxcount;
  PyObject *__pyx_n_s_maxflow;
  PyObject *__pyx_n_s_maximal_independent_set;
  PyObject *__pyx_n_s_maximize;
  PyObject *__pyx_n_s_maximum_clique;
  PyObject *__pyx_n_s_maximum_degree;
  PyObject *__pyx_n_s_maximum_independent_set;
  PyObject *__pyx_n_s_maximum_matching;
  PyObject *__pyx_n_s_maxnorm;
  PyObject *__pyx_n_s_maxsize;
  PyObject *__pyx_n_s_me;
  PyObject *__pyx_n_s_mean;
  PyObject *__pyx_n_s_median;
  PyObject *__pyx_n_s_median_line;
  PyObject *__pyx_n_s_member;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_mgf;
  PyObject *__pyx_n_s_mho;
  PyObject *__pyx_n_s_miUS;
  PyObject *__pyx_kp_s_miUS_2;
  PyObject *__pyx_kp_s_mi_2;
  PyObject *__pyx_n_s_mid;
  PyObject *__pyx_n_s_middle_point;
  PyObject *__pyx_n_s_midpoint;
  PyObject *__pyx_n_s_mil;
  PyObject *__pyx_n_s_mile;
  PyObject *__pyx_n_s_mille;
  PyObject *__pyx_n_s_min;
  PyObject *__pyx_n_s_minimal_edge_coloring;
  PyObject *__pyx_n_s_minimal_spanning_tree;
  PyObject *__pyx_n_s_minimal_vertex_coloring;
  PyObject *__pyx_n_s_minimax;
  PyObject *__pyx_n_s_minimize;
  PyObject *__pyx_n_s_minimum_cut;
  PyObject *__pyx_n_s_minimum_degree;
  PyObject *__pyx_n_s_minimum_vertex_cover;
  PyObject *__pyx_n_s_minus;
  PyObject *__pyx_n_s_mixdown;
  PyObject *__pyx_n_s_mkisom;
  PyObject *__pyx_n_s_mksa;
  PyObject *__pyx_n_s_ml;
  PyObject *__pyx_n_s_mm;
  PyObject *__pyx_n_s_mmHg;
  PyObject *__pyx_n_s_mn;
  PyObject *__pyx_n_s_mod;
  PyObject *__pyx_n_s_modf;
  PyObject *__pyx_n_s_modgcd;
  PyObject *__pyx_n_s_mods;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_mol;
  PyObject *__pyx_n_s_momentum;
  PyObject *__pyx_n_s_monotonic;
  PyObject *__pyx_n_s_montre_tortue;
  PyObject *__pyx_n_s_moremethods;
  PyObject *__pyx_n_s_moretests;
  PyObject *__pyx_kp_u_moretests_line_2061;
  PyObject *__pyx_n_s_mostkeywords;
  PyObject *__pyx_n_s_moustache;
  PyObject *__pyx_n_s_moving_average;
  PyObject *__pyx_n_s_moyal;
  PyObject *__pyx_n_s_moyenne;
  PyObject *__pyx_n_s_mp;
  PyObject *__pyx_n_s_mph;
  PyObject *__pyx_n_s_mpme;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_s_mu0;
  PyObject *__pyx_n_s_muB;
  PyObject *__pyx_n_s_muN;
  PyObject *__pyx_n_s_mul;
  PyObject *__pyx_n_s_mul_2;
  PyObject *__pyx_n_s_mult_c_conjugate;
  PyObject *__pyx_n_s_mult_conjugate;
  PyObject *__pyx_n_s_multinomial;
  PyObject *__pyx_n_s_multiplier_conjugue;
  PyObject *__pyx_n_s_multiplier_conjugue_complexe;
  PyObject *__pyx_n_s_multiply;
  PyObject *__pyx_n_s_mupad2maple;
  PyObject *__pyx_n_s_mupad2xcas;
  PyObject *__pyx_n_s_mycielski;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_n_s_nCr;
  PyObject *__pyx_n_s_nDeriv;
  PyObject *__pyx_n_s_nInt;
  PyObject *__pyx_n_s_nPr;
  PyObject *__pyx_n_s_nSolve;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_navy;
  PyObject *__pyx_n_s_ncols;
  PyObject *__pyx_n_s_neg;
  PyObject *__pyx_n_s_negbinomial;
  PyObject *__pyx_n_s_negbinomial_cdf;
  PyObject *__pyx_n_s_negbinomial_icdf;
  PyObject *__pyx_n_s_neighbors;
  PyObject *__pyx_n_s_network_transitivity;
  PyObject *__pyx_n_s_neural_network;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_newList;
  PyObject *__pyx_n_s_newMat;
  PyObject *__pyx_n_s_newton;
  PyObject *__pyx_n_s_newton_solver;
  PyObject *__pyx_n_s_newtonj_solver;
  PyObject *__pyx_n_s_nextperm;
  PyObject *__pyx_n_s_nextprime;
  PyObject *__pyx_n_s_nlp_binary;
  PyObject *__pyx_n_s_nlp_binaryvariables;
  PyObject *__pyx_n_s_nlp_initialpoint;
  PyObject *__pyx_n_s_nlp_integer;
  PyObject *__pyx_n_s_nlp_integervariables;
  PyObject *__pyx_n_s_nlp_iterationlimit;
  PyObject *__pyx_n_s_nlp_maximize;
  PyObject *__pyx_n_s_nlp_method;
  PyObject *__pyx_n_s_nlp_nonnegative;
  PyObject *__pyx_n_s_nlp_nonnegint;
  PyObject *__pyx_n_s_nlp_precision;
  PyObject *__pyx_n_s_nlp_presolve;
  PyObject *__pyx_n_s_nlp_tolerance;
  PyObject *__pyx_n_s_nlp_verbose;
  PyObject *__pyx_n_s_nlpsolve;
  PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
  PyObject *__pyx_n_s_nodisp;
  PyObject *__pyx_n_s_noir;
  PyObject *__pyx_n_s_nom_cache;
  PyObject *__pyx_n_s_non;
  PyObject *__pyx_n_s_non_recursive_normal;
  PyObject *__pyx_n_s_nonevaluable;
  PyObject *__pyx_n_s_nonnegint;
  PyObject *__pyx_n_s_nop;
  PyObject *__pyx_n_s_nops;
  PyObject *__pyx_n_s_norm;
  PyObject *__pyx_n_s_normal;
  PyObject *__pyx_n_s_normal_cdf;
  PyObject *__pyx_n_s_normal_icdf;
  PyObject *__pyx_n_s_normald;
  PyObject *__pyx_n_s_normald_cdf;
  PyObject *__pyx_n_s_normald_icdf;
  PyObject *__pyx_n_s_normalize;
  PyObject *__pyx_n_s_normalt;
  PyObject *__pyx_n_s_normalvariate;
  PyObject *__pyx_n_s_not;
  PyObject *__pyx_n_s_nprimes;
  PyObject *__pyx_n_s_nrows;
  PyObject *__pyx_n_s_nstep;
  PyObject *__pyx_n_s_nuage_points;
  PyObject *__pyx_n_s_nullspace;
  PyObject *__pyx_n_s_number_of_edges;
  PyObject *__pyx_n_s_number_of_spanning_trees;
  PyObject *__pyx_n_s_number_of_triangles;
  PyObject *__pyx_n_s_number_of_vertices;
  PyObject *__pyx_n_s_numdiff;
  PyObject *__pyx_n_s_numer;
  PyObject *__pyx_n_s_octahedron;
  PyObject *__pyx_n_s_od;
  PyObject *__pyx_n_s_odd;
  PyObject *__pyx_n_s_odd_girth;
  PyObject *__pyx_n_s_odd_graph;
  PyObject *__pyx_n_s_odeplot;
  PyObject *__pyx_n_s_odesolve;
  PyObject *__pyx_n_s_of;
  PyObject *__pyx_n_s_oldies;
  PyObject *__pyx_n_s_olive;
  PyObject *__pyx_n_s_op;
  PyObject *__pyx_n_s_open;
  PyObject *__pyx_n_s_open_polygon;
  PyObject *__pyx_n_s_option;
  PyObject *__pyx_n_s_or;
  PyObject *__pyx_n_s_orange;
  PyObject *__pyx_n_s_ord;
  PyObject *__pyx_n_s_order;
  PyObject *__pyx_n_s_order_size;
  PyObject *__pyx_n_s_ordinate;
  PyObject *__pyx_n_s_orthocenter;
  PyObject *__pyx_n_s_orthogonal;
  PyObject *__pyx_n_s_os;
  PyObject *__pyx_n_s_osculating_circle;
  PyObject *__pyx_n_s_otherwise;
  PyObject *__pyx_n_s_ou;
  PyObject *__pyx_n_s_output;
  PyObject *__pyx_n_s_oz;
  PyObject *__pyx_n_s_ozUK;
  PyObject *__pyx_n_s_ozfl;
  PyObject *__pyx_n_s_ozt;
  PyObject *__pyx_n_s_p1oc2;
  PyObject *__pyx_n_s_p1op2;
  PyObject *__pyx_n_s_pa2b2;
  PyObject *__pyx_n_s_pade;
  PyObject *__pyx_n_s_paley_graph;
  PyObject *__pyx_n_s_parabola;
  PyObject *__pyx_n_s_parallel;
  PyObject *__pyx_n_s_parallelepiped;
  PyObject *__pyx_n_s_parallelogram;
  PyObject *__pyx_n_s_param;
  PyObject *__pyx_n_s_parameq;
  PyObject *__pyx_n_s_parameter;
  PyObject *__pyx_n_s_paramplot;
  PyObject *__pyx_n_s_parfrac;
  PyObject *__pyx_n_s_pari;
  PyObject *__pyx_n_s_part;
  PyObject *__pyx_n_s_partfrac;
  PyObject *__pyx_n_s_parzen_window;
  PyObject *__pyx_n_s_pas;
  PyObject *__pyx_n_s_pas_de_cote;
  PyObject *__pyx_n_s_path_graph;
  PyObject *__pyx_n_s_pc;
  PyObject *__pyx_n_s_pcar;
  PyObject *__pyx_n_s_pcar_hessenberg;
  PyObject *__pyx_n_s_pcoef;
  PyObject *__pyx_n_s_pcoeff;
  PyObject *__pyx_n_s_pdl;
  PyObject *__pyx_n_s_pencolor;
  PyObject *__pyx_n_s_pendown;
  PyObject *__pyx_n_s_penup;
  PyObject *__pyx_n_s_perimeter;
  PyObject *__pyx_n_s_perimeterat;
  PyObject *__pyx_n_s_perimeteratraw;
  PyObject *__pyx_n_s_period;
  PyObject *__pyx_n_s_periodic;
  PyObject *__pyx_n_s_perm;
  PyObject *__pyx_n_s_perminv;
  PyObject *__pyx_n_s_permu2cycles;
  PyObject *__pyx_n_s_permu2mat;
  PyObject *__pyx_n_s_permuorder;
  PyObject *__pyx_n_s_permute_vertices;
  PyObject *__pyx_n_s_perpen_bisector;
  PyObject *__pyx_n_s_perpendicular;
  PyObject *__pyx_n_s_petersen_graph;
  PyObject *__pyx_n_s_peval;
  PyObject *__pyx_n_s_ph;
  PyObject *__pyx_n_s_phi;
  PyObject *__pyx_n_s_pi;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_pie;
  PyObject *__pyx_n_s_piecewise;
  PyObject *__pyx_n_s_pink;
  PyObject *__pyx_n_s_pivot;
  PyObject *__pyx_n_s_pixoff;
  PyObject *__pyx_n_s_pixon;
  PyObject *__pyx_n_s_pk;
  PyObject *__pyx_n_s_planar;
  PyObject *__pyx_n_s_plane;
  PyObject *__pyx_n_s_plane_dual;
  PyObject *__pyx_n_s_playsnd;
  PyObject *__pyx_n_s_plex;
  PyObject *__pyx_n_s_plot;
  PyObject *__pyx_n_s_plot3d;
  PyObject *__pyx_n_s_plotarea;
  PyObject *__pyx_n_s_plotcdf;
  PyObject *__pyx_n_s_plotcontour;
  PyObject *__pyx_n_s_plotdensity;
  PyObject *__pyx_n_s_plotfield;
  PyObject *__pyx_n_s_plotfunc;
  PyObject *__pyx_n_s_plotimf;
  PyObject *__pyx_n_s_plotimplicit;
  PyObject *__pyx_n_s_plotinequation;
  PyObject *__pyx_n_s_plotlist;
  PyObject *__pyx_n_s_plotode;
  PyObject *__pyx_n_s_plotparam;
  PyObject *__pyx_n_s_plotpolar;
  PyObject *__pyx_n_s_plotproba;
  PyObject *__pyx_n_s_plotseq;
  PyObject *__pyx_n_s_plotspectrum;
  PyObject *__pyx_n_s_plotwav;
  PyObject *__pyx_n_s_plus_point;
  PyObject *__pyx_n_s_pmin;
  PyObject *__pyx_n_s_pnt;
  PyObject *__pyx_n_s_point;
  PyObject *__pyx_n_s_point2d;
  PyObject *__pyx_n_s_point3d;
  PyObject *__pyx_n_s_point_arret;
  PyObject *__pyx_n_s_point_carre;
  PyObject *__pyx_n_s_point_croix;
  PyObject *__pyx_n_s_point_div;
  PyObject *__pyx_n_s_point_etoile;
  PyObject *__pyx_n_s_point_invisible;
  PyObject *__pyx_n_s_point_losange;
  PyObject *__pyx_n_s_point_milieu;
  PyObject *__pyx_n_s_point_plus;
  PyObject *__pyx_n_s_point_point;
  PyObject *__pyx_n_s_point_polaire;
  PyObject *__pyx_n_s_point_triangle;
  PyObject *__pyx_n_s_point_width_1;
  PyObject *__pyx_n_s_point_width_2;
  PyObject *__pyx_n_s_point_width_3;
  PyObject *__pyx_n_s_point_width_4;
  PyObject *__pyx_n_s_point_width_5;
  PyObject *__pyx_n_s_point_width_6;
  PyObject *__pyx_n_s_point_width_7;
  PyObject *__pyx_n_s_poisson;
  PyObject *__pyx_n_s_poisson_cdf;
  PyObject *__pyx_n_s_poisson_icdf;
  PyObject *__pyx_n_s_poisson_window;
  PyObject *__pyx_n_s_polar;
  PyObject *__pyx_n_s_polar_coordinates;
  PyObject *__pyx_n_s_polar_point;
  PyObject *__pyx_n_s_polarplot;
  PyObject *__pyx_n_s_pole;
  PyObject *__pyx_n_s_poly2symb;
  PyObject *__pyx_n_s_polyEval;
  PyObject *__pyx_n_s_polygon;
  PyObject *__pyx_n_s_polygone_rempli;
  PyObject *__pyx_n_s_polygonplot;
  PyObject *__pyx_n_s_polygonscatterplot;
  PyObject *__pyx_n_s_polyhedron;
  PyObject *__pyx_n_s_polynom;
  PyObject *__pyx_n_s_polynomial_regression;
  PyObject *__pyx_n_s_polynomial_regression_plot;
  PyObject *__pyx_n_s_position;
  PyObject *__pyx_n_s_poslbdLMQ;
  PyObject *__pyx_n_s_posubLMQ;
  PyObject *__pyx_n_s_potential;
  PyObject *__pyx_n_s_pour;
  PyObject *__pyx_n_s_pow;
  PyObject *__pyx_n_s_pow2exp;
  PyObject *__pyx_n_s_pow_2;
  PyObject *__pyx_n_s_power_regression;
  PyObject *__pyx_n_s_power_regression_plot;
  PyObject *__pyx_n_s_powermod;
  PyObject *__pyx_n_s_powerpc;
  PyObject *__pyx_n_s_powexpand;
  PyObject *__pyx_n_s_powmod;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_prepend;
  PyObject *__pyx_n_s_preval;
  PyObject *__pyx_n_s_prevperm;
  PyObject *__pyx_n_s_prevprime;
  PyObject *__pyx_n_s_primpart;
  PyObject *__pyx_n_s_print;
  PyObject *__pyx_n_s_printf;
  PyObject *__pyx_kp_s_printpow_1;
  PyObject *__pyx_n_s_prism;
  PyObject *__pyx_n_s_prism_graph;
  PyObject *__pyx_n_s_proc;
  PyObject *__pyx_n_s_product;
  PyObject *__pyx_n_s_program;
  PyObject *__pyx_n_s_projection;
  PyObject *__pyx_n_s_proot;
  PyObject *__pyx_n_s_propFrac;
  PyObject *__pyx_n_s_propfrac;
  PyObject *__pyx_n_s_pruefer_code;
  PyObject *__pyx_n_s_psi;
  PyObject *__pyx_n_s_psrgcd;
  PyObject *__pyx_n_s_ptUK;
  PyObject *__pyx_n_s_ptayl;
  PyObject *__pyx_n_s_purge;
  PyObject *__pyx_kp_s_purge_GIACPY_TMP_NAME05026807096;
  PyObject *__pyx_n_s_purple;
  PyObject *__pyx_n_s_pwd;
  PyObject *__pyx_n_s_pyramid;
  PyObject *__pyx_n_s_python_compat;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_capi;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_GiacMethods_base;
  PyObject *__pyx_n_s_q;
  PyObject *__pyx_n_s_q2a;
  PyObject *__pyx_n_s_qcas;
  PyObject *__pyx_kp_u_qcas_line_1879;
  PyObject *__pyx_n_s_qe;
  PyObject *__pyx_n_s_qepsilon0;
  PyObject *__pyx_n_s_qme;
  PyObject *__pyx_n_s_qr;
  PyObject *__pyx_n_s_qt;
  PyObject *__pyx_n_s_quadrant1;
  PyObject *__pyx_n_s_quadrant2;
  PyObject *__pyx_n_s_quadrant3;
  PyObject *__pyx_n_s_quadrant4;
  PyObject *__pyx_n_s_quadric;
  PyObject *__pyx_n_s_quadrilateral;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_quantile;
  PyObject *__pyx_n_s_quartile1;
  PyObject *__pyx_n_s_quartile3;
  PyObject *__pyx_n_s_quartiles;
  PyObject *__pyx_n_s_quest;
  PyObject *__pyx_n_s_quo;
  PyObject *__pyx_n_s_quorem;
  PyObject *__pyx_n_s_quote;
  PyObject *__pyx_n_s_r2e;
  PyObject *__pyx_n_s_rad;
  PyObject *__pyx_n_s_rad_2;
  PyObject *__pyx_kp_s_rad_s;
  PyObject *__pyx_kp_s_rad_s_2;
  PyObject *__pyx_n_s_radians;
  PyObject *__pyx_n_s_radical_axis;
  PyObject *__pyx_n_s_radius;
  PyObject *__pyx_n_s_ramene;
  PyObject *__pyx_n_s_rand;
  PyObject *__pyx_n_s_randMat;
  PyObject *__pyx_n_s_randNorm;
  PyObject *__pyx_n_s_randPoly;
  PyObject *__pyx_n_s_randbetad;
  PyObject *__pyx_n_s_randbinomial;
  PyObject *__pyx_n_s_randchisquare;
  PyObject *__pyx_n_s_randexp;
  PyObject *__pyx_n_s_randfisher;
  PyObject *__pyx_n_s_randgammad;
  PyObject *__pyx_n_s_randgeometric;
  PyObject *__pyx_n_s_randint;
  PyObject *__pyx_n_s_randmarkov;
  PyObject *__pyx_n_s_randmatrix;
  PyObject *__pyx_n_s_randmultinomial;
  PyObject *__pyx_n_s_randnorm;
  PyObject *__pyx_n_s_random;
  PyObject *__pyx_n_s_random_bipartite_graph;
  PyObject *__pyx_n_s_random_digraph;
  PyObject *__pyx_n_s_random_graph;
  PyObject *__pyx_n_s_random_network;
  PyObject *__pyx_n_s_random_planar_graph;
  PyObject *__pyx_n_s_random_regular_graph;
  PyObject *__pyx_n_s_random_sequence_graph;
  PyObject *__pyx_n_s_random_tournament;
  PyObject *__pyx_n_s_random_tree;
  PyObject *__pyx_n_s_random_variable;
  PyObject *__pyx_n_s_randperm;
  PyObject *__pyx_n_s_randpoisson;
  PyObject *__pyx_n_s_randpoly;
  PyObject *__pyx_n_s_randseed;
  PyObject *__pyx_n_s_randstudent;
  PyObject *__pyx_n_s_randvar;
  PyObject *__pyx_n_s_randvector;
  PyObject *__pyx_n_s_randweibulld;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_rank;
  PyObject *__pyx_n_s_ranm;
  PyObject *__pyx_n_s_ranv;
  PyObject *__pyx_n_s_rassembler_trigo;
  PyObject *__pyx_n_s_rat_jordan;
  PyObject *__pyx_n_s_ratinterp;
  PyObject *__pyx_n_s_rational;
  PyObject *__pyx_n_s_rationalroot;
  PyObject *__pyx_n_s_ratnormal;
  PyObject *__pyx_n_s_rd;
  PyObject *__pyx_n_s_rdiv;
  PyObject *__pyx_n_s_re;
  PyObject *__pyx_n_s_reachable;
  PyObject *__pyx_n_s_read;
  PyObject *__pyx_n_s_readrgb;
  PyObject *__pyx_n_s_readwav;
  PyObject *__pyx_n_s_real;
  PyObject *__pyx_n_s_realroot;
  PyObject *__pyx_n_s_reciprocation;
  PyObject *__pyx_n_s_rect;
  PyObject *__pyx_n_s_rectangle;
  PyObject *__pyx_n_s_rectangle_droit;
  PyObject *__pyx_n_s_rectangle_gauche;
  PyObject *__pyx_n_s_rectangle_plein;
  PyObject *__pyx_n_s_rectangular_coordinates;
  PyObject *__pyx_n_s_recule;
  PyObject *__pyx_n_s_red;
  PyObject *__pyx_n_s_redim;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_reduced_conic;
  PyObject *__pyx_n_s_reduced_quadric;
  PyObject *__pyx_n_s_ref;
  PyObject *__pyx_n_s_reflection;
  PyObject *__pyx_n_s_regroup;
  PyObject *__pyx_n_s_relabel_vertices;
  PyObject *__pyx_n_s_reliability_polynomial;
  PyObject *__pyx_n_s_rem;
  PyObject *__pyx_n_s_rem_2;
  PyObject *__pyx_n_s_remain;
  PyObject *__pyx_n_s_remove;
  PyObject *__pyx_n_s_reorder;
  PyObject *__pyx_n_s_repeat;
  PyObject *__pyx_n_s_repete;
  PyObject *__pyx_n_s_repeter;
  PyObject *__pyx_n_s_replace;
  PyObject *__pyx_n_s_repr;
  PyObject *__pyx_n_s_repr_html;
  PyObject *__pyx_n_s_repr_latex;
  PyObject *__pyx_n_s_resample;
  PyObject *__pyx_n_s_residue;
  PyObject *__pyx_n_s_resoudre;
  PyObject *__pyx_n_s_resoudre_dans_C;
  PyObject *__pyx_n_s_resoudre_systeme_lineaire;
  PyObject *__pyx_n_s_restart;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_resultant;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_reverse;
  PyObject *__pyx_n_s_reverse_graph;
  PyObject *__pyx_n_s_reverse_rsolve;
  PyObject *__pyx_n_s_revert;
  PyObject *__pyx_n_s_revlex;
  PyObject *__pyx_n_s_revlist;
  PyObject *__pyx_n_s_rgb;
  PyObject *__pyx_n_s_rgb2hsv;
  PyObject *__pyx_n_s_rgb2xyz;
  PyObject *__pyx_n_s_rhombus;
  PyObject *__pyx_n_s_rhombus_point;
  PyObject *__pyx_n_s_rhs;
  PyObject *__pyx_n_s_riemann_window;
  PyObject *__pyx_n_s_right;
  PyObject *__pyx_n_s_right_rectangle;
  PyObject *__pyx_n_s_right_triangle;
  PyObject *__pyx_n_s_risch;
  PyObject *__pyx_n_s_rm_a_z;
  PyObject *__pyx_n_s_rm_all_vars;
  PyObject *__pyx_n_s_rmbreakpoint;
  PyObject *__pyx_n_s_rmmod;
  PyObject *__pyx_n_s_rms;
  PyObject *__pyx_n_s_rmwatch;
  PyObject *__pyx_n_s_rod;
  PyObject *__pyx_n_s_romberg;
  PyObject *__pyx_n_s_rombergm;
  PyObject *__pyx_n_s_rombergt;
  PyObject *__pyx_n_s_rond;
  PyObject *__pyx_n_s_root;
  PyObject *__pyx_n_s_rootof;
  PyObject *__pyx_n_s_roots;
  PyObject *__pyx_n_s_rotate;
  PyObject *__pyx_n_s_rotation;
  PyObject *__pyx_n_s_rouge;
  PyObject *__pyx_n_s_round;
  PyObject *__pyx_n_s_row;
  PyObject *__pyx_n_s_rowAdd;
  PyObject *__pyx_n_s_rowDim;
  PyObject *__pyx_n_s_rowNorm;
  PyObject *__pyx_n_s_rowSwap;
  PyObject *__pyx_n_s_rowdim;
  PyObject *__pyx_n_s_rownorm;
  PyObject *__pyx_n_s_rowspace;
  PyObject *__pyx_n_s_rowswap;
  PyObject *__pyx_n_s_rpm;
  PyObject *__pyx_n_s_rref;
  PyObject *__pyx_n_s_rsolve;
  PyObject *__pyx_n_s_rur;
  PyObject *__pyx_n_s_rur_certify;
  PyObject *__pyx_n_s_rur_gbasis;
  PyObject *__pyx_n_s_s;
  PyObject *__pyx_n_s_s_2;
  PyObject *__pyx_kp_s_s_s;
  PyObject *__pyx_n_s_saisir;
  PyObject *__pyx_n_s_saisir_chaine;
  PyObject *__pyx_n_s_same;
  PyObject *__pyx_n_s_sample;
  PyObject *__pyx_n_s_samplerate;
  PyObject *__pyx_n_s_sans_factoriser;
  PyObject *__pyx_n_s_saute;
  PyObject *__pyx_n_s_sauve;
  PyObject *__pyx_n_s_save;
  PyObject *__pyx_n_s_save_history;
  PyObject *__pyx_n_s_sb;
  PyObject *__pyx_n_s_scalarProduct;
  PyObject *__pyx_n_s_scalar_product;
  PyObject *__pyx_n_s_scale;
  PyObject *__pyx_n_s_scaleadd;
  PyObject *__pyx_n_s_scatterplot;
  PyObject *__pyx_n_s_schur;
  PyObject *__pyx_n_s_sd;
  PyObject *__pyx_n_s_sec;
  PyObject *__pyx_n_s_secant_solver;
  PyObject *__pyx_n_s_segment;
  PyObject *__pyx_n_s_seidel_spectrum;
  PyObject *__pyx_n_s_seidel_switch;
  PyObject *__pyx_n_s_select;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_kp_s_self_is_not_a_giac_List;
  PyObject *__pyx_kp_s_self_is_not_a_giac_integer;
  PyObject *__pyx_kp_s_self_is_not_a_giac_real;
  PyObject *__pyx_n_s_semi_augment;
  PyObject *__pyx_n_s_send;
  PyObject *__pyx_n_s_seq;
  PyObject *__pyx_n_s_seqplot;
  PyObject *__pyx_n_s_seqsolve;
  PyObject *__pyx_n_s_sequence_graph;
  PyObject *__pyx_n_s_series;
  PyObject *__pyx_kp_s_set;
  PyObject *__pyx_n_s_set_channel_data;
  PyObject *__pyx_n_s_set_edge_attribute;
  PyObject *__pyx_n_s_set_edge_weight;
  PyObject *__pyx_n_s_set_graph_attribute;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_set_pixel;
  PyObject *__pyx_n_s_set_screen;
  PyObject *__pyx_n_s_set_vertex_attribute;
  PyObject *__pyx_n_s_set_vertex_positions;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_shift;
  PyObject *__pyx_n_s_shift_phase;
  PyObject *__pyx_n_s_shortest_path;
  PyObject *__pyx_n_s_show_pixels;
  PyObject *__pyx_n_s_shuffle;
  PyObject *__pyx_n_s_si;
  PyObject *__pyx_n_s_sierpinski_graph;
  PyObject *__pyx_n_s_sigma;
  PyObject *__pyx_n_s_sign;
  PyObject *__pyx_n_s_sign2Heaviside;
  PyObject *__pyx_n_s_signature;
  PyObject *__pyx_n_s_signe;
  PyObject *__pyx_n_s_similarity;
  PyObject *__pyx_n_s_simp2;
  PyObject *__pyx_n_s_simplex_reduce;
  PyObject *__pyx_n_s_simplicial_vertices;
  PyObject *__pyx_n_s_simplifier;
  PyObject *__pyx_n_s_simplify;
  PyObject *__pyx_n_s_simplifyDirac;
  PyObject *__pyx_n_s_simpson;
  PyObject *__pyx_n_s_simulated_annealing;
  PyObject *__pyx_n_s_simult;
  PyObject *__pyx_n_s_sin;
  PyObject *__pyx_n_s_sin2costan;
  PyObject *__pyx_n_s_sinc;
  PyObject *__pyx_n_s_sincos;
  PyObject *__pyx_n_s_single_inter;
  PyObject *__pyx_n_s_sinh;
  PyObject *__pyx_n_s_sinon;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_s_sizes;
  PyObject *__pyx_n_s_sleep;
  PyObject *__pyx_n_s_slope;
  PyObject *__pyx_n_s_slopeat;
  PyObject *__pyx_n_s_slopeatraw;
  PyObject *__pyx_n_s_slug;
  PyObject *__pyx_n_s_smith;
  PyObject *__pyx_n_s_smod;
  PyObject *__pyx_n_s_snedecor;
  PyObject *__pyx_n_s_snedecor_cdf;
  PyObject *__pyx_n_s_snedecor_icdf;
  PyObject *__pyx_n_s_snedecord;
  PyObject *__pyx_n_s_snedecord_cdf;
  PyObject *__pyx_n_s_snedecord_icdf;
  PyObject *__pyx_n_s_solid_line;
  PyObject *__pyx_n_s_solve;
  PyObject *__pyx_n_s_somme;
  PyObject *__pyx_n_s_sommet;
  PyObject *__pyx_n_s_sort;
  PyObject *__pyx_n_s_sorta;
  PyObject *__pyx_n_s_sortd;
  PyObject *__pyx_n_s_sorted;
  PyObject *__pyx_n_s_sortperm;
  PyObject *__pyx_n_s_soundsec;
  PyObject *__pyx_n_s_spanning_tree;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_sphere;
  PyObject *__pyx_n_s_splice;
  PyObject *__pyx_n_s_spline;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_spring;
  PyObject *__pyx_n_s_sq;
  PyObject *__pyx_n_s_sqrfree;
  PyObject *__pyx_n_s_sqrt;
  PyObject *__pyx_n_s_square;
  PyObject *__pyx_n_s_square_point;
  PyObject *__pyx_n_s_sr;
  PyObject *__pyx_n_s_srand;
  PyObject *__pyx_n_s_sst;
  PyObject *__pyx_n_s_sst_in;
  PyObject *__pyx_n_s_st;
  PyObject *__pyx_n_s_st_ordering;
  PyObject *__pyx_n_s_stack;
  PyObject *__pyx_n_s_star_graph;
  PyObject *__pyx_n_s_star_point;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_stdDev;
  PyObject *__pyx_n_s_stddev;
  PyObject *__pyx_n_s_stddevp;
  PyObject *__pyx_n_s_steffenson_solver;
  PyObject *__pyx_n_s_step;
  PyObject *__pyx_n_s_stereo2mono;
  PyObject *__pyx_n_s_stft;
  PyObject *__pyx_n_s_sto;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_n_s_str_2;
  PyObject *__pyx_n_s_string;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_strip;
  PyObject *__pyx_n_s_strongly_connected_components;
  PyObject *__pyx_n_s_student;
  PyObject *__pyx_n_s_student_cdf;
  PyObject *__pyx_n_s_student_icdf;
  PyObject *__pyx_n_s_studentd;
  PyObject *__pyx_n_s_studentt;
  PyObject *__pyx_n_s_sturm;
  PyObject *__pyx_n_s_sturmab;
  PyObject *__pyx_n_s_sturmseq;
  PyObject *__pyx_n_s_style;
  PyObject *__pyx_n_s_sub;
  PyObject *__pyx_n_s_subMat;
  PyObject *__pyx_n_s_subdivide_edges;
  PyObject *__pyx_n_s_subgraph;
  PyObject *__pyx_n_s_subs;
  PyObject *__pyx_n_s_subsop;
  PyObject *__pyx_n_s_subst;
  PyObject *__pyx_n_s_substituer;
  PyObject *__pyx_n_s_subtype;
  PyObject *__pyx_n_s_subtype_2;
  PyObject *__pyx_n_s_sum;
  PyObject *__pyx_n_s_sum_riemann;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_supposons;
  PyObject *__pyx_n_s_suppress;
  PyObject *__pyx_n_s_surd;
  PyObject *__pyx_n_s_svd;
  PyObject *__pyx_n_s_swapcol;
  PyObject *__pyx_n_s_swaprow;
  PyObject *__pyx_n_s_switch;
  PyObject *__pyx_n_s_switch_axes;
  PyObject *__pyx_n_s_sylvester;
  PyObject *__pyx_n_s_symb2poly;
  PyObject *__pyx_n_s_symbol;
  PyObject *__pyx_n_s_symbol_array;
  PyObject *__pyx_n_s_syr;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_s_syst2mat;
  PyObject *__pyx_n_s_t;
  PyObject *__pyx_n_s_tCollect;
  PyObject *__pyx_n_s_tExpand;
  PyObject *__pyx_n_s_table;
  PyObject *__pyx_n_s_tablefunc;
  PyObject *__pyx_n_s_tableseq;
  PyObject *__pyx_n_s_tabsign;
  PyObject *__pyx_n_s_tabvar;
  PyObject *__pyx_n_s_tail;
  PyObject *__pyx_n_s_tan;
  PyObject *__pyx_n_s_tan2cossin2;
  PyObject *__pyx_n_s_tan2sincos;
  PyObject *__pyx_n_s_tan2sincos2;
  PyObject *__pyx_n_s_tangent;
  PyObject *__pyx_n_s_tangente;
  PyObject *__pyx_n_s_tanh;
  PyObject *__pyx_n_s_tantque;
  PyObject *__pyx_n_s_tar;
  PyObject *__pyx_n_s_taux_accroissement;
  PyObject *__pyx_n_s_taylor;
  PyObject *__pyx_n_s_tbsp;
  PyObject *__pyx_n_s_tchebyshev1;
  PyObject *__pyx_n_s_tchebyshev2;
  PyObject *__pyx_n_s_tcoeff;
  PyObject *__pyx_n_s_tcollect;
  PyObject *__pyx_n_s_tdeg;
  PyObject *__pyx_n_s_teal;
  PyObject *__pyx_n_s_tec;
  PyObject *__pyx_n_s_tensor_product;
  PyObject *__pyx_n_s_tep;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_test_2;
  PyObject *__pyx_n_s_tetrahedron;
  PyObject *__pyx_n_s_tex;
  PyObject *__pyx_n_s_texpand;
  PyObject *__pyx_n_s_textinput;
  PyObject *__pyx_n_s_then;
  PyObject *__pyx_n_s_therm;
  PyObject *__pyx_n_s_thickness;
  PyObject *__pyx_n_s_thiele;
  PyObject *__pyx_n_s_threadeval;
  PyObject *__pyx_kp_s_threads_s;
  PyObject *__pyx_n_s_threshold;
  PyObject *__pyx_n_s_throw;
  PyObject *__pyx_n_s_time;
  PyObject *__pyx_n_s_title;
  PyObject *__pyx_n_s_titre;
  PyObject *__pyx_n_s_tlin;
  PyObject *__pyx_n_s_tmp;
  PyObject *__pyx_n_s_to;
  PyObject *__pyx_n_s_ton;
  PyObject *__pyx_n_s_tonUK;
  PyObject *__pyx_n_s_tonnetz;
  PyObject *__pyx_n_s_topologic_sort;
  PyObject *__pyx_n_s_topological_sort;
  PyObject *__pyx_n_s_topology;
  PyObject *__pyx_n_s_toqcas;
  PyObject *__pyx_n_s_toremove;
  PyObject *__pyx_n_s_torr;
  PyObject *__pyx_n_s_torus_grid_graph;
  PyObject *__pyx_n_s_total_degree;
  PyObject *__pyx_n_s_tourne_droite;
  PyObject *__pyx_n_s_tourne_gauche;
  PyObject *__pyx_n_s_tpsolve;
  PyObject *__pyx_n_s_tr;
  PyObject *__pyx_kp_s_tr_min;
  PyObject *__pyx_kp_s_tr_s;
  PyObject *__pyx_n_s_trace;
  PyObject *__pyx_n_s_trail;
  PyObject *__pyx_n_s_trail2edges;
  PyObject *__pyx_n_s_train;
  PyObject *__pyx_n_s_trames;
  PyObject *__pyx_n_s_tran;
  PyObject *__pyx_n_s_transitive_closure;
  PyObject *__pyx_n_s_translation;
  PyObject *__pyx_n_s_transpose;
  PyObject *__pyx_n_s_trapeze;
  PyObject *__pyx_n_s_trapezoid;
  PyObject *__pyx_n_s_traveling_salesman;
  PyObject *__pyx_n_s_tree;
  PyObject *__pyx_n_s_tree_height;
  PyObject *__pyx_n_s_tri;
  PyObject *__pyx_n_s_triangle;
  PyObject *__pyx_n_s_triangle_paper;
  PyObject *__pyx_n_s_triangle_plein;
  PyObject *__pyx_n_s_triangle_point;
  PyObject *__pyx_n_s_triangle_window;
  PyObject *__pyx_n_s_trig2exp;
  PyObject *__pyx_n_s_trigcos;
  PyObject *__pyx_n_s_trigexpand;
  PyObject *__pyx_n_s_triginterp;
  PyObject *__pyx_n_s_trigsimplify;
  PyObject *__pyx_n_s_trigsin;
  PyObject *__pyx_n_s_trigtan;
  PyObject *__pyx_n_s_trim;
  PyObject *__pyx_n_s_trn;
  PyObject *__pyx_n_s_true;
  PyObject *__pyx_n_s_truediv;
  PyObject *__pyx_n_s_trunc;
  PyObject *__pyx_n_s_truncate;
  PyObject *__pyx_n_s_truncate_graph;
  PyObject *__pyx_n_s_try;
  PyObject *__pyx_kp_s_trying_soft_interruption_wait_2s;
  PyObject *__pyx_n_s_tsimplify;
  PyObject *__pyx_n_s_tsp;
  PyObject *__pyx_n_s_tstep;
  PyObject *__pyx_n_s_tuer;
  PyObject *__pyx_n_s_tukey_window;
  PyObject *__pyx_n_s_tutte_polynomial;
  PyObject *__pyx_n_s_two_edge_connected_components;
  PyObject *__pyx_n_s_twopi;
  PyObject *__pyx_n_s_type;
  PyObject *__pyx_n_s_type_2;
  PyObject *__pyx_n_s_u;
  PyObject *__pyx_n_s_ufactor;
  PyObject *__pyx_n_s_ugamma;
  PyObject *__pyx_n_s_unapply;
  PyObject *__pyx_n_s_unarchive;
  PyObject *__pyx_n_s_undef;
  PyObject *__pyx_n_s_underlying_graph;
  PyObject *__pyx_n_s_unfactored;
  PyObject *__pyx_n_s_uniform;
  PyObject *__pyx_n_s_uniform_cdf;
  PyObject *__pyx_n_s_uniform_icdf;
  PyObject *__pyx_n_s_uniformd;
  PyObject *__pyx_n_s_uniformd_cdf;
  PyObject *__pyx_n_s_uniformd_icdf;
  PyObject *__pyx_n_s_union;
  PyObject *__pyx_n_s_unitV;
  PyObject *__pyx_n_s_unquote;
  PyObject *__pyx_n_s_until;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_upper;
  PyObject *__pyx_n_s_url;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_n_s_user_operator;
  PyObject *__pyx_n_s_usimplify;
  PyObject *__pyx_kp_s_using_sendtext;
  PyObject *__pyx_n_s_ustep;
  PyObject *__pyx_n_s_val;
  PyObject *__pyx_n_s_valuation;
  PyObject *__pyx_n_s_vandermonde;
  PyObject *__pyx_n_s_var;
  PyObject *__pyx_n_s_variables_are_files;
  PyObject *__pyx_n_s_variance;
  PyObject *__pyx_n_s_vector;
  PyObject *__pyx_n_s_vers;
  PyObject *__pyx_n_s_version;
  PyObject *__pyx_n_s_version_info;
  PyObject *__pyx_n_s_vert;
  PyObject *__pyx_n_s_vertex_connectivity;
  PyObject *__pyx_n_s_vertex_cover_number;
  PyObject *__pyx_n_s_vertex_degree;
  PyObject *__pyx_n_s_vertex_distance;
  PyObject *__pyx_n_s_vertex_in_degree;
  PyObject *__pyx_n_s_vertex_out_degree;
  PyObject *__pyx_n_s_vertices;
  PyObject *__pyx_n_s_vertices_abc;
  PyObject *__pyx_n_s_vertices_abca;
  PyObject *__pyx_kp_u_vide_Pygen_giac_version_dpt_eit;
  PyObject *__pyx_n_s_violet;
  PyObject *__pyx_n_s_vpotential;
  PyObject *__pyx_n_s_vrai;
  PyObject *__pyx_n_s_vstep;
  PyObject *__pyx_kp_s_warning_Killing_thread;
  PyObject *__pyx_n_s_watch;
  PyObject *__pyx_n_s_web_graph;
  PyObject *__pyx_n_s_webbrowser;
  PyObject *__pyx_n_s_weibull;
  PyObject *__pyx_n_s_weibull_cdf;
  PyObject *__pyx_n_s_weibull_icdf;
  PyObject *__pyx_n_s_weibulld;
  PyObject *__pyx_n_s_weibulld_cdf;
  PyObject *__pyx_n_s_weibulld_icdf;
  PyObject *__pyx_n_s_weibullvariate;
  PyObject *__pyx_n_s_weight_decay;
  PyObject *__pyx_n_s_weight_matrix;
  PyObject *__pyx_n_s_weighted;
  PyObject *__pyx_n_s_weights;
  PyObject *__pyx_n_s_welch_window;
  PyObject *__pyx_n_s_wheel_graph;
  PyObject *__pyx_n_s_when;
  PyObject *__pyx_n_s_while;
  PyObject *__pyx_n_s_white;
  PyObject *__pyx_n_s_widget_size;
  PyObject *__pyx_n_s_wilcoxonp;
  PyObject *__pyx_n_s_wilcoxons;
  PyObject *__pyx_n_s_wilcoxont;
  PyObject *__pyx_n_s_with_sqrt;
  PyObject *__pyx_n_s_write;
  PyObject *__pyx_n_s_writergb;
  PyObject *__pyx_n_s_writewav;
  PyObject *__pyx_n_s_wwwbrowseropen;
  PyObject *__pyx_n_s_wz_certificate;
  PyObject *__pyx_n_s_xcas_mode;
  PyObject *__pyx_n_s_xml_print;
  PyObject *__pyx_n_s_xor;
  PyObject *__pyx_n_s_xstep;
  PyObject *__pyx_n_s_xyz2rgb;
  PyObject *__pyx_n_s_xyztrange;
  PyObject *__pyx_n_s_yd;
  PyObject *__pyx_kp_s_yd_2;
  PyObject *__pyx_kp_s_yd_3;
  PyObject *__pyx_n_s_yellow;
  PyObject *__pyx_n_s_yr;
  PyObject *__pyx_n_s_ystep;
  PyObject *__pyx_n_s_zeros;
  PyObject *__pyx_n_s_zip;
  PyObject *__pyx_n_s_znorder;
  PyObject *__pyx_n_s_znprimroot;
  PyObject *__pyx_n_s_zstep;
  PyObject *__pyx_n_s_ztrans;
  PyObject *__pyx_float_0_05;
  PyObject *__pyx_float_0_001;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_7;
  PyObject *__pyx_int_8;
  PyObject *__pyx_int_12;
  PyObject *__pyx_int_14;
  PyObject *__pyx_int_100;
  PyObject *__pyx_int_1000000;
  PyObject *__pyx_int_222419149;
  PyObject *__pyx_int_228825662;
  PyObject *__pyx_int_238750788;
  PyObject *__pyx_tuple_;
  PyObject *__pyx_slice__2;
  PyObject *__pyx_tuple__3;
  PyObject *__pyx_tuple__4;
  PyObject *__pyx_tuple__5;
  PyObject *__pyx_tuple__6;
  PyObject *__pyx_tuple__7;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__22;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_codeobj__16;
  PyObject *__pyx_codeobj__17;
  PyObject *__pyx_codeobj__19;
  PyObject *__pyx_codeobj__21;
  PyObject *__pyx_codeobj__23;
  PyObject *__pyx_codeobj__25;
  PyObject *__pyx_codeobj__26;
  PyObject *__pyx_codeobj__27;
  PyObject *__pyx_codeobj__28;
  PyObject *__pyx_codeobj__29;
  PyObject *__pyx_codeobj__30;
  PyObject *__pyx_codeobj__31;
  PyObject *__pyx_codeobj__32;
  PyObject *__pyx_codeobj__33;
  PyObject *__pyx_codeobj__34;
  PyObject *__pyx_codeobj__35;
  PyObject *__pyx_codeobj__36;
  PyObject *__pyx_codeobj__37;
  PyObject *__pyx_codeobj__38;
  PyObject *__pyx_codeobj__39;
  PyObject *__pyx_codeobj__40;
  PyObject *__pyx_codeobj__41;
  PyObject *__pyx_codeobj__42;
  PyObject *__pyx_codeobj__43;
  PyObject *__pyx_codeobj__44;
  PyObject *__pyx_codeobj__45;
  PyObject *__pyx_codeobj__46;
  PyObject *__pyx_codeobj__47;
  PyObject *__pyx_codeobj__48;
  PyObject *__pyx_codeobj__49;
  PyObject *__pyx_codeobj__50;
  PyObject *__pyx_codeobj__51;
  PyObject *__pyx_codeobj__52;
  PyObject *__pyx_codeobj__53;
  PyObject *__pyx_codeobj__54;
  PyObject *__pyx_codeobj__55;
  PyObject *__pyx_codeobj__56;
  PyObject *__pyx_codeobj__57;
  PyObject *__pyx_codeobj__58;
  PyObject *__pyx_codeobj__59;
  PyObject *__pyx_codeobj__60;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__62;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__64;
  PyObject *__pyx_codeobj__65;
  PyObject *__pyx_codeobj__66;
  PyObject *__pyx_codeobj__67;
  PyObject *__pyx_codeobj__68;
  PyObject *__pyx_codeobj__69;
  PyObject *__pyx_codeobj__70;
  PyObject *__pyx_codeobj__71;
  PyObject *__pyx_codeobj__72;
  PyObject *__pyx_codeobj__73;
  PyObject *__pyx_codeobj__74;
  PyObject *__pyx_codeobj__75;
  PyObject *__pyx_codeobj__76;
  PyObject *__pyx_codeobj__77;
  PyObject *__pyx_codeobj__78;
  PyObject *__pyx_codeobj__79;
  PyObject *__pyx_codeobj__80;
  PyObject *__pyx_codeobj__81;
  PyObject *__pyx_codeobj__82;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__84;
  PyObject *__pyx_codeobj__85;
  PyObject *__pyx_codeobj__86;
  PyObject *__pyx_codeobj__87;
  PyObject *__pyx_codeobj__88;
  PyObject *__pyx_codeobj__89;
  PyObject *__pyx_codeobj__90;
  PyObject *__pyx_codeobj__91;
  PyObject *__pyx_codeobj__92;
  PyObject *__pyx_codeobj__93;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__95;
  PyObject *__pyx_codeobj__96;
  PyObject *__pyx_codeobj__97;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__99;
  PyObject *__pyx_tuple__1627;
  PyObject *__pyx_tuple__1630;
  PyObject *__pyx_tuple__1632;
  PyObject *__pyx_tuple__1637;
  PyObject *__pyx_tuple__1639;
  PyObject *__pyx_tuple__1641;
  PyObject *__pyx_tuple__1643;
  PyObject *__pyx_tuple__1645;
  PyObject *__pyx_tuple__1646;
  PyObject *__pyx_tuple__1650;
  PyObject *__pyx_tuple__1651;
  PyObject *__pyx_tuple__1653;
  PyObject *__pyx_tuple__1702;
  PyObject *__pyx_tuple__1707;
  PyObject *__pyx_tuple__1713;
  PyObject *__pyx_tuple__1719;
  PyObject *__pyx_tuple__1721;
  PyObject *__pyx_tuple__1722;
  PyObject *__pyx_tuple__1724;
  PyObject *__pyx_tuple__1726;
  PyObject *__pyx_codeobj__100;
  PyObject *__pyx_codeobj__101;
  PyObject *__pyx_codeobj__102;
  PyObject *__pyx_codeobj__103;
  PyObject *__pyx_codeobj__104;
  PyObject *__pyx_codeobj__105;
  PyObject *__pyx_codeobj__106;
  PyObject *__pyx_codeobj__107;
  PyObject *__pyx_codeobj__108;
  PyObject *__pyx_codeobj__109;
  PyObject *__pyx_codeobj__110;
  PyObject *__pyx_codeobj__111;
  PyObject *__pyx_codeobj__112;
  PyObject *__pyx_codeobj__113;
  PyObject *__pyx_codeobj__114;
  PyObject *__pyx_codeobj__115;
  PyObject *__pyx_codeobj__116;
  PyObject *__pyx_codeobj__117;
  PyObject *__pyx_codeobj__118;
  PyObject *__pyx_codeobj__119;
  PyObject *__pyx_codeobj__120;
  PyObject *__pyx_codeobj__121;
  PyObject *__pyx_codeobj__122;
  PyObject *__pyx_codeobj__123;
  PyObject *__pyx_codeobj__124;
  PyObject *__pyx_codeobj__125;
  PyObject *__pyx_codeobj__126;
  PyObject *__pyx_codeobj__127;
  PyObject *__pyx_codeobj__128;
  PyObject *__pyx_codeobj__129;
  PyObject *__pyx_codeobj__130;
  PyObject *__pyx_codeobj__131;
  PyObject *__pyx_codeobj__132;
  PyObject *__pyx_codeobj__133;
  PyObject *__pyx_codeobj__134;
  PyObject *__pyx_codeobj__135;
  PyObject *__pyx_codeobj__136;
  PyObject *__pyx_codeobj__137;
  PyObject *__pyx_codeobj__138;
  PyObject *__pyx_codeobj__139;
  PyObject *__pyx_codeobj__140;
  PyObject *__pyx_codeobj__141;
  PyObject *__pyx_codeobj__142;
  PyObject *__pyx_codeobj__143;
  PyObject *__pyx_codeobj__144;
  PyObject *__pyx_codeobj__145;
  PyObject *__pyx_codeobj__146;
  PyObject *__pyx_codeobj__147;
  PyObject *__pyx_codeobj__148;
  PyObject *__pyx_codeobj__149;
  PyObject *__pyx_codeobj__150;
  PyObject *__pyx_codeobj__151;
  PyObject *__pyx_codeobj__152;
  PyObject *__pyx_codeobj__153;
  PyObject *__pyx_codeobj__154;
  PyObject *__pyx_codeobj__155;
  PyObject *__pyx_codeobj__156;
  PyObject *__pyx_codeobj__157;
  PyObject *__pyx_codeobj__158;
  PyObject *__pyx_codeobj__159;
  PyObject *__pyx_codeobj__160;
  PyObject *__pyx_codeobj__161;
  PyObject *__pyx_codeobj__162;
  PyObject *__pyx_codeobj__163;
  PyObject *__pyx_codeobj__164;
  PyObject *__pyx_codeobj__165;
  PyObject *__pyx_codeobj__166;
  PyObject *__pyx_codeobj__167;
  PyObject *__pyx_codeobj__168;
  PyObject *__pyx_codeobj__169;
  PyObject *__pyx_codeobj__170;
  PyObject *__pyx_codeobj__171;
  PyObject *__pyx_codeobj__172;
  PyObject *__pyx_codeobj__173;
  PyObject *__pyx_codeobj__174;
  PyObject *__pyx_codeobj__175;
  PyObject *__pyx_codeobj__176;
  PyObject *__pyx_codeobj__177;
  PyObject *__pyx_codeobj__178;
  PyObject *__pyx_codeobj__179;
  PyObject *__pyx_codeobj__180;
  PyObject *__pyx_codeobj__181;
  PyObject *__pyx_codeobj__182;
  PyObject *__pyx_codeobj__183;
  PyObject *__pyx_codeobj__184;
  PyObject *__pyx_codeobj__185;
  PyObject *__pyx_codeobj__186;
  PyObject *__pyx_codeobj__187;
  PyObject *__pyx_codeobj__188;
  PyObject *__pyx_codeobj__189;
  PyObject *__pyx_codeobj__190;
  PyObject *__pyx_codeobj__191;
  PyObject *__pyx_codeobj__192;
  PyObject *__pyx_codeobj__193;
  PyObject *__pyx_codeobj__194;
  PyObject *__pyx_codeobj__195;
  PyObject *__pyx_codeobj__196;
  PyObject *__pyx_codeobj__197;
  PyObject *__pyx_codeobj__198;
  PyObject *__pyx_codeobj__199;
  PyObject *__pyx_codeobj__200;
  PyObject *__pyx_codeobj__201;
  PyObject *__pyx_codeobj__202;
  PyObject *__pyx_codeobj__203;
  PyObject *__pyx_codeobj__204;
  PyObject *__pyx_codeobj__205;
  PyObject *__pyx_codeobj__206;
  PyObject *__pyx_codeobj__207;
  PyObject *__pyx_codeobj__208;
  PyObject *__pyx_codeobj__209;
  PyObject *__pyx_codeobj__210;
  PyObject *__pyx_codeobj__211;
  PyObject *__pyx_codeobj__212;
  PyObject *__pyx_codeobj__213;
  PyObject *__pyx_codeobj__214;
  PyObject *__pyx_codeobj__215;
  PyObject *__pyx_codeobj__216;
  PyObject *__pyx_codeobj__217;
  PyObject *__pyx_codeobj__218;
  PyObject *__pyx_codeobj__219;
  PyObject *__pyx_codeobj__220;
  PyObject *__pyx_codeobj__221;
  PyObject *__pyx_codeobj__222;
  PyObject *__pyx_codeobj__223;
  PyObject *__pyx_codeobj__224;
  PyObject *__pyx_codeobj__225;
  PyObject *__pyx_codeobj__226;
  PyObject *__pyx_codeobj__227;
  PyObject *__pyx_codeobj__228;
  PyObject *__pyx_codeobj__229;
  PyObject *__pyx_codeobj__230;
  PyObject *__pyx_codeobj__231;
  PyObject *__pyx_codeobj__232;
  PyObject *__pyx_codeobj__233;
  PyObject *__pyx_codeobj__234;
  PyObject *__pyx_codeobj__235;
  PyObject *__pyx_codeobj__236;
  PyObject *__pyx_codeobj__237;
  PyObject *__pyx_codeobj__238;
  PyObject *__pyx_codeobj__239;
  PyObject *__pyx_codeobj__240;
  PyObject *__pyx_codeobj__241;
  PyObject *__pyx_codeobj__242;
  PyObject *__pyx_codeobj__243;
  PyObject *__pyx_codeobj__244;
  PyObject *__pyx_codeobj__245;
  PyObject *__pyx_codeobj__246;
  PyObject *__pyx_codeobj__247;
  PyObject *__pyx_codeobj__248;
  PyObject *__pyx_codeobj__249;
  PyObject *__pyx_codeobj__250;
  PyObject *__pyx_codeobj__251;
  PyObject *__pyx_codeobj__252;
  PyObject *__pyx_codeobj__253;
  PyObject *__pyx_codeobj__254;
  PyObject *__pyx_codeobj__255;
  PyObject *__pyx_codeobj__256;
  PyObject *__pyx_codeobj__257;
  PyObject *__pyx_codeobj__258;
  PyObject *__pyx_codeobj__259;
  PyObject *__pyx_codeobj__260;
  PyObject *__pyx_codeobj__261;
  PyObject *__pyx_codeobj__262;
  PyObject *__pyx_codeobj__263;
  PyObject *__pyx_codeobj__264;
  PyObject *__pyx_codeobj__265;
  PyObject *__pyx_codeobj__266;
  PyObject *__pyx_codeobj__267;
  PyObject *__pyx_codeobj__268;
  PyObject *__pyx_codeobj__269;
  PyObject *__pyx_codeobj__270;
  PyObject *__pyx_codeobj__271;
  PyObject *__pyx_codeobj__272;
  PyObject *__pyx_codeobj__273;
  PyObject *__pyx_codeobj__274;
  PyObject *__pyx_codeobj__275;
  PyObject *__pyx_codeobj__276;
  PyObject *__pyx_codeobj__277;
  PyObject *__pyx_codeobj__278;
  PyObject *__pyx_codeobj__279;
  PyObject *__pyx_codeobj__280;
  PyObject *__pyx_codeobj__281;
  PyObject *__pyx_codeobj__282;
  PyObject *__pyx_codeobj__283;
  PyObject *__pyx_codeobj__284;
  PyObject *__pyx_codeobj__285;
  PyObject *__pyx_codeobj__286;
  PyObject *__pyx_codeobj__287;
  PyObject *__pyx_codeobj__288;
  PyObject *__pyx_codeobj__289;
  PyObject *__pyx_codeobj__290;
  PyObject *__pyx_codeobj__291;
  PyObject *__pyx_codeobj__292;
  PyObject *__pyx_codeobj__293;
  PyObject *__pyx_codeobj__294;
  PyObject *__pyx_codeobj__295;
  PyObject *__pyx_codeobj__296;
  PyObject *__pyx_codeobj__297;
  PyObject *__pyx_codeobj__298;
  PyObject *__pyx_codeobj__299;
  PyObject *__pyx_codeobj__300;
  PyObject *__pyx_codeobj__301;
  PyObject *__pyx_codeobj__302;
  PyObject *__pyx_codeobj__303;
  PyObject *__pyx_codeobj__304;
  PyObject *__pyx_codeobj__305;
  PyObject *__pyx_codeobj__306;
  PyObject *__pyx_codeobj__307;
  PyObject *__pyx_codeobj__308;
  PyObject *__pyx_codeobj__309;
  PyObject *__pyx_codeobj__310;
  PyObject *__pyx_codeobj__311;
  PyObject *__pyx_codeobj__312;
  PyObject *__pyx_codeobj__313;
  PyObject *__pyx_codeobj__314;
  PyObject *__pyx_codeobj__315;
  PyObject *__pyx_codeobj__316;
  PyObject *__pyx_codeobj__317;
  PyObject *__pyx_codeobj__318;
  PyObject *__pyx_codeobj__319;
  PyObject *__pyx_codeobj__320;
  PyObject *__pyx_codeobj__321;
  PyObject *__pyx_codeobj__322;
  PyObject *__pyx_codeobj__323;
  PyObject *__pyx_codeobj__324;
  PyObject *__pyx_codeobj__325;
  PyObject *__pyx_codeobj__326;
  PyObject *__pyx_codeobj__327;
  PyObject *__pyx_codeobj__328;
  PyObject *__pyx_codeobj__329;
  PyObject *__pyx_codeobj__330;
  PyObject *__pyx_codeobj__331;
  PyObject *__pyx_codeobj__332;
  PyObject *__pyx_codeobj__333;
  PyObject *__pyx_codeobj__334;
  PyObject *__pyx_codeobj__335;
  PyObject *__pyx_codeobj__336;
  PyObject *__pyx_codeobj__337;
  PyObject *__pyx_codeobj__338;
  PyObject *__pyx_codeobj__339;
  PyObject *__pyx_codeobj__340;
  PyObject *__pyx_codeobj__341;
  PyObject *__pyx_codeobj__342;
  PyObject *__pyx_codeobj__343;
  PyObject *__pyx_codeobj__344;
  PyObject *__pyx_codeobj__345;
  PyObject *__pyx_codeobj__346;
  PyObject *__pyx_codeobj__347;
  PyObject *__pyx_codeobj__348;
  PyObject *__pyx_codeobj__349;
  PyObject *__pyx_codeobj__350;
  PyObject *__pyx_codeobj__351;
  PyObject *__pyx_codeobj__352;
  PyObject *__pyx_codeobj__353;
  PyObject *__pyx_codeobj__354;
  PyObject *__pyx_codeobj__355;
  PyObject *__pyx_codeobj__356;
  PyObject *__pyx_codeobj__357;
  PyObject *__pyx_codeobj__358;
  PyObject *__pyx_codeobj__359;
  PyObject *__pyx_codeobj__360;
  PyObject *__pyx_codeobj__361;
  PyObject *__pyx_codeobj__362;
  PyObject *__pyx_codeobj__363;
  PyObject *__pyx_codeobj__364;
  PyObject *__pyx_codeobj__365;
  PyObject *__pyx_codeobj__366;
  PyObject *__pyx_codeobj__367;
  PyObject *__pyx_codeobj__368;
  PyObject *__pyx_codeobj__369;
  PyObject *__pyx_codeobj__370;
  PyObject *__pyx_codeobj__371;
  PyObject *__pyx_codeobj__372;
  PyObject *__pyx_codeobj__373;
  PyObject *__pyx_codeobj__374;
  PyObject *__pyx_codeobj__375;
  PyObject *__pyx_codeobj__376;
  PyObject *__pyx_codeobj__377;
  PyObject *__pyx_codeobj__378;
  PyObject *__pyx_codeobj__379;
  PyObject *__pyx_codeobj__380;
  PyObject *__pyx_codeobj__381;
  PyObject *__pyx_codeobj__382;
  PyObject *__pyx_codeobj__383;
  PyObject *__pyx_codeobj__384;
  PyObject *__pyx_codeobj__385;
  PyObject *__pyx_codeobj__386;
  PyObject *__pyx_codeobj__387;
  PyObject *__pyx_codeobj__388;
  PyObject *__pyx_codeobj__389;
  PyObject *__pyx_codeobj__390;
  PyObject *__pyx_codeobj__391;
  PyObject *__pyx_codeobj__392;
  PyObject *__pyx_codeobj__393;
  PyObject *__pyx_codeobj__394;
  PyObject *__pyx_codeobj__395;
  PyObject *__pyx_codeobj__396;
  PyObject *__pyx_codeobj__397;
  PyObject *__pyx_codeobj__398;
  PyObject *__pyx_codeobj__399;
  PyObject *__pyx_codeobj__400;
  PyObject *__pyx_codeobj__401;
  PyObject *__pyx_codeobj__402;
  PyObject *__pyx_codeobj__403;
  PyObject *__pyx_codeobj__404;
  PyObject *__pyx_codeobj__405;
  PyObject *__pyx_codeobj__406;
  PyObject *__pyx_codeobj__407;
  PyObject *__pyx_codeobj__408;
  PyObject *__pyx_codeobj__409;
  PyObject *__pyx_codeobj__410;
  PyObject *__pyx_codeobj__411;
  PyObject *__pyx_codeobj__412;
  PyObject *__pyx_codeobj__413;
  PyObject *__pyx_codeobj__414;
  PyObject *__pyx_codeobj__415;
  PyObject *__pyx_codeobj__416;
  PyObject *__pyx_codeobj__417;
  PyObject *__pyx_codeobj__418;
  PyObject *__pyx_codeobj__419;
  PyObject *__pyx_codeobj__420;
  PyObject *__pyx_codeobj__421;
  PyObject *__pyx_codeobj__422;
  PyObject *__pyx_codeobj__423;
  PyObject *__pyx_codeobj__424;
  PyObject *__pyx_codeobj__425;
  PyObject *__pyx_codeobj__426;
  PyObject *__pyx_codeobj__427;
  PyObject *__pyx_codeobj__428;
  PyObject *__pyx_codeobj__429;
  PyObject *__pyx_codeobj__430;
  PyObject *__pyx_codeobj__431;
  PyObject *__pyx_codeobj__432;
  PyObject *__pyx_codeobj__433;
  PyObject *__pyx_codeobj__434;
  PyObject *__pyx_codeobj__435;
  PyObject *__pyx_codeobj__436;
  PyObject *__pyx_codeobj__437;
  PyObject *__pyx_codeobj__438;
  PyObject *__pyx_codeobj__439;
  PyObject *__pyx_codeobj__440;
  PyObject *__pyx_codeobj__441;
  PyObject *__pyx_codeobj__442;
  PyObject *__pyx_codeobj__443;
  PyObject *__pyx_codeobj__444;
  PyObject *__pyx_codeobj__445;
  PyObject *__pyx_codeobj__446;
  PyObject *__pyx_codeobj__447;
  PyObject *__pyx_codeobj__448;
  PyObject *__pyx_codeobj__449;
  PyObject *__pyx_codeobj__450;
  PyObject *__pyx_codeobj__451;
  PyObject *__pyx_codeobj__452;
  PyObject *__pyx_codeobj__453;
  PyObject *__pyx_codeobj__454;
  PyObject *__pyx_codeobj__455;
  PyObject *__pyx_codeobj__456;
  PyObject *__pyx_codeobj__457;
  PyObject *__pyx_codeobj__458;
  PyObject *__pyx_codeobj__459;
  PyObject *__pyx_codeobj__460;
  PyObject *__pyx_codeobj__461;
  PyObject *__pyx_codeobj__462;
  PyObject *__pyx_codeobj__463;
  PyObject *__pyx_codeobj__464;
  PyObject *__pyx_codeobj__465;
  PyObject *__pyx_codeobj__466;
  PyObject *__pyx_codeobj__467;
  PyObject *__pyx_codeobj__468;
  PyObject *__pyx_codeobj__469;
  PyObject *__pyx_codeobj__470;
  PyObject *__pyx_codeobj__471;
  PyObject *__pyx_codeobj__472;
  PyObject *__pyx_codeobj__473;
  PyObject *__pyx_codeobj__474;
  PyObject *__pyx_codeobj__475;
  PyObject *__pyx_codeobj__476;
  PyObject *__pyx_codeobj__477;
  PyObject *__pyx_codeobj__478;
  PyObject *__pyx_codeobj__479;
  PyObject *__pyx_codeobj__480;
  PyObject *__pyx_codeobj__481;
  PyObject *__pyx_codeobj__482;
  PyObject *__pyx_codeobj__483;
  PyObject *__pyx_codeobj__484;
  PyObject *__pyx_codeobj__485;
  PyObject *__pyx_codeobj__486;
  PyObject *__pyx_codeobj__487;
  PyObject *__pyx_codeobj__488;
  PyObject *__pyx_codeobj__489;
  PyObject *__pyx_codeobj__490;
  PyObject *__pyx_codeobj__491;
  PyObject *__pyx_codeobj__492;
  PyObject *__pyx_codeobj__493;
  PyObject *__pyx_codeobj__494;
  PyObject *__pyx_codeobj__495;
  PyObject *__pyx_codeobj__496;
  PyObject *__pyx_codeobj__497;
  PyObject *__pyx_codeobj__498;
  PyObject *__pyx_codeobj__499;
  PyObject *__pyx_codeobj__500;
  PyObject *__pyx_codeobj__501;
  PyObject *__pyx_codeobj__502;
  PyObject *__pyx_codeobj__503;
  PyObject *__pyx_codeobj__504;
  PyObject *__pyx_codeobj__505;
  PyObject *__pyx_codeobj__506;
  PyObject *__pyx_codeobj__507;
  PyObject *__pyx_codeobj__508;
  PyObject *__pyx_codeobj__509;
  PyObject *__pyx_codeobj__510;
  PyObject *__pyx_codeobj__511;
  PyObject *__pyx_codeobj__512;
  PyObject *__pyx_codeobj__513;
  PyObject *__pyx_codeobj__514;
  PyObject *__pyx_codeobj__515;
  PyObject *__pyx_codeobj__516;
  PyObject *__pyx_codeobj__517;
  PyObject *__pyx_codeobj__518;
  PyObject *__pyx_codeobj__519;
  PyObject *__pyx_codeobj__520;
  PyObject *__pyx_codeobj__521;
  PyObject *__pyx_codeobj__522;
  PyObject *__pyx_codeobj__523;
  PyObject *__pyx_codeobj__524;
  PyObject *__pyx_codeobj__525;
  PyObject *__pyx_codeobj__526;
  PyObject *__pyx_codeobj__527;
  PyObject *__pyx_codeobj__528;
  PyObject *__pyx_codeobj__529;
  PyObject *__pyx_codeobj__530;
  PyObject *__pyx_codeobj__531;
  PyObject *__pyx_codeobj__532;
  PyObject *__pyx_codeobj__533;
  PyObject *__pyx_codeobj__534;
  PyObject *__pyx_codeobj__535;
  PyObject *__pyx_codeobj__536;
  PyObject *__pyx_codeobj__537;
  PyObject *__pyx_codeobj__538;
  PyObject *__pyx_codeobj__539;
  PyObject *__pyx_codeobj__540;
  PyObject *__pyx_codeobj__541;
  PyObject *__pyx_codeobj__542;
  PyObject *__pyx_codeobj__543;
  PyObject *__pyx_codeobj__544;
  PyObject *__pyx_codeobj__545;
  PyObject *__pyx_codeobj__546;
  PyObject *__pyx_codeobj__547;
  PyObject *__pyx_codeobj__548;
  PyObject *__pyx_codeobj__549;
  PyObject *__pyx_codeobj__550;
  PyObject *__pyx_codeobj__551;
  PyObject *__pyx_codeobj__552;
  PyObject *__pyx_codeobj__553;
  PyObject *__pyx_codeobj__554;
  PyObject *__pyx_codeobj__555;
  PyObject *__pyx_codeobj__556;
  PyObject *__pyx_codeobj__557;
  PyObject *__pyx_codeobj__558;
  PyObject *__pyx_codeobj__559;
  PyObject *__pyx_codeobj__560;
  PyObject *__pyx_codeobj__561;
  PyObject *__pyx_codeobj__562;
  PyObject *__pyx_codeobj__563;
  PyObject *__pyx_codeobj__564;
  PyObject *__pyx_codeobj__565;
  PyObject *__pyx_codeobj__566;
  PyObject *__pyx_codeobj__567;
  PyObject *__pyx_codeobj__568;
  PyObject *__pyx_codeobj__569;
  PyObject *__pyx_codeobj__570;
  PyObject *__pyx_codeobj__571;
  PyObject *__pyx_codeobj__572;
  PyObject *__pyx_codeobj__573;
  PyObject *__pyx_codeobj__574;
  PyObject *__pyx_codeobj__575;
  PyObject *__pyx_codeobj__576;
  PyObject *__pyx_codeobj__577;
  PyObject *__pyx_codeobj__578;
  PyObject *__pyx_codeobj__579;
  PyObject *__pyx_codeobj__580;
  PyObject *__pyx_codeobj__581;
  PyObject *__pyx_codeobj__582;
  PyObject *__pyx_codeobj__583;
  PyObject *__pyx_codeobj__584;
  PyObject *__pyx_codeobj__585;
  PyObject *__pyx_codeobj__586;
  PyObject *__pyx_codeobj__587;
  PyObject *__pyx_codeobj__588;
  PyObject *__pyx_codeobj__589;
  PyObject *__pyx_codeobj__590;
  PyObject *__pyx_codeobj__591;
  PyObject *__pyx_codeobj__592;
  PyObject *__pyx_codeobj__593;
  PyObject *__pyx_codeobj__594;
  PyObject *__pyx_codeobj__595;
  PyObject *__pyx_codeobj__596;
  PyObject *__pyx_codeobj__597;
  PyObject *__pyx_codeobj__598;
  PyObject *__pyx_codeobj__599;
  PyObject *__pyx_codeobj__600;
  PyObject *__pyx_codeobj__601;
  PyObject *__pyx_codeobj__602;
  PyObject *__pyx_codeobj__603;
  PyObject *__pyx_codeobj__604;
  PyObject *__pyx_codeobj__605;
  PyObject *__pyx_codeobj__606;
  PyObject *__pyx_codeobj__607;
  PyObject *__pyx_codeobj__608;
  PyObject *__pyx_codeobj__609;
  PyObject *__pyx_codeobj__610;
  PyObject *__pyx_codeobj__611;
  PyObject *__pyx_codeobj__612;
  PyObject *__pyx_codeobj__613;
  PyObject *__pyx_codeobj__614;
  PyObject *__pyx_codeobj__615;
  PyObject *__pyx_codeobj__616;
  PyObject *__pyx_codeobj__617;
  PyObject *__pyx_codeobj__618;
  PyObject *__pyx_codeobj__619;
  PyObject *__pyx_codeobj__620;
  PyObject *__pyx_codeobj__621;
  PyObject *__pyx_codeobj__622;
  PyObject *__pyx_codeobj__623;
  PyObject *__pyx_codeobj__624;
  PyObject *__pyx_codeobj__625;
  PyObject *__pyx_codeobj__626;
  PyObject *__pyx_codeobj__627;
  PyObject *__pyx_codeobj__628;
  PyObject *__pyx_codeobj__629;
  PyObject *__pyx_codeobj__630;
  PyObject *__pyx_codeobj__631;
  PyObject *__pyx_codeobj__632;
  PyObject *__pyx_codeobj__633;
  PyObject *__pyx_codeobj__634;
  PyObject *__pyx_codeobj__635;
  PyObject *__pyx_codeobj__636;
  PyObject *__pyx_codeobj__637;
  PyObject *__pyx_codeobj__638;
  PyObject *__pyx_codeobj__639;
  PyObject *__pyx_codeobj__640;
  PyObject *__pyx_codeobj__641;
  PyObject *__pyx_codeobj__642;
  PyObject *__pyx_codeobj__643;
  PyObject *__pyx_codeobj__644;
  PyObject *__pyx_codeobj__645;
  PyObject *__pyx_codeobj__646;
  PyObject *__pyx_codeobj__647;
  PyObject *__pyx_codeobj__648;
  PyObject *__pyx_codeobj__649;
  PyObject *__pyx_codeobj__650;
  PyObject *__pyx_codeobj__651;
  PyObject *__pyx_codeobj__652;
  PyObject *__pyx_codeobj__653;
  PyObject *__pyx_codeobj__654;
  PyObject *__pyx_codeobj__655;
  PyObject *__pyx_codeobj__656;
  PyObject *__pyx_codeobj__657;
  PyObject *__pyx_codeobj__658;
  PyObject *__pyx_codeobj__659;
  PyObject *__pyx_codeobj__660;
  PyObject *__pyx_codeobj__661;
  PyObject *__pyx_codeobj__662;
  PyObject *__pyx_codeobj__663;
  PyObject *__pyx_codeobj__664;
  PyObject *__pyx_codeobj__665;
  PyObject *__pyx_codeobj__666;
  PyObject *__pyx_codeobj__667;
  PyObject *__pyx_codeobj__668;
  PyObject *__pyx_codeobj__669;
  PyObject *__pyx_codeobj__670;
  PyObject *__pyx_codeobj__671;
  PyObject *__pyx_codeobj__672;
  PyObject *__pyx_codeobj__673;
  PyObject *__pyx_codeobj__674;
  PyObject *__pyx_codeobj__675;
  PyObject *__pyx_codeobj__676;
  PyObject *__pyx_codeobj__677;
  PyObject *__pyx_codeobj__678;
  PyObject *__pyx_codeobj__679;
  PyObject *__pyx_codeobj__680;
  PyObject *__pyx_codeobj__681;
  PyObject *__pyx_codeobj__682;
  PyObject *__pyx_codeobj__683;
  PyObject *__pyx_codeobj__684;
  PyObject *__pyx_codeobj__685;
  PyObject *__pyx_codeobj__686;
  PyObject *__pyx_codeobj__687;
  PyObject *__pyx_codeobj__688;
  PyObject *__pyx_codeobj__689;
  PyObject *__pyx_codeobj__690;
  PyObject *__pyx_codeobj__691;
  PyObject *__pyx_codeobj__692;
  PyObject *__pyx_codeobj__693;
  PyObject *__pyx_codeobj__694;
  PyObject *__pyx_codeobj__695;
  PyObject *__pyx_codeobj__696;
  PyObject *__pyx_codeobj__697;
  PyObject *__pyx_codeobj__698;
  PyObject *__pyx_codeobj__699;
  PyObject *__pyx_codeobj__700;
  PyObject *__pyx_codeobj__701;
  PyObject *__pyx_codeobj__702;
  PyObject *__pyx_codeobj__703;
  PyObject *__pyx_codeobj__704;
  PyObject *__pyx_codeobj__705;
  PyObject *__pyx_codeobj__706;
  PyObject *__pyx_codeobj__707;
  PyObject *__pyx_codeobj__708;
  PyObject *__pyx_codeobj__709;
  PyObject *__pyx_codeobj__710;
  PyObject *__pyx_codeobj__711;
  PyObject *__pyx_codeobj__712;
  PyObject *__pyx_codeobj__713;
  PyObject *__pyx_codeobj__714;
  PyObject *__pyx_codeobj__715;
  PyObject *__pyx_codeobj__716;
  PyObject *__pyx_codeobj__717;
  PyObject *__pyx_codeobj__718;
  PyObject *__pyx_codeobj__719;
  PyObject *__pyx_codeobj__720;
  PyObject *__pyx_codeobj__721;
  PyObject *__pyx_codeobj__722;
  PyObject *__pyx_codeobj__723;
  PyObject *__pyx_codeobj__724;
  PyObject *__pyx_codeobj__725;
  PyObject *__pyx_codeobj__726;
  PyObject *__pyx_codeobj__727;
  PyObject *__pyx_codeobj__728;
  PyObject *__pyx_codeobj__729;
  PyObject *__pyx_codeobj__730;
  PyObject *__pyx_codeobj__731;
  PyObject *__pyx_codeobj__732;
  PyObject *__pyx_codeobj__733;
  PyObject *__pyx_codeobj__734;
  PyObject *__pyx_codeobj__735;
  PyObject *__pyx_codeobj__736;
  PyObject *__pyx_codeobj__737;
  PyObject *__pyx_codeobj__738;
  PyObject *__pyx_codeobj__739;
  PyObject *__pyx_codeobj__740;
  PyObject *__pyx_codeobj__741;
  PyObject *__pyx_codeobj__742;
  PyObject *__pyx_codeobj__743;
  PyObject *__pyx_codeobj__744;
  PyObject *__pyx_codeobj__745;
  PyObject *__pyx_codeobj__746;
  PyObject *__pyx_codeobj__747;
  PyObject *__pyx_codeobj__748;
  PyObject *__pyx_codeobj__749;
  PyObject *__pyx_codeobj__750;
  PyObject *__pyx_codeobj__751;
  PyObject *__pyx_codeobj__752;
  PyObject *__pyx_codeobj__753;
  PyObject *__pyx_codeobj__754;
  PyObject *__pyx_codeobj__755;
  PyObject *__pyx_codeobj__756;
  PyObject *__pyx_codeobj__757;
  PyObject *__pyx_codeobj__758;
  PyObject *__pyx_codeobj__759;
  PyObject *__pyx_codeobj__760;
  PyObject *__pyx_codeobj__761;
  PyObject *__pyx_codeobj__762;
  PyObject *__pyx_codeobj__763;
  PyObject *__pyx_codeobj__764;
  PyObject *__pyx_codeobj__765;
  PyObject *__pyx_codeobj__766;
  PyObject *__pyx_codeobj__767;
  PyObject *__pyx_codeobj__768;
  PyObject *__pyx_codeobj__769;
  PyObject *__pyx_codeobj__770;
  PyObject *__pyx_codeobj__771;
  PyObject *__pyx_codeobj__772;
  PyObject *__pyx_codeobj__773;
  PyObject *__pyx_codeobj__774;
  PyObject *__pyx_codeobj__775;
  PyObject *__pyx_codeobj__776;
  PyObject *__pyx_codeobj__777;
  PyObject *__pyx_codeobj__778;
  PyObject *__pyx_codeobj__779;
  PyObject *__pyx_codeobj__780;
  PyObject *__pyx_codeobj__781;
  PyObject *__pyx_codeobj__782;
  PyObject *__pyx_codeobj__783;
  PyObject *__pyx_codeobj__784;
  PyObject *__pyx_codeobj__785;
  PyObject *__pyx_codeobj__786;
  PyObject *__pyx_codeobj__787;
  PyObject *__pyx_codeobj__788;
  PyObject *__pyx_codeobj__789;
  PyObject *__pyx_codeobj__790;
  PyObject *__pyx_codeobj__791;
  PyObject *__pyx_codeobj__792;
  PyObject *__pyx_codeobj__793;
  PyObject *__pyx_codeobj__794;
  PyObject *__pyx_codeobj__795;
  PyObject *__pyx_codeobj__796;
  PyObject *__pyx_codeobj__797;
  PyObject *__pyx_codeobj__798;
  PyObject *__pyx_codeobj__799;
  PyObject *__pyx_codeobj__800;
  PyObject *__pyx_codeobj__801;
  PyObject *__pyx_codeobj__802;
  PyObject *__pyx_codeobj__803;
  PyObject *__pyx_codeobj__804;
  PyObject *__pyx_codeobj__805;
  PyObject *__pyx_codeobj__806;
  PyObject *__pyx_codeobj__807;
  PyObject *__pyx_codeobj__808;
  PyObject *__pyx_codeobj__809;
  PyObject *__pyx_codeobj__810;
  PyObject *__pyx_codeobj__811;
  PyObject *__pyx_codeobj__812;
  PyObject *__pyx_codeobj__813;
  PyObject *__pyx_codeobj__814;
  PyObject *__pyx_codeobj__815;
  PyObject *__pyx_codeobj__816;
  PyObject *__pyx_codeobj__817;
  PyObject *__pyx_codeobj__818;
  PyObject *__pyx_codeobj__819;
  PyObject *__pyx_codeobj__820;
  PyObject *__pyx_codeobj__821;
  PyObject *__pyx_codeobj__822;
  PyObject *__pyx_codeobj__823;
  PyObject *__pyx_codeobj__824;
  PyObject *__pyx_codeobj__825;
  PyObject *__pyx_codeobj__826;
  PyObject *__pyx_codeobj__827;
  PyObject *__pyx_codeobj__828;
  PyObject *__pyx_codeobj__829;
  PyObject *__pyx_codeobj__830;
  PyObject *__pyx_codeobj__831;
  PyObject *__pyx_codeobj__832;
  PyObject *__pyx_codeobj__833;
  PyObject *__pyx_codeobj__834;
  PyObject *__pyx_codeobj__835;
  PyObject *__pyx_codeobj__836;
  PyObject *__pyx_codeobj__837;
  PyObject *__pyx_codeobj__838;
  PyObject *__pyx_codeobj__839;
  PyObject *__pyx_codeobj__840;
  PyObject *__pyx_codeobj__841;
  PyObject *__pyx_codeobj__842;
  PyObject *__pyx_codeobj__843;
  PyObject *__pyx_codeobj__844;
  PyObject *__pyx_codeobj__845;
  PyObject *__pyx_codeobj__846;
  PyObject *__pyx_codeobj__847;
  PyObject *__pyx_codeobj__848;
  PyObject *__pyx_codeobj__849;
  PyObject *__pyx_codeobj__850;
  PyObject *__pyx_codeobj__851;
  PyObject *__pyx_codeobj__852;
  PyObject *__pyx_codeobj__853;
  PyObject *__pyx_codeobj__854;
  PyObject *__pyx_codeobj__855;
  PyObject *__pyx_codeobj__856;
  PyObject *__pyx_codeobj__857;
  PyObject *__pyx_codeobj__858;
  PyObject *__pyx_codeobj__859;
  PyObject *__pyx_codeobj__860;
  PyObject *__pyx_codeobj__861;
  PyObject *__pyx_codeobj__862;
  PyObject *__pyx_codeobj__863;
  PyObject *__pyx_codeobj__864;
  PyObject *__pyx_codeobj__865;
  PyObject *__pyx_codeobj__866;
  PyObject *__pyx_codeobj__867;
  PyObject *__pyx_codeobj__868;
  PyObject *__pyx_codeobj__869;
  PyObject *__pyx_codeobj__870;
  PyObject *__pyx_codeobj__871;
  PyObject *__pyx_codeobj__872;
  PyObject *__pyx_codeobj__873;
  PyObject *__pyx_codeobj__874;
  PyObject *__pyx_codeobj__875;
  PyObject *__pyx_codeobj__876;
  PyObject *__pyx_codeobj__877;
  PyObject *__pyx_codeobj__878;
  PyObject *__pyx_codeobj__879;
  PyObject *__pyx_codeobj__880;
  PyObject *__pyx_codeobj__881;
  PyObject *__pyx_codeobj__882;
  PyObject *__pyx_codeobj__883;
  PyObject *__pyx_codeobj__884;
  PyObject *__pyx_codeobj__885;
  PyObject *__pyx_codeobj__886;
  PyObject *__pyx_codeobj__887;
  PyObject *__pyx_codeobj__888;
  PyObject *__pyx_codeobj__889;
  PyObject *__pyx_codeobj__890;
  PyObject *__pyx_codeobj__891;
  PyObject *__pyx_codeobj__892;
  PyObject *__pyx_codeobj__893;
  PyObject *__pyx_codeobj__894;
  PyObject *__pyx_codeobj__895;
  PyObject *__pyx_codeobj__896;
  PyObject *__pyx_codeobj__897;
  PyObject *__pyx_codeobj__898;
  PyObject *__pyx_codeobj__899;
  PyObject *__pyx_codeobj__900;
  PyObject *__pyx_codeobj__901;
  PyObject *__pyx_codeobj__902;
  PyObject *__pyx_codeobj__903;
  PyObject *__pyx_codeobj__904;
  PyObject *__pyx_codeobj__905;
  PyObject *__pyx_codeobj__906;
  PyObject *__pyx_codeobj__907;
  PyObject *__pyx_codeobj__908;
  PyObject *__pyx_codeobj__909;
  PyObject *__pyx_codeobj__910;
  PyObject *__pyx_codeobj__911;
  PyObject *__pyx_codeobj__912;
  PyObject *__pyx_codeobj__913;
  PyObject *__pyx_codeobj__914;
  PyObject *__pyx_codeobj__915;
  PyObject *__pyx_codeobj__916;
  PyObject *__pyx_codeobj__917;
  PyObject *__pyx_codeobj__918;
  PyObject *__pyx_codeobj__919;
  PyObject *__pyx_codeobj__920;
  PyObject *__pyx_codeobj__921;
  PyObject *__pyx_codeobj__922;
  PyObject *__pyx_codeobj__923;
  PyObject *__pyx_codeobj__924;
  PyObject *__pyx_codeobj__925;
  PyObject *__pyx_codeobj__926;
  PyObject *__pyx_codeobj__927;
  PyObject *__pyx_codeobj__928;
  PyObject *__pyx_codeobj__929;
  PyObject *__pyx_codeobj__930;
  PyObject *__pyx_codeobj__931;
  PyObject *__pyx_codeobj__932;
  PyObject *__pyx_codeobj__933;
  PyObject *__pyx_codeobj__934;
  PyObject *__pyx_codeobj__935;
  PyObject *__pyx_codeobj__936;
  PyObject *__pyx_codeobj__937;
  PyObject *__pyx_codeobj__938;
  PyObject *__pyx_codeobj__939;
  PyObject *__pyx_codeobj__940;
  PyObject *__pyx_codeobj__941;
  PyObject *__pyx_codeobj__942;
  PyObject *__pyx_codeobj__943;
  PyObject *__pyx_codeobj__944;
  PyObject *__pyx_codeobj__945;
  PyObject *__pyx_codeobj__946;
  PyObject *__pyx_codeobj__947;
  PyObject *__pyx_codeobj__948;
  PyObject *__pyx_codeobj__949;
  PyObject *__pyx_codeobj__950;
  PyObject *__pyx_codeobj__951;
  PyObject *__pyx_codeobj__952;
  PyObject *__pyx_codeobj__953;
  PyObject *__pyx_codeobj__954;
  PyObject *__pyx_codeobj__955;
  PyObject *__pyx_codeobj__956;
  PyObject *__pyx_codeobj__957;
  PyObject *__pyx_codeobj__958;
  PyObject *__pyx_codeobj__959;
  PyObject *__pyx_codeobj__960;
  PyObject *__pyx_codeobj__961;
  PyObject *__pyx_codeobj__962;
  PyObject *__pyx_codeobj__963;
  PyObject *__pyx_codeobj__964;
  PyObject *__pyx_codeobj__965;
  PyObject *__pyx_codeobj__966;
  PyObject *__pyx_codeobj__967;
  PyObject *__pyx_codeobj__968;
  PyObject *__pyx_codeobj__969;
  PyObject *__pyx_codeobj__970;
  PyObject *__pyx_codeobj__971;
  PyObject *__pyx_codeobj__972;
  PyObject *__pyx_codeobj__973;
  PyObject *__pyx_codeobj__974;
  PyObject *__pyx_codeobj__975;
  PyObject *__pyx_codeobj__976;
  PyObject *__pyx_codeobj__977;
  PyObject *__pyx_codeobj__978;
  PyObject *__pyx_codeobj__979;
  PyObject *__pyx_codeobj__980;
  PyObject *__pyx_codeobj__981;
  PyObject *__pyx_codeobj__982;
  PyObject *__pyx_codeobj__983;
  PyObject *__pyx_codeobj__984;
  PyObject *__pyx_codeobj__985;
  PyObject *__pyx_codeobj__986;
  PyObject *__pyx_codeobj__987;
  PyObject *__pyx_codeobj__988;
  PyObject *__pyx_codeobj__989;
  PyObject *__pyx_codeobj__990;
  PyObject *__pyx_codeobj__991;
  PyObject *__pyx_codeobj__992;
  PyObject *__pyx_codeobj__993;
  PyObject *__pyx_codeobj__994;
  PyObject *__pyx_codeobj__995;
  PyObject *__pyx_codeobj__996;
  PyObject *__pyx_codeobj__997;
  PyObject *__pyx_codeobj__998;
  PyObject *__pyx_codeobj__999;
  PyObject *__pyx_codeobj__1000;
  PyObject *__pyx_codeobj__1001;
  PyObject *__pyx_codeobj__1002;
  PyObject *__pyx_codeobj__1003;
  PyObject *__pyx_codeobj__1004;
  PyObject *__pyx_codeobj__1005;
  PyObject *__pyx_codeobj__1006;
  PyObject *__pyx_codeobj__1007;
  PyObject *__pyx_codeobj__1008;
  PyObject *__pyx_codeobj__1009;
  PyObject *__pyx_codeobj__1010;
  PyObject *__pyx_codeobj__1011;
  PyObject *__pyx_codeobj__1012;
  PyObject *__pyx_codeobj__1013;
  PyObject *__pyx_codeobj__1014;
  PyObject *__pyx_codeobj__1015;
  PyObject *__pyx_codeobj__1016;
  PyObject *__pyx_codeobj__1017;
  PyObject *__pyx_codeobj__1018;
  PyObject *__pyx_codeobj__1019;
  PyObject *__pyx_codeobj__1020;
  PyObject *__pyx_codeobj__1021;
  PyObject *__pyx_codeobj__1022;
  PyObject *__pyx_codeobj__1023;
  PyObject *__pyx_codeobj__1024;
  PyObject *__pyx_codeobj__1025;
  PyObject *__pyx_codeobj__1026;
  PyObject *__pyx_codeobj__1027;
  PyObject *__pyx_codeobj__1028;
  PyObject *__pyx_codeobj__1029;
  PyObject *__pyx_codeobj__1030;
  PyObject *__pyx_codeobj__1031;
  PyObject *__pyx_codeobj__1032;
  PyObject *__pyx_codeobj__1033;
  PyObject *__pyx_codeobj__1034;
  PyObject *__pyx_codeobj__1035;
  PyObject *__pyx_codeobj__1036;
  PyObject *__pyx_codeobj__1037;
  PyObject *__pyx_codeobj__1038;
  PyObject *__pyx_codeobj__1039;
  PyObject *__pyx_codeobj__1040;
  PyObject *__pyx_codeobj__1041;
  PyObject *__pyx_codeobj__1042;
  PyObject *__pyx_codeobj__1043;
  PyObject *__pyx_codeobj__1044;
  PyObject *__pyx_codeobj__1045;
  PyObject *__pyx_codeobj__1046;
  PyObject *__pyx_codeobj__1047;
  PyObject *__pyx_codeobj__1048;
  PyObject *__pyx_codeobj__1049;
  PyObject *__pyx_codeobj__1050;
  PyObject *__pyx_codeobj__1051;
  PyObject *__pyx_codeobj__1052;
  PyObject *__pyx_codeobj__1053;
  PyObject *__pyx_codeobj__1054;
  PyObject *__pyx_codeobj__1055;
  PyObject *__pyx_codeobj__1056;
  PyObject *__pyx_codeobj__1057;
  PyObject *__pyx_codeobj__1058;
  PyObject *__pyx_codeobj__1059;
  PyObject *__pyx_codeobj__1060;
  PyObject *__pyx_codeobj__1061;
  PyObject *__pyx_codeobj__1062;
  PyObject *__pyx_codeobj__1063;
  PyObject *__pyx_codeobj__1064;
  PyObject *__pyx_codeobj__1065;
  PyObject *__pyx_codeobj__1066;
  PyObject *__pyx_codeobj__1067;
  PyObject *__pyx_codeobj__1068;
  PyObject *__pyx_codeobj__1069;
  PyObject *__pyx_codeobj__1070;
  PyObject *__pyx_codeobj__1071;
  PyObject *__pyx_codeobj__1072;
  PyObject *__pyx_codeobj__1073;
  PyObject *__pyx_codeobj__1074;
  PyObject *__pyx_codeobj__1075;
  PyObject *__pyx_codeobj__1076;
  PyObject *__pyx_codeobj__1077;
  PyObject *__pyx_codeobj__1078;
  PyObject *__pyx_codeobj__1079;
  PyObject *__pyx_codeobj__1080;
  PyObject *__pyx_codeobj__1081;
  PyObject *__pyx_codeobj__1082;
  PyObject *__pyx_codeobj__1083;
  PyObject *__pyx_codeobj__1084;
  PyObject *__pyx_codeobj__1085;
  PyObject *__pyx_codeobj__1086;
  PyObject *__pyx_codeobj__1087;
  PyObject *__pyx_codeobj__1088;
  PyObject *__pyx_codeobj__1089;
  PyObject *__pyx_codeobj__1090;
  PyObject *__pyx_codeobj__1091;
  PyObject *__pyx_codeobj__1092;
  PyObject *__pyx_codeobj__1093;
  PyObject *__pyx_codeobj__1094;
  PyObject *__pyx_codeobj__1095;
  PyObject *__pyx_codeobj__1096;
  PyObject *__pyx_codeobj__1097;
  PyObject *__pyx_codeobj__1098;
  PyObject *__pyx_codeobj__1099;
  PyObject *__pyx_codeobj__1100;
  PyObject *__pyx_codeobj__1101;
  PyObject *__pyx_codeobj__1102;
  PyObject *__pyx_codeobj__1103;
  PyObject *__pyx_codeobj__1104;
  PyObject *__pyx_codeobj__1105;
  PyObject *__pyx_codeobj__1106;
  PyObject *__pyx_codeobj__1107;
  PyObject *__pyx_codeobj__1108;
  PyObject *__pyx_codeobj__1109;
  PyObject *__pyx_codeobj__1110;
  PyObject *__pyx_codeobj__1111;
  PyObject *__pyx_codeobj__1112;
  PyObject *__pyx_codeobj__1113;
  PyObject *__pyx_codeobj__1114;
  PyObject *__pyx_codeobj__1115;
  PyObject *__pyx_codeobj__1116;
  PyObject *__pyx_codeobj__1117;
  PyObject *__pyx_codeobj__1118;
  PyObject *__pyx_codeobj__1119;
  PyObject *__pyx_codeobj__1120;
  PyObject *__pyx_codeobj__1121;
  PyObject *__pyx_codeobj__1122;
  PyObject *__pyx_codeobj__1123;
  PyObject *__pyx_codeobj__1124;
  PyObject *__pyx_codeobj__1125;
  PyObject *__pyx_codeobj__1126;
  PyObject *__pyx_codeobj__1127;
  PyObject *__pyx_codeobj__1128;
  PyObject *__pyx_codeobj__1129;
  PyObject *__pyx_codeobj__1130;
  PyObject *__pyx_codeobj__1131;
  PyObject *__pyx_codeobj__1132;
  PyObject *__pyx_codeobj__1133;
  PyObject *__pyx_codeobj__1134;
  PyObject *__pyx_codeobj__1135;
  PyObject *__pyx_codeobj__1136;
  PyObject *__pyx_codeobj__1137;
  PyObject *__pyx_codeobj__1138;
  PyObject *__pyx_codeobj__1139;
  PyObject *__pyx_codeobj__1140;
  PyObject *__pyx_codeobj__1141;
  PyObject *__pyx_codeobj__1142;
  PyObject *__pyx_codeobj__1143;
  PyObject *__pyx_codeobj__1144;
  PyObject *__pyx_codeobj__1145;
  PyObject *__pyx_codeobj__1146;
  PyObject *__pyx_codeobj__1147;
  PyObject *__pyx_codeobj__1148;
  PyObject *__pyx_codeobj__1149;
  PyObject *__pyx_codeobj__1150;
  PyObject *__pyx_codeobj__1151;
  PyObject *__pyx_codeobj__1152;
  PyObject *__pyx_codeobj__1153;
  PyObject *__pyx_codeobj__1154;
  PyObject *__pyx_codeobj__1155;
  PyObject *__pyx_codeobj__1156;
  PyObject *__pyx_codeobj__1157;
  PyObject *__pyx_codeobj__1158;
  PyObject *__pyx_codeobj__1159;
  PyObject *__pyx_codeobj__1160;
  PyObject *__pyx_codeobj__1161;
  PyObject *__pyx_codeobj__1162;
  PyObject *__pyx_codeobj__1163;
  PyObject *__pyx_codeobj__1164;
  PyObject *__pyx_codeobj__1165;
  PyObject *__pyx_codeobj__1166;
  PyObject *__pyx_codeobj__1167;
  PyObject *__pyx_codeobj__1168;
  PyObject *__pyx_codeobj__1169;
  PyObject *__pyx_codeobj__1170;
  PyObject *__pyx_codeobj__1171;
  PyObject *__pyx_codeobj__1172;
  PyObject *__pyx_codeobj__1173;
  PyObject *__pyx_codeobj__1174;
  PyObject *__pyx_codeobj__1175;
  PyObject *__pyx_codeobj__1176;
  PyObject *__pyx_codeobj__1177;
  PyObject *__pyx_codeobj__1178;
  PyObject *__pyx_codeobj__1179;
  PyObject *__pyx_codeobj__1180;
  PyObject *__pyx_codeobj__1181;
  PyObject *__pyx_codeobj__1182;
  PyObject *__pyx_codeobj__1183;
  PyObject *__pyx_codeobj__1184;
  PyObject *__pyx_codeobj__1185;
  PyObject *__pyx_codeobj__1186;
  PyObject *__pyx_codeobj__1187;
  PyObject *__pyx_codeobj__1188;
  PyObject *__pyx_codeobj__1189;
  PyObject *__pyx_codeobj__1190;
  PyObject *__pyx_codeobj__1191;
  PyObject *__pyx_codeobj__1192;
  PyObject *__pyx_codeobj__1193;
  PyObject *__pyx_codeobj__1194;
  PyObject *__pyx_codeobj__1195;
  PyObject *__pyx_codeobj__1196;
  PyObject *__pyx_codeobj__1197;
  PyObject *__pyx_codeobj__1198;
  PyObject *__pyx_codeobj__1199;
  PyObject *__pyx_codeobj__1200;
  PyObject *__pyx_codeobj__1201;
  PyObject *__pyx_codeobj__1202;
  PyObject *__pyx_codeobj__1203;
  PyObject *__pyx_codeobj__1204;
  PyObject *__pyx_codeobj__1205;
  PyObject *__pyx_codeobj__1206;
  PyObject *__pyx_codeobj__1207;
  PyObject *__pyx_codeobj__1208;
  PyObject *__pyx_codeobj__1209;
  PyObject *__pyx_codeobj__1210;
  PyObject *__pyx_codeobj__1211;
  PyObject *__pyx_codeobj__1212;
  PyObject *__pyx_codeobj__1213;
  PyObject *__pyx_codeobj__1214;
  PyObject *__pyx_codeobj__1215;
  PyObject *__pyx_codeobj__1216;
  PyObject *__pyx_codeobj__1217;
  PyObject *__pyx_codeobj__1218;
  PyObject *__pyx_codeobj__1219;
  PyObject *__pyx_codeobj__1220;
  PyObject *__pyx_codeobj__1221;
  PyObject *__pyx_codeobj__1222;
  PyObject *__pyx_codeobj__1223;
  PyObject *__pyx_codeobj__1224;
  PyObject *__pyx_codeobj__1225;
  PyObject *__pyx_codeobj__1226;
  PyObject *__pyx_codeobj__1227;
  PyObject *__pyx_codeobj__1228;
  PyObject *__pyx_codeobj__1229;
  PyObject *__pyx_codeobj__1230;
  PyObject *__pyx_codeobj__1231;
  PyObject *__pyx_codeobj__1232;
  PyObject *__pyx_codeobj__1233;
  PyObject *__pyx_codeobj__1234;
  PyObject *__pyx_codeobj__1235;
  PyObject *__pyx_codeobj__1236;
  PyObject *__pyx_codeobj__1237;
  PyObject *__pyx_codeobj__1238;
  PyObject *__pyx_codeobj__1239;
  PyObject *__pyx_codeobj__1240;
  PyObject *__pyx_codeobj__1241;
  PyObject *__pyx_codeobj__1242;
  PyObject *__pyx_codeobj__1243;
  PyObject *__pyx_codeobj__1244;
  PyObject *__pyx_codeobj__1245;
  PyObject *__pyx_codeobj__1246;
  PyObject *__pyx_codeobj__1247;
  PyObject *__pyx_codeobj__1248;
  PyObject *__pyx_codeobj__1249;
  PyObject *__pyx_codeobj__1250;
  PyObject *__pyx_codeobj__1251;
  PyObject *__pyx_codeobj__1252;
  PyObject *__pyx_codeobj__1253;
  PyObject *__pyx_codeobj__1254;
  PyObject *__pyx_codeobj__1255;
  PyObject *__pyx_codeobj__1256;
  PyObject *__pyx_codeobj__1257;
  PyObject *__pyx_codeobj__1258;
  PyObject *__pyx_codeobj__1259;
  PyObject *__pyx_codeobj__1260;
  PyObject *__pyx_codeobj__1261;
  PyObject *__pyx_codeobj__1262;
  PyObject *__pyx_codeobj__1263;
  PyObject *__pyx_codeobj__1264;
  PyObject *__pyx_codeobj__1265;
  PyObject *__pyx_codeobj__1266;
  PyObject *__pyx_codeobj__1267;
  PyObject *__pyx_codeobj__1268;
  PyObject *__pyx_codeobj__1269;
  PyObject *__pyx_codeobj__1270;
  PyObject *__pyx_codeobj__1271;
  PyObject *__pyx_codeobj__1272;
  PyObject *__pyx_codeobj__1273;
  PyObject *__pyx_codeobj__1274;
  PyObject *__pyx_codeobj__1275;
  PyObject *__pyx_codeobj__1276;
  PyObject *__pyx_codeobj__1277;
  PyObject *__pyx_codeobj__1278;
  PyObject *__pyx_codeobj__1279;
  PyObject *__pyx_codeobj__1280;
  PyObject *__pyx_codeobj__1281;
  PyObject *__pyx_codeobj__1282;
  PyObject *__pyx_codeobj__1283;
  PyObject *__pyx_codeobj__1284;
  PyObject *__pyx_codeobj__1285;
  PyObject *__pyx_codeobj__1286;
  PyObject *__pyx_codeobj__1287;
  PyObject *__pyx_codeobj__1288;
  PyObject *__pyx_codeobj__1289;
  PyObject *__pyx_codeobj__1290;
  PyObject *__pyx_codeobj__1291;
  PyObject *__pyx_codeobj__1292;
  PyObject *__pyx_codeobj__1293;
  PyObject *__pyx_codeobj__1294;
  PyObject *__pyx_codeobj__1295;
  PyObject *__pyx_codeobj__1296;
  PyObject *__pyx_codeobj__1297;
  PyObject *__pyx_codeobj__1298;
  PyObject *__pyx_codeobj__1299;
  PyObject *__pyx_codeobj__1300;
  PyObject *__pyx_codeobj__1301;
  PyObject *__pyx_codeobj__1302;
  PyObject *__pyx_codeobj__1303;
  PyObject *__pyx_codeobj__1304;
  PyObject *__pyx_codeobj__1305;
  PyObject *__pyx_codeobj__1306;
  PyObject *__pyx_codeobj__1307;
  PyObject *__pyx_codeobj__1308;
  PyObject *__pyx_codeobj__1309;
  PyObject *__pyx_codeobj__1310;
  PyObject *__pyx_codeobj__1311;
  PyObject *__pyx_codeobj__1312;
  PyObject *__pyx_codeobj__1313;
  PyObject *__pyx_codeobj__1314;
  PyObject *__pyx_codeobj__1315;
  PyObject *__pyx_codeobj__1316;
  PyObject *__pyx_codeobj__1317;
  PyObject *__pyx_codeobj__1318;
  PyObject *__pyx_codeobj__1319;
  PyObject *__pyx_codeobj__1320;
  PyObject *__pyx_codeobj__1321;
  PyObject *__pyx_codeobj__1322;
  PyObject *__pyx_codeobj__1323;
  PyObject *__pyx_codeobj__1324;
  PyObject *__pyx_codeobj__1325;
  PyObject *__pyx_codeobj__1326;
  PyObject *__pyx_codeobj__1327;
  PyObject *__pyx_codeobj__1328;
  PyObject *__pyx_codeobj__1329;
  PyObject *__pyx_codeobj__1330;
  PyObject *__pyx_codeobj__1331;
  PyObject *__pyx_codeobj__1332;
  PyObject *__pyx_codeobj__1333;
  PyObject *__pyx_codeobj__1334;
  PyObject *__pyx_codeobj__1335;
  PyObject *__pyx_codeobj__1336;
  PyObject *__pyx_codeobj__1337;
  PyObject *__pyx_codeobj__1338;
  PyObject *__pyx_codeobj__1339;
  PyObject *__pyx_codeobj__1340;
  PyObject *__pyx_codeobj__1341;
  PyObject *__pyx_codeobj__1342;
  PyObject *__pyx_codeobj__1343;
  PyObject *__pyx_codeobj__1344;
  PyObject *__pyx_codeobj__1345;
  PyObject *__pyx_codeobj__1346;
  PyObject *__pyx_codeobj__1347;
  PyObject *__pyx_codeobj__1348;
  PyObject *__pyx_codeobj__1349;
  PyObject *__pyx_codeobj__1350;
  PyObject *__pyx_codeobj__1351;
  PyObject *__pyx_codeobj__1352;
  PyObject *__pyx_codeobj__1353;
  PyObject *__pyx_codeobj__1354;
  PyObject *__pyx_codeobj__1355;
  PyObject *__pyx_codeobj__1356;
  PyObject *__pyx_codeobj__1357;
  PyObject *__pyx_codeobj__1358;
  PyObject *__pyx_codeobj__1359;
  PyObject *__pyx_codeobj__1360;
  PyObject *__pyx_codeobj__1361;
  PyObject *__pyx_codeobj__1362;
  PyObject *__pyx_codeobj__1363;
  PyObject *__pyx_codeobj__1364;
  PyObject *__pyx_codeobj__1365;
  PyObject *__pyx_codeobj__1366;
  PyObject *__pyx_codeobj__1367;
  PyObject *__pyx_codeobj__1368;
  PyObject *__pyx_codeobj__1369;
  PyObject *__pyx_codeobj__1370;
  PyObject *__pyx_codeobj__1371;
  PyObject *__pyx_codeobj__1372;
  PyObject *__pyx_codeobj__1373;
  PyObject *__pyx_codeobj__1374;
  PyObject *__pyx_codeobj__1375;
  PyObject *__pyx_codeobj__1376;
  PyObject *__pyx_codeobj__1377;
  PyObject *__pyx_codeobj__1378;
  PyObject *__pyx_codeobj__1379;
  PyObject *__pyx_codeobj__1380;
  PyObject *__pyx_codeobj__1381;
  PyObject *__pyx_codeobj__1382;
  PyObject *__pyx_codeobj__1383;
  PyObject *__pyx_codeobj__1384;
  PyObject *__pyx_codeobj__1385;
  PyObject *__pyx_codeobj__1386;
  PyObject *__pyx_codeobj__1387;
  PyObject *__pyx_codeobj__1388;
  PyObject *__pyx_codeobj__1389;
  PyObject *__pyx_codeobj__1390;
  PyObject *__pyx_codeobj__1391;
  PyObject *__pyx_codeobj__1392;
  PyObject *__pyx_codeobj__1393;
  PyObject *__pyx_codeobj__1394;
  PyObject *__pyx_codeobj__1395;
  PyObject *__pyx_codeobj__1396;
  PyObject *__pyx_codeobj__1397;
  PyObject *__pyx_codeobj__1398;
  PyObject *__pyx_codeobj__1399;
  PyObject *__pyx_codeobj__1400;
  PyObject *__pyx_codeobj__1401;
  PyObject *__pyx_codeobj__1402;
  PyObject *__pyx_codeobj__1403;
  PyObject *__pyx_codeobj__1404;
  PyObject *__pyx_codeobj__1405;
  PyObject *__pyx_codeobj__1406;
  PyObject *__pyx_codeobj__1407;
  PyObject *__pyx_codeobj__1408;
  PyObject *__pyx_codeobj__1409;
  PyObject *__pyx_codeobj__1410;
  PyObject *__pyx_codeobj__1411;
  PyObject *__pyx_codeobj__1412;
  PyObject *__pyx_codeobj__1413;
  PyObject *__pyx_codeobj__1414;
  PyObject *__pyx_codeobj__1415;
  PyObject *__pyx_codeobj__1416;
  PyObject *__pyx_codeobj__1417;
  PyObject *__pyx_codeobj__1418;
  PyObject *__pyx_codeobj__1419;
  PyObject *__pyx_codeobj__1420;
  PyObject *__pyx_codeobj__1421;
  PyObject *__pyx_codeobj__1422;
  PyObject *__pyx_codeobj__1423;
  PyObject *__pyx_codeobj__1424;
  PyObject *__pyx_codeobj__1425;
  PyObject *__pyx_codeobj__1426;
  PyObject *__pyx_codeobj__1427;
  PyObject *__pyx_codeobj__1428;
  PyObject *__pyx_codeobj__1429;
  PyObject *__pyx_codeobj__1430;
  PyObject *__pyx_codeobj__1431;
  PyObject *__pyx_codeobj__1432;
  PyObject *__pyx_codeobj__1433;
  PyObject *__pyx_codeobj__1434;
  PyObject *__pyx_codeobj__1435;
  PyObject *__pyx_codeobj__1436;
  PyObject *__pyx_codeobj__1437;
  PyObject *__pyx_codeobj__1438;
  PyObject *__pyx_codeobj__1439;
  PyObject *__pyx_codeobj__1440;
  PyObject *__pyx_codeobj__1441;
  PyObject *__pyx_codeobj__1442;
  PyObject *__pyx_codeobj__1443;
  PyObject *__pyx_codeobj__1444;
  PyObject *__pyx_codeobj__1445;
  PyObject *__pyx_codeobj__1446;
  PyObject *__pyx_codeobj__1447;
  PyObject *__pyx_codeobj__1448;
  PyObject *__pyx_codeobj__1449;
  PyObject *__pyx_codeobj__1450;
  PyObject *__pyx_codeobj__1451;
  PyObject *__pyx_codeobj__1452;
  PyObject *__pyx_codeobj__1453;
  PyObject *__pyx_codeobj__1454;
  PyObject *__pyx_codeobj__1455;
  PyObject *__pyx_codeobj__1456;
  PyObject *__pyx_codeobj__1457;
  PyObject *__pyx_codeobj__1458;
  PyObject *__pyx_codeobj__1459;
  PyObject *__pyx_codeobj__1460;
  PyObject *__pyx_codeobj__1461;
  PyObject *__pyx_codeobj__1462;
  PyObject *__pyx_codeobj__1463;
  PyObject *__pyx_codeobj__1464;
  PyObject *__pyx_codeobj__1465;
  PyObject *__pyx_codeobj__1466;
  PyObject *__pyx_codeobj__1467;
  PyObject *__pyx_codeobj__1468;
  PyObject *__pyx_codeobj__1469;
  PyObject *__pyx_codeobj__1470;
  PyObject *__pyx_codeobj__1471;
  PyObject *__pyx_codeobj__1472;
  PyObject *__pyx_codeobj__1473;
  PyObject *__pyx_codeobj__1474;
  PyObject *__pyx_codeobj__1475;
  PyObject *__pyx_codeobj__1476;
  PyObject *__pyx_codeobj__1477;
  PyObject *__pyx_codeobj__1478;
  PyObject *__pyx_codeobj__1479;
  PyObject *__pyx_codeobj__1480;
  PyObject *__pyx_codeobj__1481;
  PyObject *__pyx_codeobj__1482;
  PyObject *__pyx_codeobj__1483;
  PyObject *__pyx_codeobj__1484;
  PyObject *__pyx_codeobj__1485;
  PyObject *__pyx_codeobj__1486;
  PyObject *__pyx_codeobj__1487;
  PyObject *__pyx_codeobj__1488;
  PyObject *__pyx_codeobj__1489;
  PyObject *__pyx_codeobj__1490;
  PyObject *__pyx_codeobj__1491;
  PyObject *__pyx_codeobj__1492;
  PyObject *__pyx_codeobj__1493;
  PyObject *__pyx_codeobj__1494;
  PyObject *__pyx_codeobj__1495;
  PyObject *__pyx_codeobj__1496;
  PyObject *__pyx_codeobj__1497;
  PyObject *__pyx_codeobj__1498;
  PyObject *__pyx_codeobj__1499;
  PyObject *__pyx_codeobj__1500;
  PyObject *__pyx_codeobj__1501;
  PyObject *__pyx_codeobj__1502;
  PyObject *__pyx_codeobj__1503;
  PyObject *__pyx_codeobj__1504;
  PyObject *__pyx_codeobj__1505;
  PyObject *__pyx_codeobj__1506;
  PyObject *__pyx_codeobj__1507;
  PyObject *__pyx_codeobj__1508;
  PyObject *__pyx_codeobj__1509;
  PyObject *__pyx_codeobj__1510;
  PyObject *__pyx_codeobj__1511;
  PyObject *__pyx_codeobj__1512;
  PyObject *__pyx_codeobj__1513;
  PyObject *__pyx_codeobj__1514;
  PyObject *__pyx_codeobj__1515;
  PyObject *__pyx_codeobj__1516;
  PyObject *__pyx_codeobj__1517;
  PyObject *__pyx_codeobj__1518;
  PyObject *__pyx_codeobj__1519;
  PyObject *__pyx_codeobj__1520;
  PyObject *__pyx_codeobj__1521;
  PyObject *__pyx_codeobj__1522;
  PyObject *__pyx_codeobj__1523;
  PyObject *__pyx_codeobj__1524;
  PyObject *__pyx_codeobj__1525;
  PyObject *__pyx_codeobj__1526;
  PyObject *__pyx_codeobj__1527;
  PyObject *__pyx_codeobj__1528;
  PyObject *__pyx_codeobj__1529;
  PyObject *__pyx_codeobj__1530;
  PyObject *__pyx_codeobj__1531;
  PyObject *__pyx_codeobj__1532;
  PyObject *__pyx_codeobj__1533;
  PyObject *__pyx_codeobj__1534;
  PyObject *__pyx_codeobj__1535;
  PyObject *__pyx_codeobj__1536;
  PyObject *__pyx_codeobj__1537;
  PyObject *__pyx_codeobj__1538;
  PyObject *__pyx_codeobj__1539;
  PyObject *__pyx_codeobj__1540;
  PyObject *__pyx_codeobj__1541;
  PyObject *__pyx_codeobj__1542;
  PyObject *__pyx_codeobj__1543;
  PyObject *__pyx_codeobj__1544;
  PyObject *__pyx_codeobj__1545;
  PyObject *__pyx_codeobj__1546;
  PyObject *__pyx_codeobj__1547;
  PyObject *__pyx_codeobj__1548;
  PyObject *__pyx_codeobj__1549;
  PyObject *__pyx_codeobj__1550;
  PyObject *__pyx_codeobj__1551;
  PyObject *__pyx_codeobj__1552;
  PyObject *__pyx_codeobj__1553;
  PyObject *__pyx_codeobj__1554;
  PyObject *__pyx_codeobj__1555;
  PyObject *__pyx_codeobj__1556;
  PyObject *__pyx_codeobj__1557;
  PyObject *__pyx_codeobj__1558;
  PyObject *__pyx_codeobj__1559;
  PyObject *__pyx_codeobj__1560;
  PyObject *__pyx_codeobj__1561;
  PyObject *__pyx_codeobj__1562;
  PyObject *__pyx_codeobj__1563;
  PyObject *__pyx_codeobj__1564;
  PyObject *__pyx_codeobj__1565;
  PyObject *__pyx_codeobj__1566;
  PyObject *__pyx_codeobj__1567;
  PyObject *__pyx_codeobj__1568;
  PyObject *__pyx_codeobj__1569;
  PyObject *__pyx_codeobj__1570;
  PyObject *__pyx_codeobj__1571;
  PyObject *__pyx_codeobj__1572;
  PyObject *__pyx_codeobj__1573;
  PyObject *__pyx_codeobj__1574;
  PyObject *__pyx_codeobj__1575;
  PyObject *__pyx_codeobj__1576;
  PyObject *__pyx_codeobj__1577;
  PyObject *__pyx_codeobj__1578;
  PyObject *__pyx_codeobj__1579;
  PyObject *__pyx_codeobj__1580;
  PyObject *__pyx_codeobj__1581;
  PyObject *__pyx_codeobj__1582;
  PyObject *__pyx_codeobj__1583;
  PyObject *__pyx_codeobj__1584;
  PyObject *__pyx_codeobj__1585;
  PyObject *__pyx_codeobj__1586;
  PyObject *__pyx_codeobj__1587;
  PyObject *__pyx_codeobj__1588;
  PyObject *__pyx_codeobj__1589;
  PyObject *__pyx_codeobj__1590;
  PyObject *__pyx_codeobj__1591;
  PyObject *__pyx_codeobj__1592;
  PyObject *__pyx_codeobj__1593;
  PyObject *__pyx_codeobj__1594;
  PyObject *__pyx_codeobj__1595;
  PyObject *__pyx_codeobj__1596;
  PyObject *__pyx_codeobj__1597;
  PyObject *__pyx_codeobj__1598;
  PyObject *__pyx_codeobj__1599;
  PyObject *__pyx_codeobj__1600;
  PyObject *__pyx_codeobj__1601;
  PyObject *__pyx_codeobj__1602;
  PyObject *__pyx_codeobj__1603;
  PyObject *__pyx_codeobj__1604;
  PyObject *__pyx_codeobj__1605;
  PyObject *__pyx_codeobj__1606;
  PyObject *__pyx_codeobj__1607;
  PyObject *__pyx_codeobj__1608;
  PyObject *__pyx_codeobj__1609;
  PyObject *__pyx_codeobj__1610;
  PyObject *__pyx_codeobj__1611;
  PyObject *__pyx_codeobj__1612;
  PyObject *__pyx_codeobj__1613;
  PyObject *__pyx_codeobj__1614;
  PyObject *__pyx_codeobj__1615;
  PyObject *__pyx_codeobj__1616;
  PyObject *__pyx_codeobj__1617;
  PyObject *__pyx_codeobj__1618;
  PyObject *__pyx_codeobj__1619;
  PyObject *__pyx_codeobj__1620;
  PyObject *__pyx_codeobj__1621;
  PyObject *__pyx_codeobj__1622;
  PyObject *__pyx_codeobj__1623;
  PyObject *__pyx_codeobj__1624;
  PyObject *__pyx_codeobj__1625;
  PyObject *__pyx_codeobj__1626;
  PyObject *__pyx_codeobj__1628;
  PyObject *__pyx_codeobj__1629;
  PyObject *__pyx_codeobj__1631;
  PyObject *__pyx_codeobj__1633;
  PyObject *__pyx_codeobj__1634;
  PyObject *__pyx_codeobj__1635;
  PyObject *__pyx_codeobj__1636;
  PyObject *__pyx_codeobj__1638;
  PyObject *__pyx_codeobj__1640;
  PyObject *__pyx_codeobj__1642;
  PyObject *__pyx_codeobj__1644;
  PyObject *__pyx_codeobj__1647;
  PyObject *__pyx_codeobj__1648;
  PyObject *__pyx_codeobj__1649;
  PyObject *__pyx_codeobj__1652;
  PyObject *__pyx_codeobj__1654;
  PyObject *__pyx_codeobj__1701;
  PyObject *__pyx_codeobj__1703;
  PyObject *__pyx_codeobj__1704;
  PyObject *__pyx_codeobj__1705;
  PyObject *__pyx_codeobj__1706;
  PyObject *__pyx_codeobj__1708;
  PyObject *__pyx_codeobj__1709;
  PyObject *__pyx_codeobj__1710;
  PyObject *__pyx_codeobj__1711;
  PyObject *__pyx_codeobj__1712;
  PyObject *__pyx_codeobj__1714;
  PyObject *__pyx_codeobj__1715;
  PyObject *__pyx_codeobj__1716;
  PyObject *__pyx_codeobj__1717;
  PyObject *__pyx_codeobj__1718;
  PyObject *__pyx_codeobj__1720;
  PyObject *__pyx_codeobj__1723;
  PyObject *__pyx_codeobj__1725;
  PyObject *__pyx_codeobj__1727;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);
  Py_CLEAR(clear_module_state->__pyx_type_6giacpy_6giacpy_GiacMethods_base);
  Py_CLEAR(clear_module_state->__pyx_ptype_6giacpy_6giacpy_Pygen);
  Py_CLEAR(clear_module_state->__pyx_type_6giacpy_6giacpy_Pygen);
  Py_CLEAR(clear_module_state->__pyx_ptype_6giacpy_6giacpy_GiacSetting);
  Py_CLEAR(clear_module_state->__pyx_type_6giacpy_6giacpy_GiacSetting);
  Py_CLEAR(clear_module_state->__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__);
  Py_CLEAR(clear_module_state->__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__);
  Py_CLEAR(clear_module_state->__pyx_n_s_A);
  Py_CLEAR(clear_module_state->__pyx_n_s_ACOSH);
  Py_CLEAR(clear_module_state->__pyx_n_s_ACOT);
  Py_CLEAR(clear_module_state->__pyx_n_s_ACSC);
  Py_CLEAR(clear_module_state->__pyx_n_s_ASEC);
  Py_CLEAR(clear_module_state->__pyx_n_s_ASIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_ASINH);
  Py_CLEAR(clear_module_state->__pyx_n_s_ATAN);
  Py_CLEAR(clear_module_state->__pyx_n_s_ATANH);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Airy_Ai);
  Py_CLEAR(clear_module_state->__pyx_n_s_Airy_Bi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Angstrom);
  Py_CLEAR(clear_module_state->__pyx_n_s_Archive);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Archive_a_Pygen_element_to_a_fi);
  Py_CLEAR(clear_module_state->__pyx_n_s_BesselJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_BesselY);
  Py_CLEAR(clear_module_state->__pyx_n_s_Beta);
  Py_CLEAR(clear_module_state->__pyx_n_s_BlockDiagonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_Bq);
  Py_CLEAR(clear_module_state->__pyx_n_s_Btu);
  Py_CLEAR(clear_module_state->__pyx_n_s_COND);
  Py_CLEAR(clear_module_state->__pyx_n_s_COS);
  Py_CLEAR(clear_module_state->__pyx_n_s_COSH);
  Py_CLEAR(clear_module_state->__pyx_n_s_COT);
  Py_CLEAR(clear_module_state->__pyx_n_s_CSC);
  Py_CLEAR(clear_module_state->__pyx_n_s_CST);
  Py_CLEAR(clear_module_state->__pyx_n_s_Celsius2Fahrenheit);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ci);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ci_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_ClrDraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_ClrGraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_ClrIO);
  Py_CLEAR(clear_module_state->__pyx_n_s_Col);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Convert_a_giac_integer_type_Pyg);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Convert_a_giac_real_to_a_Python);
  Py_CLEAR(clear_module_state->__pyx_n_s_CopyVar);
  Py_CLEAR(clear_module_state->__pyx_n_s_CyclePic);
  Py_CLEAR(clear_module_state->__pyx_n_s_DIGITS);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_COMPLEX);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_FLOAT);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_FUNC);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_IDENT);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_INT);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_LIST);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_RAT);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_STRING);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_SYMBOLIC);
  Py_CLEAR(clear_module_state->__pyx_n_s_DOM_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_DelFold);
  Py_CLEAR(clear_module_state->__pyx_n_s_DelVar);
  Py_CLEAR(clear_module_state->__pyx_n_s_Det);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dialog);
  Py_CLEAR(clear_module_state->__pyx_n_s_Digits);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dirac);
  Py_CLEAR(clear_module_state->__pyx_n_s_Disp);
  Py_CLEAR(clear_module_state->__pyx_n_s_DispG);
  Py_CLEAR(clear_module_state->__pyx_n_s_DispHome);
  Py_CLEAR(clear_module_state->__pyx_n_s_DrawFunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_DrawInv);
  Py_CLEAR(clear_module_state->__pyx_n_s_DrawParm);
  Py_CLEAR(clear_module_state->__pyx_n_s_DrawPol);
  Py_CLEAR(clear_module_state->__pyx_n_s_DrawSlp);
  Py_CLEAR(clear_module_state->__pyx_n_s_DropDown);
  Py_CLEAR(clear_module_state->__pyx_n_s_DrwCtour);
  Py_CLEAR(clear_module_state->__pyx_n_s_ERROR);
  Py_CLEAR(clear_module_state->__pyx_n_s_EXP);
  Py_CLEAR(clear_module_state->__pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ei);
  Py_CLEAR(clear_module_state->__pyx_n_s_EndDlog);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Error_executing_code_in_Giac_COD);
  Py_CLEAR(clear_module_state->__pyx_n_s_F);
  Py_CLEAR(clear_module_state->__pyx_n_s_FALSE);
  Py_CLEAR(clear_module_state->__pyx_n_s_F_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_F_OK);
  Py_CLEAR(clear_module_state->__pyx_n_s_Factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_Fahrenheit2Celsius);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Failed_to_start_a_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_False);
  Py_CLEAR(clear_module_state->__pyx_n_s_Fdy);
  Py_CLEAR(clear_module_state->__pyx_n_s_Fill);
  Py_CLEAR(clear_module_state->__pyx_n_s_Fourier);
  Py_CLEAR(clear_module_state->__pyx_n_s_G);
  Py_CLEAR(clear_module_state->__pyx_n_s_GF);
  Py_CLEAR(clear_module_state->__pyx_n_s_GIACNULL);
  Py_CLEAR(clear_module_state->__pyx_n_s_GIACPY_TMP_NAME05026807096929010);
  Py_CLEAR(clear_module_state->__pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Gal);
  Py_CLEAR(clear_module_state->__pyx_n_s_Gamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_Gcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GetFold);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___add);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___call);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___div);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___mul);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___neg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___pow);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction___truediv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction_htmlhelp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacFunction_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Airy_Ai);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Airy_Bi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Archive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_BesselJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_BesselY);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Beta);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_BlockDiagonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Ci);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Col);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_CopyVar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Dirac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Ei);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Fourier);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_GF);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Gamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Heaviside);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Heaviside2sign);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Hilbert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_JordanBlock);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_LU);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_LambertW);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Li);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_LineHorz);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_LineTan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_LineVert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_MSE);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Phi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Pi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Psi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_QR);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_RandSeed);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ReLU);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Row);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_SortA);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_SortD);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_UTPC);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_UTPF);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_UTPN);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_UTPT);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_VARS);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_VAS);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_VAS_positive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_Zeta);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_a2q);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_abcuv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_about);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_abs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_abscissa);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_accumulate_head);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acos2asin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acos2atan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acosh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acsc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_acyclic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_adaptive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_add_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_add_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_add_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_additionally);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_addtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_adjacency_matri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_adjoint_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_affix);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_algsubs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_algvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_all_trig_soluti);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_allpairs_distan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_alog10);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_altitude);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_angle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_angle_radian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_angleat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_angleatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ans);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_antiprism_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_approx);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arcLen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arccos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arccosh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arclen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arcsin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arcsinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arctan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arctanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_area);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_areaat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_areaatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_areaplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_arrivals);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_articulation_po);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_asin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_asin2acos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_asin2atan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_asinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_assign_edge_wei);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_assume);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_at);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_atan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_atan2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_atan2acos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_atan2asin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_atanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_atrig2ln);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_augment);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_auto_correlatio);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_autosimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_avance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_avgRC);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_axes);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_back);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_backward);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_baisse_crayon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bandwidth);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bar_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_barplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bartlett_hann_w);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_barycenter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_basis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_batons);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bellman_ford);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_berlekamp_masse);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bernoulli);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bernoulli_mod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_besselJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_besselY);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_betad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_betad_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_betad_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_betavariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_betweenness_cen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bezier);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bezout_entiers);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bezoutian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_biconnected_com);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_binomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_binomial_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_binomial_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bins);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bipartite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bipartite_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bisection_solve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bisector);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bit_depth);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bitand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bitor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bitxor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_blackman_harris);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_blackman_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_block_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_blockmatrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bohman_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_border);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_box_constraints);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_boxcar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_boxwhisker);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_brent_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_brown);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bspline);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_bvpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cFactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cSolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cZeros);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_camembert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_canonical_form);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_canonical_label);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cartesian_produ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cauchy);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cauchy_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cauchy_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cauchyd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cauchyd_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cauchyd_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ceil);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ceiling);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_center);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_center2interval);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_centered_cube);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_centered_tetrah);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cfactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cfsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_changebase);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_channel_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_channels);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_char);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_charpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chinrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquare);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquare_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquare_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquared);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquared_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquared_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chisquaret);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_choice);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cholesky);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chromatic_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chromatic_numbe);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_chromatic_polyn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_circumcircle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_classes);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_clear);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_clique_cover);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_clique_cover_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_clique_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_closeness_centr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cluster);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_clustering_coef);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_coeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_coeffs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_col);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colDim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colNorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colSwap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_coldim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_collect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colormap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_colswap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_comDenom);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_comb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_combine);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_comment);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_common_perpendi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_companion);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_compare);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_complete_binary);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_complete_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_complete_kary_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_complex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_complex_variabl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_complexroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_concat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cond);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_condensation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cone);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_confrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_conic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_conj);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_conjugate_equat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_conjugate_gradi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_connected);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_connected_compo);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cont);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_content);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_contourplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_contract_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_contract_subgra);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_convert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_convertir);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_convex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_convexhull);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_convolution);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_coordinates);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_correlation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cos2sintan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cosh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cosine_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cote);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_count_eq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_count_inf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_count_sup);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_courbe_parametr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_courbe_polaire);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_covariance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_covariance_corr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cpartfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_crationalroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_crayon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_createwav);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cross);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_crossP);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cross_correlati);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cross_entropy);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cross_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cross_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_crossproduct);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_csc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_csolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_csv2gen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cube);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cumSum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cumsum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cumulated_frequ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_curl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_current_sheet);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_curvature);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_curve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cyan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cycle2perm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cycle_basis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cycle_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cycleinv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cycles2permu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cyclotomic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_cylinder);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dash_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dashdot_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dashdotdot_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dayofweek);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_deSolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_debut_enregistr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_degree_centrali);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_degree_sequence);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_degrees);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_delcols);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_delete_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_delete_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_delete_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_delrows);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_deltalist);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_denom);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_densityplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_departures);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_derive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_deriver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_desolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dessine_tortue);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_det);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_det_minor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_developper);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_developper_tran);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dfc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dfc2f);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_diag);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_digraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dijkstra);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_directed);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_discard_edge_at);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_discard_graph_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_discard_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_disjoint_union);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_display);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_disque);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_disque_centre);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_distance2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_distanceat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_distanceatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_divergence);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_divide);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_divis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_division_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_divisors);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_divmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_divpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dnewton_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dodecahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_domain);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dotP);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dot_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dotprod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_pixel);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_polygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_draw_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_droit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_droite_tangente);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_duration);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_dwt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_e2r);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ecart_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ecart_type_popu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ecef2geodetic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ecm_factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_edge_connectivi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_egcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_egv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_egvl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eigVc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eigVl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eigenvals);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eigenvalues);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eigenvectors);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eigenvects);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_element);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eliminate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ellipse);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_emd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_entry);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_envelope);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_epsilon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_epsilon2zero);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_equal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_equal2diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_equal2list);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_equation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_equilateral_tri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_erf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_erfc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_est_permu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_euler);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_euler_gamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_euler_lagrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_eval_level);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_evala);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_evalb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_evalc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_evalf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_evalm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_even);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_evolute);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exact);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exbisector);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_excircle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_execute);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exp2list);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exp2pow);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exp2trig);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_expand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_expexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_expln);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponential);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponential_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponential_icd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponential_reg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponential_reg_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponentiald);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponentiald_cd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_exponentiald_ic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_export_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_export_mathml);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_expovariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_expr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_extend);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_extract_measure);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_extrema);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ezgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_f2nd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fMax);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fMin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fPart);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_faces);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_facteurs_premie);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factor_xn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factorial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factoriser);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factoriser_enti);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factoriser_sur);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_factors);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fadeev);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_false);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_falsepos_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fclose);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fdistrib);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fft);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fieldplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_find);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_find_cliques);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_find_cycles);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_find_minimum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_find_vertex_cov);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_findhelp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fisher);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fisher_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fisher_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fisherd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fisherd_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fisherd_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fitdistr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fitpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fitspline);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_flatten);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_float2rational);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_floor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_flow_polynomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_flower_snark);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_foldl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_foldr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fonction_derive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_forward);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fourier);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fourier_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fourier_bn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fourier_cn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fprint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_frac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fracmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_frame_2d);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_frank_wolfe);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_frequencies);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_frobenius_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_froot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fullparfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_funcplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_function_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fundamental_cyc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_fxnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gammad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gammad_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gammad_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gammavariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gauss);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gauss15);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gauss_seidel_li);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gaussian_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gaussjord);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gaussquad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gbasis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gbasis_max_pair);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gbasis_reinject);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gbasis_simult_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gcdex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_genpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_geodetic2ecef);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_geometric);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_geometric_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_geometric_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_getDenom);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_getKey);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_getNum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_getType);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_get_edge_attrib);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_get_edge_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_get_graph_attri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_get_vertex_attr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_girth);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gl_showaxes);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gold);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_goldberg_snark);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_grad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_gramschmidt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_automorph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_charpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_complemen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_diameter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_equal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_power);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_rank);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_union);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_graph_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_greduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_greedy_clique);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_greedy_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_greedy_independ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_grey);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_grid_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_groupermu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_haar_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hadamard);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_half_cone);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_half_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_halftan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_halftan_hyp2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_halt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hamdist);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hamming);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hamming_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hann_poisson_wi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hann_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_harmonic_centra);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_harmonic_conjug);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_harmonic_divisi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_has);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_has_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_has_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hasard);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_head);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_heading);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_heapify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_heappop);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_heappush);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hermite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hessenberg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hessian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_heugcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hexagon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hht);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_highlight_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_highlight_subgr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_highlight_trail);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_highlight_verte);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_highpass);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hilbert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_histogram);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hold);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_homogeneize);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_homothety);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_horner);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hsv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hsv2rgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hybrid_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hybridj_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hybrids_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hybridsj_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hyp2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hyperbola);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_hypercube_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_iPart);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_iabcuv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ibasis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ibpdv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ibpu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ichinrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ichrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_icomp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_icontent);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_icosahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_identify_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_identity);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_idivis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_idn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_idwt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_iegcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ifactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ifactors);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ifourier);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_igamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_igcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_igcdex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ihermite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ilaplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_im);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_imag);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_image);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_imfplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_implicitdiff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_implicitplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_import_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inString);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_in_ideal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_incidence_matri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_incident_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_incircle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_increasing_powe);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_independence_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_indets);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_induced_subgrap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inequationplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inertia);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_infinity);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_information_cen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_insert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_insmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_instfreq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_instphase);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_intDiv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_integrate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_integrer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_interactive_ode);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_interactive_plo);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_interp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_interval);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_interval2center);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_interval_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_inversion);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_invisible_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_invlaplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_invztrans);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_iquo);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_iquorem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_iratrecon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_irem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isPrime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_acyclic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_arborescence);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_biconnected);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_bipartite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_clique);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_collinear);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_concyclic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_conjugate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_connected);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_coplanar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_cospherical);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_cut_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_cycle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_directed);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_element);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_equilateral);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_eulerian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_forest);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_graphic_sequ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_hamiltonian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_harmonic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_harmonic_cir);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_harmonic_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_inside);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_integer_grap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_irreducible);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_isomorphic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_isosceles);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_network);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_orthogonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_parallel);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_parallelogra);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_permu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_perpendicula);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_planar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_prime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_pseudoprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_reachable);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_regular);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_rhombus);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_split_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_square);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_strongly_con);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_strongly_reg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_subgraph_iso);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_tournament);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_triconnected);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_two_edge_con);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_vertex_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_is_weighted);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isinf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ismith);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isnan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isobarycenter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isom);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isomorphic_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isopolygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isosceles_trian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isposdef);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_isprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_istft);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ithprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_jacobi_equation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_jacobi_linsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_jacobi_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_johnson_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_jordan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_katz_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kde);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_keep_pivot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ker);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kernel);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kernel_density);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kmeans);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kneser_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kolmogorovd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kolmogorovt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kovacicsols);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_kspaths);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_l1norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_l2norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lagrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_laguerre);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_laplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_laplacian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_laplacian_matri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_latex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lcf_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lcm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ldegree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ldl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_learning_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_left);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_left_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_legend);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_legendre);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_legendre_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_levenshtein);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lhs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_chapeau_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_chapeau_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_chapeau_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_polygonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_polygonal_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_tiret);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_tiret_poi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_tiret_poi_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ligne_trait_ple);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_limit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_limite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linabs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_line_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_line_inter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_line_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_line_segments);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linear_interpol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linear_regressi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linear_regressi_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lineariser);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lineariser_trig);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linfnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_linstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lis_phrase);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_list2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_list2mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_list_edge_attri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_list_graph_attr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_list_vertex_att);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_listplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lll);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ln);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lname);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lncollect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lnexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_locus);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_log);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_log10);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_log2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_log_loss);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_logarithmic_reg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_logarithmic_reg_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_logb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_logistic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_logistic_regres);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_logistic_regres_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lower);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lowest_common_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lowpass);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_assume);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_bestlocalbou);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_bestprojecti);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_binary);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_binaryvariab);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_breadthfirst);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_depthfirst);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_depthlimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_firstfractio);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_gaptolerance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_heuristic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_hybrid);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_integervaria);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_interiorpoin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_iterationlim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_lastfraction);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_maxcuts);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_maximize);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_method);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_mostfraction);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_nodelimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_nodeselect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_nonnegative);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_nonnegint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_presolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_pseudocost);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_simplex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_timelimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_varselect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lp_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lsmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lsq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_lvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mRow);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mRowAdd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_magenta);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_make_directed);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_make_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_make_weighted);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_makelist);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_makemat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_makesuite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_makevector);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maple2mupad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maple2xcas);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maple_ifactors);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maple_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_markov);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mat2list);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mathml);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_matpow);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_matrix_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maxflow);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maximal_indepen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maximize);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maximum_clique);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maximum_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maximum_indepen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maximum_matchin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_maxnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mean);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_median);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_median_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_member);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mgf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mid);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_middle_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_midpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimal_edge_co);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimal_spannin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimal_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimax);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimize);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimum_cut);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimum_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_minimum_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mixdown);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mkisom);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mksa);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_modf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_modgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mods);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_momentum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_monotonic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_montre_tortue);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_moustache);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_moving_average);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_moyal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_moyenne);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mul);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mult_c_conjugat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mult_conjugate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_multinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_multiplier_conj);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_multiplier_conj_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_multiply);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mupad2maple);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mupad2xcas);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_mycielski);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nCr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nDeriv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nInt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nPr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nSolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_navy);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ncols);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_negbinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_negbinomial_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_negbinomial_icd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_neighbors);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_network_transit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_neural_network);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_newList);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_newMat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_newton);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_newton_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_newtonj_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nextperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nextprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_binary);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_binaryvaria);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_initialpoin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_integervari);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_iterationli);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_maximize);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_method);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_nonnegative);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_nonnegint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_precision);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_presolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_tolerance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlp_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nlpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nodisp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_non_recursive_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nonnegint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nop);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nops);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normal_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normal_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normald);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normald_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normald_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normalize);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normalt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_normalvariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nprimes);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nrows);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nuage_points);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_nullspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_number_of_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_number_of_spann);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_number_of_trian);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_number_of_verti);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_numdiff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_numer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_octahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_odd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_odd_girth);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_odd_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_odeplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_odesolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_olive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_op);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_open_polygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_orange);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ord);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_order_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ordinate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_orthocenter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_orthogonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_osculating_circ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_p1oc2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_p1op2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pa2b2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pade);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_paley_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parabola);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parallel);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parallelepiped);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parallelogram);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parameq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parameter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_paramplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pari);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_part);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_partfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_parzen_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pas_de_cote);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_path_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pcar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pcar_hessenberg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pcoef);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pencolor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pendown);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_penup);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perimeter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perimeterat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perimeteratraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_period);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_periodic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perminv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_permu2cycles);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_permu2mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_permuorder);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_permute_vertice);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perpen_bisector);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_perpendicular);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_petersen_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_peval);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pie);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_piecewise);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pink);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pivot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pixoff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pixon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_planar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plane);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plane_dual);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_playsnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plot3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotarea);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotcdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotcontour);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotdensity);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotfield);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotfunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotimf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotimplicit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotinequation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotode);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotparam);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotpolar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotproba);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotspectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plotwav);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_plus_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_point2d);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_point3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_poisson);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_poisson_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_poisson_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_poisson_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polar_coordinat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polar_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polarplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pole);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_poly2symb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polyEval);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polygone_rempli);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polygonplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polygonscatterp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polyhedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polynom);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polynomial_regr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_polynomial_regr_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_position);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_poslbdLMQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_posubLMQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_potential);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pow2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_power_regressio);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_power_regressio_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_powermod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_powerpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_powexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_powmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_prepend);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_preval);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_prevperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_prevprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_primpart);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_printf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_prism);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_prism_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_projection);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_proot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_propFrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_propfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pruefer_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_psrgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ptayl);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_purge);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_purple);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pwd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_pyramid);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_python_compat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_q2a);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_qr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quadric);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quadrilateral);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quantile);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quartile1);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quartile3);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quartiles);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quest);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quo);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quorem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_quote);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_r2e);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_radians);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_radical_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_radius);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ramene);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randMat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randNorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randPoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randbetad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randbinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randchisquare);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randexp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randfisher);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randgammad);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randgeometric);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randmarkov);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randmatrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randmultinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_bipartit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_digraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_network);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_planar_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_regular);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_sequence);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_tourname);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_random_variable);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randpoisson);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randseed);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randstudent);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randvector);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_randweibulld);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rank);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ranm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ranv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rassembler_trig);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rat_jordan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ratinterp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rational);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rationalroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ratnormal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rdiv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reachable);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_read);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_readrgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_readwav);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_real);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_realroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reciprocation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rectangle_droit);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rectangle_gauch);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rectangle_plein);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rectangular_coo);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_recule);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_red);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reduced_conic);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reduced_quadric);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ref);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reflection);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_regroup);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_relabel_vertice);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reliability_pol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_remain);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_remove);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reorder);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_resample);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_residue);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_resoudre);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_resoudre_dans_C);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_resoudre_system);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_resultant);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reverse_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_reverse_rsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_revert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_revlex);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_revlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rgb2hsv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rgb2xyz);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rhombus);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rhombus_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rhs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_riemann_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_right);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_right_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_right_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_risch);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rm_a_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rm_all_vars);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rmbreakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rmmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rms);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rmwatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_romberg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rombergm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rombergt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rond);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_root);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rootof);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_roots);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rotate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rotation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_round);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_row);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowAdd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowDim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowNorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowSwap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowdim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rownorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rowswap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rref);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rur);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rur_certify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_rur_gbasis);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_same);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sample);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_samplerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sans_factoriser);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_saute);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_scalarProduct);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_scalar_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_scatterplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_schur);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sec);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_secant_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_segment);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_seidel_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_seidel_switch);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_select);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_semi_augment);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_seq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_seqplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_seqsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sequence_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_series);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_channel_dat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_edge_attrib);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_edge_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_graph_attri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_pixel);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_screen);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_vertex_attr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_set_vertex_posi);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_shift);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_shift_phase);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_shortest_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_show_pixels);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_shuffle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sierpinski_grap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sign);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sign2Heaviside);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_signature);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_signe);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_similarity);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simp2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simplex_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simplicial_vert);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simplifier);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simplifyDirac);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simpson);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simulated_annea);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_simult);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sin2costan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sinc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sincos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_single_inter);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sizes);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_slope);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_slopeat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_slopeatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_smith);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_smod);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_snedecor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_snedecor_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_snedecor_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_snedecord);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_snedecord_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_snedecord_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_solid_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_solve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_somme);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sommet);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sorta);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sortd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sorted);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sortperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_soundsec);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_spanning_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sphere);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_splice);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_spline);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_spring);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sqrfree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sqrt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_square);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_square_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_srand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sst);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sst_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_st_ordering);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_star_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_star_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_stdDev);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_stddev);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_stddevp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_steffenson_solv);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_stereo2mono);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_stft);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_strip);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_strongly_connec);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_student);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_student_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_student_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_studentd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_studentt);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sturm);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sturmab);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sturmseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_style);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subMat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subdivide_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subgraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subs);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subsop);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subst);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_substituer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_subtype);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sum);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sum_riemann);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_suppress);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_surd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_svd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_swapcol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_swaprow);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_switch_axes);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_sylvester);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_symb2poly);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_symbol_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_syst2mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tCollect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tExpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_table);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tablefunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tableseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tabsign);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tabvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tail);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tan2cossin2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tan2sincos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tan2sincos2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tangent);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tangente);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tar);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_taux_accroissem);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_taylor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tchebyshev1);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tchebyshev2);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tcollect);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tdeg);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_teal);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tensor_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tetrahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_texpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_thickness);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_threshold);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_title);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_titre);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tlin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tonnetz);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_topologic_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_topological_sor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_topology);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_torus_grid_grap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_total_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tourne_droite);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tourne_gauche);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trace);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trail);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trail2edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_train);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trames);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tran);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_transitive_clos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_translation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_transpose);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trapeze);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trapezoid);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_traveling_sales);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tree_height);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tri);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_triangle_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_triangle_plein);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_triangle_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_triangle_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trig2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trigcos);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trigexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_triginterp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trigsimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trigsin);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trigtan);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trim);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trn);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_true);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_trunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_truncate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_truncate_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tsimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tuer);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tukey_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_tutte_polynomia);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_two_edge_connec);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ufactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ugamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_unapply);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_unarchive);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_undef);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_underlying_grap);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_unfactored);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_uniform);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_uniform_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_uniform_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_uniformd);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_uniformd_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_uniformd_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_unitV);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_unquote);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_upper);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_user_operator);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_usimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ustep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_valuation);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vandermonde);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_variables_are_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_variance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertex_connecti);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertex_cover_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertex_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertex_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertex_in_degre);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertex_out_degr);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertices_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vertices_abca);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_violet);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vpotential);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_vstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_web_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibull);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibull_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibull_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibulld);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibulld_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibulld_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weibullvariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weight_decay);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weight_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weighted);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_weights);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_welch_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_wheel_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_widget_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_wilcoxonp);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_wilcoxons);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_wilcoxont);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_writergb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_writewav);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_xcas_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_xml_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_xstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_xyz2rgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_xyztrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ystep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_zeros);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_zip);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_znorder);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_znprimroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_zstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacMethods_base_ztrans);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacSetting);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacSetting___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_GiacSetting___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Giac_Settings);
  Py_CLEAR(clear_module_state->__pyx_n_s_Graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_Gy);
  Py_CLEAR(clear_module_state->__pyx_n_s_H);
  Py_CLEAR(clear_module_state->__pyx_n_s_Heaviside);
  Py_CLEAR(clear_module_state->__pyx_n_s_Heaviside2sign);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hilbert);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hz);
  Py_CLEAR(clear_module_state->__pyx_n_s_I);
  Py_CLEAR(clear_module_state->__pyx_n_s_I0);
  Py_CLEAR(clear_module_state->__pyx_n_s_IFTE);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Increase_the_size_of_a_matrix_w);
  Py_CLEAR(clear_module_state->__pyx_n_s_IndexError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Input);
  Py_CLEAR(clear_module_state->__pyx_n_s_InputStr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Interrupted_by_a_ctrl_c_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_Inverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_J);
  Py_CLEAR(clear_module_state->__pyx_n_s_JordanBlock);
  Py_CLEAR(clear_module_state->__pyx_n_s_K);
  Py_CLEAR(clear_module_state->__pyx_n_s_Kcal);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyboardInterrupt);
  Py_CLEAR(clear_module_state->__pyx_n_s_LN);
  Py_CLEAR(clear_module_state->__pyx_n_s_LQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_LSQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_LU);
  Py_CLEAR(clear_module_state->__pyx_n_s_LambertW);
  Py_CLEAR(clear_module_state->__pyx_n_s_Li);
  Py_CLEAR(clear_module_state->__pyx_n_s_Line);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineHorz);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineTan);
  Py_CLEAR(clear_module_state->__pyx_n_s_LineVert);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Lists_of_10_6_integers_should_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_MHz);
  Py_CLEAR(clear_module_state->__pyx_n_s_MSE);
  Py_CLEAR(clear_module_state->__pyx_n_s_MW);
  Py_CLEAR(clear_module_state->__pyx_n_s_MeV);
  Py_CLEAR(clear_module_state->__pyx_n_s_N);
  Py_CLEAR(clear_module_state->__pyx_n_s_NA);
  Py_CLEAR(clear_module_state->__pyx_n_s_NORMALD);
  Py_CLEAR(clear_module_state->__pyx_n_s_NULL);
  Py_CLEAR(clear_module_state->__pyx_n_s_NewFold);
  Py_CLEAR(clear_module_state->__pyx_n_s_NewPic);
  Py_CLEAR(clear_module_state->__pyx_n_s_Nullspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ohm);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Open_a_file_in_giac_compressed);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Open_the_giac_html_detailled_he);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Open_the_giac_html_detailled_he_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Output);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ox_2d_unit_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ox_3d_unit_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Oy_2d_unit_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Oy_3d_unit_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Oz_3d_unit_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_P);
  Py_CLEAR(clear_module_state->__pyx_n_s_PSun);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pa);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pause);
  Py_CLEAR(clear_module_state->__pyx_n_s_Phi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pi);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_PopUp);
  Py_CLEAR(clear_module_state->__pyx_n_s_Psi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___float___line_1078);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___getitem___line_913);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___int___line_1059);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen___iter);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___iter___line_1035);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___radd___line_1192);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___repr___line_877);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___rmod___line_1410);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___rmul___line_1286);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___rpow___line_1372);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___rsub___line_1248);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___rtruediv___line_1337);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen___setitem___line_986);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen__repr_html);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen__repr_latex);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_cas_setup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_eval);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_help);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_htmlhelp);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen_htmlhelp_line_1498);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen_lists_of_10_6_elements_sh);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_qcas);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen_qcas_line_1552);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_redim);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen_redim_line_1526);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_save);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Pygen_save_line_1469);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pygen_threadeval);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pymaxint);
  Py_CLEAR(clear_module_state->__pyx_n_s_PythonVersion3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pyversioninfo);
  Py_CLEAR(clear_module_state->__pyx_n_s_QR);
  Py_CLEAR(clear_module_state->__pyx_n_s_Quo);
  Py_CLEAR(clear_module_state->__pyx_n_s_R);
  Py_CLEAR(clear_module_state->__pyx_n_s_REDIM);
  Py_CLEAR(clear_module_state->__pyx_n_s_REPLACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_REarth);
  Py_CLEAR(clear_module_state->__pyx_n_s_RSun);
  Py_CLEAR(clear_module_state->__pyx_n_s_R_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_RandSeed);
  Py_CLEAR(clear_module_state->__pyx_n_s_Rankine);
  Py_CLEAR(clear_module_state->__pyx_n_s_RclPic);
  Py_CLEAR(clear_module_state->__pyx_n_s_ReLU);
  Py_CLEAR(clear_module_state->__pyx_n_s_Rem);
  Py_CLEAR(clear_module_state->__pyx_n_s_Request);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Result_is_too_big_for_Display_I);
  Py_CLEAR(clear_module_state->__pyx_n_s_Resultant);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Reverse_operator_7_giac_3_Calle);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_1_d_C);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_2_d_C);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Rinfinity);
  Py_CLEAR(clear_module_state->__pyx_n_s_Row);
  Py_CLEAR(clear_module_state->__pyx_n_s_RplcPic);
  Py_CLEAR(clear_module_state->__pyx_n_s_Rref);
  Py_CLEAR(clear_module_state->__pyx_n_s_RuntimeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_S);
  Py_CLEAR(clear_module_state->__pyx_n_s_SCALE);
  Py_CLEAR(clear_module_state->__pyx_n_s_SCALEADD);
  Py_CLEAR(clear_module_state->__pyx_n_s_SCHUR);
  Py_CLEAR(clear_module_state->__pyx_n_s_SIN);
  Py_CLEAR(clear_module_state->__pyx_n_s_SVD);
  Py_CLEAR(clear_module_state->__pyx_n_s_SVL);
  Py_CLEAR(clear_module_state->__pyx_n_s_SWAPCOL);
  Py_CLEAR(clear_module_state->__pyx_n_s_SWAPROW);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Send_a_giac_graphic_to_qcas_3D);
  Py_CLEAR(clear_module_state->__pyx_n_s_SetFold);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Set_the_value_of_a_coefficient);
  Py_CLEAR(clear_module_state->__pyx_n_s_Si);
  Py_CLEAR(clear_module_state->__pyx_n_s_SortA);
  Py_CLEAR(clear_module_state->__pyx_n_s_SortD);
  Py_CLEAR(clear_module_state->__pyx_n_s_St);
  Py_CLEAR(clear_module_state->__pyx_n_s_StdP);
  Py_CLEAR(clear_module_state->__pyx_n_s_StdT);
  Py_CLEAR(clear_module_state->__pyx_n_s_StoPic);
  Py_CLEAR(clear_module_state->__pyx_n_s_Store);
  Py_CLEAR(clear_module_state->__pyx_n_s_Sv);
  Py_CLEAR(clear_module_state->__pyx_n_s_T);
  Py_CLEAR(clear_module_state->__pyx_n_s_TAN);
  Py_CLEAR(clear_module_state->__pyx_n_s_TRUE);
  Py_CLEAR(clear_module_state->__pyx_n_s_TeX);
  Py_CLEAR(clear_module_state->__pyx_n_s_Text);
  Py_CLEAR(clear_module_state->__pyx_kp_u_This_function_evaluate_a_python);
  Py_CLEAR(clear_module_state->__pyx_n_s_ThreadedPygen);
  Py_CLEAR(clear_module_state->__pyx_n_s_ThreadedPygen___call);
  Py_CLEAR(clear_module_state->__pyx_n_s_Title);
  Py_CLEAR(clear_module_state->__pyx_n_s_True);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_UTF_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_UTPC);
  Py_CLEAR(clear_module_state->__pyx_n_s_UTPF);
  Py_CLEAR(clear_module_state->__pyx_n_s_UTPN);
  Py_CLEAR(clear_module_state->__pyx_n_s_UTPT);
  Py_CLEAR(clear_module_state->__pyx_n_s_Unarchiv);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Use_this_subclass_of_to_call_yo);
  Py_CLEAR(clear_module_state->__pyx_n_s_V);
  Py_CLEAR(clear_module_state->__pyx_n_s_VARS);
  Py_CLEAR(clear_module_state->__pyx_n_s_VAS);
  Py_CLEAR(clear_module_state->__pyx_n_s_VAS_positive);
  Py_CLEAR(clear_module_state->__pyx_n_s_Vm);
  Py_CLEAR(clear_module_state->__pyx_n_s_W);
  Py_CLEAR(clear_module_state->__pyx_n_s_WAIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_Wb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Wh);
  Py_CLEAR(clear_module_state->__pyx_n_s_Zeta);
  Py_CLEAR(clear_module_state->__pyx_kp_s__10);
  Py_CLEAR(clear_module_state->__pyx_kp_s__12);
  Py_CLEAR(clear_module_state->__pyx_n_s__14);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1655);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1656);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1657);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1658);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1659);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1660);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1661);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1662);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1663);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1664);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1665);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1666);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1667);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1668);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1669);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1670);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1671);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1672);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1673);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1674);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1675);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1676);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1677);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1678);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1679);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1680);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1681);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1682);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1683);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1684);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1685);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1686);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1687);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1688);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1689);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1690);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1691);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1692);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1693);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1694);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1695);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1696);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1697);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1698);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1699);
  Py_CLEAR(clear_module_state->__pyx_kp_s__1700);
  Py_CLEAR(clear_module_state->__pyx_kp_u__8);
  Py_CLEAR(clear_module_state->__pyx_n_s_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_a0);
  Py_CLEAR(clear_module_state->__pyx_n_s_a2q);
  Py_CLEAR(clear_module_state->__pyx_n_s_a_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_abcuv);
  Py_CLEAR(clear_module_state->__pyx_n_s_about);
  Py_CLEAR(clear_module_state->__pyx_n_s_abs);
  Py_CLEAR(clear_module_state->__pyx_n_s_abscissa);
  Py_CLEAR(clear_module_state->__pyx_n_s_access);
  Py_CLEAR(clear_module_state->__pyx_n_s_accumulate_head_tail);
  Py_CLEAR(clear_module_state->__pyx_n_s_acos);
  Py_CLEAR(clear_module_state->__pyx_n_s_acos2asin);
  Py_CLEAR(clear_module_state->__pyx_n_s_acos2atan);
  Py_CLEAR(clear_module_state->__pyx_n_s_acosh);
  Py_CLEAR(clear_module_state->__pyx_n_s_acot);
  Py_CLEAR(clear_module_state->__pyx_n_s_acre);
  Py_CLEAR(clear_module_state->__pyx_n_s_acsc);
  Py_CLEAR(clear_module_state->__pyx_n_s_acyclic);
  Py_CLEAR(clear_module_state->__pyx_n_s_adaptive);
  Py_CLEAR(clear_module_state->__pyx_n_s_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_edge);
  Py_CLEAR(clear_module_state->__pyx_kp_s_add_language_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_additionally);
  Py_CLEAR(clear_module_state->__pyx_n_s_addtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_adjacency_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_adjoint_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_affichage);
  Py_CLEAR(clear_module_state->__pyx_n_s_affix);
  Py_CLEAR(clear_module_state->__pyx_n_s_algsubs);
  Py_CLEAR(clear_module_state->__pyx_n_s_algvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_all);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_trig_solutions);
  Py_CLEAR(clear_module_state->__pyx_n_s_allpairs_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_alog10);
  Py_CLEAR(clear_module_state->__pyx_n_s_alors);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_altitude);
  Py_CLEAR(clear_module_state->__pyx_n_s_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_angl);
  Py_CLEAR(clear_module_state->__pyx_n_s_angle);
  Py_CLEAR(clear_module_state->__pyx_n_s_angle_radian);
  Py_CLEAR(clear_module_state->__pyx_n_s_angleat);
  Py_CLEAR(clear_module_state->__pyx_n_s_angleatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_animate);
  Py_CLEAR(clear_module_state->__pyx_n_s_animate3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_animation);
  Py_CLEAR(clear_module_state->__pyx_n_s_ans);
  Py_CLEAR(clear_module_state->__pyx_n_s_antiprism_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_approx);
  Py_CLEAR(clear_module_state->__pyx_n_s_approx_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_arcLen);
  Py_CLEAR(clear_module_state->__pyx_n_s_arccos);
  Py_CLEAR(clear_module_state->__pyx_n_s_arccosh);
  Py_CLEAR(clear_module_state->__pyx_n_s_archive);
  Py_CLEAR(clear_module_state->__pyx_n_s_arclen);
  Py_CLEAR(clear_module_state->__pyx_n_s_arcmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_arcs);
  Py_CLEAR(clear_module_state->__pyx_n_s_arcsin);
  Py_CLEAR(clear_module_state->__pyx_n_s_arcsinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_arctan);
  Py_CLEAR(clear_module_state->__pyx_n_s_arctanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_area);
  Py_CLEAR(clear_module_state->__pyx_n_s_areaat);
  Py_CLEAR(clear_module_state->__pyx_n_s_areaatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_areaplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_arg);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_kp_s_argument_must_be_a_Pygen_list_an);
  Py_CLEAR(clear_module_state->__pyx_kp_s_argument_must_be_a_tuple_or_a_li);
  Py_CLEAR(clear_module_state->__pyx_n_s_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_arrivals);
  Py_CLEAR(clear_module_state->__pyx_n_s_articulation_points);
  Py_CLEAR(clear_module_state->__pyx_n_s_as_function_of);
  Py_CLEAR(clear_module_state->__pyx_n_s_asc);
  Py_CLEAR(clear_module_state->__pyx_n_s_asec);
  Py_CLEAR(clear_module_state->__pyx_n_s_asin);
  Py_CLEAR(clear_module_state->__pyx_n_s_asin2acos);
  Py_CLEAR(clear_module_state->__pyx_n_s_asin2atan);
  Py_CLEAR(clear_module_state->__pyx_n_s_asinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_assert);
  Py_CLEAR(clear_module_state->__pyx_n_s_assign);
  Py_CLEAR(clear_module_state->__pyx_n_s_assign_edge_weights);
  Py_CLEAR(clear_module_state->__pyx_n_s_assume);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_at);
  Py_CLEAR(clear_module_state->__pyx_n_s_atan);
  Py_CLEAR(clear_module_state->__pyx_n_s_atan2);
  Py_CLEAR(clear_module_state->__pyx_n_s_atan2acos);
  Py_CLEAR(clear_module_state->__pyx_n_s_atan2asin);
  Py_CLEAR(clear_module_state->__pyx_n_s_atanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_atm);
  Py_CLEAR(clear_module_state->__pyx_n_s_atrig2ln);
  Py_CLEAR(clear_module_state->__pyx_n_s_au);
  Py_CLEAR(clear_module_state->__pyx_n_s_augment);
  Py_CLEAR(clear_module_state->__pyx_n_s_auto_correlation);
  Py_CLEAR(clear_module_state->__pyx_n_s_autosimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_avance);
  Py_CLEAR(clear_module_state->__pyx_n_s_avgRC);
  Py_CLEAR(clear_module_state->__pyx_n_s_axes);
  Py_CLEAR(clear_module_state->__pyx_n_s_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_b_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_back);
  Py_CLEAR(clear_module_state->__pyx_n_s_backquote);
  Py_CLEAR(clear_module_state->__pyx_n_s_backward);
  Py_CLEAR(clear_module_state->__pyx_n_s_baisse_crayon);
  Py_CLEAR(clear_module_state->__pyx_n_s_bandwidth);
  Py_CLEAR(clear_module_state->__pyx_n_s_bar);
  Py_CLEAR(clear_module_state->__pyx_n_s_bar_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_barplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_bartlett_hann_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_barycenter);
  Py_CLEAR(clear_module_state->__pyx_n_s_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_basis);
  Py_CLEAR(clear_module_state->__pyx_n_s_batons);
  Py_CLEAR(clear_module_state->__pyx_n_s_bbl);
  Py_CLEAR(clear_module_state->__pyx_n_s_bblep);
  Py_CLEAR(clear_module_state->__pyx_n_s_begin);
  Py_CLEAR(clear_module_state->__pyx_n_s_bellman_ford);
  Py_CLEAR(clear_module_state->__pyx_n_s_berlekamp_massey);
  Py_CLEAR(clear_module_state->__pyx_n_s_bernoulli);
  Py_CLEAR(clear_module_state->__pyx_n_s_bernoulli_mod);
  Py_CLEAR(clear_module_state->__pyx_n_s_besselJ);
  Py_CLEAR(clear_module_state->__pyx_n_s_besselY);
  Py_CLEAR(clear_module_state->__pyx_n_s_betad);
  Py_CLEAR(clear_module_state->__pyx_n_s_betad_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_betad_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_betavariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_betweenness_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_bezier);
  Py_CLEAR(clear_module_state->__pyx_n_s_bezout_entiers);
  Py_CLEAR(clear_module_state->__pyx_n_s_bezoutian);
  Py_CLEAR(clear_module_state->__pyx_n_s_biconnected_components);
  Py_CLEAR(clear_module_state->__pyx_n_s_binomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_binomial_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_binomial_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_bins);
  Py_CLEAR(clear_module_state->__pyx_n_s_bipartite);
  Py_CLEAR(clear_module_state->__pyx_n_s_bipartite_matching);
  Py_CLEAR(clear_module_state->__pyx_n_s_bisection_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_bisector);
  Py_CLEAR(clear_module_state->__pyx_n_s_bit_depth);
  Py_CLEAR(clear_module_state->__pyx_n_s_bit_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_bitand);
  Py_CLEAR(clear_module_state->__pyx_n_s_bitor);
  Py_CLEAR(clear_module_state->__pyx_n_s_bitxor);
  Py_CLEAR(clear_module_state->__pyx_n_s_black);
  Py_CLEAR(clear_module_state->__pyx_n_s_blacklist);
  Py_CLEAR(clear_module_state->__pyx_n_s_blackman_harris_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_blackman_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_blanc);
  Py_CLEAR(clear_module_state->__pyx_n_s_bleu);
  Py_CLEAR(clear_module_state->__pyx_n_s_bloc);
  Py_CLEAR(clear_module_state->__pyx_n_s_block_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_blockmatrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_blue);
  Py_CLEAR(clear_module_state->__pyx_n_s_bohman_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_border);
  Py_CLEAR(clear_module_state->__pyx_n_s_box_constraints);
  Py_CLEAR(clear_module_state->__pyx_n_s_boxcar);
  Py_CLEAR(clear_module_state->__pyx_n_s_boxwhisker);
  Py_CLEAR(clear_module_state->__pyx_n_s_break);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_brent_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_brown);
  Py_CLEAR(clear_module_state->__pyx_n_s_bspline);
  Py_CLEAR(clear_module_state->__pyx_n_s_bu);
  Py_CLEAR(clear_module_state->__pyx_n_s_buUS);
  Py_CLEAR(clear_module_state->__pyx_n_s_builtins);
  Py_CLEAR(clear_module_state->__pyx_n_s_bvpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_by);
  Py_CLEAR(clear_module_state->__pyx_n_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_c1oc2);
  Py_CLEAR(clear_module_state->__pyx_n_s_c1op2);
  Py_CLEAR(clear_module_state->__pyx_n_s_c3);
  Py_CLEAR(clear_module_state->__pyx_n_s_cFactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_cSolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_cZeros);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_tortue);
  Py_CLEAR(clear_module_state->__pyx_n_s_cal);
  Py_CLEAR(clear_module_state->__pyx_n_s_call);
  Py_CLEAR(clear_module_state->__pyx_n_s_camembert);
  Py_CLEAR(clear_module_state->__pyx_n_s_canonical_form);
  Py_CLEAR(clear_module_state->__pyx_n_s_canonical_labeling);
  Py_CLEAR(clear_module_state->__pyx_n_s_cap);
  Py_CLEAR(clear_module_state->__pyx_n_s_cap_flat_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_cap_round_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_cap_square_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_cartesian_product);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cas_monitor_status);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cas_monitor_status_after_killing);
  Py_CLEAR(clear_module_state->__pyx_n_s_cas_setup);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cas_setup_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cas_setup_s);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cascmd);
  Py_CLEAR(clear_module_state->__pyx_n_s_case);
  Py_CLEAR(clear_module_state->__pyx_n_s_cat);
  Py_CLEAR(clear_module_state->__pyx_n_s_catch);
  Py_CLEAR(clear_module_state->__pyx_n_s_cauchy);
  Py_CLEAR(clear_module_state->__pyx_n_s_cauchy_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_cauchy_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_cauchyd);
  Py_CLEAR(clear_module_state->__pyx_n_s_cauchyd_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_cauchyd_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_cd);
  Py_CLEAR(clear_module_state->__pyx_n_s_cd_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_ceil);
  Py_CLEAR(clear_module_state->__pyx_n_s_ceiling);
  Py_CLEAR(clear_module_state->__pyx_n_s_center);
  Py_CLEAR(clear_module_state->__pyx_n_s_center2interval);
  Py_CLEAR(clear_module_state->__pyx_n_s_centered_cube);
  Py_CLEAR(clear_module_state->__pyx_n_s_centered_tetrahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_cfactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_cfsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_chain);
  Py_CLEAR(clear_module_state->__pyx_n_s_changebase);
  Py_CLEAR(clear_module_state->__pyx_n_s_channel_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_channels);
  Py_CLEAR(clear_module_state->__pyx_n_s_char);
  Py_CLEAR(clear_module_state->__pyx_n_s_charpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_chinrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquare);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquare_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquare_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquared);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquared_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquared_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_chisquaret);
  Py_CLEAR(clear_module_state->__pyx_n_s_choice);
  Py_CLEAR(clear_module_state->__pyx_n_s_cholesky);
  Py_CLEAR(clear_module_state->__pyx_n_s_choosebox);
  Py_CLEAR(clear_module_state->__pyx_n_s_chr);
  Py_CLEAR(clear_module_state->__pyx_n_s_chrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_chromatic_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_chromatic_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_chromatic_polynomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_circumcircle);
  Py_CLEAR(clear_module_state->__pyx_n_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_classes);
  Py_CLEAR(clear_module_state->__pyx_n_s_clear);
  Py_CLEAR(clear_module_state->__pyx_n_s_click);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_clique_cover);
  Py_CLEAR(clear_module_state->__pyx_n_s_clique_cover_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_clique_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_closeness_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_cluster);
  Py_CLEAR(clear_module_state->__pyx_n_s_clustering_coefficient);
  Py_CLEAR(clear_module_state->__pyx_n_s_cm);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cm_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cm_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_cm_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_coeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_coeffs);
  Py_CLEAR(clear_module_state->__pyx_n_s_col);
  Py_CLEAR(clear_module_state->__pyx_n_s_colDim);
  Py_CLEAR(clear_module_state->__pyx_n_s_colNorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_colSwap);
  Py_CLEAR(clear_module_state->__pyx_n_s_coldim);
  Py_CLEAR(clear_module_state->__pyx_n_s_collect);
  Py_CLEAR(clear_module_state->__pyx_n_s_colnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_colormap);
  Py_CLEAR(clear_module_state->__pyx_n_s_colspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_colswap);
  Py_CLEAR(clear_module_state->__pyx_n_s_comDenom);
  Py_CLEAR(clear_module_state->__pyx_n_s_comb);
  Py_CLEAR(clear_module_state->__pyx_n_s_combine);
  Py_CLEAR(clear_module_state->__pyx_n_s_comment);
  Py_CLEAR(clear_module_state->__pyx_n_s_common_perpendicular);
  Py_CLEAR(clear_module_state->__pyx_n_s_companion);
  Py_CLEAR(clear_module_state->__pyx_n_s_compare);
  Py_CLEAR(clear_module_state->__pyx_n_s_complete_binary_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_complete_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_complete_kary_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_complex);
  Py_CLEAR(clear_module_state->__pyx_n_s_complex_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_complex_variables);
  Py_CLEAR(clear_module_state->__pyx_n_s_complexroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_concat);
  Py_CLEAR(clear_module_state->__pyx_n_s_cond);
  Py_CLEAR(clear_module_state->__pyx_n_s_condensation);
  Py_CLEAR(clear_module_state->__pyx_n_s_condi);
  Py_CLEAR(clear_module_state->__pyx_n_s_cone);
  Py_CLEAR(clear_module_state->__pyx_n_s_confrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_conic);
  Py_CLEAR(clear_module_state->__pyx_n_s_conj);
  Py_CLEAR(clear_module_state->__pyx_n_s_conjugate_equation);
  Py_CLEAR(clear_module_state->__pyx_n_s_conjugate_gradient);
  Py_CLEAR(clear_module_state->__pyx_n_s_connected);
  Py_CLEAR(clear_module_state->__pyx_n_s_connected_components);
  Py_CLEAR(clear_module_state->__pyx_n_s_cont);
  Py_CLEAR(clear_module_state->__pyx_n_s_contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_content);
  Py_CLEAR(clear_module_state->__pyx_n_s_context_ptr);
  Py_CLEAR(clear_module_state->__pyx_n_s_continue);
  Py_CLEAR(clear_module_state->__pyx_n_s_contourplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_contract_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_contract_subgraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_convert);
  Py_CLEAR(clear_module_state->__pyx_n_s_convertir);
  Py_CLEAR(clear_module_state->__pyx_n_s_convex);
  Py_CLEAR(clear_module_state->__pyx_n_s_convexhull);
  Py_CLEAR(clear_module_state->__pyx_n_s_convolution);
  Py_CLEAR(clear_module_state->__pyx_n_s_coordinates);
  Py_CLEAR(clear_module_state->__pyx_n_s_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_correlation);
  Py_CLEAR(clear_module_state->__pyx_n_s_cos);
  Py_CLEAR(clear_module_state->__pyx_n_s_cos2sintan);
  Py_CLEAR(clear_module_state->__pyx_n_s_cosh);
  Py_CLEAR(clear_module_state->__pyx_n_s_cosine_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_cot);
  Py_CLEAR(clear_module_state->__pyx_n_s_cote);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_count_eq);
  Py_CLEAR(clear_module_state->__pyx_n_s_count_inf);
  Py_CLEAR(clear_module_state->__pyx_n_s_count_sup);
  Py_CLEAR(clear_module_state->__pyx_n_s_courbe_parametrique);
  Py_CLEAR(clear_module_state->__pyx_n_s_courbe_polaire);
  Py_CLEAR(clear_module_state->__pyx_n_s_covariance);
  Py_CLEAR(clear_module_state->__pyx_n_s_covariance_correlation);
  Py_CLEAR(clear_module_state->__pyx_n_s_cpartfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_crationalroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_crayon);
  Py_CLEAR(clear_module_state->__pyx_n_s_createwav);
  Py_CLEAR(clear_module_state->__pyx_n_s_cross);
  Py_CLEAR(clear_module_state->__pyx_n_s_crossP);
  Py_CLEAR(clear_module_state->__pyx_n_s_cross_correlation);
  Py_CLEAR(clear_module_state->__pyx_n_s_cross_entropy);
  Py_CLEAR(clear_module_state->__pyx_n_s_cross_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_cross_ratio);
  Py_CLEAR(clear_module_state->__pyx_n_s_crossproduct);
  Py_CLEAR(clear_module_state->__pyx_n_s_csc);
  Py_CLEAR(clear_module_state->__pyx_n_s_csolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_csv2gen);
  Py_CLEAR(clear_module_state->__pyx_n_s_ct);
  Py_CLEAR(clear_module_state->__pyx_n_s_cu);
  Py_CLEAR(clear_module_state->__pyx_n_s_cube);
  Py_CLEAR(clear_module_state->__pyx_n_s_cumSum);
  Py_CLEAR(clear_module_state->__pyx_n_s_cumsum);
  Py_CLEAR(clear_module_state->__pyx_n_s_cumulated_frequencies);
  Py_CLEAR(clear_module_state->__pyx_n_s_curl);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_sheet);
  Py_CLEAR(clear_module_state->__pyx_n_s_curvature);
  Py_CLEAR(clear_module_state->__pyx_n_s_curve);
  Py_CLEAR(clear_module_state->__pyx_n_s_cyan);
  Py_CLEAR(clear_module_state->__pyx_n_s_cycle2perm);
  Py_CLEAR(clear_module_state->__pyx_n_s_cycle_basis);
  Py_CLEAR(clear_module_state->__pyx_n_s_cycle_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_cycleinv);
  Py_CLEAR(clear_module_state->__pyx_n_s_cycles2permu);
  Py_CLEAR(clear_module_state->__pyx_n_s_cyclotomic);
  Py_CLEAR(clear_module_state->__pyx_n_s_cylinder);
  Py_CLEAR(clear_module_state->__pyx_n_s_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_dB);
  Py_CLEAR(clear_module_state->__pyx_n_s_d_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_dash_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_dashdot_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_dashdotdot_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_dayofweek);
  Py_CLEAR(clear_module_state->__pyx_n_s_de);
  Py_CLEAR(clear_module_state->__pyx_n_s_deSolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_debug);
  Py_CLEAR(clear_module_state->__pyx_n_s_debut_enregistrement);
  Py_CLEAR(clear_module_state->__pyx_n_s_decode);
  Py_CLEAR(clear_module_state->__pyx_n_s_decstring23);
  Py_CLEAR(clear_module_state->__pyx_n_s_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_deg);
  Py_CLEAR(clear_module_state->__pyx_n_s_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_degreeF);
  Py_CLEAR(clear_module_state->__pyx_n_s_degree_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_degree_sequence);
  Py_CLEAR(clear_module_state->__pyx_n_s_degrees);
  Py_CLEAR(clear_module_state->__pyx_n_s_del);
  Py_CLEAR(clear_module_state->__pyx_n_s_delcols);
  Py_CLEAR(clear_module_state->__pyx_n_s_delete_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_delete_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_delete_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_delrows);
  Py_CLEAR(clear_module_state->__pyx_n_s_deltalist);
  Py_CLEAR(clear_module_state->__pyx_n_s_denom);
  Py_CLEAR(clear_module_state->__pyx_n_s_densityplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_departures);
  Py_CLEAR(clear_module_state->__pyx_n_s_derive);
  Py_CLEAR(clear_module_state->__pyx_n_s_deriver);
  Py_CLEAR(clear_module_state->__pyx_n_s_desolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_dessine_tortue);
  Py_CLEAR(clear_module_state->__pyx_n_s_det);
  Py_CLEAR(clear_module_state->__pyx_n_s_det_minor);
  Py_CLEAR(clear_module_state->__pyx_n_s_developper);
  Py_CLEAR(clear_module_state->__pyx_n_s_developper_transcendant);
  Py_CLEAR(clear_module_state->__pyx_n_s_dfc);
  Py_CLEAR(clear_module_state->__pyx_n_s_dfc2f);
  Py_CLEAR(clear_module_state->__pyx_n_s_diag);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_digraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_dijkstra);
  Py_CLEAR(clear_module_state->__pyx_n_s_dim);
  Py_CLEAR(clear_module_state->__pyx_n_s_directed);
  Py_CLEAR(clear_module_state->__pyx_n_s_directevalued);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_discard_edge_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_discard_graph_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_discard_vertex_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_disjoint_union);
  Py_CLEAR(clear_module_state->__pyx_n_s_display);
  Py_CLEAR(clear_module_state->__pyx_n_s_disque);
  Py_CLEAR(clear_module_state->__pyx_n_s_disque_centre);
  Py_CLEAR(clear_module_state->__pyx_n_s_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_distance2);
  Py_CLEAR(clear_module_state->__pyx_n_s_distanceat);
  Py_CLEAR(clear_module_state->__pyx_n_s_distanceatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_div);
  Py_CLEAR(clear_module_state->__pyx_n_s_div_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_divergence);
  Py_CLEAR(clear_module_state->__pyx_n_s_divide);
  Py_CLEAR(clear_module_state->__pyx_n_s_divis);
  Py_CLEAR(clear_module_state->__pyx_n_s_division_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_divisors);
  Py_CLEAR(clear_module_state->__pyx_n_s_divmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_divpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_dnewton_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_do);
  Py_CLEAR(clear_module_state->__pyx_kp_s_doc);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_dodecahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_domain);
  Py_CLEAR(clear_module_state->__pyx_n_s_dot);
  Py_CLEAR(clear_module_state->__pyx_n_s_dotP);
  Py_CLEAR(clear_module_state->__pyx_n_s_dot_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_dotprod);
  Py_CLEAR(clear_module_state->__pyx_n_s_double);
  Py_CLEAR(clear_module_state->__pyx_n_s_double_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_pixel);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_polygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_draw_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_droit);
  Py_CLEAR(clear_module_state->__pyx_n_s_droite_tangente);
  Py_CLEAR(clear_module_state->__pyx_n_s_dsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_duration);
  Py_CLEAR(clear_module_state->__pyx_n_s_dwt);
  Py_CLEAR(clear_module_state->__pyx_n_s_dyn);
  Py_CLEAR(clear_module_state->__pyx_n_s_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_e2r);
  Py_CLEAR(clear_module_state->__pyx_n_s_eV);
  Py_CLEAR(clear_module_state->__pyx_n_s_ecart_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_ecart_type_population);
  Py_CLEAR(clear_module_state->__pyx_n_s_ecef2geodetic);
  Py_CLEAR(clear_module_state->__pyx_n_s_ecm_factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_ecris);
  Py_CLEAR(clear_module_state->__pyx_n_s_edge_connectivity);
  Py_CLEAR(clear_module_state->__pyx_n_s_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_efface);
  Py_CLEAR(clear_module_state->__pyx_n_s_egcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_egv);
  Py_CLEAR(clear_module_state->__pyx_n_s_egvl);
  Py_CLEAR(clear_module_state->__pyx_n_s_eigVc);
  Py_CLEAR(clear_module_state->__pyx_n_s_eigVl);
  Py_CLEAR(clear_module_state->__pyx_n_s_eigenvals);
  Py_CLEAR(clear_module_state->__pyx_n_s_eigenvalues);
  Py_CLEAR(clear_module_state->__pyx_n_s_eigenvectors);
  Py_CLEAR(clear_module_state->__pyx_n_s_eigenvects);
  Py_CLEAR(clear_module_state->__pyx_n_s_el);
  Py_CLEAR(clear_module_state->__pyx_n_s_element);
  Py_CLEAR(clear_module_state->__pyx_n_s_elif);
  Py_CLEAR(clear_module_state->__pyx_n_s_eliminate);
  Py_CLEAR(clear_module_state->__pyx_n_s_ellipse);
  Py_CLEAR(clear_module_state->__pyx_n_s_else);
  Py_CLEAR(clear_module_state->__pyx_n_s_emd);
  Py_CLEAR(clear_module_state->__pyx_n_s_en);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_encstring23);
  Py_CLEAR(clear_module_state->__pyx_n_s_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_for);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_if);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_while);
  Py_CLEAR(clear_module_state->__pyx_n_s_entry);
  Py_CLEAR(clear_module_state->__pyx_n_s_envelope);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_ligne_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_epaisseur_point_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilon);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilon0);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilon0q);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilon2zero);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilonox);
  Py_CLEAR(clear_module_state->__pyx_n_s_epsilonsi);
  Py_CLEAR(clear_module_state->__pyx_n_s_equal);
  Py_CLEAR(clear_module_state->__pyx_n_s_equal2diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_equal2list);
  Py_CLEAR(clear_module_state->__pyx_n_s_equation);
  Py_CLEAR(clear_module_state->__pyx_n_s_equilateral_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_erase);
  Py_CLEAR(clear_module_state->__pyx_n_s_erase3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_erf);
  Py_CLEAR(clear_module_state->__pyx_n_s_erfc);
  Py_CLEAR(clear_module_state->__pyx_n_s_erg);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_est_cocyclique);
  Py_CLEAR(clear_module_state->__pyx_n_s_est_inclus);
  Py_CLEAR(clear_module_state->__pyx_n_s_est_permu);
  Py_CLEAR(clear_module_state->__pyx_n_s_et);
  Py_CLEAR(clear_module_state->__pyx_n_s_euler);
  Py_CLEAR(clear_module_state->__pyx_n_s_euler_gamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_euler_lagrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_eval);
  Py_CLEAR(clear_module_state->__pyx_n_s_eval_level);
  Py_CLEAR(clear_module_state->__pyx_n_s_evala);
  Py_CLEAR(clear_module_state->__pyx_n_s_evalb);
  Py_CLEAR(clear_module_state->__pyx_n_s_evalc);
  Py_CLEAR(clear_module_state->__pyx_n_s_evalf);
  Py_CLEAR(clear_module_state->__pyx_n_s_evalm);
  Py_CLEAR(clear_module_state->__pyx_n_s_even);
  Py_CLEAR(clear_module_state->__pyx_n_s_evolute);
  Py_CLEAR(clear_module_state->__pyx_n_s_exact);
  Py_CLEAR(clear_module_state->__pyx_n_s_exbisector);
  Py_CLEAR(clear_module_state->__pyx_n_s_excircle);
  Py_CLEAR(clear_module_state->__pyx_n_s_execute);
  Py_CLEAR(clear_module_state->__pyx_n_s_exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_exp2list);
  Py_CLEAR(clear_module_state->__pyx_n_s_exp2pow);
  Py_CLEAR(clear_module_state->__pyx_n_s_exp2trig);
  Py_CLEAR(clear_module_state->__pyx_n_s_expand);
  Py_CLEAR(clear_module_state->__pyx_n_s_expexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_expln);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponential);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponential_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponential_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponential_regression);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponential_regression_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponentiald);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponentiald_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_exponentiald_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_export_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_export_mathml);
  Py_CLEAR(clear_module_state->__pyx_n_s_expovariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_expr);
  Py_CLEAR(clear_module_state->__pyx_n_s_expression);
  Py_CLEAR(clear_module_state->__pyx_n_s_extend);
  Py_CLEAR(clear_module_state->__pyx_n_s_extract_measure);
  Py_CLEAR(clear_module_state->__pyx_n_s_extrema);
  Py_CLEAR(clear_module_state->__pyx_n_s_ezgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_f0);
  Py_CLEAR(clear_module_state->__pyx_n_s_f2nd);
  Py_CLEAR(clear_module_state->__pyx_n_s_fMax);
  Py_CLEAR(clear_module_state->__pyx_n_s_fMin);
  Py_CLEAR(clear_module_state->__pyx_n_s_fPart);
  Py_CLEAR(clear_module_state->__pyx_n_s_faces);
  Py_CLEAR(clear_module_state->__pyx_n_s_facteurs_premiers);
  Py_CLEAR(clear_module_state->__pyx_n_s_factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_factor_xn);
  Py_CLEAR(clear_module_state->__pyx_n_s_factorial);
  Py_CLEAR(clear_module_state->__pyx_n_s_factoriser);
  Py_CLEAR(clear_module_state->__pyx_n_s_factoriser_entier);
  Py_CLEAR(clear_module_state->__pyx_n_s_factoriser_sur_C);
  Py_CLEAR(clear_module_state->__pyx_n_s_factors);
  Py_CLEAR(clear_module_state->__pyx_n_s_fadeev);
  Py_CLEAR(clear_module_state->__pyx_kp_s_failed_to_init_doc_from_giac_s_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_faire);
  Py_CLEAR(clear_module_state->__pyx_n_s_false);
  Py_CLEAR(clear_module_state->__pyx_n_s_falsepos_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_fath);
  Py_CLEAR(clear_module_state->__pyx_n_s_faux);
  Py_CLEAR(clear_module_state->__pyx_n_s_fbm);
  Py_CLEAR(clear_module_state->__pyx_n_s_fc);
  Py_CLEAR(clear_module_state->__pyx_n_s_fclose);
  Py_CLEAR(clear_module_state->__pyx_n_s_fcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_fdistrib);
  Py_CLEAR(clear_module_state->__pyx_n_s_fermi);
  Py_CLEAR(clear_module_state->__pyx_n_s_feuille);
  Py_CLEAR(clear_module_state->__pyx_n_s_ffaire);
  Py_CLEAR(clear_module_state->__pyx_n_s_ffonction);
  Py_CLEAR(clear_module_state->__pyx_n_s_fft);
  Py_CLEAR(clear_module_state->__pyx_n_s_ffunction);
  Py_CLEAR(clear_module_state->__pyx_n_s_fi);
  Py_CLEAR(clear_module_state->__pyx_n_s_fieldplot);
  Py_CLEAR(clear_module_state->__pyx_kp_s_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_filled);
  Py_CLEAR(clear_module_state->__pyx_n_s_fin_enregistrement);
  Py_CLEAR(clear_module_state->__pyx_n_s_find);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_cliques);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_cycles);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_minimum);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_vertex_cover);
  Py_CLEAR(clear_module_state->__pyx_n_s_findhelp);
  Py_CLEAR(clear_module_state->__pyx_n_s_fisher);
  Py_CLEAR(clear_module_state->__pyx_n_s_fisher_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_fisher_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_fisherd);
  Py_CLEAR(clear_module_state->__pyx_n_s_fisherd_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_fisherd_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_fitdistr);
  Py_CLEAR(clear_module_state->__pyx_n_s_fitpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_fitspline);
  Py_CLEAR(clear_module_state->__pyx_n_s_flam);
  Py_CLEAR(clear_module_state->__pyx_n_s_flatten);
  Py_CLEAR(clear_module_state->__pyx_n_s_float);
  Py_CLEAR(clear_module_state->__pyx_n_s_float2rational);
  Py_CLEAR(clear_module_state->__pyx_n_s_floor);
  Py_CLEAR(clear_module_state->__pyx_n_s_flow_polynomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_flower_snark);
  Py_CLEAR(clear_module_state->__pyx_n_s_fm);
  Py_CLEAR(clear_module_state->__pyx_n_s_fmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_foldl);
  Py_CLEAR(clear_module_state->__pyx_n_s_foldr);
  Py_CLEAR(clear_module_state->__pyx_n_s_fonction);
  Py_CLEAR(clear_module_state->__pyx_n_s_fonction_derivee);
  Py_CLEAR(clear_module_state->__pyx_n_s_fopen);
  Py_CLEAR(clear_module_state->__pyx_n_s_for);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_forward);
  Py_CLEAR(clear_module_state->__pyx_n_s_fourier);
  Py_CLEAR(clear_module_state->__pyx_n_s_fourier_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_fourier_bn);
  Py_CLEAR(clear_module_state->__pyx_n_s_fourier_cn);
  Py_CLEAR(clear_module_state->__pyx_n_s_fpour);
  Py_CLEAR(clear_module_state->__pyx_n_s_fprint);
  Py_CLEAR(clear_module_state->__pyx_n_s_fr);
  Py_CLEAR(clear_module_state->__pyx_n_s_frac);
  Py_CLEAR(clear_module_state->__pyx_n_s_fracmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_frame_2d);
  Py_CLEAR(clear_module_state->__pyx_n_s_frame_3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_frames);
  Py_CLEAR(clear_module_state->__pyx_n_s_frank_wolfe);
  Py_CLEAR(clear_module_state->__pyx_n_s_frequencies);
  Py_CLEAR(clear_module_state->__pyx_n_s_frobenius_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_from);
  Py_CLEAR(clear_module_state->__pyx_kp_s_from_giac_s_help);
  Py_CLEAR(clear_module_state->__pyx_kp_u_from_giacpy_import_giac_giac_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_froot);
  Py_CLEAR(clear_module_state->__pyx_n_s_fsi);
  Py_CLEAR(clear_module_state->__pyx_n_s_fsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_ft);
  Py_CLEAR(clear_module_state->__pyx_n_s_ftUS);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ft_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ft_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ft_lb);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ft_lb_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_ft_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_ftantque);
  Py_CLEAR(clear_module_state->__pyx_n_s_fullparfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_func);
  Py_CLEAR(clear_module_state->__pyx_n_s_funcplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_function);
  Py_CLEAR(clear_module_state->__pyx_n_s_function_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_fundamental_cycle);
  Py_CLEAR(clear_module_state->__pyx_n_s_fxnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_g_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ga);
  Py_CLEAR(clear_module_state->__pyx_n_s_galC);
  Py_CLEAR(clear_module_state->__pyx_n_s_galUK);
  Py_CLEAR(clear_module_state->__pyx_n_s_galUS);
  Py_CLEAR(clear_module_state->__pyx_n_s_gammad);
  Py_CLEAR(clear_module_state->__pyx_n_s_gammad_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_gammad_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_gammavariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_gauche);
  Py_CLEAR(clear_module_state->__pyx_n_s_gauss);
  Py_CLEAR(clear_module_state->__pyx_n_s_gauss15);
  Py_CLEAR(clear_module_state->__pyx_n_s_gauss_seidel_linsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_gaussian_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_gaussjord);
  Py_CLEAR(clear_module_state->__pyx_n_s_gaussquad);
  Py_CLEAR(clear_module_state->__pyx_n_s_gbasis);
  Py_CLEAR(clear_module_state->__pyx_n_s_gbasis_max_pairs);
  Py_CLEAR(clear_module_state->__pyx_n_s_gbasis_reinject);
  Py_CLEAR(clear_module_state->__pyx_n_s_gbasis_simult_primes);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_gcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_gcdex);
  Py_CLEAR(clear_module_state->__pyx_kp_s_gen_indexes_are_not_yet_implemen);
  Py_CLEAR(clear_module_state->__pyx_n_s_genpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_geodetic2ecef);
  Py_CLEAR(clear_module_state->__pyx_n_s_geometric);
  Py_CLEAR(clear_module_state->__pyx_n_s_geometric_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_geometric_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_getDenom);
  Py_CLEAR(clear_module_state->__pyx_n_s_getKey);
  Py_CLEAR(clear_module_state->__pyx_n_s_getNum);
  Py_CLEAR(clear_module_state->__pyx_n_s_getType);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_edge_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_edge_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_graph_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_vertex_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_gf);
  Py_CLEAR(clear_module_state->__pyx_n_s_giac);
  Py_CLEAR(clear_module_state->__pyx_kp_s_giac_docs_dir_not_found);
  Py_CLEAR(clear_module_state->__pyx_kp_u_giac_line_163);
  Py_CLEAR(clear_module_state->__pyx_n_s_giacbasedir);
  Py_CLEAR(clear_module_state->__pyx_n_s_giacpy2qcas);
  Py_CLEAR(clear_module_state->__pyx_kp_s_giacpy_auto_methods_pxi);
  Py_CLEAR(clear_module_state->__pyx_n_s_giacpy_giacpy);
  Py_CLEAR(clear_module_state->__pyx_kp_s_giacpy_giacpy_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_giacsettings);
  Py_CLEAR(clear_module_state->__pyx_n_s_girth);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_ortho);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_quaternion);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_rotation);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_showaxes);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_shownames);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_texture);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_x);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_x_axis_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_x_axis_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_x_axis_unit);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_xtick);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_y_axis_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_y_axis_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_y_axis_unit);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_ytick);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_z_axis_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_z_axis_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_z_axis_unit);
  Py_CLEAR(clear_module_state->__pyx_n_s_gl_ztick);
  Py_CLEAR(clear_module_state->__pyx_n_s_gmol);
  Py_CLEAR(clear_module_state->__pyx_n_s_gnuplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_gold);
  Py_CLEAR(clear_module_state->__pyx_n_s_goldberg_snark);
  Py_CLEAR(clear_module_state->__pyx_n_s_gon);
  Py_CLEAR(clear_module_state->__pyx_n_s_goto);
  Py_CLEAR(clear_module_state->__pyx_n_s_grad);
  Py_CLEAR(clear_module_state->__pyx_n_s_grad_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_grain);
  Py_CLEAR(clear_module_state->__pyx_n_s_gramschmidt);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph2tex);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph3d2tex);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_automorphisms);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_charpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_complement);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_diameter);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_equal);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_power);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_rank);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_union);
  Py_CLEAR(clear_module_state->__pyx_n_s_graph_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_graphe);
  Py_CLEAR(clear_module_state->__pyx_n_s_graphe3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_graphe_probabiliste);
  Py_CLEAR(clear_module_state->__pyx_n_s_graphe_suite);
  Py_CLEAR(clear_module_state->__pyx_n_s_greduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_greedy_clique);
  Py_CLEAR(clear_module_state->__pyx_n_s_greedy_color);
  Py_CLEAR(clear_module_state->__pyx_n_s_greedy_independent_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_green);
  Py_CLEAR(clear_module_state->__pyx_n_s_grey);
  Py_CLEAR(clear_module_state->__pyx_n_s_grid_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_grid_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_groupermu);
  Py_CLEAR(clear_module_state->__pyx_n_s_h);
  Py_CLEAR(clear_module_state->__pyx_n_s_h_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ha);
  Py_CLEAR(clear_module_state->__pyx_n_s_haar_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_hadamard);
  Py_CLEAR(clear_module_state->__pyx_n_s_half_cone);
  Py_CLEAR(clear_module_state->__pyx_n_s_half_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_halftan);
  Py_CLEAR(clear_module_state->__pyx_n_s_halftan_hyp2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_halt);
  Py_CLEAR(clear_module_state->__pyx_n_s_hamdist);
  Py_CLEAR(clear_module_state->__pyx_n_s_hamming);
  Py_CLEAR(clear_module_state->__pyx_n_s_hamming_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_hann_poisson_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_hann_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_harmonic_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_harmonic_conjugate);
  Py_CLEAR(clear_module_state->__pyx_n_s_harmonic_division);
  Py_CLEAR(clear_module_state->__pyx_n_s_has);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_arc);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_edge);
  Py_CLEAR(clear_module_state->__pyx_n_s_hasard);
  Py_CLEAR(clear_module_state->__pyx_n_s_hbar);
  Py_CLEAR(clear_module_state->__pyx_n_s_head);
  Py_CLEAR(clear_module_state->__pyx_n_s_heading);
  Py_CLEAR(clear_module_state->__pyx_n_s_heapify);
  Py_CLEAR(clear_module_state->__pyx_n_s_heappop);
  Py_CLEAR(clear_module_state->__pyx_n_s_heappush);
  Py_CLEAR(clear_module_state->__pyx_n_s_help);
  Py_CLEAR(clear_module_state->__pyx_n_s_hermite);
  Py_CLEAR(clear_module_state->__pyx_n_s_hessenberg);
  Py_CLEAR(clear_module_state->__pyx_n_s_hessian);
  Py_CLEAR(clear_module_state->__pyx_n_s_heugcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_hexagon);
  Py_CLEAR(clear_module_state->__pyx_n_s_hht);
  Py_CLEAR(clear_module_state->__pyx_n_s_hidden_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_highlight_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_highlight_subgraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_highlight_trail);
  Py_CLEAR(clear_module_state->__pyx_n_s_highlight_vertex);
  Py_CLEAR(clear_module_state->__pyx_n_s_highpass);
  Py_CLEAR(clear_module_state->__pyx_n_s_hilbert);
  Py_CLEAR(clear_module_state->__pyx_n_s_histogram);
  Py_CLEAR(clear_module_state->__pyx_n_s_hold);
  Py_CLEAR(clear_module_state->__pyx_n_s_homogeneize);
  Py_CLEAR(clear_module_state->__pyx_n_s_homothety);
  Py_CLEAR(clear_module_state->__pyx_n_s_horner);
  Py_CLEAR(clear_module_state->__pyx_n_s_hp);
  Py_CLEAR(clear_module_state->__pyx_n_s_hsv);
  Py_CLEAR(clear_module_state->__pyx_n_s_hsv2rgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_htmlhelp);
  Py_CLEAR(clear_module_state->__pyx_kp_u_htmlhelp_line_1849);
  Py_CLEAR(clear_module_state->__pyx_kp_s_http_www_fourier_ujf_grenoble_fr);
  Py_CLEAR(clear_module_state->__pyx_n_s_hybrid_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_hybridj_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_hybrids_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_hybridsj_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_hyp2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_hyperbola);
  Py_CLEAR(clear_module_state->__pyx_n_s_hypercube_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_iPart);
  Py_CLEAR(clear_module_state->__pyx_kp_s_i_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_iabcuv);
  Py_CLEAR(clear_module_state->__pyx_n_s_ibasis);
  Py_CLEAR(clear_module_state->__pyx_n_s_ibpdv);
  Py_CLEAR(clear_module_state->__pyx_n_s_ibpu);
  Py_CLEAR(clear_module_state->__pyx_n_s_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_ichinrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_ichrem);
  Py_CLEAR(clear_module_state->__pyx_n_s_icomp);
  Py_CLEAR(clear_module_state->__pyx_n_s_icontent);
  Py_CLEAR(clear_module_state->__pyx_n_s_icosahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_identifier);
  Py_CLEAR(clear_module_state->__pyx_n_s_identify_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_identity);
  Py_CLEAR(clear_module_state->__pyx_n_s_idivis);
  Py_CLEAR(clear_module_state->__pyx_n_s_idn);
  Py_CLEAR(clear_module_state->__pyx_n_s_idwt);
  Py_CLEAR(clear_module_state->__pyx_n_s_iegcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_if);
  Py_CLEAR(clear_module_state->__pyx_n_s_ifactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_ifactors);
  Py_CLEAR(clear_module_state->__pyx_n_s_ifft);
  Py_CLEAR(clear_module_state->__pyx_n_s_ifourier);
  Py_CLEAR(clear_module_state->__pyx_n_s_ifte);
  Py_CLEAR(clear_module_state->__pyx_n_s_igamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_igcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_igcdex);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignored);
  Py_CLEAR(clear_module_state->__pyx_n_s_ihermite);
  Py_CLEAR(clear_module_state->__pyx_n_s_ilaplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_im);
  Py_CLEAR(clear_module_state->__pyx_n_s_imag);
  Py_CLEAR(clear_module_state->__pyx_n_s_image);
  Py_CLEAR(clear_module_state->__pyx_n_s_imfplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_implicitdiff);
  Py_CLEAR(clear_module_state->__pyx_n_s_implicitplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_import_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_inH20);
  Py_CLEAR(clear_module_state->__pyx_n_s_inHg);
  Py_CLEAR(clear_module_state->__pyx_n_s_inString);
  Py_CLEAR(clear_module_state->__pyx_n_s_in_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_in_2_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_in_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_in_ideal);
  Py_CLEAR(clear_module_state->__pyx_n_s_incidence_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_incident_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_incircle);
  Py_CLEAR(clear_module_state->__pyx_n_s_increasing_power);
  Py_CLEAR(clear_module_state->__pyx_n_s_independence_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_indets);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_kp_s_index_html);
  Py_CLEAR(clear_module_state->__pyx_n_s_indices);
  Py_CLEAR(clear_module_state->__pyx_n_s_induced_subgraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_inequationplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_inertia);
  Py_CLEAR(clear_module_state->__pyx_n_s_inf);
  Py_CLEAR(clear_module_state->__pyx_n_s_infinity);
  Py_CLEAR(clear_module_state->__pyx_kp_s_infinity_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_infinity_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_information_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_input);
  Py_CLEAR(clear_module_state->__pyx_n_s_inputform);
  Py_CLEAR(clear_module_state->__pyx_n_s_insert);
  Py_CLEAR(clear_module_state->__pyx_n_s_insmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_instfreq);
  Py_CLEAR(clear_module_state->__pyx_n_s_instphase);
  Py_CLEAR(clear_module_state->__pyx_n_s_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_intDiv);
  Py_CLEAR(clear_module_state->__pyx_n_s_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_integrate);
  Py_CLEAR(clear_module_state->__pyx_n_s_integrer);
  Py_CLEAR(clear_module_state->__pyx_n_s_inter);
  Py_CLEAR(clear_module_state->__pyx_n_s_interactive_odeplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_interactive_plotode);
  Py_CLEAR(clear_module_state->__pyx_n_s_interp);
  Py_CLEAR(clear_module_state->__pyx_n_s_intersect);
  Py_CLEAR(clear_module_state->__pyx_n_s_interval);
  Py_CLEAR(clear_module_state->__pyx_n_s_interval2center);
  Py_CLEAR(clear_module_state->__pyx_n_s_interval_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_inv);
  Py_CLEAR(clear_module_state->__pyx_n_s_inverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_inversion);
  Py_CLEAR(clear_module_state->__pyx_n_s_invisible_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_invlaplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_invztrans);
  Py_CLEAR(clear_module_state->__pyx_n_s_iquo);
  Py_CLEAR(clear_module_state->__pyx_n_s_iquorem);
  Py_CLEAR(clear_module_state->__pyx_n_s_iratrecon);
  Py_CLEAR(clear_module_state->__pyx_n_s_irem);
  Py_CLEAR(clear_module_state->__pyx_n_s_isPrime);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_acyclic);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_arborescence);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_biconnected);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_bipartite);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_clique);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_collinear);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_concyclic);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_conjugate);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_connected);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coplanar);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_cospherical);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_cut_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_cycle);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_directed);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_element);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_equilateral);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_eulerian);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_forest);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_graphic_sequence);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_hamiltonian);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_harmonic);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_harmonic_circle_bundle);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_harmonic_line_bundle);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_included);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_inside);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_integer_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_irreducible);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_isomorphic);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_isosceles);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_network);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_orthogonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_parallel);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_parallelogram);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_permu);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_perpendicular);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_planar);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_prime);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_pseudoprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_reachable);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_regular);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_rhombus);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_split_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_square);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_strongly_connected);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_strongly_regular);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_subgraph_isomorphic);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_tournament);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_triconnected);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_two_edge_connected);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_vertex_colorable);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_weighted);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_isinf);
  Py_CLEAR(clear_module_state->__pyx_n_s_ismith);
  Py_CLEAR(clear_module_state->__pyx_n_s_isnan);
  Py_CLEAR(clear_module_state->__pyx_n_s_isobarycenter);
  Py_CLEAR(clear_module_state->__pyx_n_s_isolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_isom);
  Py_CLEAR(clear_module_state->__pyx_n_s_isomorphic_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_isopolygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_isosceles_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_isposdef);
  Py_CLEAR(clear_module_state->__pyx_n_s_isprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_istft);
  Py_CLEAR(clear_module_state->__pyx_n_s_iter);
  Py_CLEAR(clear_module_state->__pyx_n_s_ithprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_j);
  Py_CLEAR(clear_module_state->__pyx_n_s_jacobi_equation);
  Py_CLEAR(clear_module_state->__pyx_n_s_jacobi_linsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_jacobi_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_johnson_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_jordan);
  Py_CLEAR(clear_module_state->__pyx_n_s_jusqu_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_jusqua);
  Py_CLEAR(clear_module_state->__pyx_n_s_jusque);
  Py_CLEAR(clear_module_state->__pyx_n_s_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_kWh);
  Py_CLEAR(clear_module_state->__pyx_n_s_katz_centrality);
  Py_CLEAR(clear_module_state->__pyx_n_s_kde);
  Py_CLEAR(clear_module_state->__pyx_n_s_keep_algext);
  Py_CLEAR(clear_module_state->__pyx_n_s_keep_pivot);
  Py_CLEAR(clear_module_state->__pyx_n_s_ker);
  Py_CLEAR(clear_module_state->__pyx_n_s_kernel);
  Py_CLEAR(clear_module_state->__pyx_n_s_kernel_density);
  Py_CLEAR(clear_module_state->__pyx_n_s_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_kill);
  Py_CLEAR(clear_module_state->__pyx_kp_s_killing_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_kip);
  Py_CLEAR(clear_module_state->__pyx_n_s_km);
  Py_CLEAR(clear_module_state->__pyx_kp_s_km_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_kmeans);
  Py_CLEAR(clear_module_state->__pyx_n_s_kneser_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_knot);
  Py_CLEAR(clear_module_state->__pyx_n_s_kolmogorovd);
  Py_CLEAR(clear_module_state->__pyx_n_s_kolmogorovt);
  Py_CLEAR(clear_module_state->__pyx_n_s_kovacicsols);
  Py_CLEAR(clear_module_state->__pyx_n_s_kph);
  Py_CLEAR(clear_module_state->__pyx_n_s_kq);
  Py_CLEAR(clear_module_state->__pyx_n_s_kspaths);
  Py_CLEAR(clear_module_state->__pyx_n_s_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_l1norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_l2norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_l_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_label);
  Py_CLEAR(clear_module_state->__pyx_n_s_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_lagrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_laguerre);
  Py_CLEAR(clear_module_state->__pyx_n_s_lam);
  Py_CLEAR(clear_module_state->__pyx_n_s_lambda0);
  Py_CLEAR(clear_module_state->__pyx_n_s_lambdac);
  Py_CLEAR(clear_module_state->__pyx_n_s_lang);
  Py_CLEAR(clear_module_state->__pyx_n_s_laplace);
  Py_CLEAR(clear_module_state->__pyx_n_s_laplacian);
  Py_CLEAR(clear_module_state->__pyx_n_s_laplacian_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_latex);
  Py_CLEAR(clear_module_state->__pyx_n_s_lb);
  Py_CLEAR(clear_module_state->__pyx_n_s_lbf);
  Py_CLEAR(clear_module_state->__pyx_n_s_lbmol);
  Py_CLEAR(clear_module_state->__pyx_n_s_lbt);
  Py_CLEAR(clear_module_state->__pyx_n_s_lcf_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_lcm);
  Py_CLEAR(clear_module_state->__pyx_n_s_lcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_ldegree);
  Py_CLEAR(clear_module_state->__pyx_n_s_ldl);
  Py_CLEAR(clear_module_state->__pyx_n_s_learning_rate);
  Py_CLEAR(clear_module_state->__pyx_n_s_left);
  Py_CLEAR(clear_module_state->__pyx_n_s_left_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_legend);
  Py_CLEAR(clear_module_state->__pyx_n_s_legendre);
  Py_CLEAR(clear_module_state->__pyx_n_s_legendre_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_length);
  Py_CLEAR(clear_module_state->__pyx_n_s_lep);
  Py_CLEAR(clear_module_state->__pyx_n_s_leve_crayon);
  Py_CLEAR(clear_module_state->__pyx_n_s_levenshtein);
  Py_CLEAR(clear_module_state->__pyx_n_s_lgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_lhs);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_chapeau_carre);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_chapeau_plat);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_chapeau_rond);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_polygonale);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_polygonale_pointee);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_tiret);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_tiret_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_tiret_pointpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_ligne_trait_plein);
  Py_CLEAR(clear_module_state->__pyx_n_s_limit);
  Py_CLEAR(clear_module_state->__pyx_n_s_limite);
  Py_CLEAR(clear_module_state->__pyx_n_s_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_linabs);
  Py_CLEAR(clear_module_state->__pyx_n_s_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_inter);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_segments);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_width_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_linear_interpolate);
  Py_CLEAR(clear_module_state->__pyx_n_s_linear_regression);
  Py_CLEAR(clear_module_state->__pyx_n_s_linear_regression_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_lineariser);
  Py_CLEAR(clear_module_state->__pyx_n_s_lineariser_trigo);
  Py_CLEAR(clear_module_state->__pyx_n_s_linfnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_linsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_linspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_linstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_liqpt);
  Py_CLEAR(clear_module_state->__pyx_n_s_lis);
  Py_CLEAR(clear_module_state->__pyx_n_s_lis_phrase);
  Py_CLEAR(clear_module_state->__pyx_n_s_list);
  Py_CLEAR(clear_module_state->__pyx_n_s_list2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_list2mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_edge_attributes);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_graph_attributes);
  Py_CLEAR(clear_module_state->__pyx_kp_s_list_index_s_out_of_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_list_vertex_attributes);
  Py_CLEAR(clear_module_state->__pyx_n_s_listplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_listrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_lll);
  Py_CLEAR(clear_module_state->__pyx_n_s_lm);
  Py_CLEAR(clear_module_state->__pyx_n_s_ln);
  Py_CLEAR(clear_module_state->__pyx_n_s_lname);
  Py_CLEAR(clear_module_state->__pyx_n_s_lncollect);
  Py_CLEAR(clear_module_state->__pyx_n_s_lnexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_loadgiacgen);
  Py_CLEAR(clear_module_state->__pyx_kp_u_loadgiacgen_line_2106);
  Py_CLEAR(clear_module_state->__pyx_n_s_local);
  Py_CLEAR(clear_module_state->__pyx_n_s_locus);
  Py_CLEAR(clear_module_state->__pyx_n_s_log);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10);
  Py_CLEAR(clear_module_state->__pyx_n_s_log2);
  Py_CLEAR(clear_module_state->__pyx_n_s_log_loss);
  Py_CLEAR(clear_module_state->__pyx_n_s_logarithmic_regression);
  Py_CLEAR(clear_module_state->__pyx_n_s_logarithmic_regression_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_logb);
  Py_CLEAR(clear_module_state->__pyx_n_s_logistic);
  Py_CLEAR(clear_module_state->__pyx_n_s_logistic_regression);
  Py_CLEAR(clear_module_state->__pyx_n_s_logistic_regression_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_long);
  Py_CLEAR(clear_module_state->__pyx_n_s_lower);
  Py_CLEAR(clear_module_state->__pyx_n_s_lowest_common_ancestor);
  Py_CLEAR(clear_module_state->__pyx_n_s_lowpass);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_assume);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_bestlocalbound);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_bestprojection);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_binary);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_binaryvariables);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_breadthfirst);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_depthfirst);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_depthlimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_firstfractional);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_gaptolerance);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_heuristic);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_hybrid);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_integervariables);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_interiorpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_iterationlimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_lastfractional);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_maxcuts);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_maximize);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_method);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_mostfractional);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_nodelimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_nodeselect);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_nonnegative);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_nonnegint);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_presolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_pseudocost);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_simplex);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_timelimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_varselect);
  Py_CLEAR(clear_module_state->__pyx_n_s_lp_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_lpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_lsmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_lsq);
  Py_CLEAR(clear_module_state->__pyx_n_s_lu);
  Py_CLEAR(clear_module_state->__pyx_n_s_lvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_lx);
  Py_CLEAR(clear_module_state->__pyx_n_s_lyr);
  Py_CLEAR(clear_module_state->__pyx_n_s_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_mEarth);
  Py_CLEAR(clear_module_state->__pyx_n_s_mRow);
  Py_CLEAR(clear_module_state->__pyx_n_s_mRowAdd);
  Py_CLEAR(clear_module_state->__pyx_kp_s_m_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_m_3);
  Py_CLEAR(clear_module_state->__pyx_kp_s_m_s);
  Py_CLEAR(clear_module_state->__pyx_kp_s_m_s_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_magenta);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_directed);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_weighted);
  Py_CLEAR(clear_module_state->__pyx_n_s_makelist);
  Py_CLEAR(clear_module_state->__pyx_n_s_makemat);
  Py_CLEAR(clear_module_state->__pyx_n_s_makesuite);
  Py_CLEAR(clear_module_state->__pyx_n_s_makevector);
  Py_CLEAR(clear_module_state->__pyx_n_s_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_maple2mupad);
  Py_CLEAR(clear_module_state->__pyx_n_s_maple2xcas);
  Py_CLEAR(clear_module_state->__pyx_n_s_maple_ifactors);
  Py_CLEAR(clear_module_state->__pyx_n_s_maple_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_markov);
  Py_CLEAR(clear_module_state->__pyx_n_s_mat2list);
  Py_CLEAR(clear_module_state->__pyx_n_s_math);
  Py_CLEAR(clear_module_state->__pyx_n_s_mathml);
  Py_CLEAR(clear_module_state->__pyx_n_s_matpow);
  Py_CLEAR(clear_module_state->__pyx_n_s_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_matrix_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxcount);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxflow);
  Py_CLEAR(clear_module_state->__pyx_n_s_maximal_independent_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_maximize);
  Py_CLEAR(clear_module_state->__pyx_n_s_maximum_clique);
  Py_CLEAR(clear_module_state->__pyx_n_s_maximum_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_maximum_independent_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_maximum_matching);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxsize);
  Py_CLEAR(clear_module_state->__pyx_n_s_me);
  Py_CLEAR(clear_module_state->__pyx_n_s_mean);
  Py_CLEAR(clear_module_state->__pyx_n_s_median);
  Py_CLEAR(clear_module_state->__pyx_n_s_median_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_member);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_mgf);
  Py_CLEAR(clear_module_state->__pyx_n_s_mho);
  Py_CLEAR(clear_module_state->__pyx_n_s_miUS);
  Py_CLEAR(clear_module_state->__pyx_kp_s_miUS_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_mi_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_mid);
  Py_CLEAR(clear_module_state->__pyx_n_s_middle_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_midpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_mil);
  Py_CLEAR(clear_module_state->__pyx_n_s_mile);
  Py_CLEAR(clear_module_state->__pyx_n_s_mille);
  Py_CLEAR(clear_module_state->__pyx_n_s_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimal_edge_coloring);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimal_spanning_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimal_vertex_coloring);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimax);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimize);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimum_cut);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimum_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_minimum_vertex_cover);
  Py_CLEAR(clear_module_state->__pyx_n_s_minus);
  Py_CLEAR(clear_module_state->__pyx_n_s_mixdown);
  Py_CLEAR(clear_module_state->__pyx_n_s_mkisom);
  Py_CLEAR(clear_module_state->__pyx_n_s_mksa);
  Py_CLEAR(clear_module_state->__pyx_n_s_ml);
  Py_CLEAR(clear_module_state->__pyx_n_s_mm);
  Py_CLEAR(clear_module_state->__pyx_n_s_mmHg);
  Py_CLEAR(clear_module_state->__pyx_n_s_mn);
  Py_CLEAR(clear_module_state->__pyx_n_s_mod);
  Py_CLEAR(clear_module_state->__pyx_n_s_modf);
  Py_CLEAR(clear_module_state->__pyx_n_s_modgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_mods);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_mol);
  Py_CLEAR(clear_module_state->__pyx_n_s_momentum);
  Py_CLEAR(clear_module_state->__pyx_n_s_monotonic);
  Py_CLEAR(clear_module_state->__pyx_n_s_montre_tortue);
  Py_CLEAR(clear_module_state->__pyx_n_s_moremethods);
  Py_CLEAR(clear_module_state->__pyx_n_s_moretests);
  Py_CLEAR(clear_module_state->__pyx_kp_u_moretests_line_2061);
  Py_CLEAR(clear_module_state->__pyx_n_s_mostkeywords);
  Py_CLEAR(clear_module_state->__pyx_n_s_moustache);
  Py_CLEAR(clear_module_state->__pyx_n_s_moving_average);
  Py_CLEAR(clear_module_state->__pyx_n_s_moyal);
  Py_CLEAR(clear_module_state->__pyx_n_s_moyenne);
  Py_CLEAR(clear_module_state->__pyx_n_s_mp);
  Py_CLEAR(clear_module_state->__pyx_n_s_mph);
  Py_CLEAR(clear_module_state->__pyx_n_s_mpme);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_s_mu0);
  Py_CLEAR(clear_module_state->__pyx_n_s_muB);
  Py_CLEAR(clear_module_state->__pyx_n_s_muN);
  Py_CLEAR(clear_module_state->__pyx_n_s_mul);
  Py_CLEAR(clear_module_state->__pyx_n_s_mul_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_mult_c_conjugate);
  Py_CLEAR(clear_module_state->__pyx_n_s_mult_conjugate);
  Py_CLEAR(clear_module_state->__pyx_n_s_multinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_multiplier_conjugue);
  Py_CLEAR(clear_module_state->__pyx_n_s_multiplier_conjugue_complexe);
  Py_CLEAR(clear_module_state->__pyx_n_s_multiply);
  Py_CLEAR(clear_module_state->__pyx_n_s_mupad2maple);
  Py_CLEAR(clear_module_state->__pyx_n_s_mupad2xcas);
  Py_CLEAR(clear_module_state->__pyx_n_s_mycielski);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_nCr);
  Py_CLEAR(clear_module_state->__pyx_n_s_nDeriv);
  Py_CLEAR(clear_module_state->__pyx_n_s_nInt);
  Py_CLEAR(clear_module_state->__pyx_n_s_nPr);
  Py_CLEAR(clear_module_state->__pyx_n_s_nSolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_navy);
  Py_CLEAR(clear_module_state->__pyx_n_s_ncols);
  Py_CLEAR(clear_module_state->__pyx_n_s_neg);
  Py_CLEAR(clear_module_state->__pyx_n_s_negbinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_negbinomial_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_negbinomial_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_neighbors);
  Py_CLEAR(clear_module_state->__pyx_n_s_network_transitivity);
  Py_CLEAR(clear_module_state->__pyx_n_s_neural_network);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_newList);
  Py_CLEAR(clear_module_state->__pyx_n_s_newMat);
  Py_CLEAR(clear_module_state->__pyx_n_s_newton);
  Py_CLEAR(clear_module_state->__pyx_n_s_newton_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_newtonj_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_nextperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_nextprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_binary);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_binaryvariables);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_initialpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_integer);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_integervariables);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_iterationlimit);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_maximize);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_method);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_nonnegative);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_nonnegint);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_precision);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_presolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_tolerance);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlp_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_nlpsolve);
  Py_CLEAR(clear_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_CLEAR(clear_module_state->__pyx_n_s_nodisp);
  Py_CLEAR(clear_module_state->__pyx_n_s_noir);
  Py_CLEAR(clear_module_state->__pyx_n_s_nom_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_non);
  Py_CLEAR(clear_module_state->__pyx_n_s_non_recursive_normal);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonevaluable);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonnegint);
  Py_CLEAR(clear_module_state->__pyx_n_s_nop);
  Py_CLEAR(clear_module_state->__pyx_n_s_nops);
  Py_CLEAR(clear_module_state->__pyx_n_s_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_normal);
  Py_CLEAR(clear_module_state->__pyx_n_s_normal_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_normal_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_normald);
  Py_CLEAR(clear_module_state->__pyx_n_s_normald_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_normald_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_normalize);
  Py_CLEAR(clear_module_state->__pyx_n_s_normalt);
  Py_CLEAR(clear_module_state->__pyx_n_s_normalvariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_not);
  Py_CLEAR(clear_module_state->__pyx_n_s_nprimes);
  Py_CLEAR(clear_module_state->__pyx_n_s_nrows);
  Py_CLEAR(clear_module_state->__pyx_n_s_nstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_nuage_points);
  Py_CLEAR(clear_module_state->__pyx_n_s_nullspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_number_of_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_number_of_spanning_trees);
  Py_CLEAR(clear_module_state->__pyx_n_s_number_of_triangles);
  Py_CLEAR(clear_module_state->__pyx_n_s_number_of_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_numdiff);
  Py_CLEAR(clear_module_state->__pyx_n_s_numer);
  Py_CLEAR(clear_module_state->__pyx_n_s_octahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_od);
  Py_CLEAR(clear_module_state->__pyx_n_s_odd);
  Py_CLEAR(clear_module_state->__pyx_n_s_odd_girth);
  Py_CLEAR(clear_module_state->__pyx_n_s_odd_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_odeplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_odesolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_of);
  Py_CLEAR(clear_module_state->__pyx_n_s_oldies);
  Py_CLEAR(clear_module_state->__pyx_n_s_olive);
  Py_CLEAR(clear_module_state->__pyx_n_s_op);
  Py_CLEAR(clear_module_state->__pyx_n_s_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_open_polygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_option);
  Py_CLEAR(clear_module_state->__pyx_n_s_or);
  Py_CLEAR(clear_module_state->__pyx_n_s_orange);
  Py_CLEAR(clear_module_state->__pyx_n_s_ord);
  Py_CLEAR(clear_module_state->__pyx_n_s_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_order_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_ordinate);
  Py_CLEAR(clear_module_state->__pyx_n_s_orthocenter);
  Py_CLEAR(clear_module_state->__pyx_n_s_orthogonal);
  Py_CLEAR(clear_module_state->__pyx_n_s_os);
  Py_CLEAR(clear_module_state->__pyx_n_s_osculating_circle);
  Py_CLEAR(clear_module_state->__pyx_n_s_otherwise);
  Py_CLEAR(clear_module_state->__pyx_n_s_ou);
  Py_CLEAR(clear_module_state->__pyx_n_s_output);
  Py_CLEAR(clear_module_state->__pyx_n_s_oz);
  Py_CLEAR(clear_module_state->__pyx_n_s_ozUK);
  Py_CLEAR(clear_module_state->__pyx_n_s_ozfl);
  Py_CLEAR(clear_module_state->__pyx_n_s_ozt);
  Py_CLEAR(clear_module_state->__pyx_n_s_p1oc2);
  Py_CLEAR(clear_module_state->__pyx_n_s_p1op2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pa2b2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pade);
  Py_CLEAR(clear_module_state->__pyx_n_s_paley_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_parabola);
  Py_CLEAR(clear_module_state->__pyx_n_s_parallel);
  Py_CLEAR(clear_module_state->__pyx_n_s_parallelepiped);
  Py_CLEAR(clear_module_state->__pyx_n_s_parallelogram);
  Py_CLEAR(clear_module_state->__pyx_n_s_param);
  Py_CLEAR(clear_module_state->__pyx_n_s_parameq);
  Py_CLEAR(clear_module_state->__pyx_n_s_parameter);
  Py_CLEAR(clear_module_state->__pyx_n_s_paramplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_parfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_pari);
  Py_CLEAR(clear_module_state->__pyx_n_s_part);
  Py_CLEAR(clear_module_state->__pyx_n_s_partfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_parzen_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_pas);
  Py_CLEAR(clear_module_state->__pyx_n_s_pas_de_cote);
  Py_CLEAR(clear_module_state->__pyx_n_s_path_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_pc);
  Py_CLEAR(clear_module_state->__pyx_n_s_pcar);
  Py_CLEAR(clear_module_state->__pyx_n_s_pcar_hessenberg);
  Py_CLEAR(clear_module_state->__pyx_n_s_pcoef);
  Py_CLEAR(clear_module_state->__pyx_n_s_pcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_pdl);
  Py_CLEAR(clear_module_state->__pyx_n_s_pencolor);
  Py_CLEAR(clear_module_state->__pyx_n_s_pendown);
  Py_CLEAR(clear_module_state->__pyx_n_s_penup);
  Py_CLEAR(clear_module_state->__pyx_n_s_perimeter);
  Py_CLEAR(clear_module_state->__pyx_n_s_perimeterat);
  Py_CLEAR(clear_module_state->__pyx_n_s_perimeteratraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_period);
  Py_CLEAR(clear_module_state->__pyx_n_s_periodic);
  Py_CLEAR(clear_module_state->__pyx_n_s_perm);
  Py_CLEAR(clear_module_state->__pyx_n_s_perminv);
  Py_CLEAR(clear_module_state->__pyx_n_s_permu2cycles);
  Py_CLEAR(clear_module_state->__pyx_n_s_permu2mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_permuorder);
  Py_CLEAR(clear_module_state->__pyx_n_s_permute_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_perpen_bisector);
  Py_CLEAR(clear_module_state->__pyx_n_s_perpendicular);
  Py_CLEAR(clear_module_state->__pyx_n_s_petersen_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_peval);
  Py_CLEAR(clear_module_state->__pyx_n_s_ph);
  Py_CLEAR(clear_module_state->__pyx_n_s_phi);
  Py_CLEAR(clear_module_state->__pyx_n_s_pi);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_pie);
  Py_CLEAR(clear_module_state->__pyx_n_s_piecewise);
  Py_CLEAR(clear_module_state->__pyx_n_s_pink);
  Py_CLEAR(clear_module_state->__pyx_n_s_pivot);
  Py_CLEAR(clear_module_state->__pyx_n_s_pixoff);
  Py_CLEAR(clear_module_state->__pyx_n_s_pixon);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk);
  Py_CLEAR(clear_module_state->__pyx_n_s_planar);
  Py_CLEAR(clear_module_state->__pyx_n_s_plane);
  Py_CLEAR(clear_module_state->__pyx_n_s_plane_dual);
  Py_CLEAR(clear_module_state->__pyx_n_s_playsnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_plex);
  Py_CLEAR(clear_module_state->__pyx_n_s_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_plot3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotarea);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotcdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotcontour);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotdensity);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotfield);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotfunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotimf);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotimplicit);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotinequation);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotode);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotparam);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotpolar);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotproba);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotspectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_plotwav);
  Py_CLEAR(clear_module_state->__pyx_n_s_plus_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_pmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_pnt);
  Py_CLEAR(clear_module_state->__pyx_n_s_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_point2d);
  Py_CLEAR(clear_module_state->__pyx_n_s_point3d);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_arret);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_carre);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_croix);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_div);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_etoile);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_invisible);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_losange);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_milieu);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_plus);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_polaire);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_point_width_7);
  Py_CLEAR(clear_module_state->__pyx_n_s_poisson);
  Py_CLEAR(clear_module_state->__pyx_n_s_poisson_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_poisson_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_poisson_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_polar);
  Py_CLEAR(clear_module_state->__pyx_n_s_polar_coordinates);
  Py_CLEAR(clear_module_state->__pyx_n_s_polar_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_polarplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_pole);
  Py_CLEAR(clear_module_state->__pyx_n_s_poly2symb);
  Py_CLEAR(clear_module_state->__pyx_n_s_polyEval);
  Py_CLEAR(clear_module_state->__pyx_n_s_polygon);
  Py_CLEAR(clear_module_state->__pyx_n_s_polygone_rempli);
  Py_CLEAR(clear_module_state->__pyx_n_s_polygonplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_polygonscatterplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_polyhedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_polynom);
  Py_CLEAR(clear_module_state->__pyx_n_s_polynomial_regression);
  Py_CLEAR(clear_module_state->__pyx_n_s_polynomial_regression_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_position);
  Py_CLEAR(clear_module_state->__pyx_n_s_poslbdLMQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_posubLMQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_potential);
  Py_CLEAR(clear_module_state->__pyx_n_s_pour);
  Py_CLEAR(clear_module_state->__pyx_n_s_pow);
  Py_CLEAR(clear_module_state->__pyx_n_s_pow2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_pow_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_power_regression);
  Py_CLEAR(clear_module_state->__pyx_n_s_power_regression_plot);
  Py_CLEAR(clear_module_state->__pyx_n_s_powermod);
  Py_CLEAR(clear_module_state->__pyx_n_s_powerpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_powexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_powmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepend);
  Py_CLEAR(clear_module_state->__pyx_n_s_preval);
  Py_CLEAR(clear_module_state->__pyx_n_s_prevperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_prevprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_primpart);
  Py_CLEAR(clear_module_state->__pyx_n_s_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_printf);
  Py_CLEAR(clear_module_state->__pyx_kp_s_printpow_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_prism);
  Py_CLEAR(clear_module_state->__pyx_n_s_prism_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_proc);
  Py_CLEAR(clear_module_state->__pyx_n_s_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_program);
  Py_CLEAR(clear_module_state->__pyx_n_s_projection);
  Py_CLEAR(clear_module_state->__pyx_n_s_proot);
  Py_CLEAR(clear_module_state->__pyx_n_s_propFrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_propfrac);
  Py_CLEAR(clear_module_state->__pyx_n_s_pruefer_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_psi);
  Py_CLEAR(clear_module_state->__pyx_n_s_psrgcd);
  Py_CLEAR(clear_module_state->__pyx_n_s_ptUK);
  Py_CLEAR(clear_module_state->__pyx_n_s_ptayl);
  Py_CLEAR(clear_module_state->__pyx_n_s_purge);
  Py_CLEAR(clear_module_state->__pyx_kp_s_purge_GIACPY_TMP_NAME05026807096);
  Py_CLEAR(clear_module_state->__pyx_n_s_purple);
  Py_CLEAR(clear_module_state->__pyx_n_s_pwd);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyramid);
  Py_CLEAR(clear_module_state->__pyx_n_s_python_compat);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_capi);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_GiacMethods_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_q);
  Py_CLEAR(clear_module_state->__pyx_n_s_q2a);
  Py_CLEAR(clear_module_state->__pyx_n_s_qcas);
  Py_CLEAR(clear_module_state->__pyx_kp_u_qcas_line_1879);
  Py_CLEAR(clear_module_state->__pyx_n_s_qe);
  Py_CLEAR(clear_module_state->__pyx_n_s_qepsilon0);
  Py_CLEAR(clear_module_state->__pyx_n_s_qme);
  Py_CLEAR(clear_module_state->__pyx_n_s_qr);
  Py_CLEAR(clear_module_state->__pyx_n_s_qt);
  Py_CLEAR(clear_module_state->__pyx_n_s_quadrant1);
  Py_CLEAR(clear_module_state->__pyx_n_s_quadrant2);
  Py_CLEAR(clear_module_state->__pyx_n_s_quadrant3);
  Py_CLEAR(clear_module_state->__pyx_n_s_quadrant4);
  Py_CLEAR(clear_module_state->__pyx_n_s_quadric);
  Py_CLEAR(clear_module_state->__pyx_n_s_quadrilateral);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_quantile);
  Py_CLEAR(clear_module_state->__pyx_n_s_quartile1);
  Py_CLEAR(clear_module_state->__pyx_n_s_quartile3);
  Py_CLEAR(clear_module_state->__pyx_n_s_quartiles);
  Py_CLEAR(clear_module_state->__pyx_n_s_quest);
  Py_CLEAR(clear_module_state->__pyx_n_s_quo);
  Py_CLEAR(clear_module_state->__pyx_n_s_quorem);
  Py_CLEAR(clear_module_state->__pyx_n_s_quote);
  Py_CLEAR(clear_module_state->__pyx_n_s_r2e);
  Py_CLEAR(clear_module_state->__pyx_n_s_rad);
  Py_CLEAR(clear_module_state->__pyx_n_s_rad_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_rad_s);
  Py_CLEAR(clear_module_state->__pyx_kp_s_rad_s_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_radians);
  Py_CLEAR(clear_module_state->__pyx_n_s_radical_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_radius);
  Py_CLEAR(clear_module_state->__pyx_n_s_ramene);
  Py_CLEAR(clear_module_state->__pyx_n_s_rand);
  Py_CLEAR(clear_module_state->__pyx_n_s_randMat);
  Py_CLEAR(clear_module_state->__pyx_n_s_randNorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_randPoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_randbetad);
  Py_CLEAR(clear_module_state->__pyx_n_s_randbinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_randchisquare);
  Py_CLEAR(clear_module_state->__pyx_n_s_randexp);
  Py_CLEAR(clear_module_state->__pyx_n_s_randfisher);
  Py_CLEAR(clear_module_state->__pyx_n_s_randgammad);
  Py_CLEAR(clear_module_state->__pyx_n_s_randgeometric);
  Py_CLEAR(clear_module_state->__pyx_n_s_randint);
  Py_CLEAR(clear_module_state->__pyx_n_s_randmarkov);
  Py_CLEAR(clear_module_state->__pyx_n_s_randmatrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_randmultinomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_randnorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_random);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_bipartite_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_digraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_network);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_planar_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_regular_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_sequence_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_tournament);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_random_variable);
  Py_CLEAR(clear_module_state->__pyx_n_s_randperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_randpoisson);
  Py_CLEAR(clear_module_state->__pyx_n_s_randpoly);
  Py_CLEAR(clear_module_state->__pyx_n_s_randseed);
  Py_CLEAR(clear_module_state->__pyx_n_s_randstudent);
  Py_CLEAR(clear_module_state->__pyx_n_s_randvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_randvector);
  Py_CLEAR(clear_module_state->__pyx_n_s_randweibulld);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_rank);
  Py_CLEAR(clear_module_state->__pyx_n_s_ranm);
  Py_CLEAR(clear_module_state->__pyx_n_s_ranv);
  Py_CLEAR(clear_module_state->__pyx_n_s_rassembler_trigo);
  Py_CLEAR(clear_module_state->__pyx_n_s_rat_jordan);
  Py_CLEAR(clear_module_state->__pyx_n_s_ratinterp);
  Py_CLEAR(clear_module_state->__pyx_n_s_rational);
  Py_CLEAR(clear_module_state->__pyx_n_s_rationalroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_ratnormal);
  Py_CLEAR(clear_module_state->__pyx_n_s_rd);
  Py_CLEAR(clear_module_state->__pyx_n_s_rdiv);
  Py_CLEAR(clear_module_state->__pyx_n_s_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_reachable);
  Py_CLEAR(clear_module_state->__pyx_n_s_read);
  Py_CLEAR(clear_module_state->__pyx_n_s_readrgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_readwav);
  Py_CLEAR(clear_module_state->__pyx_n_s_real);
  Py_CLEAR(clear_module_state->__pyx_n_s_realroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_reciprocation);
  Py_CLEAR(clear_module_state->__pyx_n_s_rect);
  Py_CLEAR(clear_module_state->__pyx_n_s_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_rectangle_droit);
  Py_CLEAR(clear_module_state->__pyx_n_s_rectangle_gauche);
  Py_CLEAR(clear_module_state->__pyx_n_s_rectangle_plein);
  Py_CLEAR(clear_module_state->__pyx_n_s_rectangular_coordinates);
  Py_CLEAR(clear_module_state->__pyx_n_s_recule);
  Py_CLEAR(clear_module_state->__pyx_n_s_red);
  Py_CLEAR(clear_module_state->__pyx_n_s_redim);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduced_conic);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduced_quadric);
  Py_CLEAR(clear_module_state->__pyx_n_s_ref);
  Py_CLEAR(clear_module_state->__pyx_n_s_reflection);
  Py_CLEAR(clear_module_state->__pyx_n_s_regroup);
  Py_CLEAR(clear_module_state->__pyx_n_s_relabel_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_reliability_polynomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_rem);
  Py_CLEAR(clear_module_state->__pyx_n_s_rem_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_remain);
  Py_CLEAR(clear_module_state->__pyx_n_s_remove);
  Py_CLEAR(clear_module_state->__pyx_n_s_reorder);
  Py_CLEAR(clear_module_state->__pyx_n_s_repeat);
  Py_CLEAR(clear_module_state->__pyx_n_s_repete);
  Py_CLEAR(clear_module_state->__pyx_n_s_repeter);
  Py_CLEAR(clear_module_state->__pyx_n_s_replace);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr_html);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr_latex);
  Py_CLEAR(clear_module_state->__pyx_n_s_resample);
  Py_CLEAR(clear_module_state->__pyx_n_s_residue);
  Py_CLEAR(clear_module_state->__pyx_n_s_resoudre);
  Py_CLEAR(clear_module_state->__pyx_n_s_resoudre_dans_C);
  Py_CLEAR(clear_module_state->__pyx_n_s_resoudre_systeme_lineaire);
  Py_CLEAR(clear_module_state->__pyx_n_s_restart);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_resultant);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_reverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_reverse_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_reverse_rsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_revert);
  Py_CLEAR(clear_module_state->__pyx_n_s_revlex);
  Py_CLEAR(clear_module_state->__pyx_n_s_revlist);
  Py_CLEAR(clear_module_state->__pyx_n_s_rgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_rgb2hsv);
  Py_CLEAR(clear_module_state->__pyx_n_s_rgb2xyz);
  Py_CLEAR(clear_module_state->__pyx_n_s_rhombus);
  Py_CLEAR(clear_module_state->__pyx_n_s_rhombus_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_rhs);
  Py_CLEAR(clear_module_state->__pyx_n_s_riemann_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_right);
  Py_CLEAR(clear_module_state->__pyx_n_s_right_rectangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_right_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_risch);
  Py_CLEAR(clear_module_state->__pyx_n_s_rm_a_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_rm_all_vars);
  Py_CLEAR(clear_module_state->__pyx_n_s_rmbreakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_rmmod);
  Py_CLEAR(clear_module_state->__pyx_n_s_rms);
  Py_CLEAR(clear_module_state->__pyx_n_s_rmwatch);
  Py_CLEAR(clear_module_state->__pyx_n_s_rod);
  Py_CLEAR(clear_module_state->__pyx_n_s_romberg);
  Py_CLEAR(clear_module_state->__pyx_n_s_rombergm);
  Py_CLEAR(clear_module_state->__pyx_n_s_rombergt);
  Py_CLEAR(clear_module_state->__pyx_n_s_rond);
  Py_CLEAR(clear_module_state->__pyx_n_s_root);
  Py_CLEAR(clear_module_state->__pyx_n_s_rootof);
  Py_CLEAR(clear_module_state->__pyx_n_s_roots);
  Py_CLEAR(clear_module_state->__pyx_n_s_rotate);
  Py_CLEAR(clear_module_state->__pyx_n_s_rotation);
  Py_CLEAR(clear_module_state->__pyx_n_s_rouge);
  Py_CLEAR(clear_module_state->__pyx_n_s_round);
  Py_CLEAR(clear_module_state->__pyx_n_s_row);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowAdd);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowDim);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowNorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowSwap);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowdim);
  Py_CLEAR(clear_module_state->__pyx_n_s_rownorm);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_rowswap);
  Py_CLEAR(clear_module_state->__pyx_n_s_rpm);
  Py_CLEAR(clear_module_state->__pyx_n_s_rref);
  Py_CLEAR(clear_module_state->__pyx_n_s_rsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_rur);
  Py_CLEAR(clear_module_state->__pyx_n_s_rur_certify);
  Py_CLEAR(clear_module_state->__pyx_n_s_rur_gbasis);
  Py_CLEAR(clear_module_state->__pyx_n_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_s_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_saisir);
  Py_CLEAR(clear_module_state->__pyx_n_s_saisir_chaine);
  Py_CLEAR(clear_module_state->__pyx_n_s_same);
  Py_CLEAR(clear_module_state->__pyx_n_s_sample);
  Py_CLEAR(clear_module_state->__pyx_n_s_samplerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_sans_factoriser);
  Py_CLEAR(clear_module_state->__pyx_n_s_saute);
  Py_CLEAR(clear_module_state->__pyx_n_s_sauve);
  Py_CLEAR(clear_module_state->__pyx_n_s_save);
  Py_CLEAR(clear_module_state->__pyx_n_s_save_history);
  Py_CLEAR(clear_module_state->__pyx_n_s_sb);
  Py_CLEAR(clear_module_state->__pyx_n_s_scalarProduct);
  Py_CLEAR(clear_module_state->__pyx_n_s_scalar_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_scale);
  Py_CLEAR(clear_module_state->__pyx_n_s_scaleadd);
  Py_CLEAR(clear_module_state->__pyx_n_s_scatterplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_schur);
  Py_CLEAR(clear_module_state->__pyx_n_s_sd);
  Py_CLEAR(clear_module_state->__pyx_n_s_sec);
  Py_CLEAR(clear_module_state->__pyx_n_s_secant_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_segment);
  Py_CLEAR(clear_module_state->__pyx_n_s_seidel_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_seidel_switch);
  Py_CLEAR(clear_module_state->__pyx_n_s_select);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_is_not_a_giac_List);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_is_not_a_giac_integer);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_is_not_a_giac_real);
  Py_CLEAR(clear_module_state->__pyx_n_s_semi_augment);
  Py_CLEAR(clear_module_state->__pyx_n_s_send);
  Py_CLEAR(clear_module_state->__pyx_n_s_seq);
  Py_CLEAR(clear_module_state->__pyx_n_s_seqplot);
  Py_CLEAR(clear_module_state->__pyx_n_s_seqsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_sequence_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_series);
  Py_CLEAR(clear_module_state->__pyx_kp_s_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_channel_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_edge_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_edge_weight);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_graph_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_pixel);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_screen);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_vertex_attribute);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_vertex_positions);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_shift);
  Py_CLEAR(clear_module_state->__pyx_n_s_shift_phase);
  Py_CLEAR(clear_module_state->__pyx_n_s_shortest_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_show_pixels);
  Py_CLEAR(clear_module_state->__pyx_n_s_shuffle);
  Py_CLEAR(clear_module_state->__pyx_n_s_si);
  Py_CLEAR(clear_module_state->__pyx_n_s_sierpinski_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma);
  Py_CLEAR(clear_module_state->__pyx_n_s_sign);
  Py_CLEAR(clear_module_state->__pyx_n_s_sign2Heaviside);
  Py_CLEAR(clear_module_state->__pyx_n_s_signature);
  Py_CLEAR(clear_module_state->__pyx_n_s_signe);
  Py_CLEAR(clear_module_state->__pyx_n_s_similarity);
  Py_CLEAR(clear_module_state->__pyx_n_s_simp2);
  Py_CLEAR(clear_module_state->__pyx_n_s_simplex_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_simplicial_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_simplifier);
  Py_CLEAR(clear_module_state->__pyx_n_s_simplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_simplifyDirac);
  Py_CLEAR(clear_module_state->__pyx_n_s_simpson);
  Py_CLEAR(clear_module_state->__pyx_n_s_simulated_annealing);
  Py_CLEAR(clear_module_state->__pyx_n_s_simult);
  Py_CLEAR(clear_module_state->__pyx_n_s_sin);
  Py_CLEAR(clear_module_state->__pyx_n_s_sin2costan);
  Py_CLEAR(clear_module_state->__pyx_n_s_sinc);
  Py_CLEAR(clear_module_state->__pyx_n_s_sincos);
  Py_CLEAR(clear_module_state->__pyx_n_s_single_inter);
  Py_CLEAR(clear_module_state->__pyx_n_s_sinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_sinon);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_sizes);
  Py_CLEAR(clear_module_state->__pyx_n_s_sleep);
  Py_CLEAR(clear_module_state->__pyx_n_s_slope);
  Py_CLEAR(clear_module_state->__pyx_n_s_slopeat);
  Py_CLEAR(clear_module_state->__pyx_n_s_slopeatraw);
  Py_CLEAR(clear_module_state->__pyx_n_s_slug);
  Py_CLEAR(clear_module_state->__pyx_n_s_smith);
  Py_CLEAR(clear_module_state->__pyx_n_s_smod);
  Py_CLEAR(clear_module_state->__pyx_n_s_snedecor);
  Py_CLEAR(clear_module_state->__pyx_n_s_snedecor_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_snedecor_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_snedecord);
  Py_CLEAR(clear_module_state->__pyx_n_s_snedecord_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_snedecord_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_solid_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_solve);
  Py_CLEAR(clear_module_state->__pyx_n_s_somme);
  Py_CLEAR(clear_module_state->__pyx_n_s_sommet);
  Py_CLEAR(clear_module_state->__pyx_n_s_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_sorta);
  Py_CLEAR(clear_module_state->__pyx_n_s_sortd);
  Py_CLEAR(clear_module_state->__pyx_n_s_sorted);
  Py_CLEAR(clear_module_state->__pyx_n_s_sortperm);
  Py_CLEAR(clear_module_state->__pyx_n_s_soundsec);
  Py_CLEAR(clear_module_state->__pyx_n_s_spanning_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_sphere);
  Py_CLEAR(clear_module_state->__pyx_n_s_splice);
  Py_CLEAR(clear_module_state->__pyx_n_s_spline);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_spring);
  Py_CLEAR(clear_module_state->__pyx_n_s_sq);
  Py_CLEAR(clear_module_state->__pyx_n_s_sqrfree);
  Py_CLEAR(clear_module_state->__pyx_n_s_sqrt);
  Py_CLEAR(clear_module_state->__pyx_n_s_square);
  Py_CLEAR(clear_module_state->__pyx_n_s_square_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_sr);
  Py_CLEAR(clear_module_state->__pyx_n_s_srand);
  Py_CLEAR(clear_module_state->__pyx_n_s_sst);
  Py_CLEAR(clear_module_state->__pyx_n_s_sst_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_st);
  Py_CLEAR(clear_module_state->__pyx_n_s_st_ordering);
  Py_CLEAR(clear_module_state->__pyx_n_s_stack);
  Py_CLEAR(clear_module_state->__pyx_n_s_star_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_star_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_stdDev);
  Py_CLEAR(clear_module_state->__pyx_n_s_stddev);
  Py_CLEAR(clear_module_state->__pyx_n_s_stddevp);
  Py_CLEAR(clear_module_state->__pyx_n_s_steffenson_solver);
  Py_CLEAR(clear_module_state->__pyx_n_s_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_stereo2mono);
  Py_CLEAR(clear_module_state->__pyx_n_s_stft);
  Py_CLEAR(clear_module_state->__pyx_n_s_sto);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_str_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_string);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_strip);
  Py_CLEAR(clear_module_state->__pyx_n_s_strongly_connected_components);
  Py_CLEAR(clear_module_state->__pyx_n_s_student);
  Py_CLEAR(clear_module_state->__pyx_n_s_student_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_student_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_studentd);
  Py_CLEAR(clear_module_state->__pyx_n_s_studentt);
  Py_CLEAR(clear_module_state->__pyx_n_s_sturm);
  Py_CLEAR(clear_module_state->__pyx_n_s_sturmab);
  Py_CLEAR(clear_module_state->__pyx_n_s_sturmseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_style);
  Py_CLEAR(clear_module_state->__pyx_n_s_sub);
  Py_CLEAR(clear_module_state->__pyx_n_s_subMat);
  Py_CLEAR(clear_module_state->__pyx_n_s_subdivide_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_subgraph);
  Py_CLEAR(clear_module_state->__pyx_n_s_subs);
  Py_CLEAR(clear_module_state->__pyx_n_s_subsop);
  Py_CLEAR(clear_module_state->__pyx_n_s_subst);
  Py_CLEAR(clear_module_state->__pyx_n_s_substituer);
  Py_CLEAR(clear_module_state->__pyx_n_s_subtype);
  Py_CLEAR(clear_module_state->__pyx_n_s_subtype_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_sum);
  Py_CLEAR(clear_module_state->__pyx_n_s_sum_riemann);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_supposons);
  Py_CLEAR(clear_module_state->__pyx_n_s_suppress);
  Py_CLEAR(clear_module_state->__pyx_n_s_surd);
  Py_CLEAR(clear_module_state->__pyx_n_s_svd);
  Py_CLEAR(clear_module_state->__pyx_n_s_swapcol);
  Py_CLEAR(clear_module_state->__pyx_n_s_swaprow);
  Py_CLEAR(clear_module_state->__pyx_n_s_switch);
  Py_CLEAR(clear_module_state->__pyx_n_s_switch_axes);
  Py_CLEAR(clear_module_state->__pyx_n_s_sylvester);
  Py_CLEAR(clear_module_state->__pyx_n_s_symb2poly);
  Py_CLEAR(clear_module_state->__pyx_n_s_symbol);
  Py_CLEAR(clear_module_state->__pyx_n_s_symbol_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_syr);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_s_syst2mat);
  Py_CLEAR(clear_module_state->__pyx_n_s_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_tCollect);
  Py_CLEAR(clear_module_state->__pyx_n_s_tExpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_table);
  Py_CLEAR(clear_module_state->__pyx_n_s_tablefunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_tableseq);
  Py_CLEAR(clear_module_state->__pyx_n_s_tabsign);
  Py_CLEAR(clear_module_state->__pyx_n_s_tabvar);
  Py_CLEAR(clear_module_state->__pyx_n_s_tail);
  Py_CLEAR(clear_module_state->__pyx_n_s_tan);
  Py_CLEAR(clear_module_state->__pyx_n_s_tan2cossin2);
  Py_CLEAR(clear_module_state->__pyx_n_s_tan2sincos);
  Py_CLEAR(clear_module_state->__pyx_n_s_tan2sincos2);
  Py_CLEAR(clear_module_state->__pyx_n_s_tangent);
  Py_CLEAR(clear_module_state->__pyx_n_s_tangente);
  Py_CLEAR(clear_module_state->__pyx_n_s_tanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_tantque);
  Py_CLEAR(clear_module_state->__pyx_n_s_tar);
  Py_CLEAR(clear_module_state->__pyx_n_s_taux_accroissement);
  Py_CLEAR(clear_module_state->__pyx_n_s_taylor);
  Py_CLEAR(clear_module_state->__pyx_n_s_tbsp);
  Py_CLEAR(clear_module_state->__pyx_n_s_tchebyshev1);
  Py_CLEAR(clear_module_state->__pyx_n_s_tchebyshev2);
  Py_CLEAR(clear_module_state->__pyx_n_s_tcoeff);
  Py_CLEAR(clear_module_state->__pyx_n_s_tcollect);
  Py_CLEAR(clear_module_state->__pyx_n_s_tdeg);
  Py_CLEAR(clear_module_state->__pyx_n_s_teal);
  Py_CLEAR(clear_module_state->__pyx_n_s_tec);
  Py_CLEAR(clear_module_state->__pyx_n_s_tensor_product);
  Py_CLEAR(clear_module_state->__pyx_n_s_tep);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_test_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_tetrahedron);
  Py_CLEAR(clear_module_state->__pyx_n_s_tex);
  Py_CLEAR(clear_module_state->__pyx_n_s_texpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_textinput);
  Py_CLEAR(clear_module_state->__pyx_n_s_then);
  Py_CLEAR(clear_module_state->__pyx_n_s_therm);
  Py_CLEAR(clear_module_state->__pyx_n_s_thickness);
  Py_CLEAR(clear_module_state->__pyx_n_s_thiele);
  Py_CLEAR(clear_module_state->__pyx_n_s_threadeval);
  Py_CLEAR(clear_module_state->__pyx_kp_s_threads_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_threshold);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_title);
  Py_CLEAR(clear_module_state->__pyx_n_s_titre);
  Py_CLEAR(clear_module_state->__pyx_n_s_tlin);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmp);
  Py_CLEAR(clear_module_state->__pyx_n_s_to);
  Py_CLEAR(clear_module_state->__pyx_n_s_ton);
  Py_CLEAR(clear_module_state->__pyx_n_s_tonUK);
  Py_CLEAR(clear_module_state->__pyx_n_s_tonnetz);
  Py_CLEAR(clear_module_state->__pyx_n_s_topologic_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_topological_sort);
  Py_CLEAR(clear_module_state->__pyx_n_s_topology);
  Py_CLEAR(clear_module_state->__pyx_n_s_toqcas);
  Py_CLEAR(clear_module_state->__pyx_n_s_toremove);
  Py_CLEAR(clear_module_state->__pyx_n_s_torr);
  Py_CLEAR(clear_module_state->__pyx_n_s_torus_grid_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_tourne_droite);
  Py_CLEAR(clear_module_state->__pyx_n_s_tourne_gauche);
  Py_CLEAR(clear_module_state->__pyx_n_s_tpsolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_tr);
  Py_CLEAR(clear_module_state->__pyx_kp_s_tr_min);
  Py_CLEAR(clear_module_state->__pyx_kp_s_tr_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_trace);
  Py_CLEAR(clear_module_state->__pyx_n_s_trail);
  Py_CLEAR(clear_module_state->__pyx_n_s_trail2edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_train);
  Py_CLEAR(clear_module_state->__pyx_n_s_trames);
  Py_CLEAR(clear_module_state->__pyx_n_s_tran);
  Py_CLEAR(clear_module_state->__pyx_n_s_transitive_closure);
  Py_CLEAR(clear_module_state->__pyx_n_s_translation);
  Py_CLEAR(clear_module_state->__pyx_n_s_transpose);
  Py_CLEAR(clear_module_state->__pyx_n_s_trapeze);
  Py_CLEAR(clear_module_state->__pyx_n_s_trapezoid);
  Py_CLEAR(clear_module_state->__pyx_n_s_traveling_salesman);
  Py_CLEAR(clear_module_state->__pyx_n_s_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_tree_height);
  Py_CLEAR(clear_module_state->__pyx_n_s_tri);
  Py_CLEAR(clear_module_state->__pyx_n_s_triangle);
  Py_CLEAR(clear_module_state->__pyx_n_s_triangle_paper);
  Py_CLEAR(clear_module_state->__pyx_n_s_triangle_plein);
  Py_CLEAR(clear_module_state->__pyx_n_s_triangle_point);
  Py_CLEAR(clear_module_state->__pyx_n_s_triangle_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_trig2exp);
  Py_CLEAR(clear_module_state->__pyx_n_s_trigcos);
  Py_CLEAR(clear_module_state->__pyx_n_s_trigexpand);
  Py_CLEAR(clear_module_state->__pyx_n_s_triginterp);
  Py_CLEAR(clear_module_state->__pyx_n_s_trigsimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_trigsin);
  Py_CLEAR(clear_module_state->__pyx_n_s_trigtan);
  Py_CLEAR(clear_module_state->__pyx_n_s_trim);
  Py_CLEAR(clear_module_state->__pyx_n_s_trn);
  Py_CLEAR(clear_module_state->__pyx_n_s_true);
  Py_CLEAR(clear_module_state->__pyx_n_s_truediv);
  Py_CLEAR(clear_module_state->__pyx_n_s_trunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_truncate);
  Py_CLEAR(clear_module_state->__pyx_n_s_truncate_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_try);
  Py_CLEAR(clear_module_state->__pyx_kp_s_trying_soft_interruption_wait_2s);
  Py_CLEAR(clear_module_state->__pyx_n_s_tsimplify);
  Py_CLEAR(clear_module_state->__pyx_n_s_tsp);
  Py_CLEAR(clear_module_state->__pyx_n_s_tstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_tuer);
  Py_CLEAR(clear_module_state->__pyx_n_s_tukey_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_tutte_polynomial);
  Py_CLEAR(clear_module_state->__pyx_n_s_two_edge_connected_components);
  Py_CLEAR(clear_module_state->__pyx_n_s_twopi);
  Py_CLEAR(clear_module_state->__pyx_n_s_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_type_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_u);
  Py_CLEAR(clear_module_state->__pyx_n_s_ufactor);
  Py_CLEAR(clear_module_state->__pyx_n_s_ugamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_unapply);
  Py_CLEAR(clear_module_state->__pyx_n_s_unarchive);
  Py_CLEAR(clear_module_state->__pyx_n_s_undef);
  Py_CLEAR(clear_module_state->__pyx_n_s_underlying_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_unfactored);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniform);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniform_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniform_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniformd);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniformd_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniformd_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_union);
  Py_CLEAR(clear_module_state->__pyx_n_s_unitV);
  Py_CLEAR(clear_module_state->__pyx_n_s_unquote);
  Py_CLEAR(clear_module_state->__pyx_n_s_until);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_upper);
  Py_CLEAR(clear_module_state->__pyx_n_s_url);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_user_operator);
  Py_CLEAR(clear_module_state->__pyx_n_s_usimplify);
  Py_CLEAR(clear_module_state->__pyx_kp_s_using_sendtext);
  Py_CLEAR(clear_module_state->__pyx_n_s_ustep);
  Py_CLEAR(clear_module_state->__pyx_n_s_val);
  Py_CLEAR(clear_module_state->__pyx_n_s_valuation);
  Py_CLEAR(clear_module_state->__pyx_n_s_vandermonde);
  Py_CLEAR(clear_module_state->__pyx_n_s_var);
  Py_CLEAR(clear_module_state->__pyx_n_s_variables_are_files);
  Py_CLEAR(clear_module_state->__pyx_n_s_variance);
  Py_CLEAR(clear_module_state->__pyx_n_s_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_vers);
  Py_CLEAR(clear_module_state->__pyx_n_s_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_vert);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertex_connectivity);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertex_cover_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertex_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertex_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertex_in_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertex_out_degree);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertices);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertices_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_vertices_abca);
  Py_CLEAR(clear_module_state->__pyx_kp_u_vide_Pygen_giac_version_dpt_eit);
  Py_CLEAR(clear_module_state->__pyx_n_s_violet);
  Py_CLEAR(clear_module_state->__pyx_n_s_vpotential);
  Py_CLEAR(clear_module_state->__pyx_n_s_vrai);
  Py_CLEAR(clear_module_state->__pyx_n_s_vstep);
  Py_CLEAR(clear_module_state->__pyx_kp_s_warning_Killing_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_watch);
  Py_CLEAR(clear_module_state->__pyx_n_s_web_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_webbrowser);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibull);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibull_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibull_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibulld);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibulld_cdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibulld_icdf);
  Py_CLEAR(clear_module_state->__pyx_n_s_weibullvariate);
  Py_CLEAR(clear_module_state->__pyx_n_s_weight_decay);
  Py_CLEAR(clear_module_state->__pyx_n_s_weight_matrix);
  Py_CLEAR(clear_module_state->__pyx_n_s_weighted);
  Py_CLEAR(clear_module_state->__pyx_n_s_weights);
  Py_CLEAR(clear_module_state->__pyx_n_s_welch_window);
  Py_CLEAR(clear_module_state->__pyx_n_s_wheel_graph);
  Py_CLEAR(clear_module_state->__pyx_n_s_when);
  Py_CLEAR(clear_module_state->__pyx_n_s_while);
  Py_CLEAR(clear_module_state->__pyx_n_s_white);
  Py_CLEAR(clear_module_state->__pyx_n_s_widget_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_wilcoxonp);
  Py_CLEAR(clear_module_state->__pyx_n_s_wilcoxons);
  Py_CLEAR(clear_module_state->__pyx_n_s_wilcoxont);
  Py_CLEAR(clear_module_state->__pyx_n_s_with_sqrt);
  Py_CLEAR(clear_module_state->__pyx_n_s_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_writergb);
  Py_CLEAR(clear_module_state->__pyx_n_s_writewav);
  Py_CLEAR(clear_module_state->__pyx_n_s_wwwbrowseropen);
  Py_CLEAR(clear_module_state->__pyx_n_s_wz_certificate);
  Py_CLEAR(clear_module_state->__pyx_n_s_xcas_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_xml_print);
  Py_CLEAR(clear_module_state->__pyx_n_s_xor);
  Py_CLEAR(clear_module_state->__pyx_n_s_xstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_xyz2rgb);
  Py_CLEAR(clear_module_state->__pyx_n_s_xyztrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_yd);
  Py_CLEAR(clear_module_state->__pyx_kp_s_yd_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_yd_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_yellow);
  Py_CLEAR(clear_module_state->__pyx_n_s_yr);
  Py_CLEAR(clear_module_state->__pyx_n_s_ystep);
  Py_CLEAR(clear_module_state->__pyx_n_s_zeros);
  Py_CLEAR(clear_module_state->__pyx_n_s_zip);
  Py_CLEAR(clear_module_state->__pyx_n_s_znorder);
  Py_CLEAR(clear_module_state->__pyx_n_s_znprimroot);
  Py_CLEAR(clear_module_state->__pyx_n_s_zstep);
  Py_CLEAR(clear_module_state->__pyx_n_s_ztrans);
  Py_CLEAR(clear_module_state->__pyx_float_0_05);
  Py_CLEAR(clear_module_state->__pyx_float_0_001);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_7);
  Py_CLEAR(clear_module_state->__pyx_int_8);
  Py_CLEAR(clear_module_state->__pyx_int_12);
  Py_CLEAR(clear_module_state->__pyx_int_14);
  Py_CLEAR(clear_module_state->__pyx_int_100);
  Py_CLEAR(clear_module_state->__pyx_int_1000000);
  Py_CLEAR(clear_module_state->__pyx_int_222419149);
  Py_CLEAR(clear_module_state->__pyx_int_228825662);
  Py_CLEAR(clear_module_state->__pyx_int_238750788);
  Py_CLEAR(clear_module_state->__pyx_tuple_);
  Py_CLEAR(clear_module_state->__pyx_slice__2);
  Py_CLEAR(clear_module_state->__pyx_tuple__3);
  Py_CLEAR(clear_module_state->__pyx_tuple__4);
  Py_CLEAR(clear_module_state->__pyx_tuple__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__6);
  Py_CLEAR(clear_module_state->__pyx_tuple__7);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__22);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_codeobj__16);
  Py_CLEAR(clear_module_state->__pyx_codeobj__17);
  Py_CLEAR(clear_module_state->__pyx_codeobj__19);
  Py_CLEAR(clear_module_state->__pyx_codeobj__21);
  Py_CLEAR(clear_module_state->__pyx_codeobj__23);
  Py_CLEAR(clear_module_state->__pyx_codeobj__25);
  Py_CLEAR(clear_module_state->__pyx_codeobj__26);
  Py_CLEAR(clear_module_state->__pyx_codeobj__27);
  Py_CLEAR(clear_module_state->__pyx_codeobj__28);
  Py_CLEAR(clear_module_state->__pyx_codeobj__29);
  Py_CLEAR(clear_module_state->__pyx_codeobj__30);
  Py_CLEAR(clear_module_state->__pyx_codeobj__31);
  Py_CLEAR(clear_module_state->__pyx_codeobj__32);
  Py_CLEAR(clear_module_state->__pyx_codeobj__33);
  Py_CLEAR(clear_module_state->__pyx_codeobj__34);
  Py_CLEAR(clear_module_state->__pyx_codeobj__35);
  Py_CLEAR(clear_module_state->__pyx_codeobj__36);
  Py_CLEAR(clear_module_state->__pyx_codeobj__37);
  Py_CLEAR(clear_module_state->__pyx_codeobj__38);
  Py_CLEAR(clear_module_state->__pyx_codeobj__39);
  Py_CLEAR(clear_module_state->__pyx_codeobj__40);
  Py_CLEAR(clear_module_state->__pyx_codeobj__41);
  Py_CLEAR(clear_module_state->__pyx_codeobj__42);
  Py_CLEAR(clear_module_state->__pyx_codeobj__43);
  Py_CLEAR(clear_module_state->__pyx_codeobj__44);
  Py_CLEAR(clear_module_state->__pyx_codeobj__45);
  Py_CLEAR(clear_module_state->__pyx_codeobj__46);
  Py_CLEAR(clear_module_state->__pyx_codeobj__47);
  Py_CLEAR(clear_module_state->__pyx_codeobj__48);
  Py_CLEAR(clear_module_state->__pyx_codeobj__49);
  Py_CLEAR(clear_module_state->__pyx_codeobj__50);
  Py_CLEAR(clear_module_state->__pyx_codeobj__51);
  Py_CLEAR(clear_module_state->__pyx_codeobj__52);
  Py_CLEAR(clear_module_state->__pyx_codeobj__53);
  Py_CLEAR(clear_module_state->__pyx_codeobj__54);
  Py_CLEAR(clear_module_state->__pyx_codeobj__55);
  Py_CLEAR(clear_module_state->__pyx_codeobj__56);
  Py_CLEAR(clear_module_state->__pyx_codeobj__57);
  Py_CLEAR(clear_module_state->__pyx_codeobj__58);
  Py_CLEAR(clear_module_state->__pyx_codeobj__59);
  Py_CLEAR(clear_module_state->__pyx_codeobj__60);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__62);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__64);
  Py_CLEAR(clear_module_state->__pyx_codeobj__65);
  Py_CLEAR(clear_module_state->__pyx_codeobj__66);
  Py_CLEAR(clear_module_state->__pyx_codeobj__67);
  Py_CLEAR(clear_module_state->__pyx_codeobj__68);
  Py_CLEAR(clear_module_state->__pyx_codeobj__69);
  Py_CLEAR(clear_module_state->__pyx_codeobj__70);
  Py_CLEAR(clear_module_state->__pyx_codeobj__71);
  Py_CLEAR(clear_module_state->__pyx_codeobj__72);
  Py_CLEAR(clear_module_state->__pyx_codeobj__73);
  Py_CLEAR(clear_module_state->__pyx_codeobj__74);
  Py_CLEAR(clear_module_state->__pyx_codeobj__75);
  Py_CLEAR(clear_module_state->__pyx_codeobj__76);
  Py_CLEAR(clear_module_state->__pyx_codeobj__77);
  Py_CLEAR(clear_module_state->__pyx_codeobj__78);
  Py_CLEAR(clear_module_state->__pyx_codeobj__79);
  Py_CLEAR(clear_module_state->__pyx_codeobj__80);
  Py_CLEAR(clear_module_state->__pyx_codeobj__81);
  Py_CLEAR(clear_module_state->__pyx_codeobj__82);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__84);
  Py_CLEAR(clear_module_state->__pyx_codeobj__85);
  Py_CLEAR(clear_module_state->__pyx_codeobj__86);
  Py_CLEAR(clear_module_state->__pyx_codeobj__87);
  Py_CLEAR(clear_module_state->__pyx_codeobj__88);
  Py_CLEAR(clear_module_state->__pyx_codeobj__89);
  Py_CLEAR(clear_module_state->__pyx_codeobj__90);
  Py_CLEAR(clear_module_state->__pyx_codeobj__91);
  Py_CLEAR(clear_module_state->__pyx_codeobj__92);
  Py_CLEAR(clear_module_state->__pyx_codeobj__93);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__95);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  Py_CLEAR(clear_module_state->__pyx_codeobj__97);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__99);
  Py_CLEAR(clear_module_state->__pyx_tuple__1627);
  Py_CLEAR(clear_module_state->__pyx_tuple__1630);
  Py_CLEAR(clear_module_state->__pyx_tuple__1632);
  Py_CLEAR(clear_module_state->__pyx_tuple__1637);
  Py_CLEAR(clear_module_state->__pyx_tuple__1639);
  Py_CLEAR(clear_module_state->__pyx_tuple__1641);
  Py_CLEAR(clear_module_state->__pyx_tuple__1643);
  Py_CLEAR(clear_module_state->__pyx_tuple__1645);
  Py_CLEAR(clear_module_state->__pyx_tuple__1646);
  Py_CLEAR(clear_module_state->__pyx_tuple__1650);
  Py_CLEAR(clear_module_state->__pyx_tuple__1651);
  Py_CLEAR(clear_module_state->__pyx_tuple__1653);
  Py_CLEAR(clear_module_state->__pyx_tuple__1702);
  Py_CLEAR(clear_module_state->__pyx_tuple__1707);
  Py_CLEAR(clear_module_state->__pyx_tuple__1713);
  Py_CLEAR(clear_module_state->__pyx_tuple__1719);
  Py_CLEAR(clear_module_state->__pyx_tuple__1721);
  Py_CLEAR(clear_module_state->__pyx_tuple__1722);
  Py_CLEAR(clear_module_state->__pyx_tuple__1724);
  Py_CLEAR(clear_module_state->__pyx_tuple__1726);
  Py_CLEAR(clear_module_state->__pyx_codeobj__100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__101);
  Py_CLEAR(clear_module_state->__pyx_codeobj__102);
  Py_CLEAR(clear_module_state->__pyx_codeobj__103);
  Py_CLEAR(clear_module_state->__pyx_codeobj__104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__105);
  Py_CLEAR(clear_module_state->__pyx_codeobj__106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__107);
  Py_CLEAR(clear_module_state->__pyx_codeobj__108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__109);
  Py_CLEAR(clear_module_state->__pyx_codeobj__110);
  Py_CLEAR(clear_module_state->__pyx_codeobj__111);
  Py_CLEAR(clear_module_state->__pyx_codeobj__112);
  Py_CLEAR(clear_module_state->__pyx_codeobj__113);
  Py_CLEAR(clear_module_state->__pyx_codeobj__114);
  Py_CLEAR(clear_module_state->__pyx_codeobj__115);
  Py_CLEAR(clear_module_state->__pyx_codeobj__116);
  Py_CLEAR(clear_module_state->__pyx_codeobj__117);
  Py_CLEAR(clear_module_state->__pyx_codeobj__118);
  Py_CLEAR(clear_module_state->__pyx_codeobj__119);
  Py_CLEAR(clear_module_state->__pyx_codeobj__120);
  Py_CLEAR(clear_module_state->__pyx_codeobj__121);
  Py_CLEAR(clear_module_state->__pyx_codeobj__122);
  Py_CLEAR(clear_module_state->__pyx_codeobj__123);
  Py_CLEAR(clear_module_state->__pyx_codeobj__124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__125);
  Py_CLEAR(clear_module_state->__pyx_codeobj__126);
  Py_CLEAR(clear_module_state->__pyx_codeobj__127);
  Py_CLEAR(clear_module_state->__pyx_codeobj__128);
  Py_CLEAR(clear_module_state->__pyx_codeobj__129);
  Py_CLEAR(clear_module_state->__pyx_codeobj__130);
  Py_CLEAR(clear_module_state->__pyx_codeobj__131);
  Py_CLEAR(clear_module_state->__pyx_codeobj__132);
  Py_CLEAR(clear_module_state->__pyx_codeobj__133);
  Py_CLEAR(clear_module_state->__pyx_codeobj__134);
  Py_CLEAR(clear_module_state->__pyx_codeobj__135);
  Py_CLEAR(clear_module_state->__pyx_codeobj__136);
  Py_CLEAR(clear_module_state->__pyx_codeobj__137);
  Py_CLEAR(clear_module_state->__pyx_codeobj__138);
  Py_CLEAR(clear_module_state->__pyx_codeobj__139);
  Py_CLEAR(clear_module_state->__pyx_codeobj__140);
  Py_CLEAR(clear_module_state->__pyx_codeobj__141);
  Py_CLEAR(clear_module_state->__pyx_codeobj__142);
  Py_CLEAR(clear_module_state->__pyx_codeobj__143);
  Py_CLEAR(clear_module_state->__pyx_codeobj__144);
  Py_CLEAR(clear_module_state->__pyx_codeobj__145);
  Py_CLEAR(clear_module_state->__pyx_codeobj__146);
  Py_CLEAR(clear_module_state->__pyx_codeobj__147);
  Py_CLEAR(clear_module_state->__pyx_codeobj__148);
  Py_CLEAR(clear_module_state->__pyx_codeobj__149);
  Py_CLEAR(clear_module_state->__pyx_codeobj__150);
  Py_CLEAR(clear_module_state->__pyx_codeobj__151);
  Py_CLEAR(clear_module_state->__pyx_codeobj__152);
  Py_CLEAR(clear_module_state->__pyx_codeobj__153);
  Py_CLEAR(clear_module_state->__pyx_codeobj__154);
  Py_CLEAR(clear_module_state->__pyx_codeobj__155);
  Py_CLEAR(clear_module_state->__pyx_codeobj__156);
  Py_CLEAR(clear_module_state->__pyx_codeobj__157);
  Py_CLEAR(clear_module_state->__pyx_codeobj__158);
  Py_CLEAR(clear_module_state->__pyx_codeobj__159);
  Py_CLEAR(clear_module_state->__pyx_codeobj__160);
  Py_CLEAR(clear_module_state->__pyx_codeobj__161);
  Py_CLEAR(clear_module_state->__pyx_codeobj__162);
  Py_CLEAR(clear_module_state->__pyx_codeobj__163);
  Py_CLEAR(clear_module_state->__pyx_codeobj__164);
  Py_CLEAR(clear_module_state->__pyx_codeobj__165);
  Py_CLEAR(clear_module_state->__pyx_codeobj__166);
  Py_CLEAR(clear_module_state->__pyx_codeobj__167);
  Py_CLEAR(clear_module_state->__pyx_codeobj__168);
  Py_CLEAR(clear_module_state->__pyx_codeobj__169);
  Py_CLEAR(clear_module_state->__pyx_codeobj__170);
  Py_CLEAR(clear_module_state->__pyx_codeobj__171);
  Py_CLEAR(clear_module_state->__pyx_codeobj__172);
  Py_CLEAR(clear_module_state->__pyx_codeobj__173);
  Py_CLEAR(clear_module_state->__pyx_codeobj__174);
  Py_CLEAR(clear_module_state->__pyx_codeobj__175);
  Py_CLEAR(clear_module_state->__pyx_codeobj__176);
  Py_CLEAR(clear_module_state->__pyx_codeobj__177);
  Py_CLEAR(clear_module_state->__pyx_codeobj__178);
  Py_CLEAR(clear_module_state->__pyx_codeobj__179);
  Py_CLEAR(clear_module_state->__pyx_codeobj__180);
  Py_CLEAR(clear_module_state->__pyx_codeobj__181);
  Py_CLEAR(clear_module_state->__pyx_codeobj__182);
  Py_CLEAR(clear_module_state->__pyx_codeobj__183);
  Py_CLEAR(clear_module_state->__pyx_codeobj__184);
  Py_CLEAR(clear_module_state->__pyx_codeobj__185);
  Py_CLEAR(clear_module_state->__pyx_codeobj__186);
  Py_CLEAR(clear_module_state->__pyx_codeobj__187);
  Py_CLEAR(clear_module_state->__pyx_codeobj__188);
  Py_CLEAR(clear_module_state->__pyx_codeobj__189);
  Py_CLEAR(clear_module_state->__pyx_codeobj__190);
  Py_CLEAR(clear_module_state->__pyx_codeobj__191);
  Py_CLEAR(clear_module_state->__pyx_codeobj__192);
  Py_CLEAR(clear_module_state->__pyx_codeobj__193);
  Py_CLEAR(clear_module_state->__pyx_codeobj__194);
  Py_CLEAR(clear_module_state->__pyx_codeobj__195);
  Py_CLEAR(clear_module_state->__pyx_codeobj__196);
  Py_CLEAR(clear_module_state->__pyx_codeobj__197);
  Py_CLEAR(clear_module_state->__pyx_codeobj__198);
  Py_CLEAR(clear_module_state->__pyx_codeobj__199);
  Py_CLEAR(clear_module_state->__pyx_codeobj__200);
  Py_CLEAR(clear_module_state->__pyx_codeobj__201);
  Py_CLEAR(clear_module_state->__pyx_codeobj__202);
  Py_CLEAR(clear_module_state->__pyx_codeobj__203);
  Py_CLEAR(clear_module_state->__pyx_codeobj__204);
  Py_CLEAR(clear_module_state->__pyx_codeobj__205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__206);
  Py_CLEAR(clear_module_state->__pyx_codeobj__207);
  Py_CLEAR(clear_module_state->__pyx_codeobj__208);
  Py_CLEAR(clear_module_state->__pyx_codeobj__209);
  Py_CLEAR(clear_module_state->__pyx_codeobj__210);
  Py_CLEAR(clear_module_state->__pyx_codeobj__211);
  Py_CLEAR(clear_module_state->__pyx_codeobj__212);
  Py_CLEAR(clear_module_state->__pyx_codeobj__213);
  Py_CLEAR(clear_module_state->__pyx_codeobj__214);
  Py_CLEAR(clear_module_state->__pyx_codeobj__215);
  Py_CLEAR(clear_module_state->__pyx_codeobj__216);
  Py_CLEAR(clear_module_state->__pyx_codeobj__217);
  Py_CLEAR(clear_module_state->__pyx_codeobj__218);
  Py_CLEAR(clear_module_state->__pyx_codeobj__219);
  Py_CLEAR(clear_module_state->__pyx_codeobj__220);
  Py_CLEAR(clear_module_state->__pyx_codeobj__221);
  Py_CLEAR(clear_module_state->__pyx_codeobj__222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__223);
  Py_CLEAR(clear_module_state->__pyx_codeobj__224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__225);
  Py_CLEAR(clear_module_state->__pyx_codeobj__226);
  Py_CLEAR(clear_module_state->__pyx_codeobj__227);
  Py_CLEAR(clear_module_state->__pyx_codeobj__228);
  Py_CLEAR(clear_module_state->__pyx_codeobj__229);
  Py_CLEAR(clear_module_state->__pyx_codeobj__230);
  Py_CLEAR(clear_module_state->__pyx_codeobj__231);
  Py_CLEAR(clear_module_state->__pyx_codeobj__232);
  Py_CLEAR(clear_module_state->__pyx_codeobj__233);
  Py_CLEAR(clear_module_state->__pyx_codeobj__234);
  Py_CLEAR(clear_module_state->__pyx_codeobj__235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__236);
  Py_CLEAR(clear_module_state->__pyx_codeobj__237);
  Py_CLEAR(clear_module_state->__pyx_codeobj__238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__240);
  Py_CLEAR(clear_module_state->__pyx_codeobj__241);
  Py_CLEAR(clear_module_state->__pyx_codeobj__242);
  Py_CLEAR(clear_module_state->__pyx_codeobj__243);
  Py_CLEAR(clear_module_state->__pyx_codeobj__244);
  Py_CLEAR(clear_module_state->__pyx_codeobj__245);
  Py_CLEAR(clear_module_state->__pyx_codeobj__246);
  Py_CLEAR(clear_module_state->__pyx_codeobj__247);
  Py_CLEAR(clear_module_state->__pyx_codeobj__248);
  Py_CLEAR(clear_module_state->__pyx_codeobj__249);
  Py_CLEAR(clear_module_state->__pyx_codeobj__250);
  Py_CLEAR(clear_module_state->__pyx_codeobj__251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__252);
  Py_CLEAR(clear_module_state->__pyx_codeobj__253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__254);
  Py_CLEAR(clear_module_state->__pyx_codeobj__255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__256);
  Py_CLEAR(clear_module_state->__pyx_codeobj__257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__258);
  Py_CLEAR(clear_module_state->__pyx_codeobj__259);
  Py_CLEAR(clear_module_state->__pyx_codeobj__260);
  Py_CLEAR(clear_module_state->__pyx_codeobj__261);
  Py_CLEAR(clear_module_state->__pyx_codeobj__262);
  Py_CLEAR(clear_module_state->__pyx_codeobj__263);
  Py_CLEAR(clear_module_state->__pyx_codeobj__264);
  Py_CLEAR(clear_module_state->__pyx_codeobj__265);
  Py_CLEAR(clear_module_state->__pyx_codeobj__266);
  Py_CLEAR(clear_module_state->__pyx_codeobj__267);
  Py_CLEAR(clear_module_state->__pyx_codeobj__268);
  Py_CLEAR(clear_module_state->__pyx_codeobj__269);
  Py_CLEAR(clear_module_state->__pyx_codeobj__270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__271);
  Py_CLEAR(clear_module_state->__pyx_codeobj__272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__273);
  Py_CLEAR(clear_module_state->__pyx_codeobj__274);
  Py_CLEAR(clear_module_state->__pyx_codeobj__275);
  Py_CLEAR(clear_module_state->__pyx_codeobj__276);
  Py_CLEAR(clear_module_state->__pyx_codeobj__277);
  Py_CLEAR(clear_module_state->__pyx_codeobj__278);
  Py_CLEAR(clear_module_state->__pyx_codeobj__279);
  Py_CLEAR(clear_module_state->__pyx_codeobj__280);
  Py_CLEAR(clear_module_state->__pyx_codeobj__281);
  Py_CLEAR(clear_module_state->__pyx_codeobj__282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__283);
  Py_CLEAR(clear_module_state->__pyx_codeobj__284);
  Py_CLEAR(clear_module_state->__pyx_codeobj__285);
  Py_CLEAR(clear_module_state->__pyx_codeobj__286);
  Py_CLEAR(clear_module_state->__pyx_codeobj__287);
  Py_CLEAR(clear_module_state->__pyx_codeobj__288);
  Py_CLEAR(clear_module_state->__pyx_codeobj__289);
  Py_CLEAR(clear_module_state->__pyx_codeobj__290);
  Py_CLEAR(clear_module_state->__pyx_codeobj__291);
  Py_CLEAR(clear_module_state->__pyx_codeobj__292);
  Py_CLEAR(clear_module_state->__pyx_codeobj__293);
  Py_CLEAR(clear_module_state->__pyx_codeobj__294);
  Py_CLEAR(clear_module_state->__pyx_codeobj__295);
  Py_CLEAR(clear_module_state->__pyx_codeobj__296);
  Py_CLEAR(clear_module_state->__pyx_codeobj__297);
  Py_CLEAR(clear_module_state->__pyx_codeobj__298);
  Py_CLEAR(clear_module_state->__pyx_codeobj__299);
  Py_CLEAR(clear_module_state->__pyx_codeobj__300);
  Py_CLEAR(clear_module_state->__pyx_codeobj__301);
  Py_CLEAR(clear_module_state->__pyx_codeobj__302);
  Py_CLEAR(clear_module_state->__pyx_codeobj__303);
  Py_CLEAR(clear_module_state->__pyx_codeobj__304);
  Py_CLEAR(clear_module_state->__pyx_codeobj__305);
  Py_CLEAR(clear_module_state->__pyx_codeobj__306);
  Py_CLEAR(clear_module_state->__pyx_codeobj__307);
  Py_CLEAR(clear_module_state->__pyx_codeobj__308);
  Py_CLEAR(clear_module_state->__pyx_codeobj__309);
  Py_CLEAR(clear_module_state->__pyx_codeobj__310);
  Py_CLEAR(clear_module_state->__pyx_codeobj__311);
  Py_CLEAR(clear_module_state->__pyx_codeobj__312);
  Py_CLEAR(clear_module_state->__pyx_codeobj__313);
  Py_CLEAR(clear_module_state->__pyx_codeobj__314);
  Py_CLEAR(clear_module_state->__pyx_codeobj__315);
  Py_CLEAR(clear_module_state->__pyx_codeobj__316);
  Py_CLEAR(clear_module_state->__pyx_codeobj__317);
  Py_CLEAR(clear_module_state->__pyx_codeobj__318);
  Py_CLEAR(clear_module_state->__pyx_codeobj__319);
  Py_CLEAR(clear_module_state->__pyx_codeobj__320);
  Py_CLEAR(clear_module_state->__pyx_codeobj__321);
  Py_CLEAR(clear_module_state->__pyx_codeobj__322);
  Py_CLEAR(clear_module_state->__pyx_codeobj__323);
  Py_CLEAR(clear_module_state->__pyx_codeobj__324);
  Py_CLEAR(clear_module_state->__pyx_codeobj__325);
  Py_CLEAR(clear_module_state->__pyx_codeobj__326);
  Py_CLEAR(clear_module_state->__pyx_codeobj__327);
  Py_CLEAR(clear_module_state->__pyx_codeobj__328);
  Py_CLEAR(clear_module_state->__pyx_codeobj__329);
  Py_CLEAR(clear_module_state->__pyx_codeobj__330);
  Py_CLEAR(clear_module_state->__pyx_codeobj__331);
  Py_CLEAR(clear_module_state->__pyx_codeobj__332);
  Py_CLEAR(clear_module_state->__pyx_codeobj__333);
  Py_CLEAR(clear_module_state->__pyx_codeobj__334);
  Py_CLEAR(clear_module_state->__pyx_codeobj__335);
  Py_CLEAR(clear_module_state->__pyx_codeobj__336);
  Py_CLEAR(clear_module_state->__pyx_codeobj__337);
  Py_CLEAR(clear_module_state->__pyx_codeobj__338);
  Py_CLEAR(clear_module_state->__pyx_codeobj__339);
  Py_CLEAR(clear_module_state->__pyx_codeobj__340);
  Py_CLEAR(clear_module_state->__pyx_codeobj__341);
  Py_CLEAR(clear_module_state->__pyx_codeobj__342);
  Py_CLEAR(clear_module_state->__pyx_codeobj__343);
  Py_CLEAR(clear_module_state->__pyx_codeobj__344);
  Py_CLEAR(clear_module_state->__pyx_codeobj__345);
  Py_CLEAR(clear_module_state->__pyx_codeobj__346);
  Py_CLEAR(clear_module_state->__pyx_codeobj__347);
  Py_CLEAR(clear_module_state->__pyx_codeobj__348);
  Py_CLEAR(clear_module_state->__pyx_codeobj__349);
  Py_CLEAR(clear_module_state->__pyx_codeobj__350);
  Py_CLEAR(clear_module_state->__pyx_codeobj__351);
  Py_CLEAR(clear_module_state->__pyx_codeobj__352);
  Py_CLEAR(clear_module_state->__pyx_codeobj__353);
  Py_CLEAR(clear_module_state->__pyx_codeobj__354);
  Py_CLEAR(clear_module_state->__pyx_codeobj__355);
  Py_CLEAR(clear_module_state->__pyx_codeobj__356);
  Py_CLEAR(clear_module_state->__pyx_codeobj__357);
  Py_CLEAR(clear_module_state->__pyx_codeobj__358);
  Py_CLEAR(clear_module_state->__pyx_codeobj__359);
  Py_CLEAR(clear_module_state->__pyx_codeobj__360);
  Py_CLEAR(clear_module_state->__pyx_codeobj__361);
  Py_CLEAR(clear_module_state->__pyx_codeobj__362);
  Py_CLEAR(clear_module_state->__pyx_codeobj__363);
  Py_CLEAR(clear_module_state->__pyx_codeobj__364);
  Py_CLEAR(clear_module_state->__pyx_codeobj__365);
  Py_CLEAR(clear_module_state->__pyx_codeobj__366);
  Py_CLEAR(clear_module_state->__pyx_codeobj__367);
  Py_CLEAR(clear_module_state->__pyx_codeobj__368);
  Py_CLEAR(clear_module_state->__pyx_codeobj__369);
  Py_CLEAR(clear_module_state->__pyx_codeobj__370);
  Py_CLEAR(clear_module_state->__pyx_codeobj__371);
  Py_CLEAR(clear_module_state->__pyx_codeobj__372);
  Py_CLEAR(clear_module_state->__pyx_codeobj__373);
  Py_CLEAR(clear_module_state->__pyx_codeobj__374);
  Py_CLEAR(clear_module_state->__pyx_codeobj__375);
  Py_CLEAR(clear_module_state->__pyx_codeobj__376);
  Py_CLEAR(clear_module_state->__pyx_codeobj__377);
  Py_CLEAR(clear_module_state->__pyx_codeobj__378);
  Py_CLEAR(clear_module_state->__pyx_codeobj__379);
  Py_CLEAR(clear_module_state->__pyx_codeobj__380);
  Py_CLEAR(clear_module_state->__pyx_codeobj__381);
  Py_CLEAR(clear_module_state->__pyx_codeobj__382);
  Py_CLEAR(clear_module_state->__pyx_codeobj__383);
  Py_CLEAR(clear_module_state->__pyx_codeobj__384);
  Py_CLEAR(clear_module_state->__pyx_codeobj__385);
  Py_CLEAR(clear_module_state->__pyx_codeobj__386);
  Py_CLEAR(clear_module_state->__pyx_codeobj__387);
  Py_CLEAR(clear_module_state->__pyx_codeobj__388);
  Py_CLEAR(clear_module_state->__pyx_codeobj__389);
  Py_CLEAR(clear_module_state->__pyx_codeobj__390);
  Py_CLEAR(clear_module_state->__pyx_codeobj__391);
  Py_CLEAR(clear_module_state->__pyx_codeobj__392);
  Py_CLEAR(clear_module_state->__pyx_codeobj__393);
  Py_CLEAR(clear_module_state->__pyx_codeobj__394);
  Py_CLEAR(clear_module_state->__pyx_codeobj__395);
  Py_CLEAR(clear_module_state->__pyx_codeobj__396);
  Py_CLEAR(clear_module_state->__pyx_codeobj__397);
  Py_CLEAR(clear_module_state->__pyx_codeobj__398);
  Py_CLEAR(clear_module_state->__pyx_codeobj__399);
  Py_CLEAR(clear_module_state->__pyx_codeobj__400);
  Py_CLEAR(clear_module_state->__pyx_codeobj__401);
  Py_CLEAR(clear_module_state->__pyx_codeobj__402);
  Py_CLEAR(clear_module_state->__pyx_codeobj__403);
  Py_CLEAR(clear_module_state->__pyx_codeobj__404);
  Py_CLEAR(clear_module_state->__pyx_codeobj__405);
  Py_CLEAR(clear_module_state->__pyx_codeobj__406);
  Py_CLEAR(clear_module_state->__pyx_codeobj__407);
  Py_CLEAR(clear_module_state->__pyx_codeobj__408);
  Py_CLEAR(clear_module_state->__pyx_codeobj__409);
  Py_CLEAR(clear_module_state->__pyx_codeobj__410);
  Py_CLEAR(clear_module_state->__pyx_codeobj__411);
  Py_CLEAR(clear_module_state->__pyx_codeobj__412);
  Py_CLEAR(clear_module_state->__pyx_codeobj__413);
  Py_CLEAR(clear_module_state->__pyx_codeobj__414);
  Py_CLEAR(clear_module_state->__pyx_codeobj__415);
  Py_CLEAR(clear_module_state->__pyx_codeobj__416);
  Py_CLEAR(clear_module_state->__pyx_codeobj__417);
  Py_CLEAR(clear_module_state->__pyx_codeobj__418);
  Py_CLEAR(clear_module_state->__pyx_codeobj__419);
  Py_CLEAR(clear_module_state->__pyx_codeobj__420);
  Py_CLEAR(clear_module_state->__pyx_codeobj__421);
  Py_CLEAR(clear_module_state->__pyx_codeobj__422);
  Py_CLEAR(clear_module_state->__pyx_codeobj__423);
  Py_CLEAR(clear_module_state->__pyx_codeobj__424);
  Py_CLEAR(clear_module_state->__pyx_codeobj__425);
  Py_CLEAR(clear_module_state->__pyx_codeobj__426);
  Py_CLEAR(clear_module_state->__pyx_codeobj__427);
  Py_CLEAR(clear_module_state->__pyx_codeobj__428);
  Py_CLEAR(clear_module_state->__pyx_codeobj__429);
  Py_CLEAR(clear_module_state->__pyx_codeobj__430);
  Py_CLEAR(clear_module_state->__pyx_codeobj__431);
  Py_CLEAR(clear_module_state->__pyx_codeobj__432);
  Py_CLEAR(clear_module_state->__pyx_codeobj__433);
  Py_CLEAR(clear_module_state->__pyx_codeobj__434);
  Py_CLEAR(clear_module_state->__pyx_codeobj__435);
  Py_CLEAR(clear_module_state->__pyx_codeobj__436);
  Py_CLEAR(clear_module_state->__pyx_codeobj__437);
  Py_CLEAR(clear_module_state->__pyx_codeobj__438);
  Py_CLEAR(clear_module_state->__pyx_codeobj__439);
  Py_CLEAR(clear_module_state->__pyx_codeobj__440);
  Py_CLEAR(clear_module_state->__pyx_codeobj__441);
  Py_CLEAR(clear_module_state->__pyx_codeobj__442);
  Py_CLEAR(clear_module_state->__pyx_codeobj__443);
  Py_CLEAR(clear_module_state->__pyx_codeobj__444);
  Py_CLEAR(clear_module_state->__pyx_codeobj__445);
  Py_CLEAR(clear_module_state->__pyx_codeobj__446);
  Py_CLEAR(clear_module_state->__pyx_codeobj__447);
  Py_CLEAR(clear_module_state->__pyx_codeobj__448);
  Py_CLEAR(clear_module_state->__pyx_codeobj__449);
  Py_CLEAR(clear_module_state->__pyx_codeobj__450);
  Py_CLEAR(clear_module_state->__pyx_codeobj__451);
  Py_CLEAR(clear_module_state->__pyx_codeobj__452);
  Py_CLEAR(clear_module_state->__pyx_codeobj__453);
  Py_CLEAR(clear_module_state->__pyx_codeobj__454);
  Py_CLEAR(clear_module_state->__pyx_codeobj__455);
  Py_CLEAR(clear_module_state->__pyx_codeobj__456);
  Py_CLEAR(clear_module_state->__pyx_codeobj__457);
  Py_CLEAR(clear_module_state->__pyx_codeobj__458);
  Py_CLEAR(clear_module_state->__pyx_codeobj__459);
  Py_CLEAR(clear_module_state->__pyx_codeobj__460);
  Py_CLEAR(clear_module_state->__pyx_codeobj__461);
  Py_CLEAR(clear_module_state->__pyx_codeobj__462);
  Py_CLEAR(clear_module_state->__pyx_codeobj__463);
  Py_CLEAR(clear_module_state->__pyx_codeobj__464);
  Py_CLEAR(clear_module_state->__pyx_codeobj__465);
  Py_CLEAR(clear_module_state->__pyx_codeobj__466);
  Py_CLEAR(clear_module_state->__pyx_codeobj__467);
  Py_CLEAR(clear_module_state->__pyx_codeobj__468);
  Py_CLEAR(clear_module_state->__pyx_codeobj__469);
  Py_CLEAR(clear_module_state->__pyx_codeobj__470);
  Py_CLEAR(clear_module_state->__pyx_codeobj__471);
  Py_CLEAR(clear_module_state->__pyx_codeobj__472);
  Py_CLEAR(clear_module_state->__pyx_codeobj__473);
  Py_CLEAR(clear_module_state->__pyx_codeobj__474);
  Py_CLEAR(clear_module_state->__pyx_codeobj__475);
  Py_CLEAR(clear_module_state->__pyx_codeobj__476);
  Py_CLEAR(clear_module_state->__pyx_codeobj__477);
  Py_CLEAR(clear_module_state->__pyx_codeobj__478);
  Py_CLEAR(clear_module_state->__pyx_codeobj__479);
  Py_CLEAR(clear_module_state->__pyx_codeobj__480);
  Py_CLEAR(clear_module_state->__pyx_codeobj__481);
  Py_CLEAR(clear_module_state->__pyx_codeobj__482);
  Py_CLEAR(clear_module_state->__pyx_codeobj__483);
  Py_CLEAR(clear_module_state->__pyx_codeobj__484);
  Py_CLEAR(clear_module_state->__pyx_codeobj__485);
  Py_CLEAR(clear_module_state->__pyx_codeobj__486);
  Py_CLEAR(clear_module_state->__pyx_codeobj__487);
  Py_CLEAR(clear_module_state->__pyx_codeobj__488);
  Py_CLEAR(clear_module_state->__pyx_codeobj__489);
  Py_CLEAR(clear_module_state->__pyx_codeobj__490);
  Py_CLEAR(clear_module_state->__pyx_codeobj__491);
  Py_CLEAR(clear_module_state->__pyx_codeobj__492);
  Py_CLEAR(clear_module_state->__pyx_codeobj__493);
  Py_CLEAR(clear_module_state->__pyx_codeobj__494);
  Py_CLEAR(clear_module_state->__pyx_codeobj__495);
  Py_CLEAR(clear_module_state->__pyx_codeobj__496);
  Py_CLEAR(clear_module_state->__pyx_codeobj__497);
  Py_CLEAR(clear_module_state->__pyx_codeobj__498);
  Py_CLEAR(clear_module_state->__pyx_codeobj__499);
  Py_CLEAR(clear_module_state->__pyx_codeobj__500);
  Py_CLEAR(clear_module_state->__pyx_codeobj__501);
  Py_CLEAR(clear_module_state->__pyx_codeobj__502);
  Py_CLEAR(clear_module_state->__pyx_codeobj__503);
  Py_CLEAR(clear_module_state->__pyx_codeobj__504);
  Py_CLEAR(clear_module_state->__pyx_codeobj__505);
  Py_CLEAR(clear_module_state->__pyx_codeobj__506);
  Py_CLEAR(clear_module_state->__pyx_codeobj__507);
  Py_CLEAR(clear_module_state->__pyx_codeobj__508);
  Py_CLEAR(clear_module_state->__pyx_codeobj__509);
  Py_CLEAR(clear_module_state->__pyx_codeobj__510);
  Py_CLEAR(clear_module_state->__pyx_codeobj__511);
  Py_CLEAR(clear_module_state->__pyx_codeobj__512);
  Py_CLEAR(clear_module_state->__pyx_codeobj__513);
  Py_CLEAR(clear_module_state->__pyx_codeobj__514);
  Py_CLEAR(clear_module_state->__pyx_codeobj__515);
  Py_CLEAR(clear_module_state->__pyx_codeobj__516);
  Py_CLEAR(clear_module_state->__pyx_codeobj__517);
  Py_CLEAR(clear_module_state->__pyx_codeobj__518);
  Py_CLEAR(clear_module_state->__pyx_codeobj__519);
  Py_CLEAR(clear_module_state->__pyx_codeobj__520);
  Py_CLEAR(clear_module_state->__pyx_codeobj__521);
  Py_CLEAR(clear_module_state->__pyx_codeobj__522);
  Py_CLEAR(clear_module_state->__pyx_codeobj__523);
  Py_CLEAR(clear_module_state->__pyx_codeobj__524);
  Py_CLEAR(clear_module_state->__pyx_codeobj__525);
  Py_CLEAR(clear_module_state->__pyx_codeobj__526);
  Py_CLEAR(clear_module_state->__pyx_codeobj__527);
  Py_CLEAR(clear_module_state->__pyx_codeobj__528);
  Py_CLEAR(clear_module_state->__pyx_codeobj__529);
  Py_CLEAR(clear_module_state->__pyx_codeobj__530);
  Py_CLEAR(clear_module_state->__pyx_codeobj__531);
  Py_CLEAR(clear_module_state->__pyx_codeobj__532);
  Py_CLEAR(clear_module_state->__pyx_codeobj__533);
  Py_CLEAR(clear_module_state->__pyx_codeobj__534);
  Py_CLEAR(clear_module_state->__pyx_codeobj__535);
  Py_CLEAR(clear_module_state->__pyx_codeobj__536);
  Py_CLEAR(clear_module_state->__pyx_codeobj__537);
  Py_CLEAR(clear_module_state->__pyx_codeobj__538);
  Py_CLEAR(clear_module_state->__pyx_codeobj__539);
  Py_CLEAR(clear_module_state->__pyx_codeobj__540);
  Py_CLEAR(clear_module_state->__pyx_codeobj__541);
  Py_CLEAR(clear_module_state->__pyx_codeobj__542);
  Py_CLEAR(clear_module_state->__pyx_codeobj__543);
  Py_CLEAR(clear_module_state->__pyx_codeobj__544);
  Py_CLEAR(clear_module_state->__pyx_codeobj__545);
  Py_CLEAR(clear_module_state->__pyx_codeobj__546);
  Py_CLEAR(clear_module_state->__pyx_codeobj__547);
  Py_CLEAR(clear_module_state->__pyx_codeobj__548);
  Py_CLEAR(clear_module_state->__pyx_codeobj__549);
  Py_CLEAR(clear_module_state->__pyx_codeobj__550);
  Py_CLEAR(clear_module_state->__pyx_codeobj__551);
  Py_CLEAR(clear_module_state->__pyx_codeobj__552);
  Py_CLEAR(clear_module_state->__pyx_codeobj__553);
  Py_CLEAR(clear_module_state->__pyx_codeobj__554);
  Py_CLEAR(clear_module_state->__pyx_codeobj__555);
  Py_CLEAR(clear_module_state->__pyx_codeobj__556);
  Py_CLEAR(clear_module_state->__pyx_codeobj__557);
  Py_CLEAR(clear_module_state->__pyx_codeobj__558);
  Py_CLEAR(clear_module_state->__pyx_codeobj__559);
  Py_CLEAR(clear_module_state->__pyx_codeobj__560);
  Py_CLEAR(clear_module_state->__pyx_codeobj__561);
  Py_CLEAR(clear_module_state->__pyx_codeobj__562);
  Py_CLEAR(clear_module_state->__pyx_codeobj__563);
  Py_CLEAR(clear_module_state->__pyx_codeobj__564);
  Py_CLEAR(clear_module_state->__pyx_codeobj__565);
  Py_CLEAR(clear_module_state->__pyx_codeobj__566);
  Py_CLEAR(clear_module_state->__pyx_codeobj__567);
  Py_CLEAR(clear_module_state->__pyx_codeobj__568);
  Py_CLEAR(clear_module_state->__pyx_codeobj__569);
  Py_CLEAR(clear_module_state->__pyx_codeobj__570);
  Py_CLEAR(clear_module_state->__pyx_codeobj__571);
  Py_CLEAR(clear_module_state->__pyx_codeobj__572);
  Py_CLEAR(clear_module_state->__pyx_codeobj__573);
  Py_CLEAR(clear_module_state->__pyx_codeobj__574);
  Py_CLEAR(clear_module_state->__pyx_codeobj__575);
  Py_CLEAR(clear_module_state->__pyx_codeobj__576);
  Py_CLEAR(clear_module_state->__pyx_codeobj__577);
  Py_CLEAR(clear_module_state->__pyx_codeobj__578);
  Py_CLEAR(clear_module_state->__pyx_codeobj__579);
  Py_CLEAR(clear_module_state->__pyx_codeobj__580);
  Py_CLEAR(clear_module_state->__pyx_codeobj__581);
  Py_CLEAR(clear_module_state->__pyx_codeobj__582);
  Py_CLEAR(clear_module_state->__pyx_codeobj__583);
  Py_CLEAR(clear_module_state->__pyx_codeobj__584);
  Py_CLEAR(clear_module_state->__pyx_codeobj__585);
  Py_CLEAR(clear_module_state->__pyx_codeobj__586);
  Py_CLEAR(clear_module_state->__pyx_codeobj__587);
  Py_CLEAR(clear_module_state->__pyx_codeobj__588);
  Py_CLEAR(clear_module_state->__pyx_codeobj__589);
  Py_CLEAR(clear_module_state->__pyx_codeobj__590);
  Py_CLEAR(clear_module_state->__pyx_codeobj__591);
  Py_CLEAR(clear_module_state->__pyx_codeobj__592);
  Py_CLEAR(clear_module_state->__pyx_codeobj__593);
  Py_CLEAR(clear_module_state->__pyx_codeobj__594);
  Py_CLEAR(clear_module_state->__pyx_codeobj__595);
  Py_CLEAR(clear_module_state->__pyx_codeobj__596);
  Py_CLEAR(clear_module_state->__pyx_codeobj__597);
  Py_CLEAR(clear_module_state->__pyx_codeobj__598);
  Py_CLEAR(clear_module_state->__pyx_codeobj__599);
  Py_CLEAR(clear_module_state->__pyx_codeobj__600);
  Py_CLEAR(clear_module_state->__pyx_codeobj__601);
  Py_CLEAR(clear_module_state->__pyx_codeobj__602);
  Py_CLEAR(clear_module_state->__pyx_codeobj__603);
  Py_CLEAR(clear_module_state->__pyx_codeobj__604);
  Py_CLEAR(clear_module_state->__pyx_codeobj__605);
  Py_CLEAR(clear_module_state->__pyx_codeobj__606);
  Py_CLEAR(clear_module_state->__pyx_codeobj__607);
  Py_CLEAR(clear_module_state->__pyx_codeobj__608);
  Py_CLEAR(clear_module_state->__pyx_codeobj__609);
  Py_CLEAR(clear_module_state->__pyx_codeobj__610);
  Py_CLEAR(clear_module_state->__pyx_codeobj__611);
  Py_CLEAR(clear_module_state->__pyx_codeobj__612);
  Py_CLEAR(clear_module_state->__pyx_codeobj__613);
  Py_CLEAR(clear_module_state->__pyx_codeobj__614);
  Py_CLEAR(clear_module_state->__pyx_codeobj__615);
  Py_CLEAR(clear_module_state->__pyx_codeobj__616);
  Py_CLEAR(clear_module_state->__pyx_codeobj__617);
  Py_CLEAR(clear_module_state->__pyx_codeobj__618);
  Py_CLEAR(clear_module_state->__pyx_codeobj__619);
  Py_CLEAR(clear_module_state->__pyx_codeobj__620);
  Py_CLEAR(clear_module_state->__pyx_codeobj__621);
  Py_CLEAR(clear_module_state->__pyx_codeobj__622);
  Py_CLEAR(clear_module_state->__pyx_codeobj__623);
  Py_CLEAR(clear_module_state->__pyx_codeobj__624);
  Py_CLEAR(clear_module_state->__pyx_codeobj__625);
  Py_CLEAR(clear_module_state->__pyx_codeobj__626);
  Py_CLEAR(clear_module_state->__pyx_codeobj__627);
  Py_CLEAR(clear_module_state->__pyx_codeobj__628);
  Py_CLEAR(clear_module_state->__pyx_codeobj__629);
  Py_CLEAR(clear_module_state->__pyx_codeobj__630);
  Py_CLEAR(clear_module_state->__pyx_codeobj__631);
  Py_CLEAR(clear_module_state->__pyx_codeobj__632);
  Py_CLEAR(clear_module_state->__pyx_codeobj__633);
  Py_CLEAR(clear_module_state->__pyx_codeobj__634);
  Py_CLEAR(clear_module_state->__pyx_codeobj__635);
  Py_CLEAR(clear_module_state->__pyx_codeobj__636);
  Py_CLEAR(clear_module_state->__pyx_codeobj__637);
  Py_CLEAR(clear_module_state->__pyx_codeobj__638);
  Py_CLEAR(clear_module_state->__pyx_codeobj__639);
  Py_CLEAR(clear_module_state->__pyx_codeobj__640);
  Py_CLEAR(clear_module_state->__pyx_codeobj__641);
  Py_CLEAR(clear_module_state->__pyx_codeobj__642);
  Py_CLEAR(clear_module_state->__pyx_codeobj__643);
  Py_CLEAR(clear_module_state->__pyx_codeobj__644);
  Py_CLEAR(clear_module_state->__pyx_codeobj__645);
  Py_CLEAR(clear_module_state->__pyx_codeobj__646);
  Py_CLEAR(clear_module_state->__pyx_codeobj__647);
  Py_CLEAR(clear_module_state->__pyx_codeobj__648);
  Py_CLEAR(clear_module_state->__pyx_codeobj__649);
  Py_CLEAR(clear_module_state->__pyx_codeobj__650);
  Py_CLEAR(clear_module_state->__pyx_codeobj__651);
  Py_CLEAR(clear_module_state->__pyx_codeobj__652);
  Py_CLEAR(clear_module_state->__pyx_codeobj__653);
  Py_CLEAR(clear_module_state->__pyx_codeobj__654);
  Py_CLEAR(clear_module_state->__pyx_codeobj__655);
  Py_CLEAR(clear_module_state->__pyx_codeobj__656);
  Py_CLEAR(clear_module_state->__pyx_codeobj__657);
  Py_CLEAR(clear_module_state->__pyx_codeobj__658);
  Py_CLEAR(clear_module_state->__pyx_codeobj__659);
  Py_CLEAR(clear_module_state->__pyx_codeobj__660);
  Py_CLEAR(clear_module_state->__pyx_codeobj__661);
  Py_CLEAR(clear_module_state->__pyx_codeobj__662);
  Py_CLEAR(clear_module_state->__pyx_codeobj__663);
  Py_CLEAR(clear_module_state->__pyx_codeobj__664);
  Py_CLEAR(clear_module_state->__pyx_codeobj__665);
  Py_CLEAR(clear_module_state->__pyx_codeobj__666);
  Py_CLEAR(clear_module_state->__pyx_codeobj__667);
  Py_CLEAR(clear_module_state->__pyx_codeobj__668);
  Py_CLEAR(clear_module_state->__pyx_codeobj__669);
  Py_CLEAR(clear_module_state->__pyx_codeobj__670);
  Py_CLEAR(clear_module_state->__pyx_codeobj__671);
  Py_CLEAR(clear_module_state->__pyx_codeobj__672);
  Py_CLEAR(clear_module_state->__pyx_codeobj__673);
  Py_CLEAR(clear_module_state->__pyx_codeobj__674);
  Py_CLEAR(clear_module_state->__pyx_codeobj__675);
  Py_CLEAR(clear_module_state->__pyx_codeobj__676);
  Py_CLEAR(clear_module_state->__pyx_codeobj__677);
  Py_CLEAR(clear_module_state->__pyx_codeobj__678);
  Py_CLEAR(clear_module_state->__pyx_codeobj__679);
  Py_CLEAR(clear_module_state->__pyx_codeobj__680);
  Py_CLEAR(clear_module_state->__pyx_codeobj__681);
  Py_CLEAR(clear_module_state->__pyx_codeobj__682);
  Py_CLEAR(clear_module_state->__pyx_codeobj__683);
  Py_CLEAR(clear_module_state->__pyx_codeobj__684);
  Py_CLEAR(clear_module_state->__pyx_codeobj__685);
  Py_CLEAR(clear_module_state->__pyx_codeobj__686);
  Py_CLEAR(clear_module_state->__pyx_codeobj__687);
  Py_CLEAR(clear_module_state->__pyx_codeobj__688);
  Py_CLEAR(clear_module_state->__pyx_codeobj__689);
  Py_CLEAR(clear_module_state->__pyx_codeobj__690);
  Py_CLEAR(clear_module_state->__pyx_codeobj__691);
  Py_CLEAR(clear_module_state->__pyx_codeobj__692);
  Py_CLEAR(clear_module_state->__pyx_codeobj__693);
  Py_CLEAR(clear_module_state->__pyx_codeobj__694);
  Py_CLEAR(clear_module_state->__pyx_codeobj__695);
  Py_CLEAR(clear_module_state->__pyx_codeobj__696);
  Py_CLEAR(clear_module_state->__pyx_codeobj__697);
  Py_CLEAR(clear_module_state->__pyx_codeobj__698);
  Py_CLEAR(clear_module_state->__pyx_codeobj__699);
  Py_CLEAR(clear_module_state->__pyx_codeobj__700);
  Py_CLEAR(clear_module_state->__pyx_codeobj__701);
  Py_CLEAR(clear_module_state->__pyx_codeobj__702);
  Py_CLEAR(clear_module_state->__pyx_codeobj__703);
  Py_CLEAR(clear_module_state->__pyx_codeobj__704);
  Py_CLEAR(clear_module_state->__pyx_codeobj__705);
  Py_CLEAR(clear_module_state->__pyx_codeobj__706);
  Py_CLEAR(clear_module_state->__pyx_codeobj__707);
  Py_CLEAR(clear_module_state->__pyx_codeobj__708);
  Py_CLEAR(clear_module_state->__pyx_codeobj__709);
  Py_CLEAR(clear_module_state->__pyx_codeobj__710);
  Py_CLEAR(clear_module_state->__pyx_codeobj__711);
  Py_CLEAR(clear_module_state->__pyx_codeobj__712);
  Py_CLEAR(clear_module_state->__pyx_codeobj__713);
  Py_CLEAR(clear_module_state->__pyx_codeobj__714);
  Py_CLEAR(clear_module_state->__pyx_codeobj__715);
  Py_CLEAR(clear_module_state->__pyx_codeobj__716);
  Py_CLEAR(clear_module_state->__pyx_codeobj__717);
  Py_CLEAR(clear_module_state->__pyx_codeobj__718);
  Py_CLEAR(clear_module_state->__pyx_codeobj__719);
  Py_CLEAR(clear_module_state->__pyx_codeobj__720);
  Py_CLEAR(clear_module_state->__pyx_codeobj__721);
  Py_CLEAR(clear_module_state->__pyx_codeobj__722);
  Py_CLEAR(clear_module_state->__pyx_codeobj__723);
  Py_CLEAR(clear_module_state->__pyx_codeobj__724);
  Py_CLEAR(clear_module_state->__pyx_codeobj__725);
  Py_CLEAR(clear_module_state->__pyx_codeobj__726);
  Py_CLEAR(clear_module_state->__pyx_codeobj__727);
  Py_CLEAR(clear_module_state->__pyx_codeobj__728);
  Py_CLEAR(clear_module_state->__pyx_codeobj__729);
  Py_CLEAR(clear_module_state->__pyx_codeobj__730);
  Py_CLEAR(clear_module_state->__pyx_codeobj__731);
  Py_CLEAR(clear_module_state->__pyx_codeobj__732);
  Py_CLEAR(clear_module_state->__pyx_codeobj__733);
  Py_CLEAR(clear_module_state->__pyx_codeobj__734);
  Py_CLEAR(clear_module_state->__pyx_codeobj__735);
  Py_CLEAR(clear_module_state->__pyx_codeobj__736);
  Py_CLEAR(clear_module_state->__pyx_codeobj__737);
  Py_CLEAR(clear_module_state->__pyx_codeobj__738);
  Py_CLEAR(clear_module_state->__pyx_codeobj__739);
  Py_CLEAR(clear_module_state->__pyx_codeobj__740);
  Py_CLEAR(clear_module_state->__pyx_codeobj__741);
  Py_CLEAR(clear_module_state->__pyx_codeobj__742);
  Py_CLEAR(clear_module_state->__pyx_codeobj__743);
  Py_CLEAR(clear_module_state->__pyx_codeobj__744);
  Py_CLEAR(clear_module_state->__pyx_codeobj__745);
  Py_CLEAR(clear_module_state->__pyx_codeobj__746);
  Py_CLEAR(clear_module_state->__pyx_codeobj__747);
  Py_CLEAR(clear_module_state->__pyx_codeobj__748);
  Py_CLEAR(clear_module_state->__pyx_codeobj__749);
  Py_CLEAR(clear_module_state->__pyx_codeobj__750);
  Py_CLEAR(clear_module_state->__pyx_codeobj__751);
  Py_CLEAR(clear_module_state->__pyx_codeobj__752);
  Py_CLEAR(clear_module_state->__pyx_codeobj__753);
  Py_CLEAR(clear_module_state->__pyx_codeobj__754);
  Py_CLEAR(clear_module_state->__pyx_codeobj__755);
  Py_CLEAR(clear_module_state->__pyx_codeobj__756);
  Py_CLEAR(clear_module_state->__pyx_codeobj__757);
  Py_CLEAR(clear_module_state->__pyx_codeobj__758);
  Py_CLEAR(clear_module_state->__pyx_codeobj__759);
  Py_CLEAR(clear_module_state->__pyx_codeobj__760);
  Py_CLEAR(clear_module_state->__pyx_codeobj__761);
  Py_CLEAR(clear_module_state->__pyx_codeobj__762);
  Py_CLEAR(clear_module_state->__pyx_codeobj__763);
  Py_CLEAR(clear_module_state->__pyx_codeobj__764);
  Py_CLEAR(clear_module_state->__pyx_codeobj__765);
  Py_CLEAR(clear_module_state->__pyx_codeobj__766);
  Py_CLEAR(clear_module_state->__pyx_codeobj__767);
  Py_CLEAR(clear_module_state->__pyx_codeobj__768);
  Py_CLEAR(clear_module_state->__pyx_codeobj__769);
  Py_CLEAR(clear_module_state->__pyx_codeobj__770);
  Py_CLEAR(clear_module_state->__pyx_codeobj__771);
  Py_CLEAR(clear_module_state->__pyx_codeobj__772);
  Py_CLEAR(clear_module_state->__pyx_codeobj__773);
  Py_CLEAR(clear_module_state->__pyx_codeobj__774);
  Py_CLEAR(clear_module_state->__pyx_codeobj__775);
  Py_CLEAR(clear_module_state->__pyx_codeobj__776);
  Py_CLEAR(clear_module_state->__pyx_codeobj__777);
  Py_CLEAR(clear_module_state->__pyx_codeobj__778);
  Py_CLEAR(clear_module_state->__pyx_codeobj__779);
  Py_CLEAR(clear_module_state->__pyx_codeobj__780);
  Py_CLEAR(clear_module_state->__pyx_codeobj__781);
  Py_CLEAR(clear_module_state->__pyx_codeobj__782);
  Py_CLEAR(clear_module_state->__pyx_codeobj__783);
  Py_CLEAR(clear_module_state->__pyx_codeobj__784);
  Py_CLEAR(clear_module_state->__pyx_codeobj__785);
  Py_CLEAR(clear_module_state->__pyx_codeobj__786);
  Py_CLEAR(clear_module_state->__pyx_codeobj__787);
  Py_CLEAR(clear_module_state->__pyx_codeobj__788);
  Py_CLEAR(clear_module_state->__pyx_codeobj__789);
  Py_CLEAR(clear_module_state->__pyx_codeobj__790);
  Py_CLEAR(clear_module_state->__pyx_codeobj__791);
  Py_CLEAR(clear_module_state->__pyx_codeobj__792);
  Py_CLEAR(clear_module_state->__pyx_codeobj__793);
  Py_CLEAR(clear_module_state->__pyx_codeobj__794);
  Py_CLEAR(clear_module_state->__pyx_codeobj__795);
  Py_CLEAR(clear_module_state->__pyx_codeobj__796);
  Py_CLEAR(clear_module_state->__pyx_codeobj__797);
  Py_CLEAR(clear_module_state->__pyx_codeobj__798);
  Py_CLEAR(clear_module_state->__pyx_codeobj__799);
  Py_CLEAR(clear_module_state->__pyx_codeobj__800);
  Py_CLEAR(clear_module_state->__pyx_codeobj__801);
  Py_CLEAR(clear_module_state->__pyx_codeobj__802);
  Py_CLEAR(clear_module_state->__pyx_codeobj__803);
  Py_CLEAR(clear_module_state->__pyx_codeobj__804);
  Py_CLEAR(clear_module_state->__pyx_codeobj__805);
  Py_CLEAR(clear_module_state->__pyx_codeobj__806);
  Py_CLEAR(clear_module_state->__pyx_codeobj__807);
  Py_CLEAR(clear_module_state->__pyx_codeobj__808);
  Py_CLEAR(clear_module_state->__pyx_codeobj__809);
  Py_CLEAR(clear_module_state->__pyx_codeobj__810);
  Py_CLEAR(clear_module_state->__pyx_codeobj__811);
  Py_CLEAR(clear_module_state->__pyx_codeobj__812);
  Py_CLEAR(clear_module_state->__pyx_codeobj__813);
  Py_CLEAR(clear_module_state->__pyx_codeobj__814);
  Py_CLEAR(clear_module_state->__pyx_codeobj__815);
  Py_CLEAR(clear_module_state->__pyx_codeobj__816);
  Py_CLEAR(clear_module_state->__pyx_codeobj__817);
  Py_CLEAR(clear_module_state->__pyx_codeobj__818);
  Py_CLEAR(clear_module_state->__pyx_codeobj__819);
  Py_CLEAR(clear_module_state->__pyx_codeobj__820);
  Py_CLEAR(clear_module_state->__pyx_codeobj__821);
  Py_CLEAR(clear_module_state->__pyx_codeobj__822);
  Py_CLEAR(clear_module_state->__pyx_codeobj__823);
  Py_CLEAR(clear_module_state->__pyx_codeobj__824);
  Py_CLEAR(clear_module_state->__pyx_codeobj__825);
  Py_CLEAR(clear_module_state->__pyx_codeobj__826);
  Py_CLEAR(clear_module_state->__pyx_codeobj__827);
  Py_CLEAR(clear_module_state->__pyx_codeobj__828);
  Py_CLEAR(clear_module_state->__pyx_codeobj__829);
  Py_CLEAR(clear_module_state->__pyx_codeobj__830);
  Py_CLEAR(clear_module_state->__pyx_codeobj__831);
  Py_CLEAR(clear_module_state->__pyx_codeobj__832);
  Py_CLEAR(clear_module_state->__pyx_codeobj__833);
  Py_CLEAR(clear_module_state->__pyx_codeobj__834);
  Py_CLEAR(clear_module_state->__pyx_codeobj__835);
  Py_CLEAR(clear_module_state->__pyx_codeobj__836);
  Py_CLEAR(clear_module_state->__pyx_codeobj__837);
  Py_CLEAR(clear_module_state->__pyx_codeobj__838);
  Py_CLEAR(clear_module_state->__pyx_codeobj__839);
  Py_CLEAR(clear_module_state->__pyx_codeobj__840);
  Py_CLEAR(clear_module_state->__pyx_codeobj__841);
  Py_CLEAR(clear_module_state->__pyx_codeobj__842);
  Py_CLEAR(clear_module_state->__pyx_codeobj__843);
  Py_CLEAR(clear_module_state->__pyx_codeobj__844);
  Py_CLEAR(clear_module_state->__pyx_codeobj__845);
  Py_CLEAR(clear_module_state->__pyx_codeobj__846);
  Py_CLEAR(clear_module_state->__pyx_codeobj__847);
  Py_CLEAR(clear_module_state->__pyx_codeobj__848);
  Py_CLEAR(clear_module_state->__pyx_codeobj__849);
  Py_CLEAR(clear_module_state->__pyx_codeobj__850);
  Py_CLEAR(clear_module_state->__pyx_codeobj__851);
  Py_CLEAR(clear_module_state->__pyx_codeobj__852);
  Py_CLEAR(clear_module_state->__pyx_codeobj__853);
  Py_CLEAR(clear_module_state->__pyx_codeobj__854);
  Py_CLEAR(clear_module_state->__pyx_codeobj__855);
  Py_CLEAR(clear_module_state->__pyx_codeobj__856);
  Py_CLEAR(clear_module_state->__pyx_codeobj__857);
  Py_CLEAR(clear_module_state->__pyx_codeobj__858);
  Py_CLEAR(clear_module_state->__pyx_codeobj__859);
  Py_CLEAR(clear_module_state->__pyx_codeobj__860);
  Py_CLEAR(clear_module_state->__pyx_codeobj__861);
  Py_CLEAR(clear_module_state->__pyx_codeobj__862);
  Py_CLEAR(clear_module_state->__pyx_codeobj__863);
  Py_CLEAR(clear_module_state->__pyx_codeobj__864);
  Py_CLEAR(clear_module_state->__pyx_codeobj__865);
  Py_CLEAR(clear_module_state->__pyx_codeobj__866);
  Py_CLEAR(clear_module_state->__pyx_codeobj__867);
  Py_CLEAR(clear_module_state->__pyx_codeobj__868);
  Py_CLEAR(clear_module_state->__pyx_codeobj__869);
  Py_CLEAR(clear_module_state->__pyx_codeobj__870);
  Py_CLEAR(clear_module_state->__pyx_codeobj__871);
  Py_CLEAR(clear_module_state->__pyx_codeobj__872);
  Py_CLEAR(clear_module_state->__pyx_codeobj__873);
  Py_CLEAR(clear_module_state->__pyx_codeobj__874);
  Py_CLEAR(clear_module_state->__pyx_codeobj__875);
  Py_CLEAR(clear_module_state->__pyx_codeobj__876);
  Py_CLEAR(clear_module_state->__pyx_codeobj__877);
  Py_CLEAR(clear_module_state->__pyx_codeobj__878);
  Py_CLEAR(clear_module_state->__pyx_codeobj__879);
  Py_CLEAR(clear_module_state->__pyx_codeobj__880);
  Py_CLEAR(clear_module_state->__pyx_codeobj__881);
  Py_CLEAR(clear_module_state->__pyx_codeobj__882);
  Py_CLEAR(clear_module_state->__pyx_codeobj__883);
  Py_CLEAR(clear_module_state->__pyx_codeobj__884);
  Py_CLEAR(clear_module_state->__pyx_codeobj__885);
  Py_CLEAR(clear_module_state->__pyx_codeobj__886);
  Py_CLEAR(clear_module_state->__pyx_codeobj__887);
  Py_CLEAR(clear_module_state->__pyx_codeobj__888);
  Py_CLEAR(clear_module_state->__pyx_codeobj__889);
  Py_CLEAR(clear_module_state->__pyx_codeobj__890);
  Py_CLEAR(clear_module_state->__pyx_codeobj__891);
  Py_CLEAR(clear_module_state->__pyx_codeobj__892);
  Py_CLEAR(clear_module_state->__pyx_codeobj__893);
  Py_CLEAR(clear_module_state->__pyx_codeobj__894);
  Py_CLEAR(clear_module_state->__pyx_codeobj__895);
  Py_CLEAR(clear_module_state->__pyx_codeobj__896);
  Py_CLEAR(clear_module_state->__pyx_codeobj__897);
  Py_CLEAR(clear_module_state->__pyx_codeobj__898);
  Py_CLEAR(clear_module_state->__pyx_codeobj__899);
  Py_CLEAR(clear_module_state->__pyx_codeobj__900);
  Py_CLEAR(clear_module_state->__pyx_codeobj__901);
  Py_CLEAR(clear_module_state->__pyx_codeobj__902);
  Py_CLEAR(clear_module_state->__pyx_codeobj__903);
  Py_CLEAR(clear_module_state->__pyx_codeobj__904);
  Py_CLEAR(clear_module_state->__pyx_codeobj__905);
  Py_CLEAR(clear_module_state->__pyx_codeobj__906);
  Py_CLEAR(clear_module_state->__pyx_codeobj__907);
  Py_CLEAR(clear_module_state->__pyx_codeobj__908);
  Py_CLEAR(clear_module_state->__pyx_codeobj__909);
  Py_CLEAR(clear_module_state->__pyx_codeobj__910);
  Py_CLEAR(clear_module_state->__pyx_codeobj__911);
  Py_CLEAR(clear_module_state->__pyx_codeobj__912);
  Py_CLEAR(clear_module_state->__pyx_codeobj__913);
  Py_CLEAR(clear_module_state->__pyx_codeobj__914);
  Py_CLEAR(clear_module_state->__pyx_codeobj__915);
  Py_CLEAR(clear_module_state->__pyx_codeobj__916);
  Py_CLEAR(clear_module_state->__pyx_codeobj__917);
  Py_CLEAR(clear_module_state->__pyx_codeobj__918);
  Py_CLEAR(clear_module_state->__pyx_codeobj__919);
  Py_CLEAR(clear_module_state->__pyx_codeobj__920);
  Py_CLEAR(clear_module_state->__pyx_codeobj__921);
  Py_CLEAR(clear_module_state->__pyx_codeobj__922);
  Py_CLEAR(clear_module_state->__pyx_codeobj__923);
  Py_CLEAR(clear_module_state->__pyx_codeobj__924);
  Py_CLEAR(clear_module_state->__pyx_codeobj__925);
  Py_CLEAR(clear_module_state->__pyx_codeobj__926);
  Py_CLEAR(clear_module_state->__pyx_codeobj__927);
  Py_CLEAR(clear_module_state->__pyx_codeobj__928);
  Py_CLEAR(clear_module_state->__pyx_codeobj__929);
  Py_CLEAR(clear_module_state->__pyx_codeobj__930);
  Py_CLEAR(clear_module_state->__pyx_codeobj__931);
  Py_CLEAR(clear_module_state->__pyx_codeobj__932);
  Py_CLEAR(clear_module_state->__pyx_codeobj__933);
  Py_CLEAR(clear_module_state->__pyx_codeobj__934);
  Py_CLEAR(clear_module_state->__pyx_codeobj__935);
  Py_CLEAR(clear_module_state->__pyx_codeobj__936);
  Py_CLEAR(clear_module_state->__pyx_codeobj__937);
  Py_CLEAR(clear_module_state->__pyx_codeobj__938);
  Py_CLEAR(clear_module_state->__pyx_codeobj__939);
  Py_CLEAR(clear_module_state->__pyx_codeobj__940);
  Py_CLEAR(clear_module_state->__pyx_codeobj__941);
  Py_CLEAR(clear_module_state->__pyx_codeobj__942);
  Py_CLEAR(clear_module_state->__pyx_codeobj__943);
  Py_CLEAR(clear_module_state->__pyx_codeobj__944);
  Py_CLEAR(clear_module_state->__pyx_codeobj__945);
  Py_CLEAR(clear_module_state->__pyx_codeobj__946);
  Py_CLEAR(clear_module_state->__pyx_codeobj__947);
  Py_CLEAR(clear_module_state->__pyx_codeobj__948);
  Py_CLEAR(clear_module_state->__pyx_codeobj__949);
  Py_CLEAR(clear_module_state->__pyx_codeobj__950);
  Py_CLEAR(clear_module_state->__pyx_codeobj__951);
  Py_CLEAR(clear_module_state->__pyx_codeobj__952);
  Py_CLEAR(clear_module_state->__pyx_codeobj__953);
  Py_CLEAR(clear_module_state->__pyx_codeobj__954);
  Py_CLEAR(clear_module_state->__pyx_codeobj__955);
  Py_CLEAR(clear_module_state->__pyx_codeobj__956);
  Py_CLEAR(clear_module_state->__pyx_codeobj__957);
  Py_CLEAR(clear_module_state->__pyx_codeobj__958);
  Py_CLEAR(clear_module_state->__pyx_codeobj__959);
  Py_CLEAR(clear_module_state->__pyx_codeobj__960);
  Py_CLEAR(clear_module_state->__pyx_codeobj__961);
  Py_CLEAR(clear_module_state->__pyx_codeobj__962);
  Py_CLEAR(clear_module_state->__pyx_codeobj__963);
  Py_CLEAR(clear_module_state->__pyx_codeobj__964);
  Py_CLEAR(clear_module_state->__pyx_codeobj__965);
  Py_CLEAR(clear_module_state->__pyx_codeobj__966);
  Py_CLEAR(clear_module_state->__pyx_codeobj__967);
  Py_CLEAR(clear_module_state->__pyx_codeobj__968);
  Py_CLEAR(clear_module_state->__pyx_codeobj__969);
  Py_CLEAR(clear_module_state->__pyx_codeobj__970);
  Py_CLEAR(clear_module_state->__pyx_codeobj__971);
  Py_CLEAR(clear_module_state->__pyx_codeobj__972);
  Py_CLEAR(clear_module_state->__pyx_codeobj__973);
  Py_CLEAR(clear_module_state->__pyx_codeobj__974);
  Py_CLEAR(clear_module_state->__pyx_codeobj__975);
  Py_CLEAR(clear_module_state->__pyx_codeobj__976);
  Py_CLEAR(clear_module_state->__pyx_codeobj__977);
  Py_CLEAR(clear_module_state->__pyx_codeobj__978);
  Py_CLEAR(clear_module_state->__pyx_codeobj__979);
  Py_CLEAR(clear_module_state->__pyx_codeobj__980);
  Py_CLEAR(clear_module_state->__pyx_codeobj__981);
  Py_CLEAR(clear_module_state->__pyx_codeobj__982);
  Py_CLEAR(clear_module_state->__pyx_codeobj__983);
  Py_CLEAR(clear_module_state->__pyx_codeobj__984);
  Py_CLEAR(clear_module_state->__pyx_codeobj__985);
  Py_CLEAR(clear_module_state->__pyx_codeobj__986);
  Py_CLEAR(clear_module_state->__pyx_codeobj__987);
  Py_CLEAR(clear_module_state->__pyx_codeobj__988);
  Py_CLEAR(clear_module_state->__pyx_codeobj__989);
  Py_CLEAR(clear_module_state->__pyx_codeobj__990);
  Py_CLEAR(clear_module_state->__pyx_codeobj__991);
  Py_CLEAR(clear_module_state->__pyx_codeobj__992);
  Py_CLEAR(clear_module_state->__pyx_codeobj__993);
  Py_CLEAR(clear_module_state->__pyx_codeobj__994);
  Py_CLEAR(clear_module_state->__pyx_codeobj__995);
  Py_CLEAR(clear_module_state->__pyx_codeobj__996);
  Py_CLEAR(clear_module_state->__pyx_codeobj__997);
  Py_CLEAR(clear_module_state->__pyx_codeobj__998);
  Py_CLEAR(clear_module_state->__pyx_codeobj__999);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1000);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1001);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1002);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1003);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1004);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1005);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1006);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1007);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1008);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1009);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1010);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1011);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1012);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1013);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1014);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1015);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1016);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1017);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1018);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1019);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1020);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1021);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1022);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1023);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1024);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1025);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1026);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1027);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1028);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1029);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1030);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1031);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1032);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1033);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1034);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1035);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1036);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1037);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1038);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1039);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1040);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1041);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1042);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1043);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1044);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1045);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1046);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1047);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1048);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1049);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1050);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1051);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1052);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1053);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1054);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1055);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1056);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1057);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1058);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1059);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1060);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1061);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1062);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1063);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1064);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1065);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1066);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1067);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1068);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1069);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1070);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1071);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1072);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1073);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1074);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1075);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1076);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1077);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1078);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1079);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1080);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1081);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1082);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1083);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1084);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1085);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1086);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1087);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1088);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1089);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1090);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1091);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1092);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1093);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1094);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1095);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1096);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1097);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1098);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1099);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1101);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1102);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1103);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1105);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1107);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1109);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1110);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1111);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1112);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1113);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1114);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1115);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1116);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1117);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1118);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1119);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1120);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1121);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1122);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1123);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1125);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1126);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1127);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1128);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1129);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1130);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1131);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1132);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1133);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1134);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1135);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1136);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1137);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1138);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1139);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1140);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1141);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1142);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1143);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1144);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1145);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1146);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1147);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1148);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1149);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1150);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1151);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1152);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1153);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1154);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1155);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1156);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1157);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1158);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1159);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1160);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1161);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1162);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1163);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1164);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1165);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1166);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1167);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1168);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1169);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1170);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1171);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1172);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1173);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1174);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1175);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1176);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1177);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1178);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1179);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1180);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1181);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1182);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1183);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1184);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1185);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1186);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1187);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1188);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1189);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1190);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1191);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1192);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1193);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1194);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1195);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1196);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1197);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1198);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1199);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1200);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1201);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1202);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1203);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1204);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1206);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1207);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1208);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1209);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1210);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1211);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1212);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1213);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1214);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1215);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1216);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1217);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1218);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1219);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1220);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1221);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1223);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1225);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1226);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1227);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1228);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1229);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1230);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1231);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1232);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1233);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1234);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1236);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1237);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1240);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1241);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1242);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1243);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1244);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1245);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1246);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1247);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1248);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1249);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1250);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1252);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1254);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1256);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1258);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1259);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1260);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1261);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1262);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1263);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1264);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1265);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1266);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1267);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1268);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1269);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1271);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1273);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1274);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1275);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1276);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1277);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1278);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1279);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1280);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1281);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1283);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1284);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1285);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1286);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1287);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1288);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1289);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1290);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1291);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1292);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1293);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1294);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1295);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1296);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1297);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1298);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1299);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1300);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1301);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1302);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1303);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1304);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1305);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1306);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1307);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1308);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1309);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1310);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1311);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1312);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1313);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1314);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1315);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1316);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1317);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1318);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1319);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1320);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1321);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1322);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1323);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1324);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1325);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1326);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1327);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1328);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1329);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1330);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1331);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1332);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1333);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1334);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1335);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1336);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1337);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1338);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1339);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1340);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1341);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1342);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1343);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1344);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1345);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1346);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1347);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1348);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1349);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1350);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1351);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1352);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1353);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1354);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1355);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1356);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1357);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1358);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1359);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1360);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1361);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1362);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1363);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1364);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1365);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1366);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1367);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1368);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1369);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1370);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1371);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1372);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1373);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1374);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1375);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1376);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1377);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1378);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1379);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1380);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1381);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1382);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1383);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1384);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1385);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1386);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1387);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1388);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1389);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1390);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1391);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1392);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1393);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1394);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1395);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1396);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1397);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1398);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1399);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1400);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1401);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1402);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1403);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1404);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1405);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1406);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1407);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1408);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1409);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1410);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1411);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1412);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1413);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1414);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1415);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1416);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1417);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1418);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1419);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1420);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1421);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1422);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1423);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1424);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1425);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1426);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1427);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1428);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1429);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1430);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1431);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1432);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1433);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1434);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1435);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1436);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1437);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1438);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1439);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1440);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1441);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1442);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1443);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1444);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1445);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1446);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1447);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1448);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1449);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1450);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1451);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1452);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1453);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1454);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1455);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1456);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1457);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1458);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1459);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1460);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1461);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1462);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1463);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1464);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1465);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1466);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1467);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1468);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1469);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1470);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1471);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1472);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1473);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1474);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1475);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1476);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1477);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1478);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1479);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1480);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1481);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1482);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1483);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1484);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1485);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1486);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1487);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1488);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1489);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1490);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1491);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1492);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1493);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1494);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1495);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1496);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1497);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1498);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1499);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1500);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1501);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1502);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1503);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1504);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1505);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1506);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1507);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1508);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1509);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1510);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1511);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1512);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1513);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1514);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1515);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1516);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1517);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1518);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1519);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1520);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1521);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1522);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1523);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1524);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1525);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1526);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1527);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1528);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1529);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1530);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1531);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1532);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1533);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1534);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1535);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1536);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1537);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1538);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1539);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1540);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1541);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1542);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1543);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1544);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1545);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1546);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1547);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1548);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1549);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1550);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1551);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1552);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1553);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1554);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1555);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1556);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1557);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1558);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1559);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1560);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1561);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1562);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1563);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1564);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1565);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1566);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1567);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1568);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1569);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1570);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1571);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1572);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1573);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1574);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1575);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1576);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1577);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1578);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1579);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1580);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1581);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1582);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1583);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1584);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1585);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1586);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1587);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1588);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1589);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1590);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1591);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1592);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1593);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1594);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1595);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1596);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1597);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1598);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1599);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1600);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1601);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1602);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1603);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1604);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1605);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1606);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1607);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1608);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1609);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1610);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1611);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1612);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1613);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1614);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1615);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1616);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1617);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1618);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1619);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1620);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1621);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1622);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1623);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1624);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1625);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1626);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1628);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1629);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1631);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1633);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1634);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1635);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1636);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1638);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1640);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1642);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1644);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1647);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1648);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1649);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1652);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1654);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1701);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1703);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1704);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1705);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1706);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1708);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1709);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1710);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1711);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1712);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1714);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1715);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1716);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1717);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1718);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1720);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1723);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1725);
  Py_CLEAR(clear_module_state->__pyx_codeobj__1727);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);
  Py_VISIT(traverse_module_state->__pyx_type_6giacpy_6giacpy_GiacMethods_base);
  Py_VISIT(traverse_module_state->__pyx_ptype_6giacpy_6giacpy_Pygen);
  Py_VISIT(traverse_module_state->__pyx_type_6giacpy_6giacpy_Pygen);
  Py_VISIT(traverse_module_state->__pyx_ptype_6giacpy_6giacpy_GiacSetting);
  Py_VISIT(traverse_module_state->__pyx_type_6giacpy_6giacpy_GiacSetting);
  Py_VISIT(traverse_module_state->__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__);
  Py_VISIT(traverse_module_state->__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__);
  Py_VISIT(traverse_module_state->__pyx_n_s_A);
  Py_VISIT(traverse_module_state->__pyx_n_s_ACOSH);
  Py_VISIT(traverse_module_state->__pyx_n_s_ACOT);
  Py_VISIT(traverse_module_state->__pyx_n_s_ACSC);
  Py_VISIT(traverse_module_state->__pyx_n_s_ASEC);
  Py_VISIT(traverse_module_state->__pyx_n_s_ASIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_ASINH);
  Py_VISIT(traverse_module_state->__pyx_n_s_ATAN);
  Py_VISIT(traverse_module_state->__pyx_n_s_ATANH);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Airy_Ai);
  Py_VISIT(traverse_module_state->__pyx_n_s_Airy_Bi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Angstrom);
  Py_VISIT(traverse_module_state->__pyx_n_s_Archive);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Archive_a_Pygen_element_to_a_fi);
  Py_VISIT(traverse_module_state->__pyx_n_s_BesselJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_BesselY);
  Py_VISIT(traverse_module_state->__pyx_n_s_Beta);
  Py_VISIT(traverse_module_state->__pyx_n_s_BlockDiagonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_Bq);
  Py_VISIT(traverse_module_state->__pyx_n_s_Btu);
  Py_VISIT(traverse_module_state->__pyx_n_s_COND);
  Py_VISIT(traverse_module_state->__pyx_n_s_COS);
  Py_VISIT(traverse_module_state->__pyx_n_s_COSH);
  Py_VISIT(traverse_module_state->__pyx_n_s_COT);
  Py_VISIT(traverse_module_state->__pyx_n_s_CSC);
  Py_VISIT(traverse_module_state->__pyx_n_s_CST);
  Py_VISIT(traverse_module_state->__pyx_n_s_Celsius2Fahrenheit);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ci);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ci_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_ClrDraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_ClrGraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_ClrIO);
  Py_VISIT(traverse_module_state->__pyx_n_s_Col);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Convert_a_giac_integer_type_Pyg);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Convert_a_giac_real_to_a_Python);
  Py_VISIT(traverse_module_state->__pyx_n_s_CopyVar);
  Py_VISIT(traverse_module_state->__pyx_n_s_CyclePic);
  Py_VISIT(traverse_module_state->__pyx_n_s_DIGITS);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_COMPLEX);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_FLOAT);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_FUNC);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_IDENT);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_INT);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_LIST);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_RAT);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_STRING);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_SYMBOLIC);
  Py_VISIT(traverse_module_state->__pyx_n_s_DOM_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_DelFold);
  Py_VISIT(traverse_module_state->__pyx_n_s_DelVar);
  Py_VISIT(traverse_module_state->__pyx_n_s_Det);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dialog);
  Py_VISIT(traverse_module_state->__pyx_n_s_Digits);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dirac);
  Py_VISIT(traverse_module_state->__pyx_n_s_Disp);
  Py_VISIT(traverse_module_state->__pyx_n_s_DispG);
  Py_VISIT(traverse_module_state->__pyx_n_s_DispHome);
  Py_VISIT(traverse_module_state->__pyx_n_s_DrawFunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_DrawInv);
  Py_VISIT(traverse_module_state->__pyx_n_s_DrawParm);
  Py_VISIT(traverse_module_state->__pyx_n_s_DrawPol);
  Py_VISIT(traverse_module_state->__pyx_n_s_DrawSlp);
  Py_VISIT(traverse_module_state->__pyx_n_s_DropDown);
  Py_VISIT(traverse_module_state->__pyx_n_s_DrwCtour);
  Py_VISIT(traverse_module_state->__pyx_n_s_ERROR);
  Py_VISIT(traverse_module_state->__pyx_n_s_EXP);
  Py_VISIT(traverse_module_state->__pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ei);
  Py_VISIT(traverse_module_state->__pyx_n_s_EndDlog);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Error_executing_code_in_Giac_COD);
  Py_VISIT(traverse_module_state->__pyx_n_s_F);
  Py_VISIT(traverse_module_state->__pyx_n_s_FALSE);
  Py_VISIT(traverse_module_state->__pyx_n_s_F_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_F_OK);
  Py_VISIT(traverse_module_state->__pyx_n_s_Factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_Fahrenheit2Celsius);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Failed_to_start_a_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_False);
  Py_VISIT(traverse_module_state->__pyx_n_s_Fdy);
  Py_VISIT(traverse_module_state->__pyx_n_s_Fill);
  Py_VISIT(traverse_module_state->__pyx_n_s_Fourier);
  Py_VISIT(traverse_module_state->__pyx_n_s_G);
  Py_VISIT(traverse_module_state->__pyx_n_s_GF);
  Py_VISIT(traverse_module_state->__pyx_n_s_GIACNULL);
  Py_VISIT(traverse_module_state->__pyx_n_s_GIACPY_TMP_NAME05026807096929010);
  Py_VISIT(traverse_module_state->__pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Gal);
  Py_VISIT(traverse_module_state->__pyx_n_s_Gamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_Gcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GetFold);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___add);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___call);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___div);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___mul);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___neg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___pow);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction___truediv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction_htmlhelp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacFunction_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Airy_Ai);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Airy_Bi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Archive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_BesselJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_BesselY);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Beta);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_BlockDiagonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Ci);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Col);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_CopyVar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Dirac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Ei);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Fourier);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_GF);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Gamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Heaviside);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Heaviside2sign);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Hilbert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_JordanBlock);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_LU);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_LambertW);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Li);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_LineHorz);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_LineTan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_LineVert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_MSE);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Phi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Pi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Psi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_QR);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_RandSeed);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ReLU);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Row);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_SortA);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_SortD);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_UTPC);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_UTPF);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_UTPN);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_UTPT);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_VARS);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_VAS);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_VAS_positive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_Zeta);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_a2q);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_abcuv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_about);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_abs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_abscissa);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_accumulate_head);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acos2asin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acos2atan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acosh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acsc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_acyclic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_adaptive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_add_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_add_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_add_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_additionally);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_addtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_adjacency_matri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_adjoint_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_affix);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_algsubs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_algvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_all_trig_soluti);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_allpairs_distan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_alog10);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_altitude);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_angle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_angle_radian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_angleat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_angleatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ans);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_antiprism_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_approx);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arcLen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arccos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arccosh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arclen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arcsin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arcsinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arctan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arctanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_area);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_areaat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_areaatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_areaplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_arrivals);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_articulation_po);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_asin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_asin2acos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_asin2atan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_asinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_assign_edge_wei);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_assume);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_at);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_atan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_atan2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_atan2acos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_atan2asin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_atanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_atrig2ln);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_augment);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_auto_correlatio);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_autosimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_avance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_avgRC);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_axes);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_back);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_backward);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_baisse_crayon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bandwidth);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bar_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_barplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bartlett_hann_w);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_barycenter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_basis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_batons);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bellman_ford);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_berlekamp_masse);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bernoulli);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bernoulli_mod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_besselJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_besselY);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_betad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_betad_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_betad_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_betavariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_betweenness_cen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bezier);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bezout_entiers);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bezoutian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_biconnected_com);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_binomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_binomial_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_binomial_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bins);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bipartite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bipartite_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bisection_solve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bisector);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bit_depth);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bitand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bitor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bitxor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_blackman_harris);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_blackman_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_block_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_blockmatrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bohman_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_border);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_box_constraints);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_boxcar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_boxwhisker);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_brent_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_brown);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bspline);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_bvpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cFactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cSolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cZeros);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_camembert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_canonical_form);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_canonical_label);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cartesian_produ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cauchy);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cauchy_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cauchy_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cauchyd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cauchyd_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cauchyd_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ceil);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ceiling);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_center);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_center2interval);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_centered_cube);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_centered_tetrah);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cfactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cfsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_changebase);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_channel_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_channels);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_char);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_charpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chinrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquare);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquare_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquare_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquared);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquared_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquared_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chisquaret);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_choice);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cholesky);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chromatic_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chromatic_numbe);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_chromatic_polyn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_circumcircle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_classes);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_clear);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_clique_cover);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_clique_cover_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_clique_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_closeness_centr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cluster);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_clustering_coef);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_coeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_coeffs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_col);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colDim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colNorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colSwap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_coldim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_collect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colormap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_colswap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_comDenom);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_comb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_combine);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_comment);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_common_perpendi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_companion);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_compare);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_complete_binary);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_complete_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_complete_kary_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_complex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_complex_variabl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_complexroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_concat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cond);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_condensation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cone);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_confrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_conic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_conj);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_conjugate_equat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_conjugate_gradi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_connected);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_connected_compo);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cont);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_content);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_contourplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_contract_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_contract_subgra);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_convert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_convertir);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_convex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_convexhull);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_convolution);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_coordinates);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_correlation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cos2sintan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cosh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cosine_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cote);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_count_eq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_count_inf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_count_sup);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_courbe_parametr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_courbe_polaire);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_covariance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_covariance_corr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cpartfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_crationalroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_crayon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_createwav);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cross);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_crossP);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cross_correlati);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cross_entropy);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cross_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cross_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_crossproduct);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_csc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_csolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_csv2gen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cube);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cumSum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cumsum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cumulated_frequ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_curl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_current_sheet);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_curvature);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_curve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cyan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cycle2perm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cycle_basis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cycle_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cycleinv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cycles2permu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cyclotomic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_cylinder);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dash_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dashdot_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dashdotdot_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dayofweek);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_deSolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_debut_enregistr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_degree_centrali);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_degree_sequence);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_degrees);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_delcols);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_delete_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_delete_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_delete_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_delrows);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_deltalist);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_denom);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_densityplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_departures);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_derive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_deriver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_desolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dessine_tortue);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_det);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_det_minor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_developper);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_developper_tran);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dfc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dfc2f);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_diag);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_digraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dijkstra);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_directed);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_discard_edge_at);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_discard_graph_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_discard_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_disjoint_union);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_display);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_disque);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_disque_centre);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_distance2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_distanceat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_distanceatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_divergence);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_divide);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_divis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_division_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_divisors);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_divmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_divpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dnewton_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dodecahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_domain);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dotP);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dot_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dotprod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_pixel);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_polygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_draw_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_droit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_droite_tangente);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_duration);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_dwt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_e2r);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ecart_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ecart_type_popu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ecef2geodetic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ecm_factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_edge_connectivi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_egcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_egv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_egvl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eigVc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eigVl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eigenvals);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eigenvalues);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eigenvectors);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eigenvects);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_element);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eliminate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ellipse);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_emd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_entry);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_envelope);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_epsilon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_epsilon2zero);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_equal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_equal2diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_equal2list);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_equation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_equilateral_tri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_erf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_erfc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_est_permu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_euler);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_euler_gamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_euler_lagrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_eval_level);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_evala);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_evalb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_evalc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_evalf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_evalm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_even);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_evolute);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exact);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exbisector);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_excircle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_execute);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exp2list);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exp2pow);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exp2trig);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_expand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_expexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_expln);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponential);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponential_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponential_icd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponential_reg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponential_reg_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponentiald);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponentiald_cd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_exponentiald_ic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_export_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_export_mathml);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_expovariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_expr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_extend);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_extract_measure);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_extrema);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ezgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_f2nd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fMax);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fMin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fPart);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_faces);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_facteurs_premie);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factor_xn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factorial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factoriser);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factoriser_enti);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factoriser_sur);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_factors);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fadeev);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_false);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_falsepos_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fclose);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fdistrib);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fft);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fieldplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_find);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_find_cliques);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_find_cycles);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_find_minimum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_find_vertex_cov);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_findhelp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fisher);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fisher_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fisher_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fisherd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fisherd_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fisherd_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fitdistr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fitpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fitspline);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_flatten);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_float2rational);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_floor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_flow_polynomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_flower_snark);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_foldl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_foldr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fonction_derive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_forward);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fourier);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fourier_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fourier_bn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fourier_cn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fprint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_frac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fracmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_frame_2d);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_frank_wolfe);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_frequencies);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_frobenius_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_froot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fullparfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_funcplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_function_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fundamental_cyc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_fxnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gammad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gammad_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gammad_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gammavariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gauss);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gauss15);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gauss_seidel_li);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gaussian_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gaussjord);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gaussquad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gbasis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gbasis_max_pair);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gbasis_reinject);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gbasis_simult_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gcdex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_genpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_geodetic2ecef);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_geometric);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_geometric_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_geometric_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_getDenom);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_getKey);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_getNum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_getType);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_get_edge_attrib);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_get_edge_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_get_graph_attri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_get_vertex_attr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_girth);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gl_showaxes);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gold);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_goldberg_snark);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_grad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_gramschmidt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_automorph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_charpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_complemen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_diameter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_equal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_power);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_rank);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_union);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_graph_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_greduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_greedy_clique);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_greedy_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_greedy_independ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_grey);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_grid_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_groupermu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_haar_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hadamard);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_half_cone);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_half_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_halftan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_halftan_hyp2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_halt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hamdist);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hamming);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hamming_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hann_poisson_wi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hann_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_harmonic_centra);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_harmonic_conjug);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_harmonic_divisi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_has);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_has_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_has_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hasard);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_head);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_heading);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_heapify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_heappop);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_heappush);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hermite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hessenberg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hessian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_heugcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hexagon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hht);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_highlight_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_highlight_subgr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_highlight_trail);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_highlight_verte);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_highpass);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hilbert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_histogram);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hold);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_homogeneize);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_homothety);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_horner);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hsv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hsv2rgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hybrid_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hybridj_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hybrids_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hybridsj_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hyp2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hyperbola);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_hypercube_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_iPart);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_iabcuv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ibasis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ibpdv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ibpu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ichinrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ichrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_icomp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_icontent);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_icosahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_identify_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_identity);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_idivis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_idn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_idwt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_iegcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ifactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ifactors);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ifourier);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_igamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_igcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_igcdex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ihermite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ilaplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_im);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_imag);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_image);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_imfplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_implicitdiff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_implicitplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_import_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inString);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_in_ideal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_incidence_matri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_incident_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_incircle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_increasing_powe);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_independence_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_indets);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_induced_subgrap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inequationplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inertia);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_infinity);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_information_cen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_insert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_insmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_instfreq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_instphase);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_intDiv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_integrate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_integrer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_interactive_ode);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_interactive_plo);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_interp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_interval);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_interval2center);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_interval_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_inversion);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_invisible_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_invlaplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_invztrans);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_iquo);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_iquorem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_iratrecon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_irem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isPrime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_acyclic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_arborescence);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_biconnected);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_bipartite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_clique);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_collinear);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_concyclic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_conjugate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_connected);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_coplanar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_cospherical);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_cut_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_cycle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_directed);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_element);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_equilateral);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_eulerian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_forest);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_graphic_sequ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_hamiltonian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_harmonic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_harmonic_cir);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_harmonic_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_inside);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_integer_grap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_irreducible);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_isomorphic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_isosceles);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_network);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_orthogonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_parallel);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_parallelogra);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_permu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_perpendicula);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_planar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_prime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_pseudoprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_reachable);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_regular);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_rhombus);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_split_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_square);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_strongly_con);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_strongly_reg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_subgraph_iso);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_tournament);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_triconnected);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_two_edge_con);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_vertex_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_is_weighted);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isinf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ismith);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isnan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isobarycenter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isom);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isomorphic_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isopolygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isosceles_trian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isposdef);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_isprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_istft);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ithprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_jacobi_equation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_jacobi_linsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_jacobi_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_johnson_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_jordan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_katz_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kde);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_keep_pivot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ker);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kernel);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kernel_density);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kmeans);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kneser_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kolmogorovd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kolmogorovt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kovacicsols);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_kspaths);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_l1norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_l2norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lagrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_laguerre);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_laplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_laplacian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_laplacian_matri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_latex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lcf_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lcm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ldegree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ldl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_learning_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_left);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_left_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_legend);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_legendre);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_legendre_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_levenshtein);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lhs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_chapeau_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_chapeau_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_chapeau_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_polygonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_polygonal_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_tiret);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_tiret_poi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_tiret_poi_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ligne_trait_ple);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_limit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_limite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linabs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_line_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_line_inter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_line_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_line_segments);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linear_interpol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linear_regressi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linear_regressi_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lineariser);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lineariser_trig);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linfnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_linstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lis_phrase);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_list2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_list2mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_list_edge_attri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_list_graph_attr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_list_vertex_att);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_listplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lll);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ln);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lname);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lncollect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lnexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_locus);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_log);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_log10);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_log2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_log_loss);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_logarithmic_reg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_logarithmic_reg_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_logb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_logistic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_logistic_regres);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_logistic_regres_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lower);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lowest_common_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lowpass);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_assume);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_bestlocalbou);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_bestprojecti);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_binary);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_binaryvariab);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_breadthfirst);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_depthfirst);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_depthlimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_firstfractio);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_gaptolerance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_heuristic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_hybrid);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_integervaria);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_interiorpoin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_iterationlim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_lastfraction);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_maxcuts);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_maximize);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_method);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_mostfraction);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_nodelimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_nodeselect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_nonnegative);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_nonnegint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_presolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_pseudocost);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_simplex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_timelimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_varselect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lp_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lsmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lsq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_lvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mRow);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mRowAdd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_magenta);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_make_directed);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_make_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_make_weighted);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_makelist);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_makemat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_makesuite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_makevector);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maple2mupad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maple2xcas);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maple_ifactors);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maple_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_markov);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mat2list);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mathml);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_matpow);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_matrix_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maxflow);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maximal_indepen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maximize);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maximum_clique);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maximum_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maximum_indepen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maximum_matchin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_maxnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mean);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_median);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_median_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_member);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mgf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mid);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_middle_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_midpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimal_edge_co);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimal_spannin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimal_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimax);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimize);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimum_cut);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimum_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_minimum_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mixdown);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mkisom);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mksa);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_modf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_modgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mods);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_momentum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_monotonic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_montre_tortue);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_moustache);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_moving_average);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_moyal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_moyenne);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mul);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mult_c_conjugat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mult_conjugate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_multinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_multiplier_conj);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_multiplier_conj_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_multiply);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mupad2maple);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mupad2xcas);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_mycielski);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nCr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nDeriv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nInt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nPr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nSolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_navy);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ncols);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_negbinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_negbinomial_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_negbinomial_icd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_neighbors);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_network_transit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_neural_network);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_newList);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_newMat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_newton);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_newton_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_newtonj_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nextperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nextprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_binary);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_binaryvaria);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_initialpoin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_integervari);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_iterationli);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_maximize);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_method);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_nonnegative);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_nonnegint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_precision);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_presolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_tolerance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlp_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nlpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nodisp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_non_recursive_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nonnegint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nop);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nops);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normal_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normal_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normald);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normald_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normald_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normalize);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normalt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_normalvariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nprimes);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nrows);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nuage_points);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_nullspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_number_of_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_number_of_spann);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_number_of_trian);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_number_of_verti);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_numdiff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_numer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_octahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_odd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_odd_girth);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_odd_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_odeplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_odesolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_olive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_op);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_open_polygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_orange);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ord);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_order_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ordinate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_orthocenter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_orthogonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_osculating_circ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_p1oc2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_p1op2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pa2b2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pade);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_paley_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parabola);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parallel);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parallelepiped);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parallelogram);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parameq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parameter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_paramplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pari);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_part);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_partfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_parzen_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pas_de_cote);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_path_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pcar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pcar_hessenberg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pcoef);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pencolor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pendown);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_penup);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perimeter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perimeterat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perimeteratraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_period);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_periodic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perminv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_permu2cycles);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_permu2mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_permuorder);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_permute_vertice);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perpen_bisector);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_perpendicular);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_petersen_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_peval);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pie);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_piecewise);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pink);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pivot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pixoff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pixon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_planar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plane);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plane_dual);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_playsnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plot3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotarea);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotcdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotcontour);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotdensity);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotfield);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotfunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotimf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotimplicit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotinequation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotode);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotparam);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotpolar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotproba);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotspectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plotwav);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_plus_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_point2d);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_point3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_poisson);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_poisson_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_poisson_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_poisson_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polar_coordinat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polar_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polarplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pole);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_poly2symb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polyEval);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polygone_rempli);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polygonplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polygonscatterp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polyhedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polynom);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polynomial_regr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_polynomial_regr_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_position);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_poslbdLMQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_posubLMQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_potential);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pow2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_power_regressio);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_power_regressio_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_powermod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_powerpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_powexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_powmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_prepend);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_preval);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_prevperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_prevprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_primpart);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_printf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_prism);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_prism_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_projection);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_proot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_propFrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_propfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pruefer_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_psrgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ptayl);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_purge);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_purple);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pwd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_pyramid);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_python_compat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_q2a);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_qr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quadric);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quadrilateral);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quantile);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quartile1);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quartile3);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quartiles);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quest);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quo);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quorem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_quote);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_r2e);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_radians);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_radical_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_radius);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ramene);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randMat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randNorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randPoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randbetad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randbinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randchisquare);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randexp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randfisher);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randgammad);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randgeometric);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randmarkov);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randmatrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randmultinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_bipartit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_digraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_network);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_planar_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_regular);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_sequence);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_tourname);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_random_variable);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randpoisson);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randseed);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randstudent);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randvector);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_randweibulld);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rank);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ranm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ranv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rassembler_trig);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rat_jordan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ratinterp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rational);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rationalroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ratnormal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rdiv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reachable);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_read);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_readrgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_readwav);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_real);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_realroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reciprocation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rectangle_droit);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rectangle_gauch);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rectangle_plein);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rectangular_coo);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_recule);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_red);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reduced_conic);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reduced_quadric);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ref);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reflection);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_regroup);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_relabel_vertice);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reliability_pol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_remain);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_remove);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reorder);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_resample);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_residue);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_resoudre);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_resoudre_dans_C);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_resoudre_system);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_resultant);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reverse_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_reverse_rsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_revert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_revlex);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_revlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rgb2hsv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rgb2xyz);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rhombus);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rhombus_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rhs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_riemann_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_right);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_right_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_right_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_risch);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rm_a_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rm_all_vars);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rmbreakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rmmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rms);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rmwatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_romberg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rombergm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rombergt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rond);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_root);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rootof);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_roots);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rotate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rotation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_round);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_row);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowAdd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowDim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowNorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowSwap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowdim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rownorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rowswap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rref);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rur);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rur_certify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_rur_gbasis);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_same);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sample);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_samplerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sans_factoriser);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_saute);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_scalarProduct);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_scalar_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_scatterplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_schur);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sec);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_secant_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_segment);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_seidel_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_seidel_switch);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_select);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_semi_augment);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_seq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_seqplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_seqsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sequence_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_series);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_channel_dat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_edge_attrib);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_edge_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_graph_attri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_pixel);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_screen);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_vertex_attr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_set_vertex_posi);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_shift);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_shift_phase);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_shortest_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_show_pixels);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_shuffle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sierpinski_grap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sign);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sign2Heaviside);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_signature);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_signe);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_similarity);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simp2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simplex_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simplicial_vert);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simplifier);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simplifyDirac);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simpson);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simulated_annea);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_simult);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sin2costan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sinc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sincos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_single_inter);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sizes);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_slope);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_slopeat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_slopeatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_smith);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_smod);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_snedecor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_snedecor_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_snedecor_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_snedecord);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_snedecord_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_snedecord_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_solid_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_solve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_somme);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sommet);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sorta);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sortd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sorted);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sortperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_soundsec);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_spanning_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sphere);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_splice);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_spline);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_spring);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sqrfree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sqrt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_square);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_square_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_srand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sst);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sst_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_st_ordering);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_star_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_star_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_stdDev);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_stddev);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_stddevp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_steffenson_solv);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_stereo2mono);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_stft);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_strip);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_strongly_connec);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_student);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_student_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_student_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_studentd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_studentt);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sturm);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sturmab);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sturmseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_style);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subMat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subdivide_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subgraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subs);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subsop);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subst);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_substituer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_subtype);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sum);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sum_riemann);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_suppress);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_surd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_svd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_swapcol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_swaprow);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_switch_axes);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_sylvester);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_symb2poly);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_symbol_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_syst2mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tCollect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tExpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_table);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tablefunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tableseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tabsign);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tabvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tail);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tan2cossin2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tan2sincos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tan2sincos2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tangent);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tangente);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tar);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_taux_accroissem);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_taylor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tchebyshev1);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tchebyshev2);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tcollect);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tdeg);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_teal);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tensor_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tetrahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_texpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_thickness);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_threshold);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_title);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_titre);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tlin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tonnetz);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_topologic_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_topological_sor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_topology);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_torus_grid_grap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_total_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tourne_droite);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tourne_gauche);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trace);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trail);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trail2edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_train);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trames);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tran);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_transitive_clos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_translation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_transpose);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trapeze);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trapezoid);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_traveling_sales);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tree_height);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tri);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_triangle_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_triangle_plein);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_triangle_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_triangle_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trig2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trigcos);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trigexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_triginterp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trigsimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trigsin);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trigtan);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trim);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trn);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_true);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_trunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_truncate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_truncate_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tsimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tuer);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tukey_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_tutte_polynomia);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_two_edge_connec);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ufactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ugamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_unapply);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_unarchive);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_undef);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_underlying_grap);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_unfactored);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_uniform);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_uniform_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_uniform_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_uniformd);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_uniformd_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_uniformd_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_unitV);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_unquote);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_upper);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_user_operator);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_usimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ustep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_valuation);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vandermonde);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_variables_are_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_variance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertex_connecti);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertex_cover_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertex_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertex_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertex_in_degre);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertex_out_degr);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertices_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vertices_abca);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_violet);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vpotential);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_vstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_web_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibull);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibull_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibull_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibulld);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibulld_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibulld_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weibullvariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weight_decay);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weight_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weighted);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_weights);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_welch_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_wheel_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_widget_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_wilcoxonp);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_wilcoxons);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_wilcoxont);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_writergb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_writewav);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_xcas_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_xml_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_xstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_xyz2rgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_xyztrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ystep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_zeros);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_zip);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_znorder);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_znprimroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_zstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacMethods_base_ztrans);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacSetting);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacSetting___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_GiacSetting___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Giac_Settings);
  Py_VISIT(traverse_module_state->__pyx_n_s_Graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_Gy);
  Py_VISIT(traverse_module_state->__pyx_n_s_H);
  Py_VISIT(traverse_module_state->__pyx_n_s_Heaviside);
  Py_VISIT(traverse_module_state->__pyx_n_s_Heaviside2sign);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hilbert);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hz);
  Py_VISIT(traverse_module_state->__pyx_n_s_I);
  Py_VISIT(traverse_module_state->__pyx_n_s_I0);
  Py_VISIT(traverse_module_state->__pyx_n_s_IFTE);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Increase_the_size_of_a_matrix_w);
  Py_VISIT(traverse_module_state->__pyx_n_s_IndexError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Input);
  Py_VISIT(traverse_module_state->__pyx_n_s_InputStr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Interrupted_by_a_ctrl_c_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_Inverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_J);
  Py_VISIT(traverse_module_state->__pyx_n_s_JordanBlock);
  Py_VISIT(traverse_module_state->__pyx_n_s_K);
  Py_VISIT(traverse_module_state->__pyx_n_s_Kcal);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyboardInterrupt);
  Py_VISIT(traverse_module_state->__pyx_n_s_LN);
  Py_VISIT(traverse_module_state->__pyx_n_s_LQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_LSQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_LU);
  Py_VISIT(traverse_module_state->__pyx_n_s_LambertW);
  Py_VISIT(traverse_module_state->__pyx_n_s_Li);
  Py_VISIT(traverse_module_state->__pyx_n_s_Line);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineHorz);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineTan);
  Py_VISIT(traverse_module_state->__pyx_n_s_LineVert);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Lists_of_10_6_integers_should_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_MHz);
  Py_VISIT(traverse_module_state->__pyx_n_s_MSE);
  Py_VISIT(traverse_module_state->__pyx_n_s_MW);
  Py_VISIT(traverse_module_state->__pyx_n_s_MeV);
  Py_VISIT(traverse_module_state->__pyx_n_s_N);
  Py_VISIT(traverse_module_state->__pyx_n_s_NA);
  Py_VISIT(traverse_module_state->__pyx_n_s_NORMALD);
  Py_VISIT(traverse_module_state->__pyx_n_s_NULL);
  Py_VISIT(traverse_module_state->__pyx_n_s_NewFold);
  Py_VISIT(traverse_module_state->__pyx_n_s_NewPic);
  Py_VISIT(traverse_module_state->__pyx_n_s_Nullspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ohm);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Open_a_file_in_giac_compressed);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Open_the_giac_html_detailled_he);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Open_the_giac_html_detailled_he_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Output);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ox_2d_unit_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ox_3d_unit_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Oy_2d_unit_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Oy_3d_unit_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Oz_3d_unit_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_P);
  Py_VISIT(traverse_module_state->__pyx_n_s_PSun);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pa);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pause);
  Py_VISIT(traverse_module_state->__pyx_n_s_Phi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pi);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_PopUp);
  Py_VISIT(traverse_module_state->__pyx_n_s_Psi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___float___line_1078);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___getitem___line_913);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___int___line_1059);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen___iter);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___iter___line_1035);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___radd___line_1192);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___repr___line_877);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___rmod___line_1410);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___rmul___line_1286);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___rpow___line_1372);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___rsub___line_1248);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___rtruediv___line_1337);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen___setitem___line_986);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen__repr_html);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen__repr_latex);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_cas_setup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_eval);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_help);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_htmlhelp);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen_htmlhelp_line_1498);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen_lists_of_10_6_elements_sh);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_qcas);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen_qcas_line_1552);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_redim);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen_redim_line_1526);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_save);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Pygen_save_line_1469);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pygen_threadeval);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pymaxint);
  Py_VISIT(traverse_module_state->__pyx_n_s_PythonVersion3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pyversioninfo);
  Py_VISIT(traverse_module_state->__pyx_n_s_QR);
  Py_VISIT(traverse_module_state->__pyx_n_s_Quo);
  Py_VISIT(traverse_module_state->__pyx_n_s_R);
  Py_VISIT(traverse_module_state->__pyx_n_s_REDIM);
  Py_VISIT(traverse_module_state->__pyx_n_s_REPLACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_REarth);
  Py_VISIT(traverse_module_state->__pyx_n_s_RSun);
  Py_VISIT(traverse_module_state->__pyx_n_s_R_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_RandSeed);
  Py_VISIT(traverse_module_state->__pyx_n_s_Rankine);
  Py_VISIT(traverse_module_state->__pyx_n_s_RclPic);
  Py_VISIT(traverse_module_state->__pyx_n_s_ReLU);
  Py_VISIT(traverse_module_state->__pyx_n_s_Rem);
  Py_VISIT(traverse_module_state->__pyx_n_s_Request);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Result_is_too_big_for_Display_I);
  Py_VISIT(traverse_module_state->__pyx_n_s_Resultant);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Reverse_operator_7_giac_3_Calle);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_1_d_C);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_2_d_C);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Rinfinity);
  Py_VISIT(traverse_module_state->__pyx_n_s_Row);
  Py_VISIT(traverse_module_state->__pyx_n_s_RplcPic);
  Py_VISIT(traverse_module_state->__pyx_n_s_Rref);
  Py_VISIT(traverse_module_state->__pyx_n_s_RuntimeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_S);
  Py_VISIT(traverse_module_state->__pyx_n_s_SCALE);
  Py_VISIT(traverse_module_state->__pyx_n_s_SCALEADD);
  Py_VISIT(traverse_module_state->__pyx_n_s_SCHUR);
  Py_VISIT(traverse_module_state->__pyx_n_s_SIN);
  Py_VISIT(traverse_module_state->__pyx_n_s_SVD);
  Py_VISIT(traverse_module_state->__pyx_n_s_SVL);
  Py_VISIT(traverse_module_state->__pyx_n_s_SWAPCOL);
  Py_VISIT(traverse_module_state->__pyx_n_s_SWAPROW);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Send_a_giac_graphic_to_qcas_3D);
  Py_VISIT(traverse_module_state->__pyx_n_s_SetFold);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Set_the_value_of_a_coefficient);
  Py_VISIT(traverse_module_state->__pyx_n_s_Si);
  Py_VISIT(traverse_module_state->__pyx_n_s_SortA);
  Py_VISIT(traverse_module_state->__pyx_n_s_SortD);
  Py_VISIT(traverse_module_state->__pyx_n_s_St);
  Py_VISIT(traverse_module_state->__pyx_n_s_StdP);
  Py_VISIT(traverse_module_state->__pyx_n_s_StdT);
  Py_VISIT(traverse_module_state->__pyx_n_s_StoPic);
  Py_VISIT(traverse_module_state->__pyx_n_s_Store);
  Py_VISIT(traverse_module_state->__pyx_n_s_Sv);
  Py_VISIT(traverse_module_state->__pyx_n_s_T);
  Py_VISIT(traverse_module_state->__pyx_n_s_TAN);
  Py_VISIT(traverse_module_state->__pyx_n_s_TRUE);
  Py_VISIT(traverse_module_state->__pyx_n_s_TeX);
  Py_VISIT(traverse_module_state->__pyx_n_s_Text);
  Py_VISIT(traverse_module_state->__pyx_kp_u_This_function_evaluate_a_python);
  Py_VISIT(traverse_module_state->__pyx_n_s_ThreadedPygen);
  Py_VISIT(traverse_module_state->__pyx_n_s_ThreadedPygen___call);
  Py_VISIT(traverse_module_state->__pyx_n_s_Title);
  Py_VISIT(traverse_module_state->__pyx_n_s_True);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_UTF_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_UTPC);
  Py_VISIT(traverse_module_state->__pyx_n_s_UTPF);
  Py_VISIT(traverse_module_state->__pyx_n_s_UTPN);
  Py_VISIT(traverse_module_state->__pyx_n_s_UTPT);
  Py_VISIT(traverse_module_state->__pyx_n_s_Unarchiv);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Use_this_subclass_of_to_call_yo);
  Py_VISIT(traverse_module_state->__pyx_n_s_V);
  Py_VISIT(traverse_module_state->__pyx_n_s_VARS);
  Py_VISIT(traverse_module_state->__pyx_n_s_VAS);
  Py_VISIT(traverse_module_state->__pyx_n_s_VAS_positive);
  Py_VISIT(traverse_module_state->__pyx_n_s_Vm);
  Py_VISIT(traverse_module_state->__pyx_n_s_W);
  Py_VISIT(traverse_module_state->__pyx_n_s_WAIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_Wb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Wh);
  Py_VISIT(traverse_module_state->__pyx_n_s_Zeta);
  Py_VISIT(traverse_module_state->__pyx_kp_s__10);
  Py_VISIT(traverse_module_state->__pyx_kp_s__12);
  Py_VISIT(traverse_module_state->__pyx_n_s__14);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1655);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1656);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1657);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1658);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1659);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1660);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1661);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1662);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1663);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1664);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1665);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1666);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1667);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1668);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1669);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1670);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1671);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1672);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1673);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1674);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1675);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1676);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1677);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1678);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1679);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1680);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1681);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1682);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1683);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1684);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1685);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1686);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1687);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1688);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1689);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1690);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1691);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1692);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1693);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1694);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1695);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1696);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1697);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1698);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1699);
  Py_VISIT(traverse_module_state->__pyx_kp_s__1700);
  Py_VISIT(traverse_module_state->__pyx_kp_u__8);
  Py_VISIT(traverse_module_state->__pyx_n_s_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_a0);
  Py_VISIT(traverse_module_state->__pyx_n_s_a2q);
  Py_VISIT(traverse_module_state->__pyx_n_s_a_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_abcuv);
  Py_VISIT(traverse_module_state->__pyx_n_s_about);
  Py_VISIT(traverse_module_state->__pyx_n_s_abs);
  Py_VISIT(traverse_module_state->__pyx_n_s_abscissa);
  Py_VISIT(traverse_module_state->__pyx_n_s_access);
  Py_VISIT(traverse_module_state->__pyx_n_s_accumulate_head_tail);
  Py_VISIT(traverse_module_state->__pyx_n_s_acos);
  Py_VISIT(traverse_module_state->__pyx_n_s_acos2asin);
  Py_VISIT(traverse_module_state->__pyx_n_s_acos2atan);
  Py_VISIT(traverse_module_state->__pyx_n_s_acosh);
  Py_VISIT(traverse_module_state->__pyx_n_s_acot);
  Py_VISIT(traverse_module_state->__pyx_n_s_acre);
  Py_VISIT(traverse_module_state->__pyx_n_s_acsc);
  Py_VISIT(traverse_module_state->__pyx_n_s_acyclic);
  Py_VISIT(traverse_module_state->__pyx_n_s_adaptive);
  Py_VISIT(traverse_module_state->__pyx_n_s_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_edge);
  Py_VISIT(traverse_module_state->__pyx_kp_s_add_language_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_additionally);
  Py_VISIT(traverse_module_state->__pyx_n_s_addtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_adjacency_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_adjoint_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_affichage);
  Py_VISIT(traverse_module_state->__pyx_n_s_affix);
  Py_VISIT(traverse_module_state->__pyx_n_s_algsubs);
  Py_VISIT(traverse_module_state->__pyx_n_s_algvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_all);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_trig_solutions);
  Py_VISIT(traverse_module_state->__pyx_n_s_allpairs_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_alog10);
  Py_VISIT(traverse_module_state->__pyx_n_s_alors);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_altitude);
  Py_VISIT(traverse_module_state->__pyx_n_s_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_angl);
  Py_VISIT(traverse_module_state->__pyx_n_s_angle);
  Py_VISIT(traverse_module_state->__pyx_n_s_angle_radian);
  Py_VISIT(traverse_module_state->__pyx_n_s_angleat);
  Py_VISIT(traverse_module_state->__pyx_n_s_angleatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_animate);
  Py_VISIT(traverse_module_state->__pyx_n_s_animate3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_animation);
  Py_VISIT(traverse_module_state->__pyx_n_s_ans);
  Py_VISIT(traverse_module_state->__pyx_n_s_antiprism_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_approx);
  Py_VISIT(traverse_module_state->__pyx_n_s_approx_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_arcLen);
  Py_VISIT(traverse_module_state->__pyx_n_s_arccos);
  Py_VISIT(traverse_module_state->__pyx_n_s_arccosh);
  Py_VISIT(traverse_module_state->__pyx_n_s_archive);
  Py_VISIT(traverse_module_state->__pyx_n_s_arclen);
  Py_VISIT(traverse_module_state->__pyx_n_s_arcmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_arcs);
  Py_VISIT(traverse_module_state->__pyx_n_s_arcsin);
  Py_VISIT(traverse_module_state->__pyx_n_s_arcsinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_arctan);
  Py_VISIT(traverse_module_state->__pyx_n_s_arctanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_area);
  Py_VISIT(traverse_module_state->__pyx_n_s_areaat);
  Py_VISIT(traverse_module_state->__pyx_n_s_areaatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_areaplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_arg);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_kp_s_argument_must_be_a_Pygen_list_an);
  Py_VISIT(traverse_module_state->__pyx_kp_s_argument_must_be_a_tuple_or_a_li);
  Py_VISIT(traverse_module_state->__pyx_n_s_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_arrivals);
  Py_VISIT(traverse_module_state->__pyx_n_s_articulation_points);
  Py_VISIT(traverse_module_state->__pyx_n_s_as_function_of);
  Py_VISIT(traverse_module_state->__pyx_n_s_asc);
  Py_VISIT(traverse_module_state->__pyx_n_s_asec);
  Py_VISIT(traverse_module_state->__pyx_n_s_asin);
  Py_VISIT(traverse_module_state->__pyx_n_s_asin2acos);
  Py_VISIT(traverse_module_state->__pyx_n_s_asin2atan);
  Py_VISIT(traverse_module_state->__pyx_n_s_asinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_assert);
  Py_VISIT(traverse_module_state->__pyx_n_s_assign);
  Py_VISIT(traverse_module_state->__pyx_n_s_assign_edge_weights);
  Py_VISIT(traverse_module_state->__pyx_n_s_assume);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_at);
  Py_VISIT(traverse_module_state->__pyx_n_s_atan);
  Py_VISIT(traverse_module_state->__pyx_n_s_atan2);
  Py_VISIT(traverse_module_state->__pyx_n_s_atan2acos);
  Py_VISIT(traverse_module_state->__pyx_n_s_atan2asin);
  Py_VISIT(traverse_module_state->__pyx_n_s_atanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_atm);
  Py_VISIT(traverse_module_state->__pyx_n_s_atrig2ln);
  Py_VISIT(traverse_module_state->__pyx_n_s_au);
  Py_VISIT(traverse_module_state->__pyx_n_s_augment);
  Py_VISIT(traverse_module_state->__pyx_n_s_auto_correlation);
  Py_VISIT(traverse_module_state->__pyx_n_s_autosimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_avance);
  Py_VISIT(traverse_module_state->__pyx_n_s_avgRC);
  Py_VISIT(traverse_module_state->__pyx_n_s_axes);
  Py_VISIT(traverse_module_state->__pyx_n_s_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_b_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_back);
  Py_VISIT(traverse_module_state->__pyx_n_s_backquote);
  Py_VISIT(traverse_module_state->__pyx_n_s_backward);
  Py_VISIT(traverse_module_state->__pyx_n_s_baisse_crayon);
  Py_VISIT(traverse_module_state->__pyx_n_s_bandwidth);
  Py_VISIT(traverse_module_state->__pyx_n_s_bar);
  Py_VISIT(traverse_module_state->__pyx_n_s_bar_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_barplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_bartlett_hann_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_barycenter);
  Py_VISIT(traverse_module_state->__pyx_n_s_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_basis);
  Py_VISIT(traverse_module_state->__pyx_n_s_batons);
  Py_VISIT(traverse_module_state->__pyx_n_s_bbl);
  Py_VISIT(traverse_module_state->__pyx_n_s_bblep);
  Py_VISIT(traverse_module_state->__pyx_n_s_begin);
  Py_VISIT(traverse_module_state->__pyx_n_s_bellman_ford);
  Py_VISIT(traverse_module_state->__pyx_n_s_berlekamp_massey);
  Py_VISIT(traverse_module_state->__pyx_n_s_bernoulli);
  Py_VISIT(traverse_module_state->__pyx_n_s_bernoulli_mod);
  Py_VISIT(traverse_module_state->__pyx_n_s_besselJ);
  Py_VISIT(traverse_module_state->__pyx_n_s_besselY);
  Py_VISIT(traverse_module_state->__pyx_n_s_betad);
  Py_VISIT(traverse_module_state->__pyx_n_s_betad_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_betad_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_betavariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_betweenness_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_bezier);
  Py_VISIT(traverse_module_state->__pyx_n_s_bezout_entiers);
  Py_VISIT(traverse_module_state->__pyx_n_s_bezoutian);
  Py_VISIT(traverse_module_state->__pyx_n_s_biconnected_components);
  Py_VISIT(traverse_module_state->__pyx_n_s_binomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_binomial_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_binomial_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_bins);
  Py_VISIT(traverse_module_state->__pyx_n_s_bipartite);
  Py_VISIT(traverse_module_state->__pyx_n_s_bipartite_matching);
  Py_VISIT(traverse_module_state->__pyx_n_s_bisection_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_bisector);
  Py_VISIT(traverse_module_state->__pyx_n_s_bit_depth);
  Py_VISIT(traverse_module_state->__pyx_n_s_bit_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_bitand);
  Py_VISIT(traverse_module_state->__pyx_n_s_bitor);
  Py_VISIT(traverse_module_state->__pyx_n_s_bitxor);
  Py_VISIT(traverse_module_state->__pyx_n_s_black);
  Py_VISIT(traverse_module_state->__pyx_n_s_blacklist);
  Py_VISIT(traverse_module_state->__pyx_n_s_blackman_harris_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_blackman_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_blanc);
  Py_VISIT(traverse_module_state->__pyx_n_s_bleu);
  Py_VISIT(traverse_module_state->__pyx_n_s_bloc);
  Py_VISIT(traverse_module_state->__pyx_n_s_block_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_blockmatrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_blue);
  Py_VISIT(traverse_module_state->__pyx_n_s_bohman_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_border);
  Py_VISIT(traverse_module_state->__pyx_n_s_box_constraints);
  Py_VISIT(traverse_module_state->__pyx_n_s_boxcar);
  Py_VISIT(traverse_module_state->__pyx_n_s_boxwhisker);
  Py_VISIT(traverse_module_state->__pyx_n_s_break);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_brent_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_brown);
  Py_VISIT(traverse_module_state->__pyx_n_s_bspline);
  Py_VISIT(traverse_module_state->__pyx_n_s_bu);
  Py_VISIT(traverse_module_state->__pyx_n_s_buUS);
  Py_VISIT(traverse_module_state->__pyx_n_s_builtins);
  Py_VISIT(traverse_module_state->__pyx_n_s_bvpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_by);
  Py_VISIT(traverse_module_state->__pyx_n_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_c1oc2);
  Py_VISIT(traverse_module_state->__pyx_n_s_c1op2);
  Py_VISIT(traverse_module_state->__pyx_n_s_c3);
  Py_VISIT(traverse_module_state->__pyx_n_s_cFactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_cSolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_cZeros);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_tortue);
  Py_VISIT(traverse_module_state->__pyx_n_s_cal);
  Py_VISIT(traverse_module_state->__pyx_n_s_call);
  Py_VISIT(traverse_module_state->__pyx_n_s_camembert);
  Py_VISIT(traverse_module_state->__pyx_n_s_canonical_form);
  Py_VISIT(traverse_module_state->__pyx_n_s_canonical_labeling);
  Py_VISIT(traverse_module_state->__pyx_n_s_cap);
  Py_VISIT(traverse_module_state->__pyx_n_s_cap_flat_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_cap_round_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_cap_square_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_cartesian_product);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cas_monitor_status);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cas_monitor_status_after_killing);
  Py_VISIT(traverse_module_state->__pyx_n_s_cas_setup);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cas_setup_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cas_setup_s);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cascmd);
  Py_VISIT(traverse_module_state->__pyx_n_s_case);
  Py_VISIT(traverse_module_state->__pyx_n_s_cat);
  Py_VISIT(traverse_module_state->__pyx_n_s_catch);
  Py_VISIT(traverse_module_state->__pyx_n_s_cauchy);
  Py_VISIT(traverse_module_state->__pyx_n_s_cauchy_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_cauchy_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_cauchyd);
  Py_VISIT(traverse_module_state->__pyx_n_s_cauchyd_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_cauchyd_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_cd);
  Py_VISIT(traverse_module_state->__pyx_n_s_cd_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_ceil);
  Py_VISIT(traverse_module_state->__pyx_n_s_ceiling);
  Py_VISIT(traverse_module_state->__pyx_n_s_center);
  Py_VISIT(traverse_module_state->__pyx_n_s_center2interval);
  Py_VISIT(traverse_module_state->__pyx_n_s_centered_cube);
  Py_VISIT(traverse_module_state->__pyx_n_s_centered_tetrahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_cfactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_cfsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_chain);
  Py_VISIT(traverse_module_state->__pyx_n_s_changebase);
  Py_VISIT(traverse_module_state->__pyx_n_s_channel_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_channels);
  Py_VISIT(traverse_module_state->__pyx_n_s_char);
  Py_VISIT(traverse_module_state->__pyx_n_s_charpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_chinrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquare);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquare_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquare_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquared);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquared_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquared_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_chisquaret);
  Py_VISIT(traverse_module_state->__pyx_n_s_choice);
  Py_VISIT(traverse_module_state->__pyx_n_s_cholesky);
  Py_VISIT(traverse_module_state->__pyx_n_s_choosebox);
  Py_VISIT(traverse_module_state->__pyx_n_s_chr);
  Py_VISIT(traverse_module_state->__pyx_n_s_chrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_chromatic_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_chromatic_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_chromatic_polynomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_circumcircle);
  Py_VISIT(traverse_module_state->__pyx_n_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_classes);
  Py_VISIT(traverse_module_state->__pyx_n_s_clear);
  Py_VISIT(traverse_module_state->__pyx_n_s_click);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_clique_cover);
  Py_VISIT(traverse_module_state->__pyx_n_s_clique_cover_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_clique_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_closeness_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_cluster);
  Py_VISIT(traverse_module_state->__pyx_n_s_clustering_coefficient);
  Py_VISIT(traverse_module_state->__pyx_n_s_cm);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cm_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cm_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_cm_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_coeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_coeffs);
  Py_VISIT(traverse_module_state->__pyx_n_s_col);
  Py_VISIT(traverse_module_state->__pyx_n_s_colDim);
  Py_VISIT(traverse_module_state->__pyx_n_s_colNorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_colSwap);
  Py_VISIT(traverse_module_state->__pyx_n_s_coldim);
  Py_VISIT(traverse_module_state->__pyx_n_s_collect);
  Py_VISIT(traverse_module_state->__pyx_n_s_colnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_colormap);
  Py_VISIT(traverse_module_state->__pyx_n_s_colspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_colswap);
  Py_VISIT(traverse_module_state->__pyx_n_s_comDenom);
  Py_VISIT(traverse_module_state->__pyx_n_s_comb);
  Py_VISIT(traverse_module_state->__pyx_n_s_combine);
  Py_VISIT(traverse_module_state->__pyx_n_s_comment);
  Py_VISIT(traverse_module_state->__pyx_n_s_common_perpendicular);
  Py_VISIT(traverse_module_state->__pyx_n_s_companion);
  Py_VISIT(traverse_module_state->__pyx_n_s_compare);
  Py_VISIT(traverse_module_state->__pyx_n_s_complete_binary_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_complete_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_complete_kary_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_complex);
  Py_VISIT(traverse_module_state->__pyx_n_s_complex_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_complex_variables);
  Py_VISIT(traverse_module_state->__pyx_n_s_complexroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_concat);
  Py_VISIT(traverse_module_state->__pyx_n_s_cond);
  Py_VISIT(traverse_module_state->__pyx_n_s_condensation);
  Py_VISIT(traverse_module_state->__pyx_n_s_condi);
  Py_VISIT(traverse_module_state->__pyx_n_s_cone);
  Py_VISIT(traverse_module_state->__pyx_n_s_confrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_conic);
  Py_VISIT(traverse_module_state->__pyx_n_s_conj);
  Py_VISIT(traverse_module_state->__pyx_n_s_conjugate_equation);
  Py_VISIT(traverse_module_state->__pyx_n_s_conjugate_gradient);
  Py_VISIT(traverse_module_state->__pyx_n_s_connected);
  Py_VISIT(traverse_module_state->__pyx_n_s_connected_components);
  Py_VISIT(traverse_module_state->__pyx_n_s_cont);
  Py_VISIT(traverse_module_state->__pyx_n_s_contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_content);
  Py_VISIT(traverse_module_state->__pyx_n_s_context_ptr);
  Py_VISIT(traverse_module_state->__pyx_n_s_continue);
  Py_VISIT(traverse_module_state->__pyx_n_s_contourplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_contract_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_contract_subgraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_convert);
  Py_VISIT(traverse_module_state->__pyx_n_s_convertir);
  Py_VISIT(traverse_module_state->__pyx_n_s_convex);
  Py_VISIT(traverse_module_state->__pyx_n_s_convexhull);
  Py_VISIT(traverse_module_state->__pyx_n_s_convolution);
  Py_VISIT(traverse_module_state->__pyx_n_s_coordinates);
  Py_VISIT(traverse_module_state->__pyx_n_s_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_correlation);
  Py_VISIT(traverse_module_state->__pyx_n_s_cos);
  Py_VISIT(traverse_module_state->__pyx_n_s_cos2sintan);
  Py_VISIT(traverse_module_state->__pyx_n_s_cosh);
  Py_VISIT(traverse_module_state->__pyx_n_s_cosine_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_cot);
  Py_VISIT(traverse_module_state->__pyx_n_s_cote);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_count_eq);
  Py_VISIT(traverse_module_state->__pyx_n_s_count_inf);
  Py_VISIT(traverse_module_state->__pyx_n_s_count_sup);
  Py_VISIT(traverse_module_state->__pyx_n_s_courbe_parametrique);
  Py_VISIT(traverse_module_state->__pyx_n_s_courbe_polaire);
  Py_VISIT(traverse_module_state->__pyx_n_s_covariance);
  Py_VISIT(traverse_module_state->__pyx_n_s_covariance_correlation);
  Py_VISIT(traverse_module_state->__pyx_n_s_cpartfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_crationalroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_crayon);
  Py_VISIT(traverse_module_state->__pyx_n_s_createwav);
  Py_VISIT(traverse_module_state->__pyx_n_s_cross);
  Py_VISIT(traverse_module_state->__pyx_n_s_crossP);
  Py_VISIT(traverse_module_state->__pyx_n_s_cross_correlation);
  Py_VISIT(traverse_module_state->__pyx_n_s_cross_entropy);
  Py_VISIT(traverse_module_state->__pyx_n_s_cross_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_cross_ratio);
  Py_VISIT(traverse_module_state->__pyx_n_s_crossproduct);
  Py_VISIT(traverse_module_state->__pyx_n_s_csc);
  Py_VISIT(traverse_module_state->__pyx_n_s_csolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_csv2gen);
  Py_VISIT(traverse_module_state->__pyx_n_s_ct);
  Py_VISIT(traverse_module_state->__pyx_n_s_cu);
  Py_VISIT(traverse_module_state->__pyx_n_s_cube);
  Py_VISIT(traverse_module_state->__pyx_n_s_cumSum);
  Py_VISIT(traverse_module_state->__pyx_n_s_cumsum);
  Py_VISIT(traverse_module_state->__pyx_n_s_cumulated_frequencies);
  Py_VISIT(traverse_module_state->__pyx_n_s_curl);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_sheet);
  Py_VISIT(traverse_module_state->__pyx_n_s_curvature);
  Py_VISIT(traverse_module_state->__pyx_n_s_curve);
  Py_VISIT(traverse_module_state->__pyx_n_s_cyan);
  Py_VISIT(traverse_module_state->__pyx_n_s_cycle2perm);
  Py_VISIT(traverse_module_state->__pyx_n_s_cycle_basis);
  Py_VISIT(traverse_module_state->__pyx_n_s_cycle_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_cycleinv);
  Py_VISIT(traverse_module_state->__pyx_n_s_cycles2permu);
  Py_VISIT(traverse_module_state->__pyx_n_s_cyclotomic);
  Py_VISIT(traverse_module_state->__pyx_n_s_cylinder);
  Py_VISIT(traverse_module_state->__pyx_n_s_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_dB);
  Py_VISIT(traverse_module_state->__pyx_n_s_d_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_dash_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_dashdot_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_dashdotdot_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_dayofweek);
  Py_VISIT(traverse_module_state->__pyx_n_s_de);
  Py_VISIT(traverse_module_state->__pyx_n_s_deSolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_debug);
  Py_VISIT(traverse_module_state->__pyx_n_s_debut_enregistrement);
  Py_VISIT(traverse_module_state->__pyx_n_s_decode);
  Py_VISIT(traverse_module_state->__pyx_n_s_decstring23);
  Py_VISIT(traverse_module_state->__pyx_n_s_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_deg);
  Py_VISIT(traverse_module_state->__pyx_n_s_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_degreeF);
  Py_VISIT(traverse_module_state->__pyx_n_s_degree_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_degree_sequence);
  Py_VISIT(traverse_module_state->__pyx_n_s_degrees);
  Py_VISIT(traverse_module_state->__pyx_n_s_del);
  Py_VISIT(traverse_module_state->__pyx_n_s_delcols);
  Py_VISIT(traverse_module_state->__pyx_n_s_delete_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_delete_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_delete_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_delrows);
  Py_VISIT(traverse_module_state->__pyx_n_s_deltalist);
  Py_VISIT(traverse_module_state->__pyx_n_s_denom);
  Py_VISIT(traverse_module_state->__pyx_n_s_densityplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_departures);
  Py_VISIT(traverse_module_state->__pyx_n_s_derive);
  Py_VISIT(traverse_module_state->__pyx_n_s_deriver);
  Py_VISIT(traverse_module_state->__pyx_n_s_desolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_dessine_tortue);
  Py_VISIT(traverse_module_state->__pyx_n_s_det);
  Py_VISIT(traverse_module_state->__pyx_n_s_det_minor);
  Py_VISIT(traverse_module_state->__pyx_n_s_developper);
  Py_VISIT(traverse_module_state->__pyx_n_s_developper_transcendant);
  Py_VISIT(traverse_module_state->__pyx_n_s_dfc);
  Py_VISIT(traverse_module_state->__pyx_n_s_dfc2f);
  Py_VISIT(traverse_module_state->__pyx_n_s_diag);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_digraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_dijkstra);
  Py_VISIT(traverse_module_state->__pyx_n_s_dim);
  Py_VISIT(traverse_module_state->__pyx_n_s_directed);
  Py_VISIT(traverse_module_state->__pyx_n_s_directevalued);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_discard_edge_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_discard_graph_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_discard_vertex_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_disjoint_union);
  Py_VISIT(traverse_module_state->__pyx_n_s_display);
  Py_VISIT(traverse_module_state->__pyx_n_s_disque);
  Py_VISIT(traverse_module_state->__pyx_n_s_disque_centre);
  Py_VISIT(traverse_module_state->__pyx_n_s_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_distance2);
  Py_VISIT(traverse_module_state->__pyx_n_s_distanceat);
  Py_VISIT(traverse_module_state->__pyx_n_s_distanceatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_div);
  Py_VISIT(traverse_module_state->__pyx_n_s_div_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_divergence);
  Py_VISIT(traverse_module_state->__pyx_n_s_divide);
  Py_VISIT(traverse_module_state->__pyx_n_s_divis);
  Py_VISIT(traverse_module_state->__pyx_n_s_division_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_divisors);
  Py_VISIT(traverse_module_state->__pyx_n_s_divmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_divpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_dnewton_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_do);
  Py_VISIT(traverse_module_state->__pyx_kp_s_doc);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_dodecahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_domain);
  Py_VISIT(traverse_module_state->__pyx_n_s_dot);
  Py_VISIT(traverse_module_state->__pyx_n_s_dotP);
  Py_VISIT(traverse_module_state->__pyx_n_s_dot_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_dotprod);
  Py_VISIT(traverse_module_state->__pyx_n_s_double);
  Py_VISIT(traverse_module_state->__pyx_n_s_double_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_pixel);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_polygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_draw_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_droit);
  Py_VISIT(traverse_module_state->__pyx_n_s_droite_tangente);
  Py_VISIT(traverse_module_state->__pyx_n_s_dsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_duration);
  Py_VISIT(traverse_module_state->__pyx_n_s_dwt);
  Py_VISIT(traverse_module_state->__pyx_n_s_dyn);
  Py_VISIT(traverse_module_state->__pyx_n_s_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_e2r);
  Py_VISIT(traverse_module_state->__pyx_n_s_eV);
  Py_VISIT(traverse_module_state->__pyx_n_s_ecart_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_ecart_type_population);
  Py_VISIT(traverse_module_state->__pyx_n_s_ecef2geodetic);
  Py_VISIT(traverse_module_state->__pyx_n_s_ecm_factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_ecris);
  Py_VISIT(traverse_module_state->__pyx_n_s_edge_connectivity);
  Py_VISIT(traverse_module_state->__pyx_n_s_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_efface);
  Py_VISIT(traverse_module_state->__pyx_n_s_egcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_egv);
  Py_VISIT(traverse_module_state->__pyx_n_s_egvl);
  Py_VISIT(traverse_module_state->__pyx_n_s_eigVc);
  Py_VISIT(traverse_module_state->__pyx_n_s_eigVl);
  Py_VISIT(traverse_module_state->__pyx_n_s_eigenvals);
  Py_VISIT(traverse_module_state->__pyx_n_s_eigenvalues);
  Py_VISIT(traverse_module_state->__pyx_n_s_eigenvectors);
  Py_VISIT(traverse_module_state->__pyx_n_s_eigenvects);
  Py_VISIT(traverse_module_state->__pyx_n_s_el);
  Py_VISIT(traverse_module_state->__pyx_n_s_element);
  Py_VISIT(traverse_module_state->__pyx_n_s_elif);
  Py_VISIT(traverse_module_state->__pyx_n_s_eliminate);
  Py_VISIT(traverse_module_state->__pyx_n_s_ellipse);
  Py_VISIT(traverse_module_state->__pyx_n_s_else);
  Py_VISIT(traverse_module_state->__pyx_n_s_emd);
  Py_VISIT(traverse_module_state->__pyx_n_s_en);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_encstring23);
  Py_VISIT(traverse_module_state->__pyx_n_s_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_for);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_if);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_while);
  Py_VISIT(traverse_module_state->__pyx_n_s_entry);
  Py_VISIT(traverse_module_state->__pyx_n_s_envelope);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_ligne_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_epaisseur_point_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilon);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilon0);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilon0q);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilon2zero);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilonox);
  Py_VISIT(traverse_module_state->__pyx_n_s_epsilonsi);
  Py_VISIT(traverse_module_state->__pyx_n_s_equal);
  Py_VISIT(traverse_module_state->__pyx_n_s_equal2diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_equal2list);
  Py_VISIT(traverse_module_state->__pyx_n_s_equation);
  Py_VISIT(traverse_module_state->__pyx_n_s_equilateral_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_erase);
  Py_VISIT(traverse_module_state->__pyx_n_s_erase3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_erf);
  Py_VISIT(traverse_module_state->__pyx_n_s_erfc);
  Py_VISIT(traverse_module_state->__pyx_n_s_erg);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_est_cocyclique);
  Py_VISIT(traverse_module_state->__pyx_n_s_est_inclus);
  Py_VISIT(traverse_module_state->__pyx_n_s_est_permu);
  Py_VISIT(traverse_module_state->__pyx_n_s_et);
  Py_VISIT(traverse_module_state->__pyx_n_s_euler);
  Py_VISIT(traverse_module_state->__pyx_n_s_euler_gamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_euler_lagrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_eval);
  Py_VISIT(traverse_module_state->__pyx_n_s_eval_level);
  Py_VISIT(traverse_module_state->__pyx_n_s_evala);
  Py_VISIT(traverse_module_state->__pyx_n_s_evalb);
  Py_VISIT(traverse_module_state->__pyx_n_s_evalc);
  Py_VISIT(traverse_module_state->__pyx_n_s_evalf);
  Py_VISIT(traverse_module_state->__pyx_n_s_evalm);
  Py_VISIT(traverse_module_state->__pyx_n_s_even);
  Py_VISIT(traverse_module_state->__pyx_n_s_evolute);
  Py_VISIT(traverse_module_state->__pyx_n_s_exact);
  Py_VISIT(traverse_module_state->__pyx_n_s_exbisector);
  Py_VISIT(traverse_module_state->__pyx_n_s_excircle);
  Py_VISIT(traverse_module_state->__pyx_n_s_execute);
  Py_VISIT(traverse_module_state->__pyx_n_s_exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_exp2list);
  Py_VISIT(traverse_module_state->__pyx_n_s_exp2pow);
  Py_VISIT(traverse_module_state->__pyx_n_s_exp2trig);
  Py_VISIT(traverse_module_state->__pyx_n_s_expand);
  Py_VISIT(traverse_module_state->__pyx_n_s_expexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_expln);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponential);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponential_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponential_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponential_regression);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponential_regression_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponentiald);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponentiald_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_exponentiald_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_export_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_export_mathml);
  Py_VISIT(traverse_module_state->__pyx_n_s_expovariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_expr);
  Py_VISIT(traverse_module_state->__pyx_n_s_expression);
  Py_VISIT(traverse_module_state->__pyx_n_s_extend);
  Py_VISIT(traverse_module_state->__pyx_n_s_extract_measure);
  Py_VISIT(traverse_module_state->__pyx_n_s_extrema);
  Py_VISIT(traverse_module_state->__pyx_n_s_ezgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_f0);
  Py_VISIT(traverse_module_state->__pyx_n_s_f2nd);
  Py_VISIT(traverse_module_state->__pyx_n_s_fMax);
  Py_VISIT(traverse_module_state->__pyx_n_s_fMin);
  Py_VISIT(traverse_module_state->__pyx_n_s_fPart);
  Py_VISIT(traverse_module_state->__pyx_n_s_faces);
  Py_VISIT(traverse_module_state->__pyx_n_s_facteurs_premiers);
  Py_VISIT(traverse_module_state->__pyx_n_s_factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_factor_xn);
  Py_VISIT(traverse_module_state->__pyx_n_s_factorial);
  Py_VISIT(traverse_module_state->__pyx_n_s_factoriser);
  Py_VISIT(traverse_module_state->__pyx_n_s_factoriser_entier);
  Py_VISIT(traverse_module_state->__pyx_n_s_factoriser_sur_C);
  Py_VISIT(traverse_module_state->__pyx_n_s_factors);
  Py_VISIT(traverse_module_state->__pyx_n_s_fadeev);
  Py_VISIT(traverse_module_state->__pyx_kp_s_failed_to_init_doc_from_giac_s_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_faire);
  Py_VISIT(traverse_module_state->__pyx_n_s_false);
  Py_VISIT(traverse_module_state->__pyx_n_s_falsepos_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_fath);
  Py_VISIT(traverse_module_state->__pyx_n_s_faux);
  Py_VISIT(traverse_module_state->__pyx_n_s_fbm);
  Py_VISIT(traverse_module_state->__pyx_n_s_fc);
  Py_VISIT(traverse_module_state->__pyx_n_s_fclose);
  Py_VISIT(traverse_module_state->__pyx_n_s_fcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_fdistrib);
  Py_VISIT(traverse_module_state->__pyx_n_s_fermi);
  Py_VISIT(traverse_module_state->__pyx_n_s_feuille);
  Py_VISIT(traverse_module_state->__pyx_n_s_ffaire);
  Py_VISIT(traverse_module_state->__pyx_n_s_ffonction);
  Py_VISIT(traverse_module_state->__pyx_n_s_fft);
  Py_VISIT(traverse_module_state->__pyx_n_s_ffunction);
  Py_VISIT(traverse_module_state->__pyx_n_s_fi);
  Py_VISIT(traverse_module_state->__pyx_n_s_fieldplot);
  Py_VISIT(traverse_module_state->__pyx_kp_s_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_filled);
  Py_VISIT(traverse_module_state->__pyx_n_s_fin_enregistrement);
  Py_VISIT(traverse_module_state->__pyx_n_s_find);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_cliques);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_cycles);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_minimum);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_vertex_cover);
  Py_VISIT(traverse_module_state->__pyx_n_s_findhelp);
  Py_VISIT(traverse_module_state->__pyx_n_s_fisher);
  Py_VISIT(traverse_module_state->__pyx_n_s_fisher_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_fisher_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_fisherd);
  Py_VISIT(traverse_module_state->__pyx_n_s_fisherd_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_fisherd_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_fitdistr);
  Py_VISIT(traverse_module_state->__pyx_n_s_fitpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_fitspline);
  Py_VISIT(traverse_module_state->__pyx_n_s_flam);
  Py_VISIT(traverse_module_state->__pyx_n_s_flatten);
  Py_VISIT(traverse_module_state->__pyx_n_s_float);
  Py_VISIT(traverse_module_state->__pyx_n_s_float2rational);
  Py_VISIT(traverse_module_state->__pyx_n_s_floor);
  Py_VISIT(traverse_module_state->__pyx_n_s_flow_polynomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_flower_snark);
  Py_VISIT(traverse_module_state->__pyx_n_s_fm);
  Py_VISIT(traverse_module_state->__pyx_n_s_fmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_foldl);
  Py_VISIT(traverse_module_state->__pyx_n_s_foldr);
  Py_VISIT(traverse_module_state->__pyx_n_s_fonction);
  Py_VISIT(traverse_module_state->__pyx_n_s_fonction_derivee);
  Py_VISIT(traverse_module_state->__pyx_n_s_fopen);
  Py_VISIT(traverse_module_state->__pyx_n_s_for);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_forward);
  Py_VISIT(traverse_module_state->__pyx_n_s_fourier);
  Py_VISIT(traverse_module_state->__pyx_n_s_fourier_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_fourier_bn);
  Py_VISIT(traverse_module_state->__pyx_n_s_fourier_cn);
  Py_VISIT(traverse_module_state->__pyx_n_s_fpour);
  Py_VISIT(traverse_module_state->__pyx_n_s_fprint);
  Py_VISIT(traverse_module_state->__pyx_n_s_fr);
  Py_VISIT(traverse_module_state->__pyx_n_s_frac);
  Py_VISIT(traverse_module_state->__pyx_n_s_fracmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_frame_2d);
  Py_VISIT(traverse_module_state->__pyx_n_s_frame_3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_frames);
  Py_VISIT(traverse_module_state->__pyx_n_s_frank_wolfe);
  Py_VISIT(traverse_module_state->__pyx_n_s_frequencies);
  Py_VISIT(traverse_module_state->__pyx_n_s_frobenius_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_from);
  Py_VISIT(traverse_module_state->__pyx_kp_s_from_giac_s_help);
  Py_VISIT(traverse_module_state->__pyx_kp_u_from_giacpy_import_giac_giac_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_froot);
  Py_VISIT(traverse_module_state->__pyx_n_s_fsi);
  Py_VISIT(traverse_module_state->__pyx_n_s_fsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_ft);
  Py_VISIT(traverse_module_state->__pyx_n_s_ftUS);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ft_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ft_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ft_lb);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ft_lb_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_ft_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_ftantque);
  Py_VISIT(traverse_module_state->__pyx_n_s_fullparfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_func);
  Py_VISIT(traverse_module_state->__pyx_n_s_funcplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_function);
  Py_VISIT(traverse_module_state->__pyx_n_s_function_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_fundamental_cycle);
  Py_VISIT(traverse_module_state->__pyx_n_s_fxnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_g_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ga);
  Py_VISIT(traverse_module_state->__pyx_n_s_galC);
  Py_VISIT(traverse_module_state->__pyx_n_s_galUK);
  Py_VISIT(traverse_module_state->__pyx_n_s_galUS);
  Py_VISIT(traverse_module_state->__pyx_n_s_gammad);
  Py_VISIT(traverse_module_state->__pyx_n_s_gammad_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_gammad_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_gammavariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_gauche);
  Py_VISIT(traverse_module_state->__pyx_n_s_gauss);
  Py_VISIT(traverse_module_state->__pyx_n_s_gauss15);
  Py_VISIT(traverse_module_state->__pyx_n_s_gauss_seidel_linsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_gaussian_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_gaussjord);
  Py_VISIT(traverse_module_state->__pyx_n_s_gaussquad);
  Py_VISIT(traverse_module_state->__pyx_n_s_gbasis);
  Py_VISIT(traverse_module_state->__pyx_n_s_gbasis_max_pairs);
  Py_VISIT(traverse_module_state->__pyx_n_s_gbasis_reinject);
  Py_VISIT(traverse_module_state->__pyx_n_s_gbasis_simult_primes);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_gcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_gcdex);
  Py_VISIT(traverse_module_state->__pyx_kp_s_gen_indexes_are_not_yet_implemen);
  Py_VISIT(traverse_module_state->__pyx_n_s_genpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_geodetic2ecef);
  Py_VISIT(traverse_module_state->__pyx_n_s_geometric);
  Py_VISIT(traverse_module_state->__pyx_n_s_geometric_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_geometric_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_getDenom);
  Py_VISIT(traverse_module_state->__pyx_n_s_getKey);
  Py_VISIT(traverse_module_state->__pyx_n_s_getNum);
  Py_VISIT(traverse_module_state->__pyx_n_s_getType);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_edge_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_edge_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_graph_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_vertex_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_gf);
  Py_VISIT(traverse_module_state->__pyx_n_s_giac);
  Py_VISIT(traverse_module_state->__pyx_kp_s_giac_docs_dir_not_found);
  Py_VISIT(traverse_module_state->__pyx_kp_u_giac_line_163);
  Py_VISIT(traverse_module_state->__pyx_n_s_giacbasedir);
  Py_VISIT(traverse_module_state->__pyx_n_s_giacpy2qcas);
  Py_VISIT(traverse_module_state->__pyx_kp_s_giacpy_auto_methods_pxi);
  Py_VISIT(traverse_module_state->__pyx_n_s_giacpy_giacpy);
  Py_VISIT(traverse_module_state->__pyx_kp_s_giacpy_giacpy_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_giacsettings);
  Py_VISIT(traverse_module_state->__pyx_n_s_girth);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_ortho);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_quaternion);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_rotation);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_showaxes);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_shownames);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_texture);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_x);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_x_axis_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_x_axis_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_x_axis_unit);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_xtick);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_y_axis_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_y_axis_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_y_axis_unit);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_ytick);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_z_axis_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_z_axis_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_z_axis_unit);
  Py_VISIT(traverse_module_state->__pyx_n_s_gl_ztick);
  Py_VISIT(traverse_module_state->__pyx_n_s_gmol);
  Py_VISIT(traverse_module_state->__pyx_n_s_gnuplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_gold);
  Py_VISIT(traverse_module_state->__pyx_n_s_goldberg_snark);
  Py_VISIT(traverse_module_state->__pyx_n_s_gon);
  Py_VISIT(traverse_module_state->__pyx_n_s_goto);
  Py_VISIT(traverse_module_state->__pyx_n_s_grad);
  Py_VISIT(traverse_module_state->__pyx_n_s_grad_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_grain);
  Py_VISIT(traverse_module_state->__pyx_n_s_gramschmidt);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph2tex);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph3d2tex);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_automorphisms);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_charpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_complement);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_diameter);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_equal);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_power);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_rank);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_union);
  Py_VISIT(traverse_module_state->__pyx_n_s_graph_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_graphe);
  Py_VISIT(traverse_module_state->__pyx_n_s_graphe3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_graphe_probabiliste);
  Py_VISIT(traverse_module_state->__pyx_n_s_graphe_suite);
  Py_VISIT(traverse_module_state->__pyx_n_s_greduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_greedy_clique);
  Py_VISIT(traverse_module_state->__pyx_n_s_greedy_color);
  Py_VISIT(traverse_module_state->__pyx_n_s_greedy_independent_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_green);
  Py_VISIT(traverse_module_state->__pyx_n_s_grey);
  Py_VISIT(traverse_module_state->__pyx_n_s_grid_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_grid_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_groupermu);
  Py_VISIT(traverse_module_state->__pyx_n_s_h);
  Py_VISIT(traverse_module_state->__pyx_n_s_h_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ha);
  Py_VISIT(traverse_module_state->__pyx_n_s_haar_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_hadamard);
  Py_VISIT(traverse_module_state->__pyx_n_s_half_cone);
  Py_VISIT(traverse_module_state->__pyx_n_s_half_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_halftan);
  Py_VISIT(traverse_module_state->__pyx_n_s_halftan_hyp2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_halt);
  Py_VISIT(traverse_module_state->__pyx_n_s_hamdist);
  Py_VISIT(traverse_module_state->__pyx_n_s_hamming);
  Py_VISIT(traverse_module_state->__pyx_n_s_hamming_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_hann_poisson_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_hann_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_harmonic_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_harmonic_conjugate);
  Py_VISIT(traverse_module_state->__pyx_n_s_harmonic_division);
  Py_VISIT(traverse_module_state->__pyx_n_s_has);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_arc);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_edge);
  Py_VISIT(traverse_module_state->__pyx_n_s_hasard);
  Py_VISIT(traverse_module_state->__pyx_n_s_hbar);
  Py_VISIT(traverse_module_state->__pyx_n_s_head);
  Py_VISIT(traverse_module_state->__pyx_n_s_heading);
  Py_VISIT(traverse_module_state->__pyx_n_s_heapify);
  Py_VISIT(traverse_module_state->__pyx_n_s_heappop);
  Py_VISIT(traverse_module_state->__pyx_n_s_heappush);
  Py_VISIT(traverse_module_state->__pyx_n_s_help);
  Py_VISIT(traverse_module_state->__pyx_n_s_hermite);
  Py_VISIT(traverse_module_state->__pyx_n_s_hessenberg);
  Py_VISIT(traverse_module_state->__pyx_n_s_hessian);
  Py_VISIT(traverse_module_state->__pyx_n_s_heugcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_hexagon);
  Py_VISIT(traverse_module_state->__pyx_n_s_hht);
  Py_VISIT(traverse_module_state->__pyx_n_s_hidden_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_highlight_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_highlight_subgraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_highlight_trail);
  Py_VISIT(traverse_module_state->__pyx_n_s_highlight_vertex);
  Py_VISIT(traverse_module_state->__pyx_n_s_highpass);
  Py_VISIT(traverse_module_state->__pyx_n_s_hilbert);
  Py_VISIT(traverse_module_state->__pyx_n_s_histogram);
  Py_VISIT(traverse_module_state->__pyx_n_s_hold);
  Py_VISIT(traverse_module_state->__pyx_n_s_homogeneize);
  Py_VISIT(traverse_module_state->__pyx_n_s_homothety);
  Py_VISIT(traverse_module_state->__pyx_n_s_horner);
  Py_VISIT(traverse_module_state->__pyx_n_s_hp);
  Py_VISIT(traverse_module_state->__pyx_n_s_hsv);
  Py_VISIT(traverse_module_state->__pyx_n_s_hsv2rgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_htmlhelp);
  Py_VISIT(traverse_module_state->__pyx_kp_u_htmlhelp_line_1849);
  Py_VISIT(traverse_module_state->__pyx_kp_s_http_www_fourier_ujf_grenoble_fr);
  Py_VISIT(traverse_module_state->__pyx_n_s_hybrid_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_hybridj_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_hybrids_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_hybridsj_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_hyp2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_hyperbola);
  Py_VISIT(traverse_module_state->__pyx_n_s_hypercube_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_iPart);
  Py_VISIT(traverse_module_state->__pyx_kp_s_i_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_iabcuv);
  Py_VISIT(traverse_module_state->__pyx_n_s_ibasis);
  Py_VISIT(traverse_module_state->__pyx_n_s_ibpdv);
  Py_VISIT(traverse_module_state->__pyx_n_s_ibpu);
  Py_VISIT(traverse_module_state->__pyx_n_s_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_ichinrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_ichrem);
  Py_VISIT(traverse_module_state->__pyx_n_s_icomp);
  Py_VISIT(traverse_module_state->__pyx_n_s_icontent);
  Py_VISIT(traverse_module_state->__pyx_n_s_icosahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_identifier);
  Py_VISIT(traverse_module_state->__pyx_n_s_identify_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_identity);
  Py_VISIT(traverse_module_state->__pyx_n_s_idivis);
  Py_VISIT(traverse_module_state->__pyx_n_s_idn);
  Py_VISIT(traverse_module_state->__pyx_n_s_idwt);
  Py_VISIT(traverse_module_state->__pyx_n_s_iegcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_if);
  Py_VISIT(traverse_module_state->__pyx_n_s_ifactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_ifactors);
  Py_VISIT(traverse_module_state->__pyx_n_s_ifft);
  Py_VISIT(traverse_module_state->__pyx_n_s_ifourier);
  Py_VISIT(traverse_module_state->__pyx_n_s_ifte);
  Py_VISIT(traverse_module_state->__pyx_n_s_igamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_igcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_igcdex);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignored);
  Py_VISIT(traverse_module_state->__pyx_n_s_ihermite);
  Py_VISIT(traverse_module_state->__pyx_n_s_ilaplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_im);
  Py_VISIT(traverse_module_state->__pyx_n_s_imag);
  Py_VISIT(traverse_module_state->__pyx_n_s_image);
  Py_VISIT(traverse_module_state->__pyx_n_s_imfplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_implicitdiff);
  Py_VISIT(traverse_module_state->__pyx_n_s_implicitplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_import_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_inH20);
  Py_VISIT(traverse_module_state->__pyx_n_s_inHg);
  Py_VISIT(traverse_module_state->__pyx_n_s_inString);
  Py_VISIT(traverse_module_state->__pyx_n_s_in_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_in_2_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_in_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_in_ideal);
  Py_VISIT(traverse_module_state->__pyx_n_s_incidence_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_incident_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_incircle);
  Py_VISIT(traverse_module_state->__pyx_n_s_increasing_power);
  Py_VISIT(traverse_module_state->__pyx_n_s_independence_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_indets);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_kp_s_index_html);
  Py_VISIT(traverse_module_state->__pyx_n_s_indices);
  Py_VISIT(traverse_module_state->__pyx_n_s_induced_subgraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_inequationplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_inertia);
  Py_VISIT(traverse_module_state->__pyx_n_s_inf);
  Py_VISIT(traverse_module_state->__pyx_n_s_infinity);
  Py_VISIT(traverse_module_state->__pyx_kp_s_infinity_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_infinity_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_information_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_input);
  Py_VISIT(traverse_module_state->__pyx_n_s_inputform);
  Py_VISIT(traverse_module_state->__pyx_n_s_insert);
  Py_VISIT(traverse_module_state->__pyx_n_s_insmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_instfreq);
  Py_VISIT(traverse_module_state->__pyx_n_s_instphase);
  Py_VISIT(traverse_module_state->__pyx_n_s_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_intDiv);
  Py_VISIT(traverse_module_state->__pyx_n_s_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_integrate);
  Py_VISIT(traverse_module_state->__pyx_n_s_integrer);
  Py_VISIT(traverse_module_state->__pyx_n_s_inter);
  Py_VISIT(traverse_module_state->__pyx_n_s_interactive_odeplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_interactive_plotode);
  Py_VISIT(traverse_module_state->__pyx_n_s_interp);
  Py_VISIT(traverse_module_state->__pyx_n_s_intersect);
  Py_VISIT(traverse_module_state->__pyx_n_s_interval);
  Py_VISIT(traverse_module_state->__pyx_n_s_interval2center);
  Py_VISIT(traverse_module_state->__pyx_n_s_interval_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_inv);
  Py_VISIT(traverse_module_state->__pyx_n_s_inverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_inversion);
  Py_VISIT(traverse_module_state->__pyx_n_s_invisible_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_invlaplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_invztrans);
  Py_VISIT(traverse_module_state->__pyx_n_s_iquo);
  Py_VISIT(traverse_module_state->__pyx_n_s_iquorem);
  Py_VISIT(traverse_module_state->__pyx_n_s_iratrecon);
  Py_VISIT(traverse_module_state->__pyx_n_s_irem);
  Py_VISIT(traverse_module_state->__pyx_n_s_isPrime);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_acyclic);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_arborescence);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_biconnected);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_bipartite);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_clique);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_collinear);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_concyclic);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_conjugate);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_connected);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coplanar);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_cospherical);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_cut_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_cycle);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_directed);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_element);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_equilateral);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_eulerian);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_forest);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_graphic_sequence);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_hamiltonian);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_harmonic);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_harmonic_circle_bundle);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_harmonic_line_bundle);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_included);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_inside);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_integer_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_irreducible);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_isomorphic);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_isosceles);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_network);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_orthogonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_parallel);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_parallelogram);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_permu);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_perpendicular);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_planar);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_prime);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_pseudoprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_reachable);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_regular);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_rhombus);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_split_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_square);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_strongly_connected);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_strongly_regular);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_subgraph_isomorphic);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_tournament);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_triconnected);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_two_edge_connected);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_vertex_colorable);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_weighted);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_isinf);
  Py_VISIT(traverse_module_state->__pyx_n_s_ismith);
  Py_VISIT(traverse_module_state->__pyx_n_s_isnan);
  Py_VISIT(traverse_module_state->__pyx_n_s_isobarycenter);
  Py_VISIT(traverse_module_state->__pyx_n_s_isolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_isom);
  Py_VISIT(traverse_module_state->__pyx_n_s_isomorphic_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_isopolygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_isosceles_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_isposdef);
  Py_VISIT(traverse_module_state->__pyx_n_s_isprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_istft);
  Py_VISIT(traverse_module_state->__pyx_n_s_iter);
  Py_VISIT(traverse_module_state->__pyx_n_s_ithprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_j);
  Py_VISIT(traverse_module_state->__pyx_n_s_jacobi_equation);
  Py_VISIT(traverse_module_state->__pyx_n_s_jacobi_linsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_jacobi_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_johnson_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_jordan);
  Py_VISIT(traverse_module_state->__pyx_n_s_jusqu_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_jusqua);
  Py_VISIT(traverse_module_state->__pyx_n_s_jusque);
  Py_VISIT(traverse_module_state->__pyx_n_s_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_kWh);
  Py_VISIT(traverse_module_state->__pyx_n_s_katz_centrality);
  Py_VISIT(traverse_module_state->__pyx_n_s_kde);
  Py_VISIT(traverse_module_state->__pyx_n_s_keep_algext);
  Py_VISIT(traverse_module_state->__pyx_n_s_keep_pivot);
  Py_VISIT(traverse_module_state->__pyx_n_s_ker);
  Py_VISIT(traverse_module_state->__pyx_n_s_kernel);
  Py_VISIT(traverse_module_state->__pyx_n_s_kernel_density);
  Py_VISIT(traverse_module_state->__pyx_n_s_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_kill);
  Py_VISIT(traverse_module_state->__pyx_kp_s_killing_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_kip);
  Py_VISIT(traverse_module_state->__pyx_n_s_km);
  Py_VISIT(traverse_module_state->__pyx_kp_s_km_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_kmeans);
  Py_VISIT(traverse_module_state->__pyx_n_s_kneser_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_knot);
  Py_VISIT(traverse_module_state->__pyx_n_s_kolmogorovd);
  Py_VISIT(traverse_module_state->__pyx_n_s_kolmogorovt);
  Py_VISIT(traverse_module_state->__pyx_n_s_kovacicsols);
  Py_VISIT(traverse_module_state->__pyx_n_s_kph);
  Py_VISIT(traverse_module_state->__pyx_n_s_kq);
  Py_VISIT(traverse_module_state->__pyx_n_s_kspaths);
  Py_VISIT(traverse_module_state->__pyx_n_s_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_l1norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_l2norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_l_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_label);
  Py_VISIT(traverse_module_state->__pyx_n_s_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_lagrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_laguerre);
  Py_VISIT(traverse_module_state->__pyx_n_s_lam);
  Py_VISIT(traverse_module_state->__pyx_n_s_lambda0);
  Py_VISIT(traverse_module_state->__pyx_n_s_lambdac);
  Py_VISIT(traverse_module_state->__pyx_n_s_lang);
  Py_VISIT(traverse_module_state->__pyx_n_s_laplace);
  Py_VISIT(traverse_module_state->__pyx_n_s_laplacian);
  Py_VISIT(traverse_module_state->__pyx_n_s_laplacian_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_latex);
  Py_VISIT(traverse_module_state->__pyx_n_s_lb);
  Py_VISIT(traverse_module_state->__pyx_n_s_lbf);
  Py_VISIT(traverse_module_state->__pyx_n_s_lbmol);
  Py_VISIT(traverse_module_state->__pyx_n_s_lbt);
  Py_VISIT(traverse_module_state->__pyx_n_s_lcf_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_lcm);
  Py_VISIT(traverse_module_state->__pyx_n_s_lcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_ldegree);
  Py_VISIT(traverse_module_state->__pyx_n_s_ldl);
  Py_VISIT(traverse_module_state->__pyx_n_s_learning_rate);
  Py_VISIT(traverse_module_state->__pyx_n_s_left);
  Py_VISIT(traverse_module_state->__pyx_n_s_left_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_legend);
  Py_VISIT(traverse_module_state->__pyx_n_s_legendre);
  Py_VISIT(traverse_module_state->__pyx_n_s_legendre_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_length);
  Py_VISIT(traverse_module_state->__pyx_n_s_lep);
  Py_VISIT(traverse_module_state->__pyx_n_s_leve_crayon);
  Py_VISIT(traverse_module_state->__pyx_n_s_levenshtein);
  Py_VISIT(traverse_module_state->__pyx_n_s_lgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_lhs);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_chapeau_carre);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_chapeau_plat);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_chapeau_rond);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_polygonale);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_polygonale_pointee);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_tiret);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_tiret_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_tiret_pointpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_ligne_trait_plein);
  Py_VISIT(traverse_module_state->__pyx_n_s_limit);
  Py_VISIT(traverse_module_state->__pyx_n_s_limite);
  Py_VISIT(traverse_module_state->__pyx_n_s_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_linabs);
  Py_VISIT(traverse_module_state->__pyx_n_s_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_inter);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_segments);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_width_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_linear_interpolate);
  Py_VISIT(traverse_module_state->__pyx_n_s_linear_regression);
  Py_VISIT(traverse_module_state->__pyx_n_s_linear_regression_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_lineariser);
  Py_VISIT(traverse_module_state->__pyx_n_s_lineariser_trigo);
  Py_VISIT(traverse_module_state->__pyx_n_s_linfnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_linsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_linspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_linstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_liqpt);
  Py_VISIT(traverse_module_state->__pyx_n_s_lis);
  Py_VISIT(traverse_module_state->__pyx_n_s_lis_phrase);
  Py_VISIT(traverse_module_state->__pyx_n_s_list);
  Py_VISIT(traverse_module_state->__pyx_n_s_list2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_list2mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_edge_attributes);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_graph_attributes);
  Py_VISIT(traverse_module_state->__pyx_kp_s_list_index_s_out_of_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_list_vertex_attributes);
  Py_VISIT(traverse_module_state->__pyx_n_s_listplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_listrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_lll);
  Py_VISIT(traverse_module_state->__pyx_n_s_lm);
  Py_VISIT(traverse_module_state->__pyx_n_s_ln);
  Py_VISIT(traverse_module_state->__pyx_n_s_lname);
  Py_VISIT(traverse_module_state->__pyx_n_s_lncollect);
  Py_VISIT(traverse_module_state->__pyx_n_s_lnexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_loadgiacgen);
  Py_VISIT(traverse_module_state->__pyx_kp_u_loadgiacgen_line_2106);
  Py_VISIT(traverse_module_state->__pyx_n_s_local);
  Py_VISIT(traverse_module_state->__pyx_n_s_locus);
  Py_VISIT(traverse_module_state->__pyx_n_s_log);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10);
  Py_VISIT(traverse_module_state->__pyx_n_s_log2);
  Py_VISIT(traverse_module_state->__pyx_n_s_log_loss);
  Py_VISIT(traverse_module_state->__pyx_n_s_logarithmic_regression);
  Py_VISIT(traverse_module_state->__pyx_n_s_logarithmic_regression_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_logb);
  Py_VISIT(traverse_module_state->__pyx_n_s_logistic);
  Py_VISIT(traverse_module_state->__pyx_n_s_logistic_regression);
  Py_VISIT(traverse_module_state->__pyx_n_s_logistic_regression_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_long);
  Py_VISIT(traverse_module_state->__pyx_n_s_lower);
  Py_VISIT(traverse_module_state->__pyx_n_s_lowest_common_ancestor);
  Py_VISIT(traverse_module_state->__pyx_n_s_lowpass);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_assume);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_bestlocalbound);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_bestprojection);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_binary);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_binaryvariables);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_breadthfirst);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_depthfirst);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_depthlimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_firstfractional);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_gaptolerance);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_heuristic);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_hybrid);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_integervariables);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_interiorpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_iterationlimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_lastfractional);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_maxcuts);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_maximize);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_method);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_mostfractional);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_nodelimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_nodeselect);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_nonnegative);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_nonnegint);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_presolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_pseudocost);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_simplex);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_timelimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_varselect);
  Py_VISIT(traverse_module_state->__pyx_n_s_lp_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_lpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_lsmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_lsq);
  Py_VISIT(traverse_module_state->__pyx_n_s_lu);
  Py_VISIT(traverse_module_state->__pyx_n_s_lvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_lx);
  Py_VISIT(traverse_module_state->__pyx_n_s_lyr);
  Py_VISIT(traverse_module_state->__pyx_n_s_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_mEarth);
  Py_VISIT(traverse_module_state->__pyx_n_s_mRow);
  Py_VISIT(traverse_module_state->__pyx_n_s_mRowAdd);
  Py_VISIT(traverse_module_state->__pyx_kp_s_m_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_m_3);
  Py_VISIT(traverse_module_state->__pyx_kp_s_m_s);
  Py_VISIT(traverse_module_state->__pyx_kp_s_m_s_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_magenta);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_directed);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_weighted);
  Py_VISIT(traverse_module_state->__pyx_n_s_makelist);
  Py_VISIT(traverse_module_state->__pyx_n_s_makemat);
  Py_VISIT(traverse_module_state->__pyx_n_s_makesuite);
  Py_VISIT(traverse_module_state->__pyx_n_s_makevector);
  Py_VISIT(traverse_module_state->__pyx_n_s_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_maple2mupad);
  Py_VISIT(traverse_module_state->__pyx_n_s_maple2xcas);
  Py_VISIT(traverse_module_state->__pyx_n_s_maple_ifactors);
  Py_VISIT(traverse_module_state->__pyx_n_s_maple_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_markov);
  Py_VISIT(traverse_module_state->__pyx_n_s_mat2list);
  Py_VISIT(traverse_module_state->__pyx_n_s_math);
  Py_VISIT(traverse_module_state->__pyx_n_s_mathml);
  Py_VISIT(traverse_module_state->__pyx_n_s_matpow);
  Py_VISIT(traverse_module_state->__pyx_n_s_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_matrix_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxcount);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxflow);
  Py_VISIT(traverse_module_state->__pyx_n_s_maximal_independent_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_maximize);
  Py_VISIT(traverse_module_state->__pyx_n_s_maximum_clique);
  Py_VISIT(traverse_module_state->__pyx_n_s_maximum_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_maximum_independent_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_maximum_matching);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxsize);
  Py_VISIT(traverse_module_state->__pyx_n_s_me);
  Py_VISIT(traverse_module_state->__pyx_n_s_mean);
  Py_VISIT(traverse_module_state->__pyx_n_s_median);
  Py_VISIT(traverse_module_state->__pyx_n_s_median_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_member);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_mgf);
  Py_VISIT(traverse_module_state->__pyx_n_s_mho);
  Py_VISIT(traverse_module_state->__pyx_n_s_miUS);
  Py_VISIT(traverse_module_state->__pyx_kp_s_miUS_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_mi_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_mid);
  Py_VISIT(traverse_module_state->__pyx_n_s_middle_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_midpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_mil);
  Py_VISIT(traverse_module_state->__pyx_n_s_mile);
  Py_VISIT(traverse_module_state->__pyx_n_s_mille);
  Py_VISIT(traverse_module_state->__pyx_n_s_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimal_edge_coloring);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimal_spanning_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimal_vertex_coloring);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimax);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimize);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimum_cut);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimum_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_minimum_vertex_cover);
  Py_VISIT(traverse_module_state->__pyx_n_s_minus);
  Py_VISIT(traverse_module_state->__pyx_n_s_mixdown);
  Py_VISIT(traverse_module_state->__pyx_n_s_mkisom);
  Py_VISIT(traverse_module_state->__pyx_n_s_mksa);
  Py_VISIT(traverse_module_state->__pyx_n_s_ml);
  Py_VISIT(traverse_module_state->__pyx_n_s_mm);
  Py_VISIT(traverse_module_state->__pyx_n_s_mmHg);
  Py_VISIT(traverse_module_state->__pyx_n_s_mn);
  Py_VISIT(traverse_module_state->__pyx_n_s_mod);
  Py_VISIT(traverse_module_state->__pyx_n_s_modf);
  Py_VISIT(traverse_module_state->__pyx_n_s_modgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_mods);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_mol);
  Py_VISIT(traverse_module_state->__pyx_n_s_momentum);
  Py_VISIT(traverse_module_state->__pyx_n_s_monotonic);
  Py_VISIT(traverse_module_state->__pyx_n_s_montre_tortue);
  Py_VISIT(traverse_module_state->__pyx_n_s_moremethods);
  Py_VISIT(traverse_module_state->__pyx_n_s_moretests);
  Py_VISIT(traverse_module_state->__pyx_kp_u_moretests_line_2061);
  Py_VISIT(traverse_module_state->__pyx_n_s_mostkeywords);
  Py_VISIT(traverse_module_state->__pyx_n_s_moustache);
  Py_VISIT(traverse_module_state->__pyx_n_s_moving_average);
  Py_VISIT(traverse_module_state->__pyx_n_s_moyal);
  Py_VISIT(traverse_module_state->__pyx_n_s_moyenne);
  Py_VISIT(traverse_module_state->__pyx_n_s_mp);
  Py_VISIT(traverse_module_state->__pyx_n_s_mph);
  Py_VISIT(traverse_module_state->__pyx_n_s_mpme);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_s_mu0);
  Py_VISIT(traverse_module_state->__pyx_n_s_muB);
  Py_VISIT(traverse_module_state->__pyx_n_s_muN);
  Py_VISIT(traverse_module_state->__pyx_n_s_mul);
  Py_VISIT(traverse_module_state->__pyx_n_s_mul_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_mult_c_conjugate);
  Py_VISIT(traverse_module_state->__pyx_n_s_mult_conjugate);
  Py_VISIT(traverse_module_state->__pyx_n_s_multinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_multiplier_conjugue);
  Py_VISIT(traverse_module_state->__pyx_n_s_multiplier_conjugue_complexe);
  Py_VISIT(traverse_module_state->__pyx_n_s_multiply);
  Py_VISIT(traverse_module_state->__pyx_n_s_mupad2maple);
  Py_VISIT(traverse_module_state->__pyx_n_s_mupad2xcas);
  Py_VISIT(traverse_module_state->__pyx_n_s_mycielski);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_nCr);
  Py_VISIT(traverse_module_state->__pyx_n_s_nDeriv);
  Py_VISIT(traverse_module_state->__pyx_n_s_nInt);
  Py_VISIT(traverse_module_state->__pyx_n_s_nPr);
  Py_VISIT(traverse_module_state->__pyx_n_s_nSolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_navy);
  Py_VISIT(traverse_module_state->__pyx_n_s_ncols);
  Py_VISIT(traverse_module_state->__pyx_n_s_neg);
  Py_VISIT(traverse_module_state->__pyx_n_s_negbinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_negbinomial_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_negbinomial_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_neighbors);
  Py_VISIT(traverse_module_state->__pyx_n_s_network_transitivity);
  Py_VISIT(traverse_module_state->__pyx_n_s_neural_network);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_newList);
  Py_VISIT(traverse_module_state->__pyx_n_s_newMat);
  Py_VISIT(traverse_module_state->__pyx_n_s_newton);
  Py_VISIT(traverse_module_state->__pyx_n_s_newton_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_newtonj_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_nextperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_nextprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_binary);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_binaryvariables);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_initialpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_integer);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_integervariables);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_iterationlimit);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_maximize);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_method);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_nonnegative);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_nonnegint);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_precision);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_presolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_tolerance);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlp_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_nlpsolve);
  Py_VISIT(traverse_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_VISIT(traverse_module_state->__pyx_n_s_nodisp);
  Py_VISIT(traverse_module_state->__pyx_n_s_noir);
  Py_VISIT(traverse_module_state->__pyx_n_s_nom_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_non);
  Py_VISIT(traverse_module_state->__pyx_n_s_non_recursive_normal);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonevaluable);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonnegint);
  Py_VISIT(traverse_module_state->__pyx_n_s_nop);
  Py_VISIT(traverse_module_state->__pyx_n_s_nops);
  Py_VISIT(traverse_module_state->__pyx_n_s_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_normal);
  Py_VISIT(traverse_module_state->__pyx_n_s_normal_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_normal_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_normald);
  Py_VISIT(traverse_module_state->__pyx_n_s_normald_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_normald_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_normalize);
  Py_VISIT(traverse_module_state->__pyx_n_s_normalt);
  Py_VISIT(traverse_module_state->__pyx_n_s_normalvariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_not);
  Py_VISIT(traverse_module_state->__pyx_n_s_nprimes);
  Py_VISIT(traverse_module_state->__pyx_n_s_nrows);
  Py_VISIT(traverse_module_state->__pyx_n_s_nstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_nuage_points);
  Py_VISIT(traverse_module_state->__pyx_n_s_nullspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_number_of_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_number_of_spanning_trees);
  Py_VISIT(traverse_module_state->__pyx_n_s_number_of_triangles);
  Py_VISIT(traverse_module_state->__pyx_n_s_number_of_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_numdiff);
  Py_VISIT(traverse_module_state->__pyx_n_s_numer);
  Py_VISIT(traverse_module_state->__pyx_n_s_octahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_od);
  Py_VISIT(traverse_module_state->__pyx_n_s_odd);
  Py_VISIT(traverse_module_state->__pyx_n_s_odd_girth);
  Py_VISIT(traverse_module_state->__pyx_n_s_odd_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_odeplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_odesolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_of);
  Py_VISIT(traverse_module_state->__pyx_n_s_oldies);
  Py_VISIT(traverse_module_state->__pyx_n_s_olive);
  Py_VISIT(traverse_module_state->__pyx_n_s_op);
  Py_VISIT(traverse_module_state->__pyx_n_s_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_open_polygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_option);
  Py_VISIT(traverse_module_state->__pyx_n_s_or);
  Py_VISIT(traverse_module_state->__pyx_n_s_orange);
  Py_VISIT(traverse_module_state->__pyx_n_s_ord);
  Py_VISIT(traverse_module_state->__pyx_n_s_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_order_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_ordinate);
  Py_VISIT(traverse_module_state->__pyx_n_s_orthocenter);
  Py_VISIT(traverse_module_state->__pyx_n_s_orthogonal);
  Py_VISIT(traverse_module_state->__pyx_n_s_os);
  Py_VISIT(traverse_module_state->__pyx_n_s_osculating_circle);
  Py_VISIT(traverse_module_state->__pyx_n_s_otherwise);
  Py_VISIT(traverse_module_state->__pyx_n_s_ou);
  Py_VISIT(traverse_module_state->__pyx_n_s_output);
  Py_VISIT(traverse_module_state->__pyx_n_s_oz);
  Py_VISIT(traverse_module_state->__pyx_n_s_ozUK);
  Py_VISIT(traverse_module_state->__pyx_n_s_ozfl);
  Py_VISIT(traverse_module_state->__pyx_n_s_ozt);
  Py_VISIT(traverse_module_state->__pyx_n_s_p1oc2);
  Py_VISIT(traverse_module_state->__pyx_n_s_p1op2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pa2b2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pade);
  Py_VISIT(traverse_module_state->__pyx_n_s_paley_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_parabola);
  Py_VISIT(traverse_module_state->__pyx_n_s_parallel);
  Py_VISIT(traverse_module_state->__pyx_n_s_parallelepiped);
  Py_VISIT(traverse_module_state->__pyx_n_s_parallelogram);
  Py_VISIT(traverse_module_state->__pyx_n_s_param);
  Py_VISIT(traverse_module_state->__pyx_n_s_parameq);
  Py_VISIT(traverse_module_state->__pyx_n_s_parameter);
  Py_VISIT(traverse_module_state->__pyx_n_s_paramplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_parfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_pari);
  Py_VISIT(traverse_module_state->__pyx_n_s_part);
  Py_VISIT(traverse_module_state->__pyx_n_s_partfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_parzen_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_pas);
  Py_VISIT(traverse_module_state->__pyx_n_s_pas_de_cote);
  Py_VISIT(traverse_module_state->__pyx_n_s_path_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_pc);
  Py_VISIT(traverse_module_state->__pyx_n_s_pcar);
  Py_VISIT(traverse_module_state->__pyx_n_s_pcar_hessenberg);
  Py_VISIT(traverse_module_state->__pyx_n_s_pcoef);
  Py_VISIT(traverse_module_state->__pyx_n_s_pcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_pdl);
  Py_VISIT(traverse_module_state->__pyx_n_s_pencolor);
  Py_VISIT(traverse_module_state->__pyx_n_s_pendown);
  Py_VISIT(traverse_module_state->__pyx_n_s_penup);
  Py_VISIT(traverse_module_state->__pyx_n_s_perimeter);
  Py_VISIT(traverse_module_state->__pyx_n_s_perimeterat);
  Py_VISIT(traverse_module_state->__pyx_n_s_perimeteratraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_period);
  Py_VISIT(traverse_module_state->__pyx_n_s_periodic);
  Py_VISIT(traverse_module_state->__pyx_n_s_perm);
  Py_VISIT(traverse_module_state->__pyx_n_s_perminv);
  Py_VISIT(traverse_module_state->__pyx_n_s_permu2cycles);
  Py_VISIT(traverse_module_state->__pyx_n_s_permu2mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_permuorder);
  Py_VISIT(traverse_module_state->__pyx_n_s_permute_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_perpen_bisector);
  Py_VISIT(traverse_module_state->__pyx_n_s_perpendicular);
  Py_VISIT(traverse_module_state->__pyx_n_s_petersen_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_peval);
  Py_VISIT(traverse_module_state->__pyx_n_s_ph);
  Py_VISIT(traverse_module_state->__pyx_n_s_phi);
  Py_VISIT(traverse_module_state->__pyx_n_s_pi);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_pie);
  Py_VISIT(traverse_module_state->__pyx_n_s_piecewise);
  Py_VISIT(traverse_module_state->__pyx_n_s_pink);
  Py_VISIT(traverse_module_state->__pyx_n_s_pivot);
  Py_VISIT(traverse_module_state->__pyx_n_s_pixoff);
  Py_VISIT(traverse_module_state->__pyx_n_s_pixon);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk);
  Py_VISIT(traverse_module_state->__pyx_n_s_planar);
  Py_VISIT(traverse_module_state->__pyx_n_s_plane);
  Py_VISIT(traverse_module_state->__pyx_n_s_plane_dual);
  Py_VISIT(traverse_module_state->__pyx_n_s_playsnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_plex);
  Py_VISIT(traverse_module_state->__pyx_n_s_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_plot3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotarea);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotcdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotcontour);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotdensity);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotfield);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotfunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotimf);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotimplicit);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotinequation);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotode);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotparam);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotpolar);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotproba);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotspectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_plotwav);
  Py_VISIT(traverse_module_state->__pyx_n_s_plus_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_pmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_pnt);
  Py_VISIT(traverse_module_state->__pyx_n_s_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_point2d);
  Py_VISIT(traverse_module_state->__pyx_n_s_point3d);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_arret);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_carre);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_croix);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_div);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_etoile);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_invisible);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_losange);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_milieu);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_plus);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_polaire);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_point_width_7);
  Py_VISIT(traverse_module_state->__pyx_n_s_poisson);
  Py_VISIT(traverse_module_state->__pyx_n_s_poisson_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_poisson_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_poisson_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_polar);
  Py_VISIT(traverse_module_state->__pyx_n_s_polar_coordinates);
  Py_VISIT(traverse_module_state->__pyx_n_s_polar_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_polarplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_pole);
  Py_VISIT(traverse_module_state->__pyx_n_s_poly2symb);
  Py_VISIT(traverse_module_state->__pyx_n_s_polyEval);
  Py_VISIT(traverse_module_state->__pyx_n_s_polygon);
  Py_VISIT(traverse_module_state->__pyx_n_s_polygone_rempli);
  Py_VISIT(traverse_module_state->__pyx_n_s_polygonplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_polygonscatterplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_polyhedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_polynom);
  Py_VISIT(traverse_module_state->__pyx_n_s_polynomial_regression);
  Py_VISIT(traverse_module_state->__pyx_n_s_polynomial_regression_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_position);
  Py_VISIT(traverse_module_state->__pyx_n_s_poslbdLMQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_posubLMQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_potential);
  Py_VISIT(traverse_module_state->__pyx_n_s_pour);
  Py_VISIT(traverse_module_state->__pyx_n_s_pow);
  Py_VISIT(traverse_module_state->__pyx_n_s_pow2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_pow_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_power_regression);
  Py_VISIT(traverse_module_state->__pyx_n_s_power_regression_plot);
  Py_VISIT(traverse_module_state->__pyx_n_s_powermod);
  Py_VISIT(traverse_module_state->__pyx_n_s_powerpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_powexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_powmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepend);
  Py_VISIT(traverse_module_state->__pyx_n_s_preval);
  Py_VISIT(traverse_module_state->__pyx_n_s_prevperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_prevprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_primpart);
  Py_VISIT(traverse_module_state->__pyx_n_s_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_printf);
  Py_VISIT(traverse_module_state->__pyx_kp_s_printpow_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_prism);
  Py_VISIT(traverse_module_state->__pyx_n_s_prism_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_proc);
  Py_VISIT(traverse_module_state->__pyx_n_s_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_program);
  Py_VISIT(traverse_module_state->__pyx_n_s_projection);
  Py_VISIT(traverse_module_state->__pyx_n_s_proot);
  Py_VISIT(traverse_module_state->__pyx_n_s_propFrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_propfrac);
  Py_VISIT(traverse_module_state->__pyx_n_s_pruefer_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_psi);
  Py_VISIT(traverse_module_state->__pyx_n_s_psrgcd);
  Py_VISIT(traverse_module_state->__pyx_n_s_ptUK);
  Py_VISIT(traverse_module_state->__pyx_n_s_ptayl);
  Py_VISIT(traverse_module_state->__pyx_n_s_purge);
  Py_VISIT(traverse_module_state->__pyx_kp_s_purge_GIACPY_TMP_NAME05026807096);
  Py_VISIT(traverse_module_state->__pyx_n_s_purple);
  Py_VISIT(traverse_module_state->__pyx_n_s_pwd);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyramid);
  Py_VISIT(traverse_module_state->__pyx_n_s_python_compat);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_capi);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_GiacMethods_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_q);
  Py_VISIT(traverse_module_state->__pyx_n_s_q2a);
  Py_VISIT(traverse_module_state->__pyx_n_s_qcas);
  Py_VISIT(traverse_module_state->__pyx_kp_u_qcas_line_1879);
  Py_VISIT(traverse_module_state->__pyx_n_s_qe);
  Py_VISIT(traverse_module_state->__pyx_n_s_qepsilon0);
  Py_VISIT(traverse_module_state->__pyx_n_s_qme);
  Py_VISIT(traverse_module_state->__pyx_n_s_qr);
  Py_VISIT(traverse_module_state->__pyx_n_s_qt);
  Py_VISIT(traverse_module_state->__pyx_n_s_quadrant1);
  Py_VISIT(traverse_module_state->__pyx_n_s_quadrant2);
  Py_VISIT(traverse_module_state->__pyx_n_s_quadrant3);
  Py_VISIT(traverse_module_state->__pyx_n_s_quadrant4);
  Py_VISIT(traverse_module_state->__pyx_n_s_quadric);
  Py_VISIT(traverse_module_state->__pyx_n_s_quadrilateral);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_quantile);
  Py_VISIT(traverse_module_state->__pyx_n_s_quartile1);
  Py_VISIT(traverse_module_state->__pyx_n_s_quartile3);
  Py_VISIT(traverse_module_state->__pyx_n_s_quartiles);
  Py_VISIT(traverse_module_state->__pyx_n_s_quest);
  Py_VISIT(traverse_module_state->__pyx_n_s_quo);
  Py_VISIT(traverse_module_state->__pyx_n_s_quorem);
  Py_VISIT(traverse_module_state->__pyx_n_s_quote);
  Py_VISIT(traverse_module_state->__pyx_n_s_r2e);
  Py_VISIT(traverse_module_state->__pyx_n_s_rad);
  Py_VISIT(traverse_module_state->__pyx_n_s_rad_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_rad_s);
  Py_VISIT(traverse_module_state->__pyx_kp_s_rad_s_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_radians);
  Py_VISIT(traverse_module_state->__pyx_n_s_radical_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_radius);
  Py_VISIT(traverse_module_state->__pyx_n_s_ramene);
  Py_VISIT(traverse_module_state->__pyx_n_s_rand);
  Py_VISIT(traverse_module_state->__pyx_n_s_randMat);
  Py_VISIT(traverse_module_state->__pyx_n_s_randNorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_randPoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_randbetad);
  Py_VISIT(traverse_module_state->__pyx_n_s_randbinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_randchisquare);
  Py_VISIT(traverse_module_state->__pyx_n_s_randexp);
  Py_VISIT(traverse_module_state->__pyx_n_s_randfisher);
  Py_VISIT(traverse_module_state->__pyx_n_s_randgammad);
  Py_VISIT(traverse_module_state->__pyx_n_s_randgeometric);
  Py_VISIT(traverse_module_state->__pyx_n_s_randint);
  Py_VISIT(traverse_module_state->__pyx_n_s_randmarkov);
  Py_VISIT(traverse_module_state->__pyx_n_s_randmatrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_randmultinomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_randnorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_random);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_bipartite_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_digraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_network);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_planar_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_regular_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_sequence_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_tournament);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_random_variable);
  Py_VISIT(traverse_module_state->__pyx_n_s_randperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_randpoisson);
  Py_VISIT(traverse_module_state->__pyx_n_s_randpoly);
  Py_VISIT(traverse_module_state->__pyx_n_s_randseed);
  Py_VISIT(traverse_module_state->__pyx_n_s_randstudent);
  Py_VISIT(traverse_module_state->__pyx_n_s_randvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_randvector);
  Py_VISIT(traverse_module_state->__pyx_n_s_randweibulld);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_rank);
  Py_VISIT(traverse_module_state->__pyx_n_s_ranm);
  Py_VISIT(traverse_module_state->__pyx_n_s_ranv);
  Py_VISIT(traverse_module_state->__pyx_n_s_rassembler_trigo);
  Py_VISIT(traverse_module_state->__pyx_n_s_rat_jordan);
  Py_VISIT(traverse_module_state->__pyx_n_s_ratinterp);
  Py_VISIT(traverse_module_state->__pyx_n_s_rational);
  Py_VISIT(traverse_module_state->__pyx_n_s_rationalroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_ratnormal);
  Py_VISIT(traverse_module_state->__pyx_n_s_rd);
  Py_VISIT(traverse_module_state->__pyx_n_s_rdiv);
  Py_VISIT(traverse_module_state->__pyx_n_s_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_reachable);
  Py_VISIT(traverse_module_state->__pyx_n_s_read);
  Py_VISIT(traverse_module_state->__pyx_n_s_readrgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_readwav);
  Py_VISIT(traverse_module_state->__pyx_n_s_real);
  Py_VISIT(traverse_module_state->__pyx_n_s_realroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_reciprocation);
  Py_VISIT(traverse_module_state->__pyx_n_s_rect);
  Py_VISIT(traverse_module_state->__pyx_n_s_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_rectangle_droit);
  Py_VISIT(traverse_module_state->__pyx_n_s_rectangle_gauche);
  Py_VISIT(traverse_module_state->__pyx_n_s_rectangle_plein);
  Py_VISIT(traverse_module_state->__pyx_n_s_rectangular_coordinates);
  Py_VISIT(traverse_module_state->__pyx_n_s_recule);
  Py_VISIT(traverse_module_state->__pyx_n_s_red);
  Py_VISIT(traverse_module_state->__pyx_n_s_redim);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduced_conic);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduced_quadric);
  Py_VISIT(traverse_module_state->__pyx_n_s_ref);
  Py_VISIT(traverse_module_state->__pyx_n_s_reflection);
  Py_VISIT(traverse_module_state->__pyx_n_s_regroup);
  Py_VISIT(traverse_module_state->__pyx_n_s_relabel_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_reliability_polynomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_rem);
  Py_VISIT(traverse_module_state->__pyx_n_s_rem_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_remain);
  Py_VISIT(traverse_module_state->__pyx_n_s_remove);
  Py_VISIT(traverse_module_state->__pyx_n_s_reorder);
  Py_VISIT(traverse_module_state->__pyx_n_s_repeat);
  Py_VISIT(traverse_module_state->__pyx_n_s_repete);
  Py_VISIT(traverse_module_state->__pyx_n_s_repeter);
  Py_VISIT(traverse_module_state->__pyx_n_s_replace);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr_html);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr_latex);
  Py_VISIT(traverse_module_state->__pyx_n_s_resample);
  Py_VISIT(traverse_module_state->__pyx_n_s_residue);
  Py_VISIT(traverse_module_state->__pyx_n_s_resoudre);
  Py_VISIT(traverse_module_state->__pyx_n_s_resoudre_dans_C);
  Py_VISIT(traverse_module_state->__pyx_n_s_resoudre_systeme_lineaire);
  Py_VISIT(traverse_module_state->__pyx_n_s_restart);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_resultant);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_reverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_reverse_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_reverse_rsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_revert);
  Py_VISIT(traverse_module_state->__pyx_n_s_revlex);
  Py_VISIT(traverse_module_state->__pyx_n_s_revlist);
  Py_VISIT(traverse_module_state->__pyx_n_s_rgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_rgb2hsv);
  Py_VISIT(traverse_module_state->__pyx_n_s_rgb2xyz);
  Py_VISIT(traverse_module_state->__pyx_n_s_rhombus);
  Py_VISIT(traverse_module_state->__pyx_n_s_rhombus_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_rhs);
  Py_VISIT(traverse_module_state->__pyx_n_s_riemann_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_right);
  Py_VISIT(traverse_module_state->__pyx_n_s_right_rectangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_right_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_risch);
  Py_VISIT(traverse_module_state->__pyx_n_s_rm_a_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_rm_all_vars);
  Py_VISIT(traverse_module_state->__pyx_n_s_rmbreakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_rmmod);
  Py_VISIT(traverse_module_state->__pyx_n_s_rms);
  Py_VISIT(traverse_module_state->__pyx_n_s_rmwatch);
  Py_VISIT(traverse_module_state->__pyx_n_s_rod);
  Py_VISIT(traverse_module_state->__pyx_n_s_romberg);
  Py_VISIT(traverse_module_state->__pyx_n_s_rombergm);
  Py_VISIT(traverse_module_state->__pyx_n_s_rombergt);
  Py_VISIT(traverse_module_state->__pyx_n_s_rond);
  Py_VISIT(traverse_module_state->__pyx_n_s_root);
  Py_VISIT(traverse_module_state->__pyx_n_s_rootof);
  Py_VISIT(traverse_module_state->__pyx_n_s_roots);
  Py_VISIT(traverse_module_state->__pyx_n_s_rotate);
  Py_VISIT(traverse_module_state->__pyx_n_s_rotation);
  Py_VISIT(traverse_module_state->__pyx_n_s_rouge);
  Py_VISIT(traverse_module_state->__pyx_n_s_round);
  Py_VISIT(traverse_module_state->__pyx_n_s_row);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowAdd);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowDim);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowNorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowSwap);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowdim);
  Py_VISIT(traverse_module_state->__pyx_n_s_rownorm);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_rowswap);
  Py_VISIT(traverse_module_state->__pyx_n_s_rpm);
  Py_VISIT(traverse_module_state->__pyx_n_s_rref);
  Py_VISIT(traverse_module_state->__pyx_n_s_rsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_rur);
  Py_VISIT(traverse_module_state->__pyx_n_s_rur_certify);
  Py_VISIT(traverse_module_state->__pyx_n_s_rur_gbasis);
  Py_VISIT(traverse_module_state->__pyx_n_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_s_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_saisir);
  Py_VISIT(traverse_module_state->__pyx_n_s_saisir_chaine);
  Py_VISIT(traverse_module_state->__pyx_n_s_same);
  Py_VISIT(traverse_module_state->__pyx_n_s_sample);
  Py_VISIT(traverse_module_state->__pyx_n_s_samplerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_sans_factoriser);
  Py_VISIT(traverse_module_state->__pyx_n_s_saute);
  Py_VISIT(traverse_module_state->__pyx_n_s_sauve);
  Py_VISIT(traverse_module_state->__pyx_n_s_save);
  Py_VISIT(traverse_module_state->__pyx_n_s_save_history);
  Py_VISIT(traverse_module_state->__pyx_n_s_sb);
  Py_VISIT(traverse_module_state->__pyx_n_s_scalarProduct);
  Py_VISIT(traverse_module_state->__pyx_n_s_scalar_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_scale);
  Py_VISIT(traverse_module_state->__pyx_n_s_scaleadd);
  Py_VISIT(traverse_module_state->__pyx_n_s_scatterplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_schur);
  Py_VISIT(traverse_module_state->__pyx_n_s_sd);
  Py_VISIT(traverse_module_state->__pyx_n_s_sec);
  Py_VISIT(traverse_module_state->__pyx_n_s_secant_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_segment);
  Py_VISIT(traverse_module_state->__pyx_n_s_seidel_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_seidel_switch);
  Py_VISIT(traverse_module_state->__pyx_n_s_select);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_is_not_a_giac_List);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_is_not_a_giac_integer);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_is_not_a_giac_real);
  Py_VISIT(traverse_module_state->__pyx_n_s_semi_augment);
  Py_VISIT(traverse_module_state->__pyx_n_s_send);
  Py_VISIT(traverse_module_state->__pyx_n_s_seq);
  Py_VISIT(traverse_module_state->__pyx_n_s_seqplot);
  Py_VISIT(traverse_module_state->__pyx_n_s_seqsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_sequence_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_series);
  Py_VISIT(traverse_module_state->__pyx_kp_s_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_channel_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_edge_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_edge_weight);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_graph_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_pixel);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_screen);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_vertex_attribute);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_vertex_positions);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_shift);
  Py_VISIT(traverse_module_state->__pyx_n_s_shift_phase);
  Py_VISIT(traverse_module_state->__pyx_n_s_shortest_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_show_pixels);
  Py_VISIT(traverse_module_state->__pyx_n_s_shuffle);
  Py_VISIT(traverse_module_state->__pyx_n_s_si);
  Py_VISIT(traverse_module_state->__pyx_n_s_sierpinski_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma);
  Py_VISIT(traverse_module_state->__pyx_n_s_sign);
  Py_VISIT(traverse_module_state->__pyx_n_s_sign2Heaviside);
  Py_VISIT(traverse_module_state->__pyx_n_s_signature);
  Py_VISIT(traverse_module_state->__pyx_n_s_signe);
  Py_VISIT(traverse_module_state->__pyx_n_s_similarity);
  Py_VISIT(traverse_module_state->__pyx_n_s_simp2);
  Py_VISIT(traverse_module_state->__pyx_n_s_simplex_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_simplicial_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_simplifier);
  Py_VISIT(traverse_module_state->__pyx_n_s_simplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_simplifyDirac);
  Py_VISIT(traverse_module_state->__pyx_n_s_simpson);
  Py_VISIT(traverse_module_state->__pyx_n_s_simulated_annealing);
  Py_VISIT(traverse_module_state->__pyx_n_s_simult);
  Py_VISIT(traverse_module_state->__pyx_n_s_sin);
  Py_VISIT(traverse_module_state->__pyx_n_s_sin2costan);
  Py_VISIT(traverse_module_state->__pyx_n_s_sinc);
  Py_VISIT(traverse_module_state->__pyx_n_s_sincos);
  Py_VISIT(traverse_module_state->__pyx_n_s_single_inter);
  Py_VISIT(traverse_module_state->__pyx_n_s_sinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_sinon);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_sizes);
  Py_VISIT(traverse_module_state->__pyx_n_s_sleep);
  Py_VISIT(traverse_module_state->__pyx_n_s_slope);
  Py_VISIT(traverse_module_state->__pyx_n_s_slopeat);
  Py_VISIT(traverse_module_state->__pyx_n_s_slopeatraw);
  Py_VISIT(traverse_module_state->__pyx_n_s_slug);
  Py_VISIT(traverse_module_state->__pyx_n_s_smith);
  Py_VISIT(traverse_module_state->__pyx_n_s_smod);
  Py_VISIT(traverse_module_state->__pyx_n_s_snedecor);
  Py_VISIT(traverse_module_state->__pyx_n_s_snedecor_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_snedecor_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_snedecord);
  Py_VISIT(traverse_module_state->__pyx_n_s_snedecord_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_snedecord_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_solid_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_solve);
  Py_VISIT(traverse_module_state->__pyx_n_s_somme);
  Py_VISIT(traverse_module_state->__pyx_n_s_sommet);
  Py_VISIT(traverse_module_state->__pyx_n_s_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_sorta);
  Py_VISIT(traverse_module_state->__pyx_n_s_sortd);
  Py_VISIT(traverse_module_state->__pyx_n_s_sorted);
  Py_VISIT(traverse_module_state->__pyx_n_s_sortperm);
  Py_VISIT(traverse_module_state->__pyx_n_s_soundsec);
  Py_VISIT(traverse_module_state->__pyx_n_s_spanning_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_sphere);
  Py_VISIT(traverse_module_state->__pyx_n_s_splice);
  Py_VISIT(traverse_module_state->__pyx_n_s_spline);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_spring);
  Py_VISIT(traverse_module_state->__pyx_n_s_sq);
  Py_VISIT(traverse_module_state->__pyx_n_s_sqrfree);
  Py_VISIT(traverse_module_state->__pyx_n_s_sqrt);
  Py_VISIT(traverse_module_state->__pyx_n_s_square);
  Py_VISIT(traverse_module_state->__pyx_n_s_square_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_sr);
  Py_VISIT(traverse_module_state->__pyx_n_s_srand);
  Py_VISIT(traverse_module_state->__pyx_n_s_sst);
  Py_VISIT(traverse_module_state->__pyx_n_s_sst_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_st);
  Py_VISIT(traverse_module_state->__pyx_n_s_st_ordering);
  Py_VISIT(traverse_module_state->__pyx_n_s_stack);
  Py_VISIT(traverse_module_state->__pyx_n_s_star_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_star_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_stdDev);
  Py_VISIT(traverse_module_state->__pyx_n_s_stddev);
  Py_VISIT(traverse_module_state->__pyx_n_s_stddevp);
  Py_VISIT(traverse_module_state->__pyx_n_s_steffenson_solver);
  Py_VISIT(traverse_module_state->__pyx_n_s_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_stereo2mono);
  Py_VISIT(traverse_module_state->__pyx_n_s_stft);
  Py_VISIT(traverse_module_state->__pyx_n_s_sto);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_str_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_string);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_strip);
  Py_VISIT(traverse_module_state->__pyx_n_s_strongly_connected_components);
  Py_VISIT(traverse_module_state->__pyx_n_s_student);
  Py_VISIT(traverse_module_state->__pyx_n_s_student_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_student_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_studentd);
  Py_VISIT(traverse_module_state->__pyx_n_s_studentt);
  Py_VISIT(traverse_module_state->__pyx_n_s_sturm);
  Py_VISIT(traverse_module_state->__pyx_n_s_sturmab);
  Py_VISIT(traverse_module_state->__pyx_n_s_sturmseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_style);
  Py_VISIT(traverse_module_state->__pyx_n_s_sub);
  Py_VISIT(traverse_module_state->__pyx_n_s_subMat);
  Py_VISIT(traverse_module_state->__pyx_n_s_subdivide_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_subgraph);
  Py_VISIT(traverse_module_state->__pyx_n_s_subs);
  Py_VISIT(traverse_module_state->__pyx_n_s_subsop);
  Py_VISIT(traverse_module_state->__pyx_n_s_subst);
  Py_VISIT(traverse_module_state->__pyx_n_s_substituer);
  Py_VISIT(traverse_module_state->__pyx_n_s_subtype);
  Py_VISIT(traverse_module_state->__pyx_n_s_subtype_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_sum);
  Py_VISIT(traverse_module_state->__pyx_n_s_sum_riemann);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_supposons);
  Py_VISIT(traverse_module_state->__pyx_n_s_suppress);
  Py_VISIT(traverse_module_state->__pyx_n_s_surd);
  Py_VISIT(traverse_module_state->__pyx_n_s_svd);
  Py_VISIT(traverse_module_state->__pyx_n_s_swapcol);
  Py_VISIT(traverse_module_state->__pyx_n_s_swaprow);
  Py_VISIT(traverse_module_state->__pyx_n_s_switch);
  Py_VISIT(traverse_module_state->__pyx_n_s_switch_axes);
  Py_VISIT(traverse_module_state->__pyx_n_s_sylvester);
  Py_VISIT(traverse_module_state->__pyx_n_s_symb2poly);
  Py_VISIT(traverse_module_state->__pyx_n_s_symbol);
  Py_VISIT(traverse_module_state->__pyx_n_s_symbol_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_syr);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_s_syst2mat);
  Py_VISIT(traverse_module_state->__pyx_n_s_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_tCollect);
  Py_VISIT(traverse_module_state->__pyx_n_s_tExpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_table);
  Py_VISIT(traverse_module_state->__pyx_n_s_tablefunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_tableseq);
  Py_VISIT(traverse_module_state->__pyx_n_s_tabsign);
  Py_VISIT(traverse_module_state->__pyx_n_s_tabvar);
  Py_VISIT(traverse_module_state->__pyx_n_s_tail);
  Py_VISIT(traverse_module_state->__pyx_n_s_tan);
  Py_VISIT(traverse_module_state->__pyx_n_s_tan2cossin2);
  Py_VISIT(traverse_module_state->__pyx_n_s_tan2sincos);
  Py_VISIT(traverse_module_state->__pyx_n_s_tan2sincos2);
  Py_VISIT(traverse_module_state->__pyx_n_s_tangent);
  Py_VISIT(traverse_module_state->__pyx_n_s_tangente);
  Py_VISIT(traverse_module_state->__pyx_n_s_tanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_tantque);
  Py_VISIT(traverse_module_state->__pyx_n_s_tar);
  Py_VISIT(traverse_module_state->__pyx_n_s_taux_accroissement);
  Py_VISIT(traverse_module_state->__pyx_n_s_taylor);
  Py_VISIT(traverse_module_state->__pyx_n_s_tbsp);
  Py_VISIT(traverse_module_state->__pyx_n_s_tchebyshev1);
  Py_VISIT(traverse_module_state->__pyx_n_s_tchebyshev2);
  Py_VISIT(traverse_module_state->__pyx_n_s_tcoeff);
  Py_VISIT(traverse_module_state->__pyx_n_s_tcollect);
  Py_VISIT(traverse_module_state->__pyx_n_s_tdeg);
  Py_VISIT(traverse_module_state->__pyx_n_s_teal);
  Py_VISIT(traverse_module_state->__pyx_n_s_tec);
  Py_VISIT(traverse_module_state->__pyx_n_s_tensor_product);
  Py_VISIT(traverse_module_state->__pyx_n_s_tep);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_test_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_tetrahedron);
  Py_VISIT(traverse_module_state->__pyx_n_s_tex);
  Py_VISIT(traverse_module_state->__pyx_n_s_texpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_textinput);
  Py_VISIT(traverse_module_state->__pyx_n_s_then);
  Py_VISIT(traverse_module_state->__pyx_n_s_therm);
  Py_VISIT(traverse_module_state->__pyx_n_s_thickness);
  Py_VISIT(traverse_module_state->__pyx_n_s_thiele);
  Py_VISIT(traverse_module_state->__pyx_n_s_threadeval);
  Py_VISIT(traverse_module_state->__pyx_kp_s_threads_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_threshold);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_title);
  Py_VISIT(traverse_module_state->__pyx_n_s_titre);
  Py_VISIT(traverse_module_state->__pyx_n_s_tlin);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmp);
  Py_VISIT(traverse_module_state->__pyx_n_s_to);
  Py_VISIT(traverse_module_state->__pyx_n_s_ton);
  Py_VISIT(traverse_module_state->__pyx_n_s_tonUK);
  Py_VISIT(traverse_module_state->__pyx_n_s_tonnetz);
  Py_VISIT(traverse_module_state->__pyx_n_s_topologic_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_topological_sort);
  Py_VISIT(traverse_module_state->__pyx_n_s_topology);
  Py_VISIT(traverse_module_state->__pyx_n_s_toqcas);
  Py_VISIT(traverse_module_state->__pyx_n_s_toremove);
  Py_VISIT(traverse_module_state->__pyx_n_s_torr);
  Py_VISIT(traverse_module_state->__pyx_n_s_torus_grid_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_tourne_droite);
  Py_VISIT(traverse_module_state->__pyx_n_s_tourne_gauche);
  Py_VISIT(traverse_module_state->__pyx_n_s_tpsolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_tr);
  Py_VISIT(traverse_module_state->__pyx_kp_s_tr_min);
  Py_VISIT(traverse_module_state->__pyx_kp_s_tr_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_trace);
  Py_VISIT(traverse_module_state->__pyx_n_s_trail);
  Py_VISIT(traverse_module_state->__pyx_n_s_trail2edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_train);
  Py_VISIT(traverse_module_state->__pyx_n_s_trames);
  Py_VISIT(traverse_module_state->__pyx_n_s_tran);
  Py_VISIT(traverse_module_state->__pyx_n_s_transitive_closure);
  Py_VISIT(traverse_module_state->__pyx_n_s_translation);
  Py_VISIT(traverse_module_state->__pyx_n_s_transpose);
  Py_VISIT(traverse_module_state->__pyx_n_s_trapeze);
  Py_VISIT(traverse_module_state->__pyx_n_s_trapezoid);
  Py_VISIT(traverse_module_state->__pyx_n_s_traveling_salesman);
  Py_VISIT(traverse_module_state->__pyx_n_s_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_tree_height);
  Py_VISIT(traverse_module_state->__pyx_n_s_tri);
  Py_VISIT(traverse_module_state->__pyx_n_s_triangle);
  Py_VISIT(traverse_module_state->__pyx_n_s_triangle_paper);
  Py_VISIT(traverse_module_state->__pyx_n_s_triangle_plein);
  Py_VISIT(traverse_module_state->__pyx_n_s_triangle_point);
  Py_VISIT(traverse_module_state->__pyx_n_s_triangle_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_trig2exp);
  Py_VISIT(traverse_module_state->__pyx_n_s_trigcos);
  Py_VISIT(traverse_module_state->__pyx_n_s_trigexpand);
  Py_VISIT(traverse_module_state->__pyx_n_s_triginterp);
  Py_VISIT(traverse_module_state->__pyx_n_s_trigsimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_trigsin);
  Py_VISIT(traverse_module_state->__pyx_n_s_trigtan);
  Py_VISIT(traverse_module_state->__pyx_n_s_trim);
  Py_VISIT(traverse_module_state->__pyx_n_s_trn);
  Py_VISIT(traverse_module_state->__pyx_n_s_true);
  Py_VISIT(traverse_module_state->__pyx_n_s_truediv);
  Py_VISIT(traverse_module_state->__pyx_n_s_trunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_truncate);
  Py_VISIT(traverse_module_state->__pyx_n_s_truncate_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_try);
  Py_VISIT(traverse_module_state->__pyx_kp_s_trying_soft_interruption_wait_2s);
  Py_VISIT(traverse_module_state->__pyx_n_s_tsimplify);
  Py_VISIT(traverse_module_state->__pyx_n_s_tsp);
  Py_VISIT(traverse_module_state->__pyx_n_s_tstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_tuer);
  Py_VISIT(traverse_module_state->__pyx_n_s_tukey_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_tutte_polynomial);
  Py_VISIT(traverse_module_state->__pyx_n_s_two_edge_connected_components);
  Py_VISIT(traverse_module_state->__pyx_n_s_twopi);
  Py_VISIT(traverse_module_state->__pyx_n_s_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_type_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_u);
  Py_VISIT(traverse_module_state->__pyx_n_s_ufactor);
  Py_VISIT(traverse_module_state->__pyx_n_s_ugamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_unapply);
  Py_VISIT(traverse_module_state->__pyx_n_s_unarchive);
  Py_VISIT(traverse_module_state->__pyx_n_s_undef);
  Py_VISIT(traverse_module_state->__pyx_n_s_underlying_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_unfactored);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniform);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniform_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniform_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniformd);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniformd_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniformd_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_union);
  Py_VISIT(traverse_module_state->__pyx_n_s_unitV);
  Py_VISIT(traverse_module_state->__pyx_n_s_unquote);
  Py_VISIT(traverse_module_state->__pyx_n_s_until);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_upper);
  Py_VISIT(traverse_module_state->__pyx_n_s_url);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_user_operator);
  Py_VISIT(traverse_module_state->__pyx_n_s_usimplify);
  Py_VISIT(traverse_module_state->__pyx_kp_s_using_sendtext);
  Py_VISIT(traverse_module_state->__pyx_n_s_ustep);
  Py_VISIT(traverse_module_state->__pyx_n_s_val);
  Py_VISIT(traverse_module_state->__pyx_n_s_valuation);
  Py_VISIT(traverse_module_state->__pyx_n_s_vandermonde);
  Py_VISIT(traverse_module_state->__pyx_n_s_var);
  Py_VISIT(traverse_module_state->__pyx_n_s_variables_are_files);
  Py_VISIT(traverse_module_state->__pyx_n_s_variance);
  Py_VISIT(traverse_module_state->__pyx_n_s_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_vers);
  Py_VISIT(traverse_module_state->__pyx_n_s_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_vert);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertex_connectivity);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertex_cover_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertex_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertex_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertex_in_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertex_out_degree);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertices);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertices_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_vertices_abca);
  Py_VISIT(traverse_module_state->__pyx_kp_u_vide_Pygen_giac_version_dpt_eit);
  Py_VISIT(traverse_module_state->__pyx_n_s_violet);
  Py_VISIT(traverse_module_state->__pyx_n_s_vpotential);
  Py_VISIT(traverse_module_state->__pyx_n_s_vrai);
  Py_VISIT(traverse_module_state->__pyx_n_s_vstep);
  Py_VISIT(traverse_module_state->__pyx_kp_s_warning_Killing_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_watch);
  Py_VISIT(traverse_module_state->__pyx_n_s_web_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_webbrowser);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibull);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibull_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibull_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibulld);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibulld_cdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibulld_icdf);
  Py_VISIT(traverse_module_state->__pyx_n_s_weibullvariate);
  Py_VISIT(traverse_module_state->__pyx_n_s_weight_decay);
  Py_VISIT(traverse_module_state->__pyx_n_s_weight_matrix);
  Py_VISIT(traverse_module_state->__pyx_n_s_weighted);
  Py_VISIT(traverse_module_state->__pyx_n_s_weights);
  Py_VISIT(traverse_module_state->__pyx_n_s_welch_window);
  Py_VISIT(traverse_module_state->__pyx_n_s_wheel_graph);
  Py_VISIT(traverse_module_state->__pyx_n_s_when);
  Py_VISIT(traverse_module_state->__pyx_n_s_while);
  Py_VISIT(traverse_module_state->__pyx_n_s_white);
  Py_VISIT(traverse_module_state->__pyx_n_s_widget_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_wilcoxonp);
  Py_VISIT(traverse_module_state->__pyx_n_s_wilcoxons);
  Py_VISIT(traverse_module_state->__pyx_n_s_wilcoxont);
  Py_VISIT(traverse_module_state->__pyx_n_s_with_sqrt);
  Py_VISIT(traverse_module_state->__pyx_n_s_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_writergb);
  Py_VISIT(traverse_module_state->__pyx_n_s_writewav);
  Py_VISIT(traverse_module_state->__pyx_n_s_wwwbrowseropen);
  Py_VISIT(traverse_module_state->__pyx_n_s_wz_certificate);
  Py_VISIT(traverse_module_state->__pyx_n_s_xcas_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_xml_print);
  Py_VISIT(traverse_module_state->__pyx_n_s_xor);
  Py_VISIT(traverse_module_state->__pyx_n_s_xstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_xyz2rgb);
  Py_VISIT(traverse_module_state->__pyx_n_s_xyztrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_yd);
  Py_VISIT(traverse_module_state->__pyx_kp_s_yd_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_yd_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_yellow);
  Py_VISIT(traverse_module_state->__pyx_n_s_yr);
  Py_VISIT(traverse_module_state->__pyx_n_s_ystep);
  Py_VISIT(traverse_module_state->__pyx_n_s_zeros);
  Py_VISIT(traverse_module_state->__pyx_n_s_zip);
  Py_VISIT(traverse_module_state->__pyx_n_s_znorder);
  Py_VISIT(traverse_module_state->__pyx_n_s_znprimroot);
  Py_VISIT(traverse_module_state->__pyx_n_s_zstep);
  Py_VISIT(traverse_module_state->__pyx_n_s_ztrans);
  Py_VISIT(traverse_module_state->__pyx_float_0_05);
  Py_VISIT(traverse_module_state->__pyx_float_0_001);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_7);
  Py_VISIT(traverse_module_state->__pyx_int_8);
  Py_VISIT(traverse_module_state->__pyx_int_12);
  Py_VISIT(traverse_module_state->__pyx_int_14);
  Py_VISIT(traverse_module_state->__pyx_int_100);
  Py_VISIT(traverse_module_state->__pyx_int_1000000);
  Py_VISIT(traverse_module_state->__pyx_int_222419149);
  Py_VISIT(traverse_module_state->__pyx_int_228825662);
  Py_VISIT(traverse_module_state->__pyx_int_238750788);
  Py_VISIT(traverse_module_state->__pyx_tuple_);
  Py_VISIT(traverse_module_state->__pyx_slice__2);
  Py_VISIT(traverse_module_state->__pyx_tuple__3);
  Py_VISIT(traverse_module_state->__pyx_tuple__4);
  Py_VISIT(traverse_module_state->__pyx_tuple__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__6);
  Py_VISIT(traverse_module_state->__pyx_tuple__7);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__22);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_codeobj__16);
  Py_VISIT(traverse_module_state->__pyx_codeobj__17);
  Py_VISIT(traverse_module_state->__pyx_codeobj__19);
  Py_VISIT(traverse_module_state->__pyx_codeobj__21);
  Py_VISIT(traverse_module_state->__pyx_codeobj__23);
  Py_VISIT(traverse_module_state->__pyx_codeobj__25);
  Py_VISIT(traverse_module_state->__pyx_codeobj__26);
  Py_VISIT(traverse_module_state->__pyx_codeobj__27);
  Py_VISIT(traverse_module_state->__pyx_codeobj__28);
  Py_VISIT(traverse_module_state->__pyx_codeobj__29);
  Py_VISIT(traverse_module_state->__pyx_codeobj__30);
  Py_VISIT(traverse_module_state->__pyx_codeobj__31);
  Py_VISIT(traverse_module_state->__pyx_codeobj__32);
  Py_VISIT(traverse_module_state->__pyx_codeobj__33);
  Py_VISIT(traverse_module_state->__pyx_codeobj__34);
  Py_VISIT(traverse_module_state->__pyx_codeobj__35);
  Py_VISIT(traverse_module_state->__pyx_codeobj__36);
  Py_VISIT(traverse_module_state->__pyx_codeobj__37);
  Py_VISIT(traverse_module_state->__pyx_codeobj__38);
  Py_VISIT(traverse_module_state->__pyx_codeobj__39);
  Py_VISIT(traverse_module_state->__pyx_codeobj__40);
  Py_VISIT(traverse_module_state->__pyx_codeobj__41);
  Py_VISIT(traverse_module_state->__pyx_codeobj__42);
  Py_VISIT(traverse_module_state->__pyx_codeobj__43);
  Py_VISIT(traverse_module_state->__pyx_codeobj__44);
  Py_VISIT(traverse_module_state->__pyx_codeobj__45);
  Py_VISIT(traverse_module_state->__pyx_codeobj__46);
  Py_VISIT(traverse_module_state->__pyx_codeobj__47);
  Py_VISIT(traverse_module_state->__pyx_codeobj__48);
  Py_VISIT(traverse_module_state->__pyx_codeobj__49);
  Py_VISIT(traverse_module_state->__pyx_codeobj__50);
  Py_VISIT(traverse_module_state->__pyx_codeobj__51);
  Py_VISIT(traverse_module_state->__pyx_codeobj__52);
  Py_VISIT(traverse_module_state->__pyx_codeobj__53);
  Py_VISIT(traverse_module_state->__pyx_codeobj__54);
  Py_VISIT(traverse_module_state->__pyx_codeobj__55);
  Py_VISIT(traverse_module_state->__pyx_codeobj__56);
  Py_VISIT(traverse_module_state->__pyx_codeobj__57);
  Py_VISIT(traverse_module_state->__pyx_codeobj__58);
  Py_VISIT(traverse_module_state->__pyx_codeobj__59);
  Py_VISIT(traverse_module_state->__pyx_codeobj__60);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__62);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__64);
  Py_VISIT(traverse_module_state->__pyx_codeobj__65);
  Py_VISIT(traverse_module_state->__pyx_codeobj__66);
  Py_VISIT(traverse_module_state->__pyx_codeobj__67);
  Py_VISIT(traverse_module_state->__pyx_codeobj__68);
  Py_VISIT(traverse_module_state->__pyx_codeobj__69);
  Py_VISIT(traverse_module_state->__pyx_codeobj__70);
  Py_VISIT(traverse_module_state->__pyx_codeobj__71);
  Py_VISIT(traverse_module_state->__pyx_codeobj__72);
  Py_VISIT(traverse_module_state->__pyx_codeobj__73);
  Py_VISIT(traverse_module_state->__pyx_codeobj__74);
  Py_VISIT(traverse_module_state->__pyx_codeobj__75);
  Py_VISIT(traverse_module_state->__pyx_codeobj__76);
  Py_VISIT(traverse_module_state->__pyx_codeobj__77);
  Py_VISIT(traverse_module_state->__pyx_codeobj__78);
  Py_VISIT(traverse_module_state->__pyx_codeobj__79);
  Py_VISIT(traverse_module_state->__pyx_codeobj__80);
  Py_VISIT(traverse_module_state->__pyx_codeobj__81);
  Py_VISIT(traverse_module_state->__pyx_codeobj__82);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__84);
  Py_VISIT(traverse_module_state->__pyx_codeobj__85);
  Py_VISIT(traverse_module_state->__pyx_codeobj__86);
  Py_VISIT(traverse_module_state->__pyx_codeobj__87);
  Py_VISIT(traverse_module_state->__pyx_codeobj__88);
  Py_VISIT(traverse_module_state->__pyx_codeobj__89);
  Py_VISIT(traverse_module_state->__pyx_codeobj__90);
  Py_VISIT(traverse_module_state->__pyx_codeobj__91);
  Py_VISIT(traverse_module_state->__pyx_codeobj__92);
  Py_VISIT(traverse_module_state->__pyx_codeobj__93);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__95);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  Py_VISIT(traverse_module_state->__pyx_codeobj__97);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__99);
  Py_VISIT(traverse_module_state->__pyx_tuple__1627);
  Py_VISIT(traverse_module_state->__pyx_tuple__1630);
  Py_VISIT(traverse_module_state->__pyx_tuple__1632);
  Py_VISIT(traverse_module_state->__pyx_tuple__1637);
  Py_VISIT(traverse_module_state->__pyx_tuple__1639);
  Py_VISIT(traverse_module_state->__pyx_tuple__1641);
  Py_VISIT(traverse_module_state->__pyx_tuple__1643);
  Py_VISIT(traverse_module_state->__pyx_tuple__1645);
  Py_VISIT(traverse_module_state->__pyx_tuple__1646);
  Py_VISIT(traverse_module_state->__pyx_tuple__1650);
  Py_VISIT(traverse_module_state->__pyx_tuple__1651);
  Py_VISIT(traverse_module_state->__pyx_tuple__1653);
  Py_VISIT(traverse_module_state->__pyx_tuple__1702);
  Py_VISIT(traverse_module_state->__pyx_tuple__1707);
  Py_VISIT(traverse_module_state->__pyx_tuple__1713);
  Py_VISIT(traverse_module_state->__pyx_tuple__1719);
  Py_VISIT(traverse_module_state->__pyx_tuple__1721);
  Py_VISIT(traverse_module_state->__pyx_tuple__1722);
  Py_VISIT(traverse_module_state->__pyx_tuple__1724);
  Py_VISIT(traverse_module_state->__pyx_tuple__1726);
  Py_VISIT(traverse_module_state->__pyx_codeobj__100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__101);
  Py_VISIT(traverse_module_state->__pyx_codeobj__102);
  Py_VISIT(traverse_module_state->__pyx_codeobj__103);
  Py_VISIT(traverse_module_state->__pyx_codeobj__104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__105);
  Py_VISIT(traverse_module_state->__pyx_codeobj__106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__107);
  Py_VISIT(traverse_module_state->__pyx_codeobj__108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__109);
  Py_VISIT(traverse_module_state->__pyx_codeobj__110);
  Py_VISIT(traverse_module_state->__pyx_codeobj__111);
  Py_VISIT(traverse_module_state->__pyx_codeobj__112);
  Py_VISIT(traverse_module_state->__pyx_codeobj__113);
  Py_VISIT(traverse_module_state->__pyx_codeobj__114);
  Py_VISIT(traverse_module_state->__pyx_codeobj__115);
  Py_VISIT(traverse_module_state->__pyx_codeobj__116);
  Py_VISIT(traverse_module_state->__pyx_codeobj__117);
  Py_VISIT(traverse_module_state->__pyx_codeobj__118);
  Py_VISIT(traverse_module_state->__pyx_codeobj__119);
  Py_VISIT(traverse_module_state->__pyx_codeobj__120);
  Py_VISIT(traverse_module_state->__pyx_codeobj__121);
  Py_VISIT(traverse_module_state->__pyx_codeobj__122);
  Py_VISIT(traverse_module_state->__pyx_codeobj__123);
  Py_VISIT(traverse_module_state->__pyx_codeobj__124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__125);
  Py_VISIT(traverse_module_state->__pyx_codeobj__126);
  Py_VISIT(traverse_module_state->__pyx_codeobj__127);
  Py_VISIT(traverse_module_state->__pyx_codeobj__128);
  Py_VISIT(traverse_module_state->__pyx_codeobj__129);
  Py_VISIT(traverse_module_state->__pyx_codeobj__130);
  Py_VISIT(traverse_module_state->__pyx_codeobj__131);
  Py_VISIT(traverse_module_state->__pyx_codeobj__132);
  Py_VISIT(traverse_module_state->__pyx_codeobj__133);
  Py_VISIT(traverse_module_state->__pyx_codeobj__134);
  Py_VISIT(traverse_module_state->__pyx_codeobj__135);
  Py_VISIT(traverse_module_state->__pyx_codeobj__136);
  Py_VISIT(traverse_module_state->__pyx_codeobj__137);
  Py_VISIT(traverse_module_state->__pyx_codeobj__138);
  Py_VISIT(traverse_module_state->__pyx_codeobj__139);
  Py_VISIT(traverse_module_state->__pyx_codeobj__140);
  Py_VISIT(traverse_module_state->__pyx_codeobj__141);
  Py_VISIT(traverse_module_state->__pyx_codeobj__142);
  Py_VISIT(traverse_module_state->__pyx_codeobj__143);
  Py_VISIT(traverse_module_state->__pyx_codeobj__144);
  Py_VISIT(traverse_module_state->__pyx_codeobj__145);
  Py_VISIT(traverse_module_state->__pyx_codeobj__146);
  Py_VISIT(traverse_module_state->__pyx_codeobj__147);
  Py_VISIT(traverse_module_state->__pyx_codeobj__148);
  Py_VISIT(traverse_module_state->__pyx_codeobj__149);
  Py_VISIT(traverse_module_state->__pyx_codeobj__150);
  Py_VISIT(traverse_module_state->__pyx_codeobj__151);
  Py_VISIT(traverse_module_state->__pyx_codeobj__152);
  Py_VISIT(traverse_module_state->__pyx_codeobj__153);
  Py_VISIT(traverse_module_state->__pyx_codeobj__154);
  Py_VISIT(traverse_module_state->__pyx_codeobj__155);
  Py_VISIT(traverse_module_state->__pyx_codeobj__156);
  Py_VISIT(traverse_module_state->__pyx_codeobj__157);
  Py_VISIT(traverse_module_state->__pyx_codeobj__158);
  Py_VISIT(traverse_module_state->__pyx_codeobj__159);
  Py_VISIT(traverse_module_state->__pyx_codeobj__160);
  Py_VISIT(traverse_module_state->__pyx_codeobj__161);
  Py_VISIT(traverse_module_state->__pyx_codeobj__162);
  Py_VISIT(traverse_module_state->__pyx_codeobj__163);
  Py_VISIT(traverse_module_state->__pyx_codeobj__164);
  Py_VISIT(traverse_module_state->__pyx_codeobj__165);
  Py_VISIT(traverse_module_state->__pyx_codeobj__166);
  Py_VISIT(traverse_module_state->__pyx_codeobj__167);
  Py_VISIT(traverse_module_state->__pyx_codeobj__168);
  Py_VISIT(traverse_module_state->__pyx_codeobj__169);
  Py_VISIT(traverse_module_state->__pyx_codeobj__170);
  Py_VISIT(traverse_module_state->__pyx_codeobj__171);
  Py_VISIT(traverse_module_state->__pyx_codeobj__172);
  Py_VISIT(traverse_module_state->__pyx_codeobj__173);
  Py_VISIT(traverse_module_state->__pyx_codeobj__174);
  Py_VISIT(traverse_module_state->__pyx_codeobj__175);
  Py_VISIT(traverse_module_state->__pyx_codeobj__176);
  Py_VISIT(traverse_module_state->__pyx_codeobj__177);
  Py_VISIT(traverse_module_state->__pyx_codeobj__178);
  Py_VISIT(traverse_module_state->__pyx_codeobj__179);
  Py_VISIT(traverse_module_state->__pyx_codeobj__180);
  Py_VISIT(traverse_module_state->__pyx_codeobj__181);
  Py_VISIT(traverse_module_state->__pyx_codeobj__182);
  Py_VISIT(traverse_module_state->__pyx_codeobj__183);
  Py_VISIT(traverse_module_state->__pyx_codeobj__184);
  Py_VISIT(traverse_module_state->__pyx_codeobj__185);
  Py_VISIT(traverse_module_state->__pyx_codeobj__186);
  Py_VISIT(traverse_module_state->__pyx_codeobj__187);
  Py_VISIT(traverse_module_state->__pyx_codeobj__188);
  Py_VISIT(traverse_module_state->__pyx_codeobj__189);
  Py_VISIT(traverse_module_state->__pyx_codeobj__190);
  Py_VISIT(traverse_module_state->__pyx_codeobj__191);
  Py_VISIT(traverse_module_state->__pyx_codeobj__192);
  Py_VISIT(traverse_module_state->__pyx_codeobj__193);
  Py_VISIT(traverse_module_state->__pyx_codeobj__194);
  Py_VISIT(traverse_module_state->__pyx_codeobj__195);
  Py_VISIT(traverse_module_state->__pyx_codeobj__196);
  Py_VISIT(traverse_module_state->__pyx_codeobj__197);
  Py_VISIT(traverse_module_state->__pyx_codeobj__198);
  Py_VISIT(traverse_module_state->__pyx_codeobj__199);
  Py_VISIT(traverse_module_state->__pyx_codeobj__200);
  Py_VISIT(traverse_module_state->__pyx_codeobj__201);
  Py_VISIT(traverse_module_state->__pyx_codeobj__202);
  Py_VISIT(traverse_module_state->__pyx_codeobj__203);
  Py_VISIT(traverse_module_state->__pyx_codeobj__204);
  Py_VISIT(traverse_module_state->__pyx_codeobj__205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__206);
  Py_VISIT(traverse_module_state->__pyx_codeobj__207);
  Py_VISIT(traverse_module_state->__pyx_codeobj__208);
  Py_VISIT(traverse_module_state->__pyx_codeobj__209);
  Py_VISIT(traverse_module_state->__pyx_codeobj__210);
  Py_VISIT(traverse_module_state->__pyx_codeobj__211);
  Py_VISIT(traverse_module_state->__pyx_codeobj__212);
  Py_VISIT(traverse_module_state->__pyx_codeobj__213);
  Py_VISIT(traverse_module_state->__pyx_codeobj__214);
  Py_VISIT(traverse_module_state->__pyx_codeobj__215);
  Py_VISIT(traverse_module_state->__pyx_codeobj__216);
  Py_VISIT(traverse_module_state->__pyx_codeobj__217);
  Py_VISIT(traverse_module_state->__pyx_codeobj__218);
  Py_VISIT(traverse_module_state->__pyx_codeobj__219);
  Py_VISIT(traverse_module_state->__pyx_codeobj__220);
  Py_VISIT(traverse_module_state->__pyx_codeobj__221);
  Py_VISIT(traverse_module_state->__pyx_codeobj__222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__223);
  Py_VISIT(traverse_module_state->__pyx_codeobj__224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__225);
  Py_VISIT(traverse_module_state->__pyx_codeobj__226);
  Py_VISIT(traverse_module_state->__pyx_codeobj__227);
  Py_VISIT(traverse_module_state->__pyx_codeobj__228);
  Py_VISIT(traverse_module_state->__pyx_codeobj__229);
  Py_VISIT(traverse_module_state->__pyx_codeobj__230);
  Py_VISIT(traverse_module_state->__pyx_codeobj__231);
  Py_VISIT(traverse_module_state->__pyx_codeobj__232);
  Py_VISIT(traverse_module_state->__pyx_codeobj__233);
  Py_VISIT(traverse_module_state->__pyx_codeobj__234);
  Py_VISIT(traverse_module_state->__pyx_codeobj__235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__236);
  Py_VISIT(traverse_module_state->__pyx_codeobj__237);
  Py_VISIT(traverse_module_state->__pyx_codeobj__238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__240);
  Py_VISIT(traverse_module_state->__pyx_codeobj__241);
  Py_VISIT(traverse_module_state->__pyx_codeobj__242);
  Py_VISIT(traverse_module_state->__pyx_codeobj__243);
  Py_VISIT(traverse_module_state->__pyx_codeobj__244);
  Py_VISIT(traverse_module_state->__pyx_codeobj__245);
  Py_VISIT(traverse_module_state->__pyx_codeobj__246);
  Py_VISIT(traverse_module_state->__pyx_codeobj__247);
  Py_VISIT(traverse_module_state->__pyx_codeobj__248);
  Py_VISIT(traverse_module_state->__pyx_codeobj__249);
  Py_VISIT(traverse_module_state->__pyx_codeobj__250);
  Py_VISIT(traverse_module_state->__pyx_codeobj__251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__252);
  Py_VISIT(traverse_module_state->__pyx_codeobj__253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__254);
  Py_VISIT(traverse_module_state->__pyx_codeobj__255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__256);
  Py_VISIT(traverse_module_state->__pyx_codeobj__257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__258);
  Py_VISIT(traverse_module_state->__pyx_codeobj__259);
  Py_VISIT(traverse_module_state->__pyx_codeobj__260);
  Py_VISIT(traverse_module_state->__pyx_codeobj__261);
  Py_VISIT(traverse_module_state->__pyx_codeobj__262);
  Py_VISIT(traverse_module_state->__pyx_codeobj__263);
  Py_VISIT(traverse_module_state->__pyx_codeobj__264);
  Py_VISIT(traverse_module_state->__pyx_codeobj__265);
  Py_VISIT(traverse_module_state->__pyx_codeobj__266);
  Py_VISIT(traverse_module_state->__pyx_codeobj__267);
  Py_VISIT(traverse_module_state->__pyx_codeobj__268);
  Py_VISIT(traverse_module_state->__pyx_codeobj__269);
  Py_VISIT(traverse_module_state->__pyx_codeobj__270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__271);
  Py_VISIT(traverse_module_state->__pyx_codeobj__272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__273);
  Py_VISIT(traverse_module_state->__pyx_codeobj__274);
  Py_VISIT(traverse_module_state->__pyx_codeobj__275);
  Py_VISIT(traverse_module_state->__pyx_codeobj__276);
  Py_VISIT(traverse_module_state->__pyx_codeobj__277);
  Py_VISIT(traverse_module_state->__pyx_codeobj__278);
  Py_VISIT(traverse_module_state->__pyx_codeobj__279);
  Py_VISIT(traverse_module_state->__pyx_codeobj__280);
  Py_VISIT(traverse_module_state->__pyx_codeobj__281);
  Py_VISIT(traverse_module_state->__pyx_codeobj__282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__283);
  Py_VISIT(traverse_module_state->__pyx_codeobj__284);
  Py_VISIT(traverse_module_state->__pyx_codeobj__285);
  Py_VISIT(traverse_module_state->__pyx_codeobj__286);
  Py_VISIT(traverse_module_state->__pyx_codeobj__287);
  Py_VISIT(traverse_module_state->__pyx_codeobj__288);
  Py_VISIT(traverse_module_state->__pyx_codeobj__289);
  Py_VISIT(traverse_module_state->__pyx_codeobj__290);
  Py_VISIT(traverse_module_state->__pyx_codeobj__291);
  Py_VISIT(traverse_module_state->__pyx_codeobj__292);
  Py_VISIT(traverse_module_state->__pyx_codeobj__293);
  Py_VISIT(traverse_module_state->__pyx_codeobj__294);
  Py_VISIT(traverse_module_state->__pyx_codeobj__295);
  Py_VISIT(traverse_module_state->__pyx_codeobj__296);
  Py_VISIT(traverse_module_state->__pyx_codeobj__297);
  Py_VISIT(traverse_module_state->__pyx_codeobj__298);
  Py_VISIT(traverse_module_state->__pyx_codeobj__299);
  Py_VISIT(traverse_module_state->__pyx_codeobj__300);
  Py_VISIT(traverse_module_state->__pyx_codeobj__301);
  Py_VISIT(traverse_module_state->__pyx_codeobj__302);
  Py_VISIT(traverse_module_state->__pyx_codeobj__303);
  Py_VISIT(traverse_module_state->__pyx_codeobj__304);
  Py_VISIT(traverse_module_state->__pyx_codeobj__305);
  Py_VISIT(traverse_module_state->__pyx_codeobj__306);
  Py_VISIT(traverse_module_state->__pyx_codeobj__307);
  Py_VISIT(traverse_module_state->__pyx_codeobj__308);
  Py_VISIT(traverse_module_state->__pyx_codeobj__309);
  Py_VISIT(traverse_module_state->__pyx_codeobj__310);
  Py_VISIT(traverse_module_state->__pyx_codeobj__311);
  Py_VISIT(traverse_module_state->__pyx_codeobj__312);
  Py_VISIT(traverse_module_state->__pyx_codeobj__313);
  Py_VISIT(traverse_module_state->__pyx_codeobj__314);
  Py_VISIT(traverse_module_state->__pyx_codeobj__315);
  Py_VISIT(traverse_module_state->__pyx_codeobj__316);
  Py_VISIT(traverse_module_state->__pyx_codeobj__317);
  Py_VISIT(traverse_module_state->__pyx_codeobj__318);
  Py_VISIT(traverse_module_state->__pyx_codeobj__319);
  Py_VISIT(traverse_module_state->__pyx_codeobj__320);
  Py_VISIT(traverse_module_state->__pyx_codeobj__321);
  Py_VISIT(traverse_module_state->__pyx_codeobj__322);
  Py_VISIT(traverse_module_state->__pyx_codeobj__323);
  Py_VISIT(traverse_module_state->__pyx_codeobj__324);
  Py_VISIT(traverse_module_state->__pyx_codeobj__325);
  Py_VISIT(traverse_module_state->__pyx_codeobj__326);
  Py_VISIT(traverse_module_state->__pyx_codeobj__327);
  Py_VISIT(traverse_module_state->__pyx_codeobj__328);
  Py_VISIT(traverse_module_state->__pyx_codeobj__329);
  Py_VISIT(traverse_module_state->__pyx_codeobj__330);
  Py_VISIT(traverse_module_state->__pyx_codeobj__331);
  Py_VISIT(traverse_module_state->__pyx_codeobj__332);
  Py_VISIT(traverse_module_state->__pyx_codeobj__333);
  Py_VISIT(traverse_module_state->__pyx_codeobj__334);
  Py_VISIT(traverse_module_state->__pyx_codeobj__335);
  Py_VISIT(traverse_module_state->__pyx_codeobj__336);
  Py_VISIT(traverse_module_state->__pyx_codeobj__337);
  Py_VISIT(traverse_module_state->__pyx_codeobj__338);
  Py_VISIT(traverse_module_state->__pyx_codeobj__339);
  Py_VISIT(traverse_module_state->__pyx_codeobj__340);
  Py_VISIT(traverse_module_state->__pyx_codeobj__341);
  Py_VISIT(traverse_module_state->__pyx_codeobj__342);
  Py_VISIT(traverse_module_state->__pyx_codeobj__343);
  Py_VISIT(traverse_module_state->__pyx_codeobj__344);
  Py_VISIT(traverse_module_state->__pyx_codeobj__345);
  Py_VISIT(traverse_module_state->__pyx_codeobj__346);
  Py_VISIT(traverse_module_state->__pyx_codeobj__347);
  Py_VISIT(traverse_module_state->__pyx_codeobj__348);
  Py_VISIT(traverse_module_state->__pyx_codeobj__349);
  Py_VISIT(traverse_module_state->__pyx_codeobj__350);
  Py_VISIT(traverse_module_state->__pyx_codeobj__351);
  Py_VISIT(traverse_module_state->__pyx_codeobj__352);
  Py_VISIT(traverse_module_state->__pyx_codeobj__353);
  Py_VISIT(traverse_module_state->__pyx_codeobj__354);
  Py_VISIT(traverse_module_state->__pyx_codeobj__355);
  Py_VISIT(traverse_module_state->__pyx_codeobj__356);
  Py_VISIT(traverse_module_state->__pyx_codeobj__357);
  Py_VISIT(traverse_module_state->__pyx_codeobj__358);
  Py_VISIT(traverse_module_state->__pyx_codeobj__359);
  Py_VISIT(traverse_module_state->__pyx_codeobj__360);
  Py_VISIT(traverse_module_state->__pyx_codeobj__361);
  Py_VISIT(traverse_module_state->__pyx_codeobj__362);
  Py_VISIT(traverse_module_state->__pyx_codeobj__363);
  Py_VISIT(traverse_module_state->__pyx_codeobj__364);
  Py_VISIT(traverse_module_state->__pyx_codeobj__365);
  Py_VISIT(traverse_module_state->__pyx_codeobj__366);
  Py_VISIT(traverse_module_state->__pyx_codeobj__367);
  Py_VISIT(traverse_module_state->__pyx_codeobj__368);
  Py_VISIT(traverse_module_state->__pyx_codeobj__369);
  Py_VISIT(traverse_module_state->__pyx_codeobj__370);
  Py_VISIT(traverse_module_state->__pyx_codeobj__371);
  Py_VISIT(traverse_module_state->__pyx_codeobj__372);
  Py_VISIT(traverse_module_state->__pyx_codeobj__373);
  Py_VISIT(traverse_module_state->__pyx_codeobj__374);
  Py_VISIT(traverse_module_state->__pyx_codeobj__375);
  Py_VISIT(traverse_module_state->__pyx_codeobj__376);
  Py_VISIT(traverse_module_state->__pyx_codeobj__377);
  Py_VISIT(traverse_module_state->__pyx_codeobj__378);
  Py_VISIT(traverse_module_state->__pyx_codeobj__379);
  Py_VISIT(traverse_module_state->__pyx_codeobj__380);
  Py_VISIT(traverse_module_state->__pyx_codeobj__381);
  Py_VISIT(traverse_module_state->__pyx_codeobj__382);
  Py_VISIT(traverse_module_state->__pyx_codeobj__383);
  Py_VISIT(traverse_module_state->__pyx_codeobj__384);
  Py_VISIT(traverse_module_state->__pyx_codeobj__385);
  Py_VISIT(traverse_module_state->__pyx_codeobj__386);
  Py_VISIT(traverse_module_state->__pyx_codeobj__387);
  Py_VISIT(traverse_module_state->__pyx_codeobj__388);
  Py_VISIT(traverse_module_state->__pyx_codeobj__389);
  Py_VISIT(traverse_module_state->__pyx_codeobj__390);
  Py_VISIT(traverse_module_state->__pyx_codeobj__391);
  Py_VISIT(traverse_module_state->__pyx_codeobj__392);
  Py_VISIT(traverse_module_state->__pyx_codeobj__393);
  Py_VISIT(traverse_module_state->__pyx_codeobj__394);
  Py_VISIT(traverse_module_state->__pyx_codeobj__395);
  Py_VISIT(traverse_module_state->__pyx_codeobj__396);
  Py_VISIT(traverse_module_state->__pyx_codeobj__397);
  Py_VISIT(traverse_module_state->__pyx_codeobj__398);
  Py_VISIT(traverse_module_state->__pyx_codeobj__399);
  Py_VISIT(traverse_module_state->__pyx_codeobj__400);
  Py_VISIT(traverse_module_state->__pyx_codeobj__401);
  Py_VISIT(traverse_module_state->__pyx_codeobj__402);
  Py_VISIT(traverse_module_state->__pyx_codeobj__403);
  Py_VISIT(traverse_module_state->__pyx_codeobj__404);
  Py_VISIT(traverse_module_state->__pyx_codeobj__405);
  Py_VISIT(traverse_module_state->__pyx_codeobj__406);
  Py_VISIT(traverse_module_state->__pyx_codeobj__407);
  Py_VISIT(traverse_module_state->__pyx_codeobj__408);
  Py_VISIT(traverse_module_state->__pyx_codeobj__409);
  Py_VISIT(traverse_module_state->__pyx_codeobj__410);
  Py_VISIT(traverse_module_state->__pyx_codeobj__411);
  Py_VISIT(traverse_module_state->__pyx_codeobj__412);
  Py_VISIT(traverse_module_state->__pyx_codeobj__413);
  Py_VISIT(traverse_module_state->__pyx_codeobj__414);
  Py_VISIT(traverse_module_state->__pyx_codeobj__415);
  Py_VISIT(traverse_module_state->__pyx_codeobj__416);
  Py_VISIT(traverse_module_state->__pyx_codeobj__417);
  Py_VISIT(traverse_module_state->__pyx_codeobj__418);
  Py_VISIT(traverse_module_state->__pyx_codeobj__419);
  Py_VISIT(traverse_module_state->__pyx_codeobj__420);
  Py_VISIT(traverse_module_state->__pyx_codeobj__421);
  Py_VISIT(traverse_module_state->__pyx_codeobj__422);
  Py_VISIT(traverse_module_state->__pyx_codeobj__423);
  Py_VISIT(traverse_module_state->__pyx_codeobj__424);
  Py_VISIT(traverse_module_state->__pyx_codeobj__425);
  Py_VISIT(traverse_module_state->__pyx_codeobj__426);
  Py_VISIT(traverse_module_state->__pyx_codeobj__427);
  Py_VISIT(traverse_module_state->__pyx_codeobj__428);
  Py_VISIT(traverse_module_state->__pyx_codeobj__429);
  Py_VISIT(traverse_module_state->__pyx_codeobj__430);
  Py_VISIT(traverse_module_state->__pyx_codeobj__431);
  Py_VISIT(traverse_module_state->__pyx_codeobj__432);
  Py_VISIT(traverse_module_state->__pyx_codeobj__433);
  Py_VISIT(traverse_module_state->__pyx_codeobj__434);
  Py_VISIT(traverse_module_state->__pyx_codeobj__435);
  Py_VISIT(traverse_module_state->__pyx_codeobj__436);
  Py_VISIT(traverse_module_state->__pyx_codeobj__437);
  Py_VISIT(traverse_module_state->__pyx_codeobj__438);
  Py_VISIT(traverse_module_state->__pyx_codeobj__439);
  Py_VISIT(traverse_module_state->__pyx_codeobj__440);
  Py_VISIT(traverse_module_state->__pyx_codeobj__441);
  Py_VISIT(traverse_module_state->__pyx_codeobj__442);
  Py_VISIT(traverse_module_state->__pyx_codeobj__443);
  Py_VISIT(traverse_module_state->__pyx_codeobj__444);
  Py_VISIT(traverse_module_state->__pyx_codeobj__445);
  Py_VISIT(traverse_module_state->__pyx_codeobj__446);
  Py_VISIT(traverse_module_state->__pyx_codeobj__447);
  Py_VISIT(traverse_module_state->__pyx_codeobj__448);
  Py_VISIT(traverse_module_state->__pyx_codeobj__449);
  Py_VISIT(traverse_module_state->__pyx_codeobj__450);
  Py_VISIT(traverse_module_state->__pyx_codeobj__451);
  Py_VISIT(traverse_module_state->__pyx_codeobj__452);
  Py_VISIT(traverse_module_state->__pyx_codeobj__453);
  Py_VISIT(traverse_module_state->__pyx_codeobj__454);
  Py_VISIT(traverse_module_state->__pyx_codeobj__455);
  Py_VISIT(traverse_module_state->__pyx_codeobj__456);
  Py_VISIT(traverse_module_state->__pyx_codeobj__457);
  Py_VISIT(traverse_module_state->__pyx_codeobj__458);
  Py_VISIT(traverse_module_state->__pyx_codeobj__459);
  Py_VISIT(traverse_module_state->__pyx_codeobj__460);
  Py_VISIT(traverse_module_state->__pyx_codeobj__461);
  Py_VISIT(traverse_module_state->__pyx_codeobj__462);
  Py_VISIT(traverse_module_state->__pyx_codeobj__463);
  Py_VISIT(traverse_module_state->__pyx_codeobj__464);
  Py_VISIT(traverse_module_state->__pyx_codeobj__465);
  Py_VISIT(traverse_module_state->__pyx_codeobj__466);
  Py_VISIT(traverse_module_state->__pyx_codeobj__467);
  Py_VISIT(traverse_module_state->__pyx_codeobj__468);
  Py_VISIT(traverse_module_state->__pyx_codeobj__469);
  Py_VISIT(traverse_module_state->__pyx_codeobj__470);
  Py_VISIT(traverse_module_state->__pyx_codeobj__471);
  Py_VISIT(traverse_module_state->__pyx_codeobj__472);
  Py_VISIT(traverse_module_state->__pyx_codeobj__473);
  Py_VISIT(traverse_module_state->__pyx_codeobj__474);
  Py_VISIT(traverse_module_state->__pyx_codeobj__475);
  Py_VISIT(traverse_module_state->__pyx_codeobj__476);
  Py_VISIT(traverse_module_state->__pyx_codeobj__477);
  Py_VISIT(traverse_module_state->__pyx_codeobj__478);
  Py_VISIT(traverse_module_state->__pyx_codeobj__479);
  Py_VISIT(traverse_module_state->__pyx_codeobj__480);
  Py_VISIT(traverse_module_state->__pyx_codeobj__481);
  Py_VISIT(traverse_module_state->__pyx_codeobj__482);
  Py_VISIT(traverse_module_state->__pyx_codeobj__483);
  Py_VISIT(traverse_module_state->__pyx_codeobj__484);
  Py_VISIT(traverse_module_state->__pyx_codeobj__485);
  Py_VISIT(traverse_module_state->__pyx_codeobj__486);
  Py_VISIT(traverse_module_state->__pyx_codeobj__487);
  Py_VISIT(traverse_module_state->__pyx_codeobj__488);
  Py_VISIT(traverse_module_state->__pyx_codeobj__489);
  Py_VISIT(traverse_module_state->__pyx_codeobj__490);
  Py_VISIT(traverse_module_state->__pyx_codeobj__491);
  Py_VISIT(traverse_module_state->__pyx_codeobj__492);
  Py_VISIT(traverse_module_state->__pyx_codeobj__493);
  Py_VISIT(traverse_module_state->__pyx_codeobj__494);
  Py_VISIT(traverse_module_state->__pyx_codeobj__495);
  Py_VISIT(traverse_module_state->__pyx_codeobj__496);
  Py_VISIT(traverse_module_state->__pyx_codeobj__497);
  Py_VISIT(traverse_module_state->__pyx_codeobj__498);
  Py_VISIT(traverse_module_state->__pyx_codeobj__499);
  Py_VISIT(traverse_module_state->__pyx_codeobj__500);
  Py_VISIT(traverse_module_state->__pyx_codeobj__501);
  Py_VISIT(traverse_module_state->__pyx_codeobj__502);
  Py_VISIT(traverse_module_state->__pyx_codeobj__503);
  Py_VISIT(traverse_module_state->__pyx_codeobj__504);
  Py_VISIT(traverse_module_state->__pyx_codeobj__505);
  Py_VISIT(traverse_module_state->__pyx_codeobj__506);
  Py_VISIT(traverse_module_state->__pyx_codeobj__507);
  Py_VISIT(traverse_module_state->__pyx_codeobj__508);
  Py_VISIT(traverse_module_state->__pyx_codeobj__509);
  Py_VISIT(traverse_module_state->__pyx_codeobj__510);
  Py_VISIT(traverse_module_state->__pyx_codeobj__511);
  Py_VISIT(traverse_module_state->__pyx_codeobj__512);
  Py_VISIT(traverse_module_state->__pyx_codeobj__513);
  Py_VISIT(traverse_module_state->__pyx_codeobj__514);
  Py_VISIT(traverse_module_state->__pyx_codeobj__515);
  Py_VISIT(traverse_module_state->__pyx_codeobj__516);
  Py_VISIT(traverse_module_state->__pyx_codeobj__517);
  Py_VISIT(traverse_module_state->__pyx_codeobj__518);
  Py_VISIT(traverse_module_state->__pyx_codeobj__519);
  Py_VISIT(traverse_module_state->__pyx_codeobj__520);
  Py_VISIT(traverse_module_state->__pyx_codeobj__521);
  Py_VISIT(traverse_module_state->__pyx_codeobj__522);
  Py_VISIT(traverse_module_state->__pyx_codeobj__523);
  Py_VISIT(traverse_module_state->__pyx_codeobj__524);
  Py_VISIT(traverse_module_state->__pyx_codeobj__525);
  Py_VISIT(traverse_module_state->__pyx_codeobj__526);
  Py_VISIT(traverse_module_state->__pyx_codeobj__527);
  Py_VISIT(traverse_module_state->__pyx_codeobj__528);
  Py_VISIT(traverse_module_state->__pyx_codeobj__529);
  Py_VISIT(traverse_module_state->__pyx_codeobj__530);
  Py_VISIT(traverse_module_state->__pyx_codeobj__531);
  Py_VISIT(traverse_module_state->__pyx_codeobj__532);
  Py_VISIT(traverse_module_state->__pyx_codeobj__533);
  Py_VISIT(traverse_module_state->__pyx_codeobj__534);
  Py_VISIT(traverse_module_state->__pyx_codeobj__535);
  Py_VISIT(traverse_module_state->__pyx_codeobj__536);
  Py_VISIT(traverse_module_state->__pyx_codeobj__537);
  Py_VISIT(traverse_module_state->__pyx_codeobj__538);
  Py_VISIT(traverse_module_state->__pyx_codeobj__539);
  Py_VISIT(traverse_module_state->__pyx_codeobj__540);
  Py_VISIT(traverse_module_state->__pyx_codeobj__541);
  Py_VISIT(traverse_module_state->__pyx_codeobj__542);
  Py_VISIT(traverse_module_state->__pyx_codeobj__543);
  Py_VISIT(traverse_module_state->__pyx_codeobj__544);
  Py_VISIT(traverse_module_state->__pyx_codeobj__545);
  Py_VISIT(traverse_module_state->__pyx_codeobj__546);
  Py_VISIT(traverse_module_state->__pyx_codeobj__547);
  Py_VISIT(traverse_module_state->__pyx_codeobj__548);
  Py_VISIT(traverse_module_state->__pyx_codeobj__549);
  Py_VISIT(traverse_module_state->__pyx_codeobj__550);
  Py_VISIT(traverse_module_state->__pyx_codeobj__551);
  Py_VISIT(traverse_module_state->__pyx_codeobj__552);
  Py_VISIT(traverse_module_state->__pyx_codeobj__553);
  Py_VISIT(traverse_module_state->__pyx_codeobj__554);
  Py_VISIT(traverse_module_state->__pyx_codeobj__555);
  Py_VISIT(traverse_module_state->__pyx_codeobj__556);
  Py_VISIT(traverse_module_state->__pyx_codeobj__557);
  Py_VISIT(traverse_module_state->__pyx_codeobj__558);
  Py_VISIT(traverse_module_state->__pyx_codeobj__559);
  Py_VISIT(traverse_module_state->__pyx_codeobj__560);
  Py_VISIT(traverse_module_state->__pyx_codeobj__561);
  Py_VISIT(traverse_module_state->__pyx_codeobj__562);
  Py_VISIT(traverse_module_state->__pyx_codeobj__563);
  Py_VISIT(traverse_module_state->__pyx_codeobj__564);
  Py_VISIT(traverse_module_state->__pyx_codeobj__565);
  Py_VISIT(traverse_module_state->__pyx_codeobj__566);
  Py_VISIT(traverse_module_state->__pyx_codeobj__567);
  Py_VISIT(traverse_module_state->__pyx_codeobj__568);
  Py_VISIT(traverse_module_state->__pyx_codeobj__569);
  Py_VISIT(traverse_module_state->__pyx_codeobj__570);
  Py_VISIT(traverse_module_state->__pyx_codeobj__571);
  Py_VISIT(traverse_module_state->__pyx_codeobj__572);
  Py_VISIT(traverse_module_state->__pyx_codeobj__573);
  Py_VISIT(traverse_module_state->__pyx_codeobj__574);
  Py_VISIT(traverse_module_state->__pyx_codeobj__575);
  Py_VISIT(traverse_module_state->__pyx_codeobj__576);
  Py_VISIT(traverse_module_state->__pyx_codeobj__577);
  Py_VISIT(traverse_module_state->__pyx_codeobj__578);
  Py_VISIT(traverse_module_state->__pyx_codeobj__579);
  Py_VISIT(traverse_module_state->__pyx_codeobj__580);
  Py_VISIT(traverse_module_state->__pyx_codeobj__581);
  Py_VISIT(traverse_module_state->__pyx_codeobj__582);
  Py_VISIT(traverse_module_state->__pyx_codeobj__583);
  Py_VISIT(traverse_module_state->__pyx_codeobj__584);
  Py_VISIT(traverse_module_state->__pyx_codeobj__585);
  Py_VISIT(traverse_module_state->__pyx_codeobj__586);
  Py_VISIT(traverse_module_state->__pyx_codeobj__587);
  Py_VISIT(traverse_module_state->__pyx_codeobj__588);
  Py_VISIT(traverse_module_state->__pyx_codeobj__589);
  Py_VISIT(traverse_module_state->__pyx_codeobj__590);
  Py_VISIT(traverse_module_state->__pyx_codeobj__591);
  Py_VISIT(traverse_module_state->__pyx_codeobj__592);
  Py_VISIT(traverse_module_state->__pyx_codeobj__593);
  Py_VISIT(traverse_module_state->__pyx_codeobj__594);
  Py_VISIT(traverse_module_state->__pyx_codeobj__595);
  Py_VISIT(traverse_module_state->__pyx_codeobj__596);
  Py_VISIT(traverse_module_state->__pyx_codeobj__597);
  Py_VISIT(traverse_module_state->__pyx_codeobj__598);
  Py_VISIT(traverse_module_state->__pyx_codeobj__599);
  Py_VISIT(traverse_module_state->__pyx_codeobj__600);
  Py_VISIT(traverse_module_state->__pyx_codeobj__601);
  Py_VISIT(traverse_module_state->__pyx_codeobj__602);
  Py_VISIT(traverse_module_state->__pyx_codeobj__603);
  Py_VISIT(traverse_module_state->__pyx_codeobj__604);
  Py_VISIT(traverse_module_state->__pyx_codeobj__605);
  Py_VISIT(traverse_module_state->__pyx_codeobj__606);
  Py_VISIT(traverse_module_state->__pyx_codeobj__607);
  Py_VISIT(traverse_module_state->__pyx_codeobj__608);
  Py_VISIT(traverse_module_state->__pyx_codeobj__609);
  Py_VISIT(traverse_module_state->__pyx_codeobj__610);
  Py_VISIT(traverse_module_state->__pyx_codeobj__611);
  Py_VISIT(traverse_module_state->__pyx_codeobj__612);
  Py_VISIT(traverse_module_state->__pyx_codeobj__613);
  Py_VISIT(traverse_module_state->__pyx_codeobj__614);
  Py_VISIT(traverse_module_state->__pyx_codeobj__615);
  Py_VISIT(traverse_module_state->__pyx_codeobj__616);
  Py_VISIT(traverse_module_state->__pyx_codeobj__617);
  Py_VISIT(traverse_module_state->__pyx_codeobj__618);
  Py_VISIT(traverse_module_state->__pyx_codeobj__619);
  Py_VISIT(traverse_module_state->__pyx_codeobj__620);
  Py_VISIT(traverse_module_state->__pyx_codeobj__621);
  Py_VISIT(traverse_module_state->__pyx_codeobj__622);
  Py_VISIT(traverse_module_state->__pyx_codeobj__623);
  Py_VISIT(traverse_module_state->__pyx_codeobj__624);
  Py_VISIT(traverse_module_state->__pyx_codeobj__625);
  Py_VISIT(traverse_module_state->__pyx_codeobj__626);
  Py_VISIT(traverse_module_state->__pyx_codeobj__627);
  Py_VISIT(traverse_module_state->__pyx_codeobj__628);
  Py_VISIT(traverse_module_state->__pyx_codeobj__629);
  Py_VISIT(traverse_module_state->__pyx_codeobj__630);
  Py_VISIT(traverse_module_state->__pyx_codeobj__631);
  Py_VISIT(traverse_module_state->__pyx_codeobj__632);
  Py_VISIT(traverse_module_state->__pyx_codeobj__633);
  Py_VISIT(traverse_module_state->__pyx_codeobj__634);
  Py_VISIT(traverse_module_state->__pyx_codeobj__635);
  Py_VISIT(traverse_module_state->__pyx_codeobj__636);
  Py_VISIT(traverse_module_state->__pyx_codeobj__637);
  Py_VISIT(traverse_module_state->__pyx_codeobj__638);
  Py_VISIT(traverse_module_state->__pyx_codeobj__639);
  Py_VISIT(traverse_module_state->__pyx_codeobj__640);
  Py_VISIT(traverse_module_state->__pyx_codeobj__641);
  Py_VISIT(traverse_module_state->__pyx_codeobj__642);
  Py_VISIT(traverse_module_state->__pyx_codeobj__643);
  Py_VISIT(traverse_module_state->__pyx_codeobj__644);
  Py_VISIT(traverse_module_state->__pyx_codeobj__645);
  Py_VISIT(traverse_module_state->__pyx_codeobj__646);
  Py_VISIT(traverse_module_state->__pyx_codeobj__647);
  Py_VISIT(traverse_module_state->__pyx_codeobj__648);
  Py_VISIT(traverse_module_state->__pyx_codeobj__649);
  Py_VISIT(traverse_module_state->__pyx_codeobj__650);
  Py_VISIT(traverse_module_state->__pyx_codeobj__651);
  Py_VISIT(traverse_module_state->__pyx_codeobj__652);
  Py_VISIT(traverse_module_state->__pyx_codeobj__653);
  Py_VISIT(traverse_module_state->__pyx_codeobj__654);
  Py_VISIT(traverse_module_state->__pyx_codeobj__655);
  Py_VISIT(traverse_module_state->__pyx_codeobj__656);
  Py_VISIT(traverse_module_state->__pyx_codeobj__657);
  Py_VISIT(traverse_module_state->__pyx_codeobj__658);
  Py_VISIT(traverse_module_state->__pyx_codeobj__659);
  Py_VISIT(traverse_module_state->__pyx_codeobj__660);
  Py_VISIT(traverse_module_state->__pyx_codeobj__661);
  Py_VISIT(traverse_module_state->__pyx_codeobj__662);
  Py_VISIT(traverse_module_state->__pyx_codeobj__663);
  Py_VISIT(traverse_module_state->__pyx_codeobj__664);
  Py_VISIT(traverse_module_state->__pyx_codeobj__665);
  Py_VISIT(traverse_module_state->__pyx_codeobj__666);
  Py_VISIT(traverse_module_state->__pyx_codeobj__667);
  Py_VISIT(traverse_module_state->__pyx_codeobj__668);
  Py_VISIT(traverse_module_state->__pyx_codeobj__669);
  Py_VISIT(traverse_module_state->__pyx_codeobj__670);
  Py_VISIT(traverse_module_state->__pyx_codeobj__671);
  Py_VISIT(traverse_module_state->__pyx_codeobj__672);
  Py_VISIT(traverse_module_state->__pyx_codeobj__673);
  Py_VISIT(traverse_module_state->__pyx_codeobj__674);
  Py_VISIT(traverse_module_state->__pyx_codeobj__675);
  Py_VISIT(traverse_module_state->__pyx_codeobj__676);
  Py_VISIT(traverse_module_state->__pyx_codeobj__677);
  Py_VISIT(traverse_module_state->__pyx_codeobj__678);
  Py_VISIT(traverse_module_state->__pyx_codeobj__679);
  Py_VISIT(traverse_module_state->__pyx_codeobj__680);
  Py_VISIT(traverse_module_state->__pyx_codeobj__681);
  Py_VISIT(traverse_module_state->__pyx_codeobj__682);
  Py_VISIT(traverse_module_state->__pyx_codeobj__683);
  Py_VISIT(traverse_module_state->__pyx_codeobj__684);
  Py_VISIT(traverse_module_state->__pyx_codeobj__685);
  Py_VISIT(traverse_module_state->__pyx_codeobj__686);
  Py_VISIT(traverse_module_state->__pyx_codeobj__687);
  Py_VISIT(traverse_module_state->__pyx_codeobj__688);
  Py_VISIT(traverse_module_state->__pyx_codeobj__689);
  Py_VISIT(traverse_module_state->__pyx_codeobj__690);
  Py_VISIT(traverse_module_state->__pyx_codeobj__691);
  Py_VISIT(traverse_module_state->__pyx_codeobj__692);
  Py_VISIT(traverse_module_state->__pyx_codeobj__693);
  Py_VISIT(traverse_module_state->__pyx_codeobj__694);
  Py_VISIT(traverse_module_state->__pyx_codeobj__695);
  Py_VISIT(traverse_module_state->__pyx_codeobj__696);
  Py_VISIT(traverse_module_state->__pyx_codeobj__697);
  Py_VISIT(traverse_module_state->__pyx_codeobj__698);
  Py_VISIT(traverse_module_state->__pyx_codeobj__699);
  Py_VISIT(traverse_module_state->__pyx_codeobj__700);
  Py_VISIT(traverse_module_state->__pyx_codeobj__701);
  Py_VISIT(traverse_module_state->__pyx_codeobj__702);
  Py_VISIT(traverse_module_state->__pyx_codeobj__703);
  Py_VISIT(traverse_module_state->__pyx_codeobj__704);
  Py_VISIT(traverse_module_state->__pyx_codeobj__705);
  Py_VISIT(traverse_module_state->__pyx_codeobj__706);
  Py_VISIT(traverse_module_state->__pyx_codeobj__707);
  Py_VISIT(traverse_module_state->__pyx_codeobj__708);
  Py_VISIT(traverse_module_state->__pyx_codeobj__709);
  Py_VISIT(traverse_module_state->__pyx_codeobj__710);
  Py_VISIT(traverse_module_state->__pyx_codeobj__711);
  Py_VISIT(traverse_module_state->__pyx_codeobj__712);
  Py_VISIT(traverse_module_state->__pyx_codeobj__713);
  Py_VISIT(traverse_module_state->__pyx_codeobj__714);
  Py_VISIT(traverse_module_state->__pyx_codeobj__715);
  Py_VISIT(traverse_module_state->__pyx_codeobj__716);
  Py_VISIT(traverse_module_state->__pyx_codeobj__717);
  Py_VISIT(traverse_module_state->__pyx_codeobj__718);
  Py_VISIT(traverse_module_state->__pyx_codeobj__719);
  Py_VISIT(traverse_module_state->__pyx_codeobj__720);
  Py_VISIT(traverse_module_state->__pyx_codeobj__721);
  Py_VISIT(traverse_module_state->__pyx_codeobj__722);
  Py_VISIT(traverse_module_state->__pyx_codeobj__723);
  Py_VISIT(traverse_module_state->__pyx_codeobj__724);
  Py_VISIT(traverse_module_state->__pyx_codeobj__725);
  Py_VISIT(traverse_module_state->__pyx_codeobj__726);
  Py_VISIT(traverse_module_state->__pyx_codeobj__727);
  Py_VISIT(traverse_module_state->__pyx_codeobj__728);
  Py_VISIT(traverse_module_state->__pyx_codeobj__729);
  Py_VISIT(traverse_module_state->__pyx_codeobj__730);
  Py_VISIT(traverse_module_state->__pyx_codeobj__731);
  Py_VISIT(traverse_module_state->__pyx_codeobj__732);
  Py_VISIT(traverse_module_state->__pyx_codeobj__733);
  Py_VISIT(traverse_module_state->__pyx_codeobj__734);
  Py_VISIT(traverse_module_state->__pyx_codeobj__735);
  Py_VISIT(traverse_module_state->__pyx_codeobj__736);
  Py_VISIT(traverse_module_state->__pyx_codeobj__737);
  Py_VISIT(traverse_module_state->__pyx_codeobj__738);
  Py_VISIT(traverse_module_state->__pyx_codeobj__739);
  Py_VISIT(traverse_module_state->__pyx_codeobj__740);
  Py_VISIT(traverse_module_state->__pyx_codeobj__741);
  Py_VISIT(traverse_module_state->__pyx_codeobj__742);
  Py_VISIT(traverse_module_state->__pyx_codeobj__743);
  Py_VISIT(traverse_module_state->__pyx_codeobj__744);
  Py_VISIT(traverse_module_state->__pyx_codeobj__745);
  Py_VISIT(traverse_module_state->__pyx_codeobj__746);
  Py_VISIT(traverse_module_state->__pyx_codeobj__747);
  Py_VISIT(traverse_module_state->__pyx_codeobj__748);
  Py_VISIT(traverse_module_state->__pyx_codeobj__749);
  Py_VISIT(traverse_module_state->__pyx_codeobj__750);
  Py_VISIT(traverse_module_state->__pyx_codeobj__751);
  Py_VISIT(traverse_module_state->__pyx_codeobj__752);
  Py_VISIT(traverse_module_state->__pyx_codeobj__753);
  Py_VISIT(traverse_module_state->__pyx_codeobj__754);
  Py_VISIT(traverse_module_state->__pyx_codeobj__755);
  Py_VISIT(traverse_module_state->__pyx_codeobj__756);
  Py_VISIT(traverse_module_state->__pyx_codeobj__757);
  Py_VISIT(traverse_module_state->__pyx_codeobj__758);
  Py_VISIT(traverse_module_state->__pyx_codeobj__759);
  Py_VISIT(traverse_module_state->__pyx_codeobj__760);
  Py_VISIT(traverse_module_state->__pyx_codeobj__761);
  Py_VISIT(traverse_module_state->__pyx_codeobj__762);
  Py_VISIT(traverse_module_state->__pyx_codeobj__763);
  Py_VISIT(traverse_module_state->__pyx_codeobj__764);
  Py_VISIT(traverse_module_state->__pyx_codeobj__765);
  Py_VISIT(traverse_module_state->__pyx_codeobj__766);
  Py_VISIT(traverse_module_state->__pyx_codeobj__767);
  Py_VISIT(traverse_module_state->__pyx_codeobj__768);
  Py_VISIT(traverse_module_state->__pyx_codeobj__769);
  Py_VISIT(traverse_module_state->__pyx_codeobj__770);
  Py_VISIT(traverse_module_state->__pyx_codeobj__771);
  Py_VISIT(traverse_module_state->__pyx_codeobj__772);
  Py_VISIT(traverse_module_state->__pyx_codeobj__773);
  Py_VISIT(traverse_module_state->__pyx_codeobj__774);
  Py_VISIT(traverse_module_state->__pyx_codeobj__775);
  Py_VISIT(traverse_module_state->__pyx_codeobj__776);
  Py_VISIT(traverse_module_state->__pyx_codeobj__777);
  Py_VISIT(traverse_module_state->__pyx_codeobj__778);
  Py_VISIT(traverse_module_state->__pyx_codeobj__779);
  Py_VISIT(traverse_module_state->__pyx_codeobj__780);
  Py_VISIT(traverse_module_state->__pyx_codeobj__781);
  Py_VISIT(traverse_module_state->__pyx_codeobj__782);
  Py_VISIT(traverse_module_state->__pyx_codeobj__783);
  Py_VISIT(traverse_module_state->__pyx_codeobj__784);
  Py_VISIT(traverse_module_state->__pyx_codeobj__785);
  Py_VISIT(traverse_module_state->__pyx_codeobj__786);
  Py_VISIT(traverse_module_state->__pyx_codeobj__787);
  Py_VISIT(traverse_module_state->__pyx_codeobj__788);
  Py_VISIT(traverse_module_state->__pyx_codeobj__789);
  Py_VISIT(traverse_module_state->__pyx_codeobj__790);
  Py_VISIT(traverse_module_state->__pyx_codeobj__791);
  Py_VISIT(traverse_module_state->__pyx_codeobj__792);
  Py_VISIT(traverse_module_state->__pyx_codeobj__793);
  Py_VISIT(traverse_module_state->__pyx_codeobj__794);
  Py_VISIT(traverse_module_state->__pyx_codeobj__795);
  Py_VISIT(traverse_module_state->__pyx_codeobj__796);
  Py_VISIT(traverse_module_state->__pyx_codeobj__797);
  Py_VISIT(traverse_module_state->__pyx_codeobj__798);
  Py_VISIT(traverse_module_state->__pyx_codeobj__799);
  Py_VISIT(traverse_module_state->__pyx_codeobj__800);
  Py_VISIT(traverse_module_state->__pyx_codeobj__801);
  Py_VISIT(traverse_module_state->__pyx_codeobj__802);
  Py_VISIT(traverse_module_state->__pyx_codeobj__803);
  Py_VISIT(traverse_module_state->__pyx_codeobj__804);
  Py_VISIT(traverse_module_state->__pyx_codeobj__805);
  Py_VISIT(traverse_module_state->__pyx_codeobj__806);
  Py_VISIT(traverse_module_state->__pyx_codeobj__807);
  Py_VISIT(traverse_module_state->__pyx_codeobj__808);
  Py_VISIT(traverse_module_state->__pyx_codeobj__809);
  Py_VISIT(traverse_module_state->__pyx_codeobj__810);
  Py_VISIT(traverse_module_state->__pyx_codeobj__811);
  Py_VISIT(traverse_module_state->__pyx_codeobj__812);
  Py_VISIT(traverse_module_state->__pyx_codeobj__813);
  Py_VISIT(traverse_module_state->__pyx_codeobj__814);
  Py_VISIT(traverse_module_state->__pyx_codeobj__815);
  Py_VISIT(traverse_module_state->__pyx_codeobj__816);
  Py_VISIT(traverse_module_state->__pyx_codeobj__817);
  Py_VISIT(traverse_module_state->__pyx_codeobj__818);
  Py_VISIT(traverse_module_state->__pyx_codeobj__819);
  Py_VISIT(traverse_module_state->__pyx_codeobj__820);
  Py_VISIT(traverse_module_state->__pyx_codeobj__821);
  Py_VISIT(traverse_module_state->__pyx_codeobj__822);
  Py_VISIT(traverse_module_state->__pyx_codeobj__823);
  Py_VISIT(traverse_module_state->__pyx_codeobj__824);
  Py_VISIT(traverse_module_state->__pyx_codeobj__825);
  Py_VISIT(traverse_module_state->__pyx_codeobj__826);
  Py_VISIT(traverse_module_state->__pyx_codeobj__827);
  Py_VISIT(traverse_module_state->__pyx_codeobj__828);
  Py_VISIT(traverse_module_state->__pyx_codeobj__829);
  Py_VISIT(traverse_module_state->__pyx_codeobj__830);
  Py_VISIT(traverse_module_state->__pyx_codeobj__831);
  Py_VISIT(traverse_module_state->__pyx_codeobj__832);
  Py_VISIT(traverse_module_state->__pyx_codeobj__833);
  Py_VISIT(traverse_module_state->__pyx_codeobj__834);
  Py_VISIT(traverse_module_state->__pyx_codeobj__835);
  Py_VISIT(traverse_module_state->__pyx_codeobj__836);
  Py_VISIT(traverse_module_state->__pyx_codeobj__837);
  Py_VISIT(traverse_module_state->__pyx_codeobj__838);
  Py_VISIT(traverse_module_state->__pyx_codeobj__839);
  Py_VISIT(traverse_module_state->__pyx_codeobj__840);
  Py_VISIT(traverse_module_state->__pyx_codeobj__841);
  Py_VISIT(traverse_module_state->__pyx_codeobj__842);
  Py_VISIT(traverse_module_state->__pyx_codeobj__843);
  Py_VISIT(traverse_module_state->__pyx_codeobj__844);
  Py_VISIT(traverse_module_state->__pyx_codeobj__845);
  Py_VISIT(traverse_module_state->__pyx_codeobj__846);
  Py_VISIT(traverse_module_state->__pyx_codeobj__847);
  Py_VISIT(traverse_module_state->__pyx_codeobj__848);
  Py_VISIT(traverse_module_state->__pyx_codeobj__849);
  Py_VISIT(traverse_module_state->__pyx_codeobj__850);
  Py_VISIT(traverse_module_state->__pyx_codeobj__851);
  Py_VISIT(traverse_module_state->__pyx_codeobj__852);
  Py_VISIT(traverse_module_state->__pyx_codeobj__853);
  Py_VISIT(traverse_module_state->__pyx_codeobj__854);
  Py_VISIT(traverse_module_state->__pyx_codeobj__855);
  Py_VISIT(traverse_module_state->__pyx_codeobj__856);
  Py_VISIT(traverse_module_state->__pyx_codeobj__857);
  Py_VISIT(traverse_module_state->__pyx_codeobj__858);
  Py_VISIT(traverse_module_state->__pyx_codeobj__859);
  Py_VISIT(traverse_module_state->__pyx_codeobj__860);
  Py_VISIT(traverse_module_state->__pyx_codeobj__861);
  Py_VISIT(traverse_module_state->__pyx_codeobj__862);
  Py_VISIT(traverse_module_state->__pyx_codeobj__863);
  Py_VISIT(traverse_module_state->__pyx_codeobj__864);
  Py_VISIT(traverse_module_state->__pyx_codeobj__865);
  Py_VISIT(traverse_module_state->__pyx_codeobj__866);
  Py_VISIT(traverse_module_state->__pyx_codeobj__867);
  Py_VISIT(traverse_module_state->__pyx_codeobj__868);
  Py_VISIT(traverse_module_state->__pyx_codeobj__869);
  Py_VISIT(traverse_module_state->__pyx_codeobj__870);
  Py_VISIT(traverse_module_state->__pyx_codeobj__871);
  Py_VISIT(traverse_module_state->__pyx_codeobj__872);
  Py_VISIT(traverse_module_state->__pyx_codeobj__873);
  Py_VISIT(traverse_module_state->__pyx_codeobj__874);
  Py_VISIT(traverse_module_state->__pyx_codeobj__875);
  Py_VISIT(traverse_module_state->__pyx_codeobj__876);
  Py_VISIT(traverse_module_state->__pyx_codeobj__877);
  Py_VISIT(traverse_module_state->__pyx_codeobj__878);
  Py_VISIT(traverse_module_state->__pyx_codeobj__879);
  Py_VISIT(traverse_module_state->__pyx_codeobj__880);
  Py_VISIT(traverse_module_state->__pyx_codeobj__881);
  Py_VISIT(traverse_module_state->__pyx_codeobj__882);
  Py_VISIT(traverse_module_state->__pyx_codeobj__883);
  Py_VISIT(traverse_module_state->__pyx_codeobj__884);
  Py_VISIT(traverse_module_state->__pyx_codeobj__885);
  Py_VISIT(traverse_module_state->__pyx_codeobj__886);
  Py_VISIT(traverse_module_state->__pyx_codeobj__887);
  Py_VISIT(traverse_module_state->__pyx_codeobj__888);
  Py_VISIT(traverse_module_state->__pyx_codeobj__889);
  Py_VISIT(traverse_module_state->__pyx_codeobj__890);
  Py_VISIT(traverse_module_state->__pyx_codeobj__891);
  Py_VISIT(traverse_module_state->__pyx_codeobj__892);
  Py_VISIT(traverse_module_state->__pyx_codeobj__893);
  Py_VISIT(traverse_module_state->__pyx_codeobj__894);
  Py_VISIT(traverse_module_state->__pyx_codeobj__895);
  Py_VISIT(traverse_module_state->__pyx_codeobj__896);
  Py_VISIT(traverse_module_state->__pyx_codeobj__897);
  Py_VISIT(traverse_module_state->__pyx_codeobj__898);
  Py_VISIT(traverse_module_state->__pyx_codeobj__899);
  Py_VISIT(traverse_module_state->__pyx_codeobj__900);
  Py_VISIT(traverse_module_state->__pyx_codeobj__901);
  Py_VISIT(traverse_module_state->__pyx_codeobj__902);
  Py_VISIT(traverse_module_state->__pyx_codeobj__903);
  Py_VISIT(traverse_module_state->__pyx_codeobj__904);
  Py_VISIT(traverse_module_state->__pyx_codeobj__905);
  Py_VISIT(traverse_module_state->__pyx_codeobj__906);
  Py_VISIT(traverse_module_state->__pyx_codeobj__907);
  Py_VISIT(traverse_module_state->__pyx_codeobj__908);
  Py_VISIT(traverse_module_state->__pyx_codeobj__909);
  Py_VISIT(traverse_module_state->__pyx_codeobj__910);
  Py_VISIT(traverse_module_state->__pyx_codeobj__911);
  Py_VISIT(traverse_module_state->__pyx_codeobj__912);
  Py_VISIT(traverse_module_state->__pyx_codeobj__913);
  Py_VISIT(traverse_module_state->__pyx_codeobj__914);
  Py_VISIT(traverse_module_state->__pyx_codeobj__915);
  Py_VISIT(traverse_module_state->__pyx_codeobj__916);
  Py_VISIT(traverse_module_state->__pyx_codeobj__917);
  Py_VISIT(traverse_module_state->__pyx_codeobj__918);
  Py_VISIT(traverse_module_state->__pyx_codeobj__919);
  Py_VISIT(traverse_module_state->__pyx_codeobj__920);
  Py_VISIT(traverse_module_state->__pyx_codeobj__921);
  Py_VISIT(traverse_module_state->__pyx_codeobj__922);
  Py_VISIT(traverse_module_state->__pyx_codeobj__923);
  Py_VISIT(traverse_module_state->__pyx_codeobj__924);
  Py_VISIT(traverse_module_state->__pyx_codeobj__925);
  Py_VISIT(traverse_module_state->__pyx_codeobj__926);
  Py_VISIT(traverse_module_state->__pyx_codeobj__927);
  Py_VISIT(traverse_module_state->__pyx_codeobj__928);
  Py_VISIT(traverse_module_state->__pyx_codeobj__929);
  Py_VISIT(traverse_module_state->__pyx_codeobj__930);
  Py_VISIT(traverse_module_state->__pyx_codeobj__931);
  Py_VISIT(traverse_module_state->__pyx_codeobj__932);
  Py_VISIT(traverse_module_state->__pyx_codeobj__933);
  Py_VISIT(traverse_module_state->__pyx_codeobj__934);
  Py_VISIT(traverse_module_state->__pyx_codeobj__935);
  Py_VISIT(traverse_module_state->__pyx_codeobj__936);
  Py_VISIT(traverse_module_state->__pyx_codeobj__937);
  Py_VISIT(traverse_module_state->__pyx_codeobj__938);
  Py_VISIT(traverse_module_state->__pyx_codeobj__939);
  Py_VISIT(traverse_module_state->__pyx_codeobj__940);
  Py_VISIT(traverse_module_state->__pyx_codeobj__941);
  Py_VISIT(traverse_module_state->__pyx_codeobj__942);
  Py_VISIT(traverse_module_state->__pyx_codeobj__943);
  Py_VISIT(traverse_module_state->__pyx_codeobj__944);
  Py_VISIT(traverse_module_state->__pyx_codeobj__945);
  Py_VISIT(traverse_module_state->__pyx_codeobj__946);
  Py_VISIT(traverse_module_state->__pyx_codeobj__947);
  Py_VISIT(traverse_module_state->__pyx_codeobj__948);
  Py_VISIT(traverse_module_state->__pyx_codeobj__949);
  Py_VISIT(traverse_module_state->__pyx_codeobj__950);
  Py_VISIT(traverse_module_state->__pyx_codeobj__951);
  Py_VISIT(traverse_module_state->__pyx_codeobj__952);
  Py_VISIT(traverse_module_state->__pyx_codeobj__953);
  Py_VISIT(traverse_module_state->__pyx_codeobj__954);
  Py_VISIT(traverse_module_state->__pyx_codeobj__955);
  Py_VISIT(traverse_module_state->__pyx_codeobj__956);
  Py_VISIT(traverse_module_state->__pyx_codeobj__957);
  Py_VISIT(traverse_module_state->__pyx_codeobj__958);
  Py_VISIT(traverse_module_state->__pyx_codeobj__959);
  Py_VISIT(traverse_module_state->__pyx_codeobj__960);
  Py_VISIT(traverse_module_state->__pyx_codeobj__961);
  Py_VISIT(traverse_module_state->__pyx_codeobj__962);
  Py_VISIT(traverse_module_state->__pyx_codeobj__963);
  Py_VISIT(traverse_module_state->__pyx_codeobj__964);
  Py_VISIT(traverse_module_state->__pyx_codeobj__965);
  Py_VISIT(traverse_module_state->__pyx_codeobj__966);
  Py_VISIT(traverse_module_state->__pyx_codeobj__967);
  Py_VISIT(traverse_module_state->__pyx_codeobj__968);
  Py_VISIT(traverse_module_state->__pyx_codeobj__969);
  Py_VISIT(traverse_module_state->__pyx_codeobj__970);
  Py_VISIT(traverse_module_state->__pyx_codeobj__971);
  Py_VISIT(traverse_module_state->__pyx_codeobj__972);
  Py_VISIT(traverse_module_state->__pyx_codeobj__973);
  Py_VISIT(traverse_module_state->__pyx_codeobj__974);
  Py_VISIT(traverse_module_state->__pyx_codeobj__975);
  Py_VISIT(traverse_module_state->__pyx_codeobj__976);
  Py_VISIT(traverse_module_state->__pyx_codeobj__977);
  Py_VISIT(traverse_module_state->__pyx_codeobj__978);
  Py_VISIT(traverse_module_state->__pyx_codeobj__979);
  Py_VISIT(traverse_module_state->__pyx_codeobj__980);
  Py_VISIT(traverse_module_state->__pyx_codeobj__981);
  Py_VISIT(traverse_module_state->__pyx_codeobj__982);
  Py_VISIT(traverse_module_state->__pyx_codeobj__983);
  Py_VISIT(traverse_module_state->__pyx_codeobj__984);
  Py_VISIT(traverse_module_state->__pyx_codeobj__985);
  Py_VISIT(traverse_module_state->__pyx_codeobj__986);
  Py_VISIT(traverse_module_state->__pyx_codeobj__987);
  Py_VISIT(traverse_module_state->__pyx_codeobj__988);
  Py_VISIT(traverse_module_state->__pyx_codeobj__989);
  Py_VISIT(traverse_module_state->__pyx_codeobj__990);
  Py_VISIT(traverse_module_state->__pyx_codeobj__991);
  Py_VISIT(traverse_module_state->__pyx_codeobj__992);
  Py_VISIT(traverse_module_state->__pyx_codeobj__993);
  Py_VISIT(traverse_module_state->__pyx_codeobj__994);
  Py_VISIT(traverse_module_state->__pyx_codeobj__995);
  Py_VISIT(traverse_module_state->__pyx_codeobj__996);
  Py_VISIT(traverse_module_state->__pyx_codeobj__997);
  Py_VISIT(traverse_module_state->__pyx_codeobj__998);
  Py_VISIT(traverse_module_state->__pyx_codeobj__999);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1000);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1001);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1002);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1003);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1004);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1005);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1006);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1007);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1008);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1009);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1010);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1011);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1012);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1013);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1014);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1015);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1016);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1017);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1018);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1019);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1020);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1021);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1022);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1023);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1024);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1025);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1026);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1027);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1028);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1029);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1030);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1031);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1032);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1033);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1034);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1035);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1036);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1037);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1038);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1039);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1040);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1041);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1042);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1043);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1044);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1045);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1046);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1047);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1048);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1049);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1050);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1051);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1052);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1053);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1054);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1055);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1056);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1057);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1058);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1059);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1060);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1061);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1062);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1063);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1064);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1065);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1066);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1067);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1068);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1069);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1070);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1071);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1072);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1073);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1074);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1075);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1076);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1077);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1078);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1079);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1080);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1081);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1082);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1083);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1084);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1085);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1086);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1087);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1088);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1089);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1090);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1091);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1092);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1093);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1094);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1095);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1096);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1097);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1098);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1099);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1101);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1102);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1103);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1105);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1107);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1109);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1110);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1111);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1112);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1113);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1114);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1115);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1116);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1117);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1118);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1119);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1120);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1121);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1122);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1123);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1125);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1126);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1127);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1128);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1129);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1130);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1131);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1132);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1133);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1134);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1135);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1136);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1137);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1138);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1139);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1140);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1141);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1142);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1143);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1144);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1145);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1146);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1147);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1148);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1149);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1150);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1151);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1152);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1153);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1154);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1155);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1156);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1157);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1158);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1159);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1160);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1161);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1162);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1163);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1164);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1165);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1166);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1167);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1168);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1169);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1170);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1171);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1172);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1173);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1174);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1175);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1176);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1177);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1178);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1179);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1180);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1181);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1182);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1183);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1184);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1185);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1186);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1187);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1188);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1189);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1190);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1191);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1192);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1193);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1194);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1195);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1196);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1197);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1198);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1199);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1200);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1201);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1202);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1203);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1204);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1206);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1207);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1208);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1209);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1210);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1211);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1212);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1213);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1214);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1215);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1216);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1217);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1218);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1219);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1220);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1221);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1223);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1225);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1226);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1227);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1228);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1229);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1230);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1231);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1232);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1233);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1234);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1236);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1237);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1240);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1241);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1242);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1243);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1244);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1245);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1246);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1247);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1248);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1249);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1250);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1252);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1254);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1256);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1258);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1259);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1260);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1261);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1262);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1263);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1264);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1265);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1266);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1267);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1268);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1269);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1271);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1273);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1274);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1275);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1276);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1277);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1278);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1279);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1280);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1281);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1283);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1284);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1285);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1286);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1287);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1288);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1289);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1290);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1291);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1292);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1293);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1294);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1295);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1296);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1297);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1298);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1299);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1300);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1301);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1302);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1303);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1304);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1305);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1306);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1307);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1308);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1309);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1310);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1311);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1312);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1313);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1314);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1315);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1316);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1317);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1318);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1319);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1320);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1321);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1322);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1323);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1324);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1325);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1326);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1327);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1328);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1329);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1330);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1331);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1332);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1333);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1334);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1335);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1336);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1337);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1338);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1339);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1340);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1341);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1342);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1343);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1344);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1345);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1346);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1347);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1348);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1349);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1350);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1351);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1352);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1353);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1354);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1355);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1356);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1357);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1358);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1359);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1360);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1361);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1362);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1363);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1364);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1365);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1366);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1367);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1368);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1369);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1370);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1371);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1372);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1373);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1374);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1375);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1376);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1377);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1378);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1379);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1380);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1381);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1382);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1383);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1384);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1385);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1386);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1387);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1388);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1389);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1390);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1391);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1392);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1393);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1394);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1395);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1396);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1397);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1398);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1399);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1400);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1401);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1402);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1403);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1404);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1405);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1406);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1407);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1408);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1409);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1410);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1411);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1412);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1413);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1414);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1415);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1416);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1417);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1418);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1419);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1420);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1421);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1422);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1423);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1424);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1425);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1426);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1427);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1428);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1429);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1430);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1431);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1432);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1433);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1434);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1435);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1436);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1437);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1438);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1439);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1440);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1441);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1442);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1443);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1444);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1445);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1446);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1447);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1448);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1449);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1450);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1451);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1452);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1453);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1454);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1455);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1456);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1457);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1458);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1459);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1460);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1461);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1462);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1463);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1464);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1465);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1466);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1467);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1468);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1469);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1470);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1471);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1472);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1473);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1474);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1475);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1476);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1477);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1478);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1479);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1480);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1481);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1482);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1483);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1484);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1485);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1486);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1487);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1488);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1489);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1490);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1491);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1492);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1493);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1494);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1495);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1496);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1497);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1498);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1499);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1500);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1501);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1502);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1503);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1504);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1505);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1506);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1507);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1508);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1509);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1510);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1511);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1512);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1513);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1514);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1515);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1516);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1517);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1518);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1519);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1520);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1521);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1522);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1523);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1524);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1525);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1526);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1527);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1528);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1529);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1530);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1531);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1532);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1533);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1534);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1535);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1536);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1537);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1538);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1539);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1540);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1541);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1542);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1543);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1544);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1545);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1546);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1547);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1548);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1549);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1550);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1551);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1552);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1553);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1554);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1555);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1556);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1557);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1558);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1559);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1560);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1561);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1562);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1563);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1564);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1565);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1566);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1567);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1568);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1569);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1570);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1571);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1572);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1573);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1574);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1575);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1576);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1577);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1578);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1579);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1580);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1581);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1582);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1583);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1584);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1585);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1586);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1587);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1588);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1589);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1590);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1591);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1592);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1593);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1594);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1595);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1596);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1597);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1598);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1599);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1600);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1601);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1602);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1603);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1604);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1605);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1606);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1607);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1608);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1609);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1610);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1611);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1612);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1613);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1614);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1615);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1616);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1617);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1618);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1619);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1620);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1621);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1622);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1623);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1624);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1625);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1626);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1628);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1629);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1631);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1633);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1634);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1635);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1636);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1638);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1640);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1642);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1644);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1647);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1648);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1649);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1652);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1654);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1701);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1703);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1704);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1705);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1706);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1708);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1709);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1710);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1711);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1712);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1714);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1715);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1716);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1717);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1718);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1720);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1723);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1725);
  Py_VISIT(traverse_module_state->__pyx_codeobj__1727);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_6giacpy_6giacpy_GiacMethods_base __pyx_mstate_global->__pyx_type_6giacpy_6giacpy_GiacMethods_base
#define __pyx_type_6giacpy_6giacpy_Pygen __pyx_mstate_global->__pyx_type_6giacpy_6giacpy_Pygen
#define __pyx_type_6giacpy_6giacpy_GiacSetting __pyx_mstate_global->__pyx_type_6giacpy_6giacpy_GiacSetting
#define __pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__ __pyx_mstate_global->__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__
#endif
#define __pyx_ptype_6giacpy_6giacpy_GiacMethods_base __pyx_mstate_global->__pyx_ptype_6giacpy_6giacpy_GiacMethods_base
#define __pyx_ptype_6giacpy_6giacpy_Pygen __pyx_mstate_global->__pyx_ptype_6giacpy_6giacpy_Pygen
#define __pyx_ptype_6giacpy_6giacpy_GiacSetting __pyx_mstate_global->__pyx_ptype_6giacpy_6giacpy_GiacSetting
#define __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__ __pyx_mstate_global->__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__
#define __pyx_n_s_A __pyx_mstate_global->__pyx_n_s_A
#define __pyx_n_s_ACOSH __pyx_mstate_global->__pyx_n_s_ACOSH
#define __pyx_n_s_ACOT __pyx_mstate_global->__pyx_n_s_ACOT
#define __pyx_n_s_ACSC __pyx_mstate_global->__pyx_n_s_ACSC
#define __pyx_n_s_ASEC __pyx_mstate_global->__pyx_n_s_ASEC
#define __pyx_n_s_ASIN __pyx_mstate_global->__pyx_n_s_ASIN
#define __pyx_n_s_ASINH __pyx_mstate_global->__pyx_n_s_ASINH
#define __pyx_n_s_ATAN __pyx_mstate_global->__pyx_n_s_ATAN
#define __pyx_n_s_ATANH __pyx_mstate_global->__pyx_n_s_ATANH
#define __pyx_n_s_A_2 __pyx_mstate_global->__pyx_n_s_A_2
#define __pyx_n_s_Airy_Ai __pyx_mstate_global->__pyx_n_s_Airy_Ai
#define __pyx_n_s_Airy_Bi __pyx_mstate_global->__pyx_n_s_Airy_Bi
#define __pyx_n_s_Angstrom __pyx_mstate_global->__pyx_n_s_Angstrom
#define __pyx_n_s_Archive __pyx_mstate_global->__pyx_n_s_Archive
#define __pyx_kp_u_Archive_a_Pygen_element_to_a_fi __pyx_mstate_global->__pyx_kp_u_Archive_a_Pygen_element_to_a_fi
#define __pyx_n_s_BesselJ __pyx_mstate_global->__pyx_n_s_BesselJ
#define __pyx_n_s_BesselY __pyx_mstate_global->__pyx_n_s_BesselY
#define __pyx_n_s_Beta __pyx_mstate_global->__pyx_n_s_Beta
#define __pyx_n_s_BlockDiagonal __pyx_mstate_global->__pyx_n_s_BlockDiagonal
#define __pyx_n_s_Bq __pyx_mstate_global->__pyx_n_s_Bq
#define __pyx_n_s_Btu __pyx_mstate_global->__pyx_n_s_Btu
#define __pyx_n_s_COND __pyx_mstate_global->__pyx_n_s_COND
#define __pyx_n_s_COS __pyx_mstate_global->__pyx_n_s_COS
#define __pyx_n_s_COSH __pyx_mstate_global->__pyx_n_s_COSH
#define __pyx_n_s_COT __pyx_mstate_global->__pyx_n_s_COT
#define __pyx_n_s_CSC __pyx_mstate_global->__pyx_n_s_CSC
#define __pyx_n_s_CST __pyx_mstate_global->__pyx_n_s_CST
#define __pyx_n_s_Celsius2Fahrenheit __pyx_mstate_global->__pyx_n_s_Celsius2Fahrenheit
#define __pyx_n_s_Ci __pyx_mstate_global->__pyx_n_s_Ci
#define __pyx_n_s_Ci_2 __pyx_mstate_global->__pyx_n_s_Ci_2
#define __pyx_n_s_Circle __pyx_mstate_global->__pyx_n_s_Circle
#define __pyx_n_s_ClrDraw __pyx_mstate_global->__pyx_n_s_ClrDraw
#define __pyx_n_s_ClrGraph __pyx_mstate_global->__pyx_n_s_ClrGraph
#define __pyx_n_s_ClrIO __pyx_mstate_global->__pyx_n_s_ClrIO
#define __pyx_n_s_Col __pyx_mstate_global->__pyx_n_s_Col
#define __pyx_kp_u_Convert_a_giac_integer_type_Pyg __pyx_mstate_global->__pyx_kp_u_Convert_a_giac_integer_type_Pyg
#define __pyx_kp_u_Convert_a_giac_real_to_a_Python __pyx_mstate_global->__pyx_kp_u_Convert_a_giac_real_to_a_Python
#define __pyx_n_s_CopyVar __pyx_mstate_global->__pyx_n_s_CopyVar
#define __pyx_n_s_CyclePic __pyx_mstate_global->__pyx_n_s_CyclePic
#define __pyx_n_s_DIGITS __pyx_mstate_global->__pyx_n_s_DIGITS
#define __pyx_n_s_DOM_COMPLEX __pyx_mstate_global->__pyx_n_s_DOM_COMPLEX
#define __pyx_n_s_DOM_FLOAT __pyx_mstate_global->__pyx_n_s_DOM_FLOAT
#define __pyx_n_s_DOM_FUNC __pyx_mstate_global->__pyx_n_s_DOM_FUNC
#define __pyx_n_s_DOM_IDENT __pyx_mstate_global->__pyx_n_s_DOM_IDENT
#define __pyx_n_s_DOM_INT __pyx_mstate_global->__pyx_n_s_DOM_INT
#define __pyx_n_s_DOM_LIST __pyx_mstate_global->__pyx_n_s_DOM_LIST
#define __pyx_n_s_DOM_RAT __pyx_mstate_global->__pyx_n_s_DOM_RAT
#define __pyx_n_s_DOM_STRING __pyx_mstate_global->__pyx_n_s_DOM_STRING
#define __pyx_n_s_DOM_SYMBOLIC __pyx_mstate_global->__pyx_n_s_DOM_SYMBOLIC
#define __pyx_n_s_DOM_int __pyx_mstate_global->__pyx_n_s_DOM_int
#define __pyx_n_s_DelFold __pyx_mstate_global->__pyx_n_s_DelFold
#define __pyx_n_s_DelVar __pyx_mstate_global->__pyx_n_s_DelVar
#define __pyx_n_s_Det __pyx_mstate_global->__pyx_n_s_Det
#define __pyx_n_s_Dialog __pyx_mstate_global->__pyx_n_s_Dialog
#define __pyx_n_s_Digits __pyx_mstate_global->__pyx_n_s_Digits
#define __pyx_n_s_Dirac __pyx_mstate_global->__pyx_n_s_Dirac
#define __pyx_n_s_Disp __pyx_mstate_global->__pyx_n_s_Disp
#define __pyx_n_s_DispG __pyx_mstate_global->__pyx_n_s_DispG
#define __pyx_n_s_DispHome __pyx_mstate_global->__pyx_n_s_DispHome
#define __pyx_n_s_DrawFunc __pyx_mstate_global->__pyx_n_s_DrawFunc
#define __pyx_n_s_DrawInv __pyx_mstate_global->__pyx_n_s_DrawInv
#define __pyx_n_s_DrawParm __pyx_mstate_global->__pyx_n_s_DrawParm
#define __pyx_n_s_DrawPol __pyx_mstate_global->__pyx_n_s_DrawPol
#define __pyx_n_s_DrawSlp __pyx_mstate_global->__pyx_n_s_DrawSlp
#define __pyx_n_s_DropDown __pyx_mstate_global->__pyx_n_s_DropDown
#define __pyx_n_s_DrwCtour __pyx_mstate_global->__pyx_n_s_DrwCtour
#define __pyx_n_s_ERROR __pyx_mstate_global->__pyx_n_s_ERROR
#define __pyx_n_s_EXP __pyx_mstate_global->__pyx_n_s_EXP
#define __pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman __pyx_mstate_global->__pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman
#define __pyx_n_s_Ei __pyx_mstate_global->__pyx_n_s_Ei
#define __pyx_n_s_EndDlog __pyx_mstate_global->__pyx_n_s_EndDlog
#define __pyx_kp_s_Error_executing_code_in_Giac_COD __pyx_mstate_global->__pyx_kp_s_Error_executing_code_in_Giac_COD
#define __pyx_n_s_F __pyx_mstate_global->__pyx_n_s_F
#define __pyx_n_s_FALSE __pyx_mstate_global->__pyx_n_s_FALSE
#define __pyx_n_s_F_2 __pyx_mstate_global->__pyx_n_s_F_2
#define __pyx_n_s_F_OK __pyx_mstate_global->__pyx_n_s_F_OK
#define __pyx_n_s_Factor __pyx_mstate_global->__pyx_n_s_Factor
#define __pyx_n_s_Fahrenheit2Celsius __pyx_mstate_global->__pyx_n_s_Fahrenheit2Celsius
#define __pyx_kp_s_Failed_to_start_a_thread __pyx_mstate_global->__pyx_kp_s_Failed_to_start_a_thread
#define __pyx_n_s_False __pyx_mstate_global->__pyx_n_s_False
#define __pyx_n_s_Fdy __pyx_mstate_global->__pyx_n_s_Fdy
#define __pyx_n_s_Fill __pyx_mstate_global->__pyx_n_s_Fill
#define __pyx_n_s_Fourier __pyx_mstate_global->__pyx_n_s_Fourier
#define __pyx_n_s_G __pyx_mstate_global->__pyx_n_s_G
#define __pyx_n_s_GF __pyx_mstate_global->__pyx_n_s_GF
#define __pyx_n_s_GIACNULL __pyx_mstate_global->__pyx_n_s_GIACNULL
#define __pyx_n_s_GIACPY_TMP_NAME05026807096929010 __pyx_mstate_global->__pyx_n_s_GIACPY_TMP_NAME05026807096929010
#define __pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2 __pyx_mstate_global->__pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2
#define __pyx_n_s_Gal __pyx_mstate_global->__pyx_n_s_Gal
#define __pyx_n_s_Gamma __pyx_mstate_global->__pyx_n_s_Gamma
#define __pyx_n_s_Gcd __pyx_mstate_global->__pyx_n_s_Gcd
#define __pyx_n_s_GetFold __pyx_mstate_global->__pyx_n_s_GetFold
#define __pyx_n_s_GiacFunction __pyx_mstate_global->__pyx_n_s_GiacFunction
#define __pyx_n_s_GiacFunction___add __pyx_mstate_global->__pyx_n_s_GiacFunction___add
#define __pyx_n_s_GiacFunction___call __pyx_mstate_global->__pyx_n_s_GiacFunction___call
#define __pyx_n_s_GiacFunction___div __pyx_mstate_global->__pyx_n_s_GiacFunction___div
#define __pyx_n_s_GiacFunction___init __pyx_mstate_global->__pyx_n_s_GiacFunction___init
#define __pyx_n_s_GiacFunction___mul __pyx_mstate_global->__pyx_n_s_GiacFunction___mul
#define __pyx_n_s_GiacFunction___neg __pyx_mstate_global->__pyx_n_s_GiacFunction___neg
#define __pyx_n_s_GiacFunction___pow __pyx_mstate_global->__pyx_n_s_GiacFunction___pow
#define __pyx_n_s_GiacFunction___repr __pyx_mstate_global->__pyx_n_s_GiacFunction___repr
#define __pyx_n_s_GiacFunction___str __pyx_mstate_global->__pyx_n_s_GiacFunction___str
#define __pyx_n_s_GiacFunction___sub __pyx_mstate_global->__pyx_n_s_GiacFunction___sub
#define __pyx_n_s_GiacFunction___truediv __pyx_mstate_global->__pyx_n_s_GiacFunction___truediv
#define __pyx_n_s_GiacFunction_diff __pyx_mstate_global->__pyx_n_s_GiacFunction_diff
#define __pyx_n_s_GiacFunction_htmlhelp __pyx_mstate_global->__pyx_n_s_GiacFunction_htmlhelp
#define __pyx_n_s_GiacFunction_int __pyx_mstate_global->__pyx_n_s_GiacFunction_int
#define __pyx_n_s_GiacFunction_plot __pyx_mstate_global->__pyx_n_s_GiacFunction_plot
#define __pyx_n_s_GiacMethods __pyx_mstate_global->__pyx_n_s_GiacMethods
#define __pyx_n_s_GiacMethods_base __pyx_mstate_global->__pyx_n_s_GiacMethods_base
#define __pyx_n_s_GiacMethods_base_Airy_Ai __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Airy_Ai
#define __pyx_n_s_GiacMethods_base_Airy_Bi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Airy_Bi
#define __pyx_n_s_GiacMethods_base_Archive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Archive
#define __pyx_n_s_GiacMethods_base_BesselJ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_BesselJ
#define __pyx_n_s_GiacMethods_base_BesselY __pyx_mstate_global->__pyx_n_s_GiacMethods_base_BesselY
#define __pyx_n_s_GiacMethods_base_Beta __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Beta
#define __pyx_n_s_GiacMethods_base_BlockDiagonal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_BlockDiagonal
#define __pyx_n_s_GiacMethods_base_Ci __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Ci
#define __pyx_n_s_GiacMethods_base_Circle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Circle
#define __pyx_n_s_GiacMethods_base_Col __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Col
#define __pyx_n_s_GiacMethods_base_CopyVar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_CopyVar
#define __pyx_n_s_GiacMethods_base_Dirac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Dirac
#define __pyx_n_s_GiacMethods_base_Ei __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Ei
#define __pyx_n_s_GiacMethods_base_Factor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Factor
#define __pyx_n_s_GiacMethods_base_Fourier __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Fourier
#define __pyx_n_s_GiacMethods_base_GF __pyx_mstate_global->__pyx_n_s_GiacMethods_base_GF
#define __pyx_n_s_GiacMethods_base_Gamma __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Gamma
#define __pyx_n_s_GiacMethods_base_Heaviside __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Heaviside
#define __pyx_n_s_GiacMethods_base_Heaviside2sign __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Heaviside2sign
#define __pyx_n_s_GiacMethods_base_Hilbert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Hilbert
#define __pyx_n_s_GiacMethods_base_JordanBlock __pyx_mstate_global->__pyx_n_s_GiacMethods_base_JordanBlock
#define __pyx_n_s_GiacMethods_base_LU __pyx_mstate_global->__pyx_n_s_GiacMethods_base_LU
#define __pyx_n_s_GiacMethods_base_LambertW __pyx_mstate_global->__pyx_n_s_GiacMethods_base_LambertW
#define __pyx_n_s_GiacMethods_base_Li __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Li
#define __pyx_n_s_GiacMethods_base_Line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Line
#define __pyx_n_s_GiacMethods_base_LineHorz __pyx_mstate_global->__pyx_n_s_GiacMethods_base_LineHorz
#define __pyx_n_s_GiacMethods_base_LineTan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_LineTan
#define __pyx_n_s_GiacMethods_base_LineVert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_LineVert
#define __pyx_n_s_GiacMethods_base_MSE __pyx_mstate_global->__pyx_n_s_GiacMethods_base_MSE
#define __pyx_n_s_GiacMethods_base_Phi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Phi
#define __pyx_n_s_GiacMethods_base_Pi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Pi
#define __pyx_n_s_GiacMethods_base_Psi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Psi
#define __pyx_n_s_GiacMethods_base_QR __pyx_mstate_global->__pyx_n_s_GiacMethods_base_QR
#define __pyx_n_s_GiacMethods_base_RandSeed __pyx_mstate_global->__pyx_n_s_GiacMethods_base_RandSeed
#define __pyx_n_s_GiacMethods_base_ReLU __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ReLU
#define __pyx_n_s_GiacMethods_base_Row __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Row
#define __pyx_n_s_GiacMethods_base_SortA __pyx_mstate_global->__pyx_n_s_GiacMethods_base_SortA
#define __pyx_n_s_GiacMethods_base_SortD __pyx_mstate_global->__pyx_n_s_GiacMethods_base_SortD
#define __pyx_n_s_GiacMethods_base_UTPC __pyx_mstate_global->__pyx_n_s_GiacMethods_base_UTPC
#define __pyx_n_s_GiacMethods_base_UTPF __pyx_mstate_global->__pyx_n_s_GiacMethods_base_UTPF
#define __pyx_n_s_GiacMethods_base_UTPN __pyx_mstate_global->__pyx_n_s_GiacMethods_base_UTPN
#define __pyx_n_s_GiacMethods_base_UTPT __pyx_mstate_global->__pyx_n_s_GiacMethods_base_UTPT
#define __pyx_n_s_GiacMethods_base_VARS __pyx_mstate_global->__pyx_n_s_GiacMethods_base_VARS
#define __pyx_n_s_GiacMethods_base_VAS __pyx_mstate_global->__pyx_n_s_GiacMethods_base_VAS
#define __pyx_n_s_GiacMethods_base_VAS_positive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_VAS_positive
#define __pyx_n_s_GiacMethods_base_Zeta __pyx_mstate_global->__pyx_n_s_GiacMethods_base_Zeta
#define __pyx_n_s_GiacMethods_base___reduce_cython __pyx_mstate_global->__pyx_n_s_GiacMethods_base___reduce_cython
#define __pyx_n_s_GiacMethods_base___setstate_cyth __pyx_mstate_global->__pyx_n_s_GiacMethods_base___setstate_cyth
#define __pyx_n_s_GiacMethods_base_a2q __pyx_mstate_global->__pyx_n_s_GiacMethods_base_a2q
#define __pyx_n_s_GiacMethods_base_abcuv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_abcuv
#define __pyx_n_s_GiacMethods_base_about __pyx_mstate_global->__pyx_n_s_GiacMethods_base_about
#define __pyx_n_s_GiacMethods_base_abs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_abs
#define __pyx_n_s_GiacMethods_base_abscissa __pyx_mstate_global->__pyx_n_s_GiacMethods_base_abscissa
#define __pyx_n_s_GiacMethods_base_accumulate_head __pyx_mstate_global->__pyx_n_s_GiacMethods_base_accumulate_head
#define __pyx_n_s_GiacMethods_base_acos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acos
#define __pyx_n_s_GiacMethods_base_acos2asin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acos2asin
#define __pyx_n_s_GiacMethods_base_acos2atan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acos2atan
#define __pyx_n_s_GiacMethods_base_acosh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acosh
#define __pyx_n_s_GiacMethods_base_acot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acot
#define __pyx_n_s_GiacMethods_base_acsc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acsc
#define __pyx_n_s_GiacMethods_base_acyclic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_acyclic
#define __pyx_n_s_GiacMethods_base_adaptive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_adaptive
#define __pyx_n_s_GiacMethods_base_add __pyx_mstate_global->__pyx_n_s_GiacMethods_base_add
#define __pyx_n_s_GiacMethods_base_add_arc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_add_arc
#define __pyx_n_s_GiacMethods_base_add_edge __pyx_mstate_global->__pyx_n_s_GiacMethods_base_add_edge
#define __pyx_n_s_GiacMethods_base_add_vertex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_add_vertex
#define __pyx_n_s_GiacMethods_base_additionally __pyx_mstate_global->__pyx_n_s_GiacMethods_base_additionally
#define __pyx_n_s_GiacMethods_base_addtable __pyx_mstate_global->__pyx_n_s_GiacMethods_base_addtable
#define __pyx_n_s_GiacMethods_base_adjacency_matri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_adjacency_matri
#define __pyx_n_s_GiacMethods_base_adjoint_matrix __pyx_mstate_global->__pyx_n_s_GiacMethods_base_adjoint_matrix
#define __pyx_n_s_GiacMethods_base_affix __pyx_mstate_global->__pyx_n_s_GiacMethods_base_affix
#define __pyx_n_s_GiacMethods_base_algsubs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_algsubs
#define __pyx_n_s_GiacMethods_base_algvar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_algvar
#define __pyx_n_s_GiacMethods_base_all_trig_soluti __pyx_mstate_global->__pyx_n_s_GiacMethods_base_all_trig_soluti
#define __pyx_n_s_GiacMethods_base_allpairs_distan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_allpairs_distan
#define __pyx_n_s_GiacMethods_base_alog10 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_alog10
#define __pyx_n_s_GiacMethods_base_altitude __pyx_mstate_global->__pyx_n_s_GiacMethods_base_altitude
#define __pyx_n_s_GiacMethods_base_angle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_angle
#define __pyx_n_s_GiacMethods_base_angle_radian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_angle_radian
#define __pyx_n_s_GiacMethods_base_angleat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_angleat
#define __pyx_n_s_GiacMethods_base_angleatraw __pyx_mstate_global->__pyx_n_s_GiacMethods_base_angleatraw
#define __pyx_n_s_GiacMethods_base_ans __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ans
#define __pyx_n_s_GiacMethods_base_antiprism_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_antiprism_graph
#define __pyx_n_s_GiacMethods_base_append __pyx_mstate_global->__pyx_n_s_GiacMethods_base_append
#define __pyx_n_s_GiacMethods_base_apply __pyx_mstate_global->__pyx_n_s_GiacMethods_base_apply
#define __pyx_n_s_GiacMethods_base_approx __pyx_mstate_global->__pyx_n_s_GiacMethods_base_approx
#define __pyx_n_s_GiacMethods_base_arc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arc
#define __pyx_n_s_GiacMethods_base_arcLen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arcLen
#define __pyx_n_s_GiacMethods_base_arccos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arccos
#define __pyx_n_s_GiacMethods_base_arccosh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arccosh
#define __pyx_n_s_GiacMethods_base_arclen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arclen
#define __pyx_n_s_GiacMethods_base_arcsin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arcsin
#define __pyx_n_s_GiacMethods_base_arcsinh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arcsinh
#define __pyx_n_s_GiacMethods_base_arctan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arctan
#define __pyx_n_s_GiacMethods_base_arctanh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arctanh
#define __pyx_n_s_GiacMethods_base_area __pyx_mstate_global->__pyx_n_s_GiacMethods_base_area
#define __pyx_n_s_GiacMethods_base_areaat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_areaat
#define __pyx_n_s_GiacMethods_base_areaatraw __pyx_mstate_global->__pyx_n_s_GiacMethods_base_areaatraw
#define __pyx_n_s_GiacMethods_base_areaplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_areaplot
#define __pyx_n_s_GiacMethods_base_arg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arg
#define __pyx_n_s_GiacMethods_base_array __pyx_mstate_global->__pyx_n_s_GiacMethods_base_array
#define __pyx_n_s_GiacMethods_base_arrivals __pyx_mstate_global->__pyx_n_s_GiacMethods_base_arrivals
#define __pyx_n_s_GiacMethods_base_articulation_po __pyx_mstate_global->__pyx_n_s_GiacMethods_base_articulation_po
#define __pyx_n_s_GiacMethods_base_asin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_asin
#define __pyx_n_s_GiacMethods_base_asin2acos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_asin2acos
#define __pyx_n_s_GiacMethods_base_asin2atan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_asin2atan
#define __pyx_n_s_GiacMethods_base_asinh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_asinh
#define __pyx_n_s_GiacMethods_base_assign_edge_wei __pyx_mstate_global->__pyx_n_s_GiacMethods_base_assign_edge_wei
#define __pyx_n_s_GiacMethods_base_assume __pyx_mstate_global->__pyx_n_s_GiacMethods_base_assume
#define __pyx_n_s_GiacMethods_base_at __pyx_mstate_global->__pyx_n_s_GiacMethods_base_at
#define __pyx_n_s_GiacMethods_base_atan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_atan
#define __pyx_n_s_GiacMethods_base_atan2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_atan2
#define __pyx_n_s_GiacMethods_base_atan2acos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_atan2acos
#define __pyx_n_s_GiacMethods_base_atan2asin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_atan2asin
#define __pyx_n_s_GiacMethods_base_atanh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_atanh
#define __pyx_n_s_GiacMethods_base_atrig2ln __pyx_mstate_global->__pyx_n_s_GiacMethods_base_atrig2ln
#define __pyx_n_s_GiacMethods_base_augment __pyx_mstate_global->__pyx_n_s_GiacMethods_base_augment
#define __pyx_n_s_GiacMethods_base_auto_correlatio __pyx_mstate_global->__pyx_n_s_GiacMethods_base_auto_correlatio
#define __pyx_n_s_GiacMethods_base_autosimplify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_autosimplify
#define __pyx_n_s_GiacMethods_base_avance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_avance
#define __pyx_n_s_GiacMethods_base_avgRC __pyx_mstate_global->__pyx_n_s_GiacMethods_base_avgRC
#define __pyx_n_s_GiacMethods_base_axes __pyx_mstate_global->__pyx_n_s_GiacMethods_base_axes
#define __pyx_n_s_GiacMethods_base_axis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_axis
#define __pyx_n_s_GiacMethods_base_back __pyx_mstate_global->__pyx_n_s_GiacMethods_base_back
#define __pyx_n_s_GiacMethods_base_backward __pyx_mstate_global->__pyx_n_s_GiacMethods_base_backward
#define __pyx_n_s_GiacMethods_base_baisse_crayon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_baisse_crayon
#define __pyx_n_s_GiacMethods_base_bandwidth __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bandwidth
#define __pyx_n_s_GiacMethods_base_bar_plot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bar_plot
#define __pyx_n_s_GiacMethods_base_barplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_barplot
#define __pyx_n_s_GiacMethods_base_bartlett_hann_w __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bartlett_hann_w
#define __pyx_n_s_GiacMethods_base_barycenter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_barycenter
#define __pyx_n_s_GiacMethods_base_base __pyx_mstate_global->__pyx_n_s_GiacMethods_base_base
#define __pyx_n_s_GiacMethods_base_basis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_basis
#define __pyx_n_s_GiacMethods_base_batons __pyx_mstate_global->__pyx_n_s_GiacMethods_base_batons
#define __pyx_n_s_GiacMethods_base_bellman_ford __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bellman_ford
#define __pyx_n_s_GiacMethods_base_berlekamp_masse __pyx_mstate_global->__pyx_n_s_GiacMethods_base_berlekamp_masse
#define __pyx_n_s_GiacMethods_base_bernoulli __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bernoulli
#define __pyx_n_s_GiacMethods_base_bernoulli_mod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bernoulli_mod
#define __pyx_n_s_GiacMethods_base_besselJ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_besselJ
#define __pyx_n_s_GiacMethods_base_besselY __pyx_mstate_global->__pyx_n_s_GiacMethods_base_besselY
#define __pyx_n_s_GiacMethods_base_betad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_betad
#define __pyx_n_s_GiacMethods_base_betad_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_betad_cdf
#define __pyx_n_s_GiacMethods_base_betad_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_betad_icdf
#define __pyx_n_s_GiacMethods_base_betavariate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_betavariate
#define __pyx_n_s_GiacMethods_base_betweenness_cen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_betweenness_cen
#define __pyx_n_s_GiacMethods_base_bezier __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bezier
#define __pyx_n_s_GiacMethods_base_bezout_entiers __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bezout_entiers
#define __pyx_n_s_GiacMethods_base_bezoutian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bezoutian
#define __pyx_n_s_GiacMethods_base_biconnected_com __pyx_mstate_global->__pyx_n_s_GiacMethods_base_biconnected_com
#define __pyx_n_s_GiacMethods_base_binomial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_binomial
#define __pyx_n_s_GiacMethods_base_binomial_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_binomial_cdf
#define __pyx_n_s_GiacMethods_base_binomial_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_binomial_icdf
#define __pyx_n_s_GiacMethods_base_bins __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bins
#define __pyx_n_s_GiacMethods_base_bipartite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bipartite
#define __pyx_n_s_GiacMethods_base_bipartite_match __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bipartite_match
#define __pyx_n_s_GiacMethods_base_bisection_solve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bisection_solve
#define __pyx_n_s_GiacMethods_base_bisector __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bisector
#define __pyx_n_s_GiacMethods_base_bit_depth __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bit_depth
#define __pyx_n_s_GiacMethods_base_bitand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bitand
#define __pyx_n_s_GiacMethods_base_bitor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bitor
#define __pyx_n_s_GiacMethods_base_bitxor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bitxor
#define __pyx_n_s_GiacMethods_base_blackman_harris __pyx_mstate_global->__pyx_n_s_GiacMethods_base_blackman_harris
#define __pyx_n_s_GiacMethods_base_blackman_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_blackman_window
#define __pyx_n_s_GiacMethods_base_block_size __pyx_mstate_global->__pyx_n_s_GiacMethods_base_block_size
#define __pyx_n_s_GiacMethods_base_blockmatrix __pyx_mstate_global->__pyx_n_s_GiacMethods_base_blockmatrix
#define __pyx_n_s_GiacMethods_base_bohman_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bohman_window
#define __pyx_n_s_GiacMethods_base_border __pyx_mstate_global->__pyx_n_s_GiacMethods_base_border
#define __pyx_n_s_GiacMethods_base_box_constraints __pyx_mstate_global->__pyx_n_s_GiacMethods_base_box_constraints
#define __pyx_n_s_GiacMethods_base_boxcar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_boxcar
#define __pyx_n_s_GiacMethods_base_boxwhisker __pyx_mstate_global->__pyx_n_s_GiacMethods_base_boxwhisker
#define __pyx_n_s_GiacMethods_base_brent_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_brent_solver
#define __pyx_n_s_GiacMethods_base_brown __pyx_mstate_global->__pyx_n_s_GiacMethods_base_brown
#define __pyx_n_s_GiacMethods_base_bspline __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bspline
#define __pyx_n_s_GiacMethods_base_bvpsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_bvpsolve
#define __pyx_n_s_GiacMethods_base_cFactor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cFactor
#define __pyx_n_s_GiacMethods_base_cSolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cSolve
#define __pyx_n_s_GiacMethods_base_cZeros __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cZeros
#define __pyx_n_s_GiacMethods_base_camembert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_camembert
#define __pyx_n_s_GiacMethods_base_canonical_form __pyx_mstate_global->__pyx_n_s_GiacMethods_base_canonical_form
#define __pyx_n_s_GiacMethods_base_canonical_label __pyx_mstate_global->__pyx_n_s_GiacMethods_base_canonical_label
#define __pyx_n_s_GiacMethods_base_cartesian_produ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cartesian_produ
#define __pyx_n_s_GiacMethods_base_cauchy __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cauchy
#define __pyx_n_s_GiacMethods_base_cauchy_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cauchy_cdf
#define __pyx_n_s_GiacMethods_base_cauchy_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cauchy_icdf
#define __pyx_n_s_GiacMethods_base_cauchyd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cauchyd
#define __pyx_n_s_GiacMethods_base_cauchyd_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cauchyd_cdf
#define __pyx_n_s_GiacMethods_base_cauchyd_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cauchyd_icdf
#define __pyx_n_s_GiacMethods_base_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cdf
#define __pyx_n_s_GiacMethods_base_ceil __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ceil
#define __pyx_n_s_GiacMethods_base_ceiling __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ceiling
#define __pyx_n_s_GiacMethods_base_center __pyx_mstate_global->__pyx_n_s_GiacMethods_base_center
#define __pyx_n_s_GiacMethods_base_center2interval __pyx_mstate_global->__pyx_n_s_GiacMethods_base_center2interval
#define __pyx_n_s_GiacMethods_base_centered_cube __pyx_mstate_global->__pyx_n_s_GiacMethods_base_centered_cube
#define __pyx_n_s_GiacMethods_base_centered_tetrah __pyx_mstate_global->__pyx_n_s_GiacMethods_base_centered_tetrah
#define __pyx_n_s_GiacMethods_base_cfactor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cfactor
#define __pyx_n_s_GiacMethods_base_cfsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cfsolve
#define __pyx_n_s_GiacMethods_base_changebase __pyx_mstate_global->__pyx_n_s_GiacMethods_base_changebase
#define __pyx_n_s_GiacMethods_base_channel_data __pyx_mstate_global->__pyx_n_s_GiacMethods_base_channel_data
#define __pyx_n_s_GiacMethods_base_channels __pyx_mstate_global->__pyx_n_s_GiacMethods_base_channels
#define __pyx_n_s_GiacMethods_base_char __pyx_mstate_global->__pyx_n_s_GiacMethods_base_char
#define __pyx_n_s_GiacMethods_base_charpoly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_charpoly
#define __pyx_n_s_GiacMethods_base_chinrem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chinrem
#define __pyx_n_s_GiacMethods_base_chisquare __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquare
#define __pyx_n_s_GiacMethods_base_chisquare_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquare_cdf
#define __pyx_n_s_GiacMethods_base_chisquare_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquare_icdf
#define __pyx_n_s_GiacMethods_base_chisquared __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquared
#define __pyx_n_s_GiacMethods_base_chisquared_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquared_cdf
#define __pyx_n_s_GiacMethods_base_chisquared_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquared_icdf
#define __pyx_n_s_GiacMethods_base_chisquaret __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chisquaret
#define __pyx_n_s_GiacMethods_base_choice __pyx_mstate_global->__pyx_n_s_GiacMethods_base_choice
#define __pyx_n_s_GiacMethods_base_cholesky __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cholesky
#define __pyx_n_s_GiacMethods_base_chr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chr
#define __pyx_n_s_GiacMethods_base_chrem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chrem
#define __pyx_n_s_GiacMethods_base_chromatic_index __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chromatic_index
#define __pyx_n_s_GiacMethods_base_chromatic_numbe __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chromatic_numbe
#define __pyx_n_s_GiacMethods_base_chromatic_polyn __pyx_mstate_global->__pyx_n_s_GiacMethods_base_chromatic_polyn
#define __pyx_n_s_GiacMethods_base_circle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_circle
#define __pyx_n_s_GiacMethods_base_circumcircle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_circumcircle
#define __pyx_n_s_GiacMethods_base_classes __pyx_mstate_global->__pyx_n_s_GiacMethods_base_classes
#define __pyx_n_s_GiacMethods_base_clear __pyx_mstate_global->__pyx_n_s_GiacMethods_base_clear
#define __pyx_n_s_GiacMethods_base_clique_cover __pyx_mstate_global->__pyx_n_s_GiacMethods_base_clique_cover
#define __pyx_n_s_GiacMethods_base_clique_cover_nu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_clique_cover_nu
#define __pyx_n_s_GiacMethods_base_clique_number __pyx_mstate_global->__pyx_n_s_GiacMethods_base_clique_number
#define __pyx_n_s_GiacMethods_base_closeness_centr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_closeness_centr
#define __pyx_n_s_GiacMethods_base_cluster __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cluster
#define __pyx_n_s_GiacMethods_base_clustering_coef __pyx_mstate_global->__pyx_n_s_GiacMethods_base_clustering_coef
#define __pyx_n_s_GiacMethods_base_coeff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_coeff
#define __pyx_n_s_GiacMethods_base_coeffs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_coeffs
#define __pyx_n_s_GiacMethods_base_col __pyx_mstate_global->__pyx_n_s_GiacMethods_base_col
#define __pyx_n_s_GiacMethods_base_colDim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colDim
#define __pyx_n_s_GiacMethods_base_colNorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colNorm
#define __pyx_n_s_GiacMethods_base_colSwap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colSwap
#define __pyx_n_s_GiacMethods_base_coldim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_coldim
#define __pyx_n_s_GiacMethods_base_collect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_collect
#define __pyx_n_s_GiacMethods_base_colnorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colnorm
#define __pyx_n_s_GiacMethods_base_color __pyx_mstate_global->__pyx_n_s_GiacMethods_base_color
#define __pyx_n_s_GiacMethods_base_colormap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colormap
#define __pyx_n_s_GiacMethods_base_colspace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colspace
#define __pyx_n_s_GiacMethods_base_colswap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_colswap
#define __pyx_n_s_GiacMethods_base_comDenom __pyx_mstate_global->__pyx_n_s_GiacMethods_base_comDenom
#define __pyx_n_s_GiacMethods_base_comb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_comb
#define __pyx_n_s_GiacMethods_base_combine __pyx_mstate_global->__pyx_n_s_GiacMethods_base_combine
#define __pyx_n_s_GiacMethods_base_comment __pyx_mstate_global->__pyx_n_s_GiacMethods_base_comment
#define __pyx_n_s_GiacMethods_base_common_perpendi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_common_perpendi
#define __pyx_n_s_GiacMethods_base_companion __pyx_mstate_global->__pyx_n_s_GiacMethods_base_companion
#define __pyx_n_s_GiacMethods_base_compare __pyx_mstate_global->__pyx_n_s_GiacMethods_base_compare
#define __pyx_n_s_GiacMethods_base_complete_binary __pyx_mstate_global->__pyx_n_s_GiacMethods_base_complete_binary
#define __pyx_n_s_GiacMethods_base_complete_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_complete_graph
#define __pyx_n_s_GiacMethods_base_complete_kary_t __pyx_mstate_global->__pyx_n_s_GiacMethods_base_complete_kary_t
#define __pyx_n_s_GiacMethods_base_complex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_complex
#define __pyx_n_s_GiacMethods_base_complex_variabl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_complex_variabl
#define __pyx_n_s_GiacMethods_base_complexroot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_complexroot
#define __pyx_n_s_GiacMethods_base_concat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_concat
#define __pyx_n_s_GiacMethods_base_cond __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cond
#define __pyx_n_s_GiacMethods_base_condensation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_condensation
#define __pyx_n_s_GiacMethods_base_cone __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cone
#define __pyx_n_s_GiacMethods_base_confrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_confrac
#define __pyx_n_s_GiacMethods_base_conic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_conic
#define __pyx_n_s_GiacMethods_base_conj __pyx_mstate_global->__pyx_n_s_GiacMethods_base_conj
#define __pyx_n_s_GiacMethods_base_conjugate_equat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_conjugate_equat
#define __pyx_n_s_GiacMethods_base_conjugate_gradi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_conjugate_gradi
#define __pyx_n_s_GiacMethods_base_connected __pyx_mstate_global->__pyx_n_s_GiacMethods_base_connected
#define __pyx_n_s_GiacMethods_base_connected_compo __pyx_mstate_global->__pyx_n_s_GiacMethods_base_connected_compo
#define __pyx_n_s_GiacMethods_base_cont __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cont
#define __pyx_n_s_GiacMethods_base_contains __pyx_mstate_global->__pyx_n_s_GiacMethods_base_contains
#define __pyx_n_s_GiacMethods_base_content __pyx_mstate_global->__pyx_n_s_GiacMethods_base_content
#define __pyx_n_s_GiacMethods_base_contourplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_contourplot
#define __pyx_n_s_GiacMethods_base_contract_edge __pyx_mstate_global->__pyx_n_s_GiacMethods_base_contract_edge
#define __pyx_n_s_GiacMethods_base_contract_subgra __pyx_mstate_global->__pyx_n_s_GiacMethods_base_contract_subgra
#define __pyx_n_s_GiacMethods_base_convert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_convert
#define __pyx_n_s_GiacMethods_base_convertir __pyx_mstate_global->__pyx_n_s_GiacMethods_base_convertir
#define __pyx_n_s_GiacMethods_base_convex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_convex
#define __pyx_n_s_GiacMethods_base_convexhull __pyx_mstate_global->__pyx_n_s_GiacMethods_base_convexhull
#define __pyx_n_s_GiacMethods_base_convolution __pyx_mstate_global->__pyx_n_s_GiacMethods_base_convolution
#define __pyx_n_s_GiacMethods_base_coordinates __pyx_mstate_global->__pyx_n_s_GiacMethods_base_coordinates
#define __pyx_n_s_GiacMethods_base_copy __pyx_mstate_global->__pyx_n_s_GiacMethods_base_copy
#define __pyx_n_s_GiacMethods_base_correlation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_correlation
#define __pyx_n_s_GiacMethods_base_cos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cos
#define __pyx_n_s_GiacMethods_base_cos2sintan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cos2sintan
#define __pyx_n_s_GiacMethods_base_cosh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cosh
#define __pyx_n_s_GiacMethods_base_cosine_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cosine_window
#define __pyx_n_s_GiacMethods_base_cot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cot
#define __pyx_n_s_GiacMethods_base_cote __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cote
#define __pyx_n_s_GiacMethods_base_count __pyx_mstate_global->__pyx_n_s_GiacMethods_base_count
#define __pyx_n_s_GiacMethods_base_count_eq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_count_eq
#define __pyx_n_s_GiacMethods_base_count_inf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_count_inf
#define __pyx_n_s_GiacMethods_base_count_sup __pyx_mstate_global->__pyx_n_s_GiacMethods_base_count_sup
#define __pyx_n_s_GiacMethods_base_courbe_parametr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_courbe_parametr
#define __pyx_n_s_GiacMethods_base_courbe_polaire __pyx_mstate_global->__pyx_n_s_GiacMethods_base_courbe_polaire
#define __pyx_n_s_GiacMethods_base_covariance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_covariance
#define __pyx_n_s_GiacMethods_base_covariance_corr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_covariance_corr
#define __pyx_n_s_GiacMethods_base_cpartfrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cpartfrac
#define __pyx_n_s_GiacMethods_base_crationalroot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_crationalroot
#define __pyx_n_s_GiacMethods_base_crayon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_crayon
#define __pyx_n_s_GiacMethods_base_createwav __pyx_mstate_global->__pyx_n_s_GiacMethods_base_createwav
#define __pyx_n_s_GiacMethods_base_cross __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cross
#define __pyx_n_s_GiacMethods_base_crossP __pyx_mstate_global->__pyx_n_s_GiacMethods_base_crossP
#define __pyx_n_s_GiacMethods_base_cross_correlati __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cross_correlati
#define __pyx_n_s_GiacMethods_base_cross_entropy __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cross_entropy
#define __pyx_n_s_GiacMethods_base_cross_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cross_point
#define __pyx_n_s_GiacMethods_base_cross_ratio __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cross_ratio
#define __pyx_n_s_GiacMethods_base_crossproduct __pyx_mstate_global->__pyx_n_s_GiacMethods_base_crossproduct
#define __pyx_n_s_GiacMethods_base_csc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_csc
#define __pyx_n_s_GiacMethods_base_csolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_csolve
#define __pyx_n_s_GiacMethods_base_csv2gen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_csv2gen
#define __pyx_n_s_GiacMethods_base_cube __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cube
#define __pyx_n_s_GiacMethods_base_cumSum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cumSum
#define __pyx_n_s_GiacMethods_base_cumsum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cumsum
#define __pyx_n_s_GiacMethods_base_cumulated_frequ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cumulated_frequ
#define __pyx_n_s_GiacMethods_base_curl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_curl
#define __pyx_n_s_GiacMethods_base_current_sheet __pyx_mstate_global->__pyx_n_s_GiacMethods_base_current_sheet
#define __pyx_n_s_GiacMethods_base_curvature __pyx_mstate_global->__pyx_n_s_GiacMethods_base_curvature
#define __pyx_n_s_GiacMethods_base_curve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_curve
#define __pyx_n_s_GiacMethods_base_cyan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cyan
#define __pyx_n_s_GiacMethods_base_cycle2perm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cycle2perm
#define __pyx_n_s_GiacMethods_base_cycle_basis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cycle_basis
#define __pyx_n_s_GiacMethods_base_cycle_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cycle_graph
#define __pyx_n_s_GiacMethods_base_cycleinv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cycleinv
#define __pyx_n_s_GiacMethods_base_cycles2permu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cycles2permu
#define __pyx_n_s_GiacMethods_base_cyclotomic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cyclotomic
#define __pyx_n_s_GiacMethods_base_cylinder __pyx_mstate_global->__pyx_n_s_GiacMethods_base_cylinder
#define __pyx_n_s_GiacMethods_base_dash_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dash_line
#define __pyx_n_s_GiacMethods_base_dashdot_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dashdot_line
#define __pyx_n_s_GiacMethods_base_dashdotdot_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dashdotdot_line
#define __pyx_n_s_GiacMethods_base_dayofweek __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dayofweek
#define __pyx_n_s_GiacMethods_base_deSolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_deSolve
#define __pyx_n_s_GiacMethods_base_debut_enregistr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_debut_enregistr
#define __pyx_n_s_GiacMethods_base_degree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_degree
#define __pyx_n_s_GiacMethods_base_degree_centrali __pyx_mstate_global->__pyx_n_s_GiacMethods_base_degree_centrali
#define __pyx_n_s_GiacMethods_base_degree_sequence __pyx_mstate_global->__pyx_n_s_GiacMethods_base_degree_sequence
#define __pyx_n_s_GiacMethods_base_degrees __pyx_mstate_global->__pyx_n_s_GiacMethods_base_degrees
#define __pyx_n_s_GiacMethods_base_delcols __pyx_mstate_global->__pyx_n_s_GiacMethods_base_delcols
#define __pyx_n_s_GiacMethods_base_delete_arc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_delete_arc
#define __pyx_n_s_GiacMethods_base_delete_edge __pyx_mstate_global->__pyx_n_s_GiacMethods_base_delete_edge
#define __pyx_n_s_GiacMethods_base_delete_vertex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_delete_vertex
#define __pyx_n_s_GiacMethods_base_delrows __pyx_mstate_global->__pyx_n_s_GiacMethods_base_delrows
#define __pyx_n_s_GiacMethods_base_deltalist __pyx_mstate_global->__pyx_n_s_GiacMethods_base_deltalist
#define __pyx_n_s_GiacMethods_base_denom __pyx_mstate_global->__pyx_n_s_GiacMethods_base_denom
#define __pyx_n_s_GiacMethods_base_densityplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_densityplot
#define __pyx_n_s_GiacMethods_base_departures __pyx_mstate_global->__pyx_n_s_GiacMethods_base_departures
#define __pyx_n_s_GiacMethods_base_derive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_derive
#define __pyx_n_s_GiacMethods_base_deriver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_deriver
#define __pyx_n_s_GiacMethods_base_desolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_desolve
#define __pyx_n_s_GiacMethods_base_dessine_tortue __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dessine_tortue
#define __pyx_n_s_GiacMethods_base_det __pyx_mstate_global->__pyx_n_s_GiacMethods_base_det
#define __pyx_n_s_GiacMethods_base_det_minor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_det_minor
#define __pyx_n_s_GiacMethods_base_developper __pyx_mstate_global->__pyx_n_s_GiacMethods_base_developper
#define __pyx_n_s_GiacMethods_base_developper_tran __pyx_mstate_global->__pyx_n_s_GiacMethods_base_developper_tran
#define __pyx_n_s_GiacMethods_base_dfc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dfc
#define __pyx_n_s_GiacMethods_base_dfc2f __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dfc2f
#define __pyx_n_s_GiacMethods_base_diag __pyx_mstate_global->__pyx_n_s_GiacMethods_base_diag
#define __pyx_n_s_GiacMethods_base_diff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_diff
#define __pyx_n_s_GiacMethods_base_digraph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_digraph
#define __pyx_n_s_GiacMethods_base_dijkstra __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dijkstra
#define __pyx_n_s_GiacMethods_base_dim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dim
#define __pyx_n_s_GiacMethods_base_directed __pyx_mstate_global->__pyx_n_s_GiacMethods_base_directed
#define __pyx_n_s_GiacMethods_base_discard_edge_at __pyx_mstate_global->__pyx_n_s_GiacMethods_base_discard_edge_at
#define __pyx_n_s_GiacMethods_base_discard_graph_a __pyx_mstate_global->__pyx_n_s_GiacMethods_base_discard_graph_a
#define __pyx_n_s_GiacMethods_base_discard_vertex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_discard_vertex
#define __pyx_n_s_GiacMethods_base_disjoint_union __pyx_mstate_global->__pyx_n_s_GiacMethods_base_disjoint_union
#define __pyx_n_s_GiacMethods_base_display __pyx_mstate_global->__pyx_n_s_GiacMethods_base_display
#define __pyx_n_s_GiacMethods_base_disque __pyx_mstate_global->__pyx_n_s_GiacMethods_base_disque
#define __pyx_n_s_GiacMethods_base_disque_centre __pyx_mstate_global->__pyx_n_s_GiacMethods_base_disque_centre
#define __pyx_n_s_GiacMethods_base_distance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_distance
#define __pyx_n_s_GiacMethods_base_distance2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_distance2
#define __pyx_n_s_GiacMethods_base_distanceat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_distanceat
#define __pyx_n_s_GiacMethods_base_distanceatraw __pyx_mstate_global->__pyx_n_s_GiacMethods_base_distanceatraw
#define __pyx_n_s_GiacMethods_base_divergence __pyx_mstate_global->__pyx_n_s_GiacMethods_base_divergence
#define __pyx_n_s_GiacMethods_base_divide __pyx_mstate_global->__pyx_n_s_GiacMethods_base_divide
#define __pyx_n_s_GiacMethods_base_divis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_divis
#define __pyx_n_s_GiacMethods_base_division_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_division_point
#define __pyx_n_s_GiacMethods_base_divisors __pyx_mstate_global->__pyx_n_s_GiacMethods_base_divisors
#define __pyx_n_s_GiacMethods_base_divmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_divmod
#define __pyx_n_s_GiacMethods_base_divpc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_divpc
#define __pyx_n_s_GiacMethods_base_dnewton_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dnewton_solver
#define __pyx_n_s_GiacMethods_base_dodecahedron __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dodecahedron
#define __pyx_n_s_GiacMethods_base_domain __pyx_mstate_global->__pyx_n_s_GiacMethods_base_domain
#define __pyx_n_s_GiacMethods_base_dot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dot
#define __pyx_n_s_GiacMethods_base_dotP __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dotP
#define __pyx_n_s_GiacMethods_base_dot_paper __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dot_paper
#define __pyx_n_s_GiacMethods_base_dotprod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dotprod
#define __pyx_n_s_GiacMethods_base_draw_arc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_arc
#define __pyx_n_s_GiacMethods_base_draw_circle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_circle
#define __pyx_n_s_GiacMethods_base_draw_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_graph
#define __pyx_n_s_GiacMethods_base_draw_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_line
#define __pyx_n_s_GiacMethods_base_draw_pixel __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_pixel
#define __pyx_n_s_GiacMethods_base_draw_polygon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_polygon
#define __pyx_n_s_GiacMethods_base_draw_rectangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_draw_rectangle
#define __pyx_n_s_GiacMethods_base_droit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_droit
#define __pyx_n_s_GiacMethods_base_droite_tangente __pyx_mstate_global->__pyx_n_s_GiacMethods_base_droite_tangente
#define __pyx_n_s_GiacMethods_base_dsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dsolve
#define __pyx_n_s_GiacMethods_base_duration __pyx_mstate_global->__pyx_n_s_GiacMethods_base_duration
#define __pyx_n_s_GiacMethods_base_dwt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_dwt
#define __pyx_n_s_GiacMethods_base_e __pyx_mstate_global->__pyx_n_s_GiacMethods_base_e
#define __pyx_n_s_GiacMethods_base_e2r __pyx_mstate_global->__pyx_n_s_GiacMethods_base_e2r
#define __pyx_n_s_GiacMethods_base_ecart_type __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ecart_type
#define __pyx_n_s_GiacMethods_base_ecart_type_popu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ecart_type_popu
#define __pyx_n_s_GiacMethods_base_ecef2geodetic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ecef2geodetic
#define __pyx_n_s_GiacMethods_base_ecm_factor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ecm_factor
#define __pyx_n_s_GiacMethods_base_edge_connectivi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_edge_connectivi
#define __pyx_n_s_GiacMethods_base_edges __pyx_mstate_global->__pyx_n_s_GiacMethods_base_edges
#define __pyx_n_s_GiacMethods_base_egcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_egcd
#define __pyx_n_s_GiacMethods_base_egv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_egv
#define __pyx_n_s_GiacMethods_base_egvl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_egvl
#define __pyx_n_s_GiacMethods_base_eigVc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eigVc
#define __pyx_n_s_GiacMethods_base_eigVl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eigVl
#define __pyx_n_s_GiacMethods_base_eigenvals __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eigenvals
#define __pyx_n_s_GiacMethods_base_eigenvalues __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eigenvalues
#define __pyx_n_s_GiacMethods_base_eigenvectors __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eigenvectors
#define __pyx_n_s_GiacMethods_base_eigenvects __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eigenvects
#define __pyx_n_s_GiacMethods_base_element __pyx_mstate_global->__pyx_n_s_GiacMethods_base_element
#define __pyx_n_s_GiacMethods_base_eliminate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eliminate
#define __pyx_n_s_GiacMethods_base_ellipse __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ellipse
#define __pyx_n_s_GiacMethods_base_emd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_emd
#define __pyx_n_s_GiacMethods_base_entry __pyx_mstate_global->__pyx_n_s_GiacMethods_base_entry
#define __pyx_n_s_GiacMethods_base_envelope __pyx_mstate_global->__pyx_n_s_GiacMethods_base_envelope
#define __pyx_n_s_GiacMethods_base_epsilon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_epsilon
#define __pyx_n_s_GiacMethods_base_epsilon2zero __pyx_mstate_global->__pyx_n_s_GiacMethods_base_epsilon2zero
#define __pyx_n_s_GiacMethods_base_equal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_equal
#define __pyx_n_s_GiacMethods_base_equal2diff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_equal2diff
#define __pyx_n_s_GiacMethods_base_equal2list __pyx_mstate_global->__pyx_n_s_GiacMethods_base_equal2list
#define __pyx_n_s_GiacMethods_base_equation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_equation
#define __pyx_n_s_GiacMethods_base_equilateral_tri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_equilateral_tri
#define __pyx_n_s_GiacMethods_base_erf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_erf
#define __pyx_n_s_GiacMethods_base_erfc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_erfc
#define __pyx_n_s_GiacMethods_base_error __pyx_mstate_global->__pyx_n_s_GiacMethods_base_error
#define __pyx_n_s_GiacMethods_base_est_permu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_est_permu
#define __pyx_n_s_GiacMethods_base_euler __pyx_mstate_global->__pyx_n_s_GiacMethods_base_euler
#define __pyx_n_s_GiacMethods_base_euler_gamma __pyx_mstate_global->__pyx_n_s_GiacMethods_base_euler_gamma
#define __pyx_n_s_GiacMethods_base_euler_lagrange __pyx_mstate_global->__pyx_n_s_GiacMethods_base_euler_lagrange
#define __pyx_n_s_GiacMethods_base_eval_level __pyx_mstate_global->__pyx_n_s_GiacMethods_base_eval_level
#define __pyx_n_s_GiacMethods_base_evala __pyx_mstate_global->__pyx_n_s_GiacMethods_base_evala
#define __pyx_n_s_GiacMethods_base_evalb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_evalb
#define __pyx_n_s_GiacMethods_base_evalc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_evalc
#define __pyx_n_s_GiacMethods_base_evalf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_evalf
#define __pyx_n_s_GiacMethods_base_evalm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_evalm
#define __pyx_n_s_GiacMethods_base_even __pyx_mstate_global->__pyx_n_s_GiacMethods_base_even
#define __pyx_n_s_GiacMethods_base_evolute __pyx_mstate_global->__pyx_n_s_GiacMethods_base_evolute
#define __pyx_n_s_GiacMethods_base_exact __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exact
#define __pyx_n_s_GiacMethods_base_exbisector __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exbisector
#define __pyx_n_s_GiacMethods_base_excircle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_excircle
#define __pyx_n_s_GiacMethods_base_execute __pyx_mstate_global->__pyx_n_s_GiacMethods_base_execute
#define __pyx_n_s_GiacMethods_base_exp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exp
#define __pyx_n_s_GiacMethods_base_exp2list __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exp2list
#define __pyx_n_s_GiacMethods_base_exp2pow __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exp2pow
#define __pyx_n_s_GiacMethods_base_exp2trig __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exp2trig
#define __pyx_n_s_GiacMethods_base_expand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_expand
#define __pyx_n_s_GiacMethods_base_expexpand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_expexpand
#define __pyx_n_s_GiacMethods_base_expln __pyx_mstate_global->__pyx_n_s_GiacMethods_base_expln
#define __pyx_n_s_GiacMethods_base_exponential __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponential
#define __pyx_n_s_GiacMethods_base_exponential_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponential_cdf
#define __pyx_n_s_GiacMethods_base_exponential_icd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponential_icd
#define __pyx_n_s_GiacMethods_base_exponential_reg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponential_reg
#define __pyx_n_s_GiacMethods_base_exponential_reg_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponential_reg_2
#define __pyx_n_s_GiacMethods_base_exponentiald __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponentiald
#define __pyx_n_s_GiacMethods_base_exponentiald_cd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponentiald_cd
#define __pyx_n_s_GiacMethods_base_exponentiald_ic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_exponentiald_ic
#define __pyx_n_s_GiacMethods_base_export_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_export_graph
#define __pyx_n_s_GiacMethods_base_export_mathml __pyx_mstate_global->__pyx_n_s_GiacMethods_base_export_mathml
#define __pyx_n_s_GiacMethods_base_expovariate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_expovariate
#define __pyx_n_s_GiacMethods_base_expr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_expr
#define __pyx_n_s_GiacMethods_base_extend __pyx_mstate_global->__pyx_n_s_GiacMethods_base_extend
#define __pyx_n_s_GiacMethods_base_extract_measure __pyx_mstate_global->__pyx_n_s_GiacMethods_base_extract_measure
#define __pyx_n_s_GiacMethods_base_extrema __pyx_mstate_global->__pyx_n_s_GiacMethods_base_extrema
#define __pyx_n_s_GiacMethods_base_ezgcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ezgcd
#define __pyx_n_s_GiacMethods_base_f2nd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_f2nd
#define __pyx_n_s_GiacMethods_base_fMax __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fMax
#define __pyx_n_s_GiacMethods_base_fMin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fMin
#define __pyx_n_s_GiacMethods_base_fPart __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fPart
#define __pyx_n_s_GiacMethods_base_faces __pyx_mstate_global->__pyx_n_s_GiacMethods_base_faces
#define __pyx_n_s_GiacMethods_base_facteurs_premie __pyx_mstate_global->__pyx_n_s_GiacMethods_base_facteurs_premie
#define __pyx_n_s_GiacMethods_base_factor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factor
#define __pyx_n_s_GiacMethods_base_factor_xn __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factor_xn
#define __pyx_n_s_GiacMethods_base_factorial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factorial
#define __pyx_n_s_GiacMethods_base_factoriser __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factoriser
#define __pyx_n_s_GiacMethods_base_factoriser_enti __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factoriser_enti
#define __pyx_n_s_GiacMethods_base_factoriser_sur __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factoriser_sur
#define __pyx_n_s_GiacMethods_base_factors __pyx_mstate_global->__pyx_n_s_GiacMethods_base_factors
#define __pyx_n_s_GiacMethods_base_fadeev __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fadeev
#define __pyx_n_s_GiacMethods_base_false __pyx_mstate_global->__pyx_n_s_GiacMethods_base_false
#define __pyx_n_s_GiacMethods_base_falsepos_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_falsepos_solver
#define __pyx_n_s_GiacMethods_base_fclose __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fclose
#define __pyx_n_s_GiacMethods_base_fcoeff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fcoeff
#define __pyx_n_s_GiacMethods_base_fdistrib __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fdistrib
#define __pyx_n_s_GiacMethods_base_fft __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fft
#define __pyx_n_s_GiacMethods_base_fieldplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fieldplot
#define __pyx_n_s_GiacMethods_base_find __pyx_mstate_global->__pyx_n_s_GiacMethods_base_find
#define __pyx_n_s_GiacMethods_base_find_cliques __pyx_mstate_global->__pyx_n_s_GiacMethods_base_find_cliques
#define __pyx_n_s_GiacMethods_base_find_cycles __pyx_mstate_global->__pyx_n_s_GiacMethods_base_find_cycles
#define __pyx_n_s_GiacMethods_base_find_minimum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_find_minimum
#define __pyx_n_s_GiacMethods_base_find_vertex_cov __pyx_mstate_global->__pyx_n_s_GiacMethods_base_find_vertex_cov
#define __pyx_n_s_GiacMethods_base_findhelp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_findhelp
#define __pyx_n_s_GiacMethods_base_fisher __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fisher
#define __pyx_n_s_GiacMethods_base_fisher_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fisher_cdf
#define __pyx_n_s_GiacMethods_base_fisher_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fisher_icdf
#define __pyx_n_s_GiacMethods_base_fisherd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fisherd
#define __pyx_n_s_GiacMethods_base_fisherd_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fisherd_cdf
#define __pyx_n_s_GiacMethods_base_fisherd_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fisherd_icdf
#define __pyx_n_s_GiacMethods_base_fitdistr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fitdistr
#define __pyx_n_s_GiacMethods_base_fitpoly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fitpoly
#define __pyx_n_s_GiacMethods_base_fitspline __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fitspline
#define __pyx_n_s_GiacMethods_base_flatten __pyx_mstate_global->__pyx_n_s_GiacMethods_base_flatten
#define __pyx_n_s_GiacMethods_base_float2rational __pyx_mstate_global->__pyx_n_s_GiacMethods_base_float2rational
#define __pyx_n_s_GiacMethods_base_floor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_floor
#define __pyx_n_s_GiacMethods_base_flow_polynomial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_flow_polynomial
#define __pyx_n_s_GiacMethods_base_flower_snark __pyx_mstate_global->__pyx_n_s_GiacMethods_base_flower_snark
#define __pyx_n_s_GiacMethods_base_fmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fmod
#define __pyx_n_s_GiacMethods_base_foldl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_foldl
#define __pyx_n_s_GiacMethods_base_foldr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_foldr
#define __pyx_n_s_GiacMethods_base_fonction_derive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fonction_derive
#define __pyx_n_s_GiacMethods_base_forward __pyx_mstate_global->__pyx_n_s_GiacMethods_base_forward
#define __pyx_n_s_GiacMethods_base_fourier __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fourier
#define __pyx_n_s_GiacMethods_base_fourier_an __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fourier_an
#define __pyx_n_s_GiacMethods_base_fourier_bn __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fourier_bn
#define __pyx_n_s_GiacMethods_base_fourier_cn __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fourier_cn
#define __pyx_n_s_GiacMethods_base_fprint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fprint
#define __pyx_n_s_GiacMethods_base_frac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_frac
#define __pyx_n_s_GiacMethods_base_fracmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fracmod
#define __pyx_n_s_GiacMethods_base_frame_2d __pyx_mstate_global->__pyx_n_s_GiacMethods_base_frame_2d
#define __pyx_n_s_GiacMethods_base_frank_wolfe __pyx_mstate_global->__pyx_n_s_GiacMethods_base_frank_wolfe
#define __pyx_n_s_GiacMethods_base_frequencies __pyx_mstate_global->__pyx_n_s_GiacMethods_base_frequencies
#define __pyx_n_s_GiacMethods_base_frobenius_norm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_frobenius_norm
#define __pyx_n_s_GiacMethods_base_froot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_froot
#define __pyx_n_s_GiacMethods_base_fsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fsolve
#define __pyx_n_s_GiacMethods_base_fullparfrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fullparfrac
#define __pyx_n_s_GiacMethods_base_funcplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_funcplot
#define __pyx_n_s_GiacMethods_base_function_diff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_function_diff
#define __pyx_n_s_GiacMethods_base_fundamental_cyc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fundamental_cyc
#define __pyx_n_s_GiacMethods_base_fxnd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_fxnd
#define __pyx_n_s_GiacMethods_base_gammad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gammad
#define __pyx_n_s_GiacMethods_base_gammad_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gammad_cdf
#define __pyx_n_s_GiacMethods_base_gammad_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gammad_icdf
#define __pyx_n_s_GiacMethods_base_gammavariate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gammavariate
#define __pyx_n_s_GiacMethods_base_gauss __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gauss
#define __pyx_n_s_GiacMethods_base_gauss15 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gauss15
#define __pyx_n_s_GiacMethods_base_gauss_seidel_li __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gauss_seidel_li
#define __pyx_n_s_GiacMethods_base_gaussian_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gaussian_window
#define __pyx_n_s_GiacMethods_base_gaussjord __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gaussjord
#define __pyx_n_s_GiacMethods_base_gaussquad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gaussquad
#define __pyx_n_s_GiacMethods_base_gbasis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gbasis
#define __pyx_n_s_GiacMethods_base_gbasis_max_pair __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gbasis_max_pair
#define __pyx_n_s_GiacMethods_base_gbasis_reinject __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gbasis_reinject
#define __pyx_n_s_GiacMethods_base_gbasis_simult_p __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gbasis_simult_p
#define __pyx_n_s_GiacMethods_base_gcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gcd
#define __pyx_n_s_GiacMethods_base_gcdex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gcdex
#define __pyx_n_s_GiacMethods_base_genpoly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_genpoly
#define __pyx_n_s_GiacMethods_base_geodetic2ecef __pyx_mstate_global->__pyx_n_s_GiacMethods_base_geodetic2ecef
#define __pyx_n_s_GiacMethods_base_geometric __pyx_mstate_global->__pyx_n_s_GiacMethods_base_geometric
#define __pyx_n_s_GiacMethods_base_geometric_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_geometric_cdf
#define __pyx_n_s_GiacMethods_base_geometric_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_geometric_icdf
#define __pyx_n_s_GiacMethods_base_getDenom __pyx_mstate_global->__pyx_n_s_GiacMethods_base_getDenom
#define __pyx_n_s_GiacMethods_base_getKey __pyx_mstate_global->__pyx_n_s_GiacMethods_base_getKey
#define __pyx_n_s_GiacMethods_base_getNum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_getNum
#define __pyx_n_s_GiacMethods_base_getType __pyx_mstate_global->__pyx_n_s_GiacMethods_base_getType
#define __pyx_n_s_GiacMethods_base_get_edge_attrib __pyx_mstate_global->__pyx_n_s_GiacMethods_base_get_edge_attrib
#define __pyx_n_s_GiacMethods_base_get_edge_weight __pyx_mstate_global->__pyx_n_s_GiacMethods_base_get_edge_weight
#define __pyx_n_s_GiacMethods_base_get_graph_attri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_get_graph_attri
#define __pyx_n_s_GiacMethods_base_get_vertex_attr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_get_vertex_attr
#define __pyx_n_s_GiacMethods_base_girth __pyx_mstate_global->__pyx_n_s_GiacMethods_base_girth
#define __pyx_n_s_GiacMethods_base_gl_showaxes __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gl_showaxes
#define __pyx_n_s_GiacMethods_base_gold __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gold
#define __pyx_n_s_GiacMethods_base_goldberg_snark __pyx_mstate_global->__pyx_n_s_GiacMethods_base_goldberg_snark
#define __pyx_n_s_GiacMethods_base_grad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_grad
#define __pyx_n_s_GiacMethods_base_gramschmidt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_gramschmidt
#define __pyx_n_s_GiacMethods_base_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph
#define __pyx_n_s_GiacMethods_base_graph_automorph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_automorph
#define __pyx_n_s_GiacMethods_base_graph_charpoly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_charpoly
#define __pyx_n_s_GiacMethods_base_graph_complemen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_complemen
#define __pyx_n_s_GiacMethods_base_graph_diameter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_diameter
#define __pyx_n_s_GiacMethods_base_graph_equal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_equal
#define __pyx_n_s_GiacMethods_base_graph_join __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_join
#define __pyx_n_s_GiacMethods_base_graph_power __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_power
#define __pyx_n_s_GiacMethods_base_graph_rank __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_rank
#define __pyx_n_s_GiacMethods_base_graph_spectrum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_spectrum
#define __pyx_n_s_GiacMethods_base_graph_union __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_union
#define __pyx_n_s_GiacMethods_base_graph_vertices __pyx_mstate_global->__pyx_n_s_GiacMethods_base_graph_vertices
#define __pyx_n_s_GiacMethods_base_greduce __pyx_mstate_global->__pyx_n_s_GiacMethods_base_greduce
#define __pyx_n_s_GiacMethods_base_greedy_clique __pyx_mstate_global->__pyx_n_s_GiacMethods_base_greedy_clique
#define __pyx_n_s_GiacMethods_base_greedy_color __pyx_mstate_global->__pyx_n_s_GiacMethods_base_greedy_color
#define __pyx_n_s_GiacMethods_base_greedy_independ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_greedy_independ
#define __pyx_n_s_GiacMethods_base_grey __pyx_mstate_global->__pyx_n_s_GiacMethods_base_grey
#define __pyx_n_s_GiacMethods_base_grid_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_grid_graph
#define __pyx_n_s_GiacMethods_base_groupermu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_groupermu
#define __pyx_n_s_GiacMethods_base_haar_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_haar_graph
#define __pyx_n_s_GiacMethods_base_hadamard __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hadamard
#define __pyx_n_s_GiacMethods_base_half_cone __pyx_mstate_global->__pyx_n_s_GiacMethods_base_half_cone
#define __pyx_n_s_GiacMethods_base_half_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_half_line
#define __pyx_n_s_GiacMethods_base_halftan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_halftan
#define __pyx_n_s_GiacMethods_base_halftan_hyp2exp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_halftan_hyp2exp
#define __pyx_n_s_GiacMethods_base_halt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_halt
#define __pyx_n_s_GiacMethods_base_hamdist __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hamdist
#define __pyx_n_s_GiacMethods_base_hamming __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hamming
#define __pyx_n_s_GiacMethods_base_hamming_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hamming_window
#define __pyx_n_s_GiacMethods_base_hann_poisson_wi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hann_poisson_wi
#define __pyx_n_s_GiacMethods_base_hann_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hann_window
#define __pyx_n_s_GiacMethods_base_harmonic_centra __pyx_mstate_global->__pyx_n_s_GiacMethods_base_harmonic_centra
#define __pyx_n_s_GiacMethods_base_harmonic_conjug __pyx_mstate_global->__pyx_n_s_GiacMethods_base_harmonic_conjug
#define __pyx_n_s_GiacMethods_base_harmonic_divisi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_harmonic_divisi
#define __pyx_n_s_GiacMethods_base_has __pyx_mstate_global->__pyx_n_s_GiacMethods_base_has
#define __pyx_n_s_GiacMethods_base_has_arc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_has_arc
#define __pyx_n_s_GiacMethods_base_has_edge __pyx_mstate_global->__pyx_n_s_GiacMethods_base_has_edge
#define __pyx_n_s_GiacMethods_base_hasard __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hasard
#define __pyx_n_s_GiacMethods_base_head __pyx_mstate_global->__pyx_n_s_GiacMethods_base_head
#define __pyx_n_s_GiacMethods_base_heading __pyx_mstate_global->__pyx_n_s_GiacMethods_base_heading
#define __pyx_n_s_GiacMethods_base_heapify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_heapify
#define __pyx_n_s_GiacMethods_base_heappop __pyx_mstate_global->__pyx_n_s_GiacMethods_base_heappop
#define __pyx_n_s_GiacMethods_base_heappush __pyx_mstate_global->__pyx_n_s_GiacMethods_base_heappush
#define __pyx_n_s_GiacMethods_base_hermite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hermite
#define __pyx_n_s_GiacMethods_base_hessenberg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hessenberg
#define __pyx_n_s_GiacMethods_base_hessian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hessian
#define __pyx_n_s_GiacMethods_base_heugcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_heugcd
#define __pyx_n_s_GiacMethods_base_hexagon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hexagon
#define __pyx_n_s_GiacMethods_base_hht __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hht
#define __pyx_n_s_GiacMethods_base_highlight_edges __pyx_mstate_global->__pyx_n_s_GiacMethods_base_highlight_edges
#define __pyx_n_s_GiacMethods_base_highlight_subgr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_highlight_subgr
#define __pyx_n_s_GiacMethods_base_highlight_trail __pyx_mstate_global->__pyx_n_s_GiacMethods_base_highlight_trail
#define __pyx_n_s_GiacMethods_base_highlight_verte __pyx_mstate_global->__pyx_n_s_GiacMethods_base_highlight_verte
#define __pyx_n_s_GiacMethods_base_highpass __pyx_mstate_global->__pyx_n_s_GiacMethods_base_highpass
#define __pyx_n_s_GiacMethods_base_hilbert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hilbert
#define __pyx_n_s_GiacMethods_base_histogram __pyx_mstate_global->__pyx_n_s_GiacMethods_base_histogram
#define __pyx_n_s_GiacMethods_base_hold __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hold
#define __pyx_n_s_GiacMethods_base_homogeneize __pyx_mstate_global->__pyx_n_s_GiacMethods_base_homogeneize
#define __pyx_n_s_GiacMethods_base_homothety __pyx_mstate_global->__pyx_n_s_GiacMethods_base_homothety
#define __pyx_n_s_GiacMethods_base_horner __pyx_mstate_global->__pyx_n_s_GiacMethods_base_horner
#define __pyx_n_s_GiacMethods_base_hsv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hsv
#define __pyx_n_s_GiacMethods_base_hsv2rgb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hsv2rgb
#define __pyx_n_s_GiacMethods_base_hybrid_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hybrid_solver
#define __pyx_n_s_GiacMethods_base_hybridj_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hybridj_solver
#define __pyx_n_s_GiacMethods_base_hybrids_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hybrids_solver
#define __pyx_n_s_GiacMethods_base_hybridsj_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hybridsj_solver
#define __pyx_n_s_GiacMethods_base_hyp2exp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hyp2exp
#define __pyx_n_s_GiacMethods_base_hyperbola __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hyperbola
#define __pyx_n_s_GiacMethods_base_hypercube_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_hypercube_graph
#define __pyx_n_s_GiacMethods_base_iPart __pyx_mstate_global->__pyx_n_s_GiacMethods_base_iPart
#define __pyx_n_s_GiacMethods_base_iabcuv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_iabcuv
#define __pyx_n_s_GiacMethods_base_ibasis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ibasis
#define __pyx_n_s_GiacMethods_base_ibpdv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ibpdv
#define __pyx_n_s_GiacMethods_base_ibpu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ibpu
#define __pyx_n_s_GiacMethods_base_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_icdf
#define __pyx_n_s_GiacMethods_base_ichinrem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ichinrem
#define __pyx_n_s_GiacMethods_base_ichrem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ichrem
#define __pyx_n_s_GiacMethods_base_icomp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_icomp
#define __pyx_n_s_GiacMethods_base_icontent __pyx_mstate_global->__pyx_n_s_GiacMethods_base_icontent
#define __pyx_n_s_GiacMethods_base_icosahedron __pyx_mstate_global->__pyx_n_s_GiacMethods_base_icosahedron
#define __pyx_n_s_GiacMethods_base_id __pyx_mstate_global->__pyx_n_s_GiacMethods_base_id
#define __pyx_n_s_GiacMethods_base_identify_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_identify_graph
#define __pyx_n_s_GiacMethods_base_identity __pyx_mstate_global->__pyx_n_s_GiacMethods_base_identity
#define __pyx_n_s_GiacMethods_base_idivis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_idivis
#define __pyx_n_s_GiacMethods_base_idn __pyx_mstate_global->__pyx_n_s_GiacMethods_base_idn
#define __pyx_n_s_GiacMethods_base_idwt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_idwt
#define __pyx_n_s_GiacMethods_base_iegcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_iegcd
#define __pyx_n_s_GiacMethods_base_ifactor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ifactor
#define __pyx_n_s_GiacMethods_base_ifactors __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ifactors
#define __pyx_n_s_GiacMethods_base_ifourier __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ifourier
#define __pyx_n_s_GiacMethods_base_igamma __pyx_mstate_global->__pyx_n_s_GiacMethods_base_igamma
#define __pyx_n_s_GiacMethods_base_igcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_igcd
#define __pyx_n_s_GiacMethods_base_igcdex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_igcdex
#define __pyx_n_s_GiacMethods_base_ihermite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ihermite
#define __pyx_n_s_GiacMethods_base_ilaplace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ilaplace
#define __pyx_n_s_GiacMethods_base_im __pyx_mstate_global->__pyx_n_s_GiacMethods_base_im
#define __pyx_n_s_GiacMethods_base_imag __pyx_mstate_global->__pyx_n_s_GiacMethods_base_imag
#define __pyx_n_s_GiacMethods_base_image __pyx_mstate_global->__pyx_n_s_GiacMethods_base_image
#define __pyx_n_s_GiacMethods_base_imfplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_imfplot
#define __pyx_n_s_GiacMethods_base_implicitdiff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_implicitdiff
#define __pyx_n_s_GiacMethods_base_implicitplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_implicitplot
#define __pyx_n_s_GiacMethods_base_import_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_import_graph
#define __pyx_n_s_GiacMethods_base_inString __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inString
#define __pyx_n_s_GiacMethods_base_in_ideal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_in_ideal
#define __pyx_n_s_GiacMethods_base_incidence_matri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_incidence_matri
#define __pyx_n_s_GiacMethods_base_incident_edges __pyx_mstate_global->__pyx_n_s_GiacMethods_base_incident_edges
#define __pyx_n_s_GiacMethods_base_incircle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_incircle
#define __pyx_n_s_GiacMethods_base_increasing_powe __pyx_mstate_global->__pyx_n_s_GiacMethods_base_increasing_powe
#define __pyx_n_s_GiacMethods_base_independence_nu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_independence_nu
#define __pyx_n_s_GiacMethods_base_indets __pyx_mstate_global->__pyx_n_s_GiacMethods_base_indets
#define __pyx_n_s_GiacMethods_base_index __pyx_mstate_global->__pyx_n_s_GiacMethods_base_index
#define __pyx_n_s_GiacMethods_base_induced_subgrap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_induced_subgrap
#define __pyx_n_s_GiacMethods_base_inequationplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inequationplot
#define __pyx_n_s_GiacMethods_base_inertia __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inertia
#define __pyx_n_s_GiacMethods_base_inf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inf
#define __pyx_n_s_GiacMethods_base_infinity __pyx_mstate_global->__pyx_n_s_GiacMethods_base_infinity
#define __pyx_n_s_GiacMethods_base_information_cen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_information_cen
#define __pyx_n_s_GiacMethods_base_insert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_insert
#define __pyx_n_s_GiacMethods_base_insmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_insmod
#define __pyx_n_s_GiacMethods_base_instfreq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_instfreq
#define __pyx_n_s_GiacMethods_base_instphase __pyx_mstate_global->__pyx_n_s_GiacMethods_base_instphase
#define __pyx_n_s_GiacMethods_base_int __pyx_mstate_global->__pyx_n_s_GiacMethods_base_int
#define __pyx_n_s_GiacMethods_base_intDiv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_intDiv
#define __pyx_n_s_GiacMethods_base_integer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_integer
#define __pyx_n_s_GiacMethods_base_integrate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_integrate
#define __pyx_n_s_GiacMethods_base_integrer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_integrer
#define __pyx_n_s_GiacMethods_base_inter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inter
#define __pyx_n_s_GiacMethods_base_interactive_ode __pyx_mstate_global->__pyx_n_s_GiacMethods_base_interactive_ode
#define __pyx_n_s_GiacMethods_base_interactive_plo __pyx_mstate_global->__pyx_n_s_GiacMethods_base_interactive_plo
#define __pyx_n_s_GiacMethods_base_interp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_interp
#define __pyx_n_s_GiacMethods_base_interval __pyx_mstate_global->__pyx_n_s_GiacMethods_base_interval
#define __pyx_n_s_GiacMethods_base_interval2center __pyx_mstate_global->__pyx_n_s_GiacMethods_base_interval2center
#define __pyx_n_s_GiacMethods_base_interval_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_interval_graph
#define __pyx_n_s_GiacMethods_base_inv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inv
#define __pyx_n_s_GiacMethods_base_inverse __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inverse
#define __pyx_n_s_GiacMethods_base_inversion __pyx_mstate_global->__pyx_n_s_GiacMethods_base_inversion
#define __pyx_n_s_GiacMethods_base_invisible_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_invisible_point
#define __pyx_n_s_GiacMethods_base_invlaplace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_invlaplace
#define __pyx_n_s_GiacMethods_base_invztrans __pyx_mstate_global->__pyx_n_s_GiacMethods_base_invztrans
#define __pyx_n_s_GiacMethods_base_iquo __pyx_mstate_global->__pyx_n_s_GiacMethods_base_iquo
#define __pyx_n_s_GiacMethods_base_iquorem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_iquorem
#define __pyx_n_s_GiacMethods_base_iratrecon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_iratrecon
#define __pyx_n_s_GiacMethods_base_irem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_irem
#define __pyx_n_s_GiacMethods_base_isPrime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isPrime
#define __pyx_n_s_GiacMethods_base_is_acyclic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_acyclic
#define __pyx_n_s_GiacMethods_base_is_arborescence __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_arborescence
#define __pyx_n_s_GiacMethods_base_is_biconnected __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_biconnected
#define __pyx_n_s_GiacMethods_base_is_bipartite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_bipartite
#define __pyx_n_s_GiacMethods_base_is_clique __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_clique
#define __pyx_n_s_GiacMethods_base_is_collinear __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_collinear
#define __pyx_n_s_GiacMethods_base_is_concyclic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_concyclic
#define __pyx_n_s_GiacMethods_base_is_conjugate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_conjugate
#define __pyx_n_s_GiacMethods_base_is_connected __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_connected
#define __pyx_n_s_GiacMethods_base_is_coplanar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_coplanar
#define __pyx_n_s_GiacMethods_base_is_cospherical __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_cospherical
#define __pyx_n_s_GiacMethods_base_is_cut_set __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_cut_set
#define __pyx_n_s_GiacMethods_base_is_cycle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_cycle
#define __pyx_n_s_GiacMethods_base_is_directed __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_directed
#define __pyx_n_s_GiacMethods_base_is_element __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_element
#define __pyx_n_s_GiacMethods_base_is_equilateral __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_equilateral
#define __pyx_n_s_GiacMethods_base_is_eulerian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_eulerian
#define __pyx_n_s_GiacMethods_base_is_forest __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_forest
#define __pyx_n_s_GiacMethods_base_is_graphic_sequ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_graphic_sequ
#define __pyx_n_s_GiacMethods_base_is_hamiltonian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_hamiltonian
#define __pyx_n_s_GiacMethods_base_is_harmonic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_harmonic
#define __pyx_n_s_GiacMethods_base_is_harmonic_cir __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_harmonic_cir
#define __pyx_n_s_GiacMethods_base_is_harmonic_lin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_harmonic_lin
#define __pyx_n_s_GiacMethods_base_is_inside __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_inside
#define __pyx_n_s_GiacMethods_base_is_integer_grap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_integer_grap
#define __pyx_n_s_GiacMethods_base_is_irreducible __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_irreducible
#define __pyx_n_s_GiacMethods_base_is_isomorphic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_isomorphic
#define __pyx_n_s_GiacMethods_base_is_isosceles __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_isosceles
#define __pyx_n_s_GiacMethods_base_is_network __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_network
#define __pyx_n_s_GiacMethods_base_is_orthogonal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_orthogonal
#define __pyx_n_s_GiacMethods_base_is_parallel __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_parallel
#define __pyx_n_s_GiacMethods_base_is_parallelogra __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_parallelogra
#define __pyx_n_s_GiacMethods_base_is_permu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_permu
#define __pyx_n_s_GiacMethods_base_is_perpendicula __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_perpendicula
#define __pyx_n_s_GiacMethods_base_is_planar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_planar
#define __pyx_n_s_GiacMethods_base_is_prime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_prime
#define __pyx_n_s_GiacMethods_base_is_pseudoprime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_pseudoprime
#define __pyx_n_s_GiacMethods_base_is_reachable __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_reachable
#define __pyx_n_s_GiacMethods_base_is_rectangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_rectangle
#define __pyx_n_s_GiacMethods_base_is_regular __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_regular
#define __pyx_n_s_GiacMethods_base_is_rhombus __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_rhombus
#define __pyx_n_s_GiacMethods_base_is_split_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_split_graph
#define __pyx_n_s_GiacMethods_base_is_square __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_square
#define __pyx_n_s_GiacMethods_base_is_strongly_con __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_strongly_con
#define __pyx_n_s_GiacMethods_base_is_strongly_reg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_strongly_reg
#define __pyx_n_s_GiacMethods_base_is_subgraph_iso __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_subgraph_iso
#define __pyx_n_s_GiacMethods_base_is_tournament __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_tournament
#define __pyx_n_s_GiacMethods_base_is_tree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_tree
#define __pyx_n_s_GiacMethods_base_is_triconnected __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_triconnected
#define __pyx_n_s_GiacMethods_base_is_two_edge_con __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_two_edge_con
#define __pyx_n_s_GiacMethods_base_is_vertex_color __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_vertex_color
#define __pyx_n_s_GiacMethods_base_is_weighted __pyx_mstate_global->__pyx_n_s_GiacMethods_base_is_weighted
#define __pyx_n_s_GiacMethods_base_isinf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isinf
#define __pyx_n_s_GiacMethods_base_ismith __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ismith
#define __pyx_n_s_GiacMethods_base_isnan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isnan
#define __pyx_n_s_GiacMethods_base_isobarycenter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isobarycenter
#define __pyx_n_s_GiacMethods_base_isolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isolve
#define __pyx_n_s_GiacMethods_base_isom __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isom
#define __pyx_n_s_GiacMethods_base_isomorphic_copy __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isomorphic_copy
#define __pyx_n_s_GiacMethods_base_isopolygon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isopolygon
#define __pyx_n_s_GiacMethods_base_isosceles_trian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isosceles_trian
#define __pyx_n_s_GiacMethods_base_isposdef __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isposdef
#define __pyx_n_s_GiacMethods_base_isprime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_isprime
#define __pyx_n_s_GiacMethods_base_istft __pyx_mstate_global->__pyx_n_s_GiacMethods_base_istft
#define __pyx_n_s_GiacMethods_base_ithprime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ithprime
#define __pyx_n_s_GiacMethods_base_jacobi_equation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_jacobi_equation
#define __pyx_n_s_GiacMethods_base_jacobi_linsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_jacobi_linsolve
#define __pyx_n_s_GiacMethods_base_jacobi_symbol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_jacobi_symbol
#define __pyx_n_s_GiacMethods_base_johnson_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_johnson_graph
#define __pyx_n_s_GiacMethods_base_join __pyx_mstate_global->__pyx_n_s_GiacMethods_base_join
#define __pyx_n_s_GiacMethods_base_jordan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_jordan
#define __pyx_n_s_GiacMethods_base_katz_centrality __pyx_mstate_global->__pyx_n_s_GiacMethods_base_katz_centrality
#define __pyx_n_s_GiacMethods_base_kde __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kde
#define __pyx_n_s_GiacMethods_base_keep_pivot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_keep_pivot
#define __pyx_n_s_GiacMethods_base_ker __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ker
#define __pyx_n_s_GiacMethods_base_kernel __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kernel
#define __pyx_n_s_GiacMethods_base_kernel_density __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kernel_density
#define __pyx_n_s_GiacMethods_base_kmeans __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kmeans
#define __pyx_n_s_GiacMethods_base_kneser_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kneser_graph
#define __pyx_n_s_GiacMethods_base_kolmogorovd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kolmogorovd
#define __pyx_n_s_GiacMethods_base_kolmogorovt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kolmogorovt
#define __pyx_n_s_GiacMethods_base_kovacicsols __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kovacicsols
#define __pyx_n_s_GiacMethods_base_kspaths __pyx_mstate_global->__pyx_n_s_GiacMethods_base_kspaths
#define __pyx_n_s_GiacMethods_base_l1norm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_l1norm
#define __pyx_n_s_GiacMethods_base_l2norm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_l2norm
#define __pyx_n_s_GiacMethods_base_lagrange __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lagrange
#define __pyx_n_s_GiacMethods_base_laguerre __pyx_mstate_global->__pyx_n_s_GiacMethods_base_laguerre
#define __pyx_n_s_GiacMethods_base_laplace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_laplace
#define __pyx_n_s_GiacMethods_base_laplacian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_laplacian
#define __pyx_n_s_GiacMethods_base_laplacian_matri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_laplacian_matri
#define __pyx_n_s_GiacMethods_base_latex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_latex
#define __pyx_n_s_GiacMethods_base_lcf_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lcf_graph
#define __pyx_n_s_GiacMethods_base_lcm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lcm
#define __pyx_n_s_GiacMethods_base_lcoeff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lcoeff
#define __pyx_n_s_GiacMethods_base_ldegree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ldegree
#define __pyx_n_s_GiacMethods_base_ldl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ldl
#define __pyx_n_s_GiacMethods_base_learning_rate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_learning_rate
#define __pyx_n_s_GiacMethods_base_left __pyx_mstate_global->__pyx_n_s_GiacMethods_base_left
#define __pyx_n_s_GiacMethods_base_left_rectangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_left_rectangle
#define __pyx_n_s_GiacMethods_base_legend __pyx_mstate_global->__pyx_n_s_GiacMethods_base_legend
#define __pyx_n_s_GiacMethods_base_legendre __pyx_mstate_global->__pyx_n_s_GiacMethods_base_legendre
#define __pyx_n_s_GiacMethods_base_legendre_symbol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_legendre_symbol
#define __pyx_n_s_GiacMethods_base_length __pyx_mstate_global->__pyx_n_s_GiacMethods_base_length
#define __pyx_n_s_GiacMethods_base_levenshtein __pyx_mstate_global->__pyx_n_s_GiacMethods_base_levenshtein
#define __pyx_n_s_GiacMethods_base_lgcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lgcd
#define __pyx_n_s_GiacMethods_base_lhs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lhs
#define __pyx_n_s_GiacMethods_base_ligne_chapeau_c __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_chapeau_c
#define __pyx_n_s_GiacMethods_base_ligne_chapeau_p __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_chapeau_p
#define __pyx_n_s_GiacMethods_base_ligne_chapeau_r __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_chapeau_r
#define __pyx_n_s_GiacMethods_base_ligne_polygonal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_polygonal
#define __pyx_n_s_GiacMethods_base_ligne_polygonal_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_polygonal_2
#define __pyx_n_s_GiacMethods_base_ligne_tiret __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_tiret
#define __pyx_n_s_GiacMethods_base_ligne_tiret_poi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_tiret_poi
#define __pyx_n_s_GiacMethods_base_ligne_tiret_poi_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_tiret_poi_2
#define __pyx_n_s_GiacMethods_base_ligne_trait_ple __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ligne_trait_ple
#define __pyx_n_s_GiacMethods_base_limit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_limit
#define __pyx_n_s_GiacMethods_base_limite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_limite
#define __pyx_n_s_GiacMethods_base_lin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lin
#define __pyx_n_s_GiacMethods_base_linabs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linabs
#define __pyx_n_s_GiacMethods_base_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_line
#define __pyx_n_s_GiacMethods_base_line_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_line_graph
#define __pyx_n_s_GiacMethods_base_line_inter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_line_inter
#define __pyx_n_s_GiacMethods_base_line_paper __pyx_mstate_global->__pyx_n_s_GiacMethods_base_line_paper
#define __pyx_n_s_GiacMethods_base_line_segments __pyx_mstate_global->__pyx_n_s_GiacMethods_base_line_segments
#define __pyx_n_s_GiacMethods_base_linear_interpol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linear_interpol
#define __pyx_n_s_GiacMethods_base_linear_regressi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linear_regressi
#define __pyx_n_s_GiacMethods_base_linear_regressi_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linear_regressi_2
#define __pyx_n_s_GiacMethods_base_lineariser __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lineariser
#define __pyx_n_s_GiacMethods_base_lineariser_trig __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lineariser_trig
#define __pyx_n_s_GiacMethods_base_linfnorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linfnorm
#define __pyx_n_s_GiacMethods_base_linsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linsolve
#define __pyx_n_s_GiacMethods_base_linspace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linspace
#define __pyx_n_s_GiacMethods_base_linstep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_linstep
#define __pyx_n_s_GiacMethods_base_lis_phrase __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lis_phrase
#define __pyx_n_s_GiacMethods_base_list2exp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_list2exp
#define __pyx_n_s_GiacMethods_base_list2mat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_list2mat
#define __pyx_n_s_GiacMethods_base_list_edge_attri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_list_edge_attri
#define __pyx_n_s_GiacMethods_base_list_graph_attr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_list_graph_attr
#define __pyx_n_s_GiacMethods_base_list_vertex_att __pyx_mstate_global->__pyx_n_s_GiacMethods_base_list_vertex_att
#define __pyx_n_s_GiacMethods_base_listplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_listplot
#define __pyx_n_s_GiacMethods_base_lll __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lll
#define __pyx_n_s_GiacMethods_base_ln __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ln
#define __pyx_n_s_GiacMethods_base_lname __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lname
#define __pyx_n_s_GiacMethods_base_lncollect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lncollect
#define __pyx_n_s_GiacMethods_base_lnexpand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lnexpand
#define __pyx_n_s_GiacMethods_base_locus __pyx_mstate_global->__pyx_n_s_GiacMethods_base_locus
#define __pyx_n_s_GiacMethods_base_log __pyx_mstate_global->__pyx_n_s_GiacMethods_base_log
#define __pyx_n_s_GiacMethods_base_log10 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_log10
#define __pyx_n_s_GiacMethods_base_log2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_log2
#define __pyx_n_s_GiacMethods_base_log_loss __pyx_mstate_global->__pyx_n_s_GiacMethods_base_log_loss
#define __pyx_n_s_GiacMethods_base_logarithmic_reg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_logarithmic_reg
#define __pyx_n_s_GiacMethods_base_logarithmic_reg_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_logarithmic_reg_2
#define __pyx_n_s_GiacMethods_base_logb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_logb
#define __pyx_n_s_GiacMethods_base_logistic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_logistic
#define __pyx_n_s_GiacMethods_base_logistic_regres __pyx_mstate_global->__pyx_n_s_GiacMethods_base_logistic_regres
#define __pyx_n_s_GiacMethods_base_logistic_regres_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_logistic_regres_2
#define __pyx_n_s_GiacMethods_base_lower __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lower
#define __pyx_n_s_GiacMethods_base_lowest_common_a __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lowest_common_a
#define __pyx_n_s_GiacMethods_base_lowpass __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lowpass
#define __pyx_n_s_GiacMethods_base_lp_assume __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_assume
#define __pyx_n_s_GiacMethods_base_lp_bestlocalbou __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_bestlocalbou
#define __pyx_n_s_GiacMethods_base_lp_bestprojecti __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_bestprojecti
#define __pyx_n_s_GiacMethods_base_lp_binary __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_binary
#define __pyx_n_s_GiacMethods_base_lp_binaryvariab __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_binaryvariab
#define __pyx_n_s_GiacMethods_base_lp_breadthfirst __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_breadthfirst
#define __pyx_n_s_GiacMethods_base_lp_depthfirst __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_depthfirst
#define __pyx_n_s_GiacMethods_base_lp_depthlimit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_depthlimit
#define __pyx_n_s_GiacMethods_base_lp_firstfractio __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_firstfractio
#define __pyx_n_s_GiacMethods_base_lp_gaptolerance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_gaptolerance
#define __pyx_n_s_GiacMethods_base_lp_heuristic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_heuristic
#define __pyx_n_s_GiacMethods_base_lp_hybrid __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_hybrid
#define __pyx_n_s_GiacMethods_base_lp_integer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_integer
#define __pyx_n_s_GiacMethods_base_lp_integervaria __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_integervaria
#define __pyx_n_s_GiacMethods_base_lp_interiorpoin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_interiorpoin
#define __pyx_n_s_GiacMethods_base_lp_iterationlim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_iterationlim
#define __pyx_n_s_GiacMethods_base_lp_lastfraction __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_lastfraction
#define __pyx_n_s_GiacMethods_base_lp_maxcuts __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_maxcuts
#define __pyx_n_s_GiacMethods_base_lp_maximize __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_maximize
#define __pyx_n_s_GiacMethods_base_lp_method __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_method
#define __pyx_n_s_GiacMethods_base_lp_mostfraction __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_mostfraction
#define __pyx_n_s_GiacMethods_base_lp_nodelimit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_nodelimit
#define __pyx_n_s_GiacMethods_base_lp_nodeselect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_nodeselect
#define __pyx_n_s_GiacMethods_base_lp_nonnegative __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_nonnegative
#define __pyx_n_s_GiacMethods_base_lp_nonnegint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_nonnegint
#define __pyx_n_s_GiacMethods_base_lp_presolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_presolve
#define __pyx_n_s_GiacMethods_base_lp_pseudocost __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_pseudocost
#define __pyx_n_s_GiacMethods_base_lp_simplex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_simplex
#define __pyx_n_s_GiacMethods_base_lp_timelimit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_timelimit
#define __pyx_n_s_GiacMethods_base_lp_varselect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_varselect
#define __pyx_n_s_GiacMethods_base_lp_verbose __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lp_verbose
#define __pyx_n_s_GiacMethods_base_lpsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lpsolve
#define __pyx_n_s_GiacMethods_base_lsmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lsmod
#define __pyx_n_s_GiacMethods_base_lsq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lsq
#define __pyx_n_s_GiacMethods_base_lu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lu
#define __pyx_n_s_GiacMethods_base_lvar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_lvar
#define __pyx_n_s_GiacMethods_base_mRow __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mRow
#define __pyx_n_s_GiacMethods_base_mRowAdd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mRowAdd
#define __pyx_n_s_GiacMethods_base_magenta __pyx_mstate_global->__pyx_n_s_GiacMethods_base_magenta
#define __pyx_n_s_GiacMethods_base_make_directed __pyx_mstate_global->__pyx_n_s_GiacMethods_base_make_directed
#define __pyx_n_s_GiacMethods_base_make_symbol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_make_symbol
#define __pyx_n_s_GiacMethods_base_make_weighted __pyx_mstate_global->__pyx_n_s_GiacMethods_base_make_weighted
#define __pyx_n_s_GiacMethods_base_makelist __pyx_mstate_global->__pyx_n_s_GiacMethods_base_makelist
#define __pyx_n_s_GiacMethods_base_makemat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_makemat
#define __pyx_n_s_GiacMethods_base_makesuite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_makesuite
#define __pyx_n_s_GiacMethods_base_makevector __pyx_mstate_global->__pyx_n_s_GiacMethods_base_makevector
#define __pyx_n_s_GiacMethods_base_map __pyx_mstate_global->__pyx_n_s_GiacMethods_base_map
#define __pyx_n_s_GiacMethods_base_maple2mupad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maple2mupad
#define __pyx_n_s_GiacMethods_base_maple2xcas __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maple2xcas
#define __pyx_n_s_GiacMethods_base_maple_ifactors __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maple_ifactors
#define __pyx_n_s_GiacMethods_base_maple_mode __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maple_mode
#define __pyx_n_s_GiacMethods_base_markov __pyx_mstate_global->__pyx_n_s_GiacMethods_base_markov
#define __pyx_n_s_GiacMethods_base_mat2list __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mat2list
#define __pyx_n_s_GiacMethods_base_mathml __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mathml
#define __pyx_n_s_GiacMethods_base_matpow __pyx_mstate_global->__pyx_n_s_GiacMethods_base_matpow
#define __pyx_n_s_GiacMethods_base_matrix __pyx_mstate_global->__pyx_n_s_GiacMethods_base_matrix
#define __pyx_n_s_GiacMethods_base_matrix_norm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_matrix_norm
#define __pyx_n_s_GiacMethods_base_max __pyx_mstate_global->__pyx_n_s_GiacMethods_base_max
#define __pyx_n_s_GiacMethods_base_maxflow __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maxflow
#define __pyx_n_s_GiacMethods_base_maximal_indepen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maximal_indepen
#define __pyx_n_s_GiacMethods_base_maximize __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maximize
#define __pyx_n_s_GiacMethods_base_maximum_clique __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maximum_clique
#define __pyx_n_s_GiacMethods_base_maximum_degree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maximum_degree
#define __pyx_n_s_GiacMethods_base_maximum_indepen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maximum_indepen
#define __pyx_n_s_GiacMethods_base_maximum_matchin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maximum_matchin
#define __pyx_n_s_GiacMethods_base_maxnorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_maxnorm
#define __pyx_n_s_GiacMethods_base_mean __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mean
#define __pyx_n_s_GiacMethods_base_median __pyx_mstate_global->__pyx_n_s_GiacMethods_base_median
#define __pyx_n_s_GiacMethods_base_median_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_median_line
#define __pyx_n_s_GiacMethods_base_member __pyx_mstate_global->__pyx_n_s_GiacMethods_base_member
#define __pyx_n_s_GiacMethods_base_mgf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mgf
#define __pyx_n_s_GiacMethods_base_mid __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mid
#define __pyx_n_s_GiacMethods_base_middle_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_middle_point
#define __pyx_n_s_GiacMethods_base_midpoint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_midpoint
#define __pyx_n_s_GiacMethods_base_min __pyx_mstate_global->__pyx_n_s_GiacMethods_base_min
#define __pyx_n_s_GiacMethods_base_minimal_edge_co __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimal_edge_co
#define __pyx_n_s_GiacMethods_base_minimal_spannin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimal_spannin
#define __pyx_n_s_GiacMethods_base_minimal_vertex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimal_vertex
#define __pyx_n_s_GiacMethods_base_minimax __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimax
#define __pyx_n_s_GiacMethods_base_minimize __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimize
#define __pyx_n_s_GiacMethods_base_minimum_cut __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimum_cut
#define __pyx_n_s_GiacMethods_base_minimum_degree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimum_degree
#define __pyx_n_s_GiacMethods_base_minimum_vertex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_minimum_vertex
#define __pyx_n_s_GiacMethods_base_mixdown __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mixdown
#define __pyx_n_s_GiacMethods_base_mkisom __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mkisom
#define __pyx_n_s_GiacMethods_base_mksa __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mksa
#define __pyx_n_s_GiacMethods_base_modf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_modf
#define __pyx_n_s_GiacMethods_base_modgcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_modgcd
#define __pyx_n_s_GiacMethods_base_mods __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mods
#define __pyx_n_s_GiacMethods_base_momentum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_momentum
#define __pyx_n_s_GiacMethods_base_monotonic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_monotonic
#define __pyx_n_s_GiacMethods_base_montre_tortue __pyx_mstate_global->__pyx_n_s_GiacMethods_base_montre_tortue
#define __pyx_n_s_GiacMethods_base_moustache __pyx_mstate_global->__pyx_n_s_GiacMethods_base_moustache
#define __pyx_n_s_GiacMethods_base_moving_average __pyx_mstate_global->__pyx_n_s_GiacMethods_base_moving_average
#define __pyx_n_s_GiacMethods_base_moyal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_moyal
#define __pyx_n_s_GiacMethods_base_moyenne __pyx_mstate_global->__pyx_n_s_GiacMethods_base_moyenne
#define __pyx_n_s_GiacMethods_base_mul __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mul
#define __pyx_n_s_GiacMethods_base_mult_c_conjugat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mult_c_conjugat
#define __pyx_n_s_GiacMethods_base_mult_conjugate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mult_conjugate
#define __pyx_n_s_GiacMethods_base_multinomial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_multinomial
#define __pyx_n_s_GiacMethods_base_multiplier_conj __pyx_mstate_global->__pyx_n_s_GiacMethods_base_multiplier_conj
#define __pyx_n_s_GiacMethods_base_multiplier_conj_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_multiplier_conj_2
#define __pyx_n_s_GiacMethods_base_multiply __pyx_mstate_global->__pyx_n_s_GiacMethods_base_multiply
#define __pyx_n_s_GiacMethods_base_mupad2maple __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mupad2maple
#define __pyx_n_s_GiacMethods_base_mupad2xcas __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mupad2xcas
#define __pyx_n_s_GiacMethods_base_mycielski __pyx_mstate_global->__pyx_n_s_GiacMethods_base_mycielski
#define __pyx_n_s_GiacMethods_base_nCr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nCr
#define __pyx_n_s_GiacMethods_base_nDeriv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nDeriv
#define __pyx_n_s_GiacMethods_base_nInt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nInt
#define __pyx_n_s_GiacMethods_base_nPr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nPr
#define __pyx_n_s_GiacMethods_base_nSolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nSolve
#define __pyx_n_s_GiacMethods_base_navy __pyx_mstate_global->__pyx_n_s_GiacMethods_base_navy
#define __pyx_n_s_GiacMethods_base_ncols __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ncols
#define __pyx_n_s_GiacMethods_base_negbinomial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_negbinomial
#define __pyx_n_s_GiacMethods_base_negbinomial_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_negbinomial_cdf
#define __pyx_n_s_GiacMethods_base_negbinomial_icd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_negbinomial_icd
#define __pyx_n_s_GiacMethods_base_neighbors __pyx_mstate_global->__pyx_n_s_GiacMethods_base_neighbors
#define __pyx_n_s_GiacMethods_base_network_transit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_network_transit
#define __pyx_n_s_GiacMethods_base_neural_network __pyx_mstate_global->__pyx_n_s_GiacMethods_base_neural_network
#define __pyx_n_s_GiacMethods_base_newList __pyx_mstate_global->__pyx_n_s_GiacMethods_base_newList
#define __pyx_n_s_GiacMethods_base_newMat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_newMat
#define __pyx_n_s_GiacMethods_base_newton __pyx_mstate_global->__pyx_n_s_GiacMethods_base_newton
#define __pyx_n_s_GiacMethods_base_newton_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_newton_solver
#define __pyx_n_s_GiacMethods_base_newtonj_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_newtonj_solver
#define __pyx_n_s_GiacMethods_base_nextperm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nextperm
#define __pyx_n_s_GiacMethods_base_nextprime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nextprime
#define __pyx_n_s_GiacMethods_base_nlp_binary __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_binary
#define __pyx_n_s_GiacMethods_base_nlp_binaryvaria __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_binaryvaria
#define __pyx_n_s_GiacMethods_base_nlp_initialpoin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_initialpoin
#define __pyx_n_s_GiacMethods_base_nlp_integer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_integer
#define __pyx_n_s_GiacMethods_base_nlp_integervari __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_integervari
#define __pyx_n_s_GiacMethods_base_nlp_iterationli __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_iterationli
#define __pyx_n_s_GiacMethods_base_nlp_maximize __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_maximize
#define __pyx_n_s_GiacMethods_base_nlp_method __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_method
#define __pyx_n_s_GiacMethods_base_nlp_nonnegative __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_nonnegative
#define __pyx_n_s_GiacMethods_base_nlp_nonnegint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_nonnegint
#define __pyx_n_s_GiacMethods_base_nlp_precision __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_precision
#define __pyx_n_s_GiacMethods_base_nlp_presolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_presolve
#define __pyx_n_s_GiacMethods_base_nlp_tolerance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_tolerance
#define __pyx_n_s_GiacMethods_base_nlp_verbose __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlp_verbose
#define __pyx_n_s_GiacMethods_base_nlpsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nlpsolve
#define __pyx_n_s_GiacMethods_base_nodisp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nodisp
#define __pyx_n_s_GiacMethods_base_non_recursive_n __pyx_mstate_global->__pyx_n_s_GiacMethods_base_non_recursive_n
#define __pyx_n_s_GiacMethods_base_nonnegint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nonnegint
#define __pyx_n_s_GiacMethods_base_nop __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nop
#define __pyx_n_s_GiacMethods_base_nops __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nops
#define __pyx_n_s_GiacMethods_base_norm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_norm
#define __pyx_n_s_GiacMethods_base_normal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normal
#define __pyx_n_s_GiacMethods_base_normal_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normal_cdf
#define __pyx_n_s_GiacMethods_base_normal_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normal_icdf
#define __pyx_n_s_GiacMethods_base_normald __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normald
#define __pyx_n_s_GiacMethods_base_normald_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normald_cdf
#define __pyx_n_s_GiacMethods_base_normald_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normald_icdf
#define __pyx_n_s_GiacMethods_base_normalize __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normalize
#define __pyx_n_s_GiacMethods_base_normalt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normalt
#define __pyx_n_s_GiacMethods_base_normalvariate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_normalvariate
#define __pyx_n_s_GiacMethods_base_nprimes __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nprimes
#define __pyx_n_s_GiacMethods_base_nrows __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nrows
#define __pyx_n_s_GiacMethods_base_nstep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nstep
#define __pyx_n_s_GiacMethods_base_nuage_points __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nuage_points
#define __pyx_n_s_GiacMethods_base_nullspace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_nullspace
#define __pyx_n_s_GiacMethods_base_number_of_edges __pyx_mstate_global->__pyx_n_s_GiacMethods_base_number_of_edges
#define __pyx_n_s_GiacMethods_base_number_of_spann __pyx_mstate_global->__pyx_n_s_GiacMethods_base_number_of_spann
#define __pyx_n_s_GiacMethods_base_number_of_trian __pyx_mstate_global->__pyx_n_s_GiacMethods_base_number_of_trian
#define __pyx_n_s_GiacMethods_base_number_of_verti __pyx_mstate_global->__pyx_n_s_GiacMethods_base_number_of_verti
#define __pyx_n_s_GiacMethods_base_numdiff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_numdiff
#define __pyx_n_s_GiacMethods_base_numer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_numer
#define __pyx_n_s_GiacMethods_base_octahedron __pyx_mstate_global->__pyx_n_s_GiacMethods_base_octahedron
#define __pyx_n_s_GiacMethods_base_odd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_odd
#define __pyx_n_s_GiacMethods_base_odd_girth __pyx_mstate_global->__pyx_n_s_GiacMethods_base_odd_girth
#define __pyx_n_s_GiacMethods_base_odd_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_odd_graph
#define __pyx_n_s_GiacMethods_base_odeplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_odeplot
#define __pyx_n_s_GiacMethods_base_odesolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_odesolve
#define __pyx_n_s_GiacMethods_base_olive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_olive
#define __pyx_n_s_GiacMethods_base_op __pyx_mstate_global->__pyx_n_s_GiacMethods_base_op
#define __pyx_n_s_GiacMethods_base_open_polygon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_open_polygon
#define __pyx_n_s_GiacMethods_base_orange __pyx_mstate_global->__pyx_n_s_GiacMethods_base_orange
#define __pyx_n_s_GiacMethods_base_ord __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ord
#define __pyx_n_s_GiacMethods_base_order __pyx_mstate_global->__pyx_n_s_GiacMethods_base_order
#define __pyx_n_s_GiacMethods_base_order_size __pyx_mstate_global->__pyx_n_s_GiacMethods_base_order_size
#define __pyx_n_s_GiacMethods_base_ordinate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ordinate
#define __pyx_n_s_GiacMethods_base_orthocenter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_orthocenter
#define __pyx_n_s_GiacMethods_base_orthogonal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_orthogonal
#define __pyx_n_s_GiacMethods_base_osculating_circ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_osculating_circ
#define __pyx_n_s_GiacMethods_base_p1oc2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_p1oc2
#define __pyx_n_s_GiacMethods_base_p1op2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_p1op2
#define __pyx_n_s_GiacMethods_base_pa2b2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pa2b2
#define __pyx_n_s_GiacMethods_base_pade __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pade
#define __pyx_n_s_GiacMethods_base_paley_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_paley_graph
#define __pyx_n_s_GiacMethods_base_parabola __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parabola
#define __pyx_n_s_GiacMethods_base_parallel __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parallel
#define __pyx_n_s_GiacMethods_base_parallelepiped __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parallelepiped
#define __pyx_n_s_GiacMethods_base_parallelogram __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parallelogram
#define __pyx_n_s_GiacMethods_base_parameq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parameq
#define __pyx_n_s_GiacMethods_base_parameter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parameter
#define __pyx_n_s_GiacMethods_base_paramplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_paramplot
#define __pyx_n_s_GiacMethods_base_parfrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parfrac
#define __pyx_n_s_GiacMethods_base_pari __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pari
#define __pyx_n_s_GiacMethods_base_part __pyx_mstate_global->__pyx_n_s_GiacMethods_base_part
#define __pyx_n_s_GiacMethods_base_partfrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_partfrac
#define __pyx_n_s_GiacMethods_base_parzen_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_parzen_window
#define __pyx_n_s_GiacMethods_base_pas_de_cote __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pas_de_cote
#define __pyx_n_s_GiacMethods_base_path_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_path_graph
#define __pyx_n_s_GiacMethods_base_pcar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pcar
#define __pyx_n_s_GiacMethods_base_pcar_hessenberg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pcar_hessenberg
#define __pyx_n_s_GiacMethods_base_pcoef __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pcoef
#define __pyx_n_s_GiacMethods_base_pcoeff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pcoeff
#define __pyx_n_s_GiacMethods_base_pencolor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pencolor
#define __pyx_n_s_GiacMethods_base_pendown __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pendown
#define __pyx_n_s_GiacMethods_base_penup __pyx_mstate_global->__pyx_n_s_GiacMethods_base_penup
#define __pyx_n_s_GiacMethods_base_perimeter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perimeter
#define __pyx_n_s_GiacMethods_base_perimeterat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perimeterat
#define __pyx_n_s_GiacMethods_base_perimeteratraw __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perimeteratraw
#define __pyx_n_s_GiacMethods_base_period __pyx_mstate_global->__pyx_n_s_GiacMethods_base_period
#define __pyx_n_s_GiacMethods_base_periodic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_periodic
#define __pyx_n_s_GiacMethods_base_perm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perm
#define __pyx_n_s_GiacMethods_base_perminv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perminv
#define __pyx_n_s_GiacMethods_base_permu2cycles __pyx_mstate_global->__pyx_n_s_GiacMethods_base_permu2cycles
#define __pyx_n_s_GiacMethods_base_permu2mat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_permu2mat
#define __pyx_n_s_GiacMethods_base_permuorder __pyx_mstate_global->__pyx_n_s_GiacMethods_base_permuorder
#define __pyx_n_s_GiacMethods_base_permute_vertice __pyx_mstate_global->__pyx_n_s_GiacMethods_base_permute_vertice
#define __pyx_n_s_GiacMethods_base_perpen_bisector __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perpen_bisector
#define __pyx_n_s_GiacMethods_base_perpendicular __pyx_mstate_global->__pyx_n_s_GiacMethods_base_perpendicular
#define __pyx_n_s_GiacMethods_base_petersen_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_petersen_graph
#define __pyx_n_s_GiacMethods_base_peval __pyx_mstate_global->__pyx_n_s_GiacMethods_base_peval
#define __pyx_n_s_GiacMethods_base_pi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pi
#define __pyx_n_s_GiacMethods_base_pie __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pie
#define __pyx_n_s_GiacMethods_base_piecewise __pyx_mstate_global->__pyx_n_s_GiacMethods_base_piecewise
#define __pyx_n_s_GiacMethods_base_pink __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pink
#define __pyx_n_s_GiacMethods_base_pivot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pivot
#define __pyx_n_s_GiacMethods_base_pixoff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pixoff
#define __pyx_n_s_GiacMethods_base_pixon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pixon
#define __pyx_n_s_GiacMethods_base_planar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_planar
#define __pyx_n_s_GiacMethods_base_plane __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plane
#define __pyx_n_s_GiacMethods_base_plane_dual __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plane_dual
#define __pyx_n_s_GiacMethods_base_playsnd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_playsnd
#define __pyx_n_s_GiacMethods_base_plex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plex
#define __pyx_n_s_GiacMethods_base_plot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plot
#define __pyx_n_s_GiacMethods_base_plot3d __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plot3d
#define __pyx_n_s_GiacMethods_base_plotarea __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotarea
#define __pyx_n_s_GiacMethods_base_plotcdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotcdf
#define __pyx_n_s_GiacMethods_base_plotcontour __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotcontour
#define __pyx_n_s_GiacMethods_base_plotdensity __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotdensity
#define __pyx_n_s_GiacMethods_base_plotfield __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotfield
#define __pyx_n_s_GiacMethods_base_plotfunc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotfunc
#define __pyx_n_s_GiacMethods_base_plotimf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotimf
#define __pyx_n_s_GiacMethods_base_plotimplicit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotimplicit
#define __pyx_n_s_GiacMethods_base_plotinequation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotinequation
#define __pyx_n_s_GiacMethods_base_plotlist __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotlist
#define __pyx_n_s_GiacMethods_base_plotode __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotode
#define __pyx_n_s_GiacMethods_base_plotparam __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotparam
#define __pyx_n_s_GiacMethods_base_plotpolar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotpolar
#define __pyx_n_s_GiacMethods_base_plotproba __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotproba
#define __pyx_n_s_GiacMethods_base_plotseq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotseq
#define __pyx_n_s_GiacMethods_base_plotspectrum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotspectrum
#define __pyx_n_s_GiacMethods_base_plotwav __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plotwav
#define __pyx_n_s_GiacMethods_base_plus_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_plus_point
#define __pyx_n_s_GiacMethods_base_pmin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pmin
#define __pyx_n_s_GiacMethods_base_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_point
#define __pyx_n_s_GiacMethods_base_point2d __pyx_mstate_global->__pyx_n_s_GiacMethods_base_point2d
#define __pyx_n_s_GiacMethods_base_point3d __pyx_mstate_global->__pyx_n_s_GiacMethods_base_point3d
#define __pyx_n_s_GiacMethods_base_poisson __pyx_mstate_global->__pyx_n_s_GiacMethods_base_poisson
#define __pyx_n_s_GiacMethods_base_poisson_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_poisson_cdf
#define __pyx_n_s_GiacMethods_base_poisson_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_poisson_icdf
#define __pyx_n_s_GiacMethods_base_poisson_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_poisson_window
#define __pyx_n_s_GiacMethods_base_polar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polar
#define __pyx_n_s_GiacMethods_base_polar_coordinat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polar_coordinat
#define __pyx_n_s_GiacMethods_base_polar_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polar_point
#define __pyx_n_s_GiacMethods_base_polarplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polarplot
#define __pyx_n_s_GiacMethods_base_pole __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pole
#define __pyx_n_s_GiacMethods_base_poly2symb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_poly2symb
#define __pyx_n_s_GiacMethods_base_polyEval __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polyEval
#define __pyx_n_s_GiacMethods_base_polygon __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polygon
#define __pyx_n_s_GiacMethods_base_polygone_rempli __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polygone_rempli
#define __pyx_n_s_GiacMethods_base_polygonplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polygonplot
#define __pyx_n_s_GiacMethods_base_polygonscatterp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polygonscatterp
#define __pyx_n_s_GiacMethods_base_polyhedron __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polyhedron
#define __pyx_n_s_GiacMethods_base_polynom __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polynom
#define __pyx_n_s_GiacMethods_base_polynomial_regr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polynomial_regr
#define __pyx_n_s_GiacMethods_base_polynomial_regr_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_polynomial_regr_2
#define __pyx_n_s_GiacMethods_base_position __pyx_mstate_global->__pyx_n_s_GiacMethods_base_position
#define __pyx_n_s_GiacMethods_base_poslbdLMQ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_poslbdLMQ
#define __pyx_n_s_GiacMethods_base_posubLMQ __pyx_mstate_global->__pyx_n_s_GiacMethods_base_posubLMQ
#define __pyx_n_s_GiacMethods_base_potential __pyx_mstate_global->__pyx_n_s_GiacMethods_base_potential
#define __pyx_n_s_GiacMethods_base_pow2exp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pow2exp
#define __pyx_n_s_GiacMethods_base_power_regressio __pyx_mstate_global->__pyx_n_s_GiacMethods_base_power_regressio
#define __pyx_n_s_GiacMethods_base_power_regressio_2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_power_regressio_2
#define __pyx_n_s_GiacMethods_base_powermod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_powermod
#define __pyx_n_s_GiacMethods_base_powerpc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_powerpc
#define __pyx_n_s_GiacMethods_base_powexpand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_powexpand
#define __pyx_n_s_GiacMethods_base_powmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_powmod
#define __pyx_n_s_GiacMethods_base_prepend __pyx_mstate_global->__pyx_n_s_GiacMethods_base_prepend
#define __pyx_n_s_GiacMethods_base_preval __pyx_mstate_global->__pyx_n_s_GiacMethods_base_preval
#define __pyx_n_s_GiacMethods_base_prevperm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_prevperm
#define __pyx_n_s_GiacMethods_base_prevprime __pyx_mstate_global->__pyx_n_s_GiacMethods_base_prevprime
#define __pyx_n_s_GiacMethods_base_primpart __pyx_mstate_global->__pyx_n_s_GiacMethods_base_primpart
#define __pyx_n_s_GiacMethods_base_printf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_printf
#define __pyx_n_s_GiacMethods_base_prism __pyx_mstate_global->__pyx_n_s_GiacMethods_base_prism
#define __pyx_n_s_GiacMethods_base_prism_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_prism_graph
#define __pyx_n_s_GiacMethods_base_product __pyx_mstate_global->__pyx_n_s_GiacMethods_base_product
#define __pyx_n_s_GiacMethods_base_projection __pyx_mstate_global->__pyx_n_s_GiacMethods_base_projection
#define __pyx_n_s_GiacMethods_base_proot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_proot
#define __pyx_n_s_GiacMethods_base_propFrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_propFrac
#define __pyx_n_s_GiacMethods_base_propfrac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_propfrac
#define __pyx_n_s_GiacMethods_base_pruefer_code __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pruefer_code
#define __pyx_n_s_GiacMethods_base_psrgcd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_psrgcd
#define __pyx_n_s_GiacMethods_base_ptayl __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ptayl
#define __pyx_n_s_GiacMethods_base_purge __pyx_mstate_global->__pyx_n_s_GiacMethods_base_purge
#define __pyx_n_s_GiacMethods_base_purple __pyx_mstate_global->__pyx_n_s_GiacMethods_base_purple
#define __pyx_n_s_GiacMethods_base_pwd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pwd
#define __pyx_n_s_GiacMethods_base_pyramid __pyx_mstate_global->__pyx_n_s_GiacMethods_base_pyramid
#define __pyx_n_s_GiacMethods_base_python_compat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_python_compat
#define __pyx_n_s_GiacMethods_base_q2a __pyx_mstate_global->__pyx_n_s_GiacMethods_base_q2a
#define __pyx_n_s_GiacMethods_base_qr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_qr
#define __pyx_n_s_GiacMethods_base_quadric __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quadric
#define __pyx_n_s_GiacMethods_base_quadrilateral __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quadrilateral
#define __pyx_n_s_GiacMethods_base_quantile __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quantile
#define __pyx_n_s_GiacMethods_base_quartile1 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quartile1
#define __pyx_n_s_GiacMethods_base_quartile3 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quartile3
#define __pyx_n_s_GiacMethods_base_quartiles __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quartiles
#define __pyx_n_s_GiacMethods_base_quest __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quest
#define __pyx_n_s_GiacMethods_base_quo __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quo
#define __pyx_n_s_GiacMethods_base_quorem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quorem
#define __pyx_n_s_GiacMethods_base_quote __pyx_mstate_global->__pyx_n_s_GiacMethods_base_quote
#define __pyx_n_s_GiacMethods_base_r2e __pyx_mstate_global->__pyx_n_s_GiacMethods_base_r2e
#define __pyx_n_s_GiacMethods_base_radians __pyx_mstate_global->__pyx_n_s_GiacMethods_base_radians
#define __pyx_n_s_GiacMethods_base_radical_axis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_radical_axis
#define __pyx_n_s_GiacMethods_base_radius __pyx_mstate_global->__pyx_n_s_GiacMethods_base_radius
#define __pyx_n_s_GiacMethods_base_ramene __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ramene
#define __pyx_n_s_GiacMethods_base_rand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rand
#define __pyx_n_s_GiacMethods_base_randMat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randMat
#define __pyx_n_s_GiacMethods_base_randNorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randNorm
#define __pyx_n_s_GiacMethods_base_randPoly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randPoly
#define __pyx_n_s_GiacMethods_base_randbetad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randbetad
#define __pyx_n_s_GiacMethods_base_randbinomial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randbinomial
#define __pyx_n_s_GiacMethods_base_randchisquare __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randchisquare
#define __pyx_n_s_GiacMethods_base_randexp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randexp
#define __pyx_n_s_GiacMethods_base_randfisher __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randfisher
#define __pyx_n_s_GiacMethods_base_randgammad __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randgammad
#define __pyx_n_s_GiacMethods_base_randgeometric __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randgeometric
#define __pyx_n_s_GiacMethods_base_randint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randint
#define __pyx_n_s_GiacMethods_base_randmarkov __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randmarkov
#define __pyx_n_s_GiacMethods_base_randmatrix __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randmatrix
#define __pyx_n_s_GiacMethods_base_randmultinomial __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randmultinomial
#define __pyx_n_s_GiacMethods_base_randnorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randnorm
#define __pyx_n_s_GiacMethods_base_random __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random
#define __pyx_n_s_GiacMethods_base_random_bipartit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_bipartit
#define __pyx_n_s_GiacMethods_base_random_digraph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_digraph
#define __pyx_n_s_GiacMethods_base_random_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_graph
#define __pyx_n_s_GiacMethods_base_random_network __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_network
#define __pyx_n_s_GiacMethods_base_random_planar_g __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_planar_g
#define __pyx_n_s_GiacMethods_base_random_regular __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_regular
#define __pyx_n_s_GiacMethods_base_random_sequence __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_sequence
#define __pyx_n_s_GiacMethods_base_random_tourname __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_tourname
#define __pyx_n_s_GiacMethods_base_random_tree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_tree
#define __pyx_n_s_GiacMethods_base_random_variable __pyx_mstate_global->__pyx_n_s_GiacMethods_base_random_variable
#define __pyx_n_s_GiacMethods_base_randperm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randperm
#define __pyx_n_s_GiacMethods_base_randpoisson __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randpoisson
#define __pyx_n_s_GiacMethods_base_randpoly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randpoly
#define __pyx_n_s_GiacMethods_base_randseed __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randseed
#define __pyx_n_s_GiacMethods_base_randstudent __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randstudent
#define __pyx_n_s_GiacMethods_base_randvar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randvar
#define __pyx_n_s_GiacMethods_base_randvector __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randvector
#define __pyx_n_s_GiacMethods_base_randweibulld __pyx_mstate_global->__pyx_n_s_GiacMethods_base_randweibulld
#define __pyx_n_s_GiacMethods_base_rank __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rank
#define __pyx_n_s_GiacMethods_base_ranm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ranm
#define __pyx_n_s_GiacMethods_base_ranv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ranv
#define __pyx_n_s_GiacMethods_base_rassembler_trig __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rassembler_trig
#define __pyx_n_s_GiacMethods_base_rat_jordan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rat_jordan
#define __pyx_n_s_GiacMethods_base_ratinterp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ratinterp
#define __pyx_n_s_GiacMethods_base_rational __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rational
#define __pyx_n_s_GiacMethods_base_rationalroot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rationalroot
#define __pyx_n_s_GiacMethods_base_ratnormal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ratnormal
#define __pyx_n_s_GiacMethods_base_rdiv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rdiv
#define __pyx_n_s_GiacMethods_base_re __pyx_mstate_global->__pyx_n_s_GiacMethods_base_re
#define __pyx_n_s_GiacMethods_base_reachable __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reachable
#define __pyx_n_s_GiacMethods_base_read __pyx_mstate_global->__pyx_n_s_GiacMethods_base_read
#define __pyx_n_s_GiacMethods_base_readrgb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_readrgb
#define __pyx_n_s_GiacMethods_base_readwav __pyx_mstate_global->__pyx_n_s_GiacMethods_base_readwav
#define __pyx_n_s_GiacMethods_base_real __pyx_mstate_global->__pyx_n_s_GiacMethods_base_real
#define __pyx_n_s_GiacMethods_base_realroot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_realroot
#define __pyx_n_s_GiacMethods_base_reciprocation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reciprocation
#define __pyx_n_s_GiacMethods_base_rect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rect
#define __pyx_n_s_GiacMethods_base_rectangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rectangle
#define __pyx_n_s_GiacMethods_base_rectangle_droit __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rectangle_droit
#define __pyx_n_s_GiacMethods_base_rectangle_gauch __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rectangle_gauch
#define __pyx_n_s_GiacMethods_base_rectangle_plein __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rectangle_plein
#define __pyx_n_s_GiacMethods_base_rectangular_coo __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rectangular_coo
#define __pyx_n_s_GiacMethods_base_recule __pyx_mstate_global->__pyx_n_s_GiacMethods_base_recule
#define __pyx_n_s_GiacMethods_base_red __pyx_mstate_global->__pyx_n_s_GiacMethods_base_red
#define __pyx_n_s_GiacMethods_base_reduced_conic __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reduced_conic
#define __pyx_n_s_GiacMethods_base_reduced_quadric __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reduced_quadric
#define __pyx_n_s_GiacMethods_base_ref __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ref
#define __pyx_n_s_GiacMethods_base_reflection __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reflection
#define __pyx_n_s_GiacMethods_base_regroup __pyx_mstate_global->__pyx_n_s_GiacMethods_base_regroup
#define __pyx_n_s_GiacMethods_base_relabel_vertice __pyx_mstate_global->__pyx_n_s_GiacMethods_base_relabel_vertice
#define __pyx_n_s_GiacMethods_base_reliability_pol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reliability_pol
#define __pyx_n_s_GiacMethods_base_rem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rem
#define __pyx_n_s_GiacMethods_base_remain __pyx_mstate_global->__pyx_n_s_GiacMethods_base_remain
#define __pyx_n_s_GiacMethods_base_remove __pyx_mstate_global->__pyx_n_s_GiacMethods_base_remove
#define __pyx_n_s_GiacMethods_base_reorder __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reorder
#define __pyx_n_s_GiacMethods_base_resample __pyx_mstate_global->__pyx_n_s_GiacMethods_base_resample
#define __pyx_n_s_GiacMethods_base_residue __pyx_mstate_global->__pyx_n_s_GiacMethods_base_residue
#define __pyx_n_s_GiacMethods_base_resoudre __pyx_mstate_global->__pyx_n_s_GiacMethods_base_resoudre
#define __pyx_n_s_GiacMethods_base_resoudre_dans_C __pyx_mstate_global->__pyx_n_s_GiacMethods_base_resoudre_dans_C
#define __pyx_n_s_GiacMethods_base_resoudre_system __pyx_mstate_global->__pyx_n_s_GiacMethods_base_resoudre_system
#define __pyx_n_s_GiacMethods_base_resultant __pyx_mstate_global->__pyx_n_s_GiacMethods_base_resultant
#define __pyx_n_s_GiacMethods_base_reverse __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reverse
#define __pyx_n_s_GiacMethods_base_reverse_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reverse_graph
#define __pyx_n_s_GiacMethods_base_reverse_rsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_reverse_rsolve
#define __pyx_n_s_GiacMethods_base_revert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_revert
#define __pyx_n_s_GiacMethods_base_revlex __pyx_mstate_global->__pyx_n_s_GiacMethods_base_revlex
#define __pyx_n_s_GiacMethods_base_revlist __pyx_mstate_global->__pyx_n_s_GiacMethods_base_revlist
#define __pyx_n_s_GiacMethods_base_rgb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rgb
#define __pyx_n_s_GiacMethods_base_rgb2hsv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rgb2hsv
#define __pyx_n_s_GiacMethods_base_rgb2xyz __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rgb2xyz
#define __pyx_n_s_GiacMethods_base_rhombus __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rhombus
#define __pyx_n_s_GiacMethods_base_rhombus_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rhombus_point
#define __pyx_n_s_GiacMethods_base_rhs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rhs
#define __pyx_n_s_GiacMethods_base_riemann_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_riemann_window
#define __pyx_n_s_GiacMethods_base_right __pyx_mstate_global->__pyx_n_s_GiacMethods_base_right
#define __pyx_n_s_GiacMethods_base_right_rectangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_right_rectangle
#define __pyx_n_s_GiacMethods_base_right_triangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_right_triangle
#define __pyx_n_s_GiacMethods_base_risch __pyx_mstate_global->__pyx_n_s_GiacMethods_base_risch
#define __pyx_n_s_GiacMethods_base_rm_a_z __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rm_a_z
#define __pyx_n_s_GiacMethods_base_rm_all_vars __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rm_all_vars
#define __pyx_n_s_GiacMethods_base_rmbreakpoint __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rmbreakpoint
#define __pyx_n_s_GiacMethods_base_rmmod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rmmod
#define __pyx_n_s_GiacMethods_base_rms __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rms
#define __pyx_n_s_GiacMethods_base_rmwatch __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rmwatch
#define __pyx_n_s_GiacMethods_base_romberg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_romberg
#define __pyx_n_s_GiacMethods_base_rombergm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rombergm
#define __pyx_n_s_GiacMethods_base_rombergt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rombergt
#define __pyx_n_s_GiacMethods_base_rond __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rond
#define __pyx_n_s_GiacMethods_base_root __pyx_mstate_global->__pyx_n_s_GiacMethods_base_root
#define __pyx_n_s_GiacMethods_base_rootof __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rootof
#define __pyx_n_s_GiacMethods_base_roots __pyx_mstate_global->__pyx_n_s_GiacMethods_base_roots
#define __pyx_n_s_GiacMethods_base_rotate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rotate
#define __pyx_n_s_GiacMethods_base_rotation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rotation
#define __pyx_n_s_GiacMethods_base_round __pyx_mstate_global->__pyx_n_s_GiacMethods_base_round
#define __pyx_n_s_GiacMethods_base_row __pyx_mstate_global->__pyx_n_s_GiacMethods_base_row
#define __pyx_n_s_GiacMethods_base_rowAdd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowAdd
#define __pyx_n_s_GiacMethods_base_rowDim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowDim
#define __pyx_n_s_GiacMethods_base_rowNorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowNorm
#define __pyx_n_s_GiacMethods_base_rowSwap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowSwap
#define __pyx_n_s_GiacMethods_base_rowdim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowdim
#define __pyx_n_s_GiacMethods_base_rownorm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rownorm
#define __pyx_n_s_GiacMethods_base_rowspace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowspace
#define __pyx_n_s_GiacMethods_base_rowswap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rowswap
#define __pyx_n_s_GiacMethods_base_rref __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rref
#define __pyx_n_s_GiacMethods_base_rsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rsolve
#define __pyx_n_s_GiacMethods_base_rur __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rur
#define __pyx_n_s_GiacMethods_base_rur_certify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rur_certify
#define __pyx_n_s_GiacMethods_base_rur_gbasis __pyx_mstate_global->__pyx_n_s_GiacMethods_base_rur_gbasis
#define __pyx_n_s_GiacMethods_base_same __pyx_mstate_global->__pyx_n_s_GiacMethods_base_same
#define __pyx_n_s_GiacMethods_base_sample __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sample
#define __pyx_n_s_GiacMethods_base_samplerate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_samplerate
#define __pyx_n_s_GiacMethods_base_sans_factoriser __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sans_factoriser
#define __pyx_n_s_GiacMethods_base_saute __pyx_mstate_global->__pyx_n_s_GiacMethods_base_saute
#define __pyx_n_s_GiacMethods_base_scalarProduct __pyx_mstate_global->__pyx_n_s_GiacMethods_base_scalarProduct
#define __pyx_n_s_GiacMethods_base_scalar_product __pyx_mstate_global->__pyx_n_s_GiacMethods_base_scalar_product
#define __pyx_n_s_GiacMethods_base_scatterplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_scatterplot
#define __pyx_n_s_GiacMethods_base_schur __pyx_mstate_global->__pyx_n_s_GiacMethods_base_schur
#define __pyx_n_s_GiacMethods_base_sec __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sec
#define __pyx_n_s_GiacMethods_base_secant_solver __pyx_mstate_global->__pyx_n_s_GiacMethods_base_secant_solver
#define __pyx_n_s_GiacMethods_base_segment __pyx_mstate_global->__pyx_n_s_GiacMethods_base_segment
#define __pyx_n_s_GiacMethods_base_seidel_spectrum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_seidel_spectrum
#define __pyx_n_s_GiacMethods_base_seidel_switch __pyx_mstate_global->__pyx_n_s_GiacMethods_base_seidel_switch
#define __pyx_n_s_GiacMethods_base_select __pyx_mstate_global->__pyx_n_s_GiacMethods_base_select
#define __pyx_n_s_GiacMethods_base_semi_augment __pyx_mstate_global->__pyx_n_s_GiacMethods_base_semi_augment
#define __pyx_n_s_GiacMethods_base_seq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_seq
#define __pyx_n_s_GiacMethods_base_seqplot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_seqplot
#define __pyx_n_s_GiacMethods_base_seqsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_seqsolve
#define __pyx_n_s_GiacMethods_base_sequence_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sequence_graph
#define __pyx_n_s_GiacMethods_base_series __pyx_mstate_global->__pyx_n_s_GiacMethods_base_series
#define __pyx_n_s_GiacMethods_base_set_channel_dat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_channel_dat
#define __pyx_n_s_GiacMethods_base_set_edge_attrib __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_edge_attrib
#define __pyx_n_s_GiacMethods_base_set_edge_weight __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_edge_weight
#define __pyx_n_s_GiacMethods_base_set_graph_attri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_graph_attri
#define __pyx_n_s_GiacMethods_base_set_pixel __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_pixel
#define __pyx_n_s_GiacMethods_base_set_screen __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_screen
#define __pyx_n_s_GiacMethods_base_set_vertex_attr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_vertex_attr
#define __pyx_n_s_GiacMethods_base_set_vertex_posi __pyx_mstate_global->__pyx_n_s_GiacMethods_base_set_vertex_posi
#define __pyx_n_s_GiacMethods_base_shift __pyx_mstate_global->__pyx_n_s_GiacMethods_base_shift
#define __pyx_n_s_GiacMethods_base_shift_phase __pyx_mstate_global->__pyx_n_s_GiacMethods_base_shift_phase
#define __pyx_n_s_GiacMethods_base_shortest_path __pyx_mstate_global->__pyx_n_s_GiacMethods_base_shortest_path
#define __pyx_n_s_GiacMethods_base_show_pixels __pyx_mstate_global->__pyx_n_s_GiacMethods_base_show_pixels
#define __pyx_n_s_GiacMethods_base_shuffle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_shuffle
#define __pyx_n_s_GiacMethods_base_sierpinski_grap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sierpinski_grap
#define __pyx_n_s_GiacMethods_base_sign __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sign
#define __pyx_n_s_GiacMethods_base_sign2Heaviside __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sign2Heaviside
#define __pyx_n_s_GiacMethods_base_signature __pyx_mstate_global->__pyx_n_s_GiacMethods_base_signature
#define __pyx_n_s_GiacMethods_base_signe __pyx_mstate_global->__pyx_n_s_GiacMethods_base_signe
#define __pyx_n_s_GiacMethods_base_similarity __pyx_mstate_global->__pyx_n_s_GiacMethods_base_similarity
#define __pyx_n_s_GiacMethods_base_simp2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simp2
#define __pyx_n_s_GiacMethods_base_simplex_reduce __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simplex_reduce
#define __pyx_n_s_GiacMethods_base_simplicial_vert __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simplicial_vert
#define __pyx_n_s_GiacMethods_base_simplifier __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simplifier
#define __pyx_n_s_GiacMethods_base_simplify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simplify
#define __pyx_n_s_GiacMethods_base_simplifyDirac __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simplifyDirac
#define __pyx_n_s_GiacMethods_base_simpson __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simpson
#define __pyx_n_s_GiacMethods_base_simulated_annea __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simulated_annea
#define __pyx_n_s_GiacMethods_base_simult __pyx_mstate_global->__pyx_n_s_GiacMethods_base_simult
#define __pyx_n_s_GiacMethods_base_sin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sin
#define __pyx_n_s_GiacMethods_base_sin2costan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sin2costan
#define __pyx_n_s_GiacMethods_base_sinc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sinc
#define __pyx_n_s_GiacMethods_base_sincos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sincos
#define __pyx_n_s_GiacMethods_base_single_inter __pyx_mstate_global->__pyx_n_s_GiacMethods_base_single_inter
#define __pyx_n_s_GiacMethods_base_sinh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sinh
#define __pyx_n_s_GiacMethods_base_sizes __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sizes
#define __pyx_n_s_GiacMethods_base_slope __pyx_mstate_global->__pyx_n_s_GiacMethods_base_slope
#define __pyx_n_s_GiacMethods_base_slopeat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_slopeat
#define __pyx_n_s_GiacMethods_base_slopeatraw __pyx_mstate_global->__pyx_n_s_GiacMethods_base_slopeatraw
#define __pyx_n_s_GiacMethods_base_smith __pyx_mstate_global->__pyx_n_s_GiacMethods_base_smith
#define __pyx_n_s_GiacMethods_base_smod __pyx_mstate_global->__pyx_n_s_GiacMethods_base_smod
#define __pyx_n_s_GiacMethods_base_snedecor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_snedecor
#define __pyx_n_s_GiacMethods_base_snedecor_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_snedecor_cdf
#define __pyx_n_s_GiacMethods_base_snedecor_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_snedecor_icdf
#define __pyx_n_s_GiacMethods_base_snedecord __pyx_mstate_global->__pyx_n_s_GiacMethods_base_snedecord
#define __pyx_n_s_GiacMethods_base_snedecord_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_snedecord_cdf
#define __pyx_n_s_GiacMethods_base_snedecord_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_snedecord_icdf
#define __pyx_n_s_GiacMethods_base_solid_line __pyx_mstate_global->__pyx_n_s_GiacMethods_base_solid_line
#define __pyx_n_s_GiacMethods_base_solve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_solve
#define __pyx_n_s_GiacMethods_base_somme __pyx_mstate_global->__pyx_n_s_GiacMethods_base_somme
#define __pyx_n_s_GiacMethods_base_sommet __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sommet
#define __pyx_n_s_GiacMethods_base_sort __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sort
#define __pyx_n_s_GiacMethods_base_sorta __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sorta
#define __pyx_n_s_GiacMethods_base_sortd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sortd
#define __pyx_n_s_GiacMethods_base_sorted __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sorted
#define __pyx_n_s_GiacMethods_base_sortperm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sortperm
#define __pyx_n_s_GiacMethods_base_soundsec __pyx_mstate_global->__pyx_n_s_GiacMethods_base_soundsec
#define __pyx_n_s_GiacMethods_base_spanning_tree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_spanning_tree
#define __pyx_n_s_GiacMethods_base_sphere __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sphere
#define __pyx_n_s_GiacMethods_base_splice __pyx_mstate_global->__pyx_n_s_GiacMethods_base_splice
#define __pyx_n_s_GiacMethods_base_spline __pyx_mstate_global->__pyx_n_s_GiacMethods_base_spline
#define __pyx_n_s_GiacMethods_base_split __pyx_mstate_global->__pyx_n_s_GiacMethods_base_split
#define __pyx_n_s_GiacMethods_base_spring __pyx_mstate_global->__pyx_n_s_GiacMethods_base_spring
#define __pyx_n_s_GiacMethods_base_sq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sq
#define __pyx_n_s_GiacMethods_base_sqrfree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sqrfree
#define __pyx_n_s_GiacMethods_base_sqrt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sqrt
#define __pyx_n_s_GiacMethods_base_square __pyx_mstate_global->__pyx_n_s_GiacMethods_base_square
#define __pyx_n_s_GiacMethods_base_square_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_square_point
#define __pyx_n_s_GiacMethods_base_srand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_srand
#define __pyx_n_s_GiacMethods_base_sst __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sst
#define __pyx_n_s_GiacMethods_base_sst_in __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sst_in
#define __pyx_n_s_GiacMethods_base_st_ordering __pyx_mstate_global->__pyx_n_s_GiacMethods_base_st_ordering
#define __pyx_n_s_GiacMethods_base_star_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_star_graph
#define __pyx_n_s_GiacMethods_base_star_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_star_point
#define __pyx_n_s_GiacMethods_base_stdDev __pyx_mstate_global->__pyx_n_s_GiacMethods_base_stdDev
#define __pyx_n_s_GiacMethods_base_stddev __pyx_mstate_global->__pyx_n_s_GiacMethods_base_stddev
#define __pyx_n_s_GiacMethods_base_stddevp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_stddevp
#define __pyx_n_s_GiacMethods_base_steffenson_solv __pyx_mstate_global->__pyx_n_s_GiacMethods_base_steffenson_solv
#define __pyx_n_s_GiacMethods_base_stereo2mono __pyx_mstate_global->__pyx_n_s_GiacMethods_base_stereo2mono
#define __pyx_n_s_GiacMethods_base_stft __pyx_mstate_global->__pyx_n_s_GiacMethods_base_stft
#define __pyx_n_s_GiacMethods_base_str __pyx_mstate_global->__pyx_n_s_GiacMethods_base_str
#define __pyx_n_s_GiacMethods_base_strip __pyx_mstate_global->__pyx_n_s_GiacMethods_base_strip
#define __pyx_n_s_GiacMethods_base_strongly_connec __pyx_mstate_global->__pyx_n_s_GiacMethods_base_strongly_connec
#define __pyx_n_s_GiacMethods_base_student __pyx_mstate_global->__pyx_n_s_GiacMethods_base_student
#define __pyx_n_s_GiacMethods_base_student_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_student_cdf
#define __pyx_n_s_GiacMethods_base_student_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_student_icdf
#define __pyx_n_s_GiacMethods_base_studentd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_studentd
#define __pyx_n_s_GiacMethods_base_studentt __pyx_mstate_global->__pyx_n_s_GiacMethods_base_studentt
#define __pyx_n_s_GiacMethods_base_sturm __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sturm
#define __pyx_n_s_GiacMethods_base_sturmab __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sturmab
#define __pyx_n_s_GiacMethods_base_sturmseq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sturmseq
#define __pyx_n_s_GiacMethods_base_style __pyx_mstate_global->__pyx_n_s_GiacMethods_base_style
#define __pyx_n_s_GiacMethods_base_subMat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subMat
#define __pyx_n_s_GiacMethods_base_subdivide_edges __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subdivide_edges
#define __pyx_n_s_GiacMethods_base_subgraph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subgraph
#define __pyx_n_s_GiacMethods_base_subs __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subs
#define __pyx_n_s_GiacMethods_base_subsop __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subsop
#define __pyx_n_s_GiacMethods_base_subst __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subst
#define __pyx_n_s_GiacMethods_base_substituer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_substituer
#define __pyx_n_s_GiacMethods_base_subtype __pyx_mstate_global->__pyx_n_s_GiacMethods_base_subtype
#define __pyx_n_s_GiacMethods_base_sum __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sum
#define __pyx_n_s_GiacMethods_base_sum_riemann __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sum_riemann
#define __pyx_n_s_GiacMethods_base_suppress __pyx_mstate_global->__pyx_n_s_GiacMethods_base_suppress
#define __pyx_n_s_GiacMethods_base_surd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_surd
#define __pyx_n_s_GiacMethods_base_svd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_svd
#define __pyx_n_s_GiacMethods_base_swapcol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_swapcol
#define __pyx_n_s_GiacMethods_base_swaprow __pyx_mstate_global->__pyx_n_s_GiacMethods_base_swaprow
#define __pyx_n_s_GiacMethods_base_switch_axes __pyx_mstate_global->__pyx_n_s_GiacMethods_base_switch_axes
#define __pyx_n_s_GiacMethods_base_sylvester __pyx_mstate_global->__pyx_n_s_GiacMethods_base_sylvester
#define __pyx_n_s_GiacMethods_base_symb2poly __pyx_mstate_global->__pyx_n_s_GiacMethods_base_symb2poly
#define __pyx_n_s_GiacMethods_base_symbol __pyx_mstate_global->__pyx_n_s_GiacMethods_base_symbol
#define __pyx_n_s_GiacMethods_base_symbol_array __pyx_mstate_global->__pyx_n_s_GiacMethods_base_symbol_array
#define __pyx_n_s_GiacMethods_base_syst2mat __pyx_mstate_global->__pyx_n_s_GiacMethods_base_syst2mat
#define __pyx_n_s_GiacMethods_base_tCollect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tCollect
#define __pyx_n_s_GiacMethods_base_tExpand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tExpand
#define __pyx_n_s_GiacMethods_base_table __pyx_mstate_global->__pyx_n_s_GiacMethods_base_table
#define __pyx_n_s_GiacMethods_base_tablefunc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tablefunc
#define __pyx_n_s_GiacMethods_base_tableseq __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tableseq
#define __pyx_n_s_GiacMethods_base_tabsign __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tabsign
#define __pyx_n_s_GiacMethods_base_tabvar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tabvar
#define __pyx_n_s_GiacMethods_base_tail __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tail
#define __pyx_n_s_GiacMethods_base_tan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tan
#define __pyx_n_s_GiacMethods_base_tan2cossin2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tan2cossin2
#define __pyx_n_s_GiacMethods_base_tan2sincos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tan2sincos
#define __pyx_n_s_GiacMethods_base_tan2sincos2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tan2sincos2
#define __pyx_n_s_GiacMethods_base_tangent __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tangent
#define __pyx_n_s_GiacMethods_base_tangente __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tangente
#define __pyx_n_s_GiacMethods_base_tanh __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tanh
#define __pyx_n_s_GiacMethods_base_tar __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tar
#define __pyx_n_s_GiacMethods_base_taux_accroissem __pyx_mstate_global->__pyx_n_s_GiacMethods_base_taux_accroissem
#define __pyx_n_s_GiacMethods_base_taylor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_taylor
#define __pyx_n_s_GiacMethods_base_tchebyshev1 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tchebyshev1
#define __pyx_n_s_GiacMethods_base_tchebyshev2 __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tchebyshev2
#define __pyx_n_s_GiacMethods_base_tcoeff __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tcoeff
#define __pyx_n_s_GiacMethods_base_tcollect __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tcollect
#define __pyx_n_s_GiacMethods_base_tdeg __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tdeg
#define __pyx_n_s_GiacMethods_base_teal __pyx_mstate_global->__pyx_n_s_GiacMethods_base_teal
#define __pyx_n_s_GiacMethods_base_tensor_product __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tensor_product
#define __pyx_n_s_GiacMethods_base_tetrahedron __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tetrahedron
#define __pyx_n_s_GiacMethods_base_texpand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_texpand
#define __pyx_n_s_GiacMethods_base_thickness __pyx_mstate_global->__pyx_n_s_GiacMethods_base_thickness
#define __pyx_n_s_GiacMethods_base_threshold __pyx_mstate_global->__pyx_n_s_GiacMethods_base_threshold
#define __pyx_n_s_GiacMethods_base_throw __pyx_mstate_global->__pyx_n_s_GiacMethods_base_throw
#define __pyx_n_s_GiacMethods_base_title __pyx_mstate_global->__pyx_n_s_GiacMethods_base_title
#define __pyx_n_s_GiacMethods_base_titre __pyx_mstate_global->__pyx_n_s_GiacMethods_base_titre
#define __pyx_n_s_GiacMethods_base_tlin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tlin
#define __pyx_n_s_GiacMethods_base_tonnetz __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tonnetz
#define __pyx_n_s_GiacMethods_base_topologic_sort __pyx_mstate_global->__pyx_n_s_GiacMethods_base_topologic_sort
#define __pyx_n_s_GiacMethods_base_topological_sor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_topological_sor
#define __pyx_n_s_GiacMethods_base_topology __pyx_mstate_global->__pyx_n_s_GiacMethods_base_topology
#define __pyx_n_s_GiacMethods_base_torus_grid_grap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_torus_grid_grap
#define __pyx_n_s_GiacMethods_base_total_degree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_total_degree
#define __pyx_n_s_GiacMethods_base_tourne_droite __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tourne_droite
#define __pyx_n_s_GiacMethods_base_tourne_gauche __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tourne_gauche
#define __pyx_n_s_GiacMethods_base_tpsolve __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tpsolve
#define __pyx_n_s_GiacMethods_base_trace __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trace
#define __pyx_n_s_GiacMethods_base_trail __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trail
#define __pyx_n_s_GiacMethods_base_trail2edges __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trail2edges
#define __pyx_n_s_GiacMethods_base_train __pyx_mstate_global->__pyx_n_s_GiacMethods_base_train
#define __pyx_n_s_GiacMethods_base_trames __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trames
#define __pyx_n_s_GiacMethods_base_tran __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tran
#define __pyx_n_s_GiacMethods_base_transitive_clos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_transitive_clos
#define __pyx_n_s_GiacMethods_base_translation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_translation
#define __pyx_n_s_GiacMethods_base_transpose __pyx_mstate_global->__pyx_n_s_GiacMethods_base_transpose
#define __pyx_n_s_GiacMethods_base_trapeze __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trapeze
#define __pyx_n_s_GiacMethods_base_trapezoid __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trapezoid
#define __pyx_n_s_GiacMethods_base_traveling_sales __pyx_mstate_global->__pyx_n_s_GiacMethods_base_traveling_sales
#define __pyx_n_s_GiacMethods_base_tree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tree
#define __pyx_n_s_GiacMethods_base_tree_height __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tree_height
#define __pyx_n_s_GiacMethods_base_tri __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tri
#define __pyx_n_s_GiacMethods_base_triangle __pyx_mstate_global->__pyx_n_s_GiacMethods_base_triangle
#define __pyx_n_s_GiacMethods_base_triangle_paper __pyx_mstate_global->__pyx_n_s_GiacMethods_base_triangle_paper
#define __pyx_n_s_GiacMethods_base_triangle_plein __pyx_mstate_global->__pyx_n_s_GiacMethods_base_triangle_plein
#define __pyx_n_s_GiacMethods_base_triangle_point __pyx_mstate_global->__pyx_n_s_GiacMethods_base_triangle_point
#define __pyx_n_s_GiacMethods_base_triangle_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_triangle_window
#define __pyx_n_s_GiacMethods_base_trig2exp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trig2exp
#define __pyx_n_s_GiacMethods_base_trigcos __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trigcos
#define __pyx_n_s_GiacMethods_base_trigexpand __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trigexpand
#define __pyx_n_s_GiacMethods_base_triginterp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_triginterp
#define __pyx_n_s_GiacMethods_base_trigsimplify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trigsimplify
#define __pyx_n_s_GiacMethods_base_trigsin __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trigsin
#define __pyx_n_s_GiacMethods_base_trigtan __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trigtan
#define __pyx_n_s_GiacMethods_base_trim __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trim
#define __pyx_n_s_GiacMethods_base_trn __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trn
#define __pyx_n_s_GiacMethods_base_true __pyx_mstate_global->__pyx_n_s_GiacMethods_base_true
#define __pyx_n_s_GiacMethods_base_trunc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_trunc
#define __pyx_n_s_GiacMethods_base_truncate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_truncate
#define __pyx_n_s_GiacMethods_base_truncate_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_truncate_graph
#define __pyx_n_s_GiacMethods_base_tsimplify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tsimplify
#define __pyx_n_s_GiacMethods_base_tstep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tstep
#define __pyx_n_s_GiacMethods_base_tuer __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tuer
#define __pyx_n_s_GiacMethods_base_tukey_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tukey_window
#define __pyx_n_s_GiacMethods_base_tutte_polynomia __pyx_mstate_global->__pyx_n_s_GiacMethods_base_tutte_polynomia
#define __pyx_n_s_GiacMethods_base_two_edge_connec __pyx_mstate_global->__pyx_n_s_GiacMethods_base_two_edge_connec
#define __pyx_n_s_GiacMethods_base_type __pyx_mstate_global->__pyx_n_s_GiacMethods_base_type
#define __pyx_n_s_GiacMethods_base_ufactor __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ufactor
#define __pyx_n_s_GiacMethods_base_ugamma __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ugamma
#define __pyx_n_s_GiacMethods_base_unapply __pyx_mstate_global->__pyx_n_s_GiacMethods_base_unapply
#define __pyx_n_s_GiacMethods_base_unarchive __pyx_mstate_global->__pyx_n_s_GiacMethods_base_unarchive
#define __pyx_n_s_GiacMethods_base_undef __pyx_mstate_global->__pyx_n_s_GiacMethods_base_undef
#define __pyx_n_s_GiacMethods_base_underlying_grap __pyx_mstate_global->__pyx_n_s_GiacMethods_base_underlying_grap
#define __pyx_n_s_GiacMethods_base_unfactored __pyx_mstate_global->__pyx_n_s_GiacMethods_base_unfactored
#define __pyx_n_s_GiacMethods_base_uniform __pyx_mstate_global->__pyx_n_s_GiacMethods_base_uniform
#define __pyx_n_s_GiacMethods_base_uniform_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_uniform_cdf
#define __pyx_n_s_GiacMethods_base_uniform_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_uniform_icdf
#define __pyx_n_s_GiacMethods_base_uniformd __pyx_mstate_global->__pyx_n_s_GiacMethods_base_uniformd
#define __pyx_n_s_GiacMethods_base_uniformd_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_uniformd_cdf
#define __pyx_n_s_GiacMethods_base_uniformd_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_uniformd_icdf
#define __pyx_n_s_GiacMethods_base_unitV __pyx_mstate_global->__pyx_n_s_GiacMethods_base_unitV
#define __pyx_n_s_GiacMethods_base_unquote __pyx_mstate_global->__pyx_n_s_GiacMethods_base_unquote
#define __pyx_n_s_GiacMethods_base_upper __pyx_mstate_global->__pyx_n_s_GiacMethods_base_upper
#define __pyx_n_s_GiacMethods_base_user_operator __pyx_mstate_global->__pyx_n_s_GiacMethods_base_user_operator
#define __pyx_n_s_GiacMethods_base_usimplify __pyx_mstate_global->__pyx_n_s_GiacMethods_base_usimplify
#define __pyx_n_s_GiacMethods_base_ustep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ustep
#define __pyx_n_s_GiacMethods_base_valuation __pyx_mstate_global->__pyx_n_s_GiacMethods_base_valuation
#define __pyx_n_s_GiacMethods_base_vandermonde __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vandermonde
#define __pyx_n_s_GiacMethods_base_variables_are_f __pyx_mstate_global->__pyx_n_s_GiacMethods_base_variables_are_f
#define __pyx_n_s_GiacMethods_base_variance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_variance
#define __pyx_n_s_GiacMethods_base_version __pyx_mstate_global->__pyx_n_s_GiacMethods_base_version
#define __pyx_n_s_GiacMethods_base_vertex_connecti __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertex_connecti
#define __pyx_n_s_GiacMethods_base_vertex_cover_nu __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertex_cover_nu
#define __pyx_n_s_GiacMethods_base_vertex_degree __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertex_degree
#define __pyx_n_s_GiacMethods_base_vertex_distance __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertex_distance
#define __pyx_n_s_GiacMethods_base_vertex_in_degre __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertex_in_degre
#define __pyx_n_s_GiacMethods_base_vertex_out_degr __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertex_out_degr
#define __pyx_n_s_GiacMethods_base_vertices __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertices
#define __pyx_n_s_GiacMethods_base_vertices_abc __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertices_abc
#define __pyx_n_s_GiacMethods_base_vertices_abca __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vertices_abca
#define __pyx_n_s_GiacMethods_base_violet __pyx_mstate_global->__pyx_n_s_GiacMethods_base_violet
#define __pyx_n_s_GiacMethods_base_vpotential __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vpotential
#define __pyx_n_s_GiacMethods_base_vstep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_vstep
#define __pyx_n_s_GiacMethods_base_web_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_web_graph
#define __pyx_n_s_GiacMethods_base_weibull __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibull
#define __pyx_n_s_GiacMethods_base_weibull_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibull_cdf
#define __pyx_n_s_GiacMethods_base_weibull_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibull_icdf
#define __pyx_n_s_GiacMethods_base_weibulld __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibulld
#define __pyx_n_s_GiacMethods_base_weibulld_cdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibulld_cdf
#define __pyx_n_s_GiacMethods_base_weibulld_icdf __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibulld_icdf
#define __pyx_n_s_GiacMethods_base_weibullvariate __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weibullvariate
#define __pyx_n_s_GiacMethods_base_weight_decay __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weight_decay
#define __pyx_n_s_GiacMethods_base_weight_matrix __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weight_matrix
#define __pyx_n_s_GiacMethods_base_weighted __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weighted
#define __pyx_n_s_GiacMethods_base_weights __pyx_mstate_global->__pyx_n_s_GiacMethods_base_weights
#define __pyx_n_s_GiacMethods_base_welch_window __pyx_mstate_global->__pyx_n_s_GiacMethods_base_welch_window
#define __pyx_n_s_GiacMethods_base_wheel_graph __pyx_mstate_global->__pyx_n_s_GiacMethods_base_wheel_graph
#define __pyx_n_s_GiacMethods_base_widget_size __pyx_mstate_global->__pyx_n_s_GiacMethods_base_widget_size
#define __pyx_n_s_GiacMethods_base_wilcoxonp __pyx_mstate_global->__pyx_n_s_GiacMethods_base_wilcoxonp
#define __pyx_n_s_GiacMethods_base_wilcoxons __pyx_mstate_global->__pyx_n_s_GiacMethods_base_wilcoxons
#define __pyx_n_s_GiacMethods_base_wilcoxont __pyx_mstate_global->__pyx_n_s_GiacMethods_base_wilcoxont
#define __pyx_n_s_GiacMethods_base_writergb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_writergb
#define __pyx_n_s_GiacMethods_base_writewav __pyx_mstate_global->__pyx_n_s_GiacMethods_base_writewav
#define __pyx_n_s_GiacMethods_base_xcas_mode __pyx_mstate_global->__pyx_n_s_GiacMethods_base_xcas_mode
#define __pyx_n_s_GiacMethods_base_xml_print __pyx_mstate_global->__pyx_n_s_GiacMethods_base_xml_print
#define __pyx_n_s_GiacMethods_base_xstep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_xstep
#define __pyx_n_s_GiacMethods_base_xyz2rgb __pyx_mstate_global->__pyx_n_s_GiacMethods_base_xyz2rgb
#define __pyx_n_s_GiacMethods_base_xyztrange __pyx_mstate_global->__pyx_n_s_GiacMethods_base_xyztrange
#define __pyx_n_s_GiacMethods_base_ystep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ystep
#define __pyx_n_s_GiacMethods_base_zeros __pyx_mstate_global->__pyx_n_s_GiacMethods_base_zeros
#define __pyx_n_s_GiacMethods_base_zip __pyx_mstate_global->__pyx_n_s_GiacMethods_base_zip
#define __pyx_n_s_GiacMethods_base_znorder __pyx_mstate_global->__pyx_n_s_GiacMethods_base_znorder
#define __pyx_n_s_GiacMethods_base_znprimroot __pyx_mstate_global->__pyx_n_s_GiacMethods_base_znprimroot
#define __pyx_n_s_GiacMethods_base_zstep __pyx_mstate_global->__pyx_n_s_GiacMethods_base_zstep
#define __pyx_n_s_GiacMethods_base_ztrans __pyx_mstate_global->__pyx_n_s_GiacMethods_base_ztrans
#define __pyx_n_s_GiacSetting __pyx_mstate_global->__pyx_n_s_GiacSetting
#define __pyx_n_s_GiacSetting___reduce_cython __pyx_mstate_global->__pyx_n_s_GiacSetting___reduce_cython
#define __pyx_n_s_GiacSetting___setstate_cython __pyx_mstate_global->__pyx_n_s_GiacSetting___setstate_cython
#define __pyx_kp_s_Giac_Settings __pyx_mstate_global->__pyx_kp_s_Giac_Settings
#define __pyx_n_s_Graph __pyx_mstate_global->__pyx_n_s_Graph
#define __pyx_n_s_Gy __pyx_mstate_global->__pyx_n_s_Gy
#define __pyx_n_s_H __pyx_mstate_global->__pyx_n_s_H
#define __pyx_n_s_Heaviside __pyx_mstate_global->__pyx_n_s_Heaviside
#define __pyx_n_s_Heaviside2sign __pyx_mstate_global->__pyx_n_s_Heaviside2sign
#define __pyx_n_s_Hilbert __pyx_mstate_global->__pyx_n_s_Hilbert
#define __pyx_n_s_Hz __pyx_mstate_global->__pyx_n_s_Hz
#define __pyx_n_s_I __pyx_mstate_global->__pyx_n_s_I
#define __pyx_n_s_I0 __pyx_mstate_global->__pyx_n_s_I0
#define __pyx_n_s_IFTE __pyx_mstate_global->__pyx_n_s_IFTE
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_kp_u_Increase_the_size_of_a_matrix_w __pyx_mstate_global->__pyx_kp_u_Increase_the_size_of_a_matrix_w
#define __pyx_n_s_IndexError __pyx_mstate_global->__pyx_n_s_IndexError
#define __pyx_n_s_Input __pyx_mstate_global->__pyx_n_s_Input
#define __pyx_n_s_InputStr __pyx_mstate_global->__pyx_n_s_InputStr
#define __pyx_n_s_Int __pyx_mstate_global->__pyx_n_s_Int
#define __pyx_kp_s_Interrupted_by_a_ctrl_c_event __pyx_mstate_global->__pyx_kp_s_Interrupted_by_a_ctrl_c_event
#define __pyx_n_s_Inverse __pyx_mstate_global->__pyx_n_s_Inverse
#define __pyx_n_s_J __pyx_mstate_global->__pyx_n_s_J
#define __pyx_n_s_JordanBlock __pyx_mstate_global->__pyx_n_s_JordanBlock
#define __pyx_n_s_K __pyx_mstate_global->__pyx_n_s_K
#define __pyx_n_s_Kcal __pyx_mstate_global->__pyx_n_s_Kcal
#define __pyx_n_s_KeyboardInterrupt __pyx_mstate_global->__pyx_n_s_KeyboardInterrupt
#define __pyx_n_s_LN __pyx_mstate_global->__pyx_n_s_LN
#define __pyx_n_s_LQ __pyx_mstate_global->__pyx_n_s_LQ
#define __pyx_n_s_LSQ __pyx_mstate_global->__pyx_n_s_LSQ
#define __pyx_n_s_LU __pyx_mstate_global->__pyx_n_s_LU
#define __pyx_n_s_LambertW __pyx_mstate_global->__pyx_n_s_LambertW
#define __pyx_n_s_Li __pyx_mstate_global->__pyx_n_s_Li
#define __pyx_n_s_Line __pyx_mstate_global->__pyx_n_s_Line
#define __pyx_n_s_LineHorz __pyx_mstate_global->__pyx_n_s_LineHorz
#define __pyx_n_s_LineTan __pyx_mstate_global->__pyx_n_s_LineTan
#define __pyx_n_s_LineVert __pyx_mstate_global->__pyx_n_s_LineVert
#define __pyx_kp_u_Lists_of_10_6_integers_should_b __pyx_mstate_global->__pyx_kp_u_Lists_of_10_6_integers_should_b
#define __pyx_n_s_MHz __pyx_mstate_global->__pyx_n_s_MHz
#define __pyx_n_s_MSE __pyx_mstate_global->__pyx_n_s_MSE
#define __pyx_n_s_MW __pyx_mstate_global->__pyx_n_s_MW
#define __pyx_n_s_MeV __pyx_mstate_global->__pyx_n_s_MeV
#define __pyx_n_s_N __pyx_mstate_global->__pyx_n_s_N
#define __pyx_n_s_NA __pyx_mstate_global->__pyx_n_s_NA
#define __pyx_n_s_NORMALD __pyx_mstate_global->__pyx_n_s_NORMALD
#define __pyx_n_s_NULL __pyx_mstate_global->__pyx_n_s_NULL
#define __pyx_n_s_NewFold __pyx_mstate_global->__pyx_n_s_NewFold
#define __pyx_n_s_NewPic __pyx_mstate_global->__pyx_n_s_NewPic
#define __pyx_n_s_Nullspace __pyx_mstate_global->__pyx_n_s_Nullspace
#define __pyx_n_s_Ohm __pyx_mstate_global->__pyx_n_s_Ohm
#define __pyx_kp_u_Open_a_file_in_giac_compressed __pyx_mstate_global->__pyx_kp_u_Open_a_file_in_giac_compressed
#define __pyx_kp_u_Open_the_giac_html_detailled_he __pyx_mstate_global->__pyx_kp_u_Open_the_giac_html_detailled_he
#define __pyx_kp_u_Open_the_giac_html_detailled_he_2 __pyx_mstate_global->__pyx_kp_u_Open_the_giac_html_detailled_he_2
#define __pyx_n_s_Output __pyx_mstate_global->__pyx_n_s_Output
#define __pyx_n_s_Ox_2d_unit_vector __pyx_mstate_global->__pyx_n_s_Ox_2d_unit_vector
#define __pyx_n_s_Ox_3d_unit_vector __pyx_mstate_global->__pyx_n_s_Ox_3d_unit_vector
#define __pyx_n_s_Oy_2d_unit_vector __pyx_mstate_global->__pyx_n_s_Oy_2d_unit_vector
#define __pyx_n_s_Oy_3d_unit_vector __pyx_mstate_global->__pyx_n_s_Oy_3d_unit_vector
#define __pyx_n_s_Oz_3d_unit_vector __pyx_mstate_global->__pyx_n_s_Oz_3d_unit_vector
#define __pyx_n_s_P __pyx_mstate_global->__pyx_n_s_P
#define __pyx_n_s_PSun __pyx_mstate_global->__pyx_n_s_PSun
#define __pyx_n_s_Pa __pyx_mstate_global->__pyx_n_s_Pa
#define __pyx_n_s_Pause __pyx_mstate_global->__pyx_n_s_Pause
#define __pyx_n_s_Phi __pyx_mstate_global->__pyx_n_s_Phi
#define __pyx_n_s_Pi __pyx_mstate_global->__pyx_n_s_Pi
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_s_PopUp __pyx_mstate_global->__pyx_n_s_PopUp
#define __pyx_n_s_Psi __pyx_mstate_global->__pyx_n_s_Psi
#define __pyx_n_s_Pygen __pyx_mstate_global->__pyx_n_s_Pygen
#define __pyx_kp_u_Pygen___float___line_1078 __pyx_mstate_global->__pyx_kp_u_Pygen___float___line_1078
#define __pyx_kp_u_Pygen___getitem___line_913 __pyx_mstate_global->__pyx_kp_u_Pygen___getitem___line_913
#define __pyx_kp_u_Pygen___int___line_1059 __pyx_mstate_global->__pyx_kp_u_Pygen___int___line_1059
#define __pyx_n_s_Pygen___iter __pyx_mstate_global->__pyx_n_s_Pygen___iter
#define __pyx_kp_u_Pygen___iter___line_1035 __pyx_mstate_global->__pyx_kp_u_Pygen___iter___line_1035
#define __pyx_kp_u_Pygen___radd___line_1192 __pyx_mstate_global->__pyx_kp_u_Pygen___radd___line_1192
#define __pyx_n_s_Pygen___reduce_cython __pyx_mstate_global->__pyx_n_s_Pygen___reduce_cython
#define __pyx_kp_u_Pygen___repr___line_877 __pyx_mstate_global->__pyx_kp_u_Pygen___repr___line_877
#define __pyx_kp_u_Pygen___rmod___line_1410 __pyx_mstate_global->__pyx_kp_u_Pygen___rmod___line_1410
#define __pyx_kp_u_Pygen___rmul___line_1286 __pyx_mstate_global->__pyx_kp_u_Pygen___rmul___line_1286
#define __pyx_kp_u_Pygen___rpow___line_1372 __pyx_mstate_global->__pyx_kp_u_Pygen___rpow___line_1372
#define __pyx_kp_u_Pygen___rsub___line_1248 __pyx_mstate_global->__pyx_kp_u_Pygen___rsub___line_1248
#define __pyx_kp_u_Pygen___rtruediv___line_1337 __pyx_mstate_global->__pyx_kp_u_Pygen___rtruediv___line_1337
#define __pyx_kp_u_Pygen___setitem___line_986 __pyx_mstate_global->__pyx_kp_u_Pygen___setitem___line_986
#define __pyx_n_s_Pygen___setstate_cython __pyx_mstate_global->__pyx_n_s_Pygen___setstate_cython
#define __pyx_n_s_Pygen__repr_html __pyx_mstate_global->__pyx_n_s_Pygen__repr_html
#define __pyx_n_s_Pygen__repr_latex __pyx_mstate_global->__pyx_n_s_Pygen__repr_latex
#define __pyx_n_s_Pygen_cas_setup __pyx_mstate_global->__pyx_n_s_Pygen_cas_setup
#define __pyx_n_s_Pygen_eval __pyx_mstate_global->__pyx_n_s_Pygen_eval
#define __pyx_n_s_Pygen_help __pyx_mstate_global->__pyx_n_s_Pygen_help
#define __pyx_n_s_Pygen_htmlhelp __pyx_mstate_global->__pyx_n_s_Pygen_htmlhelp
#define __pyx_kp_u_Pygen_htmlhelp_line_1498 __pyx_mstate_global->__pyx_kp_u_Pygen_htmlhelp_line_1498
#define __pyx_kp_u_Pygen_lists_of_10_6_elements_sh __pyx_mstate_global->__pyx_kp_u_Pygen_lists_of_10_6_elements_sh
#define __pyx_n_s_Pygen_qcas __pyx_mstate_global->__pyx_n_s_Pygen_qcas
#define __pyx_kp_u_Pygen_qcas_line_1552 __pyx_mstate_global->__pyx_kp_u_Pygen_qcas_line_1552
#define __pyx_n_s_Pygen_redim __pyx_mstate_global->__pyx_n_s_Pygen_redim
#define __pyx_kp_u_Pygen_redim_line_1526 __pyx_mstate_global->__pyx_kp_u_Pygen_redim_line_1526
#define __pyx_n_s_Pygen_save __pyx_mstate_global->__pyx_n_s_Pygen_save
#define __pyx_kp_u_Pygen_save_line_1469 __pyx_mstate_global->__pyx_kp_u_Pygen_save_line_1469
#define __pyx_n_s_Pygen_threadeval __pyx_mstate_global->__pyx_n_s_Pygen_threadeval
#define __pyx_n_s_Pymaxint __pyx_mstate_global->__pyx_n_s_Pymaxint
#define __pyx_n_s_PythonVersion3 __pyx_mstate_global->__pyx_n_s_PythonVersion3
#define __pyx_n_s_Pyversioninfo __pyx_mstate_global->__pyx_n_s_Pyversioninfo
#define __pyx_n_s_QR __pyx_mstate_global->__pyx_n_s_QR
#define __pyx_n_s_Quo __pyx_mstate_global->__pyx_n_s_Quo
#define __pyx_n_s_R __pyx_mstate_global->__pyx_n_s_R
#define __pyx_n_s_REDIM __pyx_mstate_global->__pyx_n_s_REDIM
#define __pyx_n_s_REPLACE __pyx_mstate_global->__pyx_n_s_REPLACE
#define __pyx_n_s_REarth __pyx_mstate_global->__pyx_n_s_REarth
#define __pyx_n_s_RSun __pyx_mstate_global->__pyx_n_s_RSun
#define __pyx_n_s_R_2 __pyx_mstate_global->__pyx_n_s_R_2
#define __pyx_n_s_RandSeed __pyx_mstate_global->__pyx_n_s_RandSeed
#define __pyx_n_s_Rankine __pyx_mstate_global->__pyx_n_s_Rankine
#define __pyx_n_s_RclPic __pyx_mstate_global->__pyx_n_s_RclPic
#define __pyx_n_s_ReLU __pyx_mstate_global->__pyx_n_s_ReLU
#define __pyx_n_s_Rem __pyx_mstate_global->__pyx_n_s_Rem
#define __pyx_n_s_Request __pyx_mstate_global->__pyx_n_s_Request
#define __pyx_kp_s_Result_is_too_big_for_Display_I __pyx_mstate_global->__pyx_kp_s_Result_is_too_big_for_Display_I
#define __pyx_n_s_Resultant __pyx_mstate_global->__pyx_n_s_Resultant
#define __pyx_kp_u_Reverse_operator_7_giac_3_Calle __pyx_mstate_global->__pyx_kp_u_Reverse_operator_7_giac_3_Calle
#define __pyx_kp_u_Reverse_operator_d_giac_d_1_d_C __pyx_mstate_global->__pyx_kp_u_Reverse_operator_d_giac_d_1_d_C
#define __pyx_kp_u_Reverse_operator_d_giac_d_2_d_C __pyx_mstate_global->__pyx_kp_u_Reverse_operator_d_giac_d_2_d_C
#define __pyx_kp_u_Reverse_operator_d_giac_d_7_d_C __pyx_mstate_global->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C
#define __pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2 __pyx_mstate_global->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2
#define __pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3 __pyx_mstate_global->__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3
#define __pyx_n_s_Rinfinity __pyx_mstate_global->__pyx_n_s_Rinfinity
#define __pyx_n_s_Row __pyx_mstate_global->__pyx_n_s_Row
#define __pyx_n_s_RplcPic __pyx_mstate_global->__pyx_n_s_RplcPic
#define __pyx_n_s_Rref __pyx_mstate_global->__pyx_n_s_Rref
#define __pyx_n_s_RuntimeError __pyx_mstate_global->__pyx_n_s_RuntimeError
#define __pyx_n_s_S __pyx_mstate_global->__pyx_n_s_S
#define __pyx_n_s_SCALE __pyx_mstate_global->__pyx_n_s_SCALE
#define __pyx_n_s_SCALEADD __pyx_mstate_global->__pyx_n_s_SCALEADD
#define __pyx_n_s_SCHUR __pyx_mstate_global->__pyx_n_s_SCHUR
#define __pyx_n_s_SIN __pyx_mstate_global->__pyx_n_s_SIN
#define __pyx_n_s_SVD __pyx_mstate_global->__pyx_n_s_SVD
#define __pyx_n_s_SVL __pyx_mstate_global->__pyx_n_s_SVL
#define __pyx_n_s_SWAPCOL __pyx_mstate_global->__pyx_n_s_SWAPCOL
#define __pyx_n_s_SWAPROW __pyx_mstate_global->__pyx_n_s_SWAPROW
#define __pyx_kp_u_Send_a_giac_graphic_to_qcas_3D __pyx_mstate_global->__pyx_kp_u_Send_a_giac_graphic_to_qcas_3D
#define __pyx_n_s_SetFold __pyx_mstate_global->__pyx_n_s_SetFold
#define __pyx_kp_u_Set_the_value_of_a_coefficient __pyx_mstate_global->__pyx_kp_u_Set_the_value_of_a_coefficient
#define __pyx_n_s_Si __pyx_mstate_global->__pyx_n_s_Si
#define __pyx_n_s_SortA __pyx_mstate_global->__pyx_n_s_SortA
#define __pyx_n_s_SortD __pyx_mstate_global->__pyx_n_s_SortD
#define __pyx_n_s_St __pyx_mstate_global->__pyx_n_s_St
#define __pyx_n_s_StdP __pyx_mstate_global->__pyx_n_s_StdP
#define __pyx_n_s_StdT __pyx_mstate_global->__pyx_n_s_StdT
#define __pyx_n_s_StoPic __pyx_mstate_global->__pyx_n_s_StoPic
#define __pyx_n_s_Store __pyx_mstate_global->__pyx_n_s_Store
#define __pyx_n_s_Sv __pyx_mstate_global->__pyx_n_s_Sv
#define __pyx_n_s_T __pyx_mstate_global->__pyx_n_s_T
#define __pyx_n_s_TAN __pyx_mstate_global->__pyx_n_s_TAN
#define __pyx_n_s_TRUE __pyx_mstate_global->__pyx_n_s_TRUE
#define __pyx_n_s_TeX __pyx_mstate_global->__pyx_n_s_TeX
#define __pyx_n_s_Text __pyx_mstate_global->__pyx_n_s_Text
#define __pyx_kp_u_This_function_evaluate_a_python __pyx_mstate_global->__pyx_kp_u_This_function_evaluate_a_python
#define __pyx_n_s_ThreadedPygen __pyx_mstate_global->__pyx_n_s_ThreadedPygen
#define __pyx_n_s_ThreadedPygen___call __pyx_mstate_global->__pyx_n_s_ThreadedPygen___call
#define __pyx_n_s_Title __pyx_mstate_global->__pyx_n_s_Title
#define __pyx_n_s_True __pyx_mstate_global->__pyx_n_s_True
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_kp_s_UTF_8 __pyx_mstate_global->__pyx_kp_s_UTF_8
#define __pyx_n_s_UTPC __pyx_mstate_global->__pyx_n_s_UTPC
#define __pyx_n_s_UTPF __pyx_mstate_global->__pyx_n_s_UTPF
#define __pyx_n_s_UTPN __pyx_mstate_global->__pyx_n_s_UTPN
#define __pyx_n_s_UTPT __pyx_mstate_global->__pyx_n_s_UTPT
#define __pyx_n_s_Unarchiv __pyx_mstate_global->__pyx_n_s_Unarchiv
#define __pyx_kp_s_Use_this_subclass_of_to_call_yo __pyx_mstate_global->__pyx_kp_s_Use_this_subclass_of_to_call_yo
#define __pyx_n_s_V __pyx_mstate_global->__pyx_n_s_V
#define __pyx_n_s_VARS __pyx_mstate_global->__pyx_n_s_VARS
#define __pyx_n_s_VAS __pyx_mstate_global->__pyx_n_s_VAS
#define __pyx_n_s_VAS_positive __pyx_mstate_global->__pyx_n_s_VAS_positive
#define __pyx_n_s_Vm __pyx_mstate_global->__pyx_n_s_Vm
#define __pyx_n_s_W __pyx_mstate_global->__pyx_n_s_W
#define __pyx_n_s_WAIT __pyx_mstate_global->__pyx_n_s_WAIT
#define __pyx_n_s_Wb __pyx_mstate_global->__pyx_n_s_Wb
#define __pyx_n_s_Wh __pyx_mstate_global->__pyx_n_s_Wh
#define __pyx_n_s_Zeta __pyx_mstate_global->__pyx_n_s_Zeta
#define __pyx_kp_s__10 __pyx_mstate_global->__pyx_kp_s__10
#define __pyx_kp_s__12 __pyx_mstate_global->__pyx_kp_s__12
#define __pyx_n_s__14 __pyx_mstate_global->__pyx_n_s__14
#define __pyx_kp_s__1655 __pyx_mstate_global->__pyx_kp_s__1655
#define __pyx_kp_s__1656 __pyx_mstate_global->__pyx_kp_s__1656
#define __pyx_kp_s__1657 __pyx_mstate_global->__pyx_kp_s__1657
#define __pyx_kp_s__1658 __pyx_mstate_global->__pyx_kp_s__1658
#define __pyx_kp_s__1659 __pyx_mstate_global->__pyx_kp_s__1659
#define __pyx_kp_s__1660 __pyx_mstate_global->__pyx_kp_s__1660
#define __pyx_kp_s__1661 __pyx_mstate_global->__pyx_kp_s__1661
#define __pyx_kp_s__1662 __pyx_mstate_global->__pyx_kp_s__1662
#define __pyx_kp_s__1663 __pyx_mstate_global->__pyx_kp_s__1663
#define __pyx_kp_s__1664 __pyx_mstate_global->__pyx_kp_s__1664
#define __pyx_kp_s__1665 __pyx_mstate_global->__pyx_kp_s__1665
#define __pyx_kp_s__1666 __pyx_mstate_global->__pyx_kp_s__1666
#define __pyx_kp_s__1667 __pyx_mstate_global->__pyx_kp_s__1667
#define __pyx_kp_s__1668 __pyx_mstate_global->__pyx_kp_s__1668
#define __pyx_kp_s__1669 __pyx_mstate_global->__pyx_kp_s__1669
#define __pyx_kp_s__1670 __pyx_mstate_global->__pyx_kp_s__1670
#define __pyx_kp_s__1671 __pyx_mstate_global->__pyx_kp_s__1671
#define __pyx_kp_s__1672 __pyx_mstate_global->__pyx_kp_s__1672
#define __pyx_kp_s__1673 __pyx_mstate_global->__pyx_kp_s__1673
#define __pyx_kp_s__1674 __pyx_mstate_global->__pyx_kp_s__1674
#define __pyx_kp_s__1675 __pyx_mstate_global->__pyx_kp_s__1675
#define __pyx_kp_s__1676 __pyx_mstate_global->__pyx_kp_s__1676
#define __pyx_kp_s__1677 __pyx_mstate_global->__pyx_kp_s__1677
#define __pyx_kp_s__1678 __pyx_mstate_global->__pyx_kp_s__1678
#define __pyx_kp_s__1679 __pyx_mstate_global->__pyx_kp_s__1679
#define __pyx_kp_s__1680 __pyx_mstate_global->__pyx_kp_s__1680
#define __pyx_kp_s__1681 __pyx_mstate_global->__pyx_kp_s__1681
#define __pyx_kp_s__1682 __pyx_mstate_global->__pyx_kp_s__1682
#define __pyx_kp_s__1683 __pyx_mstate_global->__pyx_kp_s__1683
#define __pyx_kp_s__1684 __pyx_mstate_global->__pyx_kp_s__1684
#define __pyx_kp_s__1685 __pyx_mstate_global->__pyx_kp_s__1685
#define __pyx_kp_s__1686 __pyx_mstate_global->__pyx_kp_s__1686
#define __pyx_kp_s__1687 __pyx_mstate_global->__pyx_kp_s__1687
#define __pyx_kp_s__1688 __pyx_mstate_global->__pyx_kp_s__1688
#define __pyx_kp_s__1689 __pyx_mstate_global->__pyx_kp_s__1689
#define __pyx_kp_s__1690 __pyx_mstate_global->__pyx_kp_s__1690
#define __pyx_kp_s__1691 __pyx_mstate_global->__pyx_kp_s__1691
#define __pyx_kp_s__1692 __pyx_mstate_global->__pyx_kp_s__1692
#define __pyx_kp_s__1693 __pyx_mstate_global->__pyx_kp_s__1693
#define __pyx_kp_s__1694 __pyx_mstate_global->__pyx_kp_s__1694
#define __pyx_kp_s__1695 __pyx_mstate_global->__pyx_kp_s__1695
#define __pyx_kp_s__1696 __pyx_mstate_global->__pyx_kp_s__1696
#define __pyx_kp_s__1697 __pyx_mstate_global->__pyx_kp_s__1697
#define __pyx_kp_s__1698 __pyx_mstate_global->__pyx_kp_s__1698
#define __pyx_kp_s__1699 __pyx_mstate_global->__pyx_kp_s__1699
#define __pyx_kp_s__1700 __pyx_mstate_global->__pyx_kp_s__1700
#define __pyx_kp_u__8 __pyx_mstate_global->__pyx_kp_u__8
#define __pyx_n_s_a __pyx_mstate_global->__pyx_n_s_a
#define __pyx_n_s_a0 __pyx_mstate_global->__pyx_n_s_a0
#define __pyx_n_s_a2q __pyx_mstate_global->__pyx_n_s_a2q
#define __pyx_n_s_a_2 __pyx_mstate_global->__pyx_n_s_a_2
#define __pyx_n_s_abcuv __pyx_mstate_global->__pyx_n_s_abcuv
#define __pyx_n_s_about __pyx_mstate_global->__pyx_n_s_about
#define __pyx_n_s_abs __pyx_mstate_global->__pyx_n_s_abs
#define __pyx_n_s_abscissa __pyx_mstate_global->__pyx_n_s_abscissa
#define __pyx_n_s_access __pyx_mstate_global->__pyx_n_s_access
#define __pyx_n_s_accumulate_head_tail __pyx_mstate_global->__pyx_n_s_accumulate_head_tail
#define __pyx_n_s_acos __pyx_mstate_global->__pyx_n_s_acos
#define __pyx_n_s_acos2asin __pyx_mstate_global->__pyx_n_s_acos2asin
#define __pyx_n_s_acos2atan __pyx_mstate_global->__pyx_n_s_acos2atan
#define __pyx_n_s_acosh __pyx_mstate_global->__pyx_n_s_acosh
#define __pyx_n_s_acot __pyx_mstate_global->__pyx_n_s_acot
#define __pyx_n_s_acre __pyx_mstate_global->__pyx_n_s_acre
#define __pyx_n_s_acsc __pyx_mstate_global->__pyx_n_s_acsc
#define __pyx_n_s_acyclic __pyx_mstate_global->__pyx_n_s_acyclic
#define __pyx_n_s_adaptive __pyx_mstate_global->__pyx_n_s_adaptive
#define __pyx_n_s_add __pyx_mstate_global->__pyx_n_s_add
#define __pyx_n_s_add_2 __pyx_mstate_global->__pyx_n_s_add_2
#define __pyx_n_s_add_arc __pyx_mstate_global->__pyx_n_s_add_arc
#define __pyx_n_s_add_edge __pyx_mstate_global->__pyx_n_s_add_edge
#define __pyx_kp_s_add_language_1 __pyx_mstate_global->__pyx_kp_s_add_language_1
#define __pyx_n_s_add_vertex __pyx_mstate_global->__pyx_n_s_add_vertex
#define __pyx_n_s_additionally __pyx_mstate_global->__pyx_n_s_additionally
#define __pyx_n_s_addtable __pyx_mstate_global->__pyx_n_s_addtable
#define __pyx_n_s_adjacency_matrix __pyx_mstate_global->__pyx_n_s_adjacency_matrix
#define __pyx_n_s_adjoint_matrix __pyx_mstate_global->__pyx_n_s_adjoint_matrix
#define __pyx_n_s_affichage __pyx_mstate_global->__pyx_n_s_affichage
#define __pyx_n_s_affix __pyx_mstate_global->__pyx_n_s_affix
#define __pyx_n_s_algsubs __pyx_mstate_global->__pyx_n_s_algsubs
#define __pyx_n_s_algvar __pyx_mstate_global->__pyx_n_s_algvar
#define __pyx_n_s_all __pyx_mstate_global->__pyx_n_s_all
#define __pyx_n_s_all_trig_solutions __pyx_mstate_global->__pyx_n_s_all_trig_solutions
#define __pyx_n_s_allpairs_distance __pyx_mstate_global->__pyx_n_s_allpairs_distance
#define __pyx_n_s_alog10 __pyx_mstate_global->__pyx_n_s_alog10
#define __pyx_n_s_alors __pyx_mstate_global->__pyx_n_s_alors
#define __pyx_n_s_alpha __pyx_mstate_global->__pyx_n_s_alpha
#define __pyx_n_s_altitude __pyx_mstate_global->__pyx_n_s_altitude
#define __pyx_n_s_and __pyx_mstate_global->__pyx_n_s_and
#define __pyx_n_s_angl __pyx_mstate_global->__pyx_n_s_angl
#define __pyx_n_s_angle __pyx_mstate_global->__pyx_n_s_angle
#define __pyx_n_s_angle_radian __pyx_mstate_global->__pyx_n_s_angle_radian
#define __pyx_n_s_angleat __pyx_mstate_global->__pyx_n_s_angleat
#define __pyx_n_s_angleatraw __pyx_mstate_global->__pyx_n_s_angleatraw
#define __pyx_n_s_animate __pyx_mstate_global->__pyx_n_s_animate
#define __pyx_n_s_animate3d __pyx_mstate_global->__pyx_n_s_animate3d
#define __pyx_n_s_animation __pyx_mstate_global->__pyx_n_s_animation
#define __pyx_n_s_ans __pyx_mstate_global->__pyx_n_s_ans
#define __pyx_n_s_antiprism_graph __pyx_mstate_global->__pyx_n_s_antiprism_graph
#define __pyx_n_s_append __pyx_mstate_global->__pyx_n_s_append
#define __pyx_n_s_apply __pyx_mstate_global->__pyx_n_s_apply
#define __pyx_n_s_approx __pyx_mstate_global->__pyx_n_s_approx
#define __pyx_n_s_approx_mode __pyx_mstate_global->__pyx_n_s_approx_mode
#define __pyx_n_s_arc __pyx_mstate_global->__pyx_n_s_arc
#define __pyx_n_s_arcLen __pyx_mstate_global->__pyx_n_s_arcLen
#define __pyx_n_s_arccos __pyx_mstate_global->__pyx_n_s_arccos
#define __pyx_n_s_arccosh __pyx_mstate_global->__pyx_n_s_arccosh
#define __pyx_n_s_archive __pyx_mstate_global->__pyx_n_s_archive
#define __pyx_n_s_arclen __pyx_mstate_global->__pyx_n_s_arclen
#define __pyx_n_s_arcmin __pyx_mstate_global->__pyx_n_s_arcmin
#define __pyx_n_s_arcs __pyx_mstate_global->__pyx_n_s_arcs
#define __pyx_n_s_arcsin __pyx_mstate_global->__pyx_n_s_arcsin
#define __pyx_n_s_arcsinh __pyx_mstate_global->__pyx_n_s_arcsinh
#define __pyx_n_s_arctan __pyx_mstate_global->__pyx_n_s_arctan
#define __pyx_n_s_arctanh __pyx_mstate_global->__pyx_n_s_arctanh
#define __pyx_n_s_area __pyx_mstate_global->__pyx_n_s_area
#define __pyx_n_s_areaat __pyx_mstate_global->__pyx_n_s_areaat
#define __pyx_n_s_areaatraw __pyx_mstate_global->__pyx_n_s_areaatraw
#define __pyx_n_s_areaplot __pyx_mstate_global->__pyx_n_s_areaplot
#define __pyx_n_s_arg __pyx_mstate_global->__pyx_n_s_arg
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_kp_s_argument_must_be_a_Pygen_list_an __pyx_mstate_global->__pyx_kp_s_argument_must_be_a_Pygen_list_an
#define __pyx_kp_s_argument_must_be_a_tuple_or_a_li __pyx_mstate_global->__pyx_kp_s_argument_must_be_a_tuple_or_a_li
#define __pyx_n_s_array __pyx_mstate_global->__pyx_n_s_array
#define __pyx_n_s_arrivals __pyx_mstate_global->__pyx_n_s_arrivals
#define __pyx_n_s_articulation_points __pyx_mstate_global->__pyx_n_s_articulation_points
#define __pyx_n_s_as_function_of __pyx_mstate_global->__pyx_n_s_as_function_of
#define __pyx_n_s_asc __pyx_mstate_global->__pyx_n_s_asc
#define __pyx_n_s_asec __pyx_mstate_global->__pyx_n_s_asec
#define __pyx_n_s_asin __pyx_mstate_global->__pyx_n_s_asin
#define __pyx_n_s_asin2acos __pyx_mstate_global->__pyx_n_s_asin2acos
#define __pyx_n_s_asin2atan __pyx_mstate_global->__pyx_n_s_asin2atan
#define __pyx_n_s_asinh __pyx_mstate_global->__pyx_n_s_asinh
#define __pyx_n_s_assert __pyx_mstate_global->__pyx_n_s_assert
#define __pyx_n_s_assign __pyx_mstate_global->__pyx_n_s_assign
#define __pyx_n_s_assign_edge_weights __pyx_mstate_global->__pyx_n_s_assign_edge_weights
#define __pyx_n_s_assume __pyx_mstate_global->__pyx_n_s_assume
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_at __pyx_mstate_global->__pyx_n_s_at
#define __pyx_n_s_atan __pyx_mstate_global->__pyx_n_s_atan
#define __pyx_n_s_atan2 __pyx_mstate_global->__pyx_n_s_atan2
#define __pyx_n_s_atan2acos __pyx_mstate_global->__pyx_n_s_atan2acos
#define __pyx_n_s_atan2asin __pyx_mstate_global->__pyx_n_s_atan2asin
#define __pyx_n_s_atanh __pyx_mstate_global->__pyx_n_s_atanh
#define __pyx_n_s_atm __pyx_mstate_global->__pyx_n_s_atm
#define __pyx_n_s_atrig2ln __pyx_mstate_global->__pyx_n_s_atrig2ln
#define __pyx_n_s_au __pyx_mstate_global->__pyx_n_s_au
#define __pyx_n_s_augment __pyx_mstate_global->__pyx_n_s_augment
#define __pyx_n_s_auto_correlation __pyx_mstate_global->__pyx_n_s_auto_correlation
#define __pyx_n_s_autosimplify __pyx_mstate_global->__pyx_n_s_autosimplify
#define __pyx_n_s_avance __pyx_mstate_global->__pyx_n_s_avance
#define __pyx_n_s_avgRC __pyx_mstate_global->__pyx_n_s_avgRC
#define __pyx_n_s_axes __pyx_mstate_global->__pyx_n_s_axes
#define __pyx_n_s_axis __pyx_mstate_global->__pyx_n_s_axis
#define __pyx_n_s_b __pyx_mstate_global->__pyx_n_s_b
#define __pyx_n_s_b_2 __pyx_mstate_global->__pyx_n_s_b_2
#define __pyx_n_s_back __pyx_mstate_global->__pyx_n_s_back
#define __pyx_n_s_backquote __pyx_mstate_global->__pyx_n_s_backquote
#define __pyx_n_s_backward __pyx_mstate_global->__pyx_n_s_backward
#define __pyx_n_s_baisse_crayon __pyx_mstate_global->__pyx_n_s_baisse_crayon
#define __pyx_n_s_bandwidth __pyx_mstate_global->__pyx_n_s_bandwidth
#define __pyx_n_s_bar __pyx_mstate_global->__pyx_n_s_bar
#define __pyx_n_s_bar_plot __pyx_mstate_global->__pyx_n_s_bar_plot
#define __pyx_n_s_barplot __pyx_mstate_global->__pyx_n_s_barplot
#define __pyx_n_s_bartlett_hann_window __pyx_mstate_global->__pyx_n_s_bartlett_hann_window
#define __pyx_n_s_barycenter __pyx_mstate_global->__pyx_n_s_barycenter
#define __pyx_n_s_base __pyx_mstate_global->__pyx_n_s_base
#define __pyx_n_s_basis __pyx_mstate_global->__pyx_n_s_basis
#define __pyx_n_s_batons __pyx_mstate_global->__pyx_n_s_batons
#define __pyx_n_s_bbl __pyx_mstate_global->__pyx_n_s_bbl
#define __pyx_n_s_bblep __pyx_mstate_global->__pyx_n_s_bblep
#define __pyx_n_s_begin __pyx_mstate_global->__pyx_n_s_begin
#define __pyx_n_s_bellman_ford __pyx_mstate_global->__pyx_n_s_bellman_ford
#define __pyx_n_s_berlekamp_massey __pyx_mstate_global->__pyx_n_s_berlekamp_massey
#define __pyx_n_s_bernoulli __pyx_mstate_global->__pyx_n_s_bernoulli
#define __pyx_n_s_bernoulli_mod __pyx_mstate_global->__pyx_n_s_bernoulli_mod
#define __pyx_n_s_besselJ __pyx_mstate_global->__pyx_n_s_besselJ
#define __pyx_n_s_besselY __pyx_mstate_global->__pyx_n_s_besselY
#define __pyx_n_s_betad __pyx_mstate_global->__pyx_n_s_betad
#define __pyx_n_s_betad_cdf __pyx_mstate_global->__pyx_n_s_betad_cdf
#define __pyx_n_s_betad_icdf __pyx_mstate_global->__pyx_n_s_betad_icdf
#define __pyx_n_s_betavariate __pyx_mstate_global->__pyx_n_s_betavariate
#define __pyx_n_s_betweenness_centrality __pyx_mstate_global->__pyx_n_s_betweenness_centrality
#define __pyx_n_s_bezier __pyx_mstate_global->__pyx_n_s_bezier
#define __pyx_n_s_bezout_entiers __pyx_mstate_global->__pyx_n_s_bezout_entiers
#define __pyx_n_s_bezoutian __pyx_mstate_global->__pyx_n_s_bezoutian
#define __pyx_n_s_biconnected_components __pyx_mstate_global->__pyx_n_s_biconnected_components
#define __pyx_n_s_binomial __pyx_mstate_global->__pyx_n_s_binomial
#define __pyx_n_s_binomial_cdf __pyx_mstate_global->__pyx_n_s_binomial_cdf
#define __pyx_n_s_binomial_icdf __pyx_mstate_global->__pyx_n_s_binomial_icdf
#define __pyx_n_s_bins __pyx_mstate_global->__pyx_n_s_bins
#define __pyx_n_s_bipartite __pyx_mstate_global->__pyx_n_s_bipartite
#define __pyx_n_s_bipartite_matching __pyx_mstate_global->__pyx_n_s_bipartite_matching
#define __pyx_n_s_bisection_solver __pyx_mstate_global->__pyx_n_s_bisection_solver
#define __pyx_n_s_bisector __pyx_mstate_global->__pyx_n_s_bisector
#define __pyx_n_s_bit_depth __pyx_mstate_global->__pyx_n_s_bit_depth
#define __pyx_n_s_bit_length __pyx_mstate_global->__pyx_n_s_bit_length
#define __pyx_n_s_bitand __pyx_mstate_global->__pyx_n_s_bitand
#define __pyx_n_s_bitor __pyx_mstate_global->__pyx_n_s_bitor
#define __pyx_n_s_bitxor __pyx_mstate_global->__pyx_n_s_bitxor
#define __pyx_n_s_black __pyx_mstate_global->__pyx_n_s_black
#define __pyx_n_s_blacklist __pyx_mstate_global->__pyx_n_s_blacklist
#define __pyx_n_s_blackman_harris_window __pyx_mstate_global->__pyx_n_s_blackman_harris_window
#define __pyx_n_s_blackman_window __pyx_mstate_global->__pyx_n_s_blackman_window
#define __pyx_n_s_blanc __pyx_mstate_global->__pyx_n_s_blanc
#define __pyx_n_s_bleu __pyx_mstate_global->__pyx_n_s_bleu
#define __pyx_n_s_bloc __pyx_mstate_global->__pyx_n_s_bloc
#define __pyx_n_s_block_size __pyx_mstate_global->__pyx_n_s_block_size
#define __pyx_n_s_blockmatrix __pyx_mstate_global->__pyx_n_s_blockmatrix
#define __pyx_n_s_blue __pyx_mstate_global->__pyx_n_s_blue
#define __pyx_n_s_bohman_window __pyx_mstate_global->__pyx_n_s_bohman_window
#define __pyx_n_s_border __pyx_mstate_global->__pyx_n_s_border
#define __pyx_n_s_box_constraints __pyx_mstate_global->__pyx_n_s_box_constraints
#define __pyx_n_s_boxcar __pyx_mstate_global->__pyx_n_s_boxcar
#define __pyx_n_s_boxwhisker __pyx_mstate_global->__pyx_n_s_boxwhisker
#define __pyx_n_s_break __pyx_mstate_global->__pyx_n_s_break
#define __pyx_n_s_breakpoint __pyx_mstate_global->__pyx_n_s_breakpoint
#define __pyx_n_s_brent_solver __pyx_mstate_global->__pyx_n_s_brent_solver
#define __pyx_n_s_brown __pyx_mstate_global->__pyx_n_s_brown
#define __pyx_n_s_bspline __pyx_mstate_global->__pyx_n_s_bspline
#define __pyx_n_s_bu __pyx_mstate_global->__pyx_n_s_bu
#define __pyx_n_s_buUS __pyx_mstate_global->__pyx_n_s_buUS
#define __pyx_n_s_builtins __pyx_mstate_global->__pyx_n_s_builtins
#define __pyx_n_s_bvpsolve __pyx_mstate_global->__pyx_n_s_bvpsolve
#define __pyx_n_s_by __pyx_mstate_global->__pyx_n_s_by
#define __pyx_n_s_c __pyx_mstate_global->__pyx_n_s_c
#define __pyx_n_s_c1oc2 __pyx_mstate_global->__pyx_n_s_c1oc2
#define __pyx_n_s_c1op2 __pyx_mstate_global->__pyx_n_s_c1op2
#define __pyx_n_s_c3 __pyx_mstate_global->__pyx_n_s_c3
#define __pyx_n_s_cFactor __pyx_mstate_global->__pyx_n_s_cFactor
#define __pyx_n_s_cSolve __pyx_mstate_global->__pyx_n_s_cSolve
#define __pyx_n_s_cZeros __pyx_mstate_global->__pyx_n_s_cZeros
#define __pyx_n_s_cache_tortue __pyx_mstate_global->__pyx_n_s_cache_tortue
#define __pyx_n_s_cal __pyx_mstate_global->__pyx_n_s_cal
#define __pyx_n_s_call __pyx_mstate_global->__pyx_n_s_call
#define __pyx_n_s_camembert __pyx_mstate_global->__pyx_n_s_camembert
#define __pyx_n_s_canonical_form __pyx_mstate_global->__pyx_n_s_canonical_form
#define __pyx_n_s_canonical_labeling __pyx_mstate_global->__pyx_n_s_canonical_labeling
#define __pyx_n_s_cap __pyx_mstate_global->__pyx_n_s_cap
#define __pyx_n_s_cap_flat_line __pyx_mstate_global->__pyx_n_s_cap_flat_line
#define __pyx_n_s_cap_round_line __pyx_mstate_global->__pyx_n_s_cap_round_line
#define __pyx_n_s_cap_square_line __pyx_mstate_global->__pyx_n_s_cap_square_line
#define __pyx_n_s_cartesian_product __pyx_mstate_global->__pyx_n_s_cartesian_product
#define __pyx_kp_s_cas_monitor_status __pyx_mstate_global->__pyx_kp_s_cas_monitor_status
#define __pyx_kp_s_cas_monitor_status_after_killing __pyx_mstate_global->__pyx_kp_s_cas_monitor_status_after_killing
#define __pyx_n_s_cas_setup __pyx_mstate_global->__pyx_n_s_cas_setup
#define __pyx_kp_s_cas_setup_2 __pyx_mstate_global->__pyx_kp_s_cas_setup_2
#define __pyx_kp_s_cas_setup_s __pyx_mstate_global->__pyx_kp_s_cas_setup_s
#define __pyx_kp_s_cascmd __pyx_mstate_global->__pyx_kp_s_cascmd
#define __pyx_n_s_case __pyx_mstate_global->__pyx_n_s_case
#define __pyx_n_s_cat __pyx_mstate_global->__pyx_n_s_cat
#define __pyx_n_s_catch __pyx_mstate_global->__pyx_n_s_catch
#define __pyx_n_s_cauchy __pyx_mstate_global->__pyx_n_s_cauchy
#define __pyx_n_s_cauchy_cdf __pyx_mstate_global->__pyx_n_s_cauchy_cdf
#define __pyx_n_s_cauchy_icdf __pyx_mstate_global->__pyx_n_s_cauchy_icdf
#define __pyx_n_s_cauchyd __pyx_mstate_global->__pyx_n_s_cauchyd
#define __pyx_n_s_cauchyd_cdf __pyx_mstate_global->__pyx_n_s_cauchyd_cdf
#define __pyx_n_s_cauchyd_icdf __pyx_mstate_global->__pyx_n_s_cauchyd_icdf
#define __pyx_n_s_cd __pyx_mstate_global->__pyx_n_s_cd
#define __pyx_n_s_cd_2 __pyx_mstate_global->__pyx_n_s_cd_2
#define __pyx_n_s_cdf __pyx_mstate_global->__pyx_n_s_cdf
#define __pyx_n_s_ceil __pyx_mstate_global->__pyx_n_s_ceil
#define __pyx_n_s_ceiling __pyx_mstate_global->__pyx_n_s_ceiling
#define __pyx_n_s_center __pyx_mstate_global->__pyx_n_s_center
#define __pyx_n_s_center2interval __pyx_mstate_global->__pyx_n_s_center2interval
#define __pyx_n_s_centered_cube __pyx_mstate_global->__pyx_n_s_centered_cube
#define __pyx_n_s_centered_tetrahedron __pyx_mstate_global->__pyx_n_s_centered_tetrahedron
#define __pyx_n_s_cfactor __pyx_mstate_global->__pyx_n_s_cfactor
#define __pyx_n_s_cfsolve __pyx_mstate_global->__pyx_n_s_cfsolve
#define __pyx_n_s_chain __pyx_mstate_global->__pyx_n_s_chain
#define __pyx_n_s_changebase __pyx_mstate_global->__pyx_n_s_changebase
#define __pyx_n_s_channel_data __pyx_mstate_global->__pyx_n_s_channel_data
#define __pyx_n_s_channels __pyx_mstate_global->__pyx_n_s_channels
#define __pyx_n_s_char __pyx_mstate_global->__pyx_n_s_char
#define __pyx_n_s_charpoly __pyx_mstate_global->__pyx_n_s_charpoly
#define __pyx_n_s_chinrem __pyx_mstate_global->__pyx_n_s_chinrem
#define __pyx_n_s_chisquare __pyx_mstate_global->__pyx_n_s_chisquare
#define __pyx_n_s_chisquare_cdf __pyx_mstate_global->__pyx_n_s_chisquare_cdf
#define __pyx_n_s_chisquare_icdf __pyx_mstate_global->__pyx_n_s_chisquare_icdf
#define __pyx_n_s_chisquared __pyx_mstate_global->__pyx_n_s_chisquared
#define __pyx_n_s_chisquared_cdf __pyx_mstate_global->__pyx_n_s_chisquared_cdf
#define __pyx_n_s_chisquared_icdf __pyx_mstate_global->__pyx_n_s_chisquared_icdf
#define __pyx_n_s_chisquaret __pyx_mstate_global->__pyx_n_s_chisquaret
#define __pyx_n_s_choice __pyx_mstate_global->__pyx_n_s_choice
#define __pyx_n_s_cholesky __pyx_mstate_global->__pyx_n_s_cholesky
#define __pyx_n_s_choosebox __pyx_mstate_global->__pyx_n_s_choosebox
#define __pyx_n_s_chr __pyx_mstate_global->__pyx_n_s_chr
#define __pyx_n_s_chrem __pyx_mstate_global->__pyx_n_s_chrem
#define __pyx_n_s_chromatic_index __pyx_mstate_global->__pyx_n_s_chromatic_index
#define __pyx_n_s_chromatic_number __pyx_mstate_global->__pyx_n_s_chromatic_number
#define __pyx_n_s_chromatic_polynomial __pyx_mstate_global->__pyx_n_s_chromatic_polynomial
#define __pyx_n_s_circle __pyx_mstate_global->__pyx_n_s_circle
#define __pyx_n_s_circumcircle __pyx_mstate_global->__pyx_n_s_circumcircle
#define __pyx_n_s_class __pyx_mstate_global->__pyx_n_s_class
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_classes __pyx_mstate_global->__pyx_n_s_classes
#define __pyx_n_s_clear __pyx_mstate_global->__pyx_n_s_clear
#define __pyx_n_s_click __pyx_mstate_global->__pyx_n_s_click
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_clique_cover __pyx_mstate_global->__pyx_n_s_clique_cover
#define __pyx_n_s_clique_cover_number __pyx_mstate_global->__pyx_n_s_clique_cover_number
#define __pyx_n_s_clique_number __pyx_mstate_global->__pyx_n_s_clique_number
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_closeness_centrality __pyx_mstate_global->__pyx_n_s_closeness_centrality
#define __pyx_n_s_cluster __pyx_mstate_global->__pyx_n_s_cluster
#define __pyx_n_s_clustering_coefficient __pyx_mstate_global->__pyx_n_s_clustering_coefficient
#define __pyx_n_s_cm __pyx_mstate_global->__pyx_n_s_cm
#define __pyx_kp_s_cm_2 __pyx_mstate_global->__pyx_kp_s_cm_2
#define __pyx_kp_s_cm_3 __pyx_mstate_global->__pyx_kp_s_cm_3
#define __pyx_kp_s_cm_s __pyx_mstate_global->__pyx_kp_s_cm_s
#define __pyx_n_s_coeff __pyx_mstate_global->__pyx_n_s_coeff
#define __pyx_n_s_coeffs __pyx_mstate_global->__pyx_n_s_coeffs
#define __pyx_n_s_col __pyx_mstate_global->__pyx_n_s_col
#define __pyx_n_s_colDim __pyx_mstate_global->__pyx_n_s_colDim
#define __pyx_n_s_colNorm __pyx_mstate_global->__pyx_n_s_colNorm
#define __pyx_n_s_colSwap __pyx_mstate_global->__pyx_n_s_colSwap
#define __pyx_n_s_coldim __pyx_mstate_global->__pyx_n_s_coldim
#define __pyx_n_s_collect __pyx_mstate_global->__pyx_n_s_collect
#define __pyx_n_s_colnorm __pyx_mstate_global->__pyx_n_s_colnorm
#define __pyx_n_s_color __pyx_mstate_global->__pyx_n_s_color
#define __pyx_n_s_colormap __pyx_mstate_global->__pyx_n_s_colormap
#define __pyx_n_s_colspace __pyx_mstate_global->__pyx_n_s_colspace
#define __pyx_n_s_colswap __pyx_mstate_global->__pyx_n_s_colswap
#define __pyx_n_s_comDenom __pyx_mstate_global->__pyx_n_s_comDenom
#define __pyx_n_s_comb __pyx_mstate_global->__pyx_n_s_comb
#define __pyx_n_s_combine __pyx_mstate_global->__pyx_n_s_combine
#define __pyx_n_s_comment __pyx_mstate_global->__pyx_n_s_comment
#define __pyx_n_s_common_perpendicular __pyx_mstate_global->__pyx_n_s_common_perpendicular
#define __pyx_n_s_companion __pyx_mstate_global->__pyx_n_s_companion
#define __pyx_n_s_compare __pyx_mstate_global->__pyx_n_s_compare
#define __pyx_n_s_complete_binary_tree __pyx_mstate_global->__pyx_n_s_complete_binary_tree
#define __pyx_n_s_complete_graph __pyx_mstate_global->__pyx_n_s_complete_graph
#define __pyx_n_s_complete_kary_tree __pyx_mstate_global->__pyx_n_s_complete_kary_tree
#define __pyx_n_s_complex __pyx_mstate_global->__pyx_n_s_complex
#define __pyx_n_s_complex_mode __pyx_mstate_global->__pyx_n_s_complex_mode
#define __pyx_n_s_complex_variables __pyx_mstate_global->__pyx_n_s_complex_variables
#define __pyx_n_s_complexroot __pyx_mstate_global->__pyx_n_s_complexroot
#define __pyx_n_s_concat __pyx_mstate_global->__pyx_n_s_concat
#define __pyx_n_s_cond __pyx_mstate_global->__pyx_n_s_cond
#define __pyx_n_s_condensation __pyx_mstate_global->__pyx_n_s_condensation
#define __pyx_n_s_condi __pyx_mstate_global->__pyx_n_s_condi
#define __pyx_n_s_cone __pyx_mstate_global->__pyx_n_s_cone
#define __pyx_n_s_confrac __pyx_mstate_global->__pyx_n_s_confrac
#define __pyx_n_s_conic __pyx_mstate_global->__pyx_n_s_conic
#define __pyx_n_s_conj __pyx_mstate_global->__pyx_n_s_conj
#define __pyx_n_s_conjugate_equation __pyx_mstate_global->__pyx_n_s_conjugate_equation
#define __pyx_n_s_conjugate_gradient __pyx_mstate_global->__pyx_n_s_conjugate_gradient
#define __pyx_n_s_connected __pyx_mstate_global->__pyx_n_s_connected
#define __pyx_n_s_connected_components __pyx_mstate_global->__pyx_n_s_connected_components
#define __pyx_n_s_cont __pyx_mstate_global->__pyx_n_s_cont
#define __pyx_n_s_contains __pyx_mstate_global->__pyx_n_s_contains
#define __pyx_n_s_content __pyx_mstate_global->__pyx_n_s_content
#define __pyx_n_s_context_ptr __pyx_mstate_global->__pyx_n_s_context_ptr
#define __pyx_n_s_continue __pyx_mstate_global->__pyx_n_s_continue
#define __pyx_n_s_contourplot __pyx_mstate_global->__pyx_n_s_contourplot
#define __pyx_n_s_contract_edge __pyx_mstate_global->__pyx_n_s_contract_edge
#define __pyx_n_s_contract_subgraph __pyx_mstate_global->__pyx_n_s_contract_subgraph
#define __pyx_n_s_convert __pyx_mstate_global->__pyx_n_s_convert
#define __pyx_n_s_convertir __pyx_mstate_global->__pyx_n_s_convertir
#define __pyx_n_s_convex __pyx_mstate_global->__pyx_n_s_convex
#define __pyx_n_s_convexhull __pyx_mstate_global->__pyx_n_s_convexhull
#define __pyx_n_s_convolution __pyx_mstate_global->__pyx_n_s_convolution
#define __pyx_n_s_coordinates __pyx_mstate_global->__pyx_n_s_coordinates
#define __pyx_n_s_copy __pyx_mstate_global->__pyx_n_s_copy
#define __pyx_n_s_correlation __pyx_mstate_global->__pyx_n_s_correlation
#define __pyx_n_s_cos __pyx_mstate_global->__pyx_n_s_cos
#define __pyx_n_s_cos2sintan __pyx_mstate_global->__pyx_n_s_cos2sintan
#define __pyx_n_s_cosh __pyx_mstate_global->__pyx_n_s_cosh
#define __pyx_n_s_cosine_window __pyx_mstate_global->__pyx_n_s_cosine_window
#define __pyx_n_s_cot __pyx_mstate_global->__pyx_n_s_cot
#define __pyx_n_s_cote __pyx_mstate_global->__pyx_n_s_cote
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_count_eq __pyx_mstate_global->__pyx_n_s_count_eq
#define __pyx_n_s_count_inf __pyx_mstate_global->__pyx_n_s_count_inf
#define __pyx_n_s_count_sup __pyx_mstate_global->__pyx_n_s_count_sup
#define __pyx_n_s_courbe_parametrique __pyx_mstate_global->__pyx_n_s_courbe_parametrique
#define __pyx_n_s_courbe_polaire __pyx_mstate_global->__pyx_n_s_courbe_polaire
#define __pyx_n_s_covariance __pyx_mstate_global->__pyx_n_s_covariance
#define __pyx_n_s_covariance_correlation __pyx_mstate_global->__pyx_n_s_covariance_correlation
#define __pyx_n_s_cpartfrac __pyx_mstate_global->__pyx_n_s_cpartfrac
#define __pyx_n_s_crationalroot __pyx_mstate_global->__pyx_n_s_crationalroot
#define __pyx_n_s_crayon __pyx_mstate_global->__pyx_n_s_crayon
#define __pyx_n_s_createwav __pyx_mstate_global->__pyx_n_s_createwav
#define __pyx_n_s_cross __pyx_mstate_global->__pyx_n_s_cross
#define __pyx_n_s_crossP __pyx_mstate_global->__pyx_n_s_crossP
#define __pyx_n_s_cross_correlation __pyx_mstate_global->__pyx_n_s_cross_correlation
#define __pyx_n_s_cross_entropy __pyx_mstate_global->__pyx_n_s_cross_entropy
#define __pyx_n_s_cross_point __pyx_mstate_global->__pyx_n_s_cross_point
#define __pyx_n_s_cross_ratio __pyx_mstate_global->__pyx_n_s_cross_ratio
#define __pyx_n_s_crossproduct __pyx_mstate_global->__pyx_n_s_crossproduct
#define __pyx_n_s_csc __pyx_mstate_global->__pyx_n_s_csc
#define __pyx_n_s_csolve __pyx_mstate_global->__pyx_n_s_csolve
#define __pyx_n_s_csv2gen __pyx_mstate_global->__pyx_n_s_csv2gen
#define __pyx_n_s_ct __pyx_mstate_global->__pyx_n_s_ct
#define __pyx_n_s_cu __pyx_mstate_global->__pyx_n_s_cu
#define __pyx_n_s_cube __pyx_mstate_global->__pyx_n_s_cube
#define __pyx_n_s_cumSum __pyx_mstate_global->__pyx_n_s_cumSum
#define __pyx_n_s_cumsum __pyx_mstate_global->__pyx_n_s_cumsum
#define __pyx_n_s_cumulated_frequencies __pyx_mstate_global->__pyx_n_s_cumulated_frequencies
#define __pyx_n_s_curl __pyx_mstate_global->__pyx_n_s_curl
#define __pyx_n_s_current_sheet __pyx_mstate_global->__pyx_n_s_current_sheet
#define __pyx_n_s_curvature __pyx_mstate_global->__pyx_n_s_curvature
#define __pyx_n_s_curve __pyx_mstate_global->__pyx_n_s_curve
#define __pyx_n_s_cyan __pyx_mstate_global->__pyx_n_s_cyan
#define __pyx_n_s_cycle2perm __pyx_mstate_global->__pyx_n_s_cycle2perm
#define __pyx_n_s_cycle_basis __pyx_mstate_global->__pyx_n_s_cycle_basis
#define __pyx_n_s_cycle_graph __pyx_mstate_global->__pyx_n_s_cycle_graph
#define __pyx_n_s_cycleinv __pyx_mstate_global->__pyx_n_s_cycleinv
#define __pyx_n_s_cycles2permu __pyx_mstate_global->__pyx_n_s_cycles2permu
#define __pyx_n_s_cyclotomic __pyx_mstate_global->__pyx_n_s_cyclotomic
#define __pyx_n_s_cylinder __pyx_mstate_global->__pyx_n_s_cylinder
#define __pyx_n_s_d __pyx_mstate_global->__pyx_n_s_d
#define __pyx_n_s_dB __pyx_mstate_global->__pyx_n_s_dB
#define __pyx_n_s_d_2 __pyx_mstate_global->__pyx_n_s_d_2
#define __pyx_n_s_dash_line __pyx_mstate_global->__pyx_n_s_dash_line
#define __pyx_n_s_dashdot_line __pyx_mstate_global->__pyx_n_s_dashdot_line
#define __pyx_n_s_dashdotdot_line __pyx_mstate_global->__pyx_n_s_dashdotdot_line
#define __pyx_n_s_dayofweek __pyx_mstate_global->__pyx_n_s_dayofweek
#define __pyx_n_s_de __pyx_mstate_global->__pyx_n_s_de
#define __pyx_n_s_deSolve __pyx_mstate_global->__pyx_n_s_deSolve
#define __pyx_n_s_debug __pyx_mstate_global->__pyx_n_s_debug
#define __pyx_n_s_debut_enregistrement __pyx_mstate_global->__pyx_n_s_debut_enregistrement
#define __pyx_n_s_decode __pyx_mstate_global->__pyx_n_s_decode
#define __pyx_n_s_decstring23 __pyx_mstate_global->__pyx_n_s_decstring23
#define __pyx_n_s_default __pyx_mstate_global->__pyx_n_s_default
#define __pyx_n_s_deg __pyx_mstate_global->__pyx_n_s_deg
#define __pyx_n_s_degree __pyx_mstate_global->__pyx_n_s_degree
#define __pyx_n_s_degreeF __pyx_mstate_global->__pyx_n_s_degreeF
#define __pyx_n_s_degree_centrality __pyx_mstate_global->__pyx_n_s_degree_centrality
#define __pyx_n_s_degree_sequence __pyx_mstate_global->__pyx_n_s_degree_sequence
#define __pyx_n_s_degrees __pyx_mstate_global->__pyx_n_s_degrees
#define __pyx_n_s_del __pyx_mstate_global->__pyx_n_s_del
#define __pyx_n_s_delcols __pyx_mstate_global->__pyx_n_s_delcols
#define __pyx_n_s_delete_arc __pyx_mstate_global->__pyx_n_s_delete_arc
#define __pyx_n_s_delete_edge __pyx_mstate_global->__pyx_n_s_delete_edge
#define __pyx_n_s_delete_vertex __pyx_mstate_global->__pyx_n_s_delete_vertex
#define __pyx_n_s_delrows __pyx_mstate_global->__pyx_n_s_delrows
#define __pyx_n_s_deltalist __pyx_mstate_global->__pyx_n_s_deltalist
#define __pyx_n_s_denom __pyx_mstate_global->__pyx_n_s_denom
#define __pyx_n_s_densityplot __pyx_mstate_global->__pyx_n_s_densityplot
#define __pyx_n_s_departures __pyx_mstate_global->__pyx_n_s_departures
#define __pyx_n_s_derive __pyx_mstate_global->__pyx_n_s_derive
#define __pyx_n_s_deriver __pyx_mstate_global->__pyx_n_s_deriver
#define __pyx_n_s_desolve __pyx_mstate_global->__pyx_n_s_desolve
#define __pyx_n_s_dessine_tortue __pyx_mstate_global->__pyx_n_s_dessine_tortue
#define __pyx_n_s_det __pyx_mstate_global->__pyx_n_s_det
#define __pyx_n_s_det_minor __pyx_mstate_global->__pyx_n_s_det_minor
#define __pyx_n_s_developper __pyx_mstate_global->__pyx_n_s_developper
#define __pyx_n_s_developper_transcendant __pyx_mstate_global->__pyx_n_s_developper_transcendant
#define __pyx_n_s_dfc __pyx_mstate_global->__pyx_n_s_dfc
#define __pyx_n_s_dfc2f __pyx_mstate_global->__pyx_n_s_dfc2f
#define __pyx_n_s_diag __pyx_mstate_global->__pyx_n_s_diag
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_n_s_diff __pyx_mstate_global->__pyx_n_s_diff
#define __pyx_n_s_digraph __pyx_mstate_global->__pyx_n_s_digraph
#define __pyx_n_s_dijkstra __pyx_mstate_global->__pyx_n_s_dijkstra
#define __pyx_n_s_dim __pyx_mstate_global->__pyx_n_s_dim
#define __pyx_n_s_directed __pyx_mstate_global->__pyx_n_s_directed
#define __pyx_n_s_directevalued __pyx_mstate_global->__pyx_n_s_directevalued
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_discard_edge_attribute __pyx_mstate_global->__pyx_n_s_discard_edge_attribute
#define __pyx_n_s_discard_graph_attribute __pyx_mstate_global->__pyx_n_s_discard_graph_attribute
#define __pyx_n_s_discard_vertex_attribute __pyx_mstate_global->__pyx_n_s_discard_vertex_attribute
#define __pyx_n_s_disjoint_union __pyx_mstate_global->__pyx_n_s_disjoint_union
#define __pyx_n_s_display __pyx_mstate_global->__pyx_n_s_display
#define __pyx_n_s_disque __pyx_mstate_global->__pyx_n_s_disque
#define __pyx_n_s_disque_centre __pyx_mstate_global->__pyx_n_s_disque_centre
#define __pyx_n_s_distance __pyx_mstate_global->__pyx_n_s_distance
#define __pyx_n_s_distance2 __pyx_mstate_global->__pyx_n_s_distance2
#define __pyx_n_s_distanceat __pyx_mstate_global->__pyx_n_s_distanceat
#define __pyx_n_s_distanceatraw __pyx_mstate_global->__pyx_n_s_distanceatraw
#define __pyx_n_s_div __pyx_mstate_global->__pyx_n_s_div
#define __pyx_n_s_div_2 __pyx_mstate_global->__pyx_n_s_div_2
#define __pyx_n_s_divergence __pyx_mstate_global->__pyx_n_s_divergence
#define __pyx_n_s_divide __pyx_mstate_global->__pyx_n_s_divide
#define __pyx_n_s_divis __pyx_mstate_global->__pyx_n_s_divis
#define __pyx_n_s_division_point __pyx_mstate_global->__pyx_n_s_division_point
#define __pyx_n_s_divisors __pyx_mstate_global->__pyx_n_s_divisors
#define __pyx_n_s_divmod __pyx_mstate_global->__pyx_n_s_divmod
#define __pyx_n_s_divpc __pyx_mstate_global->__pyx_n_s_divpc
#define __pyx_n_s_dnewton_solver __pyx_mstate_global->__pyx_n_s_dnewton_solver
#define __pyx_n_s_do __pyx_mstate_global->__pyx_n_s_do
#define __pyx_kp_s_doc __pyx_mstate_global->__pyx_kp_s_doc
#define __pyx_n_s_doc_2 __pyx_mstate_global->__pyx_n_s_doc_2
#define __pyx_n_s_dodecahedron __pyx_mstate_global->__pyx_n_s_dodecahedron
#define __pyx_n_s_domain __pyx_mstate_global->__pyx_n_s_domain
#define __pyx_n_s_dot __pyx_mstate_global->__pyx_n_s_dot
#define __pyx_n_s_dotP __pyx_mstate_global->__pyx_n_s_dotP
#define __pyx_n_s_dot_paper __pyx_mstate_global->__pyx_n_s_dot_paper
#define __pyx_n_s_dotprod __pyx_mstate_global->__pyx_n_s_dotprod
#define __pyx_n_s_double __pyx_mstate_global->__pyx_n_s_double
#define __pyx_n_s_double_2 __pyx_mstate_global->__pyx_n_s_double_2
#define __pyx_n_s_draw_arc __pyx_mstate_global->__pyx_n_s_draw_arc
#define __pyx_n_s_draw_circle __pyx_mstate_global->__pyx_n_s_draw_circle
#define __pyx_n_s_draw_graph __pyx_mstate_global->__pyx_n_s_draw_graph
#define __pyx_n_s_draw_line __pyx_mstate_global->__pyx_n_s_draw_line
#define __pyx_n_s_draw_pixel __pyx_mstate_global->__pyx_n_s_draw_pixel
#define __pyx_n_s_draw_polygon __pyx_mstate_global->__pyx_n_s_draw_polygon
#define __pyx_n_s_draw_rectangle __pyx_mstate_global->__pyx_n_s_draw_rectangle
#define __pyx_n_s_droit __pyx_mstate_global->__pyx_n_s_droit
#define __pyx_n_s_droite_tangente __pyx_mstate_global->__pyx_n_s_droite_tangente
#define __pyx_n_s_dsolve __pyx_mstate_global->__pyx_n_s_dsolve
#define __pyx_n_s_duration __pyx_mstate_global->__pyx_n_s_duration
#define __pyx_n_s_dwt __pyx_mstate_global->__pyx_n_s_dwt
#define __pyx_n_s_dyn __pyx_mstate_global->__pyx_n_s_dyn
#define __pyx_n_s_e __pyx_mstate_global->__pyx_n_s_e
#define __pyx_n_s_e2r __pyx_mstate_global->__pyx_n_s_e2r
#define __pyx_n_s_eV __pyx_mstate_global->__pyx_n_s_eV
#define __pyx_n_s_ecart_type __pyx_mstate_global->__pyx_n_s_ecart_type
#define __pyx_n_s_ecart_type_population __pyx_mstate_global->__pyx_n_s_ecart_type_population
#define __pyx_n_s_ecef2geodetic __pyx_mstate_global->__pyx_n_s_ecef2geodetic
#define __pyx_n_s_ecm_factor __pyx_mstate_global->__pyx_n_s_ecm_factor
#define __pyx_n_s_ecris __pyx_mstate_global->__pyx_n_s_ecris
#define __pyx_n_s_edge_connectivity __pyx_mstate_global->__pyx_n_s_edge_connectivity
#define __pyx_n_s_edges __pyx_mstate_global->__pyx_n_s_edges
#define __pyx_n_s_efface __pyx_mstate_global->__pyx_n_s_efface
#define __pyx_n_s_egcd __pyx_mstate_global->__pyx_n_s_egcd
#define __pyx_n_s_egv __pyx_mstate_global->__pyx_n_s_egv
#define __pyx_n_s_egvl __pyx_mstate_global->__pyx_n_s_egvl
#define __pyx_n_s_eigVc __pyx_mstate_global->__pyx_n_s_eigVc
#define __pyx_n_s_eigVl __pyx_mstate_global->__pyx_n_s_eigVl
#define __pyx_n_s_eigenvals __pyx_mstate_global->__pyx_n_s_eigenvals
#define __pyx_n_s_eigenvalues __pyx_mstate_global->__pyx_n_s_eigenvalues
#define __pyx_n_s_eigenvectors __pyx_mstate_global->__pyx_n_s_eigenvectors
#define __pyx_n_s_eigenvects __pyx_mstate_global->__pyx_n_s_eigenvects
#define __pyx_n_s_el __pyx_mstate_global->__pyx_n_s_el
#define __pyx_n_s_element __pyx_mstate_global->__pyx_n_s_element
#define __pyx_n_s_elif __pyx_mstate_global->__pyx_n_s_elif
#define __pyx_n_s_eliminate __pyx_mstate_global->__pyx_n_s_eliminate
#define __pyx_n_s_ellipse __pyx_mstate_global->__pyx_n_s_ellipse
#define __pyx_n_s_else __pyx_mstate_global->__pyx_n_s_else
#define __pyx_n_s_emd __pyx_mstate_global->__pyx_n_s_emd
#define __pyx_n_s_en __pyx_mstate_global->__pyx_n_s_en
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_encstring23 __pyx_mstate_global->__pyx_n_s_encstring23
#define __pyx_n_s_end __pyx_mstate_global->__pyx_n_s_end
#define __pyx_n_s_end_for __pyx_mstate_global->__pyx_n_s_end_for
#define __pyx_n_s_end_if __pyx_mstate_global->__pyx_n_s_end_if
#define __pyx_n_s_end_while __pyx_mstate_global->__pyx_n_s_end_while
#define __pyx_n_s_entry __pyx_mstate_global->__pyx_n_s_entry
#define __pyx_n_s_envelope __pyx_mstate_global->__pyx_n_s_envelope
#define __pyx_n_s_epaisseur __pyx_mstate_global->__pyx_n_s_epaisseur
#define __pyx_n_s_epaisseur_ligne_1 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_1
#define __pyx_n_s_epaisseur_ligne_2 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_2
#define __pyx_n_s_epaisseur_ligne_3 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_3
#define __pyx_n_s_epaisseur_ligne_4 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_4
#define __pyx_n_s_epaisseur_ligne_5 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_5
#define __pyx_n_s_epaisseur_ligne_6 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_6
#define __pyx_n_s_epaisseur_ligne_7 __pyx_mstate_global->__pyx_n_s_epaisseur_ligne_7
#define __pyx_n_s_epaisseur_point_1 __pyx_mstate_global->__pyx_n_s_epaisseur_point_1
#define __pyx_n_s_epaisseur_point_2 __pyx_mstate_global->__pyx_n_s_epaisseur_point_2
#define __pyx_n_s_epaisseur_point_3 __pyx_mstate_global->__pyx_n_s_epaisseur_point_3
#define __pyx_n_s_epaisseur_point_4 __pyx_mstate_global->__pyx_n_s_epaisseur_point_4
#define __pyx_n_s_epaisseur_point_5 __pyx_mstate_global->__pyx_n_s_epaisseur_point_5
#define __pyx_n_s_epaisseur_point_6 __pyx_mstate_global->__pyx_n_s_epaisseur_point_6
#define __pyx_n_s_epaisseur_point_7 __pyx_mstate_global->__pyx_n_s_epaisseur_point_7
#define __pyx_n_s_epsilon __pyx_mstate_global->__pyx_n_s_epsilon
#define __pyx_n_s_epsilon0 __pyx_mstate_global->__pyx_n_s_epsilon0
#define __pyx_n_s_epsilon0q __pyx_mstate_global->__pyx_n_s_epsilon0q
#define __pyx_n_s_epsilon2zero __pyx_mstate_global->__pyx_n_s_epsilon2zero
#define __pyx_n_s_epsilonox __pyx_mstate_global->__pyx_n_s_epsilonox
#define __pyx_n_s_epsilonsi __pyx_mstate_global->__pyx_n_s_epsilonsi
#define __pyx_n_s_equal __pyx_mstate_global->__pyx_n_s_equal
#define __pyx_n_s_equal2diff __pyx_mstate_global->__pyx_n_s_equal2diff
#define __pyx_n_s_equal2list __pyx_mstate_global->__pyx_n_s_equal2list
#define __pyx_n_s_equation __pyx_mstate_global->__pyx_n_s_equation
#define __pyx_n_s_equilateral_triangle __pyx_mstate_global->__pyx_n_s_equilateral_triangle
#define __pyx_n_s_erase __pyx_mstate_global->__pyx_n_s_erase
#define __pyx_n_s_erase3d __pyx_mstate_global->__pyx_n_s_erase3d
#define __pyx_n_s_erf __pyx_mstate_global->__pyx_n_s_erf
#define __pyx_n_s_erfc __pyx_mstate_global->__pyx_n_s_erfc
#define __pyx_n_s_erg __pyx_mstate_global->__pyx_n_s_erg
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_n_s_est_cocyclique __pyx_mstate_global->__pyx_n_s_est_cocyclique
#define __pyx_n_s_est_inclus __pyx_mstate_global->__pyx_n_s_est_inclus
#define __pyx_n_s_est_permu __pyx_mstate_global->__pyx_n_s_est_permu
#define __pyx_n_s_et __pyx_mstate_global->__pyx_n_s_et
#define __pyx_n_s_euler __pyx_mstate_global->__pyx_n_s_euler
#define __pyx_n_s_euler_gamma __pyx_mstate_global->__pyx_n_s_euler_gamma
#define __pyx_n_s_euler_lagrange __pyx_mstate_global->__pyx_n_s_euler_lagrange
#define __pyx_n_s_eval __pyx_mstate_global->__pyx_n_s_eval
#define __pyx_n_s_eval_level __pyx_mstate_global->__pyx_n_s_eval_level
#define __pyx_n_s_evala __pyx_mstate_global->__pyx_n_s_evala
#define __pyx_n_s_evalb __pyx_mstate_global->__pyx_n_s_evalb
#define __pyx_n_s_evalc __pyx_mstate_global->__pyx_n_s_evalc
#define __pyx_n_s_evalf __pyx_mstate_global->__pyx_n_s_evalf
#define __pyx_n_s_evalm __pyx_mstate_global->__pyx_n_s_evalm
#define __pyx_n_s_even __pyx_mstate_global->__pyx_n_s_even
#define __pyx_n_s_evolute __pyx_mstate_global->__pyx_n_s_evolute
#define __pyx_n_s_exact __pyx_mstate_global->__pyx_n_s_exact
#define __pyx_n_s_exbisector __pyx_mstate_global->__pyx_n_s_exbisector
#define __pyx_n_s_excircle __pyx_mstate_global->__pyx_n_s_excircle
#define __pyx_n_s_execute __pyx_mstate_global->__pyx_n_s_execute
#define __pyx_n_s_exp __pyx_mstate_global->__pyx_n_s_exp
#define __pyx_n_s_exp2list __pyx_mstate_global->__pyx_n_s_exp2list
#define __pyx_n_s_exp2pow __pyx_mstate_global->__pyx_n_s_exp2pow
#define __pyx_n_s_exp2trig __pyx_mstate_global->__pyx_n_s_exp2trig
#define __pyx_n_s_expand __pyx_mstate_global->__pyx_n_s_expand
#define __pyx_n_s_expexpand __pyx_mstate_global->__pyx_n_s_expexpand
#define __pyx_n_s_expln __pyx_mstate_global->__pyx_n_s_expln
#define __pyx_n_s_exponential __pyx_mstate_global->__pyx_n_s_exponential
#define __pyx_n_s_exponential_cdf __pyx_mstate_global->__pyx_n_s_exponential_cdf
#define __pyx_n_s_exponential_icdf __pyx_mstate_global->__pyx_n_s_exponential_icdf
#define __pyx_n_s_exponential_regression __pyx_mstate_global->__pyx_n_s_exponential_regression
#define __pyx_n_s_exponential_regression_plot __pyx_mstate_global->__pyx_n_s_exponential_regression_plot
#define __pyx_n_s_exponentiald __pyx_mstate_global->__pyx_n_s_exponentiald
#define __pyx_n_s_exponentiald_cdf __pyx_mstate_global->__pyx_n_s_exponentiald_cdf
#define __pyx_n_s_exponentiald_icdf __pyx_mstate_global->__pyx_n_s_exponentiald_icdf
#define __pyx_n_s_export_graph __pyx_mstate_global->__pyx_n_s_export_graph
#define __pyx_n_s_export_mathml __pyx_mstate_global->__pyx_n_s_export_mathml
#define __pyx_n_s_expovariate __pyx_mstate_global->__pyx_n_s_expovariate
#define __pyx_n_s_expr __pyx_mstate_global->__pyx_n_s_expr
#define __pyx_n_s_expression __pyx_mstate_global->__pyx_n_s_expression
#define __pyx_n_s_extend __pyx_mstate_global->__pyx_n_s_extend
#define __pyx_n_s_extract_measure __pyx_mstate_global->__pyx_n_s_extract_measure
#define __pyx_n_s_extrema __pyx_mstate_global->__pyx_n_s_extrema
#define __pyx_n_s_ezgcd __pyx_mstate_global->__pyx_n_s_ezgcd
#define __pyx_n_s_f0 __pyx_mstate_global->__pyx_n_s_f0
#define __pyx_n_s_f2nd __pyx_mstate_global->__pyx_n_s_f2nd
#define __pyx_n_s_fMax __pyx_mstate_global->__pyx_n_s_fMax
#define __pyx_n_s_fMin __pyx_mstate_global->__pyx_n_s_fMin
#define __pyx_n_s_fPart __pyx_mstate_global->__pyx_n_s_fPart
#define __pyx_n_s_faces __pyx_mstate_global->__pyx_n_s_faces
#define __pyx_n_s_facteurs_premiers __pyx_mstate_global->__pyx_n_s_facteurs_premiers
#define __pyx_n_s_factor __pyx_mstate_global->__pyx_n_s_factor
#define __pyx_n_s_factor_xn __pyx_mstate_global->__pyx_n_s_factor_xn
#define __pyx_n_s_factorial __pyx_mstate_global->__pyx_n_s_factorial
#define __pyx_n_s_factoriser __pyx_mstate_global->__pyx_n_s_factoriser
#define __pyx_n_s_factoriser_entier __pyx_mstate_global->__pyx_n_s_factoriser_entier
#define __pyx_n_s_factoriser_sur_C __pyx_mstate_global->__pyx_n_s_factoriser_sur_C
#define __pyx_n_s_factors __pyx_mstate_global->__pyx_n_s_factors
#define __pyx_n_s_fadeev __pyx_mstate_global->__pyx_n_s_fadeev
#define __pyx_kp_s_failed_to_init_doc_from_giac_s_d __pyx_mstate_global->__pyx_kp_s_failed_to_init_doc_from_giac_s_d
#define __pyx_n_s_faire __pyx_mstate_global->__pyx_n_s_faire
#define __pyx_n_s_false __pyx_mstate_global->__pyx_n_s_false
#define __pyx_n_s_falsepos_solver __pyx_mstate_global->__pyx_n_s_falsepos_solver
#define __pyx_n_s_fath __pyx_mstate_global->__pyx_n_s_fath
#define __pyx_n_s_faux __pyx_mstate_global->__pyx_n_s_faux
#define __pyx_n_s_fbm __pyx_mstate_global->__pyx_n_s_fbm
#define __pyx_n_s_fc __pyx_mstate_global->__pyx_n_s_fc
#define __pyx_n_s_fclose __pyx_mstate_global->__pyx_n_s_fclose
#define __pyx_n_s_fcoeff __pyx_mstate_global->__pyx_n_s_fcoeff
#define __pyx_n_s_fdistrib __pyx_mstate_global->__pyx_n_s_fdistrib
#define __pyx_n_s_fermi __pyx_mstate_global->__pyx_n_s_fermi
#define __pyx_n_s_feuille __pyx_mstate_global->__pyx_n_s_feuille
#define __pyx_n_s_ffaire __pyx_mstate_global->__pyx_n_s_ffaire
#define __pyx_n_s_ffonction __pyx_mstate_global->__pyx_n_s_ffonction
#define __pyx_n_s_fft __pyx_mstate_global->__pyx_n_s_fft
#define __pyx_n_s_ffunction __pyx_mstate_global->__pyx_n_s_ffunction
#define __pyx_n_s_fi __pyx_mstate_global->__pyx_n_s_fi
#define __pyx_n_s_fieldplot __pyx_mstate_global->__pyx_n_s_fieldplot
#define __pyx_kp_s_file __pyx_mstate_global->__pyx_kp_s_file
#define __pyx_n_s_filename __pyx_mstate_global->__pyx_n_s_filename
#define __pyx_n_s_filled __pyx_mstate_global->__pyx_n_s_filled
#define __pyx_n_s_fin_enregistrement __pyx_mstate_global->__pyx_n_s_fin_enregistrement
#define __pyx_n_s_find __pyx_mstate_global->__pyx_n_s_find
#define __pyx_n_s_find_cliques __pyx_mstate_global->__pyx_n_s_find_cliques
#define __pyx_n_s_find_cycles __pyx_mstate_global->__pyx_n_s_find_cycles
#define __pyx_n_s_find_minimum __pyx_mstate_global->__pyx_n_s_find_minimum
#define __pyx_n_s_find_vertex_cover __pyx_mstate_global->__pyx_n_s_find_vertex_cover
#define __pyx_n_s_findhelp __pyx_mstate_global->__pyx_n_s_findhelp
#define __pyx_n_s_fisher __pyx_mstate_global->__pyx_n_s_fisher
#define __pyx_n_s_fisher_cdf __pyx_mstate_global->__pyx_n_s_fisher_cdf
#define __pyx_n_s_fisher_icdf __pyx_mstate_global->__pyx_n_s_fisher_icdf
#define __pyx_n_s_fisherd __pyx_mstate_global->__pyx_n_s_fisherd
#define __pyx_n_s_fisherd_cdf __pyx_mstate_global->__pyx_n_s_fisherd_cdf
#define __pyx_n_s_fisherd_icdf __pyx_mstate_global->__pyx_n_s_fisherd_icdf
#define __pyx_n_s_fitdistr __pyx_mstate_global->__pyx_n_s_fitdistr
#define __pyx_n_s_fitpoly __pyx_mstate_global->__pyx_n_s_fitpoly
#define __pyx_n_s_fitspline __pyx_mstate_global->__pyx_n_s_fitspline
#define __pyx_n_s_flam __pyx_mstate_global->__pyx_n_s_flam
#define __pyx_n_s_flatten __pyx_mstate_global->__pyx_n_s_flatten
#define __pyx_n_s_float __pyx_mstate_global->__pyx_n_s_float
#define __pyx_n_s_float2rational __pyx_mstate_global->__pyx_n_s_float2rational
#define __pyx_n_s_floor __pyx_mstate_global->__pyx_n_s_floor
#define __pyx_n_s_flow_polynomial __pyx_mstate_global->__pyx_n_s_flow_polynomial
#define __pyx_n_s_flower_snark __pyx_mstate_global->__pyx_n_s_flower_snark
#define __pyx_n_s_fm __pyx_mstate_global->__pyx_n_s_fm
#define __pyx_n_s_fmod __pyx_mstate_global->__pyx_n_s_fmod
#define __pyx_n_s_foldl __pyx_mstate_global->__pyx_n_s_foldl
#define __pyx_n_s_foldr __pyx_mstate_global->__pyx_n_s_foldr
#define __pyx_n_s_fonction __pyx_mstate_global->__pyx_n_s_fonction
#define __pyx_n_s_fonction_derivee __pyx_mstate_global->__pyx_n_s_fonction_derivee
#define __pyx_n_s_fopen __pyx_mstate_global->__pyx_n_s_fopen
#define __pyx_n_s_for __pyx_mstate_global->__pyx_n_s_for
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_forward __pyx_mstate_global->__pyx_n_s_forward
#define __pyx_n_s_fourier __pyx_mstate_global->__pyx_n_s_fourier
#define __pyx_n_s_fourier_an __pyx_mstate_global->__pyx_n_s_fourier_an
#define __pyx_n_s_fourier_bn __pyx_mstate_global->__pyx_n_s_fourier_bn
#define __pyx_n_s_fourier_cn __pyx_mstate_global->__pyx_n_s_fourier_cn
#define __pyx_n_s_fpour __pyx_mstate_global->__pyx_n_s_fpour
#define __pyx_n_s_fprint __pyx_mstate_global->__pyx_n_s_fprint
#define __pyx_n_s_fr __pyx_mstate_global->__pyx_n_s_fr
#define __pyx_n_s_frac __pyx_mstate_global->__pyx_n_s_frac
#define __pyx_n_s_fracmod __pyx_mstate_global->__pyx_n_s_fracmod
#define __pyx_n_s_frame_2d __pyx_mstate_global->__pyx_n_s_frame_2d
#define __pyx_n_s_frame_3d __pyx_mstate_global->__pyx_n_s_frame_3d
#define __pyx_n_s_frames __pyx_mstate_global->__pyx_n_s_frames
#define __pyx_n_s_frank_wolfe __pyx_mstate_global->__pyx_n_s_frank_wolfe
#define __pyx_n_s_frequencies __pyx_mstate_global->__pyx_n_s_frequencies
#define __pyx_n_s_frobenius_norm __pyx_mstate_global->__pyx_n_s_frobenius_norm
#define __pyx_n_s_from __pyx_mstate_global->__pyx_n_s_from
#define __pyx_kp_s_from_giac_s_help __pyx_mstate_global->__pyx_kp_s_from_giac_s_help
#define __pyx_kp_u_from_giacpy_import_giac_giac_3 __pyx_mstate_global->__pyx_kp_u_from_giacpy_import_giac_giac_3
#define __pyx_n_s_froot __pyx_mstate_global->__pyx_n_s_froot
#define __pyx_n_s_fsi __pyx_mstate_global->__pyx_n_s_fsi
#define __pyx_n_s_fsolve __pyx_mstate_global->__pyx_n_s_fsolve
#define __pyx_n_s_ft __pyx_mstate_global->__pyx_n_s_ft
#define __pyx_n_s_ftUS __pyx_mstate_global->__pyx_n_s_ftUS
#define __pyx_kp_s_ft_2 __pyx_mstate_global->__pyx_kp_s_ft_2
#define __pyx_kp_s_ft_3 __pyx_mstate_global->__pyx_kp_s_ft_3
#define __pyx_kp_s_ft_lb __pyx_mstate_global->__pyx_kp_s_ft_lb
#define __pyx_kp_s_ft_lb_2 __pyx_mstate_global->__pyx_kp_s_ft_lb_2
#define __pyx_kp_s_ft_s __pyx_mstate_global->__pyx_kp_s_ft_s
#define __pyx_n_s_ftantque __pyx_mstate_global->__pyx_n_s_ftantque
#define __pyx_n_s_fullparfrac __pyx_mstate_global->__pyx_n_s_fullparfrac
#define __pyx_n_s_func __pyx_mstate_global->__pyx_n_s_func
#define __pyx_n_s_funcplot __pyx_mstate_global->__pyx_n_s_funcplot
#define __pyx_n_s_function __pyx_mstate_global->__pyx_n_s_function
#define __pyx_n_s_function_diff __pyx_mstate_global->__pyx_n_s_function_diff
#define __pyx_n_s_fundamental_cycle __pyx_mstate_global->__pyx_n_s_fundamental_cycle
#define __pyx_n_s_fxnd __pyx_mstate_global->__pyx_n_s_fxnd
#define __pyx_n_s_g __pyx_mstate_global->__pyx_n_s_g
#define __pyx_n_s_g_2 __pyx_mstate_global->__pyx_n_s_g_2
#define __pyx_n_s_ga __pyx_mstate_global->__pyx_n_s_ga
#define __pyx_n_s_galC __pyx_mstate_global->__pyx_n_s_galC
#define __pyx_n_s_galUK __pyx_mstate_global->__pyx_n_s_galUK
#define __pyx_n_s_galUS __pyx_mstate_global->__pyx_n_s_galUS
#define __pyx_n_s_gammad __pyx_mstate_global->__pyx_n_s_gammad
#define __pyx_n_s_gammad_cdf __pyx_mstate_global->__pyx_n_s_gammad_cdf
#define __pyx_n_s_gammad_icdf __pyx_mstate_global->__pyx_n_s_gammad_icdf
#define __pyx_n_s_gammavariate __pyx_mstate_global->__pyx_n_s_gammavariate
#define __pyx_n_s_gauche __pyx_mstate_global->__pyx_n_s_gauche
#define __pyx_n_s_gauss __pyx_mstate_global->__pyx_n_s_gauss
#define __pyx_n_s_gauss15 __pyx_mstate_global->__pyx_n_s_gauss15
#define __pyx_n_s_gauss_seidel_linsolve __pyx_mstate_global->__pyx_n_s_gauss_seidel_linsolve
#define __pyx_n_s_gaussian_window __pyx_mstate_global->__pyx_n_s_gaussian_window
#define __pyx_n_s_gaussjord __pyx_mstate_global->__pyx_n_s_gaussjord
#define __pyx_n_s_gaussquad __pyx_mstate_global->__pyx_n_s_gaussquad
#define __pyx_n_s_gbasis __pyx_mstate_global->__pyx_n_s_gbasis
#define __pyx_n_s_gbasis_max_pairs __pyx_mstate_global->__pyx_n_s_gbasis_max_pairs
#define __pyx_n_s_gbasis_reinject __pyx_mstate_global->__pyx_n_s_gbasis_reinject
#define __pyx_n_s_gbasis_simult_primes __pyx_mstate_global->__pyx_n_s_gbasis_simult_primes
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_gcd __pyx_mstate_global->__pyx_n_s_gcd
#define __pyx_n_s_gcdex __pyx_mstate_global->__pyx_n_s_gcdex
#define __pyx_kp_s_gen_indexes_are_not_yet_implemen __pyx_mstate_global->__pyx_kp_s_gen_indexes_are_not_yet_implemen
#define __pyx_n_s_genpoly __pyx_mstate_global->__pyx_n_s_genpoly
#define __pyx_n_s_geodetic2ecef __pyx_mstate_global->__pyx_n_s_geodetic2ecef
#define __pyx_n_s_geometric __pyx_mstate_global->__pyx_n_s_geometric
#define __pyx_n_s_geometric_cdf __pyx_mstate_global->__pyx_n_s_geometric_cdf
#define __pyx_n_s_geometric_icdf __pyx_mstate_global->__pyx_n_s_geometric_icdf
#define __pyx_n_s_getDenom __pyx_mstate_global->__pyx_n_s_getDenom
#define __pyx_n_s_getKey __pyx_mstate_global->__pyx_n_s_getKey
#define __pyx_n_s_getNum __pyx_mstate_global->__pyx_n_s_getNum
#define __pyx_n_s_getType __pyx_mstate_global->__pyx_n_s_getType
#define __pyx_n_s_get_edge_attribute __pyx_mstate_global->__pyx_n_s_get_edge_attribute
#define __pyx_n_s_get_edge_weight __pyx_mstate_global->__pyx_n_s_get_edge_weight
#define __pyx_n_s_get_graph_attribute __pyx_mstate_global->__pyx_n_s_get_graph_attribute
#define __pyx_n_s_get_vertex_attribute __pyx_mstate_global->__pyx_n_s_get_vertex_attribute
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_gf __pyx_mstate_global->__pyx_n_s_gf
#define __pyx_n_s_giac __pyx_mstate_global->__pyx_n_s_giac
#define __pyx_kp_s_giac_docs_dir_not_found __pyx_mstate_global->__pyx_kp_s_giac_docs_dir_not_found
#define __pyx_kp_u_giac_line_163 __pyx_mstate_global->__pyx_kp_u_giac_line_163
#define __pyx_n_s_giacbasedir __pyx_mstate_global->__pyx_n_s_giacbasedir
#define __pyx_n_s_giacpy2qcas __pyx_mstate_global->__pyx_n_s_giacpy2qcas
#define __pyx_kp_s_giacpy_auto_methods_pxi __pyx_mstate_global->__pyx_kp_s_giacpy_auto_methods_pxi
#define __pyx_n_s_giacpy_giacpy __pyx_mstate_global->__pyx_n_s_giacpy_giacpy
#define __pyx_kp_s_giacpy_giacpy_pyx __pyx_mstate_global->__pyx_kp_s_giacpy_giacpy_pyx
#define __pyx_n_s_giacsettings __pyx_mstate_global->__pyx_n_s_giacsettings
#define __pyx_n_s_girth __pyx_mstate_global->__pyx_n_s_girth
#define __pyx_n_s_gl_ortho __pyx_mstate_global->__pyx_n_s_gl_ortho
#define __pyx_n_s_gl_quaternion __pyx_mstate_global->__pyx_n_s_gl_quaternion
#define __pyx_n_s_gl_rotation __pyx_mstate_global->__pyx_n_s_gl_rotation
#define __pyx_n_s_gl_showaxes __pyx_mstate_global->__pyx_n_s_gl_showaxes
#define __pyx_n_s_gl_shownames __pyx_mstate_global->__pyx_n_s_gl_shownames
#define __pyx_n_s_gl_texture __pyx_mstate_global->__pyx_n_s_gl_texture
#define __pyx_n_s_gl_x __pyx_mstate_global->__pyx_n_s_gl_x
#define __pyx_n_s_gl_x_axis_color __pyx_mstate_global->__pyx_n_s_gl_x_axis_color
#define __pyx_n_s_gl_x_axis_name __pyx_mstate_global->__pyx_n_s_gl_x_axis_name
#define __pyx_n_s_gl_x_axis_unit __pyx_mstate_global->__pyx_n_s_gl_x_axis_unit
#define __pyx_n_s_gl_xtick __pyx_mstate_global->__pyx_n_s_gl_xtick
#define __pyx_n_s_gl_y __pyx_mstate_global->__pyx_n_s_gl_y
#define __pyx_n_s_gl_y_axis_color __pyx_mstate_global->__pyx_n_s_gl_y_axis_color
#define __pyx_n_s_gl_y_axis_name __pyx_mstate_global->__pyx_n_s_gl_y_axis_name
#define __pyx_n_s_gl_y_axis_unit __pyx_mstate_global->__pyx_n_s_gl_y_axis_unit
#define __pyx_n_s_gl_ytick __pyx_mstate_global->__pyx_n_s_gl_ytick
#define __pyx_n_s_gl_z __pyx_mstate_global->__pyx_n_s_gl_z
#define __pyx_n_s_gl_z_axis_color __pyx_mstate_global->__pyx_n_s_gl_z_axis_color
#define __pyx_n_s_gl_z_axis_name __pyx_mstate_global->__pyx_n_s_gl_z_axis_name
#define __pyx_n_s_gl_z_axis_unit __pyx_mstate_global->__pyx_n_s_gl_z_axis_unit
#define __pyx_n_s_gl_ztick __pyx_mstate_global->__pyx_n_s_gl_ztick
#define __pyx_n_s_gmol __pyx_mstate_global->__pyx_n_s_gmol
#define __pyx_n_s_gnuplot __pyx_mstate_global->__pyx_n_s_gnuplot
#define __pyx_n_s_gold __pyx_mstate_global->__pyx_n_s_gold
#define __pyx_n_s_goldberg_snark __pyx_mstate_global->__pyx_n_s_goldberg_snark
#define __pyx_n_s_gon __pyx_mstate_global->__pyx_n_s_gon
#define __pyx_n_s_goto __pyx_mstate_global->__pyx_n_s_goto
#define __pyx_n_s_grad __pyx_mstate_global->__pyx_n_s_grad
#define __pyx_n_s_grad_2 __pyx_mstate_global->__pyx_n_s_grad_2
#define __pyx_n_s_grain __pyx_mstate_global->__pyx_n_s_grain
#define __pyx_n_s_gramschmidt __pyx_mstate_global->__pyx_n_s_gramschmidt
#define __pyx_n_s_graph __pyx_mstate_global->__pyx_n_s_graph
#define __pyx_n_s_graph2tex __pyx_mstate_global->__pyx_n_s_graph2tex
#define __pyx_n_s_graph3d2tex __pyx_mstate_global->__pyx_n_s_graph3d2tex
#define __pyx_n_s_graph_automorphisms __pyx_mstate_global->__pyx_n_s_graph_automorphisms
#define __pyx_n_s_graph_charpoly __pyx_mstate_global->__pyx_n_s_graph_charpoly
#define __pyx_n_s_graph_complement __pyx_mstate_global->__pyx_n_s_graph_complement
#define __pyx_n_s_graph_diameter __pyx_mstate_global->__pyx_n_s_graph_diameter
#define __pyx_n_s_graph_equal __pyx_mstate_global->__pyx_n_s_graph_equal
#define __pyx_n_s_graph_join __pyx_mstate_global->__pyx_n_s_graph_join
#define __pyx_n_s_graph_power __pyx_mstate_global->__pyx_n_s_graph_power
#define __pyx_n_s_graph_rank __pyx_mstate_global->__pyx_n_s_graph_rank
#define __pyx_n_s_graph_spectrum __pyx_mstate_global->__pyx_n_s_graph_spectrum
#define __pyx_n_s_graph_union __pyx_mstate_global->__pyx_n_s_graph_union
#define __pyx_n_s_graph_vertices __pyx_mstate_global->__pyx_n_s_graph_vertices
#define __pyx_n_s_graphe __pyx_mstate_global->__pyx_n_s_graphe
#define __pyx_n_s_graphe3d __pyx_mstate_global->__pyx_n_s_graphe3d
#define __pyx_n_s_graphe_probabiliste __pyx_mstate_global->__pyx_n_s_graphe_probabiliste
#define __pyx_n_s_graphe_suite __pyx_mstate_global->__pyx_n_s_graphe_suite
#define __pyx_n_s_greduce __pyx_mstate_global->__pyx_n_s_greduce
#define __pyx_n_s_greedy_clique __pyx_mstate_global->__pyx_n_s_greedy_clique
#define __pyx_n_s_greedy_color __pyx_mstate_global->__pyx_n_s_greedy_color
#define __pyx_n_s_greedy_independent_set __pyx_mstate_global->__pyx_n_s_greedy_independent_set
#define __pyx_n_s_green __pyx_mstate_global->__pyx_n_s_green
#define __pyx_n_s_grey __pyx_mstate_global->__pyx_n_s_grey
#define __pyx_n_s_grid_graph __pyx_mstate_global->__pyx_n_s_grid_graph
#define __pyx_n_s_grid_paper __pyx_mstate_global->__pyx_n_s_grid_paper
#define __pyx_n_s_groupermu __pyx_mstate_global->__pyx_n_s_groupermu
#define __pyx_n_s_h __pyx_mstate_global->__pyx_n_s_h
#define __pyx_n_s_h_2 __pyx_mstate_global->__pyx_n_s_h_2
#define __pyx_n_s_ha __pyx_mstate_global->__pyx_n_s_ha
#define __pyx_n_s_haar_graph __pyx_mstate_global->__pyx_n_s_haar_graph
#define __pyx_n_s_hadamard __pyx_mstate_global->__pyx_n_s_hadamard
#define __pyx_n_s_half_cone __pyx_mstate_global->__pyx_n_s_half_cone
#define __pyx_n_s_half_line __pyx_mstate_global->__pyx_n_s_half_line
#define __pyx_n_s_halftan __pyx_mstate_global->__pyx_n_s_halftan
#define __pyx_n_s_halftan_hyp2exp __pyx_mstate_global->__pyx_n_s_halftan_hyp2exp
#define __pyx_n_s_halt __pyx_mstate_global->__pyx_n_s_halt
#define __pyx_n_s_hamdist __pyx_mstate_global->__pyx_n_s_hamdist
#define __pyx_n_s_hamming __pyx_mstate_global->__pyx_n_s_hamming
#define __pyx_n_s_hamming_window __pyx_mstate_global->__pyx_n_s_hamming_window
#define __pyx_n_s_hann_poisson_window __pyx_mstate_global->__pyx_n_s_hann_poisson_window
#define __pyx_n_s_hann_window __pyx_mstate_global->__pyx_n_s_hann_window
#define __pyx_n_s_harmonic_centrality __pyx_mstate_global->__pyx_n_s_harmonic_centrality
#define __pyx_n_s_harmonic_conjugate __pyx_mstate_global->__pyx_n_s_harmonic_conjugate
#define __pyx_n_s_harmonic_division __pyx_mstate_global->__pyx_n_s_harmonic_division
#define __pyx_n_s_has __pyx_mstate_global->__pyx_n_s_has
#define __pyx_n_s_has_arc __pyx_mstate_global->__pyx_n_s_has_arc
#define __pyx_n_s_has_edge __pyx_mstate_global->__pyx_n_s_has_edge
#define __pyx_n_s_hasard __pyx_mstate_global->__pyx_n_s_hasard
#define __pyx_n_s_hbar __pyx_mstate_global->__pyx_n_s_hbar
#define __pyx_n_s_head __pyx_mstate_global->__pyx_n_s_head
#define __pyx_n_s_heading __pyx_mstate_global->__pyx_n_s_heading
#define __pyx_n_s_heapify __pyx_mstate_global->__pyx_n_s_heapify
#define __pyx_n_s_heappop __pyx_mstate_global->__pyx_n_s_heappop
#define __pyx_n_s_heappush __pyx_mstate_global->__pyx_n_s_heappush
#define __pyx_n_s_help __pyx_mstate_global->__pyx_n_s_help
#define __pyx_n_s_hermite __pyx_mstate_global->__pyx_n_s_hermite
#define __pyx_n_s_hessenberg __pyx_mstate_global->__pyx_n_s_hessenberg
#define __pyx_n_s_hessian __pyx_mstate_global->__pyx_n_s_hessian
#define __pyx_n_s_heugcd __pyx_mstate_global->__pyx_n_s_heugcd
#define __pyx_n_s_hexagon __pyx_mstate_global->__pyx_n_s_hexagon
#define __pyx_n_s_hht __pyx_mstate_global->__pyx_n_s_hht
#define __pyx_n_s_hidden_name __pyx_mstate_global->__pyx_n_s_hidden_name
#define __pyx_n_s_highlight_edges __pyx_mstate_global->__pyx_n_s_highlight_edges
#define __pyx_n_s_highlight_subgraph __pyx_mstate_global->__pyx_n_s_highlight_subgraph
#define __pyx_n_s_highlight_trail __pyx_mstate_global->__pyx_n_s_highlight_trail
#define __pyx_n_s_highlight_vertex __pyx_mstate_global->__pyx_n_s_highlight_vertex
#define __pyx_n_s_highpass __pyx_mstate_global->__pyx_n_s_highpass
#define __pyx_n_s_hilbert __pyx_mstate_global->__pyx_n_s_hilbert
#define __pyx_n_s_histogram __pyx_mstate_global->__pyx_n_s_histogram
#define __pyx_n_s_hold __pyx_mstate_global->__pyx_n_s_hold
#define __pyx_n_s_homogeneize __pyx_mstate_global->__pyx_n_s_homogeneize
#define __pyx_n_s_homothety __pyx_mstate_global->__pyx_n_s_homothety
#define __pyx_n_s_horner __pyx_mstate_global->__pyx_n_s_horner
#define __pyx_n_s_hp __pyx_mstate_global->__pyx_n_s_hp
#define __pyx_n_s_hsv __pyx_mstate_global->__pyx_n_s_hsv
#define __pyx_n_s_hsv2rgb __pyx_mstate_global->__pyx_n_s_hsv2rgb
#define __pyx_n_s_htmlhelp __pyx_mstate_global->__pyx_n_s_htmlhelp
#define __pyx_kp_u_htmlhelp_line_1849 __pyx_mstate_global->__pyx_kp_u_htmlhelp_line_1849
#define __pyx_kp_s_http_www_fourier_ujf_grenoble_fr __pyx_mstate_global->__pyx_kp_s_http_www_fourier_ujf_grenoble_fr
#define __pyx_n_s_hybrid_solver __pyx_mstate_global->__pyx_n_s_hybrid_solver
#define __pyx_n_s_hybridj_solver __pyx_mstate_global->__pyx_n_s_hybridj_solver
#define __pyx_n_s_hybrids_solver __pyx_mstate_global->__pyx_n_s_hybrids_solver
#define __pyx_n_s_hybridsj_solver __pyx_mstate_global->__pyx_n_s_hybridsj_solver
#define __pyx_n_s_hyp2exp __pyx_mstate_global->__pyx_n_s_hyp2exp
#define __pyx_n_s_hyperbola __pyx_mstate_global->__pyx_n_s_hyperbola
#define __pyx_n_s_hypercube_graph __pyx_mstate_global->__pyx_n_s_hypercube_graph
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_iPart __pyx_mstate_global->__pyx_n_s_iPart
#define __pyx_kp_s_i_2 __pyx_mstate_global->__pyx_kp_s_i_2
#define __pyx_n_s_iabcuv __pyx_mstate_global->__pyx_n_s_iabcuv
#define __pyx_n_s_ibasis __pyx_mstate_global->__pyx_n_s_ibasis
#define __pyx_n_s_ibpdv __pyx_mstate_global->__pyx_n_s_ibpdv
#define __pyx_n_s_ibpu __pyx_mstate_global->__pyx_n_s_ibpu
#define __pyx_n_s_icdf __pyx_mstate_global->__pyx_n_s_icdf
#define __pyx_n_s_ichinrem __pyx_mstate_global->__pyx_n_s_ichinrem
#define __pyx_n_s_ichrem __pyx_mstate_global->__pyx_n_s_ichrem
#define __pyx_n_s_icomp __pyx_mstate_global->__pyx_n_s_icomp
#define __pyx_n_s_icontent __pyx_mstate_global->__pyx_n_s_icontent
#define __pyx_n_s_icosahedron __pyx_mstate_global->__pyx_n_s_icosahedron
#define __pyx_n_s_id __pyx_mstate_global->__pyx_n_s_id
#define __pyx_n_s_identifier __pyx_mstate_global->__pyx_n_s_identifier
#define __pyx_n_s_identify_graph __pyx_mstate_global->__pyx_n_s_identify_graph
#define __pyx_n_s_identity __pyx_mstate_global->__pyx_n_s_identity
#define __pyx_n_s_idivis __pyx_mstate_global->__pyx_n_s_idivis
#define __pyx_n_s_idn __pyx_mstate_global->__pyx_n_s_idn
#define __pyx_n_s_idwt __pyx_mstate_global->__pyx_n_s_idwt
#define __pyx_n_s_iegcd __pyx_mstate_global->__pyx_n_s_iegcd
#define __pyx_n_s_if __pyx_mstate_global->__pyx_n_s_if
#define __pyx_n_s_ifactor __pyx_mstate_global->__pyx_n_s_ifactor
#define __pyx_n_s_ifactors __pyx_mstate_global->__pyx_n_s_ifactors
#define __pyx_n_s_ifft __pyx_mstate_global->__pyx_n_s_ifft
#define __pyx_n_s_ifourier __pyx_mstate_global->__pyx_n_s_ifourier
#define __pyx_n_s_ifte __pyx_mstate_global->__pyx_n_s_ifte
#define __pyx_n_s_igamma __pyx_mstate_global->__pyx_n_s_igamma
#define __pyx_n_s_igcd __pyx_mstate_global->__pyx_n_s_igcd
#define __pyx_n_s_igcdex __pyx_mstate_global->__pyx_n_s_igcdex
#define __pyx_n_s_ignored __pyx_mstate_global->__pyx_n_s_ignored
#define __pyx_n_s_ihermite __pyx_mstate_global->__pyx_n_s_ihermite
#define __pyx_n_s_ilaplace __pyx_mstate_global->__pyx_n_s_ilaplace
#define __pyx_n_s_im __pyx_mstate_global->__pyx_n_s_im
#define __pyx_n_s_imag __pyx_mstate_global->__pyx_n_s_imag
#define __pyx_n_s_image __pyx_mstate_global->__pyx_n_s_image
#define __pyx_n_s_imfplot __pyx_mstate_global->__pyx_n_s_imfplot
#define __pyx_n_s_implicitdiff __pyx_mstate_global->__pyx_n_s_implicitdiff
#define __pyx_n_s_implicitplot __pyx_mstate_global->__pyx_n_s_implicitplot
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_import_graph __pyx_mstate_global->__pyx_n_s_import_graph
#define __pyx_n_s_in __pyx_mstate_global->__pyx_n_s_in
#define __pyx_n_s_inH20 __pyx_mstate_global->__pyx_n_s_inH20
#define __pyx_n_s_inHg __pyx_mstate_global->__pyx_n_s_inHg
#define __pyx_n_s_inString __pyx_mstate_global->__pyx_n_s_inString
#define __pyx_n_s_in_2 __pyx_mstate_global->__pyx_n_s_in_2
#define __pyx_kp_s_in_2_2 __pyx_mstate_global->__pyx_kp_s_in_2_2
#define __pyx_kp_s_in_3 __pyx_mstate_global->__pyx_kp_s_in_3
#define __pyx_n_s_in_ideal __pyx_mstate_global->__pyx_n_s_in_ideal
#define __pyx_n_s_incidence_matrix __pyx_mstate_global->__pyx_n_s_incidence_matrix
#define __pyx_n_s_incident_edges __pyx_mstate_global->__pyx_n_s_incident_edges
#define __pyx_n_s_incircle __pyx_mstate_global->__pyx_n_s_incircle
#define __pyx_n_s_increasing_power __pyx_mstate_global->__pyx_n_s_increasing_power
#define __pyx_n_s_independence_number __pyx_mstate_global->__pyx_n_s_independence_number
#define __pyx_n_s_indets __pyx_mstate_global->__pyx_n_s_indets
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_kp_s_index_html __pyx_mstate_global->__pyx_kp_s_index_html
#define __pyx_n_s_indices __pyx_mstate_global->__pyx_n_s_indices
#define __pyx_n_s_induced_subgraph __pyx_mstate_global->__pyx_n_s_induced_subgraph
#define __pyx_n_s_inequationplot __pyx_mstate_global->__pyx_n_s_inequationplot
#define __pyx_n_s_inertia __pyx_mstate_global->__pyx_n_s_inertia
#define __pyx_n_s_inf __pyx_mstate_global->__pyx_n_s_inf
#define __pyx_n_s_infinity __pyx_mstate_global->__pyx_n_s_infinity
#define __pyx_kp_s_infinity_2 __pyx_mstate_global->__pyx_kp_s_infinity_2
#define __pyx_kp_s_infinity_3 __pyx_mstate_global->__pyx_kp_s_infinity_3
#define __pyx_n_s_information_centrality __pyx_mstate_global->__pyx_n_s_information_centrality
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_input __pyx_mstate_global->__pyx_n_s_input
#define __pyx_n_s_inputform __pyx_mstate_global->__pyx_n_s_inputform
#define __pyx_n_s_insert __pyx_mstate_global->__pyx_n_s_insert
#define __pyx_n_s_insmod __pyx_mstate_global->__pyx_n_s_insmod
#define __pyx_n_s_instfreq __pyx_mstate_global->__pyx_n_s_instfreq
#define __pyx_n_s_instphase __pyx_mstate_global->__pyx_n_s_instphase
#define __pyx_n_s_int __pyx_mstate_global->__pyx_n_s_int
#define __pyx_n_s_intDiv __pyx_mstate_global->__pyx_n_s_intDiv
#define __pyx_n_s_integer __pyx_mstate_global->__pyx_n_s_integer
#define __pyx_n_s_integrate __pyx_mstate_global->__pyx_n_s_integrate
#define __pyx_n_s_integrer __pyx_mstate_global->__pyx_n_s_integrer
#define __pyx_n_s_inter __pyx_mstate_global->__pyx_n_s_inter
#define __pyx_n_s_interactive_odeplot __pyx_mstate_global->__pyx_n_s_interactive_odeplot
#define __pyx_n_s_interactive_plotode __pyx_mstate_global->__pyx_n_s_interactive_plotode
#define __pyx_n_s_interp __pyx_mstate_global->__pyx_n_s_interp
#define __pyx_n_s_intersect __pyx_mstate_global->__pyx_n_s_intersect
#define __pyx_n_s_interval __pyx_mstate_global->__pyx_n_s_interval
#define __pyx_n_s_interval2center __pyx_mstate_global->__pyx_n_s_interval2center
#define __pyx_n_s_interval_graph __pyx_mstate_global->__pyx_n_s_interval_graph
#define __pyx_n_s_inv __pyx_mstate_global->__pyx_n_s_inv
#define __pyx_n_s_inverse __pyx_mstate_global->__pyx_n_s_inverse
#define __pyx_n_s_inversion __pyx_mstate_global->__pyx_n_s_inversion
#define __pyx_n_s_invisible_point __pyx_mstate_global->__pyx_n_s_invisible_point
#define __pyx_n_s_invlaplace __pyx_mstate_global->__pyx_n_s_invlaplace
#define __pyx_n_s_invztrans __pyx_mstate_global->__pyx_n_s_invztrans
#define __pyx_n_s_iquo __pyx_mstate_global->__pyx_n_s_iquo
#define __pyx_n_s_iquorem __pyx_mstate_global->__pyx_n_s_iquorem
#define __pyx_n_s_iratrecon __pyx_mstate_global->__pyx_n_s_iratrecon
#define __pyx_n_s_irem __pyx_mstate_global->__pyx_n_s_irem
#define __pyx_n_s_isPrime __pyx_mstate_global->__pyx_n_s_isPrime
#define __pyx_n_s_is_acyclic __pyx_mstate_global->__pyx_n_s_is_acyclic
#define __pyx_n_s_is_arborescence __pyx_mstate_global->__pyx_n_s_is_arborescence
#define __pyx_n_s_is_biconnected __pyx_mstate_global->__pyx_n_s_is_biconnected
#define __pyx_n_s_is_bipartite __pyx_mstate_global->__pyx_n_s_is_bipartite
#define __pyx_n_s_is_clique __pyx_mstate_global->__pyx_n_s_is_clique
#define __pyx_n_s_is_collinear __pyx_mstate_global->__pyx_n_s_is_collinear
#define __pyx_n_s_is_concyclic __pyx_mstate_global->__pyx_n_s_is_concyclic
#define __pyx_n_s_is_conjugate __pyx_mstate_global->__pyx_n_s_is_conjugate
#define __pyx_n_s_is_connected __pyx_mstate_global->__pyx_n_s_is_connected
#define __pyx_n_s_is_coplanar __pyx_mstate_global->__pyx_n_s_is_coplanar
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_cospherical __pyx_mstate_global->__pyx_n_s_is_cospherical
#define __pyx_n_s_is_cut_set __pyx_mstate_global->__pyx_n_s_is_cut_set
#define __pyx_n_s_is_cycle __pyx_mstate_global->__pyx_n_s_is_cycle
#define __pyx_n_s_is_directed __pyx_mstate_global->__pyx_n_s_is_directed
#define __pyx_n_s_is_element __pyx_mstate_global->__pyx_n_s_is_element
#define __pyx_n_s_is_equilateral __pyx_mstate_global->__pyx_n_s_is_equilateral
#define __pyx_n_s_is_eulerian __pyx_mstate_global->__pyx_n_s_is_eulerian
#define __pyx_n_s_is_forest __pyx_mstate_global->__pyx_n_s_is_forest
#define __pyx_n_s_is_graphic_sequence __pyx_mstate_global->__pyx_n_s_is_graphic_sequence
#define __pyx_n_s_is_hamiltonian __pyx_mstate_global->__pyx_n_s_is_hamiltonian
#define __pyx_n_s_is_harmonic __pyx_mstate_global->__pyx_n_s_is_harmonic
#define __pyx_n_s_is_harmonic_circle_bundle __pyx_mstate_global->__pyx_n_s_is_harmonic_circle_bundle
#define __pyx_n_s_is_harmonic_line_bundle __pyx_mstate_global->__pyx_n_s_is_harmonic_line_bundle
#define __pyx_n_s_is_included __pyx_mstate_global->__pyx_n_s_is_included
#define __pyx_n_s_is_inside __pyx_mstate_global->__pyx_n_s_is_inside
#define __pyx_n_s_is_integer_graph __pyx_mstate_global->__pyx_n_s_is_integer_graph
#define __pyx_n_s_is_irreducible __pyx_mstate_global->__pyx_n_s_is_irreducible
#define __pyx_n_s_is_isomorphic __pyx_mstate_global->__pyx_n_s_is_isomorphic
#define __pyx_n_s_is_isosceles __pyx_mstate_global->__pyx_n_s_is_isosceles
#define __pyx_n_s_is_network __pyx_mstate_global->__pyx_n_s_is_network
#define __pyx_n_s_is_orthogonal __pyx_mstate_global->__pyx_n_s_is_orthogonal
#define __pyx_n_s_is_parallel __pyx_mstate_global->__pyx_n_s_is_parallel
#define __pyx_n_s_is_parallelogram __pyx_mstate_global->__pyx_n_s_is_parallelogram
#define __pyx_n_s_is_permu __pyx_mstate_global->__pyx_n_s_is_permu
#define __pyx_n_s_is_perpendicular __pyx_mstate_global->__pyx_n_s_is_perpendicular
#define __pyx_n_s_is_planar __pyx_mstate_global->__pyx_n_s_is_planar
#define __pyx_n_s_is_prime __pyx_mstate_global->__pyx_n_s_is_prime
#define __pyx_n_s_is_pseudoprime __pyx_mstate_global->__pyx_n_s_is_pseudoprime
#define __pyx_n_s_is_reachable __pyx_mstate_global->__pyx_n_s_is_reachable
#define __pyx_n_s_is_rectangle __pyx_mstate_global->__pyx_n_s_is_rectangle
#define __pyx_n_s_is_regular __pyx_mstate_global->__pyx_n_s_is_regular
#define __pyx_n_s_is_rhombus __pyx_mstate_global->__pyx_n_s_is_rhombus
#define __pyx_n_s_is_split_graph __pyx_mstate_global->__pyx_n_s_is_split_graph
#define __pyx_n_s_is_square __pyx_mstate_global->__pyx_n_s_is_square
#define __pyx_n_s_is_strongly_connected __pyx_mstate_global->__pyx_n_s_is_strongly_connected
#define __pyx_n_s_is_strongly_regular __pyx_mstate_global->__pyx_n_s_is_strongly_regular
#define __pyx_n_s_is_subgraph_isomorphic __pyx_mstate_global->__pyx_n_s_is_subgraph_isomorphic
#define __pyx_n_s_is_tournament __pyx_mstate_global->__pyx_n_s_is_tournament
#define __pyx_n_s_is_tree __pyx_mstate_global->__pyx_n_s_is_tree
#define __pyx_n_s_is_triconnected __pyx_mstate_global->__pyx_n_s_is_triconnected
#define __pyx_n_s_is_two_edge_connected __pyx_mstate_global->__pyx_n_s_is_two_edge_connected
#define __pyx_n_s_is_vertex_colorable __pyx_mstate_global->__pyx_n_s_is_vertex_colorable
#define __pyx_n_s_is_weighted __pyx_mstate_global->__pyx_n_s_is_weighted
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_isinf __pyx_mstate_global->__pyx_n_s_isinf
#define __pyx_n_s_ismith __pyx_mstate_global->__pyx_n_s_ismith
#define __pyx_n_s_isnan __pyx_mstate_global->__pyx_n_s_isnan
#define __pyx_n_s_isobarycenter __pyx_mstate_global->__pyx_n_s_isobarycenter
#define __pyx_n_s_isolve __pyx_mstate_global->__pyx_n_s_isolve
#define __pyx_n_s_isom __pyx_mstate_global->__pyx_n_s_isom
#define __pyx_n_s_isomorphic_copy __pyx_mstate_global->__pyx_n_s_isomorphic_copy
#define __pyx_n_s_isopolygon __pyx_mstate_global->__pyx_n_s_isopolygon
#define __pyx_n_s_isosceles_triangle __pyx_mstate_global->__pyx_n_s_isosceles_triangle
#define __pyx_n_s_isposdef __pyx_mstate_global->__pyx_n_s_isposdef
#define __pyx_n_s_isprime __pyx_mstate_global->__pyx_n_s_isprime
#define __pyx_n_s_istft __pyx_mstate_global->__pyx_n_s_istft
#define __pyx_n_s_iter __pyx_mstate_global->__pyx_n_s_iter
#define __pyx_n_s_ithprime __pyx_mstate_global->__pyx_n_s_ithprime
#define __pyx_n_s_j __pyx_mstate_global->__pyx_n_s_j
#define __pyx_n_s_jacobi_equation __pyx_mstate_global->__pyx_n_s_jacobi_equation
#define __pyx_n_s_jacobi_linsolve __pyx_mstate_global->__pyx_n_s_jacobi_linsolve
#define __pyx_n_s_jacobi_symbol __pyx_mstate_global->__pyx_n_s_jacobi_symbol
#define __pyx_n_s_johnson_graph __pyx_mstate_global->__pyx_n_s_johnson_graph
#define __pyx_n_s_join __pyx_mstate_global->__pyx_n_s_join
#define __pyx_n_s_jordan __pyx_mstate_global->__pyx_n_s_jordan
#define __pyx_n_s_jusqu_a __pyx_mstate_global->__pyx_n_s_jusqu_a
#define __pyx_n_s_jusqua __pyx_mstate_global->__pyx_n_s_jusqua
#define __pyx_n_s_jusque __pyx_mstate_global->__pyx_n_s_jusque
#define __pyx_n_s_k __pyx_mstate_global->__pyx_n_s_k
#define __pyx_n_s_kWh __pyx_mstate_global->__pyx_n_s_kWh
#define __pyx_n_s_katz_centrality __pyx_mstate_global->__pyx_n_s_katz_centrality
#define __pyx_n_s_kde __pyx_mstate_global->__pyx_n_s_kde
#define __pyx_n_s_keep_algext __pyx_mstate_global->__pyx_n_s_keep_algext
#define __pyx_n_s_keep_pivot __pyx_mstate_global->__pyx_n_s_keep_pivot
#define __pyx_n_s_ker __pyx_mstate_global->__pyx_n_s_ker
#define __pyx_n_s_kernel __pyx_mstate_global->__pyx_n_s_kernel
#define __pyx_n_s_kernel_density __pyx_mstate_global->__pyx_n_s_kernel_density
#define __pyx_n_s_kg __pyx_mstate_global->__pyx_n_s_kg
#define __pyx_n_s_kill __pyx_mstate_global->__pyx_n_s_kill
#define __pyx_kp_s_killing_thread __pyx_mstate_global->__pyx_kp_s_killing_thread
#define __pyx_n_s_kip __pyx_mstate_global->__pyx_n_s_kip
#define __pyx_n_s_km __pyx_mstate_global->__pyx_n_s_km
#define __pyx_kp_s_km_2 __pyx_mstate_global->__pyx_kp_s_km_2
#define __pyx_n_s_kmeans __pyx_mstate_global->__pyx_n_s_kmeans
#define __pyx_n_s_kneser_graph __pyx_mstate_global->__pyx_n_s_kneser_graph
#define __pyx_n_s_knot __pyx_mstate_global->__pyx_n_s_knot
#define __pyx_n_s_kolmogorovd __pyx_mstate_global->__pyx_n_s_kolmogorovd
#define __pyx_n_s_kolmogorovt __pyx_mstate_global->__pyx_n_s_kolmogorovt
#define __pyx_n_s_kovacicsols __pyx_mstate_global->__pyx_n_s_kovacicsols
#define __pyx_n_s_kph __pyx_mstate_global->__pyx_n_s_kph
#define __pyx_n_s_kq __pyx_mstate_global->__pyx_n_s_kq
#define __pyx_n_s_kspaths __pyx_mstate_global->__pyx_n_s_kspaths
#define __pyx_n_s_l __pyx_mstate_global->__pyx_n_s_l
#define __pyx_n_s_l1norm __pyx_mstate_global->__pyx_n_s_l1norm
#define __pyx_n_s_l2norm __pyx_mstate_global->__pyx_n_s_l2norm
#define __pyx_n_s_l_2 __pyx_mstate_global->__pyx_n_s_l_2
#define __pyx_n_s_label __pyx_mstate_global->__pyx_n_s_label
#define __pyx_n_s_labels __pyx_mstate_global->__pyx_n_s_labels
#define __pyx_n_s_lagrange __pyx_mstate_global->__pyx_n_s_lagrange
#define __pyx_n_s_laguerre __pyx_mstate_global->__pyx_n_s_laguerre
#define __pyx_n_s_lam __pyx_mstate_global->__pyx_n_s_lam
#define __pyx_n_s_lambda0 __pyx_mstate_global->__pyx_n_s_lambda0
#define __pyx_n_s_lambdac __pyx_mstate_global->__pyx_n_s_lambdac
#define __pyx_n_s_lang __pyx_mstate_global->__pyx_n_s_lang
#define __pyx_n_s_laplace __pyx_mstate_global->__pyx_n_s_laplace
#define __pyx_n_s_laplacian __pyx_mstate_global->__pyx_n_s_laplacian
#define __pyx_n_s_laplacian_matrix __pyx_mstate_global->__pyx_n_s_laplacian_matrix
#define __pyx_n_s_latex __pyx_mstate_global->__pyx_n_s_latex
#define __pyx_n_s_lb __pyx_mstate_global->__pyx_n_s_lb
#define __pyx_n_s_lbf __pyx_mstate_global->__pyx_n_s_lbf
#define __pyx_n_s_lbmol __pyx_mstate_global->__pyx_n_s_lbmol
#define __pyx_n_s_lbt __pyx_mstate_global->__pyx_n_s_lbt
#define __pyx_n_s_lcf_graph __pyx_mstate_global->__pyx_n_s_lcf_graph
#define __pyx_n_s_lcm __pyx_mstate_global->__pyx_n_s_lcm
#define __pyx_n_s_lcoeff __pyx_mstate_global->__pyx_n_s_lcoeff
#define __pyx_n_s_ldegree __pyx_mstate_global->__pyx_n_s_ldegree
#define __pyx_n_s_ldl __pyx_mstate_global->__pyx_n_s_ldl
#define __pyx_n_s_learning_rate __pyx_mstate_global->__pyx_n_s_learning_rate
#define __pyx_n_s_left __pyx_mstate_global->__pyx_n_s_left
#define __pyx_n_s_left_rectangle __pyx_mstate_global->__pyx_n_s_left_rectangle
#define __pyx_n_s_legend __pyx_mstate_global->__pyx_n_s_legend
#define __pyx_n_s_legendre __pyx_mstate_global->__pyx_n_s_legendre
#define __pyx_n_s_legendre_symbol __pyx_mstate_global->__pyx_n_s_legendre_symbol
#define __pyx_n_s_len __pyx_mstate_global->__pyx_n_s_len
#define __pyx_n_s_length __pyx_mstate_global->__pyx_n_s_length
#define __pyx_n_s_lep __pyx_mstate_global->__pyx_n_s_lep
#define __pyx_n_s_leve_crayon __pyx_mstate_global->__pyx_n_s_leve_crayon
#define __pyx_n_s_levenshtein __pyx_mstate_global->__pyx_n_s_levenshtein
#define __pyx_n_s_lgcd __pyx_mstate_global->__pyx_n_s_lgcd
#define __pyx_n_s_lhs __pyx_mstate_global->__pyx_n_s_lhs
#define __pyx_n_s_ligne_chapeau_carre __pyx_mstate_global->__pyx_n_s_ligne_chapeau_carre
#define __pyx_n_s_ligne_chapeau_plat __pyx_mstate_global->__pyx_n_s_ligne_chapeau_plat
#define __pyx_n_s_ligne_chapeau_rond __pyx_mstate_global->__pyx_n_s_ligne_chapeau_rond
#define __pyx_n_s_ligne_polygonale __pyx_mstate_global->__pyx_n_s_ligne_polygonale
#define __pyx_n_s_ligne_polygonale_pointee __pyx_mstate_global->__pyx_n_s_ligne_polygonale_pointee
#define __pyx_n_s_ligne_tiret __pyx_mstate_global->__pyx_n_s_ligne_tiret
#define __pyx_n_s_ligne_tiret_point __pyx_mstate_global->__pyx_n_s_ligne_tiret_point
#define __pyx_n_s_ligne_tiret_pointpoint __pyx_mstate_global->__pyx_n_s_ligne_tiret_pointpoint
#define __pyx_n_s_ligne_trait_plein __pyx_mstate_global->__pyx_n_s_ligne_trait_plein
#define __pyx_n_s_limit __pyx_mstate_global->__pyx_n_s_limit
#define __pyx_n_s_limite __pyx_mstate_global->__pyx_n_s_limite
#define __pyx_n_s_lin __pyx_mstate_global->__pyx_n_s_lin
#define __pyx_n_s_linabs __pyx_mstate_global->__pyx_n_s_linabs
#define __pyx_n_s_line __pyx_mstate_global->__pyx_n_s_line
#define __pyx_n_s_line_graph __pyx_mstate_global->__pyx_n_s_line_graph
#define __pyx_n_s_line_inter __pyx_mstate_global->__pyx_n_s_line_inter
#define __pyx_n_s_line_paper __pyx_mstate_global->__pyx_n_s_line_paper
#define __pyx_n_s_line_segments __pyx_mstate_global->__pyx_n_s_line_segments
#define __pyx_n_s_line_width_1 __pyx_mstate_global->__pyx_n_s_line_width_1
#define __pyx_n_s_line_width_2 __pyx_mstate_global->__pyx_n_s_line_width_2
#define __pyx_n_s_line_width_3 __pyx_mstate_global->__pyx_n_s_line_width_3
#define __pyx_n_s_line_width_4 __pyx_mstate_global->__pyx_n_s_line_width_4
#define __pyx_n_s_line_width_5 __pyx_mstate_global->__pyx_n_s_line_width_5
#define __pyx_n_s_line_width_6 __pyx_mstate_global->__pyx_n_s_line_width_6
#define __pyx_n_s_line_width_7 __pyx_mstate_global->__pyx_n_s_line_width_7
#define __pyx_n_s_linear_interpolate __pyx_mstate_global->__pyx_n_s_linear_interpolate
#define __pyx_n_s_linear_regression __pyx_mstate_global->__pyx_n_s_linear_regression
#define __pyx_n_s_linear_regression_plot __pyx_mstate_global->__pyx_n_s_linear_regression_plot
#define __pyx_n_s_lineariser __pyx_mstate_global->__pyx_n_s_lineariser
#define __pyx_n_s_lineariser_trigo __pyx_mstate_global->__pyx_n_s_lineariser_trigo
#define __pyx_n_s_linfnorm __pyx_mstate_global->__pyx_n_s_linfnorm
#define __pyx_n_s_linsolve __pyx_mstate_global->__pyx_n_s_linsolve
#define __pyx_n_s_linspace __pyx_mstate_global->__pyx_n_s_linspace
#define __pyx_n_s_linstep __pyx_mstate_global->__pyx_n_s_linstep
#define __pyx_n_s_liqpt __pyx_mstate_global->__pyx_n_s_liqpt
#define __pyx_n_s_lis __pyx_mstate_global->__pyx_n_s_lis
#define __pyx_n_s_lis_phrase __pyx_mstate_global->__pyx_n_s_lis_phrase
#define __pyx_n_s_list __pyx_mstate_global->__pyx_n_s_list
#define __pyx_n_s_list2exp __pyx_mstate_global->__pyx_n_s_list2exp
#define __pyx_n_s_list2mat __pyx_mstate_global->__pyx_n_s_list2mat
#define __pyx_n_s_list_edge_attributes __pyx_mstate_global->__pyx_n_s_list_edge_attributes
#define __pyx_n_s_list_graph_attributes __pyx_mstate_global->__pyx_n_s_list_graph_attributes
#define __pyx_kp_s_list_index_s_out_of_range __pyx_mstate_global->__pyx_kp_s_list_index_s_out_of_range
#define __pyx_n_s_list_vertex_attributes __pyx_mstate_global->__pyx_n_s_list_vertex_attributes
#define __pyx_n_s_listplot __pyx_mstate_global->__pyx_n_s_listplot
#define __pyx_n_s_listrange __pyx_mstate_global->__pyx_n_s_listrange
#define __pyx_n_s_lll __pyx_mstate_global->__pyx_n_s_lll
#define __pyx_n_s_lm __pyx_mstate_global->__pyx_n_s_lm
#define __pyx_n_s_ln __pyx_mstate_global->__pyx_n_s_ln
#define __pyx_n_s_lname __pyx_mstate_global->__pyx_n_s_lname
#define __pyx_n_s_lncollect __pyx_mstate_global->__pyx_n_s_lncollect
#define __pyx_n_s_lnexpand __pyx_mstate_global->__pyx_n_s_lnexpand
#define __pyx_n_s_loadgiacgen __pyx_mstate_global->__pyx_n_s_loadgiacgen
#define __pyx_kp_u_loadgiacgen_line_2106 __pyx_mstate_global->__pyx_kp_u_loadgiacgen_line_2106
#define __pyx_n_s_local __pyx_mstate_global->__pyx_n_s_local
#define __pyx_n_s_locus __pyx_mstate_global->__pyx_n_s_locus
#define __pyx_n_s_log __pyx_mstate_global->__pyx_n_s_log
#define __pyx_n_s_log10 __pyx_mstate_global->__pyx_n_s_log10
#define __pyx_n_s_log2 __pyx_mstate_global->__pyx_n_s_log2
#define __pyx_n_s_log_loss __pyx_mstate_global->__pyx_n_s_log_loss
#define __pyx_n_s_logarithmic_regression __pyx_mstate_global->__pyx_n_s_logarithmic_regression
#define __pyx_n_s_logarithmic_regression_plot __pyx_mstate_global->__pyx_n_s_logarithmic_regression_plot
#define __pyx_n_s_logb __pyx_mstate_global->__pyx_n_s_logb
#define __pyx_n_s_logistic __pyx_mstate_global->__pyx_n_s_logistic
#define __pyx_n_s_logistic_regression __pyx_mstate_global->__pyx_n_s_logistic_regression
#define __pyx_n_s_logistic_regression_plot __pyx_mstate_global->__pyx_n_s_logistic_regression_plot
#define __pyx_n_s_long __pyx_mstate_global->__pyx_n_s_long
#define __pyx_n_s_lower __pyx_mstate_global->__pyx_n_s_lower
#define __pyx_n_s_lowest_common_ancestor __pyx_mstate_global->__pyx_n_s_lowest_common_ancestor
#define __pyx_n_s_lowpass __pyx_mstate_global->__pyx_n_s_lowpass
#define __pyx_n_s_lp_assume __pyx_mstate_global->__pyx_n_s_lp_assume
#define __pyx_n_s_lp_bestlocalbound __pyx_mstate_global->__pyx_n_s_lp_bestlocalbound
#define __pyx_n_s_lp_bestprojection __pyx_mstate_global->__pyx_n_s_lp_bestprojection
#define __pyx_n_s_lp_binary __pyx_mstate_global->__pyx_n_s_lp_binary
#define __pyx_n_s_lp_binaryvariables __pyx_mstate_global->__pyx_n_s_lp_binaryvariables
#define __pyx_n_s_lp_breadthfirst __pyx_mstate_global->__pyx_n_s_lp_breadthfirst
#define __pyx_n_s_lp_depthfirst __pyx_mstate_global->__pyx_n_s_lp_depthfirst
#define __pyx_n_s_lp_depthlimit __pyx_mstate_global->__pyx_n_s_lp_depthlimit
#define __pyx_n_s_lp_firstfractional __pyx_mstate_global->__pyx_n_s_lp_firstfractional
#define __pyx_n_s_lp_gaptolerance __pyx_mstate_global->__pyx_n_s_lp_gaptolerance
#define __pyx_n_s_lp_heuristic __pyx_mstate_global->__pyx_n_s_lp_heuristic
#define __pyx_n_s_lp_hybrid __pyx_mstate_global->__pyx_n_s_lp_hybrid
#define __pyx_n_s_lp_integer __pyx_mstate_global->__pyx_n_s_lp_integer
#define __pyx_n_s_lp_integervariables __pyx_mstate_global->__pyx_n_s_lp_integervariables
#define __pyx_n_s_lp_interiorpoint __pyx_mstate_global->__pyx_n_s_lp_interiorpoint
#define __pyx_n_s_lp_iterationlimit __pyx_mstate_global->__pyx_n_s_lp_iterationlimit
#define __pyx_n_s_lp_lastfractional __pyx_mstate_global->__pyx_n_s_lp_lastfractional
#define __pyx_n_s_lp_maxcuts __pyx_mstate_global->__pyx_n_s_lp_maxcuts
#define __pyx_n_s_lp_maximize __pyx_mstate_global->__pyx_n_s_lp_maximize
#define __pyx_n_s_lp_method __pyx_mstate_global->__pyx_n_s_lp_method
#define __pyx_n_s_lp_mostfractional __pyx_mstate_global->__pyx_n_s_lp_mostfractional
#define __pyx_n_s_lp_nodelimit __pyx_mstate_global->__pyx_n_s_lp_nodelimit
#define __pyx_n_s_lp_nodeselect __pyx_mstate_global->__pyx_n_s_lp_nodeselect
#define __pyx_n_s_lp_nonnegative __pyx_mstate_global->__pyx_n_s_lp_nonnegative
#define __pyx_n_s_lp_nonnegint __pyx_mstate_global->__pyx_n_s_lp_nonnegint
#define __pyx_n_s_lp_presolve __pyx_mstate_global->__pyx_n_s_lp_presolve
#define __pyx_n_s_lp_pseudocost __pyx_mstate_global->__pyx_n_s_lp_pseudocost
#define __pyx_n_s_lp_simplex __pyx_mstate_global->__pyx_n_s_lp_simplex
#define __pyx_n_s_lp_timelimit __pyx_mstate_global->__pyx_n_s_lp_timelimit
#define __pyx_n_s_lp_varselect __pyx_mstate_global->__pyx_n_s_lp_varselect
#define __pyx_n_s_lp_verbose __pyx_mstate_global->__pyx_n_s_lp_verbose
#define __pyx_n_s_lpsolve __pyx_mstate_global->__pyx_n_s_lpsolve
#define __pyx_n_s_lsmod __pyx_mstate_global->__pyx_n_s_lsmod
#define __pyx_n_s_lsq __pyx_mstate_global->__pyx_n_s_lsq
#define __pyx_n_s_lu __pyx_mstate_global->__pyx_n_s_lu
#define __pyx_n_s_lvar __pyx_mstate_global->__pyx_n_s_lvar
#define __pyx_n_s_lx __pyx_mstate_global->__pyx_n_s_lx
#define __pyx_n_s_lyr __pyx_mstate_global->__pyx_n_s_lyr
#define __pyx_n_s_m __pyx_mstate_global->__pyx_n_s_m
#define __pyx_n_s_mEarth __pyx_mstate_global->__pyx_n_s_mEarth
#define __pyx_n_s_mRow __pyx_mstate_global->__pyx_n_s_mRow
#define __pyx_n_s_mRowAdd __pyx_mstate_global->__pyx_n_s_mRowAdd
#define __pyx_kp_s_m_2 __pyx_mstate_global->__pyx_kp_s_m_2
#define __pyx_kp_s_m_3 __pyx_mstate_global->__pyx_kp_s_m_3
#define __pyx_kp_s_m_s __pyx_mstate_global->__pyx_kp_s_m_s
#define __pyx_kp_s_m_s_2 __pyx_mstate_global->__pyx_kp_s_m_s_2
#define __pyx_n_s_magenta __pyx_mstate_global->__pyx_n_s_magenta
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_make_directed __pyx_mstate_global->__pyx_n_s_make_directed
#define __pyx_n_s_make_symbol __pyx_mstate_global->__pyx_n_s_make_symbol
#define __pyx_n_s_make_weighted __pyx_mstate_global->__pyx_n_s_make_weighted
#define __pyx_n_s_makelist __pyx_mstate_global->__pyx_n_s_makelist
#define __pyx_n_s_makemat __pyx_mstate_global->__pyx_n_s_makemat
#define __pyx_n_s_makesuite __pyx_mstate_global->__pyx_n_s_makesuite
#define __pyx_n_s_makevector __pyx_mstate_global->__pyx_n_s_makevector
#define __pyx_n_s_map __pyx_mstate_global->__pyx_n_s_map
#define __pyx_n_s_maple2mupad __pyx_mstate_global->__pyx_n_s_maple2mupad
#define __pyx_n_s_maple2xcas __pyx_mstate_global->__pyx_n_s_maple2xcas
#define __pyx_n_s_maple_ifactors __pyx_mstate_global->__pyx_n_s_maple_ifactors
#define __pyx_n_s_maple_mode __pyx_mstate_global->__pyx_n_s_maple_mode
#define __pyx_n_s_markov __pyx_mstate_global->__pyx_n_s_markov
#define __pyx_n_s_mat2list __pyx_mstate_global->__pyx_n_s_mat2list
#define __pyx_n_s_math __pyx_mstate_global->__pyx_n_s_math
#define __pyx_n_s_mathml __pyx_mstate_global->__pyx_n_s_mathml
#define __pyx_n_s_matpow __pyx_mstate_global->__pyx_n_s_matpow
#define __pyx_n_s_matrix __pyx_mstate_global->__pyx_n_s_matrix
#define __pyx_n_s_matrix_norm __pyx_mstate_global->__pyx_n_s_matrix_norm
#define __pyx_n_s_max __pyx_mstate_global->__pyx_n_s_max
#define __pyx_n_s_maxcount __pyx_mstate_global->__pyx_n_s_maxcount
#define __pyx_n_s_maxflow __pyx_mstate_global->__pyx_n_s_maxflow
#define __pyx_n_s_maximal_independent_set __pyx_mstate_global->__pyx_n_s_maximal_independent_set
#define __pyx_n_s_maximize __pyx_mstate_global->__pyx_n_s_maximize
#define __pyx_n_s_maximum_clique __pyx_mstate_global->__pyx_n_s_maximum_clique
#define __pyx_n_s_maximum_degree __pyx_mstate_global->__pyx_n_s_maximum_degree
#define __pyx_n_s_maximum_independent_set __pyx_mstate_global->__pyx_n_s_maximum_independent_set
#define __pyx_n_s_maximum_matching __pyx_mstate_global->__pyx_n_s_maximum_matching
#define __pyx_n_s_maxnorm __pyx_mstate_global->__pyx_n_s_maxnorm
#define __pyx_n_s_maxsize __pyx_mstate_global->__pyx_n_s_maxsize
#define __pyx_n_s_me __pyx_mstate_global->__pyx_n_s_me
#define __pyx_n_s_mean __pyx_mstate_global->__pyx_n_s_mean
#define __pyx_n_s_median __pyx_mstate_global->__pyx_n_s_median
#define __pyx_n_s_median_line __pyx_mstate_global->__pyx_n_s_median_line
#define __pyx_n_s_member __pyx_mstate_global->__pyx_n_s_member
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_mgf __pyx_mstate_global->__pyx_n_s_mgf
#define __pyx_n_s_mho __pyx_mstate_global->__pyx_n_s_mho
#define __pyx_n_s_miUS __pyx_mstate_global->__pyx_n_s_miUS
#define __pyx_kp_s_miUS_2 __pyx_mstate_global->__pyx_kp_s_miUS_2
#define __pyx_kp_s_mi_2 __pyx_mstate_global->__pyx_kp_s_mi_2
#define __pyx_n_s_mid __pyx_mstate_global->__pyx_n_s_mid
#define __pyx_n_s_middle_point __pyx_mstate_global->__pyx_n_s_middle_point
#define __pyx_n_s_midpoint __pyx_mstate_global->__pyx_n_s_midpoint
#define __pyx_n_s_mil __pyx_mstate_global->__pyx_n_s_mil
#define __pyx_n_s_mile __pyx_mstate_global->__pyx_n_s_mile
#define __pyx_n_s_mille __pyx_mstate_global->__pyx_n_s_mille
#define __pyx_n_s_min __pyx_mstate_global->__pyx_n_s_min
#define __pyx_n_s_minimal_edge_coloring __pyx_mstate_global->__pyx_n_s_minimal_edge_coloring
#define __pyx_n_s_minimal_spanning_tree __pyx_mstate_global->__pyx_n_s_minimal_spanning_tree
#define __pyx_n_s_minimal_vertex_coloring __pyx_mstate_global->__pyx_n_s_minimal_vertex_coloring
#define __pyx_n_s_minimax __pyx_mstate_global->__pyx_n_s_minimax
#define __pyx_n_s_minimize __pyx_mstate_global->__pyx_n_s_minimize
#define __pyx_n_s_minimum_cut __pyx_mstate_global->__pyx_n_s_minimum_cut
#define __pyx_n_s_minimum_degree __pyx_mstate_global->__pyx_n_s_minimum_degree
#define __pyx_n_s_minimum_vertex_cover __pyx_mstate_global->__pyx_n_s_minimum_vertex_cover
#define __pyx_n_s_minus __pyx_mstate_global->__pyx_n_s_minus
#define __pyx_n_s_mixdown __pyx_mstate_global->__pyx_n_s_mixdown
#define __pyx_n_s_mkisom __pyx_mstate_global->__pyx_n_s_mkisom
#define __pyx_n_s_mksa __pyx_mstate_global->__pyx_n_s_mksa
#define __pyx_n_s_ml __pyx_mstate_global->__pyx_n_s_ml
#define __pyx_n_s_mm __pyx_mstate_global->__pyx_n_s_mm
#define __pyx_n_s_mmHg __pyx_mstate_global->__pyx_n_s_mmHg
#define __pyx_n_s_mn __pyx_mstate_global->__pyx_n_s_mn
#define __pyx_n_s_mod __pyx_mstate_global->__pyx_n_s_mod
#define __pyx_n_s_modf __pyx_mstate_global->__pyx_n_s_modf
#define __pyx_n_s_modgcd __pyx_mstate_global->__pyx_n_s_modgcd
#define __pyx_n_s_mods __pyx_mstate_global->__pyx_n_s_mods
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_mol __pyx_mstate_global->__pyx_n_s_mol
#define __pyx_n_s_momentum __pyx_mstate_global->__pyx_n_s_momentum
#define __pyx_n_s_monotonic __pyx_mstate_global->__pyx_n_s_monotonic
#define __pyx_n_s_montre_tortue __pyx_mstate_global->__pyx_n_s_montre_tortue
#define __pyx_n_s_moremethods __pyx_mstate_global->__pyx_n_s_moremethods
#define __pyx_n_s_moretests __pyx_mstate_global->__pyx_n_s_moretests
#define __pyx_kp_u_moretests_line_2061 __pyx_mstate_global->__pyx_kp_u_moretests_line_2061
#define __pyx_n_s_mostkeywords __pyx_mstate_global->__pyx_n_s_mostkeywords
#define __pyx_n_s_moustache __pyx_mstate_global->__pyx_n_s_moustache
#define __pyx_n_s_moving_average __pyx_mstate_global->__pyx_n_s_moving_average
#define __pyx_n_s_moyal __pyx_mstate_global->__pyx_n_s_moyal
#define __pyx_n_s_moyenne __pyx_mstate_global->__pyx_n_s_moyenne
#define __pyx_n_s_mp __pyx_mstate_global->__pyx_n_s_mp
#define __pyx_n_s_mph __pyx_mstate_global->__pyx_n_s_mph
#define __pyx_n_s_mpme __pyx_mstate_global->__pyx_n_s_mpme
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_s_mu0 __pyx_mstate_global->__pyx_n_s_mu0
#define __pyx_n_s_muB __pyx_mstate_global->__pyx_n_s_muB
#define __pyx_n_s_muN __pyx_mstate_global->__pyx_n_s_muN
#define __pyx_n_s_mul __pyx_mstate_global->__pyx_n_s_mul
#define __pyx_n_s_mul_2 __pyx_mstate_global->__pyx_n_s_mul_2
#define __pyx_n_s_mult_c_conjugate __pyx_mstate_global->__pyx_n_s_mult_c_conjugate
#define __pyx_n_s_mult_conjugate __pyx_mstate_global->__pyx_n_s_mult_conjugate
#define __pyx_n_s_multinomial __pyx_mstate_global->__pyx_n_s_multinomial
#define __pyx_n_s_multiplier_conjugue __pyx_mstate_global->__pyx_n_s_multiplier_conjugue
#define __pyx_n_s_multiplier_conjugue_complexe __pyx_mstate_global->__pyx_n_s_multiplier_conjugue_complexe
#define __pyx_n_s_multiply __pyx_mstate_global->__pyx_n_s_multiply
#define __pyx_n_s_mupad2maple __pyx_mstate_global->__pyx_n_s_mupad2maple
#define __pyx_n_s_mupad2xcas __pyx_mstate_global->__pyx_n_s_mupad2xcas
#define __pyx_n_s_mycielski __pyx_mstate_global->__pyx_n_s_mycielski
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_n_s_nCr __pyx_mstate_global->__pyx_n_s_nCr
#define __pyx_n_s_nDeriv __pyx_mstate_global->__pyx_n_s_nDeriv
#define __pyx_n_s_nInt __pyx_mstate_global->__pyx_n_s_nInt
#define __pyx_n_s_nPr __pyx_mstate_global->__pyx_n_s_nPr
#define __pyx_n_s_nSolve __pyx_mstate_global->__pyx_n_s_nSolve
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_navy __pyx_mstate_global->__pyx_n_s_navy
#define __pyx_n_s_ncols __pyx_mstate_global->__pyx_n_s_ncols
#define __pyx_n_s_neg __pyx_mstate_global->__pyx_n_s_neg
#define __pyx_n_s_negbinomial __pyx_mstate_global->__pyx_n_s_negbinomial
#define __pyx_n_s_negbinomial_cdf __pyx_mstate_global->__pyx_n_s_negbinomial_cdf
#define __pyx_n_s_negbinomial_icdf __pyx_mstate_global->__pyx_n_s_negbinomial_icdf
#define __pyx_n_s_neighbors __pyx_mstate_global->__pyx_n_s_neighbors
#define __pyx_n_s_network_transitivity __pyx_mstate_global->__pyx_n_s_network_transitivity
#define __pyx_n_s_neural_network __pyx_mstate_global->__pyx_n_s_neural_network
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_newList __pyx_mstate_global->__pyx_n_s_newList
#define __pyx_n_s_newMat __pyx_mstate_global->__pyx_n_s_newMat
#define __pyx_n_s_newton __pyx_mstate_global->__pyx_n_s_newton
#define __pyx_n_s_newton_solver __pyx_mstate_global->__pyx_n_s_newton_solver
#define __pyx_n_s_newtonj_solver __pyx_mstate_global->__pyx_n_s_newtonj_solver
#define __pyx_n_s_nextperm __pyx_mstate_global->__pyx_n_s_nextperm
#define __pyx_n_s_nextprime __pyx_mstate_global->__pyx_n_s_nextprime
#define __pyx_n_s_nlp_binary __pyx_mstate_global->__pyx_n_s_nlp_binary
#define __pyx_n_s_nlp_binaryvariables __pyx_mstate_global->__pyx_n_s_nlp_binaryvariables
#define __pyx_n_s_nlp_initialpoint __pyx_mstate_global->__pyx_n_s_nlp_initialpoint
#define __pyx_n_s_nlp_integer __pyx_mstate_global->__pyx_n_s_nlp_integer
#define __pyx_n_s_nlp_integervariables __pyx_mstate_global->__pyx_n_s_nlp_integervariables
#define __pyx_n_s_nlp_iterationlimit __pyx_mstate_global->__pyx_n_s_nlp_iterationlimit
#define __pyx_n_s_nlp_maximize __pyx_mstate_global->__pyx_n_s_nlp_maximize
#define __pyx_n_s_nlp_method __pyx_mstate_global->__pyx_n_s_nlp_method
#define __pyx_n_s_nlp_nonnegative __pyx_mstate_global->__pyx_n_s_nlp_nonnegative
#define __pyx_n_s_nlp_nonnegint __pyx_mstate_global->__pyx_n_s_nlp_nonnegint
#define __pyx_n_s_nlp_precision __pyx_mstate_global->__pyx_n_s_nlp_precision
#define __pyx_n_s_nlp_presolve __pyx_mstate_global->__pyx_n_s_nlp_presolve
#define __pyx_n_s_nlp_tolerance __pyx_mstate_global->__pyx_n_s_nlp_tolerance
#define __pyx_n_s_nlp_verbose __pyx_mstate_global->__pyx_n_s_nlp_verbose
#define __pyx_n_s_nlpsolve __pyx_mstate_global->__pyx_n_s_nlpsolve
#define __pyx_kp_s_no_default___reduce___due_to_non __pyx_mstate_global->__pyx_kp_s_no_default___reduce___due_to_non
#define __pyx_n_s_nodisp __pyx_mstate_global->__pyx_n_s_nodisp
#define __pyx_n_s_noir __pyx_mstate_global->__pyx_n_s_noir
#define __pyx_n_s_nom_cache __pyx_mstate_global->__pyx_n_s_nom_cache
#define __pyx_n_s_non __pyx_mstate_global->__pyx_n_s_non
#define __pyx_n_s_non_recursive_normal __pyx_mstate_global->__pyx_n_s_non_recursive_normal
#define __pyx_n_s_nonevaluable __pyx_mstate_global->__pyx_n_s_nonevaluable
#define __pyx_n_s_nonnegint __pyx_mstate_global->__pyx_n_s_nonnegint
#define __pyx_n_s_nop __pyx_mstate_global->__pyx_n_s_nop
#define __pyx_n_s_nops __pyx_mstate_global->__pyx_n_s_nops
#define __pyx_n_s_norm __pyx_mstate_global->__pyx_n_s_norm
#define __pyx_n_s_normal __pyx_mstate_global->__pyx_n_s_normal
#define __pyx_n_s_normal_cdf __pyx_mstate_global->__pyx_n_s_normal_cdf
#define __pyx_n_s_normal_icdf __pyx_mstate_global->__pyx_n_s_normal_icdf
#define __pyx_n_s_normald __pyx_mstate_global->__pyx_n_s_normald
#define __pyx_n_s_normald_cdf __pyx_mstate_global->__pyx_n_s_normald_cdf
#define __pyx_n_s_normald_icdf __pyx_mstate_global->__pyx_n_s_normald_icdf
#define __pyx_n_s_normalize __pyx_mstate_global->__pyx_n_s_normalize
#define __pyx_n_s_normalt __pyx_mstate_global->__pyx_n_s_normalt
#define __pyx_n_s_normalvariate __pyx_mstate_global->__pyx_n_s_normalvariate
#define __pyx_n_s_not __pyx_mstate_global->__pyx_n_s_not
#define __pyx_n_s_nprimes __pyx_mstate_global->__pyx_n_s_nprimes
#define __pyx_n_s_nrows __pyx_mstate_global->__pyx_n_s_nrows
#define __pyx_n_s_nstep __pyx_mstate_global->__pyx_n_s_nstep
#define __pyx_n_s_nuage_points __pyx_mstate_global->__pyx_n_s_nuage_points
#define __pyx_n_s_nullspace __pyx_mstate_global->__pyx_n_s_nullspace
#define __pyx_n_s_number_of_edges __pyx_mstate_global->__pyx_n_s_number_of_edges
#define __pyx_n_s_number_of_spanning_trees __pyx_mstate_global->__pyx_n_s_number_of_spanning_trees
#define __pyx_n_s_number_of_triangles __pyx_mstate_global->__pyx_n_s_number_of_triangles
#define __pyx_n_s_number_of_vertices __pyx_mstate_global->__pyx_n_s_number_of_vertices
#define __pyx_n_s_numdiff __pyx_mstate_global->__pyx_n_s_numdiff
#define __pyx_n_s_numer __pyx_mstate_global->__pyx_n_s_numer
#define __pyx_n_s_octahedron __pyx_mstate_global->__pyx_n_s_octahedron
#define __pyx_n_s_od __pyx_mstate_global->__pyx_n_s_od
#define __pyx_n_s_odd __pyx_mstate_global->__pyx_n_s_odd
#define __pyx_n_s_odd_girth __pyx_mstate_global->__pyx_n_s_odd_girth
#define __pyx_n_s_odd_graph __pyx_mstate_global->__pyx_n_s_odd_graph
#define __pyx_n_s_odeplot __pyx_mstate_global->__pyx_n_s_odeplot
#define __pyx_n_s_odesolve __pyx_mstate_global->__pyx_n_s_odesolve
#define __pyx_n_s_of __pyx_mstate_global->__pyx_n_s_of
#define __pyx_n_s_oldies __pyx_mstate_global->__pyx_n_s_oldies
#define __pyx_n_s_olive __pyx_mstate_global->__pyx_n_s_olive
#define __pyx_n_s_op __pyx_mstate_global->__pyx_n_s_op
#define __pyx_n_s_open __pyx_mstate_global->__pyx_n_s_open
#define __pyx_n_s_open_polygon __pyx_mstate_global->__pyx_n_s_open_polygon
#define __pyx_n_s_option __pyx_mstate_global->__pyx_n_s_option
#define __pyx_n_s_or __pyx_mstate_global->__pyx_n_s_or
#define __pyx_n_s_orange __pyx_mstate_global->__pyx_n_s_orange
#define __pyx_n_s_ord __pyx_mstate_global->__pyx_n_s_ord
#define __pyx_n_s_order __pyx_mstate_global->__pyx_n_s_order
#define __pyx_n_s_order_size __pyx_mstate_global->__pyx_n_s_order_size
#define __pyx_n_s_ordinate __pyx_mstate_global->__pyx_n_s_ordinate
#define __pyx_n_s_orthocenter __pyx_mstate_global->__pyx_n_s_orthocenter
#define __pyx_n_s_orthogonal __pyx_mstate_global->__pyx_n_s_orthogonal
#define __pyx_n_s_os __pyx_mstate_global->__pyx_n_s_os
#define __pyx_n_s_osculating_circle __pyx_mstate_global->__pyx_n_s_osculating_circle
#define __pyx_n_s_otherwise __pyx_mstate_global->__pyx_n_s_otherwise
#define __pyx_n_s_ou __pyx_mstate_global->__pyx_n_s_ou
#define __pyx_n_s_output __pyx_mstate_global->__pyx_n_s_output
#define __pyx_n_s_oz __pyx_mstate_global->__pyx_n_s_oz
#define __pyx_n_s_ozUK __pyx_mstate_global->__pyx_n_s_ozUK
#define __pyx_n_s_ozfl __pyx_mstate_global->__pyx_n_s_ozfl
#define __pyx_n_s_ozt __pyx_mstate_global->__pyx_n_s_ozt
#define __pyx_n_s_p1oc2 __pyx_mstate_global->__pyx_n_s_p1oc2
#define __pyx_n_s_p1op2 __pyx_mstate_global->__pyx_n_s_p1op2
#define __pyx_n_s_pa2b2 __pyx_mstate_global->__pyx_n_s_pa2b2
#define __pyx_n_s_pade __pyx_mstate_global->__pyx_n_s_pade
#define __pyx_n_s_paley_graph __pyx_mstate_global->__pyx_n_s_paley_graph
#define __pyx_n_s_parabola __pyx_mstate_global->__pyx_n_s_parabola
#define __pyx_n_s_parallel __pyx_mstate_global->__pyx_n_s_parallel
#define __pyx_n_s_parallelepiped __pyx_mstate_global->__pyx_n_s_parallelepiped
#define __pyx_n_s_parallelogram __pyx_mstate_global->__pyx_n_s_parallelogram
#define __pyx_n_s_param __pyx_mstate_global->__pyx_n_s_param
#define __pyx_n_s_parameq __pyx_mstate_global->__pyx_n_s_parameq
#define __pyx_n_s_parameter __pyx_mstate_global->__pyx_n_s_parameter
#define __pyx_n_s_paramplot __pyx_mstate_global->__pyx_n_s_paramplot
#define __pyx_n_s_parfrac __pyx_mstate_global->__pyx_n_s_parfrac
#define __pyx_n_s_pari __pyx_mstate_global->__pyx_n_s_pari
#define __pyx_n_s_part __pyx_mstate_global->__pyx_n_s_part
#define __pyx_n_s_partfrac __pyx_mstate_global->__pyx_n_s_partfrac
#define __pyx_n_s_parzen_window __pyx_mstate_global->__pyx_n_s_parzen_window
#define __pyx_n_s_pas __pyx_mstate_global->__pyx_n_s_pas
#define __pyx_n_s_pas_de_cote __pyx_mstate_global->__pyx_n_s_pas_de_cote
#define __pyx_n_s_path_graph __pyx_mstate_global->__pyx_n_s_path_graph
#define __pyx_n_s_pc __pyx_mstate_global->__pyx_n_s_pc
#define __pyx_n_s_pcar __pyx_mstate_global->__pyx_n_s_pcar
#define __pyx_n_s_pcar_hessenberg __pyx_mstate_global->__pyx_n_s_pcar_hessenberg
#define __pyx_n_s_pcoef __pyx_mstate_global->__pyx_n_s_pcoef
#define __pyx_n_s_pcoeff __pyx_mstate_global->__pyx_n_s_pcoeff
#define __pyx_n_s_pdl __pyx_mstate_global->__pyx_n_s_pdl
#define __pyx_n_s_pencolor __pyx_mstate_global->__pyx_n_s_pencolor
#define __pyx_n_s_pendown __pyx_mstate_global->__pyx_n_s_pendown
#define __pyx_n_s_penup __pyx_mstate_global->__pyx_n_s_penup
#define __pyx_n_s_perimeter __pyx_mstate_global->__pyx_n_s_perimeter
#define __pyx_n_s_perimeterat __pyx_mstate_global->__pyx_n_s_perimeterat
#define __pyx_n_s_perimeteratraw __pyx_mstate_global->__pyx_n_s_perimeteratraw
#define __pyx_n_s_period __pyx_mstate_global->__pyx_n_s_period
#define __pyx_n_s_periodic __pyx_mstate_global->__pyx_n_s_periodic
#define __pyx_n_s_perm __pyx_mstate_global->__pyx_n_s_perm
#define __pyx_n_s_perminv __pyx_mstate_global->__pyx_n_s_perminv
#define __pyx_n_s_permu2cycles __pyx_mstate_global->__pyx_n_s_permu2cycles
#define __pyx_n_s_permu2mat __pyx_mstate_global->__pyx_n_s_permu2mat
#define __pyx_n_s_permuorder __pyx_mstate_global->__pyx_n_s_permuorder
#define __pyx_n_s_permute_vertices __pyx_mstate_global->__pyx_n_s_permute_vertices
#define __pyx_n_s_perpen_bisector __pyx_mstate_global->__pyx_n_s_perpen_bisector
#define __pyx_n_s_perpendicular __pyx_mstate_global->__pyx_n_s_perpendicular
#define __pyx_n_s_petersen_graph __pyx_mstate_global->__pyx_n_s_petersen_graph
#define __pyx_n_s_peval __pyx_mstate_global->__pyx_n_s_peval
#define __pyx_n_s_ph __pyx_mstate_global->__pyx_n_s_ph
#define __pyx_n_s_phi __pyx_mstate_global->__pyx_n_s_phi
#define __pyx_n_s_pi __pyx_mstate_global->__pyx_n_s_pi
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_pie __pyx_mstate_global->__pyx_n_s_pie
#define __pyx_n_s_piecewise __pyx_mstate_global->__pyx_n_s_piecewise
#define __pyx_n_s_pink __pyx_mstate_global->__pyx_n_s_pink
#define __pyx_n_s_pivot __pyx_mstate_global->__pyx_n_s_pivot
#define __pyx_n_s_pixoff __pyx_mstate_global->__pyx_n_s_pixoff
#define __pyx_n_s_pixon __pyx_mstate_global->__pyx_n_s_pixon
#define __pyx_n_s_pk __pyx_mstate_global->__pyx_n_s_pk
#define __pyx_n_s_planar __pyx_mstate_global->__pyx_n_s_planar
#define __pyx_n_s_plane __pyx_mstate_global->__pyx_n_s_plane
#define __pyx_n_s_plane_dual __pyx_mstate_global->__pyx_n_s_plane_dual
#define __pyx_n_s_playsnd __pyx_mstate_global->__pyx_n_s_playsnd
#define __pyx_n_s_plex __pyx_mstate_global->__pyx_n_s_plex
#define __pyx_n_s_plot __pyx_mstate_global->__pyx_n_s_plot
#define __pyx_n_s_plot3d __pyx_mstate_global->__pyx_n_s_plot3d
#define __pyx_n_s_plotarea __pyx_mstate_global->__pyx_n_s_plotarea
#define __pyx_n_s_plotcdf __pyx_mstate_global->__pyx_n_s_plotcdf
#define __pyx_n_s_plotcontour __pyx_mstate_global->__pyx_n_s_plotcontour
#define __pyx_n_s_plotdensity __pyx_mstate_global->__pyx_n_s_plotdensity
#define __pyx_n_s_plotfield __pyx_mstate_global->__pyx_n_s_plotfield
#define __pyx_n_s_plotfunc __pyx_mstate_global->__pyx_n_s_plotfunc
#define __pyx_n_s_plotimf __pyx_mstate_global->__pyx_n_s_plotimf
#define __pyx_n_s_plotimplicit __pyx_mstate_global->__pyx_n_s_plotimplicit
#define __pyx_n_s_plotinequation __pyx_mstate_global->__pyx_n_s_plotinequation
#define __pyx_n_s_plotlist __pyx_mstate_global->__pyx_n_s_plotlist
#define __pyx_n_s_plotode __pyx_mstate_global->__pyx_n_s_plotode
#define __pyx_n_s_plotparam __pyx_mstate_global->__pyx_n_s_plotparam
#define __pyx_n_s_plotpolar __pyx_mstate_global->__pyx_n_s_plotpolar
#define __pyx_n_s_plotproba __pyx_mstate_global->__pyx_n_s_plotproba
#define __pyx_n_s_plotseq __pyx_mstate_global->__pyx_n_s_plotseq
#define __pyx_n_s_plotspectrum __pyx_mstate_global->__pyx_n_s_plotspectrum
#define __pyx_n_s_plotwav __pyx_mstate_global->__pyx_n_s_plotwav
#define __pyx_n_s_plus_point __pyx_mstate_global->__pyx_n_s_plus_point
#define __pyx_n_s_pmin __pyx_mstate_global->__pyx_n_s_pmin
#define __pyx_n_s_pnt __pyx_mstate_global->__pyx_n_s_pnt
#define __pyx_n_s_point __pyx_mstate_global->__pyx_n_s_point
#define __pyx_n_s_point2d __pyx_mstate_global->__pyx_n_s_point2d
#define __pyx_n_s_point3d __pyx_mstate_global->__pyx_n_s_point3d
#define __pyx_n_s_point_arret __pyx_mstate_global->__pyx_n_s_point_arret
#define __pyx_n_s_point_carre __pyx_mstate_global->__pyx_n_s_point_carre
#define __pyx_n_s_point_croix __pyx_mstate_global->__pyx_n_s_point_croix
#define __pyx_n_s_point_div __pyx_mstate_global->__pyx_n_s_point_div
#define __pyx_n_s_point_etoile __pyx_mstate_global->__pyx_n_s_point_etoile
#define __pyx_n_s_point_invisible __pyx_mstate_global->__pyx_n_s_point_invisible
#define __pyx_n_s_point_losange __pyx_mstate_global->__pyx_n_s_point_losange
#define __pyx_n_s_point_milieu __pyx_mstate_global->__pyx_n_s_point_milieu
#define __pyx_n_s_point_plus __pyx_mstate_global->__pyx_n_s_point_plus
#define __pyx_n_s_point_point __pyx_mstate_global->__pyx_n_s_point_point
#define __pyx_n_s_point_polaire __pyx_mstate_global->__pyx_n_s_point_polaire
#define __pyx_n_s_point_triangle __pyx_mstate_global->__pyx_n_s_point_triangle
#define __pyx_n_s_point_width_1 __pyx_mstate_global->__pyx_n_s_point_width_1
#define __pyx_n_s_point_width_2 __pyx_mstate_global->__pyx_n_s_point_width_2
#define __pyx_n_s_point_width_3 __pyx_mstate_global->__pyx_n_s_point_width_3
#define __pyx_n_s_point_width_4 __pyx_mstate_global->__pyx_n_s_point_width_4
#define __pyx_n_s_point_width_5 __pyx_mstate_global->__pyx_n_s_point_width_5
#define __pyx_n_s_point_width_6 __pyx_mstate_global->__pyx_n_s_point_width_6
#define __pyx_n_s_point_width_7 __pyx_mstate_global->__pyx_n_s_point_width_7
#define __pyx_n_s_poisson __pyx_mstate_global->__pyx_n_s_poisson
#define __pyx_n_s_poisson_cdf __pyx_mstate_global->__pyx_n_s_poisson_cdf
#define __pyx_n_s_poisson_icdf __pyx_mstate_global->__pyx_n_s_poisson_icdf
#define __pyx_n_s_poisson_window __pyx_mstate_global->__pyx_n_s_poisson_window
#define __pyx_n_s_polar __pyx_mstate_global->__pyx_n_s_polar
#define __pyx_n_s_polar_coordinates __pyx_mstate_global->__pyx_n_s_polar_coordinates
#define __pyx_n_s_polar_point __pyx_mstate_global->__pyx_n_s_polar_point
#define __pyx_n_s_polarplot __pyx_mstate_global->__pyx_n_s_polarplot
#define __pyx_n_s_pole __pyx_mstate_global->__pyx_n_s_pole
#define __pyx_n_s_poly2symb __pyx_mstate_global->__pyx_n_s_poly2symb
#define __pyx_n_s_polyEval __pyx_mstate_global->__pyx_n_s_polyEval
#define __pyx_n_s_polygon __pyx_mstate_global->__pyx_n_s_polygon
#define __pyx_n_s_polygone_rempli __pyx_mstate_global->__pyx_n_s_polygone_rempli
#define __pyx_n_s_polygonplot __pyx_mstate_global->__pyx_n_s_polygonplot
#define __pyx_n_s_polygonscatterplot __pyx_mstate_global->__pyx_n_s_polygonscatterplot
#define __pyx_n_s_polyhedron __pyx_mstate_global->__pyx_n_s_polyhedron
#define __pyx_n_s_polynom __pyx_mstate_global->__pyx_n_s_polynom
#define __pyx_n_s_polynomial_regression __pyx_mstate_global->__pyx_n_s_polynomial_regression
#define __pyx_n_s_polynomial_regression_plot __pyx_mstate_global->__pyx_n_s_polynomial_regression_plot
#define __pyx_n_s_position __pyx_mstate_global->__pyx_n_s_position
#define __pyx_n_s_poslbdLMQ __pyx_mstate_global->__pyx_n_s_poslbdLMQ
#define __pyx_n_s_posubLMQ __pyx_mstate_global->__pyx_n_s_posubLMQ
#define __pyx_n_s_potential __pyx_mstate_global->__pyx_n_s_potential
#define __pyx_n_s_pour __pyx_mstate_global->__pyx_n_s_pour
#define __pyx_n_s_pow __pyx_mstate_global->__pyx_n_s_pow
#define __pyx_n_s_pow2exp __pyx_mstate_global->__pyx_n_s_pow2exp
#define __pyx_n_s_pow_2 __pyx_mstate_global->__pyx_n_s_pow_2
#define __pyx_n_s_power_regression __pyx_mstate_global->__pyx_n_s_power_regression
#define __pyx_n_s_power_regression_plot __pyx_mstate_global->__pyx_n_s_power_regression_plot
#define __pyx_n_s_powermod __pyx_mstate_global->__pyx_n_s_powermod
#define __pyx_n_s_powerpc __pyx_mstate_global->__pyx_n_s_powerpc
#define __pyx_n_s_powexpand __pyx_mstate_global->__pyx_n_s_powexpand
#define __pyx_n_s_powmod __pyx_mstate_global->__pyx_n_s_powmod
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_prepend __pyx_mstate_global->__pyx_n_s_prepend
#define __pyx_n_s_preval __pyx_mstate_global->__pyx_n_s_preval
#define __pyx_n_s_prevperm __pyx_mstate_global->__pyx_n_s_prevperm
#define __pyx_n_s_prevprime __pyx_mstate_global->__pyx_n_s_prevprime
#define __pyx_n_s_primpart __pyx_mstate_global->__pyx_n_s_primpart
#define __pyx_n_s_print __pyx_mstate_global->__pyx_n_s_print
#define __pyx_n_s_printf __pyx_mstate_global->__pyx_n_s_printf
#define __pyx_kp_s_printpow_1 __pyx_mstate_global->__pyx_kp_s_printpow_1
#define __pyx_n_s_prism __pyx_mstate_global->__pyx_n_s_prism
#define __pyx_n_s_prism_graph __pyx_mstate_global->__pyx_n_s_prism_graph
#define __pyx_n_s_proc __pyx_mstate_global->__pyx_n_s_proc
#define __pyx_n_s_product __pyx_mstate_global->__pyx_n_s_product
#define __pyx_n_s_program __pyx_mstate_global->__pyx_n_s_program
#define __pyx_n_s_projection __pyx_mstate_global->__pyx_n_s_projection
#define __pyx_n_s_proot __pyx_mstate_global->__pyx_n_s_proot
#define __pyx_n_s_propFrac __pyx_mstate_global->__pyx_n_s_propFrac
#define __pyx_n_s_propfrac __pyx_mstate_global->__pyx_n_s_propfrac
#define __pyx_n_s_pruefer_code __pyx_mstate_global->__pyx_n_s_pruefer_code
#define __pyx_n_s_psi __pyx_mstate_global->__pyx_n_s_psi
#define __pyx_n_s_psrgcd __pyx_mstate_global->__pyx_n_s_psrgcd
#define __pyx_n_s_ptUK __pyx_mstate_global->__pyx_n_s_ptUK
#define __pyx_n_s_ptayl __pyx_mstate_global->__pyx_n_s_ptayl
#define __pyx_n_s_purge __pyx_mstate_global->__pyx_n_s_purge
#define __pyx_kp_s_purge_GIACPY_TMP_NAME05026807096 __pyx_mstate_global->__pyx_kp_s_purge_GIACPY_TMP_NAME05026807096
#define __pyx_n_s_purple __pyx_mstate_global->__pyx_n_s_purple
#define __pyx_n_s_pwd __pyx_mstate_global->__pyx_n_s_pwd
#define __pyx_n_s_pyramid __pyx_mstate_global->__pyx_n_s_pyramid
#define __pyx_n_s_python_compat __pyx_mstate_global->__pyx_n_s_python_compat
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_capi __pyx_mstate_global->__pyx_n_s_pyx_capi
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_GiacMethods_base __pyx_mstate_global->__pyx_n_s_pyx_unpickle_GiacMethods_base
#define __pyx_n_s_q __pyx_mstate_global->__pyx_n_s_q
#define __pyx_n_s_q2a __pyx_mstate_global->__pyx_n_s_q2a
#define __pyx_n_s_qcas __pyx_mstate_global->__pyx_n_s_qcas
#define __pyx_kp_u_qcas_line_1879 __pyx_mstate_global->__pyx_kp_u_qcas_line_1879
#define __pyx_n_s_qe __pyx_mstate_global->__pyx_n_s_qe
#define __pyx_n_s_qepsilon0 __pyx_mstate_global->__pyx_n_s_qepsilon0
#define __pyx_n_s_qme __pyx_mstate_global->__pyx_n_s_qme
#define __pyx_n_s_qr __pyx_mstate_global->__pyx_n_s_qr
#define __pyx_n_s_qt __pyx_mstate_global->__pyx_n_s_qt
#define __pyx_n_s_quadrant1 __pyx_mstate_global->__pyx_n_s_quadrant1
#define __pyx_n_s_quadrant2 __pyx_mstate_global->__pyx_n_s_quadrant2
#define __pyx_n_s_quadrant3 __pyx_mstate_global->__pyx_n_s_quadrant3
#define __pyx_n_s_quadrant4 __pyx_mstate_global->__pyx_n_s_quadrant4
#define __pyx_n_s_quadric __pyx_mstate_global->__pyx_n_s_quadric
#define __pyx_n_s_quadrilateral __pyx_mstate_global->__pyx_n_s_quadrilateral
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_quantile __pyx_mstate_global->__pyx_n_s_quantile
#define __pyx_n_s_quartile1 __pyx_mstate_global->__pyx_n_s_quartile1
#define __pyx_n_s_quartile3 __pyx_mstate_global->__pyx_n_s_quartile3
#define __pyx_n_s_quartiles __pyx_mstate_global->__pyx_n_s_quartiles
#define __pyx_n_s_quest __pyx_mstate_global->__pyx_n_s_quest
#define __pyx_n_s_quo __pyx_mstate_global->__pyx_n_s_quo
#define __pyx_n_s_quorem __pyx_mstate_global->__pyx_n_s_quorem
#define __pyx_n_s_quote __pyx_mstate_global->__pyx_n_s_quote
#define __pyx_n_s_r2e __pyx_mstate_global->__pyx_n_s_r2e
#define __pyx_n_s_rad __pyx_mstate_global->__pyx_n_s_rad
#define __pyx_n_s_rad_2 __pyx_mstate_global->__pyx_n_s_rad_2
#define __pyx_kp_s_rad_s __pyx_mstate_global->__pyx_kp_s_rad_s
#define __pyx_kp_s_rad_s_2 __pyx_mstate_global->__pyx_kp_s_rad_s_2
#define __pyx_n_s_radians __pyx_mstate_global->__pyx_n_s_radians
#define __pyx_n_s_radical_axis __pyx_mstate_global->__pyx_n_s_radical_axis
#define __pyx_n_s_radius __pyx_mstate_global->__pyx_n_s_radius
#define __pyx_n_s_ramene __pyx_mstate_global->__pyx_n_s_ramene
#define __pyx_n_s_rand __pyx_mstate_global->__pyx_n_s_rand
#define __pyx_n_s_randMat __pyx_mstate_global->__pyx_n_s_randMat
#define __pyx_n_s_randNorm __pyx_mstate_global->__pyx_n_s_randNorm
#define __pyx_n_s_randPoly __pyx_mstate_global->__pyx_n_s_randPoly
#define __pyx_n_s_randbetad __pyx_mstate_global->__pyx_n_s_randbetad
#define __pyx_n_s_randbinomial __pyx_mstate_global->__pyx_n_s_randbinomial
#define __pyx_n_s_randchisquare __pyx_mstate_global->__pyx_n_s_randchisquare
#define __pyx_n_s_randexp __pyx_mstate_global->__pyx_n_s_randexp
#define __pyx_n_s_randfisher __pyx_mstate_global->__pyx_n_s_randfisher
#define __pyx_n_s_randgammad __pyx_mstate_global->__pyx_n_s_randgammad
#define __pyx_n_s_randgeometric __pyx_mstate_global->__pyx_n_s_randgeometric
#define __pyx_n_s_randint __pyx_mstate_global->__pyx_n_s_randint
#define __pyx_n_s_randmarkov __pyx_mstate_global->__pyx_n_s_randmarkov
#define __pyx_n_s_randmatrix __pyx_mstate_global->__pyx_n_s_randmatrix
#define __pyx_n_s_randmultinomial __pyx_mstate_global->__pyx_n_s_randmultinomial
#define __pyx_n_s_randnorm __pyx_mstate_global->__pyx_n_s_randnorm
#define __pyx_n_s_random __pyx_mstate_global->__pyx_n_s_random
#define __pyx_n_s_random_bipartite_graph __pyx_mstate_global->__pyx_n_s_random_bipartite_graph
#define __pyx_n_s_random_digraph __pyx_mstate_global->__pyx_n_s_random_digraph
#define __pyx_n_s_random_graph __pyx_mstate_global->__pyx_n_s_random_graph
#define __pyx_n_s_random_network __pyx_mstate_global->__pyx_n_s_random_network
#define __pyx_n_s_random_planar_graph __pyx_mstate_global->__pyx_n_s_random_planar_graph
#define __pyx_n_s_random_regular_graph __pyx_mstate_global->__pyx_n_s_random_regular_graph
#define __pyx_n_s_random_sequence_graph __pyx_mstate_global->__pyx_n_s_random_sequence_graph
#define __pyx_n_s_random_tournament __pyx_mstate_global->__pyx_n_s_random_tournament
#define __pyx_n_s_random_tree __pyx_mstate_global->__pyx_n_s_random_tree
#define __pyx_n_s_random_variable __pyx_mstate_global->__pyx_n_s_random_variable
#define __pyx_n_s_randperm __pyx_mstate_global->__pyx_n_s_randperm
#define __pyx_n_s_randpoisson __pyx_mstate_global->__pyx_n_s_randpoisson
#define __pyx_n_s_randpoly __pyx_mstate_global->__pyx_n_s_randpoly
#define __pyx_n_s_randseed __pyx_mstate_global->__pyx_n_s_randseed
#define __pyx_n_s_randstudent __pyx_mstate_global->__pyx_n_s_randstudent
#define __pyx_n_s_randvar __pyx_mstate_global->__pyx_n_s_randvar
#define __pyx_n_s_randvector __pyx_mstate_global->__pyx_n_s_randvector
#define __pyx_n_s_randweibulld __pyx_mstate_global->__pyx_n_s_randweibulld
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_rank __pyx_mstate_global->__pyx_n_s_rank
#define __pyx_n_s_ranm __pyx_mstate_global->__pyx_n_s_ranm
#define __pyx_n_s_ranv __pyx_mstate_global->__pyx_n_s_ranv
#define __pyx_n_s_rassembler_trigo __pyx_mstate_global->__pyx_n_s_rassembler_trigo
#define __pyx_n_s_rat_jordan __pyx_mstate_global->__pyx_n_s_rat_jordan
#define __pyx_n_s_ratinterp __pyx_mstate_global->__pyx_n_s_ratinterp
#define __pyx_n_s_rational __pyx_mstate_global->__pyx_n_s_rational
#define __pyx_n_s_rationalroot __pyx_mstate_global->__pyx_n_s_rationalroot
#define __pyx_n_s_ratnormal __pyx_mstate_global->__pyx_n_s_ratnormal
#define __pyx_n_s_rd __pyx_mstate_global->__pyx_n_s_rd
#define __pyx_n_s_rdiv __pyx_mstate_global->__pyx_n_s_rdiv
#define __pyx_n_s_re __pyx_mstate_global->__pyx_n_s_re
#define __pyx_n_s_reachable __pyx_mstate_global->__pyx_n_s_reachable
#define __pyx_n_s_read __pyx_mstate_global->__pyx_n_s_read
#define __pyx_n_s_readrgb __pyx_mstate_global->__pyx_n_s_readrgb
#define __pyx_n_s_readwav __pyx_mstate_global->__pyx_n_s_readwav
#define __pyx_n_s_real __pyx_mstate_global->__pyx_n_s_real
#define __pyx_n_s_realroot __pyx_mstate_global->__pyx_n_s_realroot
#define __pyx_n_s_reciprocation __pyx_mstate_global->__pyx_n_s_reciprocation
#define __pyx_n_s_rect __pyx_mstate_global->__pyx_n_s_rect
#define __pyx_n_s_rectangle __pyx_mstate_global->__pyx_n_s_rectangle
#define __pyx_n_s_rectangle_droit __pyx_mstate_global->__pyx_n_s_rectangle_droit
#define __pyx_n_s_rectangle_gauche __pyx_mstate_global->__pyx_n_s_rectangle_gauche
#define __pyx_n_s_rectangle_plein __pyx_mstate_global->__pyx_n_s_rectangle_plein
#define __pyx_n_s_rectangular_coordinates __pyx_mstate_global->__pyx_n_s_rectangular_coordinates
#define __pyx_n_s_recule __pyx_mstate_global->__pyx_n_s_recule
#define __pyx_n_s_red __pyx_mstate_global->__pyx_n_s_red
#define __pyx_n_s_redim __pyx_mstate_global->__pyx_n_s_redim
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_reduced_conic __pyx_mstate_global->__pyx_n_s_reduced_conic
#define __pyx_n_s_reduced_quadric __pyx_mstate_global->__pyx_n_s_reduced_quadric
#define __pyx_n_s_ref __pyx_mstate_global->__pyx_n_s_ref
#define __pyx_n_s_reflection __pyx_mstate_global->__pyx_n_s_reflection
#define __pyx_n_s_regroup __pyx_mstate_global->__pyx_n_s_regroup
#define __pyx_n_s_relabel_vertices __pyx_mstate_global->__pyx_n_s_relabel_vertices
#define __pyx_n_s_reliability_polynomial __pyx_mstate_global->__pyx_n_s_reliability_polynomial
#define __pyx_n_s_rem __pyx_mstate_global->__pyx_n_s_rem
#define __pyx_n_s_rem_2 __pyx_mstate_global->__pyx_n_s_rem_2
#define __pyx_n_s_remain __pyx_mstate_global->__pyx_n_s_remain
#define __pyx_n_s_remove __pyx_mstate_global->__pyx_n_s_remove
#define __pyx_n_s_reorder __pyx_mstate_global->__pyx_n_s_reorder
#define __pyx_n_s_repeat __pyx_mstate_global->__pyx_n_s_repeat
#define __pyx_n_s_repete __pyx_mstate_global->__pyx_n_s_repete
#define __pyx_n_s_repeter __pyx_mstate_global->__pyx_n_s_repeter
#define __pyx_n_s_replace __pyx_mstate_global->__pyx_n_s_replace
#define __pyx_n_s_repr __pyx_mstate_global->__pyx_n_s_repr
#define __pyx_n_s_repr_html __pyx_mstate_global->__pyx_n_s_repr_html
#define __pyx_n_s_repr_latex __pyx_mstate_global->__pyx_n_s_repr_latex
#define __pyx_n_s_resample __pyx_mstate_global->__pyx_n_s_resample
#define __pyx_n_s_residue __pyx_mstate_global->__pyx_n_s_residue
#define __pyx_n_s_resoudre __pyx_mstate_global->__pyx_n_s_resoudre
#define __pyx_n_s_resoudre_dans_C __pyx_mstate_global->__pyx_n_s_resoudre_dans_C
#define __pyx_n_s_resoudre_systeme_lineaire __pyx_mstate_global->__pyx_n_s_resoudre_systeme_lineaire
#define __pyx_n_s_restart __pyx_mstate_global->__pyx_n_s_restart
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_resultant __pyx_mstate_global->__pyx_n_s_resultant
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_reverse __pyx_mstate_global->__pyx_n_s_reverse
#define __pyx_n_s_reverse_graph __pyx_mstate_global->__pyx_n_s_reverse_graph
#define __pyx_n_s_reverse_rsolve __pyx_mstate_global->__pyx_n_s_reverse_rsolve
#define __pyx_n_s_revert __pyx_mstate_global->__pyx_n_s_revert
#define __pyx_n_s_revlex __pyx_mstate_global->__pyx_n_s_revlex
#define __pyx_n_s_revlist __pyx_mstate_global->__pyx_n_s_revlist
#define __pyx_n_s_rgb __pyx_mstate_global->__pyx_n_s_rgb
#define __pyx_n_s_rgb2hsv __pyx_mstate_global->__pyx_n_s_rgb2hsv
#define __pyx_n_s_rgb2xyz __pyx_mstate_global->__pyx_n_s_rgb2xyz
#define __pyx_n_s_rhombus __pyx_mstate_global->__pyx_n_s_rhombus
#define __pyx_n_s_rhombus_point __pyx_mstate_global->__pyx_n_s_rhombus_point
#define __pyx_n_s_rhs __pyx_mstate_global->__pyx_n_s_rhs
#define __pyx_n_s_riemann_window __pyx_mstate_global->__pyx_n_s_riemann_window
#define __pyx_n_s_right __pyx_mstate_global->__pyx_n_s_right
#define __pyx_n_s_right_rectangle __pyx_mstate_global->__pyx_n_s_right_rectangle
#define __pyx_n_s_right_triangle __pyx_mstate_global->__pyx_n_s_right_triangle
#define __pyx_n_s_risch __pyx_mstate_global->__pyx_n_s_risch
#define __pyx_n_s_rm_a_z __pyx_mstate_global->__pyx_n_s_rm_a_z
#define __pyx_n_s_rm_all_vars __pyx_mstate_global->__pyx_n_s_rm_all_vars
#define __pyx_n_s_rmbreakpoint __pyx_mstate_global->__pyx_n_s_rmbreakpoint
#define __pyx_n_s_rmmod __pyx_mstate_global->__pyx_n_s_rmmod
#define __pyx_n_s_rms __pyx_mstate_global->__pyx_n_s_rms
#define __pyx_n_s_rmwatch __pyx_mstate_global->__pyx_n_s_rmwatch
#define __pyx_n_s_rod __pyx_mstate_global->__pyx_n_s_rod
#define __pyx_n_s_romberg __pyx_mstate_global->__pyx_n_s_romberg
#define __pyx_n_s_rombergm __pyx_mstate_global->__pyx_n_s_rombergm
#define __pyx_n_s_rombergt __pyx_mstate_global->__pyx_n_s_rombergt
#define __pyx_n_s_rond __pyx_mstate_global->__pyx_n_s_rond
#define __pyx_n_s_root __pyx_mstate_global->__pyx_n_s_root
#define __pyx_n_s_rootof __pyx_mstate_global->__pyx_n_s_rootof
#define __pyx_n_s_roots __pyx_mstate_global->__pyx_n_s_roots
#define __pyx_n_s_rotate __pyx_mstate_global->__pyx_n_s_rotate
#define __pyx_n_s_rotation __pyx_mstate_global->__pyx_n_s_rotation
#define __pyx_n_s_rouge __pyx_mstate_global->__pyx_n_s_rouge
#define __pyx_n_s_round __pyx_mstate_global->__pyx_n_s_round
#define __pyx_n_s_row __pyx_mstate_global->__pyx_n_s_row
#define __pyx_n_s_rowAdd __pyx_mstate_global->__pyx_n_s_rowAdd
#define __pyx_n_s_rowDim __pyx_mstate_global->__pyx_n_s_rowDim
#define __pyx_n_s_rowNorm __pyx_mstate_global->__pyx_n_s_rowNorm
#define __pyx_n_s_rowSwap __pyx_mstate_global->__pyx_n_s_rowSwap
#define __pyx_n_s_rowdim __pyx_mstate_global->__pyx_n_s_rowdim
#define __pyx_n_s_rownorm __pyx_mstate_global->__pyx_n_s_rownorm
#define __pyx_n_s_rowspace __pyx_mstate_global->__pyx_n_s_rowspace
#define __pyx_n_s_rowswap __pyx_mstate_global->__pyx_n_s_rowswap
#define __pyx_n_s_rpm __pyx_mstate_global->__pyx_n_s_rpm
#define __pyx_n_s_rref __pyx_mstate_global->__pyx_n_s_rref
#define __pyx_n_s_rsolve __pyx_mstate_global->__pyx_n_s_rsolve
#define __pyx_n_s_rur __pyx_mstate_global->__pyx_n_s_rur
#define __pyx_n_s_rur_certify __pyx_mstate_global->__pyx_n_s_rur_certify
#define __pyx_n_s_rur_gbasis __pyx_mstate_global->__pyx_n_s_rur_gbasis
#define __pyx_n_s_s __pyx_mstate_global->__pyx_n_s_s
#define __pyx_n_s_s_2 __pyx_mstate_global->__pyx_n_s_s_2
#define __pyx_kp_s_s_s __pyx_mstate_global->__pyx_kp_s_s_s
#define __pyx_n_s_saisir __pyx_mstate_global->__pyx_n_s_saisir
#define __pyx_n_s_saisir_chaine __pyx_mstate_global->__pyx_n_s_saisir_chaine
#define __pyx_n_s_same __pyx_mstate_global->__pyx_n_s_same
#define __pyx_n_s_sample __pyx_mstate_global->__pyx_n_s_sample
#define __pyx_n_s_samplerate __pyx_mstate_global->__pyx_n_s_samplerate
#define __pyx_n_s_sans_factoriser __pyx_mstate_global->__pyx_n_s_sans_factoriser
#define __pyx_n_s_saute __pyx_mstate_global->__pyx_n_s_saute
#define __pyx_n_s_sauve __pyx_mstate_global->__pyx_n_s_sauve
#define __pyx_n_s_save __pyx_mstate_global->__pyx_n_s_save
#define __pyx_n_s_save_history __pyx_mstate_global->__pyx_n_s_save_history
#define __pyx_n_s_sb __pyx_mstate_global->__pyx_n_s_sb
#define __pyx_n_s_scalarProduct __pyx_mstate_global->__pyx_n_s_scalarProduct
#define __pyx_n_s_scalar_product __pyx_mstate_global->__pyx_n_s_scalar_product
#define __pyx_n_s_scale __pyx_mstate_global->__pyx_n_s_scale
#define __pyx_n_s_scaleadd __pyx_mstate_global->__pyx_n_s_scaleadd
#define __pyx_n_s_scatterplot __pyx_mstate_global->__pyx_n_s_scatterplot
#define __pyx_n_s_schur __pyx_mstate_global->__pyx_n_s_schur
#define __pyx_n_s_sd __pyx_mstate_global->__pyx_n_s_sd
#define __pyx_n_s_sec __pyx_mstate_global->__pyx_n_s_sec
#define __pyx_n_s_secant_solver __pyx_mstate_global->__pyx_n_s_secant_solver
#define __pyx_n_s_segment __pyx_mstate_global->__pyx_n_s_segment
#define __pyx_n_s_seidel_spectrum __pyx_mstate_global->__pyx_n_s_seidel_spectrum
#define __pyx_n_s_seidel_switch __pyx_mstate_global->__pyx_n_s_seidel_switch
#define __pyx_n_s_select __pyx_mstate_global->__pyx_n_s_select
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_kp_s_self_is_not_a_giac_List __pyx_mstate_global->__pyx_kp_s_self_is_not_a_giac_List
#define __pyx_kp_s_self_is_not_a_giac_integer __pyx_mstate_global->__pyx_kp_s_self_is_not_a_giac_integer
#define __pyx_kp_s_self_is_not_a_giac_real __pyx_mstate_global->__pyx_kp_s_self_is_not_a_giac_real
#define __pyx_n_s_semi_augment __pyx_mstate_global->__pyx_n_s_semi_augment
#define __pyx_n_s_send __pyx_mstate_global->__pyx_n_s_send
#define __pyx_n_s_seq __pyx_mstate_global->__pyx_n_s_seq
#define __pyx_n_s_seqplot __pyx_mstate_global->__pyx_n_s_seqplot
#define __pyx_n_s_seqsolve __pyx_mstate_global->__pyx_n_s_seqsolve
#define __pyx_n_s_sequence_graph __pyx_mstate_global->__pyx_n_s_sequence_graph
#define __pyx_n_s_series __pyx_mstate_global->__pyx_n_s_series
#define __pyx_kp_s_set __pyx_mstate_global->__pyx_kp_s_set
#define __pyx_n_s_set_channel_data __pyx_mstate_global->__pyx_n_s_set_channel_data
#define __pyx_n_s_set_edge_attribute __pyx_mstate_global->__pyx_n_s_set_edge_attribute
#define __pyx_n_s_set_edge_weight __pyx_mstate_global->__pyx_n_s_set_edge_weight
#define __pyx_n_s_set_graph_attribute __pyx_mstate_global->__pyx_n_s_set_graph_attribute
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_set_pixel __pyx_mstate_global->__pyx_n_s_set_pixel
#define __pyx_n_s_set_screen __pyx_mstate_global->__pyx_n_s_set_screen
#define __pyx_n_s_set_vertex_attribute __pyx_mstate_global->__pyx_n_s_set_vertex_attribute
#define __pyx_n_s_set_vertex_positions __pyx_mstate_global->__pyx_n_s_set_vertex_positions
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_shift __pyx_mstate_global->__pyx_n_s_shift
#define __pyx_n_s_shift_phase __pyx_mstate_global->__pyx_n_s_shift_phase
#define __pyx_n_s_shortest_path __pyx_mstate_global->__pyx_n_s_shortest_path
#define __pyx_n_s_show_pixels __pyx_mstate_global->__pyx_n_s_show_pixels
#define __pyx_n_s_shuffle __pyx_mstate_global->__pyx_n_s_shuffle
#define __pyx_n_s_si __pyx_mstate_global->__pyx_n_s_si
#define __pyx_n_s_sierpinski_graph __pyx_mstate_global->__pyx_n_s_sierpinski_graph
#define __pyx_n_s_sigma __pyx_mstate_global->__pyx_n_s_sigma
#define __pyx_n_s_sign __pyx_mstate_global->__pyx_n_s_sign
#define __pyx_n_s_sign2Heaviside __pyx_mstate_global->__pyx_n_s_sign2Heaviside
#define __pyx_n_s_signature __pyx_mstate_global->__pyx_n_s_signature
#define __pyx_n_s_signe __pyx_mstate_global->__pyx_n_s_signe
#define __pyx_n_s_similarity __pyx_mstate_global->__pyx_n_s_similarity
#define __pyx_n_s_simp2 __pyx_mstate_global->__pyx_n_s_simp2
#define __pyx_n_s_simplex_reduce __pyx_mstate_global->__pyx_n_s_simplex_reduce
#define __pyx_n_s_simplicial_vertices __pyx_mstate_global->__pyx_n_s_simplicial_vertices
#define __pyx_n_s_simplifier __pyx_mstate_global->__pyx_n_s_simplifier
#define __pyx_n_s_simplify __pyx_mstate_global->__pyx_n_s_simplify
#define __pyx_n_s_simplifyDirac __pyx_mstate_global->__pyx_n_s_simplifyDirac
#define __pyx_n_s_simpson __pyx_mstate_global->__pyx_n_s_simpson
#define __pyx_n_s_simulated_annealing __pyx_mstate_global->__pyx_n_s_simulated_annealing
#define __pyx_n_s_simult __pyx_mstate_global->__pyx_n_s_simult
#define __pyx_n_s_sin __pyx_mstate_global->__pyx_n_s_sin
#define __pyx_n_s_sin2costan __pyx_mstate_global->__pyx_n_s_sin2costan
#define __pyx_n_s_sinc __pyx_mstate_global->__pyx_n_s_sinc
#define __pyx_n_s_sincos __pyx_mstate_global->__pyx_n_s_sincos
#define __pyx_n_s_single_inter __pyx_mstate_global->__pyx_n_s_single_inter
#define __pyx_n_s_sinh __pyx_mstate_global->__pyx_n_s_sinh
#define __pyx_n_s_sinon __pyx_mstate_global->__pyx_n_s_sinon
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_s_sizes __pyx_mstate_global->__pyx_n_s_sizes
#define __pyx_n_s_sleep __pyx_mstate_global->__pyx_n_s_sleep
#define __pyx_n_s_slope __pyx_mstate_global->__pyx_n_s_slope
#define __pyx_n_s_slopeat __pyx_mstate_global->__pyx_n_s_slopeat
#define __pyx_n_s_slopeatraw __pyx_mstate_global->__pyx_n_s_slopeatraw
#define __pyx_n_s_slug __pyx_mstate_global->__pyx_n_s_slug
#define __pyx_n_s_smith __pyx_mstate_global->__pyx_n_s_smith
#define __pyx_n_s_smod __pyx_mstate_global->__pyx_n_s_smod
#define __pyx_n_s_snedecor __pyx_mstate_global->__pyx_n_s_snedecor
#define __pyx_n_s_snedecor_cdf __pyx_mstate_global->__pyx_n_s_snedecor_cdf
#define __pyx_n_s_snedecor_icdf __pyx_mstate_global->__pyx_n_s_snedecor_icdf
#define __pyx_n_s_snedecord __pyx_mstate_global->__pyx_n_s_snedecord
#define __pyx_n_s_snedecord_cdf __pyx_mstate_global->__pyx_n_s_snedecord_cdf
#define __pyx_n_s_snedecord_icdf __pyx_mstate_global->__pyx_n_s_snedecord_icdf
#define __pyx_n_s_solid_line __pyx_mstate_global->__pyx_n_s_solid_line
#define __pyx_n_s_solve __pyx_mstate_global->__pyx_n_s_solve
#define __pyx_n_s_somme __pyx_mstate_global->__pyx_n_s_somme
#define __pyx_n_s_sommet __pyx_mstate_global->__pyx_n_s_sommet
#define __pyx_n_s_sort __pyx_mstate_global->__pyx_n_s_sort
#define __pyx_n_s_sorta __pyx_mstate_global->__pyx_n_s_sorta
#define __pyx_n_s_sortd __pyx_mstate_global->__pyx_n_s_sortd
#define __pyx_n_s_sorted __pyx_mstate_global->__pyx_n_s_sorted
#define __pyx_n_s_sortperm __pyx_mstate_global->__pyx_n_s_sortperm
#define __pyx_n_s_soundsec __pyx_mstate_global->__pyx_n_s_soundsec
#define __pyx_n_s_spanning_tree __pyx_mstate_global->__pyx_n_s_spanning_tree
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_sphere __pyx_mstate_global->__pyx_n_s_sphere
#define __pyx_n_s_splice __pyx_mstate_global->__pyx_n_s_splice
#define __pyx_n_s_spline __pyx_mstate_global->__pyx_n_s_spline
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_spring __pyx_mstate_global->__pyx_n_s_spring
#define __pyx_n_s_sq __pyx_mstate_global->__pyx_n_s_sq
#define __pyx_n_s_sqrfree __pyx_mstate_global->__pyx_n_s_sqrfree
#define __pyx_n_s_sqrt __pyx_mstate_global->__pyx_n_s_sqrt
#define __pyx_n_s_square __pyx_mstate_global->__pyx_n_s_square
#define __pyx_n_s_square_point __pyx_mstate_global->__pyx_n_s_square_point
#define __pyx_n_s_sr __pyx_mstate_global->__pyx_n_s_sr
#define __pyx_n_s_srand __pyx_mstate_global->__pyx_n_s_srand
#define __pyx_n_s_sst __pyx_mstate_global->__pyx_n_s_sst
#define __pyx_n_s_sst_in __pyx_mstate_global->__pyx_n_s_sst_in
#define __pyx_n_s_st __pyx_mstate_global->__pyx_n_s_st
#define __pyx_n_s_st_ordering __pyx_mstate_global->__pyx_n_s_st_ordering
#define __pyx_n_s_stack __pyx_mstate_global->__pyx_n_s_stack
#define __pyx_n_s_star_graph __pyx_mstate_global->__pyx_n_s_star_graph
#define __pyx_n_s_star_point __pyx_mstate_global->__pyx_n_s_star_point
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_stdDev __pyx_mstate_global->__pyx_n_s_stdDev
#define __pyx_n_s_stddev __pyx_mstate_global->__pyx_n_s_stddev
#define __pyx_n_s_stddevp __pyx_mstate_global->__pyx_n_s_stddevp
#define __pyx_n_s_steffenson_solver __pyx_mstate_global->__pyx_n_s_steffenson_solver
#define __pyx_n_s_step __pyx_mstate_global->__pyx_n_s_step
#define __pyx_n_s_stereo2mono __pyx_mstate_global->__pyx_n_s_stereo2mono
#define __pyx_n_s_stft __pyx_mstate_global->__pyx_n_s_stft
#define __pyx_n_s_sto __pyx_mstate_global->__pyx_n_s_sto
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_n_s_str_2 __pyx_mstate_global->__pyx_n_s_str_2
#define __pyx_n_s_string __pyx_mstate_global->__pyx_n_s_string
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_strip __pyx_mstate_global->__pyx_n_s_strip
#define __pyx_n_s_strongly_connected_components __pyx_mstate_global->__pyx_n_s_strongly_connected_components
#define __pyx_n_s_student __pyx_mstate_global->__pyx_n_s_student
#define __pyx_n_s_student_cdf __pyx_mstate_global->__pyx_n_s_student_cdf
#define __pyx_n_s_student_icdf __pyx_mstate_global->__pyx_n_s_student_icdf
#define __pyx_n_s_studentd __pyx_mstate_global->__pyx_n_s_studentd
#define __pyx_n_s_studentt __pyx_mstate_global->__pyx_n_s_studentt
#define __pyx_n_s_sturm __pyx_mstate_global->__pyx_n_s_sturm
#define __pyx_n_s_sturmab __pyx_mstate_global->__pyx_n_s_sturmab
#define __pyx_n_s_sturmseq __pyx_mstate_global->__pyx_n_s_sturmseq
#define __pyx_n_s_style __pyx_mstate_global->__pyx_n_s_style
#define __pyx_n_s_sub __pyx_mstate_global->__pyx_n_s_sub
#define __pyx_n_s_subMat __pyx_mstate_global->__pyx_n_s_subMat
#define __pyx_n_s_subdivide_edges __pyx_mstate_global->__pyx_n_s_subdivide_edges
#define __pyx_n_s_subgraph __pyx_mstate_global->__pyx_n_s_subgraph
#define __pyx_n_s_subs __pyx_mstate_global->__pyx_n_s_subs
#define __pyx_n_s_subsop __pyx_mstate_global->__pyx_n_s_subsop
#define __pyx_n_s_subst __pyx_mstate_global->__pyx_n_s_subst
#define __pyx_n_s_substituer __pyx_mstate_global->__pyx_n_s_substituer
#define __pyx_n_s_subtype __pyx_mstate_global->__pyx_n_s_subtype
#define __pyx_n_s_subtype_2 __pyx_mstate_global->__pyx_n_s_subtype_2
#define __pyx_n_s_sum __pyx_mstate_global->__pyx_n_s_sum
#define __pyx_n_s_sum_riemann __pyx_mstate_global->__pyx_n_s_sum_riemann
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_supposons __pyx_mstate_global->__pyx_n_s_supposons
#define __pyx_n_s_suppress __pyx_mstate_global->__pyx_n_s_suppress
#define __pyx_n_s_surd __pyx_mstate_global->__pyx_n_s_surd
#define __pyx_n_s_svd __pyx_mstate_global->__pyx_n_s_svd
#define __pyx_n_s_swapcol __pyx_mstate_global->__pyx_n_s_swapcol
#define __pyx_n_s_swaprow __pyx_mstate_global->__pyx_n_s_swaprow
#define __pyx_n_s_switch __pyx_mstate_global->__pyx_n_s_switch
#define __pyx_n_s_switch_axes __pyx_mstate_global->__pyx_n_s_switch_axes
#define __pyx_n_s_sylvester __pyx_mstate_global->__pyx_n_s_sylvester
#define __pyx_n_s_symb2poly __pyx_mstate_global->__pyx_n_s_symb2poly
#define __pyx_n_s_symbol __pyx_mstate_global->__pyx_n_s_symbol
#define __pyx_n_s_symbol_array __pyx_mstate_global->__pyx_n_s_symbol_array
#define __pyx_n_s_syr __pyx_mstate_global->__pyx_n_s_syr
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_s_syst2mat __pyx_mstate_global->__pyx_n_s_syst2mat
#define __pyx_n_s_t __pyx_mstate_global->__pyx_n_s_t
#define __pyx_n_s_tCollect __pyx_mstate_global->__pyx_n_s_tCollect
#define __pyx_n_s_tExpand __pyx_mstate_global->__pyx_n_s_tExpand
#define __pyx_n_s_table __pyx_mstate_global->__pyx_n_s_table
#define __pyx_n_s_tablefunc __pyx_mstate_global->__pyx_n_s_tablefunc
#define __pyx_n_s_tableseq __pyx_mstate_global->__pyx_n_s_tableseq
#define __pyx_n_s_tabsign __pyx_mstate_global->__pyx_n_s_tabsign
#define __pyx_n_s_tabvar __pyx_mstate_global->__pyx_n_s_tabvar
#define __pyx_n_s_tail __pyx_mstate_global->__pyx_n_s_tail
#define __pyx_n_s_tan __pyx_mstate_global->__pyx_n_s_tan
#define __pyx_n_s_tan2cossin2 __pyx_mstate_global->__pyx_n_s_tan2cossin2
#define __pyx_n_s_tan2sincos __pyx_mstate_global->__pyx_n_s_tan2sincos
#define __pyx_n_s_tan2sincos2 __pyx_mstate_global->__pyx_n_s_tan2sincos2
#define __pyx_n_s_tangent __pyx_mstate_global->__pyx_n_s_tangent
#define __pyx_n_s_tangente __pyx_mstate_global->__pyx_n_s_tangente
#define __pyx_n_s_tanh __pyx_mstate_global->__pyx_n_s_tanh
#define __pyx_n_s_tantque __pyx_mstate_global->__pyx_n_s_tantque
#define __pyx_n_s_tar __pyx_mstate_global->__pyx_n_s_tar
#define __pyx_n_s_taux_accroissement __pyx_mstate_global->__pyx_n_s_taux_accroissement
#define __pyx_n_s_taylor __pyx_mstate_global->__pyx_n_s_taylor
#define __pyx_n_s_tbsp __pyx_mstate_global->__pyx_n_s_tbsp
#define __pyx_n_s_tchebyshev1 __pyx_mstate_global->__pyx_n_s_tchebyshev1
#define __pyx_n_s_tchebyshev2 __pyx_mstate_global->__pyx_n_s_tchebyshev2
#define __pyx_n_s_tcoeff __pyx_mstate_global->__pyx_n_s_tcoeff
#define __pyx_n_s_tcollect __pyx_mstate_global->__pyx_n_s_tcollect
#define __pyx_n_s_tdeg __pyx_mstate_global->__pyx_n_s_tdeg
#define __pyx_n_s_teal __pyx_mstate_global->__pyx_n_s_teal
#define __pyx_n_s_tec __pyx_mstate_global->__pyx_n_s_tec
#define __pyx_n_s_tensor_product __pyx_mstate_global->__pyx_n_s_tensor_product
#define __pyx_n_s_tep __pyx_mstate_global->__pyx_n_s_tep
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_test_2 __pyx_mstate_global->__pyx_n_s_test_2
#define __pyx_n_s_tetrahedron __pyx_mstate_global->__pyx_n_s_tetrahedron
#define __pyx_n_s_tex __pyx_mstate_global->__pyx_n_s_tex
#define __pyx_n_s_texpand __pyx_mstate_global->__pyx_n_s_texpand
#define __pyx_n_s_textinput __pyx_mstate_global->__pyx_n_s_textinput
#define __pyx_n_s_then __pyx_mstate_global->__pyx_n_s_then
#define __pyx_n_s_therm __pyx_mstate_global->__pyx_n_s_therm
#define __pyx_n_s_thickness __pyx_mstate_global->__pyx_n_s_thickness
#define __pyx_n_s_thiele __pyx_mstate_global->__pyx_n_s_thiele
#define __pyx_n_s_threadeval __pyx_mstate_global->__pyx_n_s_threadeval
#define __pyx_kp_s_threads_s __pyx_mstate_global->__pyx_kp_s_threads_s
#define __pyx_n_s_threshold __pyx_mstate_global->__pyx_n_s_threshold
#define __pyx_n_s_throw __pyx_mstate_global->__pyx_n_s_throw
#define __pyx_n_s_time __pyx_mstate_global->__pyx_n_s_time
#define __pyx_n_s_title __pyx_mstate_global->__pyx_n_s_title
#define __pyx_n_s_titre __pyx_mstate_global->__pyx_n_s_titre
#define __pyx_n_s_tlin __pyx_mstate_global->__pyx_n_s_tlin
#define __pyx_n_s_tmp __pyx_mstate_global->__pyx_n_s_tmp
#define __pyx_n_s_to __pyx_mstate_global->__pyx_n_s_to
#define __pyx_n_s_ton __pyx_mstate_global->__pyx_n_s_ton
#define __pyx_n_s_tonUK __pyx_mstate_global->__pyx_n_s_tonUK
#define __pyx_n_s_tonnetz __pyx_mstate_global->__pyx_n_s_tonnetz
#define __pyx_n_s_topologic_sort __pyx_mstate_global->__pyx_n_s_topologic_sort
#define __pyx_n_s_topological_sort __pyx_mstate_global->__pyx_n_s_topological_sort
#define __pyx_n_s_topology __pyx_mstate_global->__pyx_n_s_topology
#define __pyx_n_s_toqcas __pyx_mstate_global->__pyx_n_s_toqcas
#define __pyx_n_s_toremove __pyx_mstate_global->__pyx_n_s_toremove
#define __pyx_n_s_torr __pyx_mstate_global->__pyx_n_s_torr
#define __pyx_n_s_torus_grid_graph __pyx_mstate_global->__pyx_n_s_torus_grid_graph
#define __pyx_n_s_total_degree __pyx_mstate_global->__pyx_n_s_total_degree
#define __pyx_n_s_tourne_droite __pyx_mstate_global->__pyx_n_s_tourne_droite
#define __pyx_n_s_tourne_gauche __pyx_mstate_global->__pyx_n_s_tourne_gauche
#define __pyx_n_s_tpsolve __pyx_mstate_global->__pyx_n_s_tpsolve
#define __pyx_n_s_tr __pyx_mstate_global->__pyx_n_s_tr
#define __pyx_kp_s_tr_min __pyx_mstate_global->__pyx_kp_s_tr_min
#define __pyx_kp_s_tr_s __pyx_mstate_global->__pyx_kp_s_tr_s
#define __pyx_n_s_trace __pyx_mstate_global->__pyx_n_s_trace
#define __pyx_n_s_trail __pyx_mstate_global->__pyx_n_s_trail
#define __pyx_n_s_trail2edges __pyx_mstate_global->__pyx_n_s_trail2edges
#define __pyx_n_s_train __pyx_mstate_global->__pyx_n_s_train
#define __pyx_n_s_trames __pyx_mstate_global->__pyx_n_s_trames
#define __pyx_n_s_tran __pyx_mstate_global->__pyx_n_s_tran
#define __pyx_n_s_transitive_closure __pyx_mstate_global->__pyx_n_s_transitive_closure
#define __pyx_n_s_translation __pyx_mstate_global->__pyx_n_s_translation
#define __pyx_n_s_transpose __pyx_mstate_global->__pyx_n_s_transpose
#define __pyx_n_s_trapeze __pyx_mstate_global->__pyx_n_s_trapeze
#define __pyx_n_s_trapezoid __pyx_mstate_global->__pyx_n_s_trapezoid
#define __pyx_n_s_traveling_salesman __pyx_mstate_global->__pyx_n_s_traveling_salesman
#define __pyx_n_s_tree __pyx_mstate_global->__pyx_n_s_tree
#define __pyx_n_s_tree_height __pyx_mstate_global->__pyx_n_s_tree_height
#define __pyx_n_s_tri __pyx_mstate_global->__pyx_n_s_tri
#define __pyx_n_s_triangle __pyx_mstate_global->__pyx_n_s_triangle
#define __pyx_n_s_triangle_paper __pyx_mstate_global->__pyx_n_s_triangle_paper
#define __pyx_n_s_triangle_plein __pyx_mstate_global->__pyx_n_s_triangle_plein
#define __pyx_n_s_triangle_point __pyx_mstate_global->__pyx_n_s_triangle_point
#define __pyx_n_s_triangle_window __pyx_mstate_global->__pyx_n_s_triangle_window
#define __pyx_n_s_trig2exp __pyx_mstate_global->__pyx_n_s_trig2exp
#define __pyx_n_s_trigcos __pyx_mstate_global->__pyx_n_s_trigcos
#define __pyx_n_s_trigexpand __pyx_mstate_global->__pyx_n_s_trigexpand
#define __pyx_n_s_triginterp __pyx_mstate_global->__pyx_n_s_triginterp
#define __pyx_n_s_trigsimplify __pyx_mstate_global->__pyx_n_s_trigsimplify
#define __pyx_n_s_trigsin __pyx_mstate_global->__pyx_n_s_trigsin
#define __pyx_n_s_trigtan __pyx_mstate_global->__pyx_n_s_trigtan
#define __pyx_n_s_trim __pyx_mstate_global->__pyx_n_s_trim
#define __pyx_n_s_trn __pyx_mstate_global->__pyx_n_s_trn
#define __pyx_n_s_true __pyx_mstate_global->__pyx_n_s_true
#define __pyx_n_s_truediv __pyx_mstate_global->__pyx_n_s_truediv
#define __pyx_n_s_trunc __pyx_mstate_global->__pyx_n_s_trunc
#define __pyx_n_s_truncate __pyx_mstate_global->__pyx_n_s_truncate
#define __pyx_n_s_truncate_graph __pyx_mstate_global->__pyx_n_s_truncate_graph
#define __pyx_n_s_try __pyx_mstate_global->__pyx_n_s_try
#define __pyx_kp_s_trying_soft_interruption_wait_2s __pyx_mstate_global->__pyx_kp_s_trying_soft_interruption_wait_2s
#define __pyx_n_s_tsimplify __pyx_mstate_global->__pyx_n_s_tsimplify
#define __pyx_n_s_tsp __pyx_mstate_global->__pyx_n_s_tsp
#define __pyx_n_s_tstep __pyx_mstate_global->__pyx_n_s_tstep
#define __pyx_n_s_tuer __pyx_mstate_global->__pyx_n_s_tuer
#define __pyx_n_s_tukey_window __pyx_mstate_global->__pyx_n_s_tukey_window
#define __pyx_n_s_tutte_polynomial __pyx_mstate_global->__pyx_n_s_tutte_polynomial
#define __pyx_n_s_two_edge_connected_components __pyx_mstate_global->__pyx_n_s_two_edge_connected_components
#define __pyx_n_s_twopi __pyx_mstate_global->__pyx_n_s_twopi
#define __pyx_n_s_type __pyx_mstate_global->__pyx_n_s_type
#define __pyx_n_s_type_2 __pyx_mstate_global->__pyx_n_s_type_2
#define __pyx_n_s_u __pyx_mstate_global->__pyx_n_s_u
#define __pyx_n_s_ufactor __pyx_mstate_global->__pyx_n_s_ufactor
#define __pyx_n_s_ugamma __pyx_mstate_global->__pyx_n_s_ugamma
#define __pyx_n_s_unapply __pyx_mstate_global->__pyx_n_s_unapply
#define __pyx_n_s_unarchive __pyx_mstate_global->__pyx_n_s_unarchive
#define __pyx_n_s_undef __pyx_mstate_global->__pyx_n_s_undef
#define __pyx_n_s_underlying_graph __pyx_mstate_global->__pyx_n_s_underlying_graph
#define __pyx_n_s_unfactored __pyx_mstate_global->__pyx_n_s_unfactored
#define __pyx_n_s_uniform __pyx_mstate_global->__pyx_n_s_uniform
#define __pyx_n_s_uniform_cdf __pyx_mstate_global->__pyx_n_s_uniform_cdf
#define __pyx_n_s_uniform_icdf __pyx_mstate_global->__pyx_n_s_uniform_icdf
#define __pyx_n_s_uniformd __pyx_mstate_global->__pyx_n_s_uniformd
#define __pyx_n_s_uniformd_cdf __pyx_mstate_global->__pyx_n_s_uniformd_cdf
#define __pyx_n_s_uniformd_icdf __pyx_mstate_global->__pyx_n_s_uniformd_icdf
#define __pyx_n_s_union __pyx_mstate_global->__pyx_n_s_union
#define __pyx_n_s_unitV __pyx_mstate_global->__pyx_n_s_unitV
#define __pyx_n_s_unquote __pyx_mstate_global->__pyx_n_s_unquote
#define __pyx_n_s_until __pyx_mstate_global->__pyx_n_s_until
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_upper __pyx_mstate_global->__pyx_n_s_upper
#define __pyx_n_s_url __pyx_mstate_global->__pyx_n_s_url
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_n_s_user_operator __pyx_mstate_global->__pyx_n_s_user_operator
#define __pyx_n_s_usimplify __pyx_mstate_global->__pyx_n_s_usimplify
#define __pyx_kp_s_using_sendtext __pyx_mstate_global->__pyx_kp_s_using_sendtext
#define __pyx_n_s_ustep __pyx_mstate_global->__pyx_n_s_ustep
#define __pyx_n_s_val __pyx_mstate_global->__pyx_n_s_val
#define __pyx_n_s_valuation __pyx_mstate_global->__pyx_n_s_valuation
#define __pyx_n_s_vandermonde __pyx_mstate_global->__pyx_n_s_vandermonde
#define __pyx_n_s_var __pyx_mstate_global->__pyx_n_s_var
#define __pyx_n_s_variables_are_files __pyx_mstate_global->__pyx_n_s_variables_are_files
#define __pyx_n_s_variance __pyx_mstate_global->__pyx_n_s_variance
#define __pyx_n_s_vector __pyx_mstate_global->__pyx_n_s_vector
#define __pyx_n_s_vers __pyx_mstate_global->__pyx_n_s_vers
#define __pyx_n_s_version __pyx_mstate_global->__pyx_n_s_version
#define __pyx_n_s_version_info __pyx_mstate_global->__pyx_n_s_version_info
#define __pyx_n_s_vert __pyx_mstate_global->__pyx_n_s_vert
#define __pyx_n_s_vertex_connectivity __pyx_mstate_global->__pyx_n_s_vertex_connectivity
#define __pyx_n_s_vertex_cover_number __pyx_mstate_global->__pyx_n_s_vertex_cover_number
#define __pyx_n_s_vertex_degree __pyx_mstate_global->__pyx_n_s_vertex_degree
#define __pyx_n_s_vertex_distance __pyx_mstate_global->__pyx_n_s_vertex_distance
#define __pyx_n_s_vertex_in_degree __pyx_mstate_global->__pyx_n_s_vertex_in_degree
#define __pyx_n_s_vertex_out_degree __pyx_mstate_global->__pyx_n_s_vertex_out_degree
#define __pyx_n_s_vertices __pyx_mstate_global->__pyx_n_s_vertices
#define __pyx_n_s_vertices_abc __pyx_mstate_global->__pyx_n_s_vertices_abc
#define __pyx_n_s_vertices_abca __pyx_mstate_global->__pyx_n_s_vertices_abca
#define __pyx_kp_u_vide_Pygen_giac_version_dpt_eit __pyx_mstate_global->__pyx_kp_u_vide_Pygen_giac_version_dpt_eit
#define __pyx_n_s_violet __pyx_mstate_global->__pyx_n_s_violet
#define __pyx_n_s_vpotential __pyx_mstate_global->__pyx_n_s_vpotential
#define __pyx_n_s_vrai __pyx_mstate_global->__pyx_n_s_vrai
#define __pyx_n_s_vstep __pyx_mstate_global->__pyx_n_s_vstep
#define __pyx_kp_s_warning_Killing_thread __pyx_mstate_global->__pyx_kp_s_warning_Killing_thread
#define __pyx_n_s_watch __pyx_mstate_global->__pyx_n_s_watch
#define __pyx_n_s_web_graph __pyx_mstate_global->__pyx_n_s_web_graph
#define __pyx_n_s_webbrowser __pyx_mstate_global->__pyx_n_s_webbrowser
#define __pyx_n_s_weibull __pyx_mstate_global->__pyx_n_s_weibull
#define __pyx_n_s_weibull_cdf __pyx_mstate_global->__pyx_n_s_weibull_cdf
#define __pyx_n_s_weibull_icdf __pyx_mstate_global->__pyx_n_s_weibull_icdf
#define __pyx_n_s_weibulld __pyx_mstate_global->__pyx_n_s_weibulld
#define __pyx_n_s_weibulld_cdf __pyx_mstate_global->__pyx_n_s_weibulld_cdf
#define __pyx_n_s_weibulld_icdf __pyx_mstate_global->__pyx_n_s_weibulld_icdf
#define __pyx_n_s_weibullvariate __pyx_mstate_global->__pyx_n_s_weibullvariate
#define __pyx_n_s_weight_decay __pyx_mstate_global->__pyx_n_s_weight_decay
#define __pyx_n_s_weight_matrix __pyx_mstate_global->__pyx_n_s_weight_matrix
#define __pyx_n_s_weighted __pyx_mstate_global->__pyx_n_s_weighted
#define __pyx_n_s_weights __pyx_mstate_global->__pyx_n_s_weights
#define __pyx_n_s_welch_window __pyx_mstate_global->__pyx_n_s_welch_window
#define __pyx_n_s_wheel_graph __pyx_mstate_global->__pyx_n_s_wheel_graph
#define __pyx_n_s_when __pyx_mstate_global->__pyx_n_s_when
#define __pyx_n_s_while __pyx_mstate_global->__pyx_n_s_while
#define __pyx_n_s_white __pyx_mstate_global->__pyx_n_s_white
#define __pyx_n_s_widget_size __pyx_mstate_global->__pyx_n_s_widget_size
#define __pyx_n_s_wilcoxonp __pyx_mstate_global->__pyx_n_s_wilcoxonp
#define __pyx_n_s_wilcoxons __pyx_mstate_global->__pyx_n_s_wilcoxons
#define __pyx_n_s_wilcoxont __pyx_mstate_global->__pyx_n_s_wilcoxont
#define __pyx_n_s_with_sqrt __pyx_mstate_global->__pyx_n_s_with_sqrt
#define __pyx_n_s_write __pyx_mstate_global->__pyx_n_s_write
#define __pyx_n_s_writergb __pyx_mstate_global->__pyx_n_s_writergb
#define __pyx_n_s_writewav __pyx_mstate_global->__pyx_n_s_writewav
#define __pyx_n_s_wwwbrowseropen __pyx_mstate_global->__pyx_n_s_wwwbrowseropen
#define __pyx_n_s_wz_certificate __pyx_mstate_global->__pyx_n_s_wz_certificate
#define __pyx_n_s_xcas_mode __pyx_mstate_global->__pyx_n_s_xcas_mode
#define __pyx_n_s_xml_print __pyx_mstate_global->__pyx_n_s_xml_print
#define __pyx_n_s_xor __pyx_mstate_global->__pyx_n_s_xor
#define __pyx_n_s_xstep __pyx_mstate_global->__pyx_n_s_xstep
#define __pyx_n_s_xyz2rgb __pyx_mstate_global->__pyx_n_s_xyz2rgb
#define __pyx_n_s_xyztrange __pyx_mstate_global->__pyx_n_s_xyztrange
#define __pyx_n_s_yd __pyx_mstate_global->__pyx_n_s_yd
#define __pyx_kp_s_yd_2 __pyx_mstate_global->__pyx_kp_s_yd_2
#define __pyx_kp_s_yd_3 __pyx_mstate_global->__pyx_kp_s_yd_3
#define __pyx_n_s_yellow __pyx_mstate_global->__pyx_n_s_yellow
#define __pyx_n_s_yr __pyx_mstate_global->__pyx_n_s_yr
#define __pyx_n_s_ystep __pyx_mstate_global->__pyx_n_s_ystep
#define __pyx_n_s_zeros __pyx_mstate_global->__pyx_n_s_zeros
#define __pyx_n_s_zip __pyx_mstate_global->__pyx_n_s_zip
#define __pyx_n_s_znorder __pyx_mstate_global->__pyx_n_s_znorder
#define __pyx_n_s_znprimroot __pyx_mstate_global->__pyx_n_s_znprimroot
#define __pyx_n_s_zstep __pyx_mstate_global->__pyx_n_s_zstep
#define __pyx_n_s_ztrans __pyx_mstate_global->__pyx_n_s_ztrans
#define __pyx_float_0_05 __pyx_mstate_global->__pyx_float_0_05
#define __pyx_float_0_001 __pyx_mstate_global->__pyx_float_0_001
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_7 __pyx_mstate_global->__pyx_int_7
#define __pyx_int_8 __pyx_mstate_global->__pyx_int_8
#define __pyx_int_12 __pyx_mstate_global->__pyx_int_12
#define __pyx_int_14 __pyx_mstate_global->__pyx_int_14
#define __pyx_int_100 __pyx_mstate_global->__pyx_int_100
#define __pyx_int_1000000 __pyx_mstate_global->__pyx_int_1000000
#define __pyx_int_222419149 __pyx_mstate_global->__pyx_int_222419149
#define __pyx_int_228825662 __pyx_mstate_global->__pyx_int_228825662
#define __pyx_int_238750788 __pyx_mstate_global->__pyx_int_238750788
#define __pyx_tuple_ __pyx_mstate_global->__pyx_tuple_
#define __pyx_slice__2 __pyx_mstate_global->__pyx_slice__2
#define __pyx_tuple__3 __pyx_mstate_global->__pyx_tuple__3
#define __pyx_tuple__4 __pyx_mstate_global->__pyx_tuple__4
#define __pyx_tuple__5 __pyx_mstate_global->__pyx_tuple__5
#define __pyx_tuple__6 __pyx_mstate_global->__pyx_tuple__6
#define __pyx_tuple__7 __pyx_mstate_global->__pyx_tuple__7
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__22 __pyx_mstate_global->__pyx_tuple__22
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_codeobj__16 __pyx_mstate_global->__pyx_codeobj__16
#define __pyx_codeobj__17 __pyx_mstate_global->__pyx_codeobj__17
#define __pyx_codeobj__19 __pyx_mstate_global->__pyx_codeobj__19
#define __pyx_codeobj__21 __pyx_mstate_global->__pyx_codeobj__21
#define __pyx_codeobj__23 __pyx_mstate_global->__pyx_codeobj__23
#define __pyx_codeobj__25 __pyx_mstate_global->__pyx_codeobj__25
#define __pyx_codeobj__26 __pyx_mstate_global->__pyx_codeobj__26
#define __pyx_codeobj__27 __pyx_mstate_global->__pyx_codeobj__27
#define __pyx_codeobj__28 __pyx_mstate_global->__pyx_codeobj__28
#define __pyx_codeobj__29 __pyx_mstate_global->__pyx_codeobj__29
#define __pyx_codeobj__30 __pyx_mstate_global->__pyx_codeobj__30
#define __pyx_codeobj__31 __pyx_mstate_global->__pyx_codeobj__31
#define __pyx_codeobj__32 __pyx_mstate_global->__pyx_codeobj__32
#define __pyx_codeobj__33 __pyx_mstate_global->__pyx_codeobj__33
#define __pyx_codeobj__34 __pyx_mstate_global->__pyx_codeobj__34
#define __pyx_codeobj__35 __pyx_mstate_global->__pyx_codeobj__35
#define __pyx_codeobj__36 __pyx_mstate_global->__pyx_codeobj__36
#define __pyx_codeobj__37 __pyx_mstate_global->__pyx_codeobj__37
#define __pyx_codeobj__38 __pyx_mstate_global->__pyx_codeobj__38
#define __pyx_codeobj__39 __pyx_mstate_global->__pyx_codeobj__39
#define __pyx_codeobj__40 __pyx_mstate_global->__pyx_codeobj__40
#define __pyx_codeobj__41 __pyx_mstate_global->__pyx_codeobj__41
#define __pyx_codeobj__42 __pyx_mstate_global->__pyx_codeobj__42
#define __pyx_codeobj__43 __pyx_mstate_global->__pyx_codeobj__43
#define __pyx_codeobj__44 __pyx_mstate_global->__pyx_codeobj__44
#define __pyx_codeobj__45 __pyx_mstate_global->__pyx_codeobj__45
#define __pyx_codeobj__46 __pyx_mstate_global->__pyx_codeobj__46
#define __pyx_codeobj__47 __pyx_mstate_global->__pyx_codeobj__47
#define __pyx_codeobj__48 __pyx_mstate_global->__pyx_codeobj__48
#define __pyx_codeobj__49 __pyx_mstate_global->__pyx_codeobj__49
#define __pyx_codeobj__50 __pyx_mstate_global->__pyx_codeobj__50
#define __pyx_codeobj__51 __pyx_mstate_global->__pyx_codeobj__51
#define __pyx_codeobj__52 __pyx_mstate_global->__pyx_codeobj__52
#define __pyx_codeobj__53 __pyx_mstate_global->__pyx_codeobj__53
#define __pyx_codeobj__54 __pyx_mstate_global->__pyx_codeobj__54
#define __pyx_codeobj__55 __pyx_mstate_global->__pyx_codeobj__55
#define __pyx_codeobj__56 __pyx_mstate_global->__pyx_codeobj__56
#define __pyx_codeobj__57 __pyx_mstate_global->__pyx_codeobj__57
#define __pyx_codeobj__58 __pyx_mstate_global->__pyx_codeobj__58
#define __pyx_codeobj__59 __pyx_mstate_global->__pyx_codeobj__59
#define __pyx_codeobj__60 __pyx_mstate_global->__pyx_codeobj__60
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__62 __pyx_mstate_global->__pyx_codeobj__62
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__64 __pyx_mstate_global->__pyx_codeobj__64
#define __pyx_codeobj__65 __pyx_mstate_global->__pyx_codeobj__65
#define __pyx_codeobj__66 __pyx_mstate_global->__pyx_codeobj__66
#define __pyx_codeobj__67 __pyx_mstate_global->__pyx_codeobj__67
#define __pyx_codeobj__68 __pyx_mstate_global->__pyx_codeobj__68
#define __pyx_codeobj__69 __pyx_mstate_global->__pyx_codeobj__69
#define __pyx_codeobj__70 __pyx_mstate_global->__pyx_codeobj__70
#define __pyx_codeobj__71 __pyx_mstate_global->__pyx_codeobj__71
#define __pyx_codeobj__72 __pyx_mstate_global->__pyx_codeobj__72
#define __pyx_codeobj__73 __pyx_mstate_global->__pyx_codeobj__73
#define __pyx_codeobj__74 __pyx_mstate_global->__pyx_codeobj__74
#define __pyx_codeobj__75 __pyx_mstate_global->__pyx_codeobj__75
#define __pyx_codeobj__76 __pyx_mstate_global->__pyx_codeobj__76
#define __pyx_codeobj__77 __pyx_mstate_global->__pyx_codeobj__77
#define __pyx_codeobj__78 __pyx_mstate_global->__pyx_codeobj__78
#define __pyx_codeobj__79 __pyx_mstate_global->__pyx_codeobj__79
#define __pyx_codeobj__80 __pyx_mstate_global->__pyx_codeobj__80
#define __pyx_codeobj__81 __pyx_mstate_global->__pyx_codeobj__81
#define __pyx_codeobj__82 __pyx_mstate_global->__pyx_codeobj__82
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__84 __pyx_mstate_global->__pyx_codeobj__84
#define __pyx_codeobj__85 __pyx_mstate_global->__pyx_codeobj__85
#define __pyx_codeobj__86 __pyx_mstate_global->__pyx_codeobj__86
#define __pyx_codeobj__87 __pyx_mstate_global->__pyx_codeobj__87
#define __pyx_codeobj__88 __pyx_mstate_global->__pyx_codeobj__88
#define __pyx_codeobj__89 __pyx_mstate_global->__pyx_codeobj__89
#define __pyx_codeobj__90 __pyx_mstate_global->__pyx_codeobj__90
#define __pyx_codeobj__91 __pyx_mstate_global->__pyx_codeobj__91
#define __pyx_codeobj__92 __pyx_mstate_global->__pyx_codeobj__92
#define __pyx_codeobj__93 __pyx_mstate_global->__pyx_codeobj__93
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__95 __pyx_mstate_global->__pyx_codeobj__95
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
#define __pyx_codeobj__97 __pyx_mstate_global->__pyx_codeobj__97
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__99 __pyx_mstate_global->__pyx_codeobj__99
#define __pyx_tuple__1627 __pyx_mstate_global->__pyx_tuple__1627
#define __pyx_tuple__1630 __pyx_mstate_global->__pyx_tuple__1630
#define __pyx_tuple__1632 __pyx_mstate_global->__pyx_tuple__1632
#define __pyx_tuple__1637 __pyx_mstate_global->__pyx_tuple__1637
#define __pyx_tuple__1639 __pyx_mstate_global->__pyx_tuple__1639
#define __pyx_tuple__1641 __pyx_mstate_global->__pyx_tuple__1641
#define __pyx_tuple__1643 __pyx_mstate_global->__pyx_tuple__1643
#define __pyx_tuple__1645 __pyx_mstate_global->__pyx_tuple__1645
#define __pyx_tuple__1646 __pyx_mstate_global->__pyx_tuple__1646
#define __pyx_tuple__1650 __pyx_mstate_global->__pyx_tuple__1650
#define __pyx_tuple__1651 __pyx_mstate_global->__pyx_tuple__1651
#define __pyx_tuple__1653 __pyx_mstate_global->__pyx_tuple__1653
#define __pyx_tuple__1702 __pyx_mstate_global->__pyx_tuple__1702
#define __pyx_tuple__1707 __pyx_mstate_global->__pyx_tuple__1707
#define __pyx_tuple__1713 __pyx_mstate_global->__pyx_tuple__1713
#define __pyx_tuple__1719 __pyx_mstate_global->__pyx_tuple__1719
#define __pyx_tuple__1721 __pyx_mstate_global->__pyx_tuple__1721
#define __pyx_tuple__1722 __pyx_mstate_global->__pyx_tuple__1722
#define __pyx_tuple__1724 __pyx_mstate_global->__pyx_tuple__1724
#define __pyx_tuple__1726 __pyx_mstate_global->__pyx_tuple__1726
#define __pyx_codeobj__100 __pyx_mstate_global->__pyx_codeobj__100
#define __pyx_codeobj__101 __pyx_mstate_global->__pyx_codeobj__101
#define __pyx_codeobj__102 __pyx_mstate_global->__pyx_codeobj__102
#define __pyx_codeobj__103 __pyx_mstate_global->__pyx_codeobj__103
#define __pyx_codeobj__104 __pyx_mstate_global->__pyx_codeobj__104
#define __pyx_codeobj__105 __pyx_mstate_global->__pyx_codeobj__105
#define __pyx_codeobj__106 __pyx_mstate_global->__pyx_codeobj__106
#define __pyx_codeobj__107 __pyx_mstate_global->__pyx_codeobj__107
#define __pyx_codeobj__108 __pyx_mstate_global->__pyx_codeobj__108
#define __pyx_codeobj__109 __pyx_mstate_global->__pyx_codeobj__109
#define __pyx_codeobj__110 __pyx_mstate_global->__pyx_codeobj__110
#define __pyx_codeobj__111 __pyx_mstate_global->__pyx_codeobj__111
#define __pyx_codeobj__112 __pyx_mstate_global->__pyx_codeobj__112
#define __pyx_codeobj__113 __pyx_mstate_global->__pyx_codeobj__113
#define __pyx_codeobj__114 __pyx_mstate_global->__pyx_codeobj__114
#define __pyx_codeobj__115 __pyx_mstate_global->__pyx_codeobj__115
#define __pyx_codeobj__116 __pyx_mstate_global->__pyx_codeobj__116
#define __pyx_codeobj__117 __pyx_mstate_global->__pyx_codeobj__117
#define __pyx_codeobj__118 __pyx_mstate_global->__pyx_codeobj__118
#define __pyx_codeobj__119 __pyx_mstate_global->__pyx_codeobj__119
#define __pyx_codeobj__120 __pyx_mstate_global->__pyx_codeobj__120
#define __pyx_codeobj__121 __pyx_mstate_global->__pyx_codeobj__121
#define __pyx_codeobj__122 __pyx_mstate_global->__pyx_codeobj__122
#define __pyx_codeobj__123 __pyx_mstate_global->__pyx_codeobj__123
#define __pyx_codeobj__124 __pyx_mstate_global->__pyx_codeobj__124
#define __pyx_codeobj__125 __pyx_mstate_global->__pyx_codeobj__125
#define __pyx_codeobj__126 __pyx_mstate_global->__pyx_codeobj__126
#define __pyx_codeobj__127 __pyx_mstate_global->__pyx_codeobj__127
#define __pyx_codeobj__128 __pyx_mstate_global->__pyx_codeobj__128
#define __pyx_codeobj__129 __pyx_mstate_global->__pyx_codeobj__129
#define __pyx_codeobj__130 __pyx_mstate_global->__pyx_codeobj__130
#define __pyx_codeobj__131 __pyx_mstate_global->__pyx_codeobj__131
#define __pyx_codeobj__132 __pyx_mstate_global->__pyx_codeobj__132
#define __pyx_codeobj__133 __pyx_mstate_global->__pyx_codeobj__133
#define __pyx_codeobj__134 __pyx_mstate_global->__pyx_codeobj__134
#define __pyx_codeobj__135 __pyx_mstate_global->__pyx_codeobj__135
#define __pyx_codeobj__136 __pyx_mstate_global->__pyx_codeobj__136
#define __pyx_codeobj__137 __pyx_mstate_global->__pyx_codeobj__137
#define __pyx_codeobj__138 __pyx_mstate_global->__pyx_codeobj__138
#define __pyx_codeobj__139 __pyx_mstate_global->__pyx_codeobj__139
#define __pyx_codeobj__140 __pyx_mstate_global->__pyx_codeobj__140
#define __pyx_codeobj__141 __pyx_mstate_global->__pyx_codeobj__141
#define __pyx_codeobj__142 __pyx_mstate_global->__pyx_codeobj__142
#define __pyx_codeobj__143 __pyx_mstate_global->__pyx_codeobj__143
#define __pyx_codeobj__144 __pyx_mstate_global->__pyx_codeobj__144
#define __pyx_codeobj__145 __pyx_mstate_global->__pyx_codeobj__145
#define __pyx_codeobj__146 __pyx_mstate_global->__pyx_codeobj__146
#define __pyx_codeobj__147 __pyx_mstate_global->__pyx_codeobj__147
#define __pyx_codeobj__148 __pyx_mstate_global->__pyx_codeobj__148
#define __pyx_codeobj__149 __pyx_mstate_global->__pyx_codeobj__149
#define __pyx_codeobj__150 __pyx_mstate_global->__pyx_codeobj__150
#define __pyx_codeobj__151 __pyx_mstate_global->__pyx_codeobj__151
#define __pyx_codeobj__152 __pyx_mstate_global->__pyx_codeobj__152
#define __pyx_codeobj__153 __pyx_mstate_global->__pyx_codeobj__153
#define __pyx_codeobj__154 __pyx_mstate_global->__pyx_codeobj__154
#define __pyx_codeobj__155 __pyx_mstate_global->__pyx_codeobj__155
#define __pyx_codeobj__156 __pyx_mstate_global->__pyx_codeobj__156
#define __pyx_codeobj__157 __pyx_mstate_global->__pyx_codeobj__157
#define __pyx_codeobj__158 __pyx_mstate_global->__pyx_codeobj__158
#define __pyx_codeobj__159 __pyx_mstate_global->__pyx_codeobj__159
#define __pyx_codeobj__160 __pyx_mstate_global->__pyx_codeobj__160
#define __pyx_codeobj__161 __pyx_mstate_global->__pyx_codeobj__161
#define __pyx_codeobj__162 __pyx_mstate_global->__pyx_codeobj__162
#define __pyx_codeobj__163 __pyx_mstate_global->__pyx_codeobj__163
#define __pyx_codeobj__164 __pyx_mstate_global->__pyx_codeobj__164
#define __pyx_codeobj__165 __pyx_mstate_global->__pyx_codeobj__165
#define __pyx_codeobj__166 __pyx_mstate_global->__pyx_codeobj__166
#define __pyx_codeobj__167 __pyx_mstate_global->__pyx_codeobj__167
#define __pyx_codeobj__168 __pyx_mstate_global->__pyx_codeobj__168
#define __pyx_codeobj__169 __pyx_mstate_global->__pyx_codeobj__169
#define __pyx_codeobj__170 __pyx_mstate_global->__pyx_codeobj__170
#define __pyx_codeobj__171 __pyx_mstate_global->__pyx_codeobj__171
#define __pyx_codeobj__172 __pyx_mstate_global->__pyx_codeobj__172
#define __pyx_codeobj__173 __pyx_mstate_global->__pyx_codeobj__173
#define __pyx_codeobj__174 __pyx_mstate_global->__pyx_codeobj__174
#define __pyx_codeobj__175 __pyx_mstate_global->__pyx_codeobj__175
#define __pyx_codeobj__176 __pyx_mstate_global->__pyx_codeobj__176
#define __pyx_codeobj__177 __pyx_mstate_global->__pyx_codeobj__177
#define __pyx_codeobj__178 __pyx_mstate_global->__pyx_codeobj__178
#define __pyx_codeobj__179 __pyx_mstate_global->__pyx_codeobj__179
#define __pyx_codeobj__180 __pyx_mstate_global->__pyx_codeobj__180
#define __pyx_codeobj__181 __pyx_mstate_global->__pyx_codeobj__181
#define __pyx_codeobj__182 __pyx_mstate_global->__pyx_codeobj__182
#define __pyx_codeobj__183 __pyx_mstate_global->__pyx_codeobj__183
#define __pyx_codeobj__184 __pyx_mstate_global->__pyx_codeobj__184
#define __pyx_codeobj__185 __pyx_mstate_global->__pyx_codeobj__185
#define __pyx_codeobj__186 __pyx_mstate_global->__pyx_codeobj__186
#define __pyx_codeobj__187 __pyx_mstate_global->__pyx_codeobj__187
#define __pyx_codeobj__188 __pyx_mstate_global->__pyx_codeobj__188
#define __pyx_codeobj__189 __pyx_mstate_global->__pyx_codeobj__189
#define __pyx_codeobj__190 __pyx_mstate_global->__pyx_codeobj__190
#define __pyx_codeobj__191 __pyx_mstate_global->__pyx_codeobj__191
#define __pyx_codeobj__192 __pyx_mstate_global->__pyx_codeobj__192
#define __pyx_codeobj__193 __pyx_mstate_global->__pyx_codeobj__193
#define __pyx_codeobj__194 __pyx_mstate_global->__pyx_codeobj__194
#define __pyx_codeobj__195 __pyx_mstate_global->__pyx_codeobj__195
#define __pyx_codeobj__196 __pyx_mstate_global->__pyx_codeobj__196
#define __pyx_codeobj__197 __pyx_mstate_global->__pyx_codeobj__197
#define __pyx_codeobj__198 __pyx_mstate_global->__pyx_codeobj__198
#define __pyx_codeobj__199 __pyx_mstate_global->__pyx_codeobj__199
#define __pyx_codeobj__200 __pyx_mstate_global->__pyx_codeobj__200
#define __pyx_codeobj__201 __pyx_mstate_global->__pyx_codeobj__201
#define __pyx_codeobj__202 __pyx_mstate_global->__pyx_codeobj__202
#define __pyx_codeobj__203 __pyx_mstate_global->__pyx_codeobj__203
#define __pyx_codeobj__204 __pyx_mstate_global->__pyx_codeobj__204
#define __pyx_codeobj__205 __pyx_mstate_global->__pyx_codeobj__205
#define __pyx_codeobj__206 __pyx_mstate_global->__pyx_codeobj__206
#define __pyx_codeobj__207 __pyx_mstate_global->__pyx_codeobj__207
#define __pyx_codeobj__208 __pyx_mstate_global->__pyx_codeobj__208
#define __pyx_codeobj__209 __pyx_mstate_global->__pyx_codeobj__209
#define __pyx_codeobj__210 __pyx_mstate_global->__pyx_codeobj__210
#define __pyx_codeobj__211 __pyx_mstate_global->__pyx_codeobj__211
#define __pyx_codeobj__212 __pyx_mstate_global->__pyx_codeobj__212
#define __pyx_codeobj__213 __pyx_mstate_global->__pyx_codeobj__213
#define __pyx_codeobj__214 __pyx_mstate_global->__pyx_codeobj__214
#define __pyx_codeobj__215 __pyx_mstate_global->__pyx_codeobj__215
#define __pyx_codeobj__216 __pyx_mstate_global->__pyx_codeobj__216
#define __pyx_codeobj__217 __pyx_mstate_global->__pyx_codeobj__217
#define __pyx_codeobj__218 __pyx_mstate_global->__pyx_codeobj__218
#define __pyx_codeobj__219 __pyx_mstate_global->__pyx_codeobj__219
#define __pyx_codeobj__220 __pyx_mstate_global->__pyx_codeobj__220
#define __pyx_codeobj__221 __pyx_mstate_global->__pyx_codeobj__221
#define __pyx_codeobj__222 __pyx_mstate_global->__pyx_codeobj__222
#define __pyx_codeobj__223 __pyx_mstate_global->__pyx_codeobj__223
#define __pyx_codeobj__224 __pyx_mstate_global->__pyx_codeobj__224
#define __pyx_codeobj__225 __pyx_mstate_global->__pyx_codeobj__225
#define __pyx_codeobj__226 __pyx_mstate_global->__pyx_codeobj__226
#define __pyx_codeobj__227 __pyx_mstate_global->__pyx_codeobj__227
#define __pyx_codeobj__228 __pyx_mstate_global->__pyx_codeobj__228
#define __pyx_codeobj__229 __pyx_mstate_global->__pyx_codeobj__229
#define __pyx_codeobj__230 __pyx_mstate_global->__pyx_codeobj__230
#define __pyx_codeobj__231 __pyx_mstate_global->__pyx_codeobj__231
#define __pyx_codeobj__232 __pyx_mstate_global->__pyx_codeobj__232
#define __pyx_codeobj__233 __pyx_mstate_global->__pyx_codeobj__233
#define __pyx_codeobj__234 __pyx_mstate_global->__pyx_codeobj__234
#define __pyx_codeobj__235 __pyx_mstate_global->__pyx_codeobj__235
#define __pyx_codeobj__236 __pyx_mstate_global->__pyx_codeobj__236
#define __pyx_codeobj__237 __pyx_mstate_global->__pyx_codeobj__237
#define __pyx_codeobj__238 __pyx_mstate_global->__pyx_codeobj__238
#define __pyx_codeobj__239 __pyx_mstate_global->__pyx_codeobj__239
#define __pyx_codeobj__240 __pyx_mstate_global->__pyx_codeobj__240
#define __pyx_codeobj__241 __pyx_mstate_global->__pyx_codeobj__241
#define __pyx_codeobj__242 __pyx_mstate_global->__pyx_codeobj__242
#define __pyx_codeobj__243 __pyx_mstate_global->__pyx_codeobj__243
#define __pyx_codeobj__244 __pyx_mstate_global->__pyx_codeobj__244
#define __pyx_codeobj__245 __pyx_mstate_global->__pyx_codeobj__245
#define __pyx_codeobj__246 __pyx_mstate_global->__pyx_codeobj__246
#define __pyx_codeobj__247 __pyx_mstate_global->__pyx_codeobj__247
#define __pyx_codeobj__248 __pyx_mstate_global->__pyx_codeobj__248
#define __pyx_codeobj__249 __pyx_mstate_global->__pyx_codeobj__249
#define __pyx_codeobj__250 __pyx_mstate_global->__pyx_codeobj__250
#define __pyx_codeobj__251 __pyx_mstate_global->__pyx_codeobj__251
#define __pyx_codeobj__252 __pyx_mstate_global->__pyx_codeobj__252
#define __pyx_codeobj__253 __pyx_mstate_global->__pyx_codeobj__253
#define __pyx_codeobj__254 __pyx_mstate_global->__pyx_codeobj__254
#define __pyx_codeobj__255 __pyx_mstate_global->__pyx_codeobj__255
#define __pyx_codeobj__256 __pyx_mstate_global->__pyx_codeobj__256
#define __pyx_codeobj__257 __pyx_mstate_global->__pyx_codeobj__257
#define __pyx_codeobj__258 __pyx_mstate_global->__pyx_codeobj__258
#define __pyx_codeobj__259 __pyx_mstate_global->__pyx_codeobj__259
#define __pyx_codeobj__260 __pyx_mstate_global->__pyx_codeobj__260
#define __pyx_codeobj__261 __pyx_mstate_global->__pyx_codeobj__261
#define __pyx_codeobj__262 __pyx_mstate_global->__pyx_codeobj__262
#define __pyx_codeobj__263 __pyx_mstate_global->__pyx_codeobj__263
#define __pyx_codeobj__264 __pyx_mstate_global->__pyx_codeobj__264
#define __pyx_codeobj__265 __pyx_mstate_global->__pyx_codeobj__265
#define __pyx_codeobj__266 __pyx_mstate_global->__pyx_codeobj__266
#define __pyx_codeobj__267 __pyx_mstate_global->__pyx_codeobj__267
#define __pyx_codeobj__268 __pyx_mstate_global->__pyx_codeobj__268
#define __pyx_codeobj__269 __pyx_mstate_global->__pyx_codeobj__269
#define __pyx_codeobj__270 __pyx_mstate_global->__pyx_codeobj__270
#define __pyx_codeobj__271 __pyx_mstate_global->__pyx_codeobj__271
#define __pyx_codeobj__272 __pyx_mstate_global->__pyx_codeobj__272
#define __pyx_codeobj__273 __pyx_mstate_global->__pyx_codeobj__273
#define __pyx_codeobj__274 __pyx_mstate_global->__pyx_codeobj__274
#define __pyx_codeobj__275 __pyx_mstate_global->__pyx_codeobj__275
#define __pyx_codeobj__276 __pyx_mstate_global->__pyx_codeobj__276
#define __pyx_codeobj__277 __pyx_mstate_global->__pyx_codeobj__277
#define __pyx_codeobj__278 __pyx_mstate_global->__pyx_codeobj__278
#define __pyx_codeobj__279 __pyx_mstate_global->__pyx_codeobj__279
#define __pyx_codeobj__280 __pyx_mstate_global->__pyx_codeobj__280
#define __pyx_codeobj__281 __pyx_mstate_global->__pyx_codeobj__281
#define __pyx_codeobj__282 __pyx_mstate_global->__pyx_codeobj__282
#define __pyx_codeobj__283 __pyx_mstate_global->__pyx_codeobj__283
#define __pyx_codeobj__284 __pyx_mstate_global->__pyx_codeobj__284
#define __pyx_codeobj__285 __pyx_mstate_global->__pyx_codeobj__285
#define __pyx_codeobj__286 __pyx_mstate_global->__pyx_codeobj__286
#define __pyx_codeobj__287 __pyx_mstate_global->__pyx_codeobj__287
#define __pyx_codeobj__288 __pyx_mstate_global->__pyx_codeobj__288
#define __pyx_codeobj__289 __pyx_mstate_global->__pyx_codeobj__289
#define __pyx_codeobj__290 __pyx_mstate_global->__pyx_codeobj__290
#define __pyx_codeobj__291 __pyx_mstate_global->__pyx_codeobj__291
#define __pyx_codeobj__292 __pyx_mstate_global->__pyx_codeobj__292
#define __pyx_codeobj__293 __pyx_mstate_global->__pyx_codeobj__293
#define __pyx_codeobj__294 __pyx_mstate_global->__pyx_codeobj__294
#define __pyx_codeobj__295 __pyx_mstate_global->__pyx_codeobj__295
#define __pyx_codeobj__296 __pyx_mstate_global->__pyx_codeobj__296
#define __pyx_codeobj__297 __pyx_mstate_global->__pyx_codeobj__297
#define __pyx_codeobj__298 __pyx_mstate_global->__pyx_codeobj__298
#define __pyx_codeobj__299 __pyx_mstate_global->__pyx_codeobj__299
#define __pyx_codeobj__300 __pyx_mstate_global->__pyx_codeobj__300
#define __pyx_codeobj__301 __pyx_mstate_global->__pyx_codeobj__301
#define __pyx_codeobj__302 __pyx_mstate_global->__pyx_codeobj__302
#define __pyx_codeobj__303 __pyx_mstate_global->__pyx_codeobj__303
#define __pyx_codeobj__304 __pyx_mstate_global->__pyx_codeobj__304
#define __pyx_codeobj__305 __pyx_mstate_global->__pyx_codeobj__305
#define __pyx_codeobj__306 __pyx_mstate_global->__pyx_codeobj__306
#define __pyx_codeobj__307 __pyx_mstate_global->__pyx_codeobj__307
#define __pyx_codeobj__308 __pyx_mstate_global->__pyx_codeobj__308
#define __pyx_codeobj__309 __pyx_mstate_global->__pyx_codeobj__309
#define __pyx_codeobj__310 __pyx_mstate_global->__pyx_codeobj__310
#define __pyx_codeobj__311 __pyx_mstate_global->__pyx_codeobj__311
#define __pyx_codeobj__312 __pyx_mstate_global->__pyx_codeobj__312
#define __pyx_codeobj__313 __pyx_mstate_global->__pyx_codeobj__313
#define __pyx_codeobj__314 __pyx_mstate_global->__pyx_codeobj__314
#define __pyx_codeobj__315 __pyx_mstate_global->__pyx_codeobj__315
#define __pyx_codeobj__316 __pyx_mstate_global->__pyx_codeobj__316
#define __pyx_codeobj__317 __pyx_mstate_global->__pyx_codeobj__317
#define __pyx_codeobj__318 __pyx_mstate_global->__pyx_codeobj__318
#define __pyx_codeobj__319 __pyx_mstate_global->__pyx_codeobj__319
#define __pyx_codeobj__320 __pyx_mstate_global->__pyx_codeobj__320
#define __pyx_codeobj__321 __pyx_mstate_global->__pyx_codeobj__321
#define __pyx_codeobj__322 __pyx_mstate_global->__pyx_codeobj__322
#define __pyx_codeobj__323 __pyx_mstate_global->__pyx_codeobj__323
#define __pyx_codeobj__324 __pyx_mstate_global->__pyx_codeobj__324
#define __pyx_codeobj__325 __pyx_mstate_global->__pyx_codeobj__325
#define __pyx_codeobj__326 __pyx_mstate_global->__pyx_codeobj__326
#define __pyx_codeobj__327 __pyx_mstate_global->__pyx_codeobj__327
#define __pyx_codeobj__328 __pyx_mstate_global->__pyx_codeobj__328
#define __pyx_codeobj__329 __pyx_mstate_global->__pyx_codeobj__329
#define __pyx_codeobj__330 __pyx_mstate_global->__pyx_codeobj__330
#define __pyx_codeobj__331 __pyx_mstate_global->__pyx_codeobj__331
#define __pyx_codeobj__332 __pyx_mstate_global->__pyx_codeobj__332
#define __pyx_codeobj__333 __pyx_mstate_global->__pyx_codeobj__333
#define __pyx_codeobj__334 __pyx_mstate_global->__pyx_codeobj__334
#define __pyx_codeobj__335 __pyx_mstate_global->__pyx_codeobj__335
#define __pyx_codeobj__336 __pyx_mstate_global->__pyx_codeobj__336
#define __pyx_codeobj__337 __pyx_mstate_global->__pyx_codeobj__337
#define __pyx_codeobj__338 __pyx_mstate_global->__pyx_codeobj__338
#define __pyx_codeobj__339 __pyx_mstate_global->__pyx_codeobj__339
#define __pyx_codeobj__340 __pyx_mstate_global->__pyx_codeobj__340
#define __pyx_codeobj__341 __pyx_mstate_global->__pyx_codeobj__341
#define __pyx_codeobj__342 __pyx_mstate_global->__pyx_codeobj__342
#define __pyx_codeobj__343 __pyx_mstate_global->__pyx_codeobj__343
#define __pyx_codeobj__344 __pyx_mstate_global->__pyx_codeobj__344
#define __pyx_codeobj__345 __pyx_mstate_global->__pyx_codeobj__345
#define __pyx_codeobj__346 __pyx_mstate_global->__pyx_codeobj__346
#define __pyx_codeobj__347 __pyx_mstate_global->__pyx_codeobj__347
#define __pyx_codeobj__348 __pyx_mstate_global->__pyx_codeobj__348
#define __pyx_codeobj__349 __pyx_mstate_global->__pyx_codeobj__349
#define __pyx_codeobj__350 __pyx_mstate_global->__pyx_codeobj__350
#define __pyx_codeobj__351 __pyx_mstate_global->__pyx_codeobj__351
#define __pyx_codeobj__352 __pyx_mstate_global->__pyx_codeobj__352
#define __pyx_codeobj__353 __pyx_mstate_global->__pyx_codeobj__353
#define __pyx_codeobj__354 __pyx_mstate_global->__pyx_codeobj__354
#define __pyx_codeobj__355 __pyx_mstate_global->__pyx_codeobj__355
#define __pyx_codeobj__356 __pyx_mstate_global->__pyx_codeobj__356
#define __pyx_codeobj__357 __pyx_mstate_global->__pyx_codeobj__357
#define __pyx_codeobj__358 __pyx_mstate_global->__pyx_codeobj__358
#define __pyx_codeobj__359 __pyx_mstate_global->__pyx_codeobj__359
#define __pyx_codeobj__360 __pyx_mstate_global->__pyx_codeobj__360
#define __pyx_codeobj__361 __pyx_mstate_global->__pyx_codeobj__361
#define __pyx_codeobj__362 __pyx_mstate_global->__pyx_codeobj__362
#define __pyx_codeobj__363 __pyx_mstate_global->__pyx_codeobj__363
#define __pyx_codeobj__364 __pyx_mstate_global->__pyx_codeobj__364
#define __pyx_codeobj__365 __pyx_mstate_global->__pyx_codeobj__365
#define __pyx_codeobj__366 __pyx_mstate_global->__pyx_codeobj__366
#define __pyx_codeobj__367 __pyx_mstate_global->__pyx_codeobj__367
#define __pyx_codeobj__368 __pyx_mstate_global->__pyx_codeobj__368
#define __pyx_codeobj__369 __pyx_mstate_global->__pyx_codeobj__369
#define __pyx_codeobj__370 __pyx_mstate_global->__pyx_codeobj__370
#define __pyx_codeobj__371 __pyx_mstate_global->__pyx_codeobj__371
#define __pyx_codeobj__372 __pyx_mstate_global->__pyx_codeobj__372
#define __pyx_codeobj__373 __pyx_mstate_global->__pyx_codeobj__373
#define __pyx_codeobj__374 __pyx_mstate_global->__pyx_codeobj__374
#define __pyx_codeobj__375 __pyx_mstate_global->__pyx_codeobj__375
#define __pyx_codeobj__376 __pyx_mstate_global->__pyx_codeobj__376
#define __pyx_codeobj__377 __pyx_mstate_global->__pyx_codeobj__377
#define __pyx_codeobj__378 __pyx_mstate_global->__pyx_codeobj__378
#define __pyx_codeobj__379 __pyx_mstate_global->__pyx_codeobj__379
#define __pyx_codeobj__380 __pyx_mstate_global->__pyx_codeobj__380
#define __pyx_codeobj__381 __pyx_mstate_global->__pyx_codeobj__381
#define __pyx_codeobj__382 __pyx_mstate_global->__pyx_codeobj__382
#define __pyx_codeobj__383 __pyx_mstate_global->__pyx_codeobj__383
#define __pyx_codeobj__384 __pyx_mstate_global->__pyx_codeobj__384
#define __pyx_codeobj__385 __pyx_mstate_global->__pyx_codeobj__385
#define __pyx_codeobj__386 __pyx_mstate_global->__pyx_codeobj__386
#define __pyx_codeobj__387 __pyx_mstate_global->__pyx_codeobj__387
#define __pyx_codeobj__388 __pyx_mstate_global->__pyx_codeobj__388
#define __pyx_codeobj__389 __pyx_mstate_global->__pyx_codeobj__389
#define __pyx_codeobj__390 __pyx_mstate_global->__pyx_codeobj__390
#define __pyx_codeobj__391 __pyx_mstate_global->__pyx_codeobj__391
#define __pyx_codeobj__392 __pyx_mstate_global->__pyx_codeobj__392
#define __pyx_codeobj__393 __pyx_mstate_global->__pyx_codeobj__393
#define __pyx_codeobj__394 __pyx_mstate_global->__pyx_codeobj__394
#define __pyx_codeobj__395 __pyx_mstate_global->__pyx_codeobj__395
#define __pyx_codeobj__396 __pyx_mstate_global->__pyx_codeobj__396
#define __pyx_codeobj__397 __pyx_mstate_global->__pyx_codeobj__397
#define __pyx_codeobj__398 __pyx_mstate_global->__pyx_codeobj__398
#define __pyx_codeobj__399 __pyx_mstate_global->__pyx_codeobj__399
#define __pyx_codeobj__400 __pyx_mstate_global->__pyx_codeobj__400
#define __pyx_codeobj__401 __pyx_mstate_global->__pyx_codeobj__401
#define __pyx_codeobj__402 __pyx_mstate_global->__pyx_codeobj__402
#define __pyx_codeobj__403 __pyx_mstate_global->__pyx_codeobj__403
#define __pyx_codeobj__404 __pyx_mstate_global->__pyx_codeobj__404
#define __pyx_codeobj__405 __pyx_mstate_global->__pyx_codeobj__405
#define __pyx_codeobj__406 __pyx_mstate_global->__pyx_codeobj__406
#define __pyx_codeobj__407 __pyx_mstate_global->__pyx_codeobj__407
#define __pyx_codeobj__408 __pyx_mstate_global->__pyx_codeobj__408
#define __pyx_codeobj__409 __pyx_mstate_global->__pyx_codeobj__409
#define __pyx_codeobj__410 __pyx_mstate_global->__pyx_codeobj__410
#define __pyx_codeobj__411 __pyx_mstate_global->__pyx_codeobj__411
#define __pyx_codeobj__412 __pyx_mstate_global->__pyx_codeobj__412
#define __pyx_codeobj__413 __pyx_mstate_global->__pyx_codeobj__413
#define __pyx_codeobj__414 __pyx_mstate_global->__pyx_codeobj__414
#define __pyx_codeobj__415 __pyx_mstate_global->__pyx_codeobj__415
#define __pyx_codeobj__416 __pyx_mstate_global->__pyx_codeobj__416
#define __pyx_codeobj__417 __pyx_mstate_global->__pyx_codeobj__417
#define __pyx_codeobj__418 __pyx_mstate_global->__pyx_codeobj__418
#define __pyx_codeobj__419 __pyx_mstate_global->__pyx_codeobj__419
#define __pyx_codeobj__420 __pyx_mstate_global->__pyx_codeobj__420
#define __pyx_codeobj__421 __pyx_mstate_global->__pyx_codeobj__421
#define __pyx_codeobj__422 __pyx_mstate_global->__pyx_codeobj__422
#define __pyx_codeobj__423 __pyx_mstate_global->__pyx_codeobj__423
#define __pyx_codeobj__424 __pyx_mstate_global->__pyx_codeobj__424
#define __pyx_codeobj__425 __pyx_mstate_global->__pyx_codeobj__425
#define __pyx_codeobj__426 __pyx_mstate_global->__pyx_codeobj__426
#define __pyx_codeobj__427 __pyx_mstate_global->__pyx_codeobj__427
#define __pyx_codeobj__428 __pyx_mstate_global->__pyx_codeobj__428
#define __pyx_codeobj__429 __pyx_mstate_global->__pyx_codeobj__429
#define __pyx_codeobj__430 __pyx_mstate_global->__pyx_codeobj__430
#define __pyx_codeobj__431 __pyx_mstate_global->__pyx_codeobj__431
#define __pyx_codeobj__432 __pyx_mstate_global->__pyx_codeobj__432
#define __pyx_codeobj__433 __pyx_mstate_global->__pyx_codeobj__433
#define __pyx_codeobj__434 __pyx_mstate_global->__pyx_codeobj__434
#define __pyx_codeobj__435 __pyx_mstate_global->__pyx_codeobj__435
#define __pyx_codeobj__436 __pyx_mstate_global->__pyx_codeobj__436
#define __pyx_codeobj__437 __pyx_mstate_global->__pyx_codeobj__437
#define __pyx_codeobj__438 __pyx_mstate_global->__pyx_codeobj__438
#define __pyx_codeobj__439 __pyx_mstate_global->__pyx_codeobj__439
#define __pyx_codeobj__440 __pyx_mstate_global->__pyx_codeobj__440
#define __pyx_codeobj__441 __pyx_mstate_global->__pyx_codeobj__441
#define __pyx_codeobj__442 __pyx_mstate_global->__pyx_codeobj__442
#define __pyx_codeobj__443 __pyx_mstate_global->__pyx_codeobj__443
#define __pyx_codeobj__444 __pyx_mstate_global->__pyx_codeobj__444
#define __pyx_codeobj__445 __pyx_mstate_global->__pyx_codeobj__445
#define __pyx_codeobj__446 __pyx_mstate_global->__pyx_codeobj__446
#define __pyx_codeobj__447 __pyx_mstate_global->__pyx_codeobj__447
#define __pyx_codeobj__448 __pyx_mstate_global->__pyx_codeobj__448
#define __pyx_codeobj__449 __pyx_mstate_global->__pyx_codeobj__449
#define __pyx_codeobj__450 __pyx_mstate_global->__pyx_codeobj__450
#define __pyx_codeobj__451 __pyx_mstate_global->__pyx_codeobj__451
#define __pyx_codeobj__452 __pyx_mstate_global->__pyx_codeobj__452
#define __pyx_codeobj__453 __pyx_mstate_global->__pyx_codeobj__453
#define __pyx_codeobj__454 __pyx_mstate_global->__pyx_codeobj__454
#define __pyx_codeobj__455 __pyx_mstate_global->__pyx_codeobj__455
#define __pyx_codeobj__456 __pyx_mstate_global->__pyx_codeobj__456
#define __pyx_codeobj__457 __pyx_mstate_global->__pyx_codeobj__457
#define __pyx_codeobj__458 __pyx_mstate_global->__pyx_codeobj__458
#define __pyx_codeobj__459 __pyx_mstate_global->__pyx_codeobj__459
#define __pyx_codeobj__460 __pyx_mstate_global->__pyx_codeobj__460
#define __pyx_codeobj__461 __pyx_mstate_global->__pyx_codeobj__461
#define __pyx_codeobj__462 __pyx_mstate_global->__pyx_codeobj__462
#define __pyx_codeobj__463 __pyx_mstate_global->__pyx_codeobj__463
#define __pyx_codeobj__464 __pyx_mstate_global->__pyx_codeobj__464
#define __pyx_codeobj__465 __pyx_mstate_global->__pyx_codeobj__465
#define __pyx_codeobj__466 __pyx_mstate_global->__pyx_codeobj__466
#define __pyx_codeobj__467 __pyx_mstate_global->__pyx_codeobj__467
#define __pyx_codeobj__468 __pyx_mstate_global->__pyx_codeobj__468
#define __pyx_codeobj__469 __pyx_mstate_global->__pyx_codeobj__469
#define __pyx_codeobj__470 __pyx_mstate_global->__pyx_codeobj__470
#define __pyx_codeobj__471 __pyx_mstate_global->__pyx_codeobj__471
#define __pyx_codeobj__472 __pyx_mstate_global->__pyx_codeobj__472
#define __pyx_codeobj__473 __pyx_mstate_global->__pyx_codeobj__473
#define __pyx_codeobj__474 __pyx_mstate_global->__pyx_codeobj__474
#define __pyx_codeobj__475 __pyx_mstate_global->__pyx_codeobj__475
#define __pyx_codeobj__476 __pyx_mstate_global->__pyx_codeobj__476
#define __pyx_codeobj__477 __pyx_mstate_global->__pyx_codeobj__477
#define __pyx_codeobj__478 __pyx_mstate_global->__pyx_codeobj__478
#define __pyx_codeobj__479 __pyx_mstate_global->__pyx_codeobj__479
#define __pyx_codeobj__480 __pyx_mstate_global->__pyx_codeobj__480
#define __pyx_codeobj__481 __pyx_mstate_global->__pyx_codeobj__481
#define __pyx_codeobj__482 __pyx_mstate_global->__pyx_codeobj__482
#define __pyx_codeobj__483 __pyx_mstate_global->__pyx_codeobj__483
#define __pyx_codeobj__484 __pyx_mstate_global->__pyx_codeobj__484
#define __pyx_codeobj__485 __pyx_mstate_global->__pyx_codeobj__485
#define __pyx_codeobj__486 __pyx_mstate_global->__pyx_codeobj__486
#define __pyx_codeobj__487 __pyx_mstate_global->__pyx_codeobj__487
#define __pyx_codeobj__488 __pyx_mstate_global->__pyx_codeobj__488
#define __pyx_codeobj__489 __pyx_mstate_global->__pyx_codeobj__489
#define __pyx_codeobj__490 __pyx_mstate_global->__pyx_codeobj__490
#define __pyx_codeobj__491 __pyx_mstate_global->__pyx_codeobj__491
#define __pyx_codeobj__492 __pyx_mstate_global->__pyx_codeobj__492
#define __pyx_codeobj__493 __pyx_mstate_global->__pyx_codeobj__493
#define __pyx_codeobj__494 __pyx_mstate_global->__pyx_codeobj__494
#define __pyx_codeobj__495 __pyx_mstate_global->__pyx_codeobj__495
#define __pyx_codeobj__496 __pyx_mstate_global->__pyx_codeobj__496
#define __pyx_codeobj__497 __pyx_mstate_global->__pyx_codeobj__497
#define __pyx_codeobj__498 __pyx_mstate_global->__pyx_codeobj__498
#define __pyx_codeobj__499 __pyx_mstate_global->__pyx_codeobj__499
#define __pyx_codeobj__500 __pyx_mstate_global->__pyx_codeobj__500
#define __pyx_codeobj__501 __pyx_mstate_global->__pyx_codeobj__501
#define __pyx_codeobj__502 __pyx_mstate_global->__pyx_codeobj__502
#define __pyx_codeobj__503 __pyx_mstate_global->__pyx_codeobj__503
#define __pyx_codeobj__504 __pyx_mstate_global->__pyx_codeobj__504
#define __pyx_codeobj__505 __pyx_mstate_global->__pyx_codeobj__505
#define __pyx_codeobj__506 __pyx_mstate_global->__pyx_codeobj__506
#define __pyx_codeobj__507 __pyx_mstate_global->__pyx_codeobj__507
#define __pyx_codeobj__508 __pyx_mstate_global->__pyx_codeobj__508
#define __pyx_codeobj__509 __pyx_mstate_global->__pyx_codeobj__509
#define __pyx_codeobj__510 __pyx_mstate_global->__pyx_codeobj__510
#define __pyx_codeobj__511 __pyx_mstate_global->__pyx_codeobj__511
#define __pyx_codeobj__512 __pyx_mstate_global->__pyx_codeobj__512
#define __pyx_codeobj__513 __pyx_mstate_global->__pyx_codeobj__513
#define __pyx_codeobj__514 __pyx_mstate_global->__pyx_codeobj__514
#define __pyx_codeobj__515 __pyx_mstate_global->__pyx_codeobj__515
#define __pyx_codeobj__516 __pyx_mstate_global->__pyx_codeobj__516
#define __pyx_codeobj__517 __pyx_mstate_global->__pyx_codeobj__517
#define __pyx_codeobj__518 __pyx_mstate_global->__pyx_codeobj__518
#define __pyx_codeobj__519 __pyx_mstate_global->__pyx_codeobj__519
#define __pyx_codeobj__520 __pyx_mstate_global->__pyx_codeobj__520
#define __pyx_codeobj__521 __pyx_mstate_global->__pyx_codeobj__521
#define __pyx_codeobj__522 __pyx_mstate_global->__pyx_codeobj__522
#define __pyx_codeobj__523 __pyx_mstate_global->__pyx_codeobj__523
#define __pyx_codeobj__524 __pyx_mstate_global->__pyx_codeobj__524
#define __pyx_codeobj__525 __pyx_mstate_global->__pyx_codeobj__525
#define __pyx_codeobj__526 __pyx_mstate_global->__pyx_codeobj__526
#define __pyx_codeobj__527 __pyx_mstate_global->__pyx_codeobj__527
#define __pyx_codeobj__528 __pyx_mstate_global->__pyx_codeobj__528
#define __pyx_codeobj__529 __pyx_mstate_global->__pyx_codeobj__529
#define __pyx_codeobj__530 __pyx_mstate_global->__pyx_codeobj__530
#define __pyx_codeobj__531 __pyx_mstate_global->__pyx_codeobj__531
#define __pyx_codeobj__532 __pyx_mstate_global->__pyx_codeobj__532
#define __pyx_codeobj__533 __pyx_mstate_global->__pyx_codeobj__533
#define __pyx_codeobj__534 __pyx_mstate_global->__pyx_codeobj__534
#define __pyx_codeobj__535 __pyx_mstate_global->__pyx_codeobj__535
#define __pyx_codeobj__536 __pyx_mstate_global->__pyx_codeobj__536
#define __pyx_codeobj__537 __pyx_mstate_global->__pyx_codeobj__537
#define __pyx_codeobj__538 __pyx_mstate_global->__pyx_codeobj__538
#define __pyx_codeobj__539 __pyx_mstate_global->__pyx_codeobj__539
#define __pyx_codeobj__540 __pyx_mstate_global->__pyx_codeobj__540
#define __pyx_codeobj__541 __pyx_mstate_global->__pyx_codeobj__541
#define __pyx_codeobj__542 __pyx_mstate_global->__pyx_codeobj__542
#define __pyx_codeobj__543 __pyx_mstate_global->__pyx_codeobj__543
#define __pyx_codeobj__544 __pyx_mstate_global->__pyx_codeobj__544
#define __pyx_codeobj__545 __pyx_mstate_global->__pyx_codeobj__545
#define __pyx_codeobj__546 __pyx_mstate_global->__pyx_codeobj__546
#define __pyx_codeobj__547 __pyx_mstate_global->__pyx_codeobj__547
#define __pyx_codeobj__548 __pyx_mstate_global->__pyx_codeobj__548
#define __pyx_codeobj__549 __pyx_mstate_global->__pyx_codeobj__549
#define __pyx_codeobj__550 __pyx_mstate_global->__pyx_codeobj__550
#define __pyx_codeobj__551 __pyx_mstate_global->__pyx_codeobj__551
#define __pyx_codeobj__552 __pyx_mstate_global->__pyx_codeobj__552
#define __pyx_codeobj__553 __pyx_mstate_global->__pyx_codeobj__553
#define __pyx_codeobj__554 __pyx_mstate_global->__pyx_codeobj__554
#define __pyx_codeobj__555 __pyx_mstate_global->__pyx_codeobj__555
#define __pyx_codeobj__556 __pyx_mstate_global->__pyx_codeobj__556
#define __pyx_codeobj__557 __pyx_mstate_global->__pyx_codeobj__557
#define __pyx_codeobj__558 __pyx_mstate_global->__pyx_codeobj__558
#define __pyx_codeobj__559 __pyx_mstate_global->__pyx_codeobj__559
#define __pyx_codeobj__560 __pyx_mstate_global->__pyx_codeobj__560
#define __pyx_codeobj__561 __pyx_mstate_global->__pyx_codeobj__561
#define __pyx_codeobj__562 __pyx_mstate_global->__pyx_codeobj__562
#define __pyx_codeobj__563 __pyx_mstate_global->__pyx_codeobj__563
#define __pyx_codeobj__564 __pyx_mstate_global->__pyx_codeobj__564
#define __pyx_codeobj__565 __pyx_mstate_global->__pyx_codeobj__565
#define __pyx_codeobj__566 __pyx_mstate_global->__pyx_codeobj__566
#define __pyx_codeobj__567 __pyx_mstate_global->__pyx_codeobj__567
#define __pyx_codeobj__568 __pyx_mstate_global->__pyx_codeobj__568
#define __pyx_codeobj__569 __pyx_mstate_global->__pyx_codeobj__569
#define __pyx_codeobj__570 __pyx_mstate_global->__pyx_codeobj__570
#define __pyx_codeobj__571 __pyx_mstate_global->__pyx_codeobj__571
#define __pyx_codeobj__572 __pyx_mstate_global->__pyx_codeobj__572
#define __pyx_codeobj__573 __pyx_mstate_global->__pyx_codeobj__573
#define __pyx_codeobj__574 __pyx_mstate_global->__pyx_codeobj__574
#define __pyx_codeobj__575 __pyx_mstate_global->__pyx_codeobj__575
#define __pyx_codeobj__576 __pyx_mstate_global->__pyx_codeobj__576
#define __pyx_codeobj__577 __pyx_mstate_global->__pyx_codeobj__577
#define __pyx_codeobj__578 __pyx_mstate_global->__pyx_codeobj__578
#define __pyx_codeobj__579 __pyx_mstate_global->__pyx_codeobj__579
#define __pyx_codeobj__580 __pyx_mstate_global->__pyx_codeobj__580
#define __pyx_codeobj__581 __pyx_mstate_global->__pyx_codeobj__581
#define __pyx_codeobj__582 __pyx_mstate_global->__pyx_codeobj__582
#define __pyx_codeobj__583 __pyx_mstate_global->__pyx_codeobj__583
#define __pyx_codeobj__584 __pyx_mstate_global->__pyx_codeobj__584
#define __pyx_codeobj__585 __pyx_mstate_global->__pyx_codeobj__585
#define __pyx_codeobj__586 __pyx_mstate_global->__pyx_codeobj__586
#define __pyx_codeobj__587 __pyx_mstate_global->__pyx_codeobj__587
#define __pyx_codeobj__588 __pyx_mstate_global->__pyx_codeobj__588
#define __pyx_codeobj__589 __pyx_mstate_global->__pyx_codeobj__589
#define __pyx_codeobj__590 __pyx_mstate_global->__pyx_codeobj__590
#define __pyx_codeobj__591 __pyx_mstate_global->__pyx_codeobj__591
#define __pyx_codeobj__592 __pyx_mstate_global->__pyx_codeobj__592
#define __pyx_codeobj__593 __pyx_mstate_global->__pyx_codeobj__593
#define __pyx_codeobj__594 __pyx_mstate_global->__pyx_codeobj__594
#define __pyx_codeobj__595 __pyx_mstate_global->__pyx_codeobj__595
#define __pyx_codeobj__596 __pyx_mstate_global->__pyx_codeobj__596
#define __pyx_codeobj__597 __pyx_mstate_global->__pyx_codeobj__597
#define __pyx_codeobj__598 __pyx_mstate_global->__pyx_codeobj__598
#define __pyx_codeobj__599 __pyx_mstate_global->__pyx_codeobj__599
#define __pyx_codeobj__600 __pyx_mstate_global->__pyx_codeobj__600
#define __pyx_codeobj__601 __pyx_mstate_global->__pyx_codeobj__601
#define __pyx_codeobj__602 __pyx_mstate_global->__pyx_codeobj__602
#define __pyx_codeobj__603 __pyx_mstate_global->__pyx_codeobj__603
#define __pyx_codeobj__604 __pyx_mstate_global->__pyx_codeobj__604
#define __pyx_codeobj__605 __pyx_mstate_global->__pyx_codeobj__605
#define __pyx_codeobj__606 __pyx_mstate_global->__pyx_codeobj__606
#define __pyx_codeobj__607 __pyx_mstate_global->__pyx_codeobj__607
#define __pyx_codeobj__608 __pyx_mstate_global->__pyx_codeobj__608
#define __pyx_codeobj__609 __pyx_mstate_global->__pyx_codeobj__609
#define __pyx_codeobj__610 __pyx_mstate_global->__pyx_codeobj__610
#define __pyx_codeobj__611 __pyx_mstate_global->__pyx_codeobj__611
#define __pyx_codeobj__612 __pyx_mstate_global->__pyx_codeobj__612
#define __pyx_codeobj__613 __pyx_mstate_global->__pyx_codeobj__613
#define __pyx_codeobj__614 __pyx_mstate_global->__pyx_codeobj__614
#define __pyx_codeobj__615 __pyx_mstate_global->__pyx_codeobj__615
#define __pyx_codeobj__616 __pyx_mstate_global->__pyx_codeobj__616
#define __pyx_codeobj__617 __pyx_mstate_global->__pyx_codeobj__617
#define __pyx_codeobj__618 __pyx_mstate_global->__pyx_codeobj__618
#define __pyx_codeobj__619 __pyx_mstate_global->__pyx_codeobj__619
#define __pyx_codeobj__620 __pyx_mstate_global->__pyx_codeobj__620
#define __pyx_codeobj__621 __pyx_mstate_global->__pyx_codeobj__621
#define __pyx_codeobj__622 __pyx_mstate_global->__pyx_codeobj__622
#define __pyx_codeobj__623 __pyx_mstate_global->__pyx_codeobj__623
#define __pyx_codeobj__624 __pyx_mstate_global->__pyx_codeobj__624
#define __pyx_codeobj__625 __pyx_mstate_global->__pyx_codeobj__625
#define __pyx_codeobj__626 __pyx_mstate_global->__pyx_codeobj__626
#define __pyx_codeobj__627 __pyx_mstate_global->__pyx_codeobj__627
#define __pyx_codeobj__628 __pyx_mstate_global->__pyx_codeobj__628
#define __pyx_codeobj__629 __pyx_mstate_global->__pyx_codeobj__629
#define __pyx_codeobj__630 __pyx_mstate_global->__pyx_codeobj__630
#define __pyx_codeobj__631 __pyx_mstate_global->__pyx_codeobj__631
#define __pyx_codeobj__632 __pyx_mstate_global->__pyx_codeobj__632
#define __pyx_codeobj__633 __pyx_mstate_global->__pyx_codeobj__633
#define __pyx_codeobj__634 __pyx_mstate_global->__pyx_codeobj__634
#define __pyx_codeobj__635 __pyx_mstate_global->__pyx_codeobj__635
#define __pyx_codeobj__636 __pyx_mstate_global->__pyx_codeobj__636
#define __pyx_codeobj__637 __pyx_mstate_global->__pyx_codeobj__637
#define __pyx_codeobj__638 __pyx_mstate_global->__pyx_codeobj__638
#define __pyx_codeobj__639 __pyx_mstate_global->__pyx_codeobj__639
#define __pyx_codeobj__640 __pyx_mstate_global->__pyx_codeobj__640
#define __pyx_codeobj__641 __pyx_mstate_global->__pyx_codeobj__641
#define __pyx_codeobj__642 __pyx_mstate_global->__pyx_codeobj__642
#define __pyx_codeobj__643 __pyx_mstate_global->__pyx_codeobj__643
#define __pyx_codeobj__644 __pyx_mstate_global->__pyx_codeobj__644
#define __pyx_codeobj__645 __pyx_mstate_global->__pyx_codeobj__645
#define __pyx_codeobj__646 __pyx_mstate_global->__pyx_codeobj__646
#define __pyx_codeobj__647 __pyx_mstate_global->__pyx_codeobj__647
#define __pyx_codeobj__648 __pyx_mstate_global->__pyx_codeobj__648
#define __pyx_codeobj__649 __pyx_mstate_global->__pyx_codeobj__649
#define __pyx_codeobj__650 __pyx_mstate_global->__pyx_codeobj__650
#define __pyx_codeobj__651 __pyx_mstate_global->__pyx_codeobj__651
#define __pyx_codeobj__652 __pyx_mstate_global->__pyx_codeobj__652
#define __pyx_codeobj__653 __pyx_mstate_global->__pyx_codeobj__653
#define __pyx_codeobj__654 __pyx_mstate_global->__pyx_codeobj__654
#define __pyx_codeobj__655 __pyx_mstate_global->__pyx_codeobj__655
#define __pyx_codeobj__656 __pyx_mstate_global->__pyx_codeobj__656
#define __pyx_codeobj__657 __pyx_mstate_global->__pyx_codeobj__657
#define __pyx_codeobj__658 __pyx_mstate_global->__pyx_codeobj__658
#define __pyx_codeobj__659 __pyx_mstate_global->__pyx_codeobj__659
#define __pyx_codeobj__660 __pyx_mstate_global->__pyx_codeobj__660
#define __pyx_codeobj__661 __pyx_mstate_global->__pyx_codeobj__661
#define __pyx_codeobj__662 __pyx_mstate_global->__pyx_codeobj__662
#define __pyx_codeobj__663 __pyx_mstate_global->__pyx_codeobj__663
#define __pyx_codeobj__664 __pyx_mstate_global->__pyx_codeobj__664
#define __pyx_codeobj__665 __pyx_mstate_global->__pyx_codeobj__665
#define __pyx_codeobj__666 __pyx_mstate_global->__pyx_codeobj__666
#define __pyx_codeobj__667 __pyx_mstate_global->__pyx_codeobj__667
#define __pyx_codeobj__668 __pyx_mstate_global->__pyx_codeobj__668
#define __pyx_codeobj__669 __pyx_mstate_global->__pyx_codeobj__669
#define __pyx_codeobj__670 __pyx_mstate_global->__pyx_codeobj__670
#define __pyx_codeobj__671 __pyx_mstate_global->__pyx_codeobj__671
#define __pyx_codeobj__672 __pyx_mstate_global->__pyx_codeobj__672
#define __pyx_codeobj__673 __pyx_mstate_global->__pyx_codeobj__673
#define __pyx_codeobj__674 __pyx_mstate_global->__pyx_codeobj__674
#define __pyx_codeobj__675 __pyx_mstate_global->__pyx_codeobj__675
#define __pyx_codeobj__676 __pyx_mstate_global->__pyx_codeobj__676
#define __pyx_codeobj__677 __pyx_mstate_global->__pyx_codeobj__677
#define __pyx_codeobj__678 __pyx_mstate_global->__pyx_codeobj__678
#define __pyx_codeobj__679 __pyx_mstate_global->__pyx_codeobj__679
#define __pyx_codeobj__680 __pyx_mstate_global->__pyx_codeobj__680
#define __pyx_codeobj__681 __pyx_mstate_global->__pyx_codeobj__681
#define __pyx_codeobj__682 __pyx_mstate_global->__pyx_codeobj__682
#define __pyx_codeobj__683 __pyx_mstate_global->__pyx_codeobj__683
#define __pyx_codeobj__684 __pyx_mstate_global->__pyx_codeobj__684
#define __pyx_codeobj__685 __pyx_mstate_global->__pyx_codeobj__685
#define __pyx_codeobj__686 __pyx_mstate_global->__pyx_codeobj__686
#define __pyx_codeobj__687 __pyx_mstate_global->__pyx_codeobj__687
#define __pyx_codeobj__688 __pyx_mstate_global->__pyx_codeobj__688
#define __pyx_codeobj__689 __pyx_mstate_global->__pyx_codeobj__689
#define __pyx_codeobj__690 __pyx_mstate_global->__pyx_codeobj__690
#define __pyx_codeobj__691 __pyx_mstate_global->__pyx_codeobj__691
#define __pyx_codeobj__692 __pyx_mstate_global->__pyx_codeobj__692
#define __pyx_codeobj__693 __pyx_mstate_global->__pyx_codeobj__693
#define __pyx_codeobj__694 __pyx_mstate_global->__pyx_codeobj__694
#define __pyx_codeobj__695 __pyx_mstate_global->__pyx_codeobj__695
#define __pyx_codeobj__696 __pyx_mstate_global->__pyx_codeobj__696
#define __pyx_codeobj__697 __pyx_mstate_global->__pyx_codeobj__697
#define __pyx_codeobj__698 __pyx_mstate_global->__pyx_codeobj__698
#define __pyx_codeobj__699 __pyx_mstate_global->__pyx_codeobj__699
#define __pyx_codeobj__700 __pyx_mstate_global->__pyx_codeobj__700
#define __pyx_codeobj__701 __pyx_mstate_global->__pyx_codeobj__701
#define __pyx_codeobj__702 __pyx_mstate_global->__pyx_codeobj__702
#define __pyx_codeobj__703 __pyx_mstate_global->__pyx_codeobj__703
#define __pyx_codeobj__704 __pyx_mstate_global->__pyx_codeobj__704
#define __pyx_codeobj__705 __pyx_mstate_global->__pyx_codeobj__705
#define __pyx_codeobj__706 __pyx_mstate_global->__pyx_codeobj__706
#define __pyx_codeobj__707 __pyx_mstate_global->__pyx_codeobj__707
#define __pyx_codeobj__708 __pyx_mstate_global->__pyx_codeobj__708
#define __pyx_codeobj__709 __pyx_mstate_global->__pyx_codeobj__709
#define __pyx_codeobj__710 __pyx_mstate_global->__pyx_codeobj__710
#define __pyx_codeobj__711 __pyx_mstate_global->__pyx_codeobj__711
#define __pyx_codeobj__712 __pyx_mstate_global->__pyx_codeobj__712
#define __pyx_codeobj__713 __pyx_mstate_global->__pyx_codeobj__713
#define __pyx_codeobj__714 __pyx_mstate_global->__pyx_codeobj__714
#define __pyx_codeobj__715 __pyx_mstate_global->__pyx_codeobj__715
#define __pyx_codeobj__716 __pyx_mstate_global->__pyx_codeobj__716
#define __pyx_codeobj__717 __pyx_mstate_global->__pyx_codeobj__717
#define __pyx_codeobj__718 __pyx_mstate_global->__pyx_codeobj__718
#define __pyx_codeobj__719 __pyx_mstate_global->__pyx_codeobj__719
#define __pyx_codeobj__720 __pyx_mstate_global->__pyx_codeobj__720
#define __pyx_codeobj__721 __pyx_mstate_global->__pyx_codeobj__721
#define __pyx_codeobj__722 __pyx_mstate_global->__pyx_codeobj__722
#define __pyx_codeobj__723 __pyx_mstate_global->__pyx_codeobj__723
#define __pyx_codeobj__724 __pyx_mstate_global->__pyx_codeobj__724
#define __pyx_codeobj__725 __pyx_mstate_global->__pyx_codeobj__725
#define __pyx_codeobj__726 __pyx_mstate_global->__pyx_codeobj__726
#define __pyx_codeobj__727 __pyx_mstate_global->__pyx_codeobj__727
#define __pyx_codeobj__728 __pyx_mstate_global->__pyx_codeobj__728
#define __pyx_codeobj__729 __pyx_mstate_global->__pyx_codeobj__729
#define __pyx_codeobj__730 __pyx_mstate_global->__pyx_codeobj__730
#define __pyx_codeobj__731 __pyx_mstate_global->__pyx_codeobj__731
#define __pyx_codeobj__732 __pyx_mstate_global->__pyx_codeobj__732
#define __pyx_codeobj__733 __pyx_mstate_global->__pyx_codeobj__733
#define __pyx_codeobj__734 __pyx_mstate_global->__pyx_codeobj__734
#define __pyx_codeobj__735 __pyx_mstate_global->__pyx_codeobj__735
#define __pyx_codeobj__736 __pyx_mstate_global->__pyx_codeobj__736
#define __pyx_codeobj__737 __pyx_mstate_global->__pyx_codeobj__737
#define __pyx_codeobj__738 __pyx_mstate_global->__pyx_codeobj__738
#define __pyx_codeobj__739 __pyx_mstate_global->__pyx_codeobj__739
#define __pyx_codeobj__740 __pyx_mstate_global->__pyx_codeobj__740
#define __pyx_codeobj__741 __pyx_mstate_global->__pyx_codeobj__741
#define __pyx_codeobj__742 __pyx_mstate_global->__pyx_codeobj__742
#define __pyx_codeobj__743 __pyx_mstate_global->__pyx_codeobj__743
#define __pyx_codeobj__744 __pyx_mstate_global->__pyx_codeobj__744
#define __pyx_codeobj__745 __pyx_mstate_global->__pyx_codeobj__745
#define __pyx_codeobj__746 __pyx_mstate_global->__pyx_codeobj__746
#define __pyx_codeobj__747 __pyx_mstate_global->__pyx_codeobj__747
#define __pyx_codeobj__748 __pyx_mstate_global->__pyx_codeobj__748
#define __pyx_codeobj__749 __pyx_mstate_global->__pyx_codeobj__749
#define __pyx_codeobj__750 __pyx_mstate_global->__pyx_codeobj__750
#define __pyx_codeobj__751 __pyx_mstate_global->__pyx_codeobj__751
#define __pyx_codeobj__752 __pyx_mstate_global->__pyx_codeobj__752
#define __pyx_codeobj__753 __pyx_mstate_global->__pyx_codeobj__753
#define __pyx_codeobj__754 __pyx_mstate_global->__pyx_codeobj__754
#define __pyx_codeobj__755 __pyx_mstate_global->__pyx_codeobj__755
#define __pyx_codeobj__756 __pyx_mstate_global->__pyx_codeobj__756
#define __pyx_codeobj__757 __pyx_mstate_global->__pyx_codeobj__757
#define __pyx_codeobj__758 __pyx_mstate_global->__pyx_codeobj__758
#define __pyx_codeobj__759 __pyx_mstate_global->__pyx_codeobj__759
#define __pyx_codeobj__760 __pyx_mstate_global->__pyx_codeobj__760
#define __pyx_codeobj__761 __pyx_mstate_global->__pyx_codeobj__761
#define __pyx_codeobj__762 __pyx_mstate_global->__pyx_codeobj__762
#define __pyx_codeobj__763 __pyx_mstate_global->__pyx_codeobj__763
#define __pyx_codeobj__764 __pyx_mstate_global->__pyx_codeobj__764
#define __pyx_codeobj__765 __pyx_mstate_global->__pyx_codeobj__765
#define __pyx_codeobj__766 __pyx_mstate_global->__pyx_codeobj__766
#define __pyx_codeobj__767 __pyx_mstate_global->__pyx_codeobj__767
#define __pyx_codeobj__768 __pyx_mstate_global->__pyx_codeobj__768
#define __pyx_codeobj__769 __pyx_mstate_global->__pyx_codeobj__769
#define __pyx_codeobj__770 __pyx_mstate_global->__pyx_codeobj__770
#define __pyx_codeobj__771 __pyx_mstate_global->__pyx_codeobj__771
#define __pyx_codeobj__772 __pyx_mstate_global->__pyx_codeobj__772
#define __pyx_codeobj__773 __pyx_mstate_global->__pyx_codeobj__773
#define __pyx_codeobj__774 __pyx_mstate_global->__pyx_codeobj__774
#define __pyx_codeobj__775 __pyx_mstate_global->__pyx_codeobj__775
#define __pyx_codeobj__776 __pyx_mstate_global->__pyx_codeobj__776
#define __pyx_codeobj__777 __pyx_mstate_global->__pyx_codeobj__777
#define __pyx_codeobj__778 __pyx_mstate_global->__pyx_codeobj__778
#define __pyx_codeobj__779 __pyx_mstate_global->__pyx_codeobj__779
#define __pyx_codeobj__780 __pyx_mstate_global->__pyx_codeobj__780
#define __pyx_codeobj__781 __pyx_mstate_global->__pyx_codeobj__781
#define __pyx_codeobj__782 __pyx_mstate_global->__pyx_codeobj__782
#define __pyx_codeobj__783 __pyx_mstate_global->__pyx_codeobj__783
#define __pyx_codeobj__784 __pyx_mstate_global->__pyx_codeobj__784
#define __pyx_codeobj__785 __pyx_mstate_global->__pyx_codeobj__785
#define __pyx_codeobj__786 __pyx_mstate_global->__pyx_codeobj__786
#define __pyx_codeobj__787 __pyx_mstate_global->__pyx_codeobj__787
#define __pyx_codeobj__788 __pyx_mstate_global->__pyx_codeobj__788
#define __pyx_codeobj__789 __pyx_mstate_global->__pyx_codeobj__789
#define __pyx_codeobj__790 __pyx_mstate_global->__pyx_codeobj__790
#define __pyx_codeobj__791 __pyx_mstate_global->__pyx_codeobj__791
#define __pyx_codeobj__792 __pyx_mstate_global->__pyx_codeobj__792
#define __pyx_codeobj__793 __pyx_mstate_global->__pyx_codeobj__793
#define __pyx_codeobj__794 __pyx_mstate_global->__pyx_codeobj__794
#define __pyx_codeobj__795 __pyx_mstate_global->__pyx_codeobj__795
#define __pyx_codeobj__796 __pyx_mstate_global->__pyx_codeobj__796
#define __pyx_codeobj__797 __pyx_mstate_global->__pyx_codeobj__797
#define __pyx_codeobj__798 __pyx_mstate_global->__pyx_codeobj__798
#define __pyx_codeobj__799 __pyx_mstate_global->__pyx_codeobj__799
#define __pyx_codeobj__800 __pyx_mstate_global->__pyx_codeobj__800
#define __pyx_codeobj__801 __pyx_mstate_global->__pyx_codeobj__801
#define __pyx_codeobj__802 __pyx_mstate_global->__pyx_codeobj__802
#define __pyx_codeobj__803 __pyx_mstate_global->__pyx_codeobj__803
#define __pyx_codeobj__804 __pyx_mstate_global->__pyx_codeobj__804
#define __pyx_codeobj__805 __pyx_mstate_global->__pyx_codeobj__805
#define __pyx_codeobj__806 __pyx_mstate_global->__pyx_codeobj__806
#define __pyx_codeobj__807 __pyx_mstate_global->__pyx_codeobj__807
#define __pyx_codeobj__808 __pyx_mstate_global->__pyx_codeobj__808
#define __pyx_codeobj__809 __pyx_mstate_global->__pyx_codeobj__809
#define __pyx_codeobj__810 __pyx_mstate_global->__pyx_codeobj__810
#define __pyx_codeobj__811 __pyx_mstate_global->__pyx_codeobj__811
#define __pyx_codeobj__812 __pyx_mstate_global->__pyx_codeobj__812
#define __pyx_codeobj__813 __pyx_mstate_global->__pyx_codeobj__813
#define __pyx_codeobj__814 __pyx_mstate_global->__pyx_codeobj__814
#define __pyx_codeobj__815 __pyx_mstate_global->__pyx_codeobj__815
#define __pyx_codeobj__816 __pyx_mstate_global->__pyx_codeobj__816
#define __pyx_codeobj__817 __pyx_mstate_global->__pyx_codeobj__817
#define __pyx_codeobj__818 __pyx_mstate_global->__pyx_codeobj__818
#define __pyx_codeobj__819 __pyx_mstate_global->__pyx_codeobj__819
#define __pyx_codeobj__820 __pyx_mstate_global->__pyx_codeobj__820
#define __pyx_codeobj__821 __pyx_mstate_global->__pyx_codeobj__821
#define __pyx_codeobj__822 __pyx_mstate_global->__pyx_codeobj__822
#define __pyx_codeobj__823 __pyx_mstate_global->__pyx_codeobj__823
#define __pyx_codeobj__824 __pyx_mstate_global->__pyx_codeobj__824
#define __pyx_codeobj__825 __pyx_mstate_global->__pyx_codeobj__825
#define __pyx_codeobj__826 __pyx_mstate_global->__pyx_codeobj__826
#define __pyx_codeobj__827 __pyx_mstate_global->__pyx_codeobj__827
#define __pyx_codeobj__828 __pyx_mstate_global->__pyx_codeobj__828
#define __pyx_codeobj__829 __pyx_mstate_global->__pyx_codeobj__829
#define __pyx_codeobj__830 __pyx_mstate_global->__pyx_codeobj__830
#define __pyx_codeobj__831 __pyx_mstate_global->__pyx_codeobj__831
#define __pyx_codeobj__832 __pyx_mstate_global->__pyx_codeobj__832
#define __pyx_codeobj__833 __pyx_mstate_global->__pyx_codeobj__833
#define __pyx_codeobj__834 __pyx_mstate_global->__pyx_codeobj__834
#define __pyx_codeobj__835 __pyx_mstate_global->__pyx_codeobj__835
#define __pyx_codeobj__836 __pyx_mstate_global->__pyx_codeobj__836
#define __pyx_codeobj__837 __pyx_mstate_global->__pyx_codeobj__837
#define __pyx_codeobj__838 __pyx_mstate_global->__pyx_codeobj__838
#define __pyx_codeobj__839 __pyx_mstate_global->__pyx_codeobj__839
#define __pyx_codeobj__840 __pyx_mstate_global->__pyx_codeobj__840
#define __pyx_codeobj__841 __pyx_mstate_global->__pyx_codeobj__841
#define __pyx_codeobj__842 __pyx_mstate_global->__pyx_codeobj__842
#define __pyx_codeobj__843 __pyx_mstate_global->__pyx_codeobj__843
#define __pyx_codeobj__844 __pyx_mstate_global->__pyx_codeobj__844
#define __pyx_codeobj__845 __pyx_mstate_global->__pyx_codeobj__845
#define __pyx_codeobj__846 __pyx_mstate_global->__pyx_codeobj__846
#define __pyx_codeobj__847 __pyx_mstate_global->__pyx_codeobj__847
#define __pyx_codeobj__848 __pyx_mstate_global->__pyx_codeobj__848
#define __pyx_codeobj__849 __pyx_mstate_global->__pyx_codeobj__849
#define __pyx_codeobj__850 __pyx_mstate_global->__pyx_codeobj__850
#define __pyx_codeobj__851 __pyx_mstate_global->__pyx_codeobj__851
#define __pyx_codeobj__852 __pyx_mstate_global->__pyx_codeobj__852
#define __pyx_codeobj__853 __pyx_mstate_global->__pyx_codeobj__853
#define __pyx_codeobj__854 __pyx_mstate_global->__pyx_codeobj__854
#define __pyx_codeobj__855 __pyx_mstate_global->__pyx_codeobj__855
#define __pyx_codeobj__856 __pyx_mstate_global->__pyx_codeobj__856
#define __pyx_codeobj__857 __pyx_mstate_global->__pyx_codeobj__857
#define __pyx_codeobj__858 __pyx_mstate_global->__pyx_codeobj__858
#define __pyx_codeobj__859 __pyx_mstate_global->__pyx_codeobj__859
#define __pyx_codeobj__860 __pyx_mstate_global->__pyx_codeobj__860
#define __pyx_codeobj__861 __pyx_mstate_global->__pyx_codeobj__861
#define __pyx_codeobj__862 __pyx_mstate_global->__pyx_codeobj__862
#define __pyx_codeobj__863 __pyx_mstate_global->__pyx_codeobj__863
#define __pyx_codeobj__864 __pyx_mstate_global->__pyx_codeobj__864
#define __pyx_codeobj__865 __pyx_mstate_global->__pyx_codeobj__865
#define __pyx_codeobj__866 __pyx_mstate_global->__pyx_codeobj__866
#define __pyx_codeobj__867 __pyx_mstate_global->__pyx_codeobj__867
#define __pyx_codeobj__868 __pyx_mstate_global->__pyx_codeobj__868
#define __pyx_codeobj__869 __pyx_mstate_global->__pyx_codeobj__869
#define __pyx_codeobj__870 __pyx_mstate_global->__pyx_codeobj__870
#define __pyx_codeobj__871 __pyx_mstate_global->__pyx_codeobj__871
#define __pyx_codeobj__872 __pyx_mstate_global->__pyx_codeobj__872
#define __pyx_codeobj__873 __pyx_mstate_global->__pyx_codeobj__873
#define __pyx_codeobj__874 __pyx_mstate_global->__pyx_codeobj__874
#define __pyx_codeobj__875 __pyx_mstate_global->__pyx_codeobj__875
#define __pyx_codeobj__876 __pyx_mstate_global->__pyx_codeobj__876
#define __pyx_codeobj__877 __pyx_mstate_global->__pyx_codeobj__877
#define __pyx_codeobj__878 __pyx_mstate_global->__pyx_codeobj__878
#define __pyx_codeobj__879 __pyx_mstate_global->__pyx_codeobj__879
#define __pyx_codeobj__880 __pyx_mstate_global->__pyx_codeobj__880
#define __pyx_codeobj__881 __pyx_mstate_global->__pyx_codeobj__881
#define __pyx_codeobj__882 __pyx_mstate_global->__pyx_codeobj__882
#define __pyx_codeobj__883 __pyx_mstate_global->__pyx_codeobj__883
#define __pyx_codeobj__884 __pyx_mstate_global->__pyx_codeobj__884
#define __pyx_codeobj__885 __pyx_mstate_global->__pyx_codeobj__885
#define __pyx_codeobj__886 __pyx_mstate_global->__pyx_codeobj__886
#define __pyx_codeobj__887 __pyx_mstate_global->__pyx_codeobj__887
#define __pyx_codeobj__888 __pyx_mstate_global->__pyx_codeobj__888
#define __pyx_codeobj__889 __pyx_mstate_global->__pyx_codeobj__889
#define __pyx_codeobj__890 __pyx_mstate_global->__pyx_codeobj__890
#define __pyx_codeobj__891 __pyx_mstate_global->__pyx_codeobj__891
#define __pyx_codeobj__892 __pyx_mstate_global->__pyx_codeobj__892
#define __pyx_codeobj__893 __pyx_mstate_global->__pyx_codeobj__893
#define __pyx_codeobj__894 __pyx_mstate_global->__pyx_codeobj__894
#define __pyx_codeobj__895 __pyx_mstate_global->__pyx_codeobj__895
#define __pyx_codeobj__896 __pyx_mstate_global->__pyx_codeobj__896
#define __pyx_codeobj__897 __pyx_mstate_global->__pyx_codeobj__897
#define __pyx_codeobj__898 __pyx_mstate_global->__pyx_codeobj__898
#define __pyx_codeobj__899 __pyx_mstate_global->__pyx_codeobj__899
#define __pyx_codeobj__900 __pyx_mstate_global->__pyx_codeobj__900
#define __pyx_codeobj__901 __pyx_mstate_global->__pyx_codeobj__901
#define __pyx_codeobj__902 __pyx_mstate_global->__pyx_codeobj__902
#define __pyx_codeobj__903 __pyx_mstate_global->__pyx_codeobj__903
#define __pyx_codeobj__904 __pyx_mstate_global->__pyx_codeobj__904
#define __pyx_codeobj__905 __pyx_mstate_global->__pyx_codeobj__905
#define __pyx_codeobj__906 __pyx_mstate_global->__pyx_codeobj__906
#define __pyx_codeobj__907 __pyx_mstate_global->__pyx_codeobj__907
#define __pyx_codeobj__908 __pyx_mstate_global->__pyx_codeobj__908
#define __pyx_codeobj__909 __pyx_mstate_global->__pyx_codeobj__909
#define __pyx_codeobj__910 __pyx_mstate_global->__pyx_codeobj__910
#define __pyx_codeobj__911 __pyx_mstate_global->__pyx_codeobj__911
#define __pyx_codeobj__912 __pyx_mstate_global->__pyx_codeobj__912
#define __pyx_codeobj__913 __pyx_mstate_global->__pyx_codeobj__913
#define __pyx_codeobj__914 __pyx_mstate_global->__pyx_codeobj__914
#define __pyx_codeobj__915 __pyx_mstate_global->__pyx_codeobj__915
#define __pyx_codeobj__916 __pyx_mstate_global->__pyx_codeobj__916
#define __pyx_codeobj__917 __pyx_mstate_global->__pyx_codeobj__917
#define __pyx_codeobj__918 __pyx_mstate_global->__pyx_codeobj__918
#define __pyx_codeobj__919 __pyx_mstate_global->__pyx_codeobj__919
#define __pyx_codeobj__920 __pyx_mstate_global->__pyx_codeobj__920
#define __pyx_codeobj__921 __pyx_mstate_global->__pyx_codeobj__921
#define __pyx_codeobj__922 __pyx_mstate_global->__pyx_codeobj__922
#define __pyx_codeobj__923 __pyx_mstate_global->__pyx_codeobj__923
#define __pyx_codeobj__924 __pyx_mstate_global->__pyx_codeobj__924
#define __pyx_codeobj__925 __pyx_mstate_global->__pyx_codeobj__925
#define __pyx_codeobj__926 __pyx_mstate_global->__pyx_codeobj__926
#define __pyx_codeobj__927 __pyx_mstate_global->__pyx_codeobj__927
#define __pyx_codeobj__928 __pyx_mstate_global->__pyx_codeobj__928
#define __pyx_codeobj__929 __pyx_mstate_global->__pyx_codeobj__929
#define __pyx_codeobj__930 __pyx_mstate_global->__pyx_codeobj__930
#define __pyx_codeobj__931 __pyx_mstate_global->__pyx_codeobj__931
#define __pyx_codeobj__932 __pyx_mstate_global->__pyx_codeobj__932
#define __pyx_codeobj__933 __pyx_mstate_global->__pyx_codeobj__933
#define __pyx_codeobj__934 __pyx_mstate_global->__pyx_codeobj__934
#define __pyx_codeobj__935 __pyx_mstate_global->__pyx_codeobj__935
#define __pyx_codeobj__936 __pyx_mstate_global->__pyx_codeobj__936
#define __pyx_codeobj__937 __pyx_mstate_global->__pyx_codeobj__937
#define __pyx_codeobj__938 __pyx_mstate_global->__pyx_codeobj__938
#define __pyx_codeobj__939 __pyx_mstate_global->__pyx_codeobj__939
#define __pyx_codeobj__940 __pyx_mstate_global->__pyx_codeobj__940
#define __pyx_codeobj__941 __pyx_mstate_global->__pyx_codeobj__941
#define __pyx_codeobj__942 __pyx_mstate_global->__pyx_codeobj__942
#define __pyx_codeobj__943 __pyx_mstate_global->__pyx_codeobj__943
#define __pyx_codeobj__944 __pyx_mstate_global->__pyx_codeobj__944
#define __pyx_codeobj__945 __pyx_mstate_global->__pyx_codeobj__945
#define __pyx_codeobj__946 __pyx_mstate_global->__pyx_codeobj__946
#define __pyx_codeobj__947 __pyx_mstate_global->__pyx_codeobj__947
#define __pyx_codeobj__948 __pyx_mstate_global->__pyx_codeobj__948
#define __pyx_codeobj__949 __pyx_mstate_global->__pyx_codeobj__949
#define __pyx_codeobj__950 __pyx_mstate_global->__pyx_codeobj__950
#define __pyx_codeobj__951 __pyx_mstate_global->__pyx_codeobj__951
#define __pyx_codeobj__952 __pyx_mstate_global->__pyx_codeobj__952
#define __pyx_codeobj__953 __pyx_mstate_global->__pyx_codeobj__953
#define __pyx_codeobj__954 __pyx_mstate_global->__pyx_codeobj__954
#define __pyx_codeobj__955 __pyx_mstate_global->__pyx_codeobj__955
#define __pyx_codeobj__956 __pyx_mstate_global->__pyx_codeobj__956
#define __pyx_codeobj__957 __pyx_mstate_global->__pyx_codeobj__957
#define __pyx_codeobj__958 __pyx_mstate_global->__pyx_codeobj__958
#define __pyx_codeobj__959 __pyx_mstate_global->__pyx_codeobj__959
#define __pyx_codeobj__960 __pyx_mstate_global->__pyx_codeobj__960
#define __pyx_codeobj__961 __pyx_mstate_global->__pyx_codeobj__961
#define __pyx_codeobj__962 __pyx_mstate_global->__pyx_codeobj__962
#define __pyx_codeobj__963 __pyx_mstate_global->__pyx_codeobj__963
#define __pyx_codeobj__964 __pyx_mstate_global->__pyx_codeobj__964
#define __pyx_codeobj__965 __pyx_mstate_global->__pyx_codeobj__965
#define __pyx_codeobj__966 __pyx_mstate_global->__pyx_codeobj__966
#define __pyx_codeobj__967 __pyx_mstate_global->__pyx_codeobj__967
#define __pyx_codeobj__968 __pyx_mstate_global->__pyx_codeobj__968
#define __pyx_codeobj__969 __pyx_mstate_global->__pyx_codeobj__969
#define __pyx_codeobj__970 __pyx_mstate_global->__pyx_codeobj__970
#define __pyx_codeobj__971 __pyx_mstate_global->__pyx_codeobj__971
#define __pyx_codeobj__972 __pyx_mstate_global->__pyx_codeobj__972
#define __pyx_codeobj__973 __pyx_mstate_global->__pyx_codeobj__973
#define __pyx_codeobj__974 __pyx_mstate_global->__pyx_codeobj__974
#define __pyx_codeobj__975 __pyx_mstate_global->__pyx_codeobj__975
#define __pyx_codeobj__976 __pyx_mstate_global->__pyx_codeobj__976
#define __pyx_codeobj__977 __pyx_mstate_global->__pyx_codeobj__977
#define __pyx_codeobj__978 __pyx_mstate_global->__pyx_codeobj__978
#define __pyx_codeobj__979 __pyx_mstate_global->__pyx_codeobj__979
#define __pyx_codeobj__980 __pyx_mstate_global->__pyx_codeobj__980
#define __pyx_codeobj__981 __pyx_mstate_global->__pyx_codeobj__981
#define __pyx_codeobj__982 __pyx_mstate_global->__pyx_codeobj__982
#define __pyx_codeobj__983 __pyx_mstate_global->__pyx_codeobj__983
#define __pyx_codeobj__984 __pyx_mstate_global->__pyx_codeobj__984
#define __pyx_codeobj__985 __pyx_mstate_global->__pyx_codeobj__985
#define __pyx_codeobj__986 __pyx_mstate_global->__pyx_codeobj__986
#define __pyx_codeobj__987 __pyx_mstate_global->__pyx_codeobj__987
#define __pyx_codeobj__988 __pyx_mstate_global->__pyx_codeobj__988
#define __pyx_codeobj__989 __pyx_mstate_global->__pyx_codeobj__989
#define __pyx_codeobj__990 __pyx_mstate_global->__pyx_codeobj__990
#define __pyx_codeobj__991 __pyx_mstate_global->__pyx_codeobj__991
#define __pyx_codeobj__992 __pyx_mstate_global->__pyx_codeobj__992
#define __pyx_codeobj__993 __pyx_mstate_global->__pyx_codeobj__993
#define __pyx_codeobj__994 __pyx_mstate_global->__pyx_codeobj__994
#define __pyx_codeobj__995 __pyx_mstate_global->__pyx_codeobj__995
#define __pyx_codeobj__996 __pyx_mstate_global->__pyx_codeobj__996
#define __pyx_codeobj__997 __pyx_mstate_global->__pyx_codeobj__997
#define __pyx_codeobj__998 __pyx_mstate_global->__pyx_codeobj__998
#define __pyx_codeobj__999 __pyx_mstate_global->__pyx_codeobj__999
#define __pyx_codeobj__1000 __pyx_mstate_global->__pyx_codeobj__1000
#define __pyx_codeobj__1001 __pyx_mstate_global->__pyx_codeobj__1001
#define __pyx_codeobj__1002 __pyx_mstate_global->__pyx_codeobj__1002
#define __pyx_codeobj__1003 __pyx_mstate_global->__pyx_codeobj__1003
#define __pyx_codeobj__1004 __pyx_mstate_global->__pyx_codeobj__1004
#define __pyx_codeobj__1005 __pyx_mstate_global->__pyx_codeobj__1005
#define __pyx_codeobj__1006 __pyx_mstate_global->__pyx_codeobj__1006
#define __pyx_codeobj__1007 __pyx_mstate_global->__pyx_codeobj__1007
#define __pyx_codeobj__1008 __pyx_mstate_global->__pyx_codeobj__1008
#define __pyx_codeobj__1009 __pyx_mstate_global->__pyx_codeobj__1009
#define __pyx_codeobj__1010 __pyx_mstate_global->__pyx_codeobj__1010
#define __pyx_codeobj__1011 __pyx_mstate_global->__pyx_codeobj__1011
#define __pyx_codeobj__1012 __pyx_mstate_global->__pyx_codeobj__1012
#define __pyx_codeobj__1013 __pyx_mstate_global->__pyx_codeobj__1013
#define __pyx_codeobj__1014 __pyx_mstate_global->__pyx_codeobj__1014
#define __pyx_codeobj__1015 __pyx_mstate_global->__pyx_codeobj__1015
#define __pyx_codeobj__1016 __pyx_mstate_global->__pyx_codeobj__1016
#define __pyx_codeobj__1017 __pyx_mstate_global->__pyx_codeobj__1017
#define __pyx_codeobj__1018 __pyx_mstate_global->__pyx_codeobj__1018
#define __pyx_codeobj__1019 __pyx_mstate_global->__pyx_codeobj__1019
#define __pyx_codeobj__1020 __pyx_mstate_global->__pyx_codeobj__1020
#define __pyx_codeobj__1021 __pyx_mstate_global->__pyx_codeobj__1021
#define __pyx_codeobj__1022 __pyx_mstate_global->__pyx_codeobj__1022
#define __pyx_codeobj__1023 __pyx_mstate_global->__pyx_codeobj__1023
#define __pyx_codeobj__1024 __pyx_mstate_global->__pyx_codeobj__1024
#define __pyx_codeobj__1025 __pyx_mstate_global->__pyx_codeobj__1025
#define __pyx_codeobj__1026 __pyx_mstate_global->__pyx_codeobj__1026
#define __pyx_codeobj__1027 __pyx_mstate_global->__pyx_codeobj__1027
#define __pyx_codeobj__1028 __pyx_mstate_global->__pyx_codeobj__1028
#define __pyx_codeobj__1029 __pyx_mstate_global->__pyx_codeobj__1029
#define __pyx_codeobj__1030 __pyx_mstate_global->__pyx_codeobj__1030
#define __pyx_codeobj__1031 __pyx_mstate_global->__pyx_codeobj__1031
#define __pyx_codeobj__1032 __pyx_mstate_global->__pyx_codeobj__1032
#define __pyx_codeobj__1033 __pyx_mstate_global->__pyx_codeobj__1033
#define __pyx_codeobj__1034 __pyx_mstate_global->__pyx_codeobj__1034
#define __pyx_codeobj__1035 __pyx_mstate_global->__pyx_codeobj__1035
#define __pyx_codeobj__1036 __pyx_mstate_global->__pyx_codeobj__1036
#define __pyx_codeobj__1037 __pyx_mstate_global->__pyx_codeobj__1037
#define __pyx_codeobj__1038 __pyx_mstate_global->__pyx_codeobj__1038
#define __pyx_codeobj__1039 __pyx_mstate_global->__pyx_codeobj__1039
#define __pyx_codeobj__1040 __pyx_mstate_global->__pyx_codeobj__1040
#define __pyx_codeobj__1041 __pyx_mstate_global->__pyx_codeobj__1041
#define __pyx_codeobj__1042 __pyx_mstate_global->__pyx_codeobj__1042
#define __pyx_codeobj__1043 __pyx_mstate_global->__pyx_codeobj__1043
#define __pyx_codeobj__1044 __pyx_mstate_global->__pyx_codeobj__1044
#define __pyx_codeobj__1045 __pyx_mstate_global->__pyx_codeobj__1045
#define __pyx_codeobj__1046 __pyx_mstate_global->__pyx_codeobj__1046
#define __pyx_codeobj__1047 __pyx_mstate_global->__pyx_codeobj__1047
#define __pyx_codeobj__1048 __pyx_mstate_global->__pyx_codeobj__1048
#define __pyx_codeobj__1049 __pyx_mstate_global->__pyx_codeobj__1049
#define __pyx_codeobj__1050 __pyx_mstate_global->__pyx_codeobj__1050
#define __pyx_codeobj__1051 __pyx_mstate_global->__pyx_codeobj__1051
#define __pyx_codeobj__1052 __pyx_mstate_global->__pyx_codeobj__1052
#define __pyx_codeobj__1053 __pyx_mstate_global->__pyx_codeobj__1053
#define __pyx_codeobj__1054 __pyx_mstate_global->__pyx_codeobj__1054
#define __pyx_codeobj__1055 __pyx_mstate_global->__pyx_codeobj__1055
#define __pyx_codeobj__1056 __pyx_mstate_global->__pyx_codeobj__1056
#define __pyx_codeobj__1057 __pyx_mstate_global->__pyx_codeobj__1057
#define __pyx_codeobj__1058 __pyx_mstate_global->__pyx_codeobj__1058
#define __pyx_codeobj__1059 __pyx_mstate_global->__pyx_codeobj__1059
#define __pyx_codeobj__1060 __pyx_mstate_global->__pyx_codeobj__1060
#define __pyx_codeobj__1061 __pyx_mstate_global->__pyx_codeobj__1061
#define __pyx_codeobj__1062 __pyx_mstate_global->__pyx_codeobj__1062
#define __pyx_codeobj__1063 __pyx_mstate_global->__pyx_codeobj__1063
#define __pyx_codeobj__1064 __pyx_mstate_global->__pyx_codeobj__1064
#define __pyx_codeobj__1065 __pyx_mstate_global->__pyx_codeobj__1065
#define __pyx_codeobj__1066 __pyx_mstate_global->__pyx_codeobj__1066
#define __pyx_codeobj__1067 __pyx_mstate_global->__pyx_codeobj__1067
#define __pyx_codeobj__1068 __pyx_mstate_global->__pyx_codeobj__1068
#define __pyx_codeobj__1069 __pyx_mstate_global->__pyx_codeobj__1069
#define __pyx_codeobj__1070 __pyx_mstate_global->__pyx_codeobj__1070
#define __pyx_codeobj__1071 __pyx_mstate_global->__pyx_codeobj__1071
#define __pyx_codeobj__1072 __pyx_mstate_global->__pyx_codeobj__1072
#define __pyx_codeobj__1073 __pyx_mstate_global->__pyx_codeobj__1073
#define __pyx_codeobj__1074 __pyx_mstate_global->__pyx_codeobj__1074
#define __pyx_codeobj__1075 __pyx_mstate_global->__pyx_codeobj__1075
#define __pyx_codeobj__1076 __pyx_mstate_global->__pyx_codeobj__1076
#define __pyx_codeobj__1077 __pyx_mstate_global->__pyx_codeobj__1077
#define __pyx_codeobj__1078 __pyx_mstate_global->__pyx_codeobj__1078
#define __pyx_codeobj__1079 __pyx_mstate_global->__pyx_codeobj__1079
#define __pyx_codeobj__1080 __pyx_mstate_global->__pyx_codeobj__1080
#define __pyx_codeobj__1081 __pyx_mstate_global->__pyx_codeobj__1081
#define __pyx_codeobj__1082 __pyx_mstate_global->__pyx_codeobj__1082
#define __pyx_codeobj__1083 __pyx_mstate_global->__pyx_codeobj__1083
#define __pyx_codeobj__1084 __pyx_mstate_global->__pyx_codeobj__1084
#define __pyx_codeobj__1085 __pyx_mstate_global->__pyx_codeobj__1085
#define __pyx_codeobj__1086 __pyx_mstate_global->__pyx_codeobj__1086
#define __pyx_codeobj__1087 __pyx_mstate_global->__pyx_codeobj__1087
#define __pyx_codeobj__1088 __pyx_mstate_global->__pyx_codeobj__1088
#define __pyx_codeobj__1089 __pyx_mstate_global->__pyx_codeobj__1089
#define __pyx_codeobj__1090 __pyx_mstate_global->__pyx_codeobj__1090
#define __pyx_codeobj__1091 __pyx_mstate_global->__pyx_codeobj__1091
#define __pyx_codeobj__1092 __pyx_mstate_global->__pyx_codeobj__1092
#define __pyx_codeobj__1093 __pyx_mstate_global->__pyx_codeobj__1093
#define __pyx_codeobj__1094 __pyx_mstate_global->__pyx_codeobj__1094
#define __pyx_codeobj__1095 __pyx_mstate_global->__pyx_codeobj__1095
#define __pyx_codeobj__1096 __pyx_mstate_global->__pyx_codeobj__1096
#define __pyx_codeobj__1097 __pyx_mstate_global->__pyx_codeobj__1097
#define __pyx_codeobj__1098 __pyx_mstate_global->__pyx_codeobj__1098
#define __pyx_codeobj__1099 __pyx_mstate_global->__pyx_codeobj__1099
#define __pyx_codeobj__1100 __pyx_mstate_global->__pyx_codeobj__1100
#define __pyx_codeobj__1101 __pyx_mstate_global->__pyx_codeobj__1101
#define __pyx_codeobj__1102 __pyx_mstate_global->__pyx_codeobj__1102
#define __pyx_codeobj__1103 __pyx_mstate_global->__pyx_codeobj__1103
#define __pyx_codeobj__1104 __pyx_mstate_global->__pyx_codeobj__1104
#define __pyx_codeobj__1105 __pyx_mstate_global->__pyx_codeobj__1105
#define __pyx_codeobj__1106 __pyx_mstate_global->__pyx_codeobj__1106
#define __pyx_codeobj__1107 __pyx_mstate_global->__pyx_codeobj__1107
#define __pyx_codeobj__1108 __pyx_mstate_global->__pyx_codeobj__1108
#define __pyx_codeobj__1109 __pyx_mstate_global->__pyx_codeobj__1109
#define __pyx_codeobj__1110 __pyx_mstate_global->__pyx_codeobj__1110
#define __pyx_codeobj__1111 __pyx_mstate_global->__pyx_codeobj__1111
#define __pyx_codeobj__1112 __pyx_mstate_global->__pyx_codeobj__1112
#define __pyx_codeobj__1113 __pyx_mstate_global->__pyx_codeobj__1113
#define __pyx_codeobj__1114 __pyx_mstate_global->__pyx_codeobj__1114
#define __pyx_codeobj__1115 __pyx_mstate_global->__pyx_codeobj__1115
#define __pyx_codeobj__1116 __pyx_mstate_global->__pyx_codeobj__1116
#define __pyx_codeobj__1117 __pyx_mstate_global->__pyx_codeobj__1117
#define __pyx_codeobj__1118 __pyx_mstate_global->__pyx_codeobj__1118
#define __pyx_codeobj__1119 __pyx_mstate_global->__pyx_codeobj__1119
#define __pyx_codeobj__1120 __pyx_mstate_global->__pyx_codeobj__1120
#define __pyx_codeobj__1121 __pyx_mstate_global->__pyx_codeobj__1121
#define __pyx_codeobj__1122 __pyx_mstate_global->__pyx_codeobj__1122
#define __pyx_codeobj__1123 __pyx_mstate_global->__pyx_codeobj__1123
#define __pyx_codeobj__1124 __pyx_mstate_global->__pyx_codeobj__1124
#define __pyx_codeobj__1125 __pyx_mstate_global->__pyx_codeobj__1125
#define __pyx_codeobj__1126 __pyx_mstate_global->__pyx_codeobj__1126
#define __pyx_codeobj__1127 __pyx_mstate_global->__pyx_codeobj__1127
#define __pyx_codeobj__1128 __pyx_mstate_global->__pyx_codeobj__1128
#define __pyx_codeobj__1129 __pyx_mstate_global->__pyx_codeobj__1129
#define __pyx_codeobj__1130 __pyx_mstate_global->__pyx_codeobj__1130
#define __pyx_codeobj__1131 __pyx_mstate_global->__pyx_codeobj__1131
#define __pyx_codeobj__1132 __pyx_mstate_global->__pyx_codeobj__1132
#define __pyx_codeobj__1133 __pyx_mstate_global->__pyx_codeobj__1133
#define __pyx_codeobj__1134 __pyx_mstate_global->__pyx_codeobj__1134
#define __pyx_codeobj__1135 __pyx_mstate_global->__pyx_codeobj__1135
#define __pyx_codeobj__1136 __pyx_mstate_global->__pyx_codeobj__1136
#define __pyx_codeobj__1137 __pyx_mstate_global->__pyx_codeobj__1137
#define __pyx_codeobj__1138 __pyx_mstate_global->__pyx_codeobj__1138
#define __pyx_codeobj__1139 __pyx_mstate_global->__pyx_codeobj__1139
#define __pyx_codeobj__1140 __pyx_mstate_global->__pyx_codeobj__1140
#define __pyx_codeobj__1141 __pyx_mstate_global->__pyx_codeobj__1141
#define __pyx_codeobj__1142 __pyx_mstate_global->__pyx_codeobj__1142
#define __pyx_codeobj__1143 __pyx_mstate_global->__pyx_codeobj__1143
#define __pyx_codeobj__1144 __pyx_mstate_global->__pyx_codeobj__1144
#define __pyx_codeobj__1145 __pyx_mstate_global->__pyx_codeobj__1145
#define __pyx_codeobj__1146 __pyx_mstate_global->__pyx_codeobj__1146
#define __pyx_codeobj__1147 __pyx_mstate_global->__pyx_codeobj__1147
#define __pyx_codeobj__1148 __pyx_mstate_global->__pyx_codeobj__1148
#define __pyx_codeobj__1149 __pyx_mstate_global->__pyx_codeobj__1149
#define __pyx_codeobj__1150 __pyx_mstate_global->__pyx_codeobj__1150
#define __pyx_codeobj__1151 __pyx_mstate_global->__pyx_codeobj__1151
#define __pyx_codeobj__1152 __pyx_mstate_global->__pyx_codeobj__1152
#define __pyx_codeobj__1153 __pyx_mstate_global->__pyx_codeobj__1153
#define __pyx_codeobj__1154 __pyx_mstate_global->__pyx_codeobj__1154
#define __pyx_codeobj__1155 __pyx_mstate_global->__pyx_codeobj__1155
#define __pyx_codeobj__1156 __pyx_mstate_global->__pyx_codeobj__1156
#define __pyx_codeobj__1157 __pyx_mstate_global->__pyx_codeobj__1157
#define __pyx_codeobj__1158 __pyx_mstate_global->__pyx_codeobj__1158
#define __pyx_codeobj__1159 __pyx_mstate_global->__pyx_codeobj__1159
#define __pyx_codeobj__1160 __pyx_mstate_global->__pyx_codeobj__1160
#define __pyx_codeobj__1161 __pyx_mstate_global->__pyx_codeobj__1161
#define __pyx_codeobj__1162 __pyx_mstate_global->__pyx_codeobj__1162
#define __pyx_codeobj__1163 __pyx_mstate_global->__pyx_codeobj__1163
#define __pyx_codeobj__1164 __pyx_mstate_global->__pyx_codeobj__1164
#define __pyx_codeobj__1165 __pyx_mstate_global->__pyx_codeobj__1165
#define __pyx_codeobj__1166 __pyx_mstate_global->__pyx_codeobj__1166
#define __pyx_codeobj__1167 __pyx_mstate_global->__pyx_codeobj__1167
#define __pyx_codeobj__1168 __pyx_mstate_global->__pyx_codeobj__1168
#define __pyx_codeobj__1169 __pyx_mstate_global->__pyx_codeobj__1169
#define __pyx_codeobj__1170 __pyx_mstate_global->__pyx_codeobj__1170
#define __pyx_codeobj__1171 __pyx_mstate_global->__pyx_codeobj__1171
#define __pyx_codeobj__1172 __pyx_mstate_global->__pyx_codeobj__1172
#define __pyx_codeobj__1173 __pyx_mstate_global->__pyx_codeobj__1173
#define __pyx_codeobj__1174 __pyx_mstate_global->__pyx_codeobj__1174
#define __pyx_codeobj__1175 __pyx_mstate_global->__pyx_codeobj__1175
#define __pyx_codeobj__1176 __pyx_mstate_global->__pyx_codeobj__1176
#define __pyx_codeobj__1177 __pyx_mstate_global->__pyx_codeobj__1177
#define __pyx_codeobj__1178 __pyx_mstate_global->__pyx_codeobj__1178
#define __pyx_codeobj__1179 __pyx_mstate_global->__pyx_codeobj__1179
#define __pyx_codeobj__1180 __pyx_mstate_global->__pyx_codeobj__1180
#define __pyx_codeobj__1181 __pyx_mstate_global->__pyx_codeobj__1181
#define __pyx_codeobj__1182 __pyx_mstate_global->__pyx_codeobj__1182
#define __pyx_codeobj__1183 __pyx_mstate_global->__pyx_codeobj__1183
#define __pyx_codeobj__1184 __pyx_mstate_global->__pyx_codeobj__1184
#define __pyx_codeobj__1185 __pyx_mstate_global->__pyx_codeobj__1185
#define __pyx_codeobj__1186 __pyx_mstate_global->__pyx_codeobj__1186
#define __pyx_codeobj__1187 __pyx_mstate_global->__pyx_codeobj__1187
#define __pyx_codeobj__1188 __pyx_mstate_global->__pyx_codeobj__1188
#define __pyx_codeobj__1189 __pyx_mstate_global->__pyx_codeobj__1189
#define __pyx_codeobj__1190 __pyx_mstate_global->__pyx_codeobj__1190
#define __pyx_codeobj__1191 __pyx_mstate_global->__pyx_codeobj__1191
#define __pyx_codeobj__1192 __pyx_mstate_global->__pyx_codeobj__1192
#define __pyx_codeobj__1193 __pyx_mstate_global->__pyx_codeobj__1193
#define __pyx_codeobj__1194 __pyx_mstate_global->__pyx_codeobj__1194
#define __pyx_codeobj__1195 __pyx_mstate_global->__pyx_codeobj__1195
#define __pyx_codeobj__1196 __pyx_mstate_global->__pyx_codeobj__1196
#define __pyx_codeobj__1197 __pyx_mstate_global->__pyx_codeobj__1197
#define __pyx_codeobj__1198 __pyx_mstate_global->__pyx_codeobj__1198
#define __pyx_codeobj__1199 __pyx_mstate_global->__pyx_codeobj__1199
#define __pyx_codeobj__1200 __pyx_mstate_global->__pyx_codeobj__1200
#define __pyx_codeobj__1201 __pyx_mstate_global->__pyx_codeobj__1201
#define __pyx_codeobj__1202 __pyx_mstate_global->__pyx_codeobj__1202
#define __pyx_codeobj__1203 __pyx_mstate_global->__pyx_codeobj__1203
#define __pyx_codeobj__1204 __pyx_mstate_global->__pyx_codeobj__1204
#define __pyx_codeobj__1205 __pyx_mstate_global->__pyx_codeobj__1205
#define __pyx_codeobj__1206 __pyx_mstate_global->__pyx_codeobj__1206
#define __pyx_codeobj__1207 __pyx_mstate_global->__pyx_codeobj__1207
#define __pyx_codeobj__1208 __pyx_mstate_global->__pyx_codeobj__1208
#define __pyx_codeobj__1209 __pyx_mstate_global->__pyx_codeobj__1209
#define __pyx_codeobj__1210 __pyx_mstate_global->__pyx_codeobj__1210
#define __pyx_codeobj__1211 __pyx_mstate_global->__pyx_codeobj__1211
#define __pyx_codeobj__1212 __pyx_mstate_global->__pyx_codeobj__1212
#define __pyx_codeobj__1213 __pyx_mstate_global->__pyx_codeobj__1213
#define __pyx_codeobj__1214 __pyx_mstate_global->__pyx_codeobj__1214
#define __pyx_codeobj__1215 __pyx_mstate_global->__pyx_codeobj__1215
#define __pyx_codeobj__1216 __pyx_mstate_global->__pyx_codeobj__1216
#define __pyx_codeobj__1217 __pyx_mstate_global->__pyx_codeobj__1217
#define __pyx_codeobj__1218 __pyx_mstate_global->__pyx_codeobj__1218
#define __pyx_codeobj__1219 __pyx_mstate_global->__pyx_codeobj__1219
#define __pyx_codeobj__1220 __pyx_mstate_global->__pyx_codeobj__1220
#define __pyx_codeobj__1221 __pyx_mstate_global->__pyx_codeobj__1221
#define __pyx_codeobj__1222 __pyx_mstate_global->__pyx_codeobj__1222
#define __pyx_codeobj__1223 __pyx_mstate_global->__pyx_codeobj__1223
#define __pyx_codeobj__1224 __pyx_mstate_global->__pyx_codeobj__1224
#define __pyx_codeobj__1225 __pyx_mstate_global->__pyx_codeobj__1225
#define __pyx_codeobj__1226 __pyx_mstate_global->__pyx_codeobj__1226
#define __pyx_codeobj__1227 __pyx_mstate_global->__pyx_codeobj__1227
#define __pyx_codeobj__1228 __pyx_mstate_global->__pyx_codeobj__1228
#define __pyx_codeobj__1229 __pyx_mstate_global->__pyx_codeobj__1229
#define __pyx_codeobj__1230 __pyx_mstate_global->__pyx_codeobj__1230
#define __pyx_codeobj__1231 __pyx_mstate_global->__pyx_codeobj__1231
#define __pyx_codeobj__1232 __pyx_mstate_global->__pyx_codeobj__1232
#define __pyx_codeobj__1233 __pyx_mstate_global->__pyx_codeobj__1233
#define __pyx_codeobj__1234 __pyx_mstate_global->__pyx_codeobj__1234
#define __pyx_codeobj__1235 __pyx_mstate_global->__pyx_codeobj__1235
#define __pyx_codeobj__1236 __pyx_mstate_global->__pyx_codeobj__1236
#define __pyx_codeobj__1237 __pyx_mstate_global->__pyx_codeobj__1237
#define __pyx_codeobj__1238 __pyx_mstate_global->__pyx_codeobj__1238
#define __pyx_codeobj__1239 __pyx_mstate_global->__pyx_codeobj__1239
#define __pyx_codeobj__1240 __pyx_mstate_global->__pyx_codeobj__1240
#define __pyx_codeobj__1241 __pyx_mstate_global->__pyx_codeobj__1241
#define __pyx_codeobj__1242 __pyx_mstate_global->__pyx_codeobj__1242
#define __pyx_codeobj__1243 __pyx_mstate_global->__pyx_codeobj__1243
#define __pyx_codeobj__1244 __pyx_mstate_global->__pyx_codeobj__1244
#define __pyx_codeobj__1245 __pyx_mstate_global->__pyx_codeobj__1245
#define __pyx_codeobj__1246 __pyx_mstate_global->__pyx_codeobj__1246
#define __pyx_codeobj__1247 __pyx_mstate_global->__pyx_codeobj__1247
#define __pyx_codeobj__1248 __pyx_mstate_global->__pyx_codeobj__1248
#define __pyx_codeobj__1249 __pyx_mstate_global->__pyx_codeobj__1249
#define __pyx_codeobj__1250 __pyx_mstate_global->__pyx_codeobj__1250
#define __pyx_codeobj__1251 __pyx_mstate_global->__pyx_codeobj__1251
#define __pyx_codeobj__1252 __pyx_mstate_global->__pyx_codeobj__1252
#define __pyx_codeobj__1253 __pyx_mstate_global->__pyx_codeobj__1253
#define __pyx_codeobj__1254 __pyx_mstate_global->__pyx_codeobj__1254
#define __pyx_codeobj__1255 __pyx_mstate_global->__pyx_codeobj__1255
#define __pyx_codeobj__1256 __pyx_mstate_global->__pyx_codeobj__1256
#define __pyx_codeobj__1257 __pyx_mstate_global->__pyx_codeobj__1257
#define __pyx_codeobj__1258 __pyx_mstate_global->__pyx_codeobj__1258
#define __pyx_codeobj__1259 __pyx_mstate_global->__pyx_codeobj__1259
#define __pyx_codeobj__1260 __pyx_mstate_global->__pyx_codeobj__1260
#define __pyx_codeobj__1261 __pyx_mstate_global->__pyx_codeobj__1261
#define __pyx_codeobj__1262 __pyx_mstate_global->__pyx_codeobj__1262
#define __pyx_codeobj__1263 __pyx_mstate_global->__pyx_codeobj__1263
#define __pyx_codeobj__1264 __pyx_mstate_global->__pyx_codeobj__1264
#define __pyx_codeobj__1265 __pyx_mstate_global->__pyx_codeobj__1265
#define __pyx_codeobj__1266 __pyx_mstate_global->__pyx_codeobj__1266
#define __pyx_codeobj__1267 __pyx_mstate_global->__pyx_codeobj__1267
#define __pyx_codeobj__1268 __pyx_mstate_global->__pyx_codeobj__1268
#define __pyx_codeobj__1269 __pyx_mstate_global->__pyx_codeobj__1269
#define __pyx_codeobj__1270 __pyx_mstate_global->__pyx_codeobj__1270
#define __pyx_codeobj__1271 __pyx_mstate_global->__pyx_codeobj__1271
#define __pyx_codeobj__1272 __pyx_mstate_global->__pyx_codeobj__1272
#define __pyx_codeobj__1273 __pyx_mstate_global->__pyx_codeobj__1273
#define __pyx_codeobj__1274 __pyx_mstate_global->__pyx_codeobj__1274
#define __pyx_codeobj__1275 __pyx_mstate_global->__pyx_codeobj__1275
#define __pyx_codeobj__1276 __pyx_mstate_global->__pyx_codeobj__1276
#define __pyx_codeobj__1277 __pyx_mstate_global->__pyx_codeobj__1277
#define __pyx_codeobj__1278 __pyx_mstate_global->__pyx_codeobj__1278
#define __pyx_codeobj__1279 __pyx_mstate_global->__pyx_codeobj__1279
#define __pyx_codeobj__1280 __pyx_mstate_global->__pyx_codeobj__1280
#define __pyx_codeobj__1281 __pyx_mstate_global->__pyx_codeobj__1281
#define __pyx_codeobj__1282 __pyx_mstate_global->__pyx_codeobj__1282
#define __pyx_codeobj__1283 __pyx_mstate_global->__pyx_codeobj__1283
#define __pyx_codeobj__1284 __pyx_mstate_global->__pyx_codeobj__1284
#define __pyx_codeobj__1285 __pyx_mstate_global->__pyx_codeobj__1285
#define __pyx_codeobj__1286 __pyx_mstate_global->__pyx_codeobj__1286
#define __pyx_codeobj__1287 __pyx_mstate_global->__pyx_codeobj__1287
#define __pyx_codeobj__1288 __pyx_mstate_global->__pyx_codeobj__1288
#define __pyx_codeobj__1289 __pyx_mstate_global->__pyx_codeobj__1289
#define __pyx_codeobj__1290 __pyx_mstate_global->__pyx_codeobj__1290
#define __pyx_codeobj__1291 __pyx_mstate_global->__pyx_codeobj__1291
#define __pyx_codeobj__1292 __pyx_mstate_global->__pyx_codeobj__1292
#define __pyx_codeobj__1293 __pyx_mstate_global->__pyx_codeobj__1293
#define __pyx_codeobj__1294 __pyx_mstate_global->__pyx_codeobj__1294
#define __pyx_codeobj__1295 __pyx_mstate_global->__pyx_codeobj__1295
#define __pyx_codeobj__1296 __pyx_mstate_global->__pyx_codeobj__1296
#define __pyx_codeobj__1297 __pyx_mstate_global->__pyx_codeobj__1297
#define __pyx_codeobj__1298 __pyx_mstate_global->__pyx_codeobj__1298
#define __pyx_codeobj__1299 __pyx_mstate_global->__pyx_codeobj__1299
#define __pyx_codeobj__1300 __pyx_mstate_global->__pyx_codeobj__1300
#define __pyx_codeobj__1301 __pyx_mstate_global->__pyx_codeobj__1301
#define __pyx_codeobj__1302 __pyx_mstate_global->__pyx_codeobj__1302
#define __pyx_codeobj__1303 __pyx_mstate_global->__pyx_codeobj__1303
#define __pyx_codeobj__1304 __pyx_mstate_global->__pyx_codeobj__1304
#define __pyx_codeobj__1305 __pyx_mstate_global->__pyx_codeobj__1305
#define __pyx_codeobj__1306 __pyx_mstate_global->__pyx_codeobj__1306
#define __pyx_codeobj__1307 __pyx_mstate_global->__pyx_codeobj__1307
#define __pyx_codeobj__1308 __pyx_mstate_global->__pyx_codeobj__1308
#define __pyx_codeobj__1309 __pyx_mstate_global->__pyx_codeobj__1309
#define __pyx_codeobj__1310 __pyx_mstate_global->__pyx_codeobj__1310
#define __pyx_codeobj__1311 __pyx_mstate_global->__pyx_codeobj__1311
#define __pyx_codeobj__1312 __pyx_mstate_global->__pyx_codeobj__1312
#define __pyx_codeobj__1313 __pyx_mstate_global->__pyx_codeobj__1313
#define __pyx_codeobj__1314 __pyx_mstate_global->__pyx_codeobj__1314
#define __pyx_codeobj__1315 __pyx_mstate_global->__pyx_codeobj__1315
#define __pyx_codeobj__1316 __pyx_mstate_global->__pyx_codeobj__1316
#define __pyx_codeobj__1317 __pyx_mstate_global->__pyx_codeobj__1317
#define __pyx_codeobj__1318 __pyx_mstate_global->__pyx_codeobj__1318
#define __pyx_codeobj__1319 __pyx_mstate_global->__pyx_codeobj__1319
#define __pyx_codeobj__1320 __pyx_mstate_global->__pyx_codeobj__1320
#define __pyx_codeobj__1321 __pyx_mstate_global->__pyx_codeobj__1321
#define __pyx_codeobj__1322 __pyx_mstate_global->__pyx_codeobj__1322
#define __pyx_codeobj__1323 __pyx_mstate_global->__pyx_codeobj__1323
#define __pyx_codeobj__1324 __pyx_mstate_global->__pyx_codeobj__1324
#define __pyx_codeobj__1325 __pyx_mstate_global->__pyx_codeobj__1325
#define __pyx_codeobj__1326 __pyx_mstate_global->__pyx_codeobj__1326
#define __pyx_codeobj__1327 __pyx_mstate_global->__pyx_codeobj__1327
#define __pyx_codeobj__1328 __pyx_mstate_global->__pyx_codeobj__1328
#define __pyx_codeobj__1329 __pyx_mstate_global->__pyx_codeobj__1329
#define __pyx_codeobj__1330 __pyx_mstate_global->__pyx_codeobj__1330
#define __pyx_codeobj__1331 __pyx_mstate_global->__pyx_codeobj__1331
#define __pyx_codeobj__1332 __pyx_mstate_global->__pyx_codeobj__1332
#define __pyx_codeobj__1333 __pyx_mstate_global->__pyx_codeobj__1333
#define __pyx_codeobj__1334 __pyx_mstate_global->__pyx_codeobj__1334
#define __pyx_codeobj__1335 __pyx_mstate_global->__pyx_codeobj__1335
#define __pyx_codeobj__1336 __pyx_mstate_global->__pyx_codeobj__1336
#define __pyx_codeobj__1337 __pyx_mstate_global->__pyx_codeobj__1337
#define __pyx_codeobj__1338 __pyx_mstate_global->__pyx_codeobj__1338
#define __pyx_codeobj__1339 __pyx_mstate_global->__pyx_codeobj__1339
#define __pyx_codeobj__1340 __pyx_mstate_global->__pyx_codeobj__1340
#define __pyx_codeobj__1341 __pyx_mstate_global->__pyx_codeobj__1341
#define __pyx_codeobj__1342 __pyx_mstate_global->__pyx_codeobj__1342
#define __pyx_codeobj__1343 __pyx_mstate_global->__pyx_codeobj__1343
#define __pyx_codeobj__1344 __pyx_mstate_global->__pyx_codeobj__1344
#define __pyx_codeobj__1345 __pyx_mstate_global->__pyx_codeobj__1345
#define __pyx_codeobj__1346 __pyx_mstate_global->__pyx_codeobj__1346
#define __pyx_codeobj__1347 __pyx_mstate_global->__pyx_codeobj__1347
#define __pyx_codeobj__1348 __pyx_mstate_global->__pyx_codeobj__1348
#define __pyx_codeobj__1349 __pyx_mstate_global->__pyx_codeobj__1349
#define __pyx_codeobj__1350 __pyx_mstate_global->__pyx_codeobj__1350
#define __pyx_codeobj__1351 __pyx_mstate_global->__pyx_codeobj__1351
#define __pyx_codeobj__1352 __pyx_mstate_global->__pyx_codeobj__1352
#define __pyx_codeobj__1353 __pyx_mstate_global->__pyx_codeobj__1353
#define __pyx_codeobj__1354 __pyx_mstate_global->__pyx_codeobj__1354
#define __pyx_codeobj__1355 __pyx_mstate_global->__pyx_codeobj__1355
#define __pyx_codeobj__1356 __pyx_mstate_global->__pyx_codeobj__1356
#define __pyx_codeobj__1357 __pyx_mstate_global->__pyx_codeobj__1357
#define __pyx_codeobj__1358 __pyx_mstate_global->__pyx_codeobj__1358
#define __pyx_codeobj__1359 __pyx_mstate_global->__pyx_codeobj__1359
#define __pyx_codeobj__1360 __pyx_mstate_global->__pyx_codeobj__1360
#define __pyx_codeobj__1361 __pyx_mstate_global->__pyx_codeobj__1361
#define __pyx_codeobj__1362 __pyx_mstate_global->__pyx_codeobj__1362
#define __pyx_codeobj__1363 __pyx_mstate_global->__pyx_codeobj__1363
#define __pyx_codeobj__1364 __pyx_mstate_global->__pyx_codeobj__1364
#define __pyx_codeobj__1365 __pyx_mstate_global->__pyx_codeobj__1365
#define __pyx_codeobj__1366 __pyx_mstate_global->__pyx_codeobj__1366
#define __pyx_codeobj__1367 __pyx_mstate_global->__pyx_codeobj__1367
#define __pyx_codeobj__1368 __pyx_mstate_global->__pyx_codeobj__1368
#define __pyx_codeobj__1369 __pyx_mstate_global->__pyx_codeobj__1369
#define __pyx_codeobj__1370 __pyx_mstate_global->__pyx_codeobj__1370
#define __pyx_codeobj__1371 __pyx_mstate_global->__pyx_codeobj__1371
#define __pyx_codeobj__1372 __pyx_mstate_global->__pyx_codeobj__1372
#define __pyx_codeobj__1373 __pyx_mstate_global->__pyx_codeobj__1373
#define __pyx_codeobj__1374 __pyx_mstate_global->__pyx_codeobj__1374
#define __pyx_codeobj__1375 __pyx_mstate_global->__pyx_codeobj__1375
#define __pyx_codeobj__1376 __pyx_mstate_global->__pyx_codeobj__1376
#define __pyx_codeobj__1377 __pyx_mstate_global->__pyx_codeobj__1377
#define __pyx_codeobj__1378 __pyx_mstate_global->__pyx_codeobj__1378
#define __pyx_codeobj__1379 __pyx_mstate_global->__pyx_codeobj__1379
#define __pyx_codeobj__1380 __pyx_mstate_global->__pyx_codeobj__1380
#define __pyx_codeobj__1381 __pyx_mstate_global->__pyx_codeobj__1381
#define __pyx_codeobj__1382 __pyx_mstate_global->__pyx_codeobj__1382
#define __pyx_codeobj__1383 __pyx_mstate_global->__pyx_codeobj__1383
#define __pyx_codeobj__1384 __pyx_mstate_global->__pyx_codeobj__1384
#define __pyx_codeobj__1385 __pyx_mstate_global->__pyx_codeobj__1385
#define __pyx_codeobj__1386 __pyx_mstate_global->__pyx_codeobj__1386
#define __pyx_codeobj__1387 __pyx_mstate_global->__pyx_codeobj__1387
#define __pyx_codeobj__1388 __pyx_mstate_global->__pyx_codeobj__1388
#define __pyx_codeobj__1389 __pyx_mstate_global->__pyx_codeobj__1389
#define __pyx_codeobj__1390 __pyx_mstate_global->__pyx_codeobj__1390
#define __pyx_codeobj__1391 __pyx_mstate_global->__pyx_codeobj__1391
#define __pyx_codeobj__1392 __pyx_mstate_global->__pyx_codeobj__1392
#define __pyx_codeobj__1393 __pyx_mstate_global->__pyx_codeobj__1393
#define __pyx_codeobj__1394 __pyx_mstate_global->__pyx_codeobj__1394
#define __pyx_codeobj__1395 __pyx_mstate_global->__pyx_codeobj__1395
#define __pyx_codeobj__1396 __pyx_mstate_global->__pyx_codeobj__1396
#define __pyx_codeobj__1397 __pyx_mstate_global->__pyx_codeobj__1397
#define __pyx_codeobj__1398 __pyx_mstate_global->__pyx_codeobj__1398
#define __pyx_codeobj__1399 __pyx_mstate_global->__pyx_codeobj__1399
#define __pyx_codeobj__1400 __pyx_mstate_global->__pyx_codeobj__1400
#define __pyx_codeobj__1401 __pyx_mstate_global->__pyx_codeobj__1401
#define __pyx_codeobj__1402 __pyx_mstate_global->__pyx_codeobj__1402
#define __pyx_codeobj__1403 __pyx_mstate_global->__pyx_codeobj__1403
#define __pyx_codeobj__1404 __pyx_mstate_global->__pyx_codeobj__1404
#define __pyx_codeobj__1405 __pyx_mstate_global->__pyx_codeobj__1405
#define __pyx_codeobj__1406 __pyx_mstate_global->__pyx_codeobj__1406
#define __pyx_codeobj__1407 __pyx_mstate_global->__pyx_codeobj__1407
#define __pyx_codeobj__1408 __pyx_mstate_global->__pyx_codeobj__1408
#define __pyx_codeobj__1409 __pyx_mstate_global->__pyx_codeobj__1409
#define __pyx_codeobj__1410 __pyx_mstate_global->__pyx_codeobj__1410
#define __pyx_codeobj__1411 __pyx_mstate_global->__pyx_codeobj__1411
#define __pyx_codeobj__1412 __pyx_mstate_global->__pyx_codeobj__1412
#define __pyx_codeobj__1413 __pyx_mstate_global->__pyx_codeobj__1413
#define __pyx_codeobj__1414 __pyx_mstate_global->__pyx_codeobj__1414
#define __pyx_codeobj__1415 __pyx_mstate_global->__pyx_codeobj__1415
#define __pyx_codeobj__1416 __pyx_mstate_global->__pyx_codeobj__1416
#define __pyx_codeobj__1417 __pyx_mstate_global->__pyx_codeobj__1417
#define __pyx_codeobj__1418 __pyx_mstate_global->__pyx_codeobj__1418
#define __pyx_codeobj__1419 __pyx_mstate_global->__pyx_codeobj__1419
#define __pyx_codeobj__1420 __pyx_mstate_global->__pyx_codeobj__1420
#define __pyx_codeobj__1421 __pyx_mstate_global->__pyx_codeobj__1421
#define __pyx_codeobj__1422 __pyx_mstate_global->__pyx_codeobj__1422
#define __pyx_codeobj__1423 __pyx_mstate_global->__pyx_codeobj__1423
#define __pyx_codeobj__1424 __pyx_mstate_global->__pyx_codeobj__1424
#define __pyx_codeobj__1425 __pyx_mstate_global->__pyx_codeobj__1425
#define __pyx_codeobj__1426 __pyx_mstate_global->__pyx_codeobj__1426
#define __pyx_codeobj__1427 __pyx_mstate_global->__pyx_codeobj__1427
#define __pyx_codeobj__1428 __pyx_mstate_global->__pyx_codeobj__1428
#define __pyx_codeobj__1429 __pyx_mstate_global->__pyx_codeobj__1429
#define __pyx_codeobj__1430 __pyx_mstate_global->__pyx_codeobj__1430
#define __pyx_codeobj__1431 __pyx_mstate_global->__pyx_codeobj__1431
#define __pyx_codeobj__1432 __pyx_mstate_global->__pyx_codeobj__1432
#define __pyx_codeobj__1433 __pyx_mstate_global->__pyx_codeobj__1433
#define __pyx_codeobj__1434 __pyx_mstate_global->__pyx_codeobj__1434
#define __pyx_codeobj__1435 __pyx_mstate_global->__pyx_codeobj__1435
#define __pyx_codeobj__1436 __pyx_mstate_global->__pyx_codeobj__1436
#define __pyx_codeobj__1437 __pyx_mstate_global->__pyx_codeobj__1437
#define __pyx_codeobj__1438 __pyx_mstate_global->__pyx_codeobj__1438
#define __pyx_codeobj__1439 __pyx_mstate_global->__pyx_codeobj__1439
#define __pyx_codeobj__1440 __pyx_mstate_global->__pyx_codeobj__1440
#define __pyx_codeobj__1441 __pyx_mstate_global->__pyx_codeobj__1441
#define __pyx_codeobj__1442 __pyx_mstate_global->__pyx_codeobj__1442
#define __pyx_codeobj__1443 __pyx_mstate_global->__pyx_codeobj__1443
#define __pyx_codeobj__1444 __pyx_mstate_global->__pyx_codeobj__1444
#define __pyx_codeobj__1445 __pyx_mstate_global->__pyx_codeobj__1445
#define __pyx_codeobj__1446 __pyx_mstate_global->__pyx_codeobj__1446
#define __pyx_codeobj__1447 __pyx_mstate_global->__pyx_codeobj__1447
#define __pyx_codeobj__1448 __pyx_mstate_global->__pyx_codeobj__1448
#define __pyx_codeobj__1449 __pyx_mstate_global->__pyx_codeobj__1449
#define __pyx_codeobj__1450 __pyx_mstate_global->__pyx_codeobj__1450
#define __pyx_codeobj__1451 __pyx_mstate_global->__pyx_codeobj__1451
#define __pyx_codeobj__1452 __pyx_mstate_global->__pyx_codeobj__1452
#define __pyx_codeobj__1453 __pyx_mstate_global->__pyx_codeobj__1453
#define __pyx_codeobj__1454 __pyx_mstate_global->__pyx_codeobj__1454
#define __pyx_codeobj__1455 __pyx_mstate_global->__pyx_codeobj__1455
#define __pyx_codeobj__1456 __pyx_mstate_global->__pyx_codeobj__1456
#define __pyx_codeobj__1457 __pyx_mstate_global->__pyx_codeobj__1457
#define __pyx_codeobj__1458 __pyx_mstate_global->__pyx_codeobj__1458
#define __pyx_codeobj__1459 __pyx_mstate_global->__pyx_codeobj__1459
#define __pyx_codeobj__1460 __pyx_mstate_global->__pyx_codeobj__1460
#define __pyx_codeobj__1461 __pyx_mstate_global->__pyx_codeobj__1461
#define __pyx_codeobj__1462 __pyx_mstate_global->__pyx_codeobj__1462
#define __pyx_codeobj__1463 __pyx_mstate_global->__pyx_codeobj__1463
#define __pyx_codeobj__1464 __pyx_mstate_global->__pyx_codeobj__1464
#define __pyx_codeobj__1465 __pyx_mstate_global->__pyx_codeobj__1465
#define __pyx_codeobj__1466 __pyx_mstate_global->__pyx_codeobj__1466
#define __pyx_codeobj__1467 __pyx_mstate_global->__pyx_codeobj__1467
#define __pyx_codeobj__1468 __pyx_mstate_global->__pyx_codeobj__1468
#define __pyx_codeobj__1469 __pyx_mstate_global->__pyx_codeobj__1469
#define __pyx_codeobj__1470 __pyx_mstate_global->__pyx_codeobj__1470
#define __pyx_codeobj__1471 __pyx_mstate_global->__pyx_codeobj__1471
#define __pyx_codeobj__1472 __pyx_mstate_global->__pyx_codeobj__1472
#define __pyx_codeobj__1473 __pyx_mstate_global->__pyx_codeobj__1473
#define __pyx_codeobj__1474 __pyx_mstate_global->__pyx_codeobj__1474
#define __pyx_codeobj__1475 __pyx_mstate_global->__pyx_codeobj__1475
#define __pyx_codeobj__1476 __pyx_mstate_global->__pyx_codeobj__1476
#define __pyx_codeobj__1477 __pyx_mstate_global->__pyx_codeobj__1477
#define __pyx_codeobj__1478 __pyx_mstate_global->__pyx_codeobj__1478
#define __pyx_codeobj__1479 __pyx_mstate_global->__pyx_codeobj__1479
#define __pyx_codeobj__1480 __pyx_mstate_global->__pyx_codeobj__1480
#define __pyx_codeobj__1481 __pyx_mstate_global->__pyx_codeobj__1481
#define __pyx_codeobj__1482 __pyx_mstate_global->__pyx_codeobj__1482
#define __pyx_codeobj__1483 __pyx_mstate_global->__pyx_codeobj__1483
#define __pyx_codeobj__1484 __pyx_mstate_global->__pyx_codeobj__1484
#define __pyx_codeobj__1485 __pyx_mstate_global->__pyx_codeobj__1485
#define __pyx_codeobj__1486 __pyx_mstate_global->__pyx_codeobj__1486
#define __pyx_codeobj__1487 __pyx_mstate_global->__pyx_codeobj__1487
#define __pyx_codeobj__1488 __pyx_mstate_global->__pyx_codeobj__1488
#define __pyx_codeobj__1489 __pyx_mstate_global->__pyx_codeobj__1489
#define __pyx_codeobj__1490 __pyx_mstate_global->__pyx_codeobj__1490
#define __pyx_codeobj__1491 __pyx_mstate_global->__pyx_codeobj__1491
#define __pyx_codeobj__1492 __pyx_mstate_global->__pyx_codeobj__1492
#define __pyx_codeobj__1493 __pyx_mstate_global->__pyx_codeobj__1493
#define __pyx_codeobj__1494 __pyx_mstate_global->__pyx_codeobj__1494
#define __pyx_codeobj__1495 __pyx_mstate_global->__pyx_codeobj__1495
#define __pyx_codeobj__1496 __pyx_mstate_global->__pyx_codeobj__1496
#define __pyx_codeobj__1497 __pyx_mstate_global->__pyx_codeobj__1497
#define __pyx_codeobj__1498 __pyx_mstate_global->__pyx_codeobj__1498
#define __pyx_codeobj__1499 __pyx_mstate_global->__pyx_codeobj__1499
#define __pyx_codeobj__1500 __pyx_mstate_global->__pyx_codeobj__1500
#define __pyx_codeobj__1501 __pyx_mstate_global->__pyx_codeobj__1501
#define __pyx_codeobj__1502 __pyx_mstate_global->__pyx_codeobj__1502
#define __pyx_codeobj__1503 __pyx_mstate_global->__pyx_codeobj__1503
#define __pyx_codeobj__1504 __pyx_mstate_global->__pyx_codeobj__1504
#define __pyx_codeobj__1505 __pyx_mstate_global->__pyx_codeobj__1505
#define __pyx_codeobj__1506 __pyx_mstate_global->__pyx_codeobj__1506
#define __pyx_codeobj__1507 __pyx_mstate_global->__pyx_codeobj__1507
#define __pyx_codeobj__1508 __pyx_mstate_global->__pyx_codeobj__1508
#define __pyx_codeobj__1509 __pyx_mstate_global->__pyx_codeobj__1509
#define __pyx_codeobj__1510 __pyx_mstate_global->__pyx_codeobj__1510
#define __pyx_codeobj__1511 __pyx_mstate_global->__pyx_codeobj__1511
#define __pyx_codeobj__1512 __pyx_mstate_global->__pyx_codeobj__1512
#define __pyx_codeobj__1513 __pyx_mstate_global->__pyx_codeobj__1513
#define __pyx_codeobj__1514 __pyx_mstate_global->__pyx_codeobj__1514
#define __pyx_codeobj__1515 __pyx_mstate_global->__pyx_codeobj__1515
#define __pyx_codeobj__1516 __pyx_mstate_global->__pyx_codeobj__1516
#define __pyx_codeobj__1517 __pyx_mstate_global->__pyx_codeobj__1517
#define __pyx_codeobj__1518 __pyx_mstate_global->__pyx_codeobj__1518
#define __pyx_codeobj__1519 __pyx_mstate_global->__pyx_codeobj__1519
#define __pyx_codeobj__1520 __pyx_mstate_global->__pyx_codeobj__1520
#define __pyx_codeobj__1521 __pyx_mstate_global->__pyx_codeobj__1521
#define __pyx_codeobj__1522 __pyx_mstate_global->__pyx_codeobj__1522
#define __pyx_codeobj__1523 __pyx_mstate_global->__pyx_codeobj__1523
#define __pyx_codeobj__1524 __pyx_mstate_global->__pyx_codeobj__1524
#define __pyx_codeobj__1525 __pyx_mstate_global->__pyx_codeobj__1525
#define __pyx_codeobj__1526 __pyx_mstate_global->__pyx_codeobj__1526
#define __pyx_codeobj__1527 __pyx_mstate_global->__pyx_codeobj__1527
#define __pyx_codeobj__1528 __pyx_mstate_global->__pyx_codeobj__1528
#define __pyx_codeobj__1529 __pyx_mstate_global->__pyx_codeobj__1529
#define __pyx_codeobj__1530 __pyx_mstate_global->__pyx_codeobj__1530
#define __pyx_codeobj__1531 __pyx_mstate_global->__pyx_codeobj__1531
#define __pyx_codeobj__1532 __pyx_mstate_global->__pyx_codeobj__1532
#define __pyx_codeobj__1533 __pyx_mstate_global->__pyx_codeobj__1533
#define __pyx_codeobj__1534 __pyx_mstate_global->__pyx_codeobj__1534
#define __pyx_codeobj__1535 __pyx_mstate_global->__pyx_codeobj__1535
#define __pyx_codeobj__1536 __pyx_mstate_global->__pyx_codeobj__1536
#define __pyx_codeobj__1537 __pyx_mstate_global->__pyx_codeobj__1537
#define __pyx_codeobj__1538 __pyx_mstate_global->__pyx_codeobj__1538
#define __pyx_codeobj__1539 __pyx_mstate_global->__pyx_codeobj__1539
#define __pyx_codeobj__1540 __pyx_mstate_global->__pyx_codeobj__1540
#define __pyx_codeobj__1541 __pyx_mstate_global->__pyx_codeobj__1541
#define __pyx_codeobj__1542 __pyx_mstate_global->__pyx_codeobj__1542
#define __pyx_codeobj__1543 __pyx_mstate_global->__pyx_codeobj__1543
#define __pyx_codeobj__1544 __pyx_mstate_global->__pyx_codeobj__1544
#define __pyx_codeobj__1545 __pyx_mstate_global->__pyx_codeobj__1545
#define __pyx_codeobj__1546 __pyx_mstate_global->__pyx_codeobj__1546
#define __pyx_codeobj__1547 __pyx_mstate_global->__pyx_codeobj__1547
#define __pyx_codeobj__1548 __pyx_mstate_global->__pyx_codeobj__1548
#define __pyx_codeobj__1549 __pyx_mstate_global->__pyx_codeobj__1549
#define __pyx_codeobj__1550 __pyx_mstate_global->__pyx_codeobj__1550
#define __pyx_codeobj__1551 __pyx_mstate_global->__pyx_codeobj__1551
#define __pyx_codeobj__1552 __pyx_mstate_global->__pyx_codeobj__1552
#define __pyx_codeobj__1553 __pyx_mstate_global->__pyx_codeobj__1553
#define __pyx_codeobj__1554 __pyx_mstate_global->__pyx_codeobj__1554
#define __pyx_codeobj__1555 __pyx_mstate_global->__pyx_codeobj__1555
#define __pyx_codeobj__1556 __pyx_mstate_global->__pyx_codeobj__1556
#define __pyx_codeobj__1557 __pyx_mstate_global->__pyx_codeobj__1557
#define __pyx_codeobj__1558 __pyx_mstate_global->__pyx_codeobj__1558
#define __pyx_codeobj__1559 __pyx_mstate_global->__pyx_codeobj__1559
#define __pyx_codeobj__1560 __pyx_mstate_global->__pyx_codeobj__1560
#define __pyx_codeobj__1561 __pyx_mstate_global->__pyx_codeobj__1561
#define __pyx_codeobj__1562 __pyx_mstate_global->__pyx_codeobj__1562
#define __pyx_codeobj__1563 __pyx_mstate_global->__pyx_codeobj__1563
#define __pyx_codeobj__1564 __pyx_mstate_global->__pyx_codeobj__1564
#define __pyx_codeobj__1565 __pyx_mstate_global->__pyx_codeobj__1565
#define __pyx_codeobj__1566 __pyx_mstate_global->__pyx_codeobj__1566
#define __pyx_codeobj__1567 __pyx_mstate_global->__pyx_codeobj__1567
#define __pyx_codeobj__1568 __pyx_mstate_global->__pyx_codeobj__1568
#define __pyx_codeobj__1569 __pyx_mstate_global->__pyx_codeobj__1569
#define __pyx_codeobj__1570 __pyx_mstate_global->__pyx_codeobj__1570
#define __pyx_codeobj__1571 __pyx_mstate_global->__pyx_codeobj__1571
#define __pyx_codeobj__1572 __pyx_mstate_global->__pyx_codeobj__1572
#define __pyx_codeobj__1573 __pyx_mstate_global->__pyx_codeobj__1573
#define __pyx_codeobj__1574 __pyx_mstate_global->__pyx_codeobj__1574
#define __pyx_codeobj__1575 __pyx_mstate_global->__pyx_codeobj__1575
#define __pyx_codeobj__1576 __pyx_mstate_global->__pyx_codeobj__1576
#define __pyx_codeobj__1577 __pyx_mstate_global->__pyx_codeobj__1577
#define __pyx_codeobj__1578 __pyx_mstate_global->__pyx_codeobj__1578
#define __pyx_codeobj__1579 __pyx_mstate_global->__pyx_codeobj__1579
#define __pyx_codeobj__1580 __pyx_mstate_global->__pyx_codeobj__1580
#define __pyx_codeobj__1581 __pyx_mstate_global->__pyx_codeobj__1581
#define __pyx_codeobj__1582 __pyx_mstate_global->__pyx_codeobj__1582
#define __pyx_codeobj__1583 __pyx_mstate_global->__pyx_codeobj__1583
#define __pyx_codeobj__1584 __pyx_mstate_global->__pyx_codeobj__1584
#define __pyx_codeobj__1585 __pyx_mstate_global->__pyx_codeobj__1585
#define __pyx_codeobj__1586 __pyx_mstate_global->__pyx_codeobj__1586
#define __pyx_codeobj__1587 __pyx_mstate_global->__pyx_codeobj__1587
#define __pyx_codeobj__1588 __pyx_mstate_global->__pyx_codeobj__1588
#define __pyx_codeobj__1589 __pyx_mstate_global->__pyx_codeobj__1589
#define __pyx_codeobj__1590 __pyx_mstate_global->__pyx_codeobj__1590
#define __pyx_codeobj__1591 __pyx_mstate_global->__pyx_codeobj__1591
#define __pyx_codeobj__1592 __pyx_mstate_global->__pyx_codeobj__1592
#define __pyx_codeobj__1593 __pyx_mstate_global->__pyx_codeobj__1593
#define __pyx_codeobj__1594 __pyx_mstate_global->__pyx_codeobj__1594
#define __pyx_codeobj__1595 __pyx_mstate_global->__pyx_codeobj__1595
#define __pyx_codeobj__1596 __pyx_mstate_global->__pyx_codeobj__1596
#define __pyx_codeobj__1597 __pyx_mstate_global->__pyx_codeobj__1597
#define __pyx_codeobj__1598 __pyx_mstate_global->__pyx_codeobj__1598
#define __pyx_codeobj__1599 __pyx_mstate_global->__pyx_codeobj__1599
#define __pyx_codeobj__1600 __pyx_mstate_global->__pyx_codeobj__1600
#define __pyx_codeobj__1601 __pyx_mstate_global->__pyx_codeobj__1601
#define __pyx_codeobj__1602 __pyx_mstate_global->__pyx_codeobj__1602
#define __pyx_codeobj__1603 __pyx_mstate_global->__pyx_codeobj__1603
#define __pyx_codeobj__1604 __pyx_mstate_global->__pyx_codeobj__1604
#define __pyx_codeobj__1605 __pyx_mstate_global->__pyx_codeobj__1605
#define __pyx_codeobj__1606 __pyx_mstate_global->__pyx_codeobj__1606
#define __pyx_codeobj__1607 __pyx_mstate_global->__pyx_codeobj__1607
#define __pyx_codeobj__1608 __pyx_mstate_global->__pyx_codeobj__1608
#define __pyx_codeobj__1609 __pyx_mstate_global->__pyx_codeobj__1609
#define __pyx_codeobj__1610 __pyx_mstate_global->__pyx_codeobj__1610
#define __pyx_codeobj__1611 __pyx_mstate_global->__pyx_codeobj__1611
#define __pyx_codeobj__1612 __pyx_mstate_global->__pyx_codeobj__1612
#define __pyx_codeobj__1613 __pyx_mstate_global->__pyx_codeobj__1613
#define __pyx_codeobj__1614 __pyx_mstate_global->__pyx_codeobj__1614
#define __pyx_codeobj__1615 __pyx_mstate_global->__pyx_codeobj__1615
#define __pyx_codeobj__1616 __pyx_mstate_global->__pyx_codeobj__1616
#define __pyx_codeobj__1617 __pyx_mstate_global->__pyx_codeobj__1617
#define __pyx_codeobj__1618 __pyx_mstate_global->__pyx_codeobj__1618
#define __pyx_codeobj__1619 __pyx_mstate_global->__pyx_codeobj__1619
#define __pyx_codeobj__1620 __pyx_mstate_global->__pyx_codeobj__1620
#define __pyx_codeobj__1621 __pyx_mstate_global->__pyx_codeobj__1621
#define __pyx_codeobj__1622 __pyx_mstate_global->__pyx_codeobj__1622
#define __pyx_codeobj__1623 __pyx_mstate_global->__pyx_codeobj__1623
#define __pyx_codeobj__1624 __pyx_mstate_global->__pyx_codeobj__1624
#define __pyx_codeobj__1625 __pyx_mstate_global->__pyx_codeobj__1625
#define __pyx_codeobj__1626 __pyx_mstate_global->__pyx_codeobj__1626
#define __pyx_codeobj__1628 __pyx_mstate_global->__pyx_codeobj__1628
#define __pyx_codeobj__1629 __pyx_mstate_global->__pyx_codeobj__1629
#define __pyx_codeobj__1631 __pyx_mstate_global->__pyx_codeobj__1631
#define __pyx_codeobj__1633 __pyx_mstate_global->__pyx_codeobj__1633
#define __pyx_codeobj__1634 __pyx_mstate_global->__pyx_codeobj__1634
#define __pyx_codeobj__1635 __pyx_mstate_global->__pyx_codeobj__1635
#define __pyx_codeobj__1636 __pyx_mstate_global->__pyx_codeobj__1636
#define __pyx_codeobj__1638 __pyx_mstate_global->__pyx_codeobj__1638
#define __pyx_codeobj__1640 __pyx_mstate_global->__pyx_codeobj__1640
#define __pyx_codeobj__1642 __pyx_mstate_global->__pyx_codeobj__1642
#define __pyx_codeobj__1644 __pyx_mstate_global->__pyx_codeobj__1644
#define __pyx_codeobj__1647 __pyx_mstate_global->__pyx_codeobj__1647
#define __pyx_codeobj__1648 __pyx_mstate_global->__pyx_codeobj__1648
#define __pyx_codeobj__1649 __pyx_mstate_global->__pyx_codeobj__1649
#define __pyx_codeobj__1652 __pyx_mstate_global->__pyx_codeobj__1652
#define __pyx_codeobj__1654 __pyx_mstate_global->__pyx_codeobj__1654
#define __pyx_codeobj__1701 __pyx_mstate_global->__pyx_codeobj__1701
#define __pyx_codeobj__1703 __pyx_mstate_global->__pyx_codeobj__1703
#define __pyx_codeobj__1704 __pyx_mstate_global->__pyx_codeobj__1704
#define __pyx_codeobj__1705 __pyx_mstate_global->__pyx_codeobj__1705
#define __pyx_codeobj__1706 __pyx_mstate_global->__pyx_codeobj__1706
#define __pyx_codeobj__1708 __pyx_mstate_global->__pyx_codeobj__1708
#define __pyx_codeobj__1709 __pyx_mstate_global->__pyx_codeobj__1709
#define __pyx_codeobj__1710 __pyx_mstate_global->__pyx_codeobj__1710
#define __pyx_codeobj__1711 __pyx_mstate_global->__pyx_codeobj__1711
#define __pyx_codeobj__1712 __pyx_mstate_global->__pyx_codeobj__1712
#define __pyx_codeobj__1714 __pyx_mstate_global->__pyx_codeobj__1714
#define __pyx_codeobj__1715 __pyx_mstate_global->__pyx_codeobj__1715
#define __pyx_codeobj__1716 __pyx_mstate_global->__pyx_codeobj__1716
#define __pyx_codeobj__1717 __pyx_mstate_global->__pyx_codeobj__1717
#define __pyx_codeobj__1718 __pyx_mstate_global->__pyx_codeobj__1718
#define __pyx_codeobj__1720 __pyx_mstate_global->__pyx_codeobj__1720
#define __pyx_codeobj__1723 __pyx_mstate_global->__pyx_codeobj__1723
#define __pyx_codeobj__1725 __pyx_mstate_global->__pyx_codeobj__1725
#define __pyx_codeobj__1727 __pyx_mstate_global->__pyx_codeobj__1727
/* #### Code section: module_code ### */

/* "string.from_py":13
 * 
 * @cname("__pyx_convert_string_from_py_6libcpp_6string_std__in_string")
 * cdef string __pyx_convert_string_from_py_6libcpp_6string_std__in_string(object o) except *:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t length = 0
 *     cdef const char* data = __Pyx_PyObject_AsStringAndSize(o, &length)
 */

static std::string __pyx_convert_string_from_py_6libcpp_6string_std__in_string(PyObject *__pyx_v_o) {
  Py_ssize_t __pyx_v_length;
  char const *__pyx_v_data;
  std::string __pyx_r;
  char const *__pyx_t_1;
  std::string __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "string.from_py":14
 * @cname("__pyx_convert_string_from_py_6libcpp_6string_std__in_string")
 * cdef string __pyx_convert_string_from_py_6libcpp_6string_std__in_string(object o) except *:
 *     cdef Py_ssize_t length = 0             # <<<<<<<<<<<<<<
 *     cdef const char* data = __Pyx_PyObject_AsStringAndSize(o, &length)
 *     return string(data, length)
 */
  __pyx_v_length = 0;

  /* "string.from_py":15
 * cdef string __pyx_convert_string_from_py_6libcpp_6string_std__in_string(object o) except *:
 *     cdef Py_ssize_t length = 0
 *     cdef const char* data = __Pyx_PyObject_AsStringAndSize(o, &length)             # <<<<<<<<<<<<<<
 *     return string(data, length)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsStringAndSize(__pyx_v_o, (&__pyx_v_length)); if (unlikely(__pyx_t_1 == ((char const *)NULL))) __PYX_ERR(1, 15, __pyx_L1_error)
  __pyx_v_data = __pyx_t_1;

  /* "string.from_py":16
 *     cdef Py_ssize_t length = 0
 *     cdef const char* data = __Pyx_PyObject_AsStringAndSize(o, &length)
 *     return string(data, length)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  try {
    __pyx_t_2 = std::string(__pyx_v_data, __pyx_v_length);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(1, 16, __pyx_L1_error)
  }
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "string.from_py":13
 * 
 * @cname("__pyx_convert_string_from_py_6libcpp_6string_std__in_string")
 * cdef string __pyx_convert_string_from_py_6libcpp_6string_std__in_string(object o) except *:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t length = 0
 *     cdef const char* data = __Pyx_PyObject_AsStringAndSize(o, &length)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("string.from_py.__pyx_convert_string_from_py_6libcpp_6string_std__in_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  return __pyx_r;
}

/* "string.to_py":31
 * 
 * @cname("__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyObject_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

static CYTHON_INLINE PyObject *__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string(std::string const &__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string", 1);

  /* "string.to_py":32
 * @cname("__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string(const string& s):
 *     return __Pyx_PyObject_FromStringAndSize(s.data(), s.size())             # <<<<<<<<<<<<<<
 * cdef extern from *:
 *     cdef object __Pyx_PyUnicode_FromStringAndSize(const char*, size_t)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_FromStringAndSize(__pyx_v_s.data(), __pyx_v_s.size()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "string.to_py":31
 * 
 * @cname("__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyObject_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("string.to_py.__pyx_convert_PyObject_string_to_py_6libcpp_6string_std__in_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "string.to_py":37
 * 
 * @cname("__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyUnicode_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

static CYTHON_INLINE PyObject *__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string(std::string const &__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string", 1);

  /* "string.to_py":38
 * @cname("__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string(const string& s):
 *     return __Pyx_PyUnicode_FromStringAndSize(s.data(), s.size())             # <<<<<<<<<<<<<<
 * cdef extern from *:
 *     cdef object __Pyx_PyStr_FromStringAndSize(const char*, size_t)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_FromStringAndSize(__pyx_v_s.data(), __pyx_v_s.size()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "string.to_py":37
 * 
 * @cname("__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyUnicode_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("string.to_py.__pyx_convert_PyUnicode_string_to_py_6libcpp_6string_std__in_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "string.to_py":43
 * 
 * @cname("__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyStr_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

static CYTHON_INLINE PyObject *__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string(std::string const &__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string", 1);

  /* "string.to_py":44
 * @cname("__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string(const string& s):
 *     return __Pyx_PyStr_FromStringAndSize(s.data(), s.size())             # <<<<<<<<<<<<<<
 * cdef extern from *:
 *     cdef object __Pyx_PyBytes_FromStringAndSize(const char*, size_t)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyStr_FromStringAndSize(__pyx_v_s.data(), __pyx_v_s.size()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "string.to_py":43
 * 
 * @cname("__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyStr_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("string.to_py.__pyx_convert_PyStr_string_to_py_6libcpp_6string_std__in_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "string.to_py":49
 * 
 * @cname("__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyBytes_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

static CYTHON_INLINE PyObject *__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(std::string const &__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string", 1);

  /* "string.to_py":50
 * @cname("__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(const string& s):
 *     return __Pyx_PyBytes_FromStringAndSize(s.data(), s.size())             # <<<<<<<<<<<<<<
 * cdef extern from *:
 *     cdef object __Pyx_PyByteArray_FromStringAndSize(const char*, size_t)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_s.data(), __pyx_v_s.size()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "string.to_py":49
 * 
 * @cname("__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyBytes_FromStringAndSize(s.data(), s.size())
 * cdef extern from *:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("string.to_py.__pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "string.to_py":55
 * 
 * @cname("__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyByteArray_FromStringAndSize(s.data(), s.size())
 * 
 */

static CYTHON_INLINE PyObject *__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string(std::string const &__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string", 1);

  /* "string.to_py":56
 * @cname("__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string(const string& s):
 *     return __Pyx_PyByteArray_FromStringAndSize(s.data(), s.size())             # <<<<<<<<<<<<<<
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyByteArray_FromStringAndSize(__pyx_v_s.data(), __pyx_v_s.size()); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "string.to_py":55
 * 
 * @cname("__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string")
 * cdef inline object __pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string(const string& s):             # <<<<<<<<<<<<<<
 *     return __Pyx_PyByteArray_FromStringAndSize(s.data(), s.size())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("string.to_py.__pyx_convert_PyByteArray_string_to_py_6libcpp_6string_std__in_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":112
 *    PythonVersion3 = False
 * 
 * def decstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return s.decode()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_1decstring23(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_1decstring23 = {"decstring23", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_1decstring23, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_1decstring23(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("decstring23 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 112, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "decstring23") < 0)) __PYX_ERR(0, 112, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("decstring23", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 112, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.decstring23", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_decstring23(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_decstring23(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("decstring23", 1);

  /* "giacpy/giacpy.pyx":113
 * 
 * def decstring23(s):
 *   if PythonVersion3 :             # <<<<<<<<<<<<<<
 *       return s.decode()
 *   else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PythonVersion3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":114
 * def decstring23(s):
 *   if PythonVersion3 :
 *       return s.decode()             # <<<<<<<<<<<<<<
 *   else:
 *       return s
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":113
 * 
 * def decstring23(s):
 *   if PythonVersion3 :             # <<<<<<<<<<<<<<
 *       return s.decode()
 *   else:
 */
  }

  /* "giacpy/giacpy.pyx":116
 *       return s.decode()
 *   else:
 *       return s             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_s);
    __pyx_r = __pyx_v_s;
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":112
 *    PythonVersion3 = False
 * 
 * def decstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return s.decode()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("giacpy.giacpy.decstring23", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":119
 * 
 * 
 * def encstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return bytes(s,'UTF-8')
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_3encstring23(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_3encstring23 = {"encstring23", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_3encstring23, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_3encstring23(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("encstring23 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 119, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "encstring23") < 0)) __PYX_ERR(0, 119, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("encstring23", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 119, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.encstring23", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_2encstring23(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_2encstring23(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("encstring23", 1);

  /* "giacpy/giacpy.pyx":120
 * 
 * def encstring23(s):
 *   if PythonVersion3 :             # <<<<<<<<<<<<<<
 *       return bytes(s,'UTF-8')
 *   else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PythonVersion3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":121
 * def encstring23(s):
 *   if PythonVersion3 :
 *       return bytes(s,'UTF-8')             # <<<<<<<<<<<<<<
 *   else:
 *       return s
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_s);
    __Pyx_GIVEREF(__pyx_v_s);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_s)) __PYX_ERR(0, 121, __pyx_L1_error);
    __Pyx_INCREF(__pyx_kp_s_UTF_8);
    __Pyx_GIVEREF(__pyx_kp_s_UTF_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_s_UTF_8)) __PYX_ERR(0, 121, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)(&PyBytes_Type)), __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":120
 * 
 * def encstring23(s):
 *   if PythonVersion3 :             # <<<<<<<<<<<<<<
 *       return bytes(s,'UTF-8')
 *   else:
 */
  }

  /* "giacpy/giacpy.pyx":123
 *       return bytes(s,'UTF-8')
 *   else:
 *       return s             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_s);
    __pyx_r = __pyx_v_s;
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":119
 * 
 * 
 * def encstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return bytes(s,'UTF-8')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.encstring23", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":163
 * # The wrapper to eval with giac
 * #######################################################
 * def giac(s):             # <<<<<<<<<<<<<<
 *   """
 *     This function evaluate a python object with the giac library.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5giac(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_4giac, "\n    This function evaluate a python object with the giac library.\n\n    * It creates in python a Pygen element and evaluate it with giac. For instance to compute a trigonometric expansion of cos(x+2y) where x and y are just formal symbols  we can do:\n\n     >>> from giacpy import giac,pi\n     >>> x,y=giac('x,y')\n     >>> (x+2*y).cos().texpand()\n     cos(x)*(2*cos(y)**2-1)-sin(x)*2*cos(y)*sin(y)\n\n\n   Coercion, Pygen and internal giac variables:\n   --------------------------------------------\n\n   * The most usefull objects will be the Python object of type Pygen. In the following example, we start by defining symbols x,y,z and do some formal computations\n\n    >>> from giacpy import *\n    >>> x,y,z=giac('x,y,z')\n    >>> ((x+2*y/z)*(y+1)**2).diff(y)  # compute the partial derivative with respect to y\n    2/z*(y+1)**2+(x+2*y/z)*2*(y+1)\n\n    In the next example x was previously defined as a symbol so x[i] is just another symbol. So we can use the symbols x[i] to work with polynomial in several variables as we do with theother symbols x,y,z.\n\n    For instance to compute the coefficient of x[0]^12 in (x[0]+x[1]+x[2]+x[3]+x[4])^15/(y+z) we just do the following\n    >>> f=sum([x[i] for i in range(5)])**15/(y+z);f.coeff(x[0],12)\n    (455*(x[1])**3+1365*(x[1])**2*x[2]+1365*(x[1])**2*x[3]+1365*(x[1])**2*x[4]+1365*x[1]*(x[2])**2+2730*x[1]*x[2]*x[3]+2730*x[1]*x[2]*x[4]+1365*x[1]*(x[3])**2+2730*x[1]*x[3]*x[4]+1365*x[1]*(x[4])**2+455*(x[2])**3+1365*(x[2])**2*x[3]+1365*(x[2])**2*x[4]+1365*x[2]*(x[3])**2+2730*x[2]*x[3]*x[4]+1365*x[2]*(x[4])**2+455*(x[3])**3+1365*(x[3])**2*x[4]+1365*x[3]*(x[4])**2+455*(x[4])**3)/(y+z)\n\n      Warning: The complex number sqrt(-1) is exported in python as I. (But it may appears as i)\n\n    >>> ((1+I*sqrt(3))**3).normal(); 1+I\n    -8\n    1+i\n\n   * Python integers and reals can be directly converted to giac.\n\n    >>> a=giac(2**1024);a.nextprime();(giac(1.234567)).erf().approx(10)\n    1797693134862315907729305190789024733617""97697894230657273430081157732675805500963132708477322407536021120113879871393357658789768814416622492847430639474124377767893424865485276302219601246094119453082952085005768838150682342462881473913110540827237163350510684586298239947245938479716304835356329624224137859\n    0.9191788641\n\n\n   * There are some natural coercion to Pygen elements:\n\n    >>> pi>3.14 ; pi >3.15 ; giac(3)==3\n    True\n    False\n    True\n\n   But sometimes you need to prevent Python from doing a computation before the conversion. For example if 1/3 is done in Python2 you will obtain 0 while in Python3 0.33333 so to create: x+1/3:\n   >>> x+'1/3'\n   x+1/3\n   >>> x+giac(1)/3\n   x+1/3\n\n   while to create x/(1+x) or x+x/3 you don't need quotes because at each step one of the two object is a Pygen.\n   >>> x/(1+x)\n   x/(1+x)\n   >>> (x+x/3).factor()\n   4*x/3\n\n\n   * The Python object y defined above is of type Pygen. It is not an internal giac variable. (Most of the time you won't need to use internal giac variables).\n\n    >>> yyyy=2;giac('yyyy:=1');yyyy\n    1\n    2\n\n\n   Linear Algebra:\n   ---------------\n\n   * In Giac/Xcas vectors are just lists and matrices are lists of list.\n\n    >>> x,y=giac('x,y')\n    >>> A=giac([[1,2],[3,4]])  # we create a giac matrix from it lines\n    >>> v=giac([x,y]); v   # a giac vector\n    [x,y]\n    >>> A*v # matrix product with a vector outputs a vector\n    [x+2*y,3*x+4*y]\n    >>> v*v  # dot product\n    x*x+y*y\n\n    Remark that w=giac([[x],[y]]) is a matrix of 1 column and 2 rows. It is not a vector    so w*w doesn't make sense.\n    >>> w=giac([[x],[y]])\n    >>> w.transpose()*w   # this matrix product makes sense and output a 1x1 matrix.\n    matrix[[x*x+y*y]]\n\n   * In Python affectation doesn't create a new matrix. (cf. pointers) see also  the doc of  'giacpy.Pygen.__setitem__'\n\n    >>> B1=A;\n    >>> B1[0,0]=43; B1 # in place affectation changes both B1 and A\n    [[43,2],[3,4]]\n    >>> A\n    [[43,2],[3,4]]\n    >>> A[0""][0]=A[0][0]+1; A  # similar as A[0,0]=A[0,0]+1\n    [[44,2],[3,4]]\n    >>> A.pcar(x)  # compute the characteristic polynomial of A\n    x**2-48*x+170\n    >>> B2=A.copy() # use copy to create another object\n    >>> B2[0,0]=55; B2  # here A is not modified\n    [[55,2],[3,4]]\n    >>> A\n    [[44,2],[3,4]]\n\n\n\n   * Sparse Matrices are avaible via the table function.\n    >>> import giacpy\n    >>> A=giacpy.table(()); A  # create an empty giac table\n    table(\n    )\n    >>> A[2,3]=33; A[0,2]='2/7' # set non zero entries of the sparse matrix\n    >>> A*A  # basic matrix operation are supported with sparse matrices\n    table(\n    (0,3) = 66/7\n    )\n    >>> D=giacpy.diag([22,3,'1/7']); D  # some diagonal matrix\n    [[22,0,0],[0,3,0],[0,0,1/7]]\n    >>> giacpy.table(D)    # to create a sparse matrix from an ordinary one\n    table(\n    (0,0) = 22,\n    (1,1) = 3,\n    (2,2) = 1/7\n    )\n\n\n     But many matrix functions apply only with ordinary matrices so need conversions\n\n    >>> B1=A.matrix(); B1 # convert the sparse matrix to a matrix, but the size is minimal\n    [[0,0,2/7,0],[0,0,0,0],[0,0,0,33]]\n    >>> B2=B1.redim(4,4); B2.pmin(x)  # so we may need to resize B1\n    x**3\n\n\n   Lists of Pygen and Giac lists:\n   ------------------------------\n\n   * Here l1 is a giac list and l2 is a python list of Pygen type objects.\n\n    >>> l1=giac(range(10)); l2=[1/(i**2+1) for i in l1]\n    >>> sum(l2)\n    33054527/16762850\n\n    So l1+l1 is done in giac and means a vector addition. But l2+l2 is done in Python so it is the list concatenation.\n\n    >>> l1+l1\n    [0,2,4,6,8,10,12,14,16,18]\n\n    >>> l2+l2\n    [1, 1/2, 1/5, 1/10, 1/17, 1/26, 1/37, 1/50, 1/65, 1/82, 1, 1/2, 1/5, 1/10, 1/17, 1/26, 1/37, 1/50, 1/65, 1/82]\n\n\n   * Here V is not a Pygen element. We need to push it to giac to use a giac method like dim, or we need to use an imported function.\n\n    >>> V=[ [x[i]**j for i in range(8)] for j in range(8)]\n\n    >>> giac(V).dim()\n    [8"",8]\n\n    >>> dt=det_minor(V).factor(); dt.nops()  # 28 factors\n    28\n\n    >>> sort(list(dt.op()))\n    [x[1]-(x[2]),x[1]-(x[3]),x[1]-(x[4]),x[1]-(x[5]),x[1]-(x[6]),x[1]-(x[7]),x[2]-(x[3]),x[2]-(x[4]),x[2]-(x[5]),x[2]-(x[6]),x[2]-(x[7]),x[3]-(x[4]),x[3]-(x[5]),x[3]-(x[6]),x[3]-(x[7]),x[4]-(x[5]),x[4]-(x[6]),x[4]-(x[7]),x[5]-(x[6]),x[5]-(x[7]),x[6]-(x[7]),x[0]-(x[1]),x[0]-(x[2]),x[0]-(x[3]),x[0]-(x[4]),x[0]-(x[5]),x[0]-(x[6]),x[0]-(x[7])]\n\n\n   * Modular objects with %\n\n    >>> V=ranm(5,6) % 2;\n\n    >>> ker(V).rowdim()+V.rank()\n    6\n\n    >>> a=giac(7)%3;a;a%0;7%3\n    1 % 3\n    1\n    1\n\n   Do not confuse with the  python integers:\n\n    >>> type(7%3)==type(a);type(a)==type(7%3)\n    False\n    False\n\n   Syntaxes with reserved or unknown Python symbols:\n   -------------------------------------------------\n\n   * In general equations needs symbols such as = < > or that have another meaning in Python. So those objects must be quoted.\n\n ::\n\n    >>> from giacpy import *\n\n    >>> x=giac('x')\n\n    >>> (1+2*sin(3*x)).solve(x).simplify()\n    list[-pi/18,7*pi/18]\n\n    >>> solve('sin(3*x)>2*sin(x)',x) # doctest: +SKIP \n    \"Unable to find numeric values solving equation. For trigonometric equations this may be solved using assumptions, e.g. assume(x>-pi && x<pi) Error: Bad Argument Value\"\n\n\n   * You can also add some hypothesis to a giac symbol:\n\n    >>> assume('x>-pi && x<pi')\n    x\n    >>> solve('sin(3*x)>2*sin(x)',x)\n    list[((x>(-5*pi/6)) and (x<(-pi/6))),((x>0) and (x<(pi/6))),((x>(5*pi/6)) and (x<pi))]\n\n   * To remove those hypothesis use the giac function: purge\n\n    >>> purge('x')\n    assume[[],[line[-pi,pi]],[-pi,pi]]\n    >>> solve('x>0')\n    list[x>0]\n\n ::\n\n   * Same problems with the ..\n\n    >>> from giacpy import *\n\n    >>> x=giac('x')\n\n    >>> f=1/(5+cos(4*x));f.int(x)\n    1/2/(2*sqrt(6))*(atan((-sqrt(6)*sin(4*x)+2*sin(4*x))/(sqrt(6)*cos(4*x)+sqrt(6)-2*cos(4*x)+2))+4*x/2)\n    >>> fMax(f,'x=-0..pi').s""implify()\n    pi/4,3*pi/4\n    >>> fMax.help()    # doctest: +SKIP\n    \"Returns the abscissa of the maximum of the expression.\n    Expr,[Var]\n    fMax(-x^2+2*x+1,x)\n    fMin\"\n    >>> sum(1/(1+x**2),'x=0..infinity').simplify()\n    (pi*exp(pi)**2+pi+exp(pi)**2-1)/(2*exp(pi)**2-2)\n\n\n   MEMENTO of usual GIAC functions:\n   ===============================\n\n   * Expand with simplification\n\n         - ``ratnormal``, ``normal``, ``simplify``   (from the fastest to the most sophisticated)\n\n         -  NB: ``expand`` function doesn't regroup nor cancel terms, so it could be slow. (pedagogical purpose only?)\n\n   * Factor/Regroup\n\n         - ``factor``, ``factors``, ``regroup``, ``cfactor``, ``ifactor``\n\n   * Misc\n\n         - ``unapply``, ``op``, ``subst``\n\n   * Polynomials/Fractions\n\n         - ``coeff``,  ``gbasis``, ``greduce``, ``lcoeff``, ``pcoeff``, ``canonical_form``,\n\n         - ``proot``,  ``poly2symb``,  ``symb2poly``, ``posubLMQ``, ``poslbdLMQ``, ``VAS``, ``tcoeff``,  ``valuation``\n\n         - ``gcd``, ``egcd``, ``lcm``, ``quo``, ``rem``, ``quorem``, ``abcuv``, ``chinrem``,\n\n         - ``peval``, ``horner``, ``lagrange``, ``ptayl``, ``spline``,  ``sturm``,  ``sturmab``\n\n         - ``partfrac``, ``cpartfrac``\n\n   * Memory/Variables\n\n         * ``assume``, ``about``, ``purge``, ``ans``\n\n   * Calculus/Exact\n\n         - ``linsolve``,  ``solve``,  ``csolve``,  ``desolve``,  ``seqsolve``, ``reverse_rsolve``, ``matpow``\n\n         - ``limit``, ``series``, ``sum``, ``diff``, ``fMax``, ``fMin``,\n\n         - ``integrate``, ``subst``, ``ibpdv``, ``ibpu``, ``preval``\n\n   * Calculus/Exp, Log, powers\n\n         - ``exp2pow``, ``hyp2exp``, ``expexpand``, ``lin``, ``lncollect``, ``lnexpand``, ``powexpand``, ``pow2exp``\n\n   * Trigo\n\n         - ``trigexpand``, ``tsimplify``, ``tlin``, ``tcollect``,\n\n         - ``halftan``, ``cos2sintan``, ``sin2costan``, ``tan2sincos``, ``tan2cossin2``, ``tan2sincos2``, ``trigcos``, ``trigsin``"", ``trigtan``, ``shift_phase``\n\n         - ``exp2trig``, ``trig2exp``\n\n         - ``atrig2ln``, ``acos2asin``, ``acos2atan``, ``asin2acos``, ``asin2atan``, ``atan2acos``, ``atan2asin``\n\n   * Linear Algebra\n\n         - ``identity``, ``matrix``, ``makemat``, ``syst2mat``, ``matpow``, ``table``,  ``redim``\n\n         - ``det``,  ``det_minor``, ``rank``, ``ker``, ``image``, ``rref``, ``simplex_reduce``,\n\n         - ``egv``, ``egvl``,  ``eigenvalues``, ``pcar``, ``pcar_hessenberg``, ``pmin``,\n\n         - ``jordan``, ``adjoint_matrix``, ``companion``, ``hessenberg``, ``transpose``,\n\n         - ``cholesky``, ``lll``,  ``lu``, ``qr``, ``svd``, ``a2q``, ``gauss``, ``gramschmidt``,\n           ``q2a``, ``isom``, ``mkisom``\n\n\n   * Finite Fieds\n\n         - ``%``, ``% 0``, ``mod``, ``GF``, ``powmod``\n\n\n   * Integers\n\n         - ``gcd``, ``iabcuv``, ``ichinrem``, ``idivis``, ``iegcd``,\n\n         - ``ifactor``, ``ifactors``, ``iquo``, ``iquorem``, ``irem``,\n\n         - ``is_prime, is_pseudoprime``, ``lcm``, ``mod``, ``nextprime``, ``pa2b2``, ``prevprime``,\n           ``smod``, ``euler``, ``fracmod``\n\n   * List\n\n         - ``append``, ``accumulate_head_tail``, ``concat``, ``head``, ``makelist``, ``member``, ``mid``, ``revlist``, ``rotate``, ``shift``, ``size``, ``sizes``, ``sort``, ``suppress``, ``tail``\n\n   * Set\n\n         - ``intersect``, ``minus``, ``union``, ``is_element``, ``is_included``\n\n\n  ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5giac = {"giac", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5giac, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_4giac};
static PyObject *__pyx_pw_6giacpy_6giacpy_5giac(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("giac (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 163, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "giac") < 0)) __PYX_ERR(0, 163, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("giac", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 163, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.giac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_4giac(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_4giac(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("giac", 1);

  /* "giacpy/giacpy.pyx":502
 * 
 *   """
 *   return Pygen(s).threadeval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_threadeval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":163
 * # The wrapper to eval with giac
 * #######################################################
 * def giac(s):             # <<<<<<<<<<<<<<
 *   """
 *     This function evaluate a python object with the giac library.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.giac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":606
 *      """
 * 
 *      def __repr__(self):             # <<<<<<<<<<<<<<
 *        return "Giac Settings"
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting___repr__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting___repr__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "giacpy/giacpy.pyx":607
 * 
 *      def __repr__(self):
 *        return "Giac Settings"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_s_Giac_Settings);
  __pyx_r = __pyx_kp_s_Giac_Settings;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":606
 *      """
 * 
 *      def __repr__(self):             # <<<<<<<<<<<<<<
 *        return "Giac Settings"
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":624
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[6])._val
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_6digits_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_6digits_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_6digits___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_6digits___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":625
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[6])._val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":624
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[6])._val
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.digits.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":628
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_6digits_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_6digits_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_6digits_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_6digits_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_pl = NULL;
  PyObject *__pyx_7genexpr__pyx_v_i = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":629
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            pl[6]=value
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_l = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":630
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]             # <<<<<<<<<<<<<<
 *            pl[6]=value
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 630, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_l)) || PyTuple_CheckExact(__pyx_v_l)) {
      __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 630, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 630, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 630, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 630, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 630, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 630, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 630, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 630, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 630, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_7genexpr__pyx_v_i))) __PYX_ERR(0, 630, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_i); __pyx_7genexpr__pyx_v_i = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_i); __pyx_7genexpr__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_pl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":631
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            pl[6]=value             # <<<<<<<<<<<<<<
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 * 
 */
  if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 6, __pyx_v_value, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 631, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":632
 *            pl=[ i for i in l ]
 *            pl[6]=value
 *            Pygen('cas_setup(%s)'%(pl)).eval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_cas_setup_s, __pyx_v_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":628
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.digits.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_pl);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":651
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[9])._val == 1
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_8sqrtflag_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_8sqrtflag_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_8sqrtflag___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_8sqrtflag___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":652
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[9])._val == 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":651
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[9])._val == 1
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.sqrtflag.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":655
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_8sqrtflag_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_8sqrtflag_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_8sqrtflag_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_8sqrtflag_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_pl = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_i = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":656
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            if value:
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_l = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":657
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]             # <<<<<<<<<<<<<<
 *            if value:
 *               pl[9]=1
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_l)) || PyTuple_CheckExact(__pyx_v_l)) {
      __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 657, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 657, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 657, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 657, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 657, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 657, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 657, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr1__pyx_v_i))) __PYX_ERR(0, 657, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_i); __pyx_8genexpr1__pyx_v_i = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_i); __pyx_8genexpr1__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_pl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":658
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            if value:             # <<<<<<<<<<<<<<
 *               pl[9]=1
 *            else:
 */
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 658, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "giacpy/giacpy.pyx":659
 *            pl=[ i for i in l ]
 *            if value:
 *               pl[9]=1             # <<<<<<<<<<<<<<
 *            else:
 *               pl[9]=0
 */
    if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 9, __pyx_int_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 659, __pyx_L1_error)

    /* "giacpy/giacpy.pyx":658
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            if value:             # <<<<<<<<<<<<<<
 *               pl[9]=1
 *            else:
 */
    goto __pyx_L10;
  }

  /* "giacpy/giacpy.pyx":661
 *               pl[9]=1
 *            else:
 *               pl[9]=0             # <<<<<<<<<<<<<<
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 * 
 */
  /*else*/ {
    if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 9, __pyx_int_0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 661, __pyx_L1_error)
  }
  __pyx_L10:;

  /* "giacpy/giacpy.pyx":662
 *            else:
 *               pl[9]=0
 *            Pygen('cas_setup(%s)'%(pl)).eval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_cas_setup_s, __pyx_v_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":655
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.sqrtflag.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_pl);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":681
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[2])._val == 1
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_11complexflag_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_11complexflag_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_11complexflag___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_11complexflag___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":682
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[2])._val == 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_1, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":681
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[2])._val == 1
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.complexflag.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":685
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_11complexflag_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_11complexflag_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_11complexflag_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_11complexflag_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_pl = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_i = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":686
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            if value:
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_l = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":687
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]             # <<<<<<<<<<<<<<
 *            if value:
 *               pl[2]=1
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_l)) || PyTuple_CheckExact(__pyx_v_l)) {
      __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 687, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 687, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 687, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 687, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 687, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 687, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 687, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 687, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 687, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr2__pyx_v_i))) __PYX_ERR(0, 687, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_i); __pyx_8genexpr2__pyx_v_i = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_i); __pyx_8genexpr2__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_pl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":688
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            if value:             # <<<<<<<<<<<<<<
 *               pl[2]=1
 *            else:
 */
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 688, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "giacpy/giacpy.pyx":689
 *            pl=[ i for i in l ]
 *            if value:
 *               pl[2]=1             # <<<<<<<<<<<<<<
 *            else:
 *               pl[2]=0
 */
    if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 2, __pyx_int_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 689, __pyx_L1_error)

    /* "giacpy/giacpy.pyx":688
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            if value:             # <<<<<<<<<<<<<<
 *               pl[2]=1
 *            else:
 */
    goto __pyx_L10;
  }

  /* "giacpy/giacpy.pyx":691
 *               pl[2]=1
 *            else:
 *               pl[2]=0             # <<<<<<<<<<<<<<
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 * 
 */
  /*else*/ {
    if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 2, __pyx_int_0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 691, __pyx_L1_error)
  }
  __pyx_L10:;

  /* "giacpy/giacpy.pyx":692
 *            else:
 *               pl[2]=0
 *            Pygen('cas_setup(%s)'%(pl)).eval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_cas_setup_s, __pyx_v_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":685
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.complexflag.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_pl);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":709
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[7][3])._val
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_10eval_level_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_10eval_level_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_10eval_level___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_10eval_level___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":710
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[7][3])._val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_val); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":709
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[7][3])._val
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.eval_level.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":713
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_10eval_level_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_10eval_level_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_10eval_level_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_10eval_level_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_pl = NULL;
  PyObject *__pyx_8genexpr3__pyx_v_i = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":714
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            pl[7]=[l[7][0],l[7][1],l[7][2],value]
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_l = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":715
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]             # <<<<<<<<<<<<<<
 *            pl[7]=[l[7][0],l[7][1],l[7][2],value]
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 715, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_l)) || PyTuple_CheckExact(__pyx_v_l)) {
      __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 715, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 715, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 715, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 715, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 715, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 715, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 715, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 715, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 715, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr3__pyx_v_i))) __PYX_ERR(0, 715, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_i); __pyx_8genexpr3__pyx_v_i = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_i); __pyx_8genexpr3__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_pl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":716
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            pl[7]=[l[7][0],l[7][1],l[7][2],value]             # <<<<<<<<<<<<<<
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_l, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_l, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_l, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_1, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 716, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_t_2)) __PYX_ERR(0, 716, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_t_7)) __PYX_ERR(0, 716, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_v_value)) __PYX_ERR(0, 716, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_t_7 = 0;
  if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 7, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 716, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":717
 *            pl=[ i for i in l ]
 *            pl[7]=[l[7][0],l[7][1],l[7][2],value]
 *            Pygen('cas_setup(%s)'%(pl)).eval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyString_Format(__pyx_kp_s_cas_setup_s, __pyx_v_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 717, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":713
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.eval_level.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_pl);
  __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":733
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[5][1])._double
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_13proba_epsilon___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_13proba_epsilon___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":734
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[5][1])._double             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_double); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":733
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[5][1])._double
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.proba_epsilon.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":737
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_pl = NULL;
  PyObject *__pyx_8genexpr4__pyx_v_i = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":738
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            pl[5]=[l[5][0],value]
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_l = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":739
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]             # <<<<<<<<<<<<<<
 *            pl[5]=[l[5][0],value]
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 739, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_l)) || PyTuple_CheckExact(__pyx_v_l)) {
      __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 739, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 739, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 739, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 739, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 739, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 739, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 739, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 739, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 739, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr4__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr4__pyx_v_i))) __PYX_ERR(0, 739, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_i); __pyx_8genexpr4__pyx_v_i = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_i); __pyx_8genexpr4__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_pl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":740
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            pl[5]=[l[5][0],value]             # <<<<<<<<<<<<<<
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_l, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 740, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_value)) __PYX_ERR(0, 740, __pyx_L1_error);
  __pyx_t_3 = 0;
  if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 5, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 740, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":741
 *            pl=[ i for i in l ]
 *            pl[5]=[l[5][0],value]
 *            Pygen('cas_setup(%s)'%(pl)).eval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_cas_setup_s, __pyx_v_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":737
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.proba_epsilon.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_pl);
  __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":759
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[5][0])._double
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_7epsilon_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_7epsilon_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_7epsilon___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_7epsilon___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":760
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[5][0])._double             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_double); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":759
 * 
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[5][0])._double
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.epsilon.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":763
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_7epsilon_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_7epsilon_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_7epsilon_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_7epsilon_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_pl = NULL;
  PyObject *__pyx_8genexpr5__pyx_v_i = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":764
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            pl[5]=[value,l[5][1]]
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_l = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":765
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]             # <<<<<<<<<<<<<<
 *            pl[5]=[value,l[5][1]]
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_v_l)) || PyTuple_CheckExact(__pyx_v_l)) {
      __pyx_t_3 = __pyx_v_l; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_l); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 765, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 765, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 765, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 765, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 765, __pyx_L5_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 765, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 765, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_i, __pyx_t_2);
      __pyx_t_2 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr5__pyx_v_i))) __PYX_ERR(0, 765, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_i); __pyx_8genexpr5__pyx_v_i = 0;
    goto __pyx_L9_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_i); __pyx_8genexpr5__pyx_v_i = 0;
    goto __pyx_L1_error;
    __pyx_L9_exit_scope:;
  } /* exit inner scope */
  __pyx_v_pl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":766
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 *            pl[5]=[value,l[5][1]]             # <<<<<<<<<<<<<<
 *            Pygen('cas_setup(%s)'%(pl)).eval()
 * 
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_l, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_value)) __PYX_ERR(0, 766, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 766, __pyx_L1_error);
  __pyx_t_3 = 0;
  if (unlikely((__Pyx_SetItemInt(__pyx_v_pl, 5, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":767
 *            pl=[ i for i in l ]
 *            pl[5]=[value,l[5][1]]
 *            Pygen('cas_setup(%s)'%(pl)).eval()             # <<<<<<<<<<<<<<
 * 
 *      property threads:
 */
  __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_cas_setup_s, __pyx_v_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":763
 * 
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            l=Pygen('cas_setup()').eval()
 *            pl=[ i for i in l ]
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.epsilon.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_pl);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":773
 *          Maximal number of allowed theads in giac
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[7][0])._val
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_7threads_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_7threads_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_7threads___get__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_7threads___get__(struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":774
 *          """
 *          def __get__(self):
 *            return (self.cas_setup()[7][0])._val             # <<<<<<<<<<<<<<
 * 
 *          def __set__(self,value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cas_setup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_val); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":773
 *          Maximal number of allowed theads in giac
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            return (self.cas_setup()[7][0])._val
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.threads.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":776
 *            return (self.cas_setup()[7][0])._val
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            Pygen('threads:=%s'%(str(value))).eval()
 * 
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_7threads_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_11GiacSetting_7threads_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_7threads_2__set__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_11GiacSetting_7threads_2__set__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);

  /* "giacpy/giacpy.pyx":777
 * 
 *          def __set__(self,value):
 *            Pygen('threads:=%s'%(str(value))).eval()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyString_FormatSafe(__pyx_kp_s_threads_s, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":776
 *            return (self.cas_setup()[7][0])._val
 * 
 *          def __set__(self,value):             # <<<<<<<<<<<<<<
 *            Pygen('threads:=%s'%(str(value))).eval()
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.threads.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_11GiacSetting_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_11GiacSetting_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_2__reduce_cython__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_11GiacSetting_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_11GiacSetting_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_11GiacSetting_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_11GiacSetting_4__setstate_cython__(((struct __pyx_obj_6giacpy_6giacpy_GiacSetting *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_11GiacSetting_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_GiacSetting *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("giacpy.giacpy.GiacSetting.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12
 *      """
 * 
 *      def Airy_Ai(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Ai:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1Airy_Ai(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_Airy_Ai, "From Giac's documentation:\n        Help for Airy_Ai:\n        Airy_Ai(Real)\n        Returns the value of Ai the Airy function solution of w''-xw=0. Ai(x)=Ai(0)f(z)+Ai'(0)g(z)(f and g are taylor's series sol of w''-xw=0).\n        See also: 1/ Airy_Bi \n        Ex1:Airy_Ai(0)\n        Ex2:Airy_Ai(1.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1Airy_Ai = {"Airy_Ai", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1Airy_Ai, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_Airy_Ai};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1Airy_Ai(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Airy_Ai (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Airy_Ai", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_Airy_Ai(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_Airy_Ai(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Airy_Ai", 1);

  /* "giacpy/auto-methods.pxi":22
 * 
 *         '''
 *         return GiacMethods['Airy_Ai'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Airy_Bi(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Airy_Ai); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 22, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12
 *      """
 * 
 *      def Airy_Ai(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Ai:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Airy_Ai", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":24
 *         return GiacMethods['Airy_Ai'](self,*args)
 * 
 *      def Airy_Bi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Bi:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3Airy_Bi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2Airy_Bi, "From Giac's documentation:\n        Help for Airy_Bi:\n        Airy_Bi(Real)\n        Returns the value of Ai the Airy function solution of w''-xw=0. Bi(x)=sqrt(3)(Bi(0)f(z)-Bi'(0)g(z))(f and g are taylor's series sol of w''-xw=0).\n        See also: 1/ Airy_Ai \n        Ex1:Airy_Bi(1.5)\n        Ex2:Airy_Bi(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3Airy_Bi = {"Airy_Bi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3Airy_Bi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2Airy_Bi};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3Airy_Bi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Airy_Bi (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Airy_Bi", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2Airy_Bi(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2Airy_Bi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Airy_Bi", 1);

  /* "giacpy/auto-methods.pxi":34
 * 
 *         '''
 *         return GiacMethods['Airy_Bi'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Archive(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Airy_Bi); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 34, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":24
 *         return GiacMethods['Airy_Ai'](self,*args)
 * 
 *      def Airy_Bi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Bi:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Airy_Bi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":36
 *         return GiacMethods['Airy_Bi'](self,*args)
 * 
 *      def Archive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Archive:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_5Archive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_4Archive, "From Giac's documentation:\n        Help for Archive:\n        Archive(SeqVar)\n        Protects the variables given as argument in an archive file.\n        See also: 1/ Unarchiv 2/ archive 3/ unarchive \n        Ex1:Archive(a,b)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_5Archive = {"Archive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_5Archive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_4Archive};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_5Archive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Archive (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Archive", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_4Archive(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_4Archive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Archive", 1);

  /* "giacpy/auto-methods.pxi":45
 * 
 *         '''
 *         return GiacMethods['Archive'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def BesselJ(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Archive); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 45, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":36
 *         return GiacMethods['Airy_Bi'](self,*args)
 * 
 *      def Archive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Archive:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":47
 *         return GiacMethods['Archive'](self,*args)
 * 
 *      def BesselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselJ:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_7BesselJ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_6BesselJ, "From Giac's documentation:\n        Help for BesselJ:\n        BesselJ(Int(p),Real(x))\n        BesselJ(p,x) returns the Bessel function of the first kind Jp(x).\n        See also: 1/ besselJ 2/ BesselY 3/ besselY \n        Ex1:BesselJ(2,sqrt(2))\n        Ex2:BesselJ(-2,sqrt(2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_7BesselJ = {"BesselJ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_7BesselJ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_6BesselJ};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_7BesselJ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("BesselJ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "BesselJ", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_6BesselJ(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_6BesselJ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("BesselJ", 1);

  /* "giacpy/auto-methods.pxi":57
 * 
 *         '''
 *         return GiacMethods['BesselJ'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def BesselY(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_BesselJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 57, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":47
 *         return GiacMethods['Archive'](self,*args)
 * 
 *      def BesselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselJ:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.BesselJ", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":59
 *         return GiacMethods['BesselJ'](self,*args)
 * 
 *      def BesselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselY:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_9BesselY(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_8BesselY, "From Giac's documentation:\n        Help for BesselY:\n        BesselY(Int(p),Real(x))\n        BesselY(p,x) returns the Bessel function of the second kind Yp(x).\n        See also: 1/ besselY 2/ BesselJ 3/ besselJ \n        Ex1:BesselY(BesselJ(2,sqrt(2)))\n        Ex2:BesselY(BesselJ(-2,sqrt(2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_9BesselY = {"BesselY", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_9BesselY, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_8BesselY};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_9BesselY(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("BesselY (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "BesselY", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_8BesselY(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_8BesselY(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("BesselY", 1);

  /* "giacpy/auto-methods.pxi":69
 * 
 *         '''
 *         return GiacMethods['BesselY'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Beta(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_BesselY); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 69, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":59
 *         return GiacMethods['BesselJ'](self,*args)
 * 
 *      def BesselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselY:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.BesselY", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":71
 *         return GiacMethods['BesselY'](self,*args)
 * 
 *      def Beta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Beta:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_11Beta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_10Beta, "From Giac's documentation:\n        Help for Beta:\n        Beta(Expr,Expr,[Expr],[1])\n        Beta(a,b)=int(t^(a-1)*(1-t)^(b-1),t=0..1), Beta(a,b,p)=int(t^(a-1)*(1-t)^(b-1),t=0..p), Beta(a,b,p,1)=Beta(a,b,p)/Beta(a,b).(Beta(x,y) returns Gamma(x)*Gamma(y)/Gamma(x+y)).\n        See also: 1/ Gamma 2/ igamma \n        Ex1:Beta(x,y)\n        Ex2:Beta(3,2)\n        Ex3:Beta(3,2,0.5)\n        Ex4:Beta(3,2,0.5,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_11Beta = {"Beta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_11Beta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_10Beta};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_11Beta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Beta (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Beta", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_10Beta(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_10Beta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Beta", 1);

  /* "giacpy/auto-methods.pxi":83
 * 
 *         '''
 *         return GiacMethods['Beta'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def BlockDiagonal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Beta); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 83, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":71
 *         return GiacMethods['BesselY'](self,*args)
 * 
 *      def Beta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Beta:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Beta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":85
 *         return GiacMethods['Beta'](self,*args)
 * 
 *      def BlockDiagonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BlockDiagonal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_13BlockDiagonal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_12BlockDiagonal, "From Giac's documentation:\n        Help for BlockDiagonal:\n        BlockDiagonal(Lst(l)||Mtrx(A))\n        Returns either the diagonal matrix with diagonal l or the diagonal of A.\n        See also: 1/ identity 2/ diag  \n        Ex1:BlockDiagonal([[1,2],[3,4]])\n        Ex2:BlockDiagonal([1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_13BlockDiagonal = {"BlockDiagonal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_13BlockDiagonal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_12BlockDiagonal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_13BlockDiagonal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("BlockDiagonal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "BlockDiagonal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_12BlockDiagonal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_12BlockDiagonal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("BlockDiagonal", 1);

  /* "giacpy/auto-methods.pxi":95
 * 
 *         '''
 *         return GiacMethods['BlockDiagonal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Ci(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_BlockDiagonal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 95, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":85
 *         return GiacMethods['Beta'](self,*args)
 * 
 *      def BlockDiagonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BlockDiagonal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.BlockDiagonal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":97
 *         return GiacMethods['BlockDiagonal'](self,*args)
 * 
 *      def Ci(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ci:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_15Ci(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_14Ci, "From Giac's documentation:\n        Help for Ci:\n        Ci(Expr)\n        Cosine integral int(cos(t)/t,t=-inf..x).\n        See also: 1/ Ei 2/ Si 3/ Li \n        Ex1:Ci(1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_15Ci = {"Ci", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_15Ci, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_14Ci};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_15Ci(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Ci (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Ci", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_14Ci(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_14Ci(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Ci", 1);

  /* "giacpy/auto-methods.pxi":106
 * 
 *         '''
 *         return GiacMethods['Ci'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Circle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Ci); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 106, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":97
 *         return GiacMethods['BlockDiagonal'](self,*args)
 * 
 *      def Ci(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ci:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Ci", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":108
 *         return GiacMethods['Ci'](self,*args)
 * 
 *      def Circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Circle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_17Circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_16Circle, "From Giac's documentation:\n        Help for Circle:\n        Circle(Real(xc),Real(yc),Real(r),[Intg(option)])\n        Draws the circle with center (xc,yc) and radius r (by default option=1 and option=0 is to remove this circle).\n        See also: 1/ circle \n        Ex1:Circle(0,1,1)\n        Ex2:Circle(0,1,1,0)\n        Ex3:Circle(0,1,1,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_17Circle = {"Circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_17Circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_16Circle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_17Circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Circle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Circle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_16Circle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_16Circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Circle", 1);

  /* "giacpy/auto-methods.pxi":119
 * 
 *         '''
 *         return GiacMethods['Circle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Col(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Circle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 119, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":108
 *         return GiacMethods['Ci'](self,*args)
 * 
 *      def Circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Circle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Circle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":121
 *         return GiacMethods['Circle'](self,*args)
 * 
 *      def Col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Col:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_19Col(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_18Col, "From Giac's documentation:\n        Help for Col:\n        Col(NULL)\n        Returns the index of the column of the lightened cell in the matrixwriter.\n        See also: 1/ Row \n        Ex1:Col()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_19Col = {"Col", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_19Col, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_18Col};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_19Col(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Col (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Col", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_18Col(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_18Col(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Col", 1);

  /* "giacpy/auto-methods.pxi":130
 * 
 *         '''
 *         return GiacMethods['Col'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def CopyVar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Col); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 130, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":121
 *         return GiacMethods['Circle'](self,*args)
 * 
 *      def Col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Col:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Col", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":132
 *         return GiacMethods['Col'](self,*args)
 * 
 *      def CopyVar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for CopyVar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_21CopyVar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_20CopyVar, "From Giac's documentation:\n        Help for CopyVar:\n        CopyVar(Var(var1),Var(var2))\n        Copies the storage without evaluation of var1 into var2.\n        See also: 1/  \n        Ex1:CopyVar(A,B)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_21CopyVar = {"CopyVar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_21CopyVar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_20CopyVar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_21CopyVar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("CopyVar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "CopyVar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_20CopyVar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_20CopyVar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("CopyVar", 1);

  /* "giacpy/auto-methods.pxi":141
 * 
 *         '''
 *         return GiacMethods['CopyVar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Dirac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_CopyVar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 141, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":132
 *         return GiacMethods['Col'](self,*args)
 * 
 *      def CopyVar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for CopyVar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.CopyVar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":143
 *         return GiacMethods['CopyVar'](self,*args)
 * 
 *      def Dirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Dirac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_23Dirac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_22Dirac, "From Giac's documentation:\n        Help for Dirac:\n        Dirac(Real)\n        Function derivative of Heaviside.\n        See also: 1/ Heaviside \n        Ex1:Dirac(1)\n        Ex2:Dirac(-1)\n        Ex3: int(Dirac(x)*(x-1)^2,x,-1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_23Dirac = {"Dirac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_23Dirac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_22Dirac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_23Dirac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Dirac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Dirac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_22Dirac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_22Dirac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Dirac", 1);

  /* "giacpy/auto-methods.pxi":154
 * 
 *         '''
 *         return GiacMethods['Dirac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Ei(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Dirac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":143
 *         return GiacMethods['CopyVar'](self,*args)
 * 
 *      def Dirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Dirac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Dirac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":156
 *         return GiacMethods['Dirac'](self,*args)
 * 
 *      def Ei(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ei:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_25Ei(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_24Ei, "From Giac's documentation:\n        Help for Ei:\n        Ei(Expr)\n        Exponential integral int(exp(t)/t,t=-inf..x).\n        See also: 1/ Si 2/ Ci 3/ Li \n        Ex1:Ei(1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_25Ei = {"Ei", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_25Ei, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_24Ei};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_25Ei(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Ei (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Ei", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_24Ei(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_24Ei(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Ei", 1);

  /* "giacpy/auto-methods.pxi":165
 * 
 *         '''
 *         return GiacMethods['Ei'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Factor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Ei); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 165, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":156
 *         return GiacMethods['Dirac'](self,*args)
 * 
 *      def Ei(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ei:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Ei", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":167
 *         return GiacMethods['Ei'](self,*args)
 * 
 *      def Factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Factor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_27Factor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_26Factor, "From Giac's documentation:\n        Help for Factor:\n        Factor(Expr)\n        Factors a polynomial without evaluation.\n        See also: 1/ factor 2/ ifactor 3/ normal \n        Ex1:Factor(x^4-1)\n        Ex2:Factor(x^4+12*x^3+54*x^2+108*x+81)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_27Factor = {"Factor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_27Factor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_26Factor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_27Factor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Factor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Factor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_26Factor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_26Factor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Factor", 1);

  /* "giacpy/auto-methods.pxi":177
 * 
 *         '''
 *         return GiacMethods['Factor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Fourier(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 177, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":167
 *         return GiacMethods['Ei'](self,*args)
 * 
 *      def Factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Factor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":179
 *         return GiacMethods['Factor'](self,*args)
 * 
 *      def Fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Fourier:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_29Fourier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_28Fourier, "From Giac's documentation:\n        Help for Fourier:\n        Fourier(Expr(f),Var(t),Var(omega))\n        The inert form of fourier command.\n        See also: 1/ fourier 2/ ifourier \n        Ex1: F:=Fourier(y(t),t,omega);ifourier(F)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_29Fourier = {"Fourier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_29Fourier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_28Fourier};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_29Fourier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Fourier (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Fourier", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_28Fourier(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_28Fourier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Fourier", 1);

  /* "giacpy/auto-methods.pxi":188
 * 
 *         '''
 *         return GiacMethods['Fourier'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def GF(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Fourier); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 188, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":179
 *         return GiacMethods['Factor'](self,*args)
 * 
 *      def Fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Fourier:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Fourier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":190
 *         return GiacMethods['Fourier'](self,*args)
 * 
 *      def GF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for GF:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_31GF(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_30GF, "From Giac's documentation:\n        Help for GF:\n        GF(Intg(p), Intg(n)|Minpoly,[Variable],[0|undef|Poly])\n        Creates a Galois Field of characteristic p with p^n elements. The minimal polynomial is primitive except if given or if 0 is passed as the last argument.\n        Ex1:GF(2,8)\n        Ex2:GF(5,9,a)\n        Ex3:GF(2,128,0)\n        Ex4:GF(2,w^8+w^7+w^5+w+1)\n        Ex5:GF(2,8,['a','G'])\n        Ex6: G:=GF(2,a^8+a^6+a^3+a^2+1,['a','G'],undef)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_31GF = {"GF", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_31GF, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_30GF};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_31GF(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("GF (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "GF", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_30GF(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_30GF(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("GF", 1);

  /* "giacpy/auto-methods.pxi":203
 * 
 *         '''
 *         return GiacMethods['GF'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Gamma(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_GF); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 203, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":190
 *         return GiacMethods['Fourier'](self,*args)
 * 
 *      def GF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for GF:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.GF", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":205
 *         return GiacMethods['GF'](self,*args)
 * 
 *      def Gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Gamma:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_33Gamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_32Gamma, "From Giac's documentation:\n        Help for Gamma:\n        Gamma(Real(a),[Real(b)])\n        Calculates Gamma at a point a (Gamma(n+1)=n! for n integer) if a>0, Gamma(a)=int(e^{-t}*t^{a-1},t=0..inf)) and Gamma(a)=Gamma(a+1)/a and Gamma(a,b)=ugamma(a,b).\n        See also: 1/ Psi 2/ Beta 3/ ugamma 4/ igamma \n        Ex1:Gamma(5)\n        Ex2:Gamma(1/2)\n        Ex3:Gamma(gamma(-5.1))\n        Ex4:Gamma(-5.1,2.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_33Gamma = {"Gamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_33Gamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_32Gamma};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_33Gamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Gamma (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Gamma", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_32Gamma(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_32Gamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Gamma", 1);

  /* "giacpy/auto-methods.pxi":217
 * 
 *         '''
 *         return GiacMethods['Gamma'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Heaviside(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Gamma); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 217, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":205
 *         return GiacMethods['GF'](self,*args)
 * 
 *      def Gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Gamma:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Gamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":219
 *         return GiacMethods['Gamma'](self,*args)
 * 
 *      def Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_35Heaviside(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_34Heaviside, "From Giac's documentation:\n        Help for Heaviside:\n        Heaviside(Real)\n        Function equal to 0 if x<0 and 1 if x>=0.\n        See also: 1/ Dirac 2/ laplace \n        Ex1:Heaviside(1)\n        Ex2:Heaviside(-1)\n        Ex3:Heaviside(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_35Heaviside = {"Heaviside", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_35Heaviside, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_34Heaviside};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_35Heaviside(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Heaviside (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Heaviside", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_34Heaviside(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_34Heaviside(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Heaviside", 1);

  /* "giacpy/auto-methods.pxi":230
 * 
 *         '''
 *         return GiacMethods['Heaviside'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Heaviside2sign(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Heaviside); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 230, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":219
 *         return GiacMethods['Gamma'](self,*args)
 * 
 *      def Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Heaviside", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":232
 *         return GiacMethods['Heaviside'](self,*args)
 * 
 *      def Heaviside2sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside2sign:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_37Heaviside2sign(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_36Heaviside2sign, "From Giac's documentation:\n        Help for Heaviside2sign:\n        Heaviside2sign(Expr)\n        Replaces Heaviside function by sign function in an expression.\n        See also: 1/ sign 2/ Heaviside 3/ sign2Heaviside 4/ simpd \n        Ex1:Heaviside2sign(Heaviside(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_37Heaviside2sign = {"Heaviside2sign", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_37Heaviside2sign, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_36Heaviside2sign};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_37Heaviside2sign(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Heaviside2sign (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Heaviside2sign", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_36Heaviside2sign(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_36Heaviside2sign(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Heaviside2sign", 1);

  /* "giacpy/auto-methods.pxi":241
 * 
 *         '''
 *         return GiacMethods['Heaviside2sign'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Hilbert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Heaviside2sign); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 241, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":232
 *         return GiacMethods['Heaviside'](self,*args)
 * 
 *      def Heaviside2sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside2sign:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Heaviside2sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":243
 *         return GiacMethods['Heaviside2sign'](self,*args)
 * 
 *      def Hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Hilbert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_39Hilbert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_38Hilbert, "From Giac's documentation:\n        Help for Hilbert:\n        Hilbert(Expr(f),Var(x))\n        The inert form of hilbert command.\n        See also: 1/ hilbert \n        Ex1:Hilbert(y(x),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_39Hilbert = {"Hilbert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_39Hilbert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_38Hilbert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_39Hilbert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Hilbert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Hilbert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_38Hilbert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_38Hilbert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Hilbert", 1);

  /* "giacpy/auto-methods.pxi":252
 * 
 *         '''
 *         return GiacMethods['Hilbert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def JordanBlock(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Hilbert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 252, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":243
 *         return GiacMethods['Heaviside2sign'](self,*args)
 * 
 *      def Hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Hilbert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Hilbert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":254
 *         return GiacMethods['Hilbert'](self,*args)
 * 
 *      def JordanBlock(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for JordanBlock:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_41JordanBlock(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_40JordanBlock, "From Giac's documentation:\n        Help for JordanBlock:\n        JordanBlock(Expr(a),Intg(n))\n        Returns an n*n matrix with a on the diagonal, 1 above and 0 everywhere else.\n        See also: 1/ jordan \n        Ex1:JordanBlock(7,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_41JordanBlock = {"JordanBlock", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_41JordanBlock, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_40JordanBlock};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_41JordanBlock(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("JordanBlock (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "JordanBlock", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_40JordanBlock(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_40JordanBlock(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("JordanBlock", 1);

  /* "giacpy/auto-methods.pxi":263
 * 
 *         '''
 *         return GiacMethods['JordanBlock'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def LU(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_JordanBlock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 263, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":254
 *         return GiacMethods['Hilbert'](self,*args)
 * 
 *      def JordanBlock(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for JordanBlock:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.JordanBlock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":265
 *         return GiacMethods['JordanBlock'](self,*args)
 * 
 *      def LU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LU:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_43LU(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_42LU, "From Giac's documentation:\n        Help for LU:\n        LU(Mtrx(A),Var(L),Var(U),Var(P))\n        For a numerical matrix A, stores in L a lower triangular matrix, in U an upper triangular  matrix and in P a permutation matrix such that P*A=L*U.\n        See also: 1/ lu 2/ QR \n        Ex1:LU([[1,2],[3,4]],L,U,P)\n        Ex2:LU([[6,12,18],[5,14,31],[3,8,18]],L,U,P)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_43LU = {"LU", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_43LU, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_42LU};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_43LU(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("LU (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "LU", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_42LU(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_42LU(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("LU", 1);

  /* "giacpy/auto-methods.pxi":275
 * 
 *         '''
 *         return GiacMethods['LU'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def LambertW(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_LU); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 275, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":265
 *         return GiacMethods['JordanBlock'](self,*args)
 * 
 *      def LU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LU:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.LU", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":277
 *         return GiacMethods['LU'](self,*args)
 * 
 *      def LambertW(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LambertW:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_45LambertW(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_44LambertW, "From Giac's documentation:\n        Help for LambertW:\n        LambertW(Real(x),[Intg(n)])\n        Returns a solution for t of t*exp(t)=x\n        Ex1:LambertW(1.0)\n        Ex2:LambertW(ln(4))\n        Ex3:LambertW(-0.1,-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_45LambertW = {"LambertW", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_45LambertW, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_44LambertW};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_45LambertW(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("LambertW (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "LambertW", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_44LambertW(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_44LambertW(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("LambertW", 1);

  /* "giacpy/auto-methods.pxi":287
 * 
 *         '''
 *         return GiacMethods['LambertW'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Li(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_LambertW); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 287, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":277
 *         return GiacMethods['LU'](self,*args)
 * 
 *      def LambertW(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LambertW:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.LambertW", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":289
 *         return GiacMethods['LambertW'](self,*args)
 * 
 *      def Li(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Li:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_47Li(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_46Li, "From Giac's documentation:\n        Help for Li:\n        Li(Expr)\n        Logarithm integral Li(x)=Ei(ln(x)) primitive of 1/ln(x).\n        See also: 1/ Si 2/ Ci 3/ Ei \n        Ex1:Li(2.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_47Li = {"Li", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_47Li, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_46Li};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_47Li(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Li (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Li", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_46Li(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_46Li(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Li", 1);

  /* "giacpy/auto-methods.pxi":298
 * 
 *         '''
 *         return GiacMethods['Li'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Li); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 298, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":289
 *         return GiacMethods['LambertW'](self,*args)
 * 
 *      def Li(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Li:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Li", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":300
 *         return GiacMethods['Li'](self,*args)
 * 
 *      def Line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_49Line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_48Line, "From Giac's documentation:\n        Help for Line:\n        Line(Expr(a),Expr(b),Expr(c),Expr(d))\n        Draws the segment [a+i*b,c+i*d].\n        See also: 1/ segment \n        Ex1:Line(-1,-2,1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_49Line = {"Line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_49Line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_48Line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_49Line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_48Line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_48Line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Line", 1);

  /* "giacpy/auto-methods.pxi":309
 * 
 *         '''
 *         return GiacMethods['Line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def LineHorz(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 309, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":300
 *         return GiacMethods['Li'](self,*args)
 * 
 *      def Line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":311
 *         return GiacMethods['Line'](self,*args)
 * 
 *      def LineHorz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineHorz:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_51LineHorz(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_50LineHorz, "From Giac's documentation:\n        Help for LineHorz:\n        LineHorz(Expr(a))\n        Draws the horizontal line y=a.\n        See also: 1/ Line 2/ LineVert \n        Ex1:LineHorz(-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_51LineHorz = {"LineHorz", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_51LineHorz, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_50LineHorz};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_51LineHorz(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("LineHorz (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "LineHorz", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_50LineHorz(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_50LineHorz(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("LineHorz", 1);

  /* "giacpy/auto-methods.pxi":320
 * 
 *         '''
 *         return GiacMethods['LineHorz'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def LineTan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_LineHorz); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 320, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":311
 *         return GiacMethods['Line'](self,*args)
 * 
 *      def LineHorz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineHorz:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.LineHorz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":322
 *         return GiacMethods['LineHorz'](self,*args)
 * 
 *      def LineTan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineTan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_53LineTan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_52LineTan, "From Giac's documentation:\n        Help for LineTan:\n        LineTan(Expr(f(x)),[Var],Expr(a))\n        Draws the tangent to y=f(x) at x=a. Do not use parentheses or put the parenthesis around the entire expression.\n        See also: 1/ tangent 2/ droite_tangente \n        Ex1: LineTan sin(x),pi/4\n        Ex2: LineTan sin(t),t=pi/4)\n        Ex3: LineTan sin(t),t,pi/4\n        Ex4: LineTan x^2-x,1\n        Ex5: (LineTan sin(t),t,pi/4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_53LineTan = {"LineTan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_53LineTan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_52LineTan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_53LineTan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("LineTan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "LineTan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_52LineTan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_52LineTan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("LineTan", 1);

  /* "giacpy/auto-methods.pxi":335
 * 
 *         '''
 *         return GiacMethods['LineTan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def LineVert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_LineTan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 335, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":322
 *         return GiacMethods['LineHorz'](self,*args)
 * 
 *      def LineTan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineTan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.LineTan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":337
 *         return GiacMethods['LineTan'](self,*args)
 * 
 *      def LineVert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineVert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_55LineVert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_54LineVert, "From Giac's documentation:\n        Help for LineVert:\n        LineVert(Expr(a))\n        Draws the vertical line x=a.\n        See also: 1/ Line 2/ LineHorz \n        Ex1:LineVert(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_55LineVert = {"LineVert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_55LineVert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_54LineVert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_55LineVert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("LineVert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "LineVert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_54LineVert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_54LineVert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("LineVert", 1);

  /* "giacpy/auto-methods.pxi":346
 * 
 *         '''
 *         return GiacMethods['LineVert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def MSE(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_LineVert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 346, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":337
 *         return GiacMethods['LineTan'](self,*args)
 * 
 *      def LineVert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineVert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.LineVert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":348
 *         return GiacMethods['LineVert'](self,*args)
 * 
 *      def MSE(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for MSE:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_57MSE(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_56MSE, "From Giac's documentation:\n        Help for MSE:\n        MSE(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_57MSE = {"MSE", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_57MSE, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_56MSE};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_57MSE(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("MSE (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "MSE", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_56MSE(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_56MSE(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("MSE", 1);

  /* "giacpy/auto-methods.pxi":356
 * 
 *         '''
 *         return GiacMethods['MSE'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Phi(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_MSE); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 356, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":348
 *         return GiacMethods['LineVert'](self,*args)
 * 
 *      def MSE(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for MSE:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.MSE", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":358
 *         return GiacMethods['MSE'](self,*args)
 * 
 *      def Phi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Phi:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_59Phi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_58Phi, "From Giac's documentation:\n        Help for Phi:\n        Phi(Intg(n))\n        Euler's function (euler(n)=card({p<n,gcd(n,p)=1})).\n        See also: 1/ gcd \n        Ex1:Phi(11)\n        Ex2:Phi(6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_59Phi = {"Phi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_59Phi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_58Phi};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_59Phi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Phi (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Phi", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_58Phi(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_58Phi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Phi", 1);

  /* "giacpy/auto-methods.pxi":368
 * 
 *         '''
 *         return GiacMethods['Phi'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Pi(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Phi); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 368, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":358
 *         return GiacMethods['MSE'](self,*args)
 * 
 *      def Phi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Phi:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Phi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":370
 *         return GiacMethods['Phi'](self,*args)
 * 
 *      def Pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Pi:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_61Pi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_60Pi, "From Giac's documentation:\n        Help for Pi:\n        Pi()\n        pi.\n        See also: 1/ e 2/ i \n        Ex1: pi/4\n        Ex2: Pi/4\n        Ex3: evalf(pi)\n        Ex4: evalf(Pi)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_61Pi = {"Pi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_61Pi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_60Pi};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_61Pi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Pi (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Pi", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_60Pi(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_60Pi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Pi", 1);

  /* "giacpy/auto-methods.pxi":382
 * 
 *         '''
 *         return GiacMethods['Pi'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Psi(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Pi); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 382, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":370
 *         return GiacMethods['Phi'](self,*args)
 * 
 *      def Pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Pi:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Pi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":384
 *         return GiacMethods['Pi'](self,*args)
 * 
 *      def Psi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Psi:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_63Psi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_62Psi, "From Giac's documentation:\n        Help for Psi:\n        Psi(Real(a),Intg(n))\n        Psi(a,n)=n-th derivative of the function DiGamma (=ln@Gamma) at point a (Psi(a,0)=Psi(a)).\n        See also: 1/ Gamma \n        Ex1:Psi(3,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_63Psi = {"Psi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_63Psi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_62Psi};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_63Psi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Psi (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Psi", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_62Psi(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_62Psi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Psi", 1);

  /* "giacpy/auto-methods.pxi":393
 * 
 *         '''
 *         return GiacMethods['Psi'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def QR(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Psi); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 393, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":384
 *         return GiacMethods['Pi'](self,*args)
 * 
 *      def Psi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Psi:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Psi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":395
 *         return GiacMethods['Psi'](self,*args)
 * 
 *      def QR(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for QR:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_65QR(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_64QR, "From Giac's documentation:\n        Help for QR:\n        QR(Mtrx,Var(Q),Var(R),[Real(eps)])\n        For a numerical matrix A, stores in Q a orthogonal matrix and in U a lower triangular matrix such that A=Q*R [replacing by 0 the elements such that abs(el)<eps].\n        See also: 1/ qr 2/ LU \n        Ex1:QR([[1,2],[3,4]],Q,R)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_65QR = {"QR", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_65QR, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_64QR};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_65QR(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("QR (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "QR", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_64QR(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_64QR(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("QR", 1);

  /* "giacpy/auto-methods.pxi":404
 * 
 *         '''
 *         return GiacMethods['QR'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def RandSeed(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_QR); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 404, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":395
 *         return GiacMethods['Psi'](self,*args)
 * 
 *      def QR(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for QR:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.QR", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":406
 *         return GiacMethods['QR'](self,*args)
 * 
 *      def RandSeed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for RandSeed:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_67RandSeed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_66RandSeed, "From Giac's documentation:\n        Help for RandSeed:\n        RandSeed(Intg)\n        Initializes random numbers.\n        See also: 1/ srand \n        Ex1:RandSeed(321)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_67RandSeed = {"RandSeed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_67RandSeed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_66RandSeed};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_67RandSeed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("RandSeed (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "RandSeed", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_66RandSeed(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_66RandSeed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("RandSeed", 1);

  /* "giacpy/auto-methods.pxi":415
 * 
 *         '''
 *         return GiacMethods['RandSeed'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ReLU(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_RandSeed); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 415, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":406
 *         return GiacMethods['QR'](self,*args)
 * 
 *      def RandSeed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for RandSeed:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.RandSeed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":417
 *         return GiacMethods['RandSeed'](self,*args)
 * 
 *      def ReLU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ReLU:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_69ReLU(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_68ReLU, "From Giac's documentation:\n        Help for ReLU:\n        ReLU(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_69ReLU = {"ReLU", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_69ReLU, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_68ReLU};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_69ReLU(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ReLU (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ReLU", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_68ReLU(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_68ReLU(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ReLU", 1);

  /* "giacpy/auto-methods.pxi":425
 * 
 *         '''
 *         return GiacMethods['ReLU'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Row(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ReLU); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 425, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":417
 *         return GiacMethods['RandSeed'](self,*args)
 * 
 *      def ReLU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ReLU:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ReLU", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":427
 *         return GiacMethods['ReLU'](self,*args)
 * 
 *      def Row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Row:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_71Row(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_70Row, "From Giac's documentation:\n        Help for Row:\n        Row(NULL)\n        Returns the index of the row of the lightened cell in the matrixwriter.\n        See also: 1/ Col \n        Ex1:Row()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_71Row = {"Row", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_71Row, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_70Row};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_71Row(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Row (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Row", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_70Row(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_70Row(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Row", 1);

  /* "giacpy/auto-methods.pxi":436
 * 
 *         '''
 *         return GiacMethods['Row'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def SortA(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Row); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 436, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":427
 *         return GiacMethods['ReLU'](self,*args)
 * 
 *      def Row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Row:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Row", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":438
 *         return GiacMethods['Row'](self,*args)
 * 
 *      def SortA(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortA:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_73SortA(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_72SortA, "From Giac's documentation:\n        Help for SortA:\n        SortA(LstReal||Seq||Mtrx)\n        Sorts the lists in increasing order (like TI).\n        See also: 1/ SortD 2/ sorta 3/ sort \n        Ex1: SortA [3,4,2]\n        Ex2: SortA 3,4,2\n        Ex3: SortA [3,4,2],[6,4,5]\n        Ex4: SortA [[3,4,2],[6,4,5]]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_73SortA = {"SortA", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_73SortA, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_72SortA};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_73SortA(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("SortA (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "SortA", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_72SortA(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_72SortA(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("SortA", 1);

  /* "giacpy/auto-methods.pxi":450
 * 
 *         '''
 *         return GiacMethods['SortA'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def SortD(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_SortA); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 450, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":438
 *         return GiacMethods['Row'](self,*args)
 * 
 *      def SortA(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortA:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.SortA", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":452
 *         return GiacMethods['SortA'](self,*args)
 * 
 *      def SortD(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortD:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_75SortD(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_74SortD, "From Giac's documentation:\n        Help for SortD:\n        SortD(LstReal||Seq||Mtrx)\n        Sorts the list in decreasing order (like TI).\n        See also: 1/ SortA 2/ sortd 3/ sort \n        Ex1: SortD [3,4,2]\n        Ex2: SortD 3,4,2\n        Ex3: SortD [[3,4,2],[6,4,5]]\n        Ex4: SortD [3,4,2],[6,4,5]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_75SortD = {"SortD", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_75SortD, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_74SortD};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_75SortD(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("SortD (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "SortD", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_74SortD(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_74SortD(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("SortD", 1);

  /* "giacpy/auto-methods.pxi":464
 * 
 *         '''
 *         return GiacMethods['SortD'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def UTPC(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_SortD); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 464, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":452
 *         return GiacMethods['SortA'](self,*args)
 * 
 *      def SortD(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortD:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.SortD", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":466
 *         return GiacMethods['SortD'](self,*args)
 * 
 *      def UTPC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPC:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_77UTPC(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_76UTPC, "From Giac's documentation:\n        Help for UTPC:\n        UTPC(Intg(n),Real(x0))\n        Returns the probability that a Chisquare random variable is greater than x0 (n is the number of degrees of freedom).\n        See also: 1/ chisquare_cdf 2/ chisquare_icdf \n        Ex1:UTPC(2,6.1)\n        Ex2:UTPC(4,6.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_77UTPC = {"UTPC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_77UTPC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_76UTPC};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_77UTPC(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("UTPC (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "UTPC", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_76UTPC(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_76UTPC(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("UTPC", 1);

  /* "giacpy/auto-methods.pxi":476
 * 
 *         '''
 *         return GiacMethods['UTPC'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def UTPF(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_UTPC); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 476, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":466
 *         return GiacMethods['SortD'](self,*args)
 * 
 *      def UTPC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPC:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.UTPC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":478
 *         return GiacMethods['UTPC'](self,*args)
 * 
 *      def UTPF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPF:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_79UTPF(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_78UTPF, "From Giac's documentation:\n        Help for UTPF:\n        UTPF(Intg(n),Intg(d),Real(x0))\n        Returns the probability that a Fisher-Snedecor random variable is greater than x0 (n and d are the numbers of degrees of freedom).\n        See also: 1/ fisher_cdf 2/ fisher_icdf \n        Ex1:UTPF(4,10,3.5)\n        Ex2:UTPF(4,4,2.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_79UTPF = {"UTPF", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_79UTPF, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_78UTPF};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_79UTPF(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("UTPF (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "UTPF", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_78UTPF(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_78UTPF(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("UTPF", 1);

  /* "giacpy/auto-methods.pxi":488
 * 
 *         '''
 *         return GiacMethods['UTPF'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def UTPN(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_UTPF); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 488, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":478
 *         return GiacMethods['UTPC'](self,*args)
 * 
 *      def UTPF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPF:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.UTPF", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":490
 *         return GiacMethods['UTPF'](self,*args)
 * 
 *      def UTPN(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPN:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_81UTPN(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_80UTPN, "From Giac's documentation:\n        Help for UTPN:\n        UTPN(Real(mu),Real(v),Real(x0))\n        Returns the probability that a Normal random variable is greater than x0 (mu is the mean and v the variance).\n        See also: 1/ normal_cdf 2/ normal_icdf \n        Ex1:UTPN(1.96)\n        Ex2:UTPN(1,4,2.96)+normal_cdf(1,2,2.96)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_81UTPN = {"UTPN", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_81UTPN, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_80UTPN};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_81UTPN(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("UTPN (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "UTPN", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_80UTPN(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_80UTPN(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("UTPN", 1);

  /* "giacpy/auto-methods.pxi":500
 * 
 *         '''
 *         return GiacMethods['UTPN'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def UTPT(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_UTPN); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 500, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":490
 *         return GiacMethods['UTPF'](self,*args)
 * 
 *      def UTPN(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPN:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.UTPN", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":502
 *         return GiacMethods['UTPN'](self,*args)
 * 
 *      def UTPT(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPT:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_83UTPT(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_82UTPT, "From Giac's documentation:\n        Help for UTPT:\n        UTPT(Intg(n),Real(x0))\n        Returns the probability that a Student random variable is greater than x0 (n is the number of degrees of freedom).\n        See also: 1/ student_cdf 2/ student_icdf \n        Ex1:UTPT(3,2.35)\n        Ex2:UTPT(3,-2.35)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_83UTPT = {"UTPT", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_83UTPT, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_82UTPT};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_83UTPT(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("UTPT (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "UTPT", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_82UTPT(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_82UTPT(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("UTPT", 1);

  /* "giacpy/auto-methods.pxi":512
 * 
 *         '''
 *         return GiacMethods['UTPT'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def VARS(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_UTPT); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 512, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":502
 *         return GiacMethods['UTPN'](self,*args)
 * 
 *      def UTPT(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPT:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.UTPT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":514
 *         return GiacMethods['UTPT'](self,*args)
 * 
 *      def VARS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VARS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_85VARS(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_84VARS, "From Giac's documentation:\n        Help for VARS:\n        VARS(NULL)\n        List of the variables and folders of the current directory.\n        See also: 1/ lvar \n        Ex1:VARS()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_85VARS = {"VARS", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_85VARS, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_84VARS};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_85VARS(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("VARS (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "VARS", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_84VARS(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_84VARS(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("VARS", 1);

  /* "giacpy/auto-methods.pxi":523
 * 
 *         '''
 *         return GiacMethods['VARS'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def VAS(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_VARS); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 523, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":514
 *         return GiacMethods['UTPT'](self,*args)
 * 
 *      def VARS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VARS:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.VARS", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":525
 *         return GiacMethods['VARS'](self,*args)
 * 
 *      def VAS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_87VAS(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_86VAS, "From Giac's documentation:\n        Help for VAS:\n        VAS(Poly(P))\n        Returns a list of intervals containing the real roots of P. Vincent-Akritas-Strzebonski's method (VAS) is used.\n        See also: 1/ VAS_positive 2/ sturmab 3/ realroot \n        Ex1:VAS(x^3-7*x+7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_87VAS = {"VAS", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_87VAS, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_86VAS};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_87VAS(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("VAS (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "VAS", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_86VAS(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_86VAS(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("VAS", 1);

  /* "giacpy/auto-methods.pxi":534
 * 
 *         '''
 *         return GiacMethods['VAS'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def VAS_positive(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_VAS); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 534, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":525
 *         return GiacMethods['VARS'](self,*args)
 * 
 *      def VAS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.VAS", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":536
 *         return GiacMethods['VAS'](self,*args)
 * 
 *      def VAS_positive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS_positive:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_89VAS_positive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_88VAS_positive, "From Giac's documentation:\n        Help for VAS_positive:\n        VAS_positive(Poly(P))\n        Returns a list of intervals containing the positive roots of P. Vincent-Akritas-Strzebonski's method (VAS) is used.\n        See also: 1/ poslbdLMQ 2/ posubLMQ 3/ VAS 4/ realroot \n        Ex1:VAS_positive(x^3-7*x+7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_89VAS_positive = {"VAS_positive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_89VAS_positive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_88VAS_positive};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_89VAS_positive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("VAS_positive (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "VAS_positive", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_88VAS_positive(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_88VAS_positive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("VAS_positive", 1);

  /* "giacpy/auto-methods.pxi":545
 * 
 *         '''
 *         return GiacMethods['VAS_positive'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def Zeta(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_VAS_positive); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 545, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":536
 *         return GiacMethods['VAS'](self,*args)
 * 
 *      def VAS_positive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS_positive:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.VAS_positive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":547
 *         return GiacMethods['VAS_positive'](self,*args)
 * 
 *      def Zeta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Zeta:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_91Zeta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_90Zeta, "From Giac's documentation:\n        Help for Zeta:\n        Zeta(Real(a))\n        Returns if a>1 sum(1/n^a,n,1,+infinity).\n        See also: 1/ sum \n        Ex1:Zeta(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_91Zeta = {"Zeta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_91Zeta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_90Zeta};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_91Zeta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Zeta (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Zeta", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_90Zeta(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_90Zeta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Zeta", 1);

  /* "giacpy/auto-methods.pxi":556
 * 
 *         '''
 *         return GiacMethods['Zeta'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def a2q(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_Zeta); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 556, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":547
 *         return GiacMethods['VAS_positive'](self,*args)
 * 
 *      def Zeta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Zeta:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.Zeta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":558
 *         return GiacMethods['Zeta'](self,*args)
 * 
 *      def a2q(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for a2q:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_93a2q(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_92a2q, "From Giac's documentation:\n        Help for a2q:\n        a2q(Mtrx,VectVar)\n        a2q(A,X)=the quadratic form q associated to A, X=vector of variables.\n        See also: 1/ q2a \n        Ex1:a2q([[1,2],[4,4]],[x,y])\n        Ex2:a2q([[1,3],[3,4]],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_93a2q = {"a2q", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_93a2q, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_92a2q};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_93a2q(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("a2q (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "a2q", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_92a2q(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_92a2q(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("a2q", 1);

  /* "giacpy/auto-methods.pxi":568
 * 
 *         '''
 *         return GiacMethods['a2q'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def abcuv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_a2q); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 568, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":558
 *         return GiacMethods['Zeta'](self,*args)
 * 
 *      def a2q(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for a2q:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.a2q", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":570
 *         return GiacMethods['a2q'](self,*args)
 * 
 *      def abcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abcuv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_95abcuv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_94abcuv, "From Giac's documentation:\n        Help for abcuv:\n        abcuv(Poly(a),Poly(b),Poly(c),[Var])\n        Returns [u,v] such that au+bv=c for 3 polynomials a,b,c.\n        See also: 1/ egcd 2/ iabcuv \n        Ex1:abcuv(x^2+2*x+1,x^2-1,x+1)\n        Ex2:abcuv(X^2+2*X+1,X^2-1,X+1,X)\n        Ex3:abcuv(x^2+2*x+1,x^2-1,x^3+1)\n        Ex4:abcuv(X^2+2*X+1,X^2-1,X^3+1,X)\n        Ex5:abcuv([1,2,1],[1,0,-1],[1,0,0,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_95abcuv = {"abcuv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_95abcuv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_94abcuv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_95abcuv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abcuv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "abcuv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_94abcuv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_94abcuv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("abcuv", 1);

  /* "giacpy/auto-methods.pxi":583
 * 
 *         '''
 *         return GiacMethods['abcuv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def about(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_abcuv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 583, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":570
 *         return GiacMethods['a2q'](self,*args)
 * 
 *      def abcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abcuv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.abcuv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":585
 *         return GiacMethods['abcuv'](self,*args)
 * 
 *      def about(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for about:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_97about(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_96about, "From Giac's documentation:\n        Help for about:\n        about(Var(a)||Image||Audio)\n        Returns the hypothesis made with assume on the variable a or describes an image object or an audio clip.\n        See also: 1/ assume 2/ purge \n        Ex1:about(a)\n        Ex2:about(n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_97about = {"about", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_97about, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_96about};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_97about(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("about (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "about", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_96about(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_96about(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("about", 1);

  /* "giacpy/auto-methods.pxi":595
 * 
 *         '''
 *         return GiacMethods['about'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def abs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_about); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 595, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":585
 *         return GiacMethods['abcuv'](self,*args)
 * 
 *      def about(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for about:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.about", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":597
 *         return GiacMethods['about'](self,*args)
 * 
 *      def abs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_99abs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_98abs, "From Giac's documentation:\n        Help for abs:\n        abs(Cplx||LstCplx)\n        Returns the absolute value or the norm of its argument.\n        See also: 1/ arg \n        Ex1:abs(-4)\n        Ex2:abs(1+2*i)\n        Ex3:abs((1+2*i)^2)\n        Ex4:abs([-2,1+i,-4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_99abs = {"abs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_99abs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_98abs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_99abs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "abs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_98abs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_98abs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("abs", 1);

  /* "giacpy/auto-methods.pxi":609
 * 
 *         '''
 *         return GiacMethods['abs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def abscissa(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_abs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 609, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":597
 *         return GiacMethods['about'](self,*args)
 * 
 *      def abs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.abs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":611
 *         return GiacMethods['abs'](self,*args)
 * 
 *      def abscissa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abscissa:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_101abscissa(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_100abscissa, "From Giac's documentation:\n        Help for abscissa:\n        abscissa(Pnt or Vect)\n        Returns the abscissa of a point or a vector.\n        See also: 1/ ordinate 2/ affix 3/ cote 4/ coordinates \n        Ex1:abscissa(point(1+2*i))\n        Ex2:abscissa(point(i)-point(1+2*i))\n        Ex3:abscissa(-1-i)\n        Ex4:abscissa(point(1,2,3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_101abscissa = {"abscissa", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_101abscissa, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_100abscissa};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_101abscissa(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abscissa (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "abscissa", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_100abscissa(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_100abscissa(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("abscissa", 1);

  /* "giacpy/auto-methods.pxi":623
 * 
 *         '''
 *         return GiacMethods['abscissa'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def accumulate_head_tail(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_abscissa); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 623, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":611
 *         return GiacMethods['abs'](self,*args)
 * 
 *      def abscissa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abscissa:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.abscissa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":625
 *         return GiacMethods['abscissa'](self,*args)
 * 
 *      def accumulate_head_tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for accumulate_head_tail:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_103accumulate_head_tail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_102accumulate_head_tail, "From Giac's documentation:\n        Help for accumulate_head_tail:\n        accumulate_head_tail(Lst(l),Intg(p),Intg(q))\n        Returns the list where the first p and the last q elements of l are replaced by their sum.\n        See also: 1/  \n        Ex1:accumulate_head_tail([0,1,2,3,4,5,6,7,8,9],3,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_103accumulate_head_tail = {"accumulate_head_tail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_103accumulate_head_tail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_102accumulate_head_tail};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_103accumulate_head_tail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("accumulate_head_tail (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "accumulate_head_tail", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_102accumulate_head_tail(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_102accumulate_head_tail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("accumulate_head_tail", 1);

  /* "giacpy/auto-methods.pxi":634
 * 
 *         '''
 *         return GiacMethods['accumulate_head_tail'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_accumulate_head_tail); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 634, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":625
 *         return GiacMethods['abscissa'](self,*args)
 * 
 *      def accumulate_head_tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for accumulate_head_tail:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.accumulate_head_tail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":636
 *         return GiacMethods['accumulate_head_tail'](self,*args)
 * 
 *      def acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_105acos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_104acos, "From Giac's documentation:\n        Help for acos:\n        acos(Expr)\n        Arccosine.\n        See also: 1/ cos 2/ acosh \n        Ex1:acos(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_105acos = {"acos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_105acos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_104acos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_105acos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_104acos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_104acos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acos", 1);

  /* "giacpy/auto-methods.pxi":645
 * 
 *         '''
 *         return GiacMethods['acos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acos2asin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 645, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":636
 *         return GiacMethods['accumulate_head_tail'](self,*args)
 * 
 *      def acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":647
 *         return GiacMethods['acos'](self,*args)
 * 
 *      def acos2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2asin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_107acos2asin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_106acos2asin, "From Giac's documentation:\n        Help for acos2asin:\n        acos2asin(Expr)\n        Replaces arccos(x) by pi/2-arcsin(x) in the argument.\n        See also: 1/ acos2atan \n        Ex1:acos2asin(acos(x)+asin(x))\n        Ex2:acos2asin(2*acos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_107acos2asin = {"acos2asin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_107acos2asin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_106acos2asin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_107acos2asin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acos2asin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acos2asin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_106acos2asin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_106acos2asin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acos2asin", 1);

  /* "giacpy/auto-methods.pxi":657
 * 
 *         '''
 *         return GiacMethods['acos2asin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acos2atan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acos2asin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 657, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":647
 *         return GiacMethods['acos'](self,*args)
 * 
 *      def acos2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2asin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acos2asin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":659
 *         return GiacMethods['acos2asin'](self,*args)
 * 
 *      def acos2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2atan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_109acos2atan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_108acos2atan, "From Giac's documentation:\n        Help for acos2atan:\n        acos2atan(Expr)\n        Replaces arccos(x) by pi/2-arctan(x/sqrt(1-x^2)) in the argument.\n        See also: 1/ acos2asin \n        Ex1:acos2atan(2*acos(x))\n        Ex2:acos2atan(acos(sqrt(1-x^2))+acos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_109acos2atan = {"acos2atan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_109acos2atan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_108acos2atan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_109acos2atan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acos2atan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acos2atan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_108acos2atan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_108acos2atan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acos2atan", 1);

  /* "giacpy/auto-methods.pxi":669
 * 
 *         '''
 *         return GiacMethods['acos2atan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acosh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acos2atan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 669, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":659
 *         return GiacMethods['acos2asin'](self,*args)
 * 
 *      def acos2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2atan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acos2atan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":671
 *         return GiacMethods['acos2atan'](self,*args)
 * 
 *      def acosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acosh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_111acosh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_110acosh, "From Giac's documentation:\n        Help for acosh:\n        acosh(Expr)\n        Hyperbolic arccosine.\n        See also: 1/ cosh 2/ acos \n        Ex1:acosh(1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_111acosh = {"acosh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_111acosh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_110acosh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_111acosh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acosh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acosh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_110acosh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_110acosh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acosh", 1);

  /* "giacpy/auto-methods.pxi":680
 * 
 *         '''
 *         return GiacMethods['acosh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acosh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 680, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":671
 *         return GiacMethods['acos2atan'](self,*args)
 * 
 *      def acosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acosh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acosh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":682
 *         return GiacMethods['acosh'](self,*args)
 * 
 *      def acot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_113acot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_112acot, "From Giac's documentation:\n        Help for acot:\n        acot(Expr)\n        Arccotangent.\n        See also: 1/ atan 2/ arccos \n        Ex1:acot(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_113acot = {"acot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_113acot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_112acot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_113acot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_112acot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_112acot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acot", 1);

  /* "giacpy/auto-methods.pxi":691
 * 
 *         '''
 *         return GiacMethods['acot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acsc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 691, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":682
 *         return GiacMethods['acosh'](self,*args)
 * 
 *      def acot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":693
 *         return GiacMethods['acot'](self,*args)
 * 
 *      def acsc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acsc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_115acsc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_114acsc, "From Giac's documentation:\n        Help for acsc:\n        acsc(Expr)\n        Arccosecant: acsc(x)=asin(1/x).\n        See also: 1/ asin 2/ csc \n        Ex1:acsc(1)\n        Ex2:acsc(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_115acsc = {"acsc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_115acsc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_114acsc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_115acsc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acsc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acsc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_114acsc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_114acsc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acsc", 1);

  /* "giacpy/auto-methods.pxi":703
 * 
 *         '''
 *         return GiacMethods['acsc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def acyclic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acsc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 703, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":693
 *         return GiacMethods['acot'](self,*args)
 * 
 *      def acsc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acsc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acsc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":705
 *         return GiacMethods['acsc'](self,*args)
 * 
 *      def acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acyclic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_117acyclic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_116acyclic, "From Giac's documentation:\n        Help for acyclic:\n        acyclic(Opt)\n        Option for the random_network command.\n        See also: 1/ random_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_117acyclic = {"acyclic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_117acyclic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_116acyclic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_117acyclic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("acyclic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "acyclic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_116acyclic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_116acyclic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("acyclic", 1);

  /* "giacpy/auto-methods.pxi":713
 * 
 *         '''
 *         return GiacMethods['acyclic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def adaptive(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_acyclic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 713, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":705
 *         return GiacMethods['acsc'](self,*args)
 * 
 *      def acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acyclic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.acyclic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":715
 *         return GiacMethods['acyclic'](self,*args)
 * 
 *      def adaptive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adaptive:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_119adaptive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_118adaptive, "From Giac's documentation:\n        Help for adaptive:\n        adaptive(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_119adaptive = {"adaptive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_119adaptive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_118adaptive};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_119adaptive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("adaptive (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "adaptive", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_118adaptive(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_118adaptive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("adaptive", 1);

  /* "giacpy/auto-methods.pxi":723
 * 
 *         '''
 *         return GiacMethods['adaptive'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def add(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_adaptive); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 723, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":715
 *         return GiacMethods['acyclic'](self,*args)
 * 
 *      def adaptive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adaptive:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.adaptive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":725
 *         return GiacMethods['adaptive'](self,*args)
 * 
 *      def add(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_121add(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_120add, "From Giac's documentation:\n        Help for add:\n        add(Expr,Var,VarMin(a),VarMax(b),[VarStep(p)])\n        Discrete sum (with 2 or 4 arguments return then sum from a to b if a<=b or of the opposite of the sum from b+1 to a-1 if a>b+1 or 0 if a=b+1) or the discrete primitive or sum of the elements of a list or a sequence.\n        See also: 1/ + \n        Ex1:add(1/n^2,n,1,17)\n        Ex2:add(1/n^2,n=1..17)\n        Ex3:add(1/n^2,n,17,1)\n        Ex4:add(1/n^2,n=17..1)\n        Ex5:add(1/n^2,n,17,1,1)\n        Ex6:add(1/n^2,n,1,17,2)\n        Ex7:add([1,2,3,4])\n        Ex8:add([[1,2,3,4,5,6,7,8,9],[1,2,3,4,5,6,7,8,9]])\n        Ex9:add(1/(x*(x+1)),x)\n        Ex10:add(cos(n*x),n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_121add = {"add", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_121add, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_120add};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_121add(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "add", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_120add(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_120add(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 1);

  /* "giacpy/auto-methods.pxi":743
 * 
 *         '''
 *         return GiacMethods['add'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def add_arc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 743, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":725
 *         return GiacMethods['adaptive'](self,*args)
 * 
 *      def add(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":745
 *         return GiacMethods['add'](self,*args)
 * 
 *      def add_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_arc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_123add_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_122add_arc, "From Giac's documentation:\n        Help for add_arc:\n        add_arc(Graph(G),Edge(e)||Trail(T)||Lst(E))\n        Returns a modified copy of a digraph G with the arc e (or trail T or list of arcs E) added to G.\n        See also: 1/ add_edge 2/ delete_arc 3/ digraph 4/ edges 5/ has_arc 6/ trail \n        Ex1:add_arc(digraph(trail(1,2,3,4,5,1)),[[1,3],[2,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_123add_arc = {"add_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_123add_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_122add_arc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_123add_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_arc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "add_arc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_122add_arc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_122add_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_arc", 1);

  /* "giacpy/auto-methods.pxi":754
 * 
 *         '''
 *         return GiacMethods['add_arc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def add_edge(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_add_arc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 754, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":745
 *         return GiacMethods['add'](self,*args)
 * 
 *      def add_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_arc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.add_arc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":756
 *         return GiacMethods['add_arc'](self,*args)
 * 
 *      def add_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_edge:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_125add_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_124add_edge, "From Giac's documentation:\n        Help for add_edge:\n        add_edge(Graph(G),Edge(e)||Trail(T)||Lst(E))\n        Returns a modified copy of an undirected graph G with the edge e (or trail T or list of edges E) added to G.\n        See also: 1/ add_arc 2/ delete_edge 3/ edges 4/ graph 5/ has_edge 6/ trail \n        Ex1:add_edge(graph(trail(1,2,3,4)),[4,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_125add_edge = {"add_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_125add_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_124add_edge};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_125add_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_edge (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "add_edge", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_124add_edge(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_124add_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_edge", 1);

  /* "giacpy/auto-methods.pxi":765
 * 
 *         '''
 *         return GiacMethods['add_edge'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def add_vertex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_add_edge); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 765, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":756
 *         return GiacMethods['add_arc'](self,*args)
 * 
 *      def add_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_edge:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.add_edge", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":767
 *         return GiacMethods['add_edge'](self,*args)
 * 
 *      def add_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_vertex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_127add_vertex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_126add_vertex, "From Giac's documentation:\n        Help for add_vertex:\n        add_vertex(Graph(G),Vrtx(v)||Lst(V))\n        Returns a modified copy of G with vertex v [or vertices from list V] added to G.\n        See also: 1/ add_arc 2/ add_edge 3/ delete_vertex \n        Ex1:add_vertex(cycle_graph(5),[\"a\",\"b\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_127add_vertex = {"add_vertex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_127add_vertex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_126add_vertex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_127add_vertex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_vertex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "add_vertex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_126add_vertex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_126add_vertex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_vertex", 1);

  /* "giacpy/auto-methods.pxi":776
 * 
 *         '''
 *         return GiacMethods['add_vertex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def additionally(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_add_vertex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 776, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":767
 *         return GiacMethods['add_edge'](self,*args)
 * 
 *      def add_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_vertex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.add_vertex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":778
 *         return GiacMethods['add_vertex'](self,*args)
 * 
 *      def additionally(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for additionally:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_129additionally(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_128additionally, "From Giac's documentation:\n        Help for additionally:\n        additionally(Expr)\n        Makes an additionally assumption on a variable.\n        See also: 1/ purge 2/ about 3/ assume \n        Ex1: assume(n,integer);additionally(n>5)\n        Ex2: assume(n,integer);assume(n>=2,additionally)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_129additionally = {"additionally", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_129additionally, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_128additionally};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_129additionally(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("additionally (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "additionally", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_128additionally(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_128additionally(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("additionally", 1);

  /* "giacpy/auto-methods.pxi":788
 * 
 *         '''
 *         return GiacMethods['additionally'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def addtable(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_additionally); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 788, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":778
 *         return GiacMethods['add_vertex'](self,*args)
 * 
 *      def additionally(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for additionally:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.additionally", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":790
 *         return GiacMethods['additionally'](self,*args)
 * 
 *      def addtable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for addtable:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_131addtable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_130addtable, "From Giac's documentation:\n        Help for addtable:\n        addtable(fourier||laplace,f(x),F(s),Var(x),Var(s))\n        Stores an unknown Fourier/Laplace transform pair (f,F).\n        See also: 1/ fourier 2/ laplace \n        Ex1:addtable(fourier,y(x),Y(s),x,s)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_131addtable = {"addtable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_131addtable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_130addtable};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_131addtable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addtable (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "addtable", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_130addtable(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_130addtable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addtable", 1);

  /* "giacpy/auto-methods.pxi":799
 * 
 *         '''
 *         return GiacMethods['addtable'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def adjacency_matrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_addtable); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 799, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":790
 *         return GiacMethods['additionally'](self,*args)
 * 
 *      def addtable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for addtable:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.addtable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":801
 *         return GiacMethods['addtable'](self,*args)
 * 
 *      def adjacency_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjacency_matrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_133adjacency_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_132adjacency_matrix, "From Giac's documentation:\n        Help for adjacency_matrix:\n        adjacency_matrix(Graph(G))\n        Returns the adjacency matrix of G (rows and columns correspond to vertex indices).\n        See also: 1/ neighbors \n        Ex1:adjacency_matrix(graph(trail(1,2,3,4,2,5,1,3)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_133adjacency_matrix = {"adjacency_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_133adjacency_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_132adjacency_matrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_133adjacency_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("adjacency_matrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "adjacency_matrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_132adjacency_matrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_132adjacency_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("adjacency_matrix", 1);

  /* "giacpy/auto-methods.pxi":810
 * 
 *         '''
 *         return GiacMethods['adjacency_matrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def adjoint_matrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_adjacency_matrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 810, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":801
 *         return GiacMethods['addtable'](self,*args)
 * 
 *      def adjacency_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjacency_matrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.adjacency_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":812
 *         return GiacMethods['adjacency_matrix'](self,*args)
 * 
 *      def adjoint_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjoint_matrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_135adjoint_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_134adjoint_matrix, "From Giac's documentation:\n        Help for adjoint_matrix:\n        adjoint_matrix(Mtrx)\n        Returns the characteristic polynomial of A and the comatrix of A-xI.\n        See also: 1/ pcar \n        Ex1:adjoint_matrix([[1,i],[2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_135adjoint_matrix = {"adjoint_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_135adjoint_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_134adjoint_matrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_135adjoint_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("adjoint_matrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "adjoint_matrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_134adjoint_matrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_134adjoint_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("adjoint_matrix", 1);

  /* "giacpy/auto-methods.pxi":821
 * 
 *         '''
 *         return GiacMethods['adjoint_matrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def affix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_adjoint_matrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 821, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":812
 *         return GiacMethods['adjacency_matrix'](self,*args)
 * 
 *      def adjoint_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjoint_matrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.adjoint_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":823
 *         return GiacMethods['adjoint_matrix'](self,*args)
 * 
 *      def affix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for affix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_137affix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_136affix, "From Giac's documentation:\n        Help for affix:\n        affix(Pnt||Vect)\n        Complex number equal to the affix of a point or of a vector.\n        See also: 1/ point 2/ vector \n        Ex1:affix(point(i))\n        Ex2:affix(point(i)-point(1+2*i))\n        Ex3:affix([1,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_137affix = {"affix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_137affix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_136affix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_137affix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("affix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "affix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_136affix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_136affix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("affix", 1);

  /* "giacpy/auto-methods.pxi":834
 * 
 *         '''
 *         return GiacMethods['affix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def algsubs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_affix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 834, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":823
 *         return GiacMethods['adjoint_matrix'](self,*args)
 * 
 *      def affix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for affix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.affix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":836
 *         return GiacMethods['affix'](self,*args)
 * 
 *      def algsubs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algsubs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_139algsubs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_138algsubs, "From Giac's documentation:\n        Help for algsubs:\n        algsubs(Equal(Xpr1=Xpr2),Expr(Xpr))\n        Substitutes in the expression Xpr, the algebraic expression Xpr1 by the algebraic expression Xpr2.\n        See also: 1/ subst 2/ subs \n        Ex1:algsubs(x^2=u,1+x^2+x^4)\n        Ex2:algsubs(a*b/c=d, 2*a*b^2/c)\n        Ex3:algsubs(2a=p^2-q^2,algsubs(2c=p^2+q^2,c^2-a^2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_139algsubs = {"algsubs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_139algsubs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_138algsubs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_139algsubs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("algsubs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "algsubs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_138algsubs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_138algsubs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("algsubs", 1);

  /* "giacpy/auto-methods.pxi":847
 * 
 *         '''
 *         return GiacMethods['algsubs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def algvar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_algsubs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 847, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":836
 *         return GiacMethods['affix'](self,*args)
 * 
 *      def algsubs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algsubs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.algsubs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":849
 *         return GiacMethods['algsubs'](self,*args)
 * 
 *      def algvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algvar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_141algvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_140algvar, "From Giac's documentation:\n        Help for algvar:\n        algvar(Expr)\n        List of the variables by ascending algebraic extension order.\n        See also: 1/ lvar 2/ lname \n        Ex1:algvar(sqrt(x)+y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_141algvar = {"algvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_141algvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_140algvar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_141algvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("algvar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "algvar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_140algvar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_140algvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("algvar", 1);

  /* "giacpy/auto-methods.pxi":858
 * 
 *         '''
 *         return GiacMethods['algvar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def all_trig_solutions(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_algvar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 858, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":849
 *         return GiacMethods['algsubs'](self,*args)
 * 
 *      def algvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algvar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.algvar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":860
 *         return GiacMethods['algvar'](self,*args)
 * 
 *      def all_trig_solutions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for all_trig_solutions:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_143all_trig_solutions(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_142all_trig_solutions, "From Giac's documentation:\n        Help for all_trig_solutions:\n        all_trig_solutions(:=Intg(0 or 1))\n        Pseudo-variable to return the general solution (all_trig_solutions:=1) or principal solution (all_trig_solutions:=0).\n        See also: 1/ cas_setup \n        Ex1: all_trig_solutions:=1\n        Ex2: all_trig_solutions:=0\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_143all_trig_solutions = {"all_trig_solutions", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_143all_trig_solutions, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_142all_trig_solutions};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_143all_trig_solutions(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("all_trig_solutions (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "all_trig_solutions", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_142all_trig_solutions(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_142all_trig_solutions(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("all_trig_solutions", 1);

  /* "giacpy/auto-methods.pxi":870
 * 
 *         '''
 *         return GiacMethods['all_trig_solutions'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def allpairs_distance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_all_trig_solutions); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 870, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":860
 *         return GiacMethods['algvar'](self,*args)
 * 
 *      def all_trig_solutions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for all_trig_solutions:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.all_trig_solutions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":872
 *         return GiacMethods['all_trig_solutions'](self,*args)
 * 
 *      def allpairs_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for allpairs_distance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_145allpairs_distance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_144allpairs_distance, "From Giac's documentation:\n        Help for allpairs_distance:\n        allpairs_distance(Graph(G))\n        Returns a square matrix D of order equal to the number of vertices in G such that D(i,j) is the distance between i-th and j-th vertex of the (weighted) graph G.\n        See also: 1/ dijkstra 2/ graph_diameter 3/ vertex_distance \n        Ex1:allpairs_distance(graph(%{[1,2],[1,3],[1,4],[1,5],[2,3],[3,4],[4,5],[5,2]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_145allpairs_distance = {"allpairs_distance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_145allpairs_distance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_144allpairs_distance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_145allpairs_distance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("allpairs_distance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "allpairs_distance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_144allpairs_distance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_144allpairs_distance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("allpairs_distance", 1);

  /* "giacpy/auto-methods.pxi":881
 * 
 *         '''
 *         return GiacMethods['allpairs_distance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def alog10(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_allpairs_distance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 881, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":872
 *         return GiacMethods['all_trig_solutions'](self,*args)
 * 
 *      def allpairs_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for allpairs_distance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.allpairs_distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":883
 *         return GiacMethods['allpairs_distance'](self,*args)
 * 
 *      def alog10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for alog10:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_147alog10(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_146alog10, "From Giac's documentation:\n        Help for alog10:\n        alog10(Expr)\n        Function x->10^x.\n        See also: 1/ log10 \n        Ex1:alog10(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_147alog10 = {"alog10", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_147alog10, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_146alog10};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_147alog10(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("alog10 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "alog10", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_146alog10(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_146alog10(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("alog10", 1);

  /* "giacpy/auto-methods.pxi":892
 * 
 *         '''
 *         return GiacMethods['alog10'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def altitude(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_alog10); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 892, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":883
 *         return GiacMethods['allpairs_distance'](self,*args)
 * 
 *      def alog10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for alog10:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.alog10", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":894
 *         return GiacMethods['alog10'](self,*args)
 * 
 *      def altitude(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for altitude:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_149altitude(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_148altitude, "From Giac's documentation:\n        Help for altitude:\n        altitude((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        altitude(A,B,C) draws the altitude through A of the triangle ABC.\n        See also: 1/ perpendicular 2/ orthogonal 3/ orthocenter 4/ common_perpendicular \n        Ex1:altitude(-1,1-i,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_149altitude = {"altitude", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_149altitude, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_148altitude};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_149altitude(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("altitude (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "altitude", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_148altitude(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_148altitude(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("altitude", 1);

  /* "giacpy/auto-methods.pxi":903
 * 
 *         '''
 *         return GiacMethods['altitude'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def angle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_altitude); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 903, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":894
 *         return GiacMethods['alog10'](self,*args)
 * 
 *      def altitude(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for altitude:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.altitude", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":905
 *         return GiacMethods['altitude'](self,*args)
 * 
 *      def angle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_151angle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_150angle, "From Giac's documentation:\n        Help for angle:\n        angle((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        angle(A,B,C) is the value of the measure of the angle (AB,AC).\n        See also: 1/ triangle 2/ bissector 3/ legend 4/ labels 5/ angleat 6/ angleatraw \n        Ex1:angle(point(0),point(i),point(1))\n        Ex2:angle(0,1,i)\n        Ex3:angle(0,1,i,\"\")\n        Ex4:angle(0,1,i,\"a\")\n        Ex5:angle(i,1,1+i,\"b\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_151angle = {"angle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_151angle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_150angle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_151angle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("angle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "angle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_150angle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_150angle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("angle", 1);

  /* "giacpy/auto-methods.pxi":918
 * 
 *         '''
 *         return GiacMethods['angle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def angle_radian(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_angle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 918, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":905
 *         return GiacMethods['altitude'](self,*args)
 * 
 *      def angle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.angle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":920
 *         return GiacMethods['angle'](self,*args)
 * 
 *      def angle_radian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle_radian:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_153angle_radian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_152angle_radian, "From Giac's documentation:\n        Help for angle_radian:\n        angle_radian(:=Intg(0 or 1))\n        Pseudo-variable to work with radians (angle_radian:=1) or degrees (angle_radian:=0).\n        See also: 1/ cas_setup \n        Ex1: angle_radian:=1\n        Ex2: angle_radian:=0\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_153angle_radian = {"angle_radian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_153angle_radian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_152angle_radian};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_153angle_radian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("angle_radian (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "angle_radian", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_152angle_radian(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_152angle_radian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("angle_radian", 1);

  /* "giacpy/auto-methods.pxi":930
 * 
 *         '''
 *         return GiacMethods['angle_radian'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def angleat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_angle_radian); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 930, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":920
 *         return GiacMethods['angle'](self,*args)
 * 
 *      def angle_radian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle_radian:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.angle_radian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":932
 *         return GiacMethods['angle_radian'](self,*args)
 * 
 *      def angleat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_155angleat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_154angleat, "From Giac's documentation:\n        Help for angleat:\n        angleat(Pnt(A),Pnt(B),Pnt(C),(Pnt or Cplx(z0)))\n        angleat(A,B,C,z0) displays at point(z0) with a legend, the value of the measure of the angle (AB,AC).\n        See also: 1/ angle 2/ angleatraw 3/ legend \n        Ex1: A:=point(0);B:=point(1);C:=point(i);angleat(A,B,C,-2-i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_155angleat = {"angleat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_155angleat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_154angleat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_155angleat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("angleat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "angleat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_154angleat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_154angleat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("angleat", 1);

  /* "giacpy/auto-methods.pxi":941
 * 
 *         '''
 *         return GiacMethods['angleat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def angleatraw(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_angleat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 941, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":932
 *         return GiacMethods['angle_radian'](self,*args)
 * 
 *      def angleat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.angleat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":943
 *         return GiacMethods['angleat'](self,*args)
 * 
 *      def angleatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleatraw:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_157angleatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_156angleatraw, "From Giac's documentation:\n        Help for angleatraw:\n        angleatraw(Pnt(A)),Pnt(B),Pnt(C),(Pnt or Cplx(z0)))\n        angleatraw(A,B,C,z0) displays at point(z0), the value of the measure of the angle (AB,AC).\n        See also: 1/ angle 2/ angleat \n        Ex1: A:=point(0);B:=point(1);C:=point(i);angleatraw(A,B,C,-2-i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_157angleatraw = {"angleatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_157angleatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_156angleatraw};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_157angleatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("angleatraw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "angleatraw", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_156angleatraw(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_156angleatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("angleatraw", 1);

  /* "giacpy/auto-methods.pxi":952
 * 
 *         '''
 *         return GiacMethods['angleatraw'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ans(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_angleatraw); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 952, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":943
 *         return GiacMethods['angleat'](self,*args)
 * 
 *      def angleatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleatraw:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.angleatraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":954
 *         return GiacMethods['angleatraw'](self,*args)
 * 
 *      def ans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ans:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_159ans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_158ans, "From Giac's documentation:\n        Help for ans:\n        ans(Intg(n))\n        Returns the (n+1)th answer of the command history if n>=0 or, the (-n)th previous answer if n<0 (by default n=-1 for the previous answer).\n        See also: 1/ quest \n        Ex1:ans()\n        Ex2:ans(2)\n        Ex3:ans(-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_159ans = {"ans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_159ans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_158ans};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_159ans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ans (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ans", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_158ans(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_158ans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ans", 1);

  /* "giacpy/auto-methods.pxi":965
 * 
 *         '''
 *         return GiacMethods['ans'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def antiprism_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ans); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 965, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":954
 *         return GiacMethods['angleatraw'](self,*args)
 * 
 *      def ans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ans:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ans", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":967
 *         return GiacMethods['ans'](self,*args)
 * 
 *      def antiprism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for antiprism_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_161antiprism_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_160antiprism_graph, "From Giac's documentation:\n        Help for antiprism_graph:\n        antiprism_graph(Intg(n))\n        Returns an antiprism graph of order n.\n        See also: 1/ prism_graph \n        Ex1:antiprism_graph(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_161antiprism_graph = {"antiprism_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_161antiprism_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_160antiprism_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_161antiprism_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("antiprism_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "antiprism_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_160antiprism_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_160antiprism_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("antiprism_graph", 1);

  /* "giacpy/auto-methods.pxi":976
 * 
 *         '''
 *         return GiacMethods['antiprism_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def append(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_antiprism_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 976, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":967
 *         return GiacMethods['ans'](self,*args)
 * 
 *      def antiprism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for antiprism_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.antiprism_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":978
 *         return GiacMethods['antiprism_graph'](self,*args)
 * 
 *      def append(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for append:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_163append(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_162append, "From Giac's documentation:\n        Help for append:\n        append((Lst||Set||Str(L),Elem))\n        Append an element to a set or at the end of a list or of a string (L:=append(L,a) or L.append(a)).\n        See also: 1/ concat 2/ prepend \n        Ex1:append([1,2,4],6)\n        Ex2:append(%{1,2,4%},6)\n        Ex3: L:=[1,2,4];L:=append(L,6)\n        Ex4: L:=[1,2,4];L.append(6)\n        Ex5: S:=set[1,2,4];S:=append(S,6)\n        Ex6: S:=set[1,2,4];S.append(6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_163append = {"append", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_163append, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_162append};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_163append(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "append", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_162append(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_162append(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "giacpy/auto-methods.pxi":992
 * 
 *         '''
 *         return GiacMethods['append'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def apply(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_append); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 992, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":978
 *         return GiacMethods['antiprism_graph'](self,*args)
 * 
 *      def append(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for append:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":994
 *         return GiacMethods['append'](self,*args)
 * 
 *      def apply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for apply:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_165apply(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_164apply, "From Giac's documentation:\n        Help for apply:\n        apply(Fnc(f),Lst(l))\n        Applies the function f at the elements of the list l (option matrix for a matrix).\n        See also: 1/ map 2/ unapply 3/ matrix \n        Ex1:apply(x->x^3,[1,2,3])\n        Ex2:apply(x->x+1,[[1,2,3],[1,2,3]],matrix)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_165apply = {"apply", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_165apply, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_164apply};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_165apply(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("apply (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "apply", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_164apply(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_164apply(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply", 1);

  /* "giacpy/auto-methods.pxi":1004
 * 
 *         '''
 *         return GiacMethods['apply'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def approx(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_apply); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1004, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":994
 *         return GiacMethods['append'](self,*args)
 * 
 *      def apply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for apply:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1006
 *         return GiacMethods['apply'](self,*args)
 * 
 *      def approx(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for approx:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_167approx(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_166approx, "From Giac's documentation:\n        Help for approx:\n        approx(Expr,[Int])\n        Numerical evaluation of the first argument (we can give the number of digits as second argument).\n        See also: 1/ evalb 2/ eval \n        Ex1:approx(2/3)\n        Ex2:approx(2/3,2)\n        Ex3:approx(2*sin(1))\n        Ex4:approx(2*sin(1),40)\n        Ex5:approx(sqrt(2)+pi)\n        Ex6:approx(sqrt(2)+pi,30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_167approx = {"approx", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_167approx, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_166approx};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_167approx(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("approx (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "approx", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_166approx(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_166approx(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("approx", 1);

  /* "giacpy/auto-methods.pxi":1020
 * 
 *         '''
 *         return GiacMethods['approx'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_approx); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1020, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1006
 *         return GiacMethods['apply'](self,*args)
 * 
 *      def approx(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for approx:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.approx", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1022
 *         return GiacMethods['approx'](self,*args)
 * 
 *      def arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_169arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_168arc, "From Giac's documentation:\n        Help for arc:\n        arc(Pnt, Pnt, Real,[Var(C)],[Var(r)],[Opt(segment)])\n        Draws a circular arc given by 2 vertices and the central angle [Xcas will put the center in C and the radius in r].\n        See also: 1/ circle 2/ segment 3/ plotparam \n        Ex1:arc(0,1,pi/4)\n        Ex2:arc(i,1,pi/4,C,r)\n        Ex3:arc(i,1,pi/4,segment)\n        Ex4:arc(i,1,pi/4,segment,affichage=1+rempli)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_169arc = {"arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_169arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_168arc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_169arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_168arc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_168arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arc", 1);

  /* "giacpy/auto-methods.pxi":1034
 * 
 *         '''
 *         return GiacMethods['arc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arcLen(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1034, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1022
 *         return GiacMethods['approx'](self,*args)
 * 
 *      def arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1036
 *         return GiacMethods['arc'](self,*args)
 * 
 *      def arcLen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcLen:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_171arcLen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_170arcLen, "From Giac's documentation:\n        Help for arcLen:\n        arcLen(Expr(Xpr) or Lst([Xpr1,Xpr2]),Var,Real(a),Real(b))\n        Returns the length of the arc of the curve defined by y=Xpr(or by x=Xpr1,y=Xpr2) when the parameter values are between a and b.\n        See also: 1/ int \n        Ex1:arcLen(t^2,t,1,2)\n        Ex2:arcLen([t,t^2],t,1,2)\n        Ex3:arcLen([cos(t),sin(t)],t,1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_171arcLen = {"arcLen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_171arcLen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_170arcLen};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_171arcLen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arcLen (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arcLen", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_170arcLen(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_170arcLen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arcLen", 1);

  /* "giacpy/auto-methods.pxi":1047
 * 
 *         '''
 *         return GiacMethods['arcLen'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arccos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arcLen); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1047, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1036
 *         return GiacMethods['arc'](self,*args)
 * 
 *      def arcLen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcLen:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arcLen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1049
 *         return GiacMethods['arcLen'](self,*args)
 * 
 *      def arccos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_173arccos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_172arccos, "From Giac's documentation:\n        Help for arccos:\n        arccos(Expr)\n        Arccosine.\n        See also: 1/ cos 2/ acosh \n        Ex1:arccos(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_173arccos = {"arccos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_173arccos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_172arccos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_173arccos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arccos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arccos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_172arccos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_172arccos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arccos", 1);

  /* "giacpy/auto-methods.pxi":1058
 * 
 *         '''
 *         return GiacMethods['arccos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arccosh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arccos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1058, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1049
 *         return GiacMethods['arcLen'](self,*args)
 * 
 *      def arccos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arccos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1060
 *         return GiacMethods['arccos'](self,*args)
 * 
 *      def arccosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccosh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_175arccosh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_174arccosh, "From Giac's documentation:\n        Help for arccosh:\n        arccosh(Expr)\n        Hyperbolic arccosine.\n        See also: 1/ cosh 2/ acos \n        Ex1:arccosh(1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_175arccosh = {"arccosh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_175arccosh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_174arccosh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_175arccosh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arccosh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arccosh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_174arccosh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_174arccosh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arccosh", 1);

  /* "giacpy/auto-methods.pxi":1069
 * 
 *         '''
 *         return GiacMethods['arccosh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arclen(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arccosh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1069, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1060
 *         return GiacMethods['arccos'](self,*args)
 * 
 *      def arccosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccosh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arccosh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1071
 *         return GiacMethods['arccosh'](self,*args)
 * 
 *      def arclen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arclen:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_177arclen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_176arclen, "From Giac's documentation:\n        Help for arclen:\n        arclen(Expr(Xpr) or Lst([Xpr1,Xpr2]),Var,Real(a),Real(b))\n        Returns the length of the arc of the curve defined by y=Xpr(or by x=Xpr1,y=Xpr2) when the parameter values are between a and b.\n        See also: 1/ int \n        Ex1:arclen(t^2,t,1,2)\n        Ex2:arclen([t,t^2],t,1,2)\n        Ex3:arclen([cos(t),sin(t)],t,1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_177arclen = {"arclen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_177arclen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_176arclen};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_177arclen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arclen (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arclen", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_176arclen(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_176arclen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arclen", 1);

  /* "giacpy/auto-methods.pxi":1082
 * 
 *         '''
 *         return GiacMethods['arclen'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arcsin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arclen); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1082, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1071
 *         return GiacMethods['arccosh'](self,*args)
 * 
 *      def arclen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arclen:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arclen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1084
 *         return GiacMethods['arclen'](self,*args)
 * 
 *      def arcsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_179arcsin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_178arcsin, "From Giac's documentation:\n        Help for arcsin:\n        arcsin(Expr)\n        Arcsine.\n        See also: 1/ sin \n        Ex1:arcsin(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_179arcsin = {"arcsin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_179arcsin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_178arcsin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_179arcsin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arcsin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arcsin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_178arcsin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_178arcsin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arcsin", 1);

  /* "giacpy/auto-methods.pxi":1093
 * 
 *         '''
 *         return GiacMethods['arcsin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arcsinh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arcsin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1093, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1084
 *         return GiacMethods['arclen'](self,*args)
 * 
 *      def arcsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arcsin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1095
 *         return GiacMethods['arcsin'](self,*args)
 * 
 *      def arcsinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsinh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_181arcsinh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_180arcsinh, "From Giac's documentation:\n        Help for arcsinh:\n        arcsinh(Expr)\n        Hyperbolic arcsine.\n        See also: 1/ sinh 2/ asin \n        Ex1:arcsinh(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_181arcsinh = {"arcsinh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_181arcsinh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_180arcsinh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_181arcsinh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arcsinh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arcsinh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_180arcsinh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_180arcsinh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arcsinh", 1);

  /* "giacpy/auto-methods.pxi":1104
 * 
 *         '''
 *         return GiacMethods['arcsinh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arctan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arcsinh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1104, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1095
 *         return GiacMethods['arcsin'](self,*args)
 * 
 *      def arcsinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsinh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arcsinh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1106
 *         return GiacMethods['arcsinh'](self,*args)
 * 
 *      def arctan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_183arctan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_182arctan, "From Giac's documentation:\n        Help for arctan:\n        arctan(Expr)\n        Arctangent.\n        See also: 1/ tan 2/ atanh \n        Ex1:arctan(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_183arctan = {"arctan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_183arctan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_182arctan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_183arctan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arctan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arctan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_182arctan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_182arctan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arctan", 1);

  /* "giacpy/auto-methods.pxi":1115
 * 
 *         '''
 *         return GiacMethods['arctan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arctanh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arctan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1115, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1106
 *         return GiacMethods['arcsinh'](self,*args)
 * 
 *      def arctan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arctan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1117
 *         return GiacMethods['arctan'](self,*args)
 * 
 *      def arctanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctanh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_185arctanh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_184arctanh, "From Giac's documentation:\n        Help for arctanh:\n        arctanh(Expr)\n        Hyperbolic arctangent.\n        See also: 1/ atan 2/ tanh \n        Ex1:arctanh(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_185arctanh = {"arctanh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_185arctanh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_184arctanh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_185arctanh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arctanh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arctanh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_184arctanh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_184arctanh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arctanh", 1);

  /* "giacpy/auto-methods.pxi":1126
 * 
 *         '''
 *         return GiacMethods['arctanh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def area(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arctanh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1126, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1117
 *         return GiacMethods['arctan'](self,*args)
 * 
 *      def arctanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctanh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arctanh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1128
 *         return GiacMethods['arctanh'](self,*args)
 * 
 *      def area(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for area:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_187area(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_186area, "From Giac's documentation:\n        Help for area:\n        area(Polygone || Expr,x=a..b,[n],[Method])\n        Algebraic area of a circle, a circular arc or of a (star) polygon (e.g. triangle, square, ...) or of the area below a curve, optionally with a quadrature method (trapezoid,left_rectangle,right_rectangle,middle_point,simpson,rombergt,rombergm).\n        See also: 1/ trapezoid 2/ perimeter 3/ areaatraw 4/ areaat 5/ areaplot \n        Ex1:area(triangle(0,1,i))\n        Ex2:area(square(0,2))\n        Ex3:area(circle(0,2))\n        Ex4:area(0,1,i)\n        Ex5:area(x^2,x=0..1,5,trapezoid)\n        Ex6:area(x^2,x=0..1,5,simpson)\n        Ex7:area(x^2,x=0..1,5,rombergm)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_187area = {"area", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_187area, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_186area};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_187area(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("area (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "area", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_186area(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_186area(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("area", 1);

  /* "giacpy/auto-methods.pxi":1143
 * 
 *         '''
 *         return GiacMethods['area'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def areaat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_area); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1143, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1128
 *         return GiacMethods['arctanh'](self,*args)
 * 
 *      def area(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for area:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.area", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1145
 *         return GiacMethods['area'](self,*args)
 * 
 *      def areaat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_189areaat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_188areaat, "From Giac's documentation:\n        Help for areaat:\n        areaat(Polygone, Pnt||Cplx(z0))\n        Displays at point(z0), with a legend, the algebraic area of a circle or of a (star) polygon (e.g. triangle, square, ...)\n        See also: 1/ area 2/ areaatraw 3/ polygon 4/ perimeteratraw 5/ areaplot \n        Ex1: t:=triangle(0,1,i);areaat(t,(1+i)/2)\n        Ex2: c:=square(0,2);areaat(c,1+i)\n        Ex3: c2:=circle(0,2);areaat(c2,1+i)\n        Ex4: p:=polygon(0,1,i);areaat(p,1+i)\n        Ex5: A:=point(0);B:=point(1+i);c:=carre(A,B);areaat(c,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_189areaat = {"areaat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_189areaat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_188areaat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_189areaat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("areaat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "areaat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_188areaat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_188areaat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("areaat", 1);

  /* "giacpy/auto-methods.pxi":1158
 * 
 *         '''
 *         return GiacMethods['areaat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def areaatraw(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_areaat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1158, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1145
 *         return GiacMethods['area'](self,*args)
 * 
 *      def areaat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.areaat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1160
 *         return GiacMethods['areaat'](self,*args)
 * 
 *      def areaatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaatraw:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_191areaatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_190areaatraw, "From Giac's documentation:\n        Help for areaatraw:\n        areaatraw(Polygone, Pnt||Cplx(z0))\n        Displays at point(z0), the algebraic area of a circle or of a (star-)polygon (e.g. triangle, square, ...)\n        See also: 1/ area 2/ areaat 3/ polygon 4/ perimeteratraw 5/ areaplot \n        Ex1:areaatraw(triangle(0,1,i),(1+i)/2)\n        Ex2:areaatraw(square(0,2),1+i)\n        Ex3:areaatraw(circle(0,2),1+i)\n        Ex4:areaatraw(polygon(0,1,i),1+i)\n        Ex5: A:=point(0);B:=point(1+i);c:=carre(A,B);areaatraw(c,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_191areaatraw = {"areaatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_191areaatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_190areaatraw};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_191areaatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("areaatraw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "areaatraw", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_190areaatraw(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_190areaatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("areaatraw", 1);

  /* "giacpy/auto-methods.pxi":1173
 * 
 *         '''
 *         return GiacMethods['areaatraw'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def areaplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_areaatraw); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1173, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1160
 *         return GiacMethods['areaat'](self,*args)
 * 
 *      def areaatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaatraw:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.areaatraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1175
 *         return GiacMethods['areaatraw'](self,*args)
 * 
 *      def areaplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_193areaplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_192areaplot, "From Giac's documentation:\n        Help for areaplot:\n        areaplot(Expr,x=a..b,[n],[Method])\n        Displays the area below a curve, optionally with a quadrature method (trapezoid,left_rectangle,right_rectangle,middle_point).\n        See also: 1/ integrate 2/ plot 3/ area 4/ areaat 5/ areaatraw \n        Ex1:areaplot(sin(x),x=0..pi)\n        Ex2:areaplot(x^2,x=0..1,5,trapezoid)\n        Ex3:areaplot(x^2,x=0..1,5,middle_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_193areaplot = {"areaplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_193areaplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_192areaplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_193areaplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("areaplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "areaplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_192areaplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_192areaplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("areaplot", 1);

  /* "giacpy/auto-methods.pxi":1186
 * 
 *         '''
 *         return GiacMethods['areaplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arg(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_areaplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1186, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1175
 *         return GiacMethods['areaatraw'](self,*args)
 * 
 *      def areaplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.areaplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1188
 *         return GiacMethods['areaplot'](self,*args)
 * 
 *      def arg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arg:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_195arg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_194arg, "From Giac's documentation:\n        Help for arg:\n        arg(Expr)\n        Returns the argument of a complex number.\n        See also: 1/ abs \n        Ex1:arg(1+i)\n        Ex2:arg(1+2*i)\n        Ex3:arg((1+2*i)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_195arg = {"arg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_195arg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_194arg};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_195arg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arg (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arg", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_194arg(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_194arg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arg", 1);

  /* "giacpy/auto-methods.pxi":1199
 * 
 *         '''
 *         return GiacMethods['arg'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def array(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arg); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1199, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1188
 *         return GiacMethods['areaplot'](self,*args)
 * 
 *      def arg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arg:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1201
 *         return GiacMethods['arg'](self,*args)
 * 
 *      def array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for array:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_197array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_196array, "From Giac's documentation:\n        Help for array:\n        array(Opt)\n        Option for convert for definitions of sparse matrices.\n        See also: 1/ convert 2/ table \n        Ex1: A[0..2,0..2]:=1;A[0..1,1..2]:=2;convert(A,array)\n        Ex2: B[0..1,1..2]:=1;B[2,2]:=2;convert(B,array)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_197array = {"array", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_197array, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_196array};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_197array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("array (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "array", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_196array(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_196array(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("array", 1);

  /* "giacpy/auto-methods.pxi":1211
 * 
 *         '''
 *         return GiacMethods['array'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def arrivals(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1211, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1201
 *         return GiacMethods['arg'](self,*args)
 * 
 *      def array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for array:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1213
 *         return GiacMethods['array'](self,*args)
 * 
 *      def arrivals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arrivals:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_199arrivals(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_198arrivals, "From Giac's documentation:\n        Help for arrivals:\n        arrivals(Graph(G),[Vrtx(v)])\n        Returns the list of vertices in a digraph G which are connected to v with arcs pointing to v. If v is omitted, the list of arrivals is computed for every vertex in G.\n        See also: 1/ in_degree \n        Ex1:arrivals(digraph(%{[1,2],[1,3],[2,3]%}),1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_199arrivals = {"arrivals", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_199arrivals, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_198arrivals};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_199arrivals(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("arrivals (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "arrivals", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_198arrivals(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_198arrivals(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("arrivals", 1);

  /* "giacpy/auto-methods.pxi":1222
 * 
 *         '''
 *         return GiacMethods['arrivals'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def articulation_points(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_arrivals); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1222, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1213
 *         return GiacMethods['array'](self,*args)
 * 
 *      def arrivals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arrivals:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.arrivals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1224
 *         return GiacMethods['arrivals'](self,*args)
 * 
 *      def articulation_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for articulation_points:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_201articulation_points(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_200articulation_points, "From Giac's documentation:\n        Help for articulation_points:\n        articulation_points(Graph(G))\n        Returns the list of articulation points (cut vertices) in G.\n        See also: 1/ biconnected_components 2/ is_biconnected 3/ is_connected 4/ is_triconnected \n        Ex1:articulation_points(path_graph(5))\n        Ex2:articulation_points(cycle_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_201articulation_points = {"articulation_points", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_201articulation_points, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_200articulation_points};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_201articulation_points(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("articulation_points (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "articulation_points", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_200articulation_points(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_200articulation_points(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("articulation_points", 1);

  /* "giacpy/auto-methods.pxi":1234
 * 
 *         '''
 *         return GiacMethods['articulation_points'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def asin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_articulation_points); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1234, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1224
 *         return GiacMethods['arrivals'](self,*args)
 * 
 *      def articulation_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for articulation_points:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.articulation_points", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1236
 *         return GiacMethods['articulation_points'](self,*args)
 * 
 *      def asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_203asin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_202asin, "From Giac's documentation:\n        Help for asin:\n        asin(Expr)\n        Arcsine.\n        See also: 1/ sin \n        Ex1:asin(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_203asin = {"asin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_203asin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_202asin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_203asin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "asin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_202asin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_202asin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asin", 1);

  /* "giacpy/auto-methods.pxi":1245
 * 
 *         '''
 *         return GiacMethods['asin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def asin2acos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_asin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1245, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1236
 *         return GiacMethods['articulation_points'](self,*args)
 * 
 *      def asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.asin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1247
 *         return GiacMethods['asin'](self,*args)
 * 
 *      def asin2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2acos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_205asin2acos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_204asin2acos, "From Giac's documentation:\n        Help for asin2acos:\n        asin2acos(Expr)\n        Replaces arcsin(x) by pi/2-arccos(x) in the argument.\n        See also: 1/ asin2atan \n        Ex1:asin2acos(acos(x)+asin(x))\n        Ex2:asin2acos(2*asin(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_205asin2acos = {"asin2acos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_205asin2acos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_204asin2acos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_205asin2acos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asin2acos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "asin2acos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_204asin2acos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_204asin2acos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asin2acos", 1);

  /* "giacpy/auto-methods.pxi":1257
 * 
 *         '''
 *         return GiacMethods['asin2acos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def asin2atan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_asin2acos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1257, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1247
 *         return GiacMethods['asin'](self,*args)
 * 
 *      def asin2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2acos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.asin2acos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1259
 *         return GiacMethods['asin2acos'](self,*args)
 * 
 *      def asin2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2atan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_207asin2atan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_206asin2atan, "From Giac's documentation:\n        Help for asin2atan:\n        asin2atan(Expr)\n        Replaces arcsin(x) by arctan(x/sqrt(1-x^2)) in the argument.\n        See also: 1/ asin2acos \n        Ex1:asin2atan(2*asin(x))\n        Ex2:asin2atan(asin(sqrt(1-x^2))+asin(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_207asin2atan = {"asin2atan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_207asin2atan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_206asin2atan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_207asin2atan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asin2atan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "asin2atan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_206asin2atan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_206asin2atan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asin2atan", 1);

  /* "giacpy/auto-methods.pxi":1269
 * 
 *         '''
 *         return GiacMethods['asin2atan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def asinh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_asin2atan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1269, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1259
 *         return GiacMethods['asin2acos'](self,*args)
 * 
 *      def asin2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2atan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.asin2atan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1271
 *         return GiacMethods['asin2atan'](self,*args)
 * 
 *      def asinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asinh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_209asinh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_208asinh, "From Giac's documentation:\n        Help for asinh:\n        asinh(Expr)\n        Hyperbolic arcsine.\n        See also: 1/ sinh 2/ asin \n        Ex1:asinh(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_209asinh = {"asinh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_209asinh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_208asinh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_209asinh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("asinh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "asinh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_208asinh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_208asinh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("asinh", 1);

  /* "giacpy/auto-methods.pxi":1280
 * 
 *         '''
 *         return GiacMethods['asinh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def assign_edge_weights(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_asinh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1280, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1271
 *         return GiacMethods['asin2atan'](self,*args)
 * 
 *      def asinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asinh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.asinh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1282
 *         return GiacMethods['asinh'](self,*args)
 * 
 *      def assign_edge_weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assign_edge_weights:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_211assign_edge_weights(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_210assign_edge_weights, "From Giac's documentation:\n        Help for assign_edge_weights:\n        assign_edge_weights(Graph(G),Seq(m,n)||Intrv(a..b))\n        Assigns random edge weights to the edges in G and returns a modified copy of G. If integers n and m such that n>=m are specified, then the weights are integers randomly chosen in [m,n]. If an interval a..b is specified, then the weights are uniformly distributed in the interval [a,b).\n        See also: 1/ set_edge_weight 2/ get_edge_weight 3/ weight_matrix 4/ random_digraph 5/ random_tournament \n        Ex1:assign_edge_weights(digraph(trail(1,2,3,4,1)),1,9)\n        Ex2:assign_edge_weights(digraph(trail(1,2,3,4,1)),0..1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_211assign_edge_weights = {"assign_edge_weights", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_211assign_edge_weights, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_210assign_edge_weights};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_211assign_edge_weights(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assign_edge_weights (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "assign_edge_weights", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_210assign_edge_weights(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_210assign_edge_weights(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_edge_weights", 1);

  /* "giacpy/auto-methods.pxi":1292
 * 
 *         '''
 *         return GiacMethods['assign_edge_weights'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def assume(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_assign_edge_weights); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1292, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1282
 *         return GiacMethods['asinh'](self,*args)
 * 
 *      def assign_edge_weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assign_edge_weights:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.assign_edge_weights", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1294
 *         return GiacMethods['assign_edge_weights'](self,*args)
 * 
 *      def assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assume:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_213assume(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_212assume, "From Giac's documentation:\n        Help for assume:\n        assume(Expr)\n        Makes an assumption on a variable.\n        See also: 1/ purge 2/ about 3/ additionally \n        Ex1:assume(a>0)\n        Ex2:assume(a=0.3)\n        Ex3:assume(a:=[pi/4,0,pi/2])\n        Ex4:assume(a:=[pi/4,0,pi/2,0.1])\n        Ex5:assume(n,integer);\n        Ex6:assume(n,integer);additionally(n>6)\n        Ex7:assume(a>-10 and a<10)\n        Ex8:assume((a>=2 and a<4) or a>6)\n        Ex9:assume(a>=2);additionally(a<6)\n        Ex10:assume(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_213assume = {"assume", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_213assume, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_212assume};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_213assume(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("assume (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "assume", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_212assume(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_212assume(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assume", 1);

  /* "giacpy/auto-methods.pxi":1312
 * 
 *         '''
 *         return GiacMethods['assume'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def at(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_assume); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1312, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1294
 *         return GiacMethods['assign_edge_weights'](self,*args)
 * 
 *      def assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assume:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.assume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1314
 *         return GiacMethods['assume'](self,*args)
 * 
 *      def at(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for at:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_215at(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_214at, "From Giac's documentation:\n        Help for at:\n        at(Lst(l)||Mtrx(m),Index(j)||Lst([j,k]))\n        at(l,j) (or at(m,[j,k])) is the element of the list l (or matrix m) for index=j (or for index j,k).\n        See also: 1/ of \n        Ex1:at([10,11,12],1)\n        Ex2:at([[1,2],[3,4]],[1,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_215at = {"at", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_215at, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_214at};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_215at(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("at (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "at", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_214at(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_214at(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("at", 1);

  /* "giacpy/auto-methods.pxi":1324
 * 
 *         '''
 *         return GiacMethods['at'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def atan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_at); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1324, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1314
 *         return GiacMethods['assume'](self,*args)
 * 
 *      def at(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for at:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.at", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1326
 *         return GiacMethods['at'](self,*args)
 * 
 *      def atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_217atan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_216atan, "From Giac's documentation:\n        Help for atan:\n        atan(Expr)\n        Arctangent.\n        See also: 1/ tan 2/ atanh \n        Ex1:atan(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_217atan = {"atan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_217atan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_216atan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_217atan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("atan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "atan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_216atan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_216atan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("atan", 1);

  /* "giacpy/auto-methods.pxi":1335
 * 
 *         '''
 *         return GiacMethods['atan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def atan2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_atan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1335, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1326
 *         return GiacMethods['at'](self,*args)
 * 
 *      def atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.atan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1337
 *         return GiacMethods['atan'](self,*args)
 * 
 *      def atan2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_219atan2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_218atan2, "From Giac's documentation:\n        Help for atan2:\n        atan2(Real(y),Real(x))\n        Returns the four-quadrant inverse tangent of real numbers y and x.\n        See also: 1/ tan 2/ atan \n        Ex1:atan2(-1/2,-sqrt(3)/2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_219atan2 = {"atan2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_219atan2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_218atan2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_219atan2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("atan2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "atan2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_218atan2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_218atan2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("atan2", 1);

  /* "giacpy/auto-methods.pxi":1346
 * 
 *         '''
 *         return GiacMethods['atan2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def atan2acos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_atan2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1346, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1337
 *         return GiacMethods['atan'](self,*args)
 * 
 *      def atan2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.atan2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1348
 *         return GiacMethods['atan2'](self,*args)
 * 
 *      def atan2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2acos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_221atan2acos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_220atan2acos, "From Giac's documentation:\n        Help for atan2acos:\n        atan2acos(Expr)\n        Replaces arctan(x) by pi/2-arccos(x/sqrt(1+x^2)) in the argument.\n        See also: 1/ atan2acos(atan(x)) \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_221atan2acos = {"atan2acos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_221atan2acos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_220atan2acos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_221atan2acos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("atan2acos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "atan2acos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_220atan2acos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_220atan2acos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("atan2acos", 1);

  /* "giacpy/auto-methods.pxi":1356
 * 
 *         '''
 *         return GiacMethods['atan2acos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def atan2asin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_atan2acos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1356, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1348
 *         return GiacMethods['atan2'](self,*args)
 * 
 *      def atan2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2acos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.atan2acos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1358
 *         return GiacMethods['atan2acos'](self,*args)
 * 
 *      def atan2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2asin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_223atan2asin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_222atan2asin, "From Giac's documentation:\n        Help for atan2asin:\n        atan2asin(Expr)\n        Replaces arctan(x) by arcsin(x/sqrt(1+x^2)) in the argument.\n        See also: 1/ atan2asin(atan(x)) \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_223atan2asin = {"atan2asin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_223atan2asin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_222atan2asin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_223atan2asin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("atan2asin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "atan2asin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_222atan2asin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_222atan2asin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("atan2asin", 1);

  /* "giacpy/auto-methods.pxi":1366
 * 
 *         '''
 *         return GiacMethods['atan2asin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def atanh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_atan2asin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1366, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1358
 *         return GiacMethods['atan2acos'](self,*args)
 * 
 *      def atan2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2asin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.atan2asin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1368
 *         return GiacMethods['atan2asin'](self,*args)
 * 
 *      def atanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atanh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_225atanh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_224atanh, "From Giac's documentation:\n        Help for atanh:\n        atanh(Expr)\n        Hyperbolic arctangent.\n        See also: 1/ atan 2/ tanh \n        Ex1:atanh(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_225atanh = {"atanh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_225atanh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_224atanh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_225atanh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("atanh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "atanh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_224atanh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_224atanh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("atanh", 1);

  /* "giacpy/auto-methods.pxi":1377
 * 
 *         '''
 *         return GiacMethods['atanh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def atrig2ln(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_atanh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1377, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1368
 *         return GiacMethods['atan2asin'](self,*args)
 * 
 *      def atanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atanh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.atanh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1379
 *         return GiacMethods['atanh'](self,*args)
 * 
 *      def atrig2ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atrig2ln:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_227atrig2ln(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_226atrig2ln, "From Giac's documentation:\n        Help for atrig2ln:\n        atrig2ln(Expr)\n        Rewrites the expression containing inverse trigonometric functions into logarithmic functions.\n        See also: 1/ trig2exp 2/ exp2trig \n        Ex1:atrig2ln(atan(x))\n        Ex2:atrig2ln(asin(x))\n        Ex3:atrig2ln(acos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_227atrig2ln = {"atrig2ln", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_227atrig2ln, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_226atrig2ln};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_227atrig2ln(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("atrig2ln (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "atrig2ln", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_226atrig2ln(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_226atrig2ln(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("atrig2ln", 1);

  /* "giacpy/auto-methods.pxi":1390
 * 
 *         '''
 *         return GiacMethods['atrig2ln'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def augment(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_atrig2ln); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1390, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1379
 *         return GiacMethods['atanh'](self,*args)
 * 
 *      def atrig2ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atrig2ln:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.atrig2ln", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1392
 *         return GiacMethods['atrig2ln'](self,*args)
 * 
 *      def augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for augment:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_229augment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_228augment, "From Giac's documentation:\n        Help for augment:\n        augment(Lst,Lst||Seq,Seq||Str,Str||Mtrx,Mtrx)\n        Concatenates two lists or two strings or two sequences or 2 matrices; L:=concat(L,L1) or L.concat(L1).\n        See also: 1/ append 2/ cat 3/ semi_augment 4/ border 5/ + \n        Ex1:augment([1,2],[3,4,5])\n        Ex2:augment(\"bon\",\"jour\")\n        Ex3:augment([[1,2],[3,4]],[[4,5,6],[6,7,8]])\n        Ex4: L:=[1,2];L.concat([3,4,5])\n        Ex5: S:=\"abcd\";S.concat(\"efghi\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_229augment = {"augment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_229augment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_228augment};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_229augment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("augment (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "augment", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_228augment(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_228augment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("augment", 1);

  /* "giacpy/auto-methods.pxi":1405
 * 
 *         '''
 *         return GiacMethods['augment'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def auto_correlation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_augment); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1405, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1392
 *         return GiacMethods['atrig2ln'](self,*args)
 * 
 *      def augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for augment:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.augment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1407
 *         return GiacMethods['augment'](self,*args)
 * 
 *      def auto_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for auto_correlation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_231auto_correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_230auto_correlation, "From Giac's documentation:\n        Help for auto_correlation:\n        auto_correlation(Lst)\n        Returns the cross-correlation of the given signal with itself.\n        See also: 1/ cross_correlation 2/ correlation \n        Ex1:auto_correlation([1,-1,0,2,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_231auto_correlation = {"auto_correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_231auto_correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_230auto_correlation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_231auto_correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("auto_correlation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "auto_correlation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_230auto_correlation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_230auto_correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("auto_correlation", 1);

  /* "giacpy/auto-methods.pxi":1416
 * 
 *         '''
 *         return GiacMethods['auto_correlation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def autosimplify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_auto_correlation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1416, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1407
 *         return GiacMethods['augment'](self,*args)
 * 
 *      def auto_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for auto_correlation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.auto_correlation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1418
 *         return GiacMethods['auto_correlation'](self,*args)
 * 
 *      def autosimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for autosimplify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_233autosimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_232autosimplify, "From Giac's documentation:\n        Help for autosimplify:\n        autosimplify(Cmds)\n        The argument is a command that Xcas will use to rewrite answers (initial value is regroup and for no simplification it is nop or 0).\n        See also: 1/ simplify 2/ factor 3/ regroup \n        Ex1:autosimplify(nop)\n        Ex2:autosimplify(0)\n        Ex3:autosimplify(regroup)\n        Ex4:autosimplify(1)\n        Ex5:autosimplify(factor)\n        Ex6:autosimplify(simplify)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_233autosimplify = {"autosimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_233autosimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_232autosimplify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_233autosimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("autosimplify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "autosimplify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_232autosimplify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_232autosimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("autosimplify", 1);

  /* "giacpy/auto-methods.pxi":1432
 * 
 *         '''
 *         return GiacMethods['autosimplify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def avance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_autosimplify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1432, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1418
 *         return GiacMethods['auto_correlation'](self,*args)
 * 
 *      def autosimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for autosimplify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.autosimplify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1434
 *         return GiacMethods['autosimplify'](self,*args)
 * 
 *      def avance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_235avance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_234avance, "From Giac's documentation:\n        Help for avance:\n        avance(NULL or Real(n))\n        The turtle takes n steps forward (by default n=10).\n        See also: 1/ recule 2/ saute \n        Ex1: avance 30\n        Ex2:avance(30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_235avance = {"avance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_235avance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_234avance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_235avance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("avance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "avance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_234avance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_234avance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("avance", 1);

  /* "giacpy/auto-methods.pxi":1444
 * 
 *         '''
 *         return GiacMethods['avance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def avgRC(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_avance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1444, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1434
 *         return GiacMethods['autosimplify'](self,*args)
 * 
 *      def avance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.avance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1446
 *         return GiacMethods['avance'](self,*args)
 * 
 *      def avgRC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avgRC:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_237avgRC(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_236avgRC, "From Giac's documentation:\n        Help for avgRC:\n        avgRC(Expr(Xpr),Var(Var),[Real(h)])\n        Returns (Xpr(var+h)-Xpr(Var))/h (by default h=0.001).\n        See also: 1/ nDeriv \n        Ex1:avgRC(f(x),x,h)\n        Ex2:avgRC(x^2,x,0.1)\n        Ex3:avgRC(x^2,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_237avgRC = {"avgRC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_237avgRC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_236avgRC};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_237avgRC(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("avgRC (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "avgRC", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_236avgRC(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_236avgRC(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("avgRC", 1);

  /* "giacpy/auto-methods.pxi":1457
 * 
 *         '''
 *         return GiacMethods['avgRC'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def axes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_avgRC); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1457, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1446
 *         return GiacMethods['avance'](self,*args)
 * 
 *      def avgRC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avgRC:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.avgRC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1459
 *         return GiacMethods['avgRC'](self,*args)
 * 
 *      def axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_239axes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_238axes, "From Giac's documentation:\n        Help for axes:\n        axes(Opt)\n        Global option (Maple compatibility) of a graphic command to put or not the axes.\n        See also: 1/ line_width 2/ gl_showaxes 3/ switch_axes \n        Ex1: axes=0;segment(0,point(1,1))\n        Ex2: axes=1;segment(0,point(1,1),epaisseur=5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_239axes = {"axes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_239axes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_238axes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_239axes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("axes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "axes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_238axes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_238axes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("axes", 1);

  /* "giacpy/auto-methods.pxi":1469
 * 
 *         '''
 *         return GiacMethods['axes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def axis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_axes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1469, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1459
 *         return GiacMethods['avgRC'](self,*args)
 * 
 *      def axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.axes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1471
 *         return GiacMethods['axes'](self,*args)
 * 
 *      def axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_241axis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_240axis, "From Giac's documentation:\n        Help for axis:\n        axis(xmin,xmax,ymin,ymax,[zmin,zmaz])\n        Defines the graphic display\n        Ex1:axis(-2,4,-1,6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_241axis = {"axis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_241axis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_240axis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_241axis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("axis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "axis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_240axis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_240axis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("axis", 1);

  /* "giacpy/auto-methods.pxi":1479
 * 
 *         '''
 *         return GiacMethods['axis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def back(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_axis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1479, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1471
 *         return GiacMethods['axes'](self,*args)
 * 
 *      def axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.axis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1481
 *         return GiacMethods['axis'](self,*args)
 * 
 *      def back(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for back:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_243back(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_242back, "From Giac's documentation:\n        Help for back:\n        back(Vect or Seq or Str)\n        Returns the last element of a vector or a sequence or a string.\n        See also: 1/ inter 2/ head 3/ mid 4/ left 5/ right \n        Ex1:back(1,2,3)\n        Ex2:back([1,2,3])\n        Ex3:back(\"bonjour\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_243back = {"back", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_243back, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_242back};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_243back(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("back (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "back", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_242back(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_242back(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("back", 1);

  /* "giacpy/auto-methods.pxi":1492
 * 
 *         '''
 *         return GiacMethods['back'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def backward(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1492, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1481
 *         return GiacMethods['axis'](self,*args)
 * 
 *      def back(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for back:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.back", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1494
 *         return GiacMethods['back'](self,*args)
 * 
 *      def backward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for backward:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_245backward(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_244backward, "From Giac's documentation:\n        Help for backward:\n        backward(NULL or Real(n))\n        The turtle takes n steps back (by default n=10).\n        See also: 1/ avance 2/ saute \n        Ex1: recule 30\n        Ex2:backward(30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_245backward = {"backward", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_245backward, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_244backward};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_245backward(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("backward (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "backward", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_244backward(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_244backward(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("backward", 1);

  /* "giacpy/auto-methods.pxi":1504
 * 
 *         '''
 *         return GiacMethods['backward'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def baisse_crayon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_backward); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1504, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1494
 *         return GiacMethods['back'](self,*args)
 * 
 *      def backward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for backward:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.backward", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1506
 *         return GiacMethods['backward'](self,*args)
 * 
 *      def baisse_crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for baisse_crayon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_247baisse_crayon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_246baisse_crayon, "From Giac's documentation:\n        Help for baisse_crayon:\n        baisse_crayon(NULL)\n        Presses the pencil down so that the turtle move with traces.\n        See also: 1/ leve_crayon 2/ crayon \n        Ex1:baisse_crayon()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_247baisse_crayon = {"baisse_crayon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_247baisse_crayon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_246baisse_crayon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_247baisse_crayon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("baisse_crayon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "baisse_crayon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_246baisse_crayon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_246baisse_crayon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("baisse_crayon", 1);

  /* "giacpy/auto-methods.pxi":1515
 * 
 *         '''
 *         return GiacMethods['baisse_crayon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bandwidth(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_baisse_crayon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1515, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1506
 *         return GiacMethods['backward'](self,*args)
 * 
 *      def baisse_crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for baisse_crayon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.baisse_crayon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1517
 *         return GiacMethods['baisse_crayon'](self,*args)
 * 
 *      def bandwidth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bandwidth:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_249bandwidth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_248bandwidth, "From Giac's documentation:\n        Help for bandwidth:\n        bandwidth(Opt)\n        Option for the kernel_density command.\n        See also: 1/ kernel_density 2/ bins \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_249bandwidth = {"bandwidth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_249bandwidth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_248bandwidth};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_249bandwidth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bandwidth (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bandwidth", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_248bandwidth(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_248bandwidth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bandwidth", 1);

  /* "giacpy/auto-methods.pxi":1525
 * 
 *         '''
 *         return GiacMethods['bandwidth'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bar_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bandwidth); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1525, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1517
 *         return GiacMethods['baisse_crayon'](self,*args)
 * 
 *      def bandwidth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bandwidth:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bandwidth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1527
 *         return GiacMethods['bandwidth'](self,*args)
 * 
 *      def bar_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bar_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_251bar_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_250bar_plot, "From Giac's documentation:\n        Help for bar_plot:\n        bar_plot(Mtrx)\n        Draws a barplot of a one variable statistical series.\n        See also: 1/ camembert 2/ histogram 3/ frequencies \n        Ex1:bar_plot([[\"France\",6],[\"Allemagne\",12],[\"Suisse\",5]])\n        Ex2:bar_plot([3/2,2/3,5/4,4/5,7/6,6/7,9/8,8/9,11/10])\n        Ex3:bar_plot([[2,\"xyz\",\"abc\"],[\"A\",2,5],[\"B\",5,6],[\"C\",7,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_251bar_plot = {"bar_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_251bar_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_250bar_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_251bar_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bar_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bar_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_250bar_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_250bar_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bar_plot", 1);

  /* "giacpy/auto-methods.pxi":1538
 * 
 *         '''
 *         return GiacMethods['bar_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def barplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bar_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1538, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1527
 *         return GiacMethods['bandwidth'](self,*args)
 * 
 *      def bar_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bar_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bar_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1540
 *         return GiacMethods['bar_plot'](self,*args)
 * 
 *      def barplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_253barplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_252barplot, "From Giac's documentation:\n        Help for barplot:\n        barplot(Mtrx)\n        Draws a barplot of a one variable statistical series.\n        See also: 1/ camembert 2/ histogram 3/ frequencies \n        Ex1:barplot([[\"France\",6],[\"Allemagne\",12],[\"Suisse\",5]])\n        Ex2:barplot([3/2,2/3,5/4,4/5,7/6,6/7,9/8,8/9,11/10])\n        Ex3:barplot([[2,\"xyz\",\"abc\"],[\"A\",2,5],[\"B\",5,6],[\"C\",7,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_253barplot = {"barplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_253barplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_252barplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_253barplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("barplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "barplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_252barplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_252barplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("barplot", 1);

  /* "giacpy/auto-methods.pxi":1551
 * 
 *         '''
 *         return GiacMethods['barplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bartlett_hann_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_barplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1551, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1540
 *         return GiacMethods['bar_plot'](self,*args)
 * 
 *      def barplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.barplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1553
 *         return GiacMethods['barplot'](self,*args)
 * 
 *      def bartlett_hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bartlett_hann_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_255bartlett_hann_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_254bartlett_hann_window, "From Giac's documentation:\n        Help for bartlett_hann_window:\n        bartlett_hann_window(Lst,[Interval(n1..n2)])\n        Applies the Bartlett-Hann windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(bartlett_hann_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_255bartlett_hann_window = {"bartlett_hann_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_255bartlett_hann_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_254bartlett_hann_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_255bartlett_hann_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bartlett_hann_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bartlett_hann_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_254bartlett_hann_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_254bartlett_hann_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bartlett_hann_window", 1);

  /* "giacpy/auto-methods.pxi":1562
 * 
 *         '''
 *         return GiacMethods['bartlett_hann_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def barycenter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bartlett_hann_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1562, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1553
 *         return GiacMethods['barplot'](self,*args)
 * 
 *      def bartlett_hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bartlett_hann_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bartlett_hann_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1564
 *         return GiacMethods['bartlett_hann_window'](self,*args)
 * 
 *      def barycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barycenter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_257barycenter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_256barycenter, "From Giac's documentation:\n        Help for barycenter:\n        barycenter([Pnt,Real],[Pnt,Real],[Pnt,Real])\n        barycenter([point1,coeff1],...) draws the barycenter of point1 with weight coeff1...\n        See also: 1/ isobarycenter 2/ midpoint \n        Ex1:barycenter([point(-1),1],[point(1+i),2],[point(1-i),1])\n        Ex2:barycenter([[point(-1),1],[point(1+i),2],[point(1-i),1]])\n        Ex3:barycenter([point(-1),point(1+i),point(1-i)],[1,2,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_257barycenter = {"barycenter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_257barycenter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_256barycenter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_257barycenter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("barycenter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "barycenter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_256barycenter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_256barycenter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("barycenter", 1);

  /* "giacpy/auto-methods.pxi":1575
 * 
 *         '''
 *         return GiacMethods['barycenter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def base(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_barycenter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1575, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1564
 *         return GiacMethods['bartlett_hann_window'](self,*args)
 * 
 *      def barycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barycenter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.barycenter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1577
 *         return GiacMethods['barycenter'](self,*args)
 * 
 *      def base(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for base:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_259base(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_258base, "From Giac's documentation:\n        Help for base:\n        base(Opt)\n        Option for convert : convert(p,base,b)= [a0,a1,..an] or convert([a0,a1,..an],base,b)=p with p=a0+a1*b+....an*b^(n-1).\n        See also: 1/ convert 2/ horner 3/ revlist \n        Ex1: convert(123,base,8)\n        Ex2: convert([3,7,1],base,8)\n        Ex3: horner(revlist([3,7,1]),8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_259base = {"base", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_259base, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_258base};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_259base(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("base (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "base", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_258base(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_258base(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("base", 1);

  /* "giacpy/auto-methods.pxi":1588
 * 
 *         '''
 *         return GiacMethods['base'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def basis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_base); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1588, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1577
 *         return GiacMethods['barycenter'](self,*args)
 * 
 *      def base(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for base:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1590
 *         return GiacMethods['base'](self,*args)
 * 
 *      def basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for basis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_261basis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_260basis, "From Giac's documentation:\n        Help for basis:\n        basis(Lst(vector1,..,vectorn))\n        Extracts a basis from a spanning set of vectors.\n        See also: 1/ ker 2/ ibasis \n        Ex1:basis([[1,2,3],[4,5,6],[7,8,9],[10,11,12]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_261basis = {"basis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_261basis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_260basis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_261basis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("basis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "basis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_260basis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_260basis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("basis", 1);

  /* "giacpy/auto-methods.pxi":1599
 * 
 *         '''
 *         return GiacMethods['basis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def batons(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_basis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1599, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1590
 *         return GiacMethods['base'](self,*args)
 * 
 *      def basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for basis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.basis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1601
 *         return GiacMethods['basis'](self,*args)
 * 
 *      def batons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for batons:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_263batons(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_262batons, "From Giac's documentation:\n        Help for batons:\n        batons(Mtrx)\n        Draws for k=0..nrows, the segments (xk,0)-(xk,yk) where xk=element row k column 0 and yk=element row k column j (j=1..ncols).\n        See also: 1/ polygonplot 2/ scatterplot 3/ listplot \n        Ex1:batons([1,3],[2,5],[3,2])\n        Ex2:batons([[1,3],[2,5],[3,2]])\n        Ex3:batons([1,2,3],[3,5,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_263batons = {"batons", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_263batons, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_262batons};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_263batons(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("batons (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "batons", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_262batons(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_262batons(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("batons", 1);

  /* "giacpy/auto-methods.pxi":1612
 * 
 *         '''
 *         return GiacMethods['batons'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bellman_ford(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_batons); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1612, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1601
 *         return GiacMethods['basis'](self,*args)
 * 
 *      def batons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for batons:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.batons", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1614
 *         return GiacMethods['batons'](self,*args)
 * 
 *      def bellman_ford(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bellman_ford:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_265bellman_ford(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_264bellman_ford, "From Giac's documentation:\n        Help for bellman_ford:\n        bellman_ford(Graph(G),Vrtx(s),Vrtx(t)||Lst(T))\n        Returns the length of the shortest path resp. of the shortest paths from s to vertex t resp. vertices in T in weighted graph G.\n        See also: 1/ dijkstra 2/ shortest_path \n        Ex1:bellman_ford(graph(%{[[1,2],-1],[[2,3],-3],[[3,4],-7],[[4,5],-3],[[5,6],-3],[[1,6],-3]%}),1,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_265bellman_ford = {"bellman_ford", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_265bellman_ford, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_264bellman_ford};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_265bellman_ford(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bellman_ford (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bellman_ford", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_264bellman_ford(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_264bellman_ford(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bellman_ford", 1);

  /* "giacpy/auto-methods.pxi":1623
 * 
 *         '''
 *         return GiacMethods['bellman_ford'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def berlekamp_massey(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bellman_ford); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1623, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1614
 *         return GiacMethods['batons'](self,*args)
 * 
 *      def bellman_ford(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bellman_ford:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bellman_ford", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1625
 *         return GiacMethods['bellman_ford'](self,*args)
 * 
 *      def berlekamp_massey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for berlekamp_massey:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_267berlekamp_massey(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_266berlekamp_massey, "From Giac's documentation:\n        Help for berlekamp_massey:\n        berlekamp_massey(Vect(v))\n        If v=[v_0 ... v_(2n-1)], returns [b_n,...,b_0] such that b_n*v_{n+k}+...+b_0*v_k=0 for k=0..n-1.\n        See also: 1/ rsolve \n        Ex1:berlekamp_massey([1,-1,3,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_267berlekamp_massey = {"berlekamp_massey", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_267berlekamp_massey, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_266berlekamp_massey};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_267berlekamp_massey(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("berlekamp_massey (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "berlekamp_massey", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_266berlekamp_massey(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_266berlekamp_massey(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("berlekamp_massey", 1);

  /* "giacpy/auto-methods.pxi":1634
 * 
 *         '''
 *         return GiacMethods['berlekamp_massey'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bernoulli(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_berlekamp_massey); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1634, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1625
 *         return GiacMethods['bellman_ford'](self,*args)
 * 
 *      def berlekamp_massey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for berlekamp_massey:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.berlekamp_massey", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1636
 *         return GiacMethods['berlekamp_massey'](self,*args)
 * 
 *      def bernoulli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_269bernoulli(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_268bernoulli, "From Giac's documentation:\n        Help for bernoulli:\n        bernoulli(Intg||(Intg,Var))\n        bernoulli(n) is the n-th number of Bernoulli and bernoulli(n,x) is the n-th polynomial of Bernoulli and the second argument is the variable.\n        See also: 1/  \n        Ex1:bernoulli(6)\n        Ex2:bernoulli(6,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_269bernoulli = {"bernoulli", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_269bernoulli, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_268bernoulli};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_269bernoulli(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bernoulli (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bernoulli", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_268bernoulli(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_268bernoulli(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bernoulli", 1);

  /* "giacpy/auto-methods.pxi":1646
 * 
 *         '''
 *         return GiacMethods['bernoulli'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bernoulli_mod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bernoulli); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1646, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1636
 *         return GiacMethods['berlekamp_massey'](self,*args)
 * 
 *      def bernoulli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bernoulli", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1648
 *         return GiacMethods['bernoulli'](self,*args)
 * 
 *      def bernoulli_mod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli_mod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_271bernoulli_mod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_270bernoulli_mod, "From Giac's documentation:\n        Help for bernoulli_mod:\n        bernoulli_mod(Intg,Intg)\n        bernoulli_mod(k,p) returns for k even integer and p prime the k-th Bernoulli number mod p\n        Ex1:bernoulli_mod(1234,10^6+3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_271bernoulli_mod = {"bernoulli_mod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_271bernoulli_mod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_270bernoulli_mod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_271bernoulli_mod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bernoulli_mod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bernoulli_mod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_270bernoulli_mod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_270bernoulli_mod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bernoulli_mod", 1);

  /* "giacpy/auto-methods.pxi":1656
 * 
 *         '''
 *         return GiacMethods['bernoulli_mod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def besselJ(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bernoulli_mod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1656, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1648
 *         return GiacMethods['bernoulli'](self,*args)
 * 
 *      def bernoulli_mod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli_mod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bernoulli_mod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1658
 *         return GiacMethods['bernoulli_mod'](self,*args)
 * 
 *      def besselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselJ:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_273besselJ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_272besselJ, "From Giac's documentation:\n        Help for besselJ:\n        besselJ(Real(x),Int(p))\n        besselJ(x,p) returns the Bessel function of the first kind Jp(x).\n        See also: 1/ BesselJ 2/ BesselY 3/ besselY \n        Ex1:besselJ(sqrt(2),2)\n        Ex2:besselJ(sqrt(2),-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_273besselJ = {"besselJ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_273besselJ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_272besselJ};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_273besselJ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("besselJ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "besselJ", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_272besselJ(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_272besselJ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("besselJ", 1);

  /* "giacpy/auto-methods.pxi":1668
 * 
 *         '''
 *         return GiacMethods['besselJ'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def besselY(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_besselJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1668, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1658
 *         return GiacMethods['bernoulli_mod'](self,*args)
 * 
 *      def besselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselJ:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.besselJ", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1670
 *         return GiacMethods['besselJ'](self,*args)
 * 
 *      def besselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselY:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_275besselY(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_274besselY, "From Giac's documentation:\n        Help for besselY:\n        besselY(Real(x),Int(p))\n        besselY(x,p) returns the Bessel function of the second kind Yp(x).\n        See also: 1/ BesselY 2/ BesselJ 3/ besselJ \n        Ex1:besselY(sqrt(2),2)\n        Ex2:besselY(sqrt(2),-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_275besselY = {"besselY", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_275besselY, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_274besselY};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_275besselY(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("besselY (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "besselY", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_274besselY(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_274besselY(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("besselY", 1);

  /* "giacpy/auto-methods.pxi":1680
 * 
 *         '''
 *         return GiacMethods['besselY'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def betad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_besselY); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1680, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1670
 *         return GiacMethods['besselJ'](self,*args)
 * 
 *      def besselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselY:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.besselY", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1682
 *         return GiacMethods['besselY'](self,*args)
 * 
 *      def betad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_277betad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_276betad, "From Giac's documentation:\n        Help for betad:\n        betad(Real(a>0),Real(b>0),Real(0<=x<=1))\n        Returns the probability density of the Beta law (=Gamma(a+b)*x^(a-1)*(1-x)^(b-1)/(Gamma(a)*Gamma(b))).\n        See also: 1/ betad_cdf 2/ betad_icdf \n        Ex1:betad(2.2,1.5,0.8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_277betad = {"betad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_277betad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_276betad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_277betad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("betad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "betad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_276betad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_276betad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("betad", 1);

  /* "giacpy/auto-methods.pxi":1691
 * 
 *         '''
 *         return GiacMethods['betad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def betad_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_betad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1691, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1682
 *         return GiacMethods['besselY'](self,*args)
 * 
 *      def betad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.betad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1693
 *         return GiacMethods['betad'](self,*args)
 * 
 *      def betad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_279betad_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_278betad_cdf, "From Giac's documentation:\n        Help for betad_cdf:\n        betad_cdf(Real(a>0),Real(b>0),Real(0<=x0<=1),[Real(0<=y0<=1)])\n        Returns the probability that a Beta random variable (with a and b as parameters) is less than x0 or between x0 and y0.\n        See also: 1/ betad 2/ betad_icdf \n        Ex1:betad_cdf(2,1,0.2)\n        Ex2:betad_cdf(2,1,0.1,0.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_279betad_cdf = {"betad_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_279betad_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_278betad_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_279betad_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("betad_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "betad_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_278betad_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_278betad_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("betad_cdf", 1);

  /* "giacpy/auto-methods.pxi":1703
 * 
 *         '''
 *         return GiacMethods['betad_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def betad_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_betad_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1703, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1693
 *         return GiacMethods['betad'](self,*args)
 * 
 *      def betad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.betad_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1705
 *         return GiacMethods['betad_cdf'](self,*args)
 * 
 *      def betad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_281betad_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_280betad_icdf, "From Giac's documentation:\n        Help for betad_icdf:\n        betad_icdf(Real(a>0),Real(b>0),Real(0<=p<=1))\n        Returns h such that the probability that a Beta random variable is less than h is p (0<=p<=1).\n        See also: 1/ betad_cdf 2/ betad \n        Ex1:betad_icdf(2,1,0.95)\n        Ex2:betad_icdf(2,1,0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_281betad_icdf = {"betad_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_281betad_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_280betad_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_281betad_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("betad_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "betad_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_280betad_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_280betad_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("betad_icdf", 1);

  /* "giacpy/auto-methods.pxi":1715
 * 
 *         '''
 *         return GiacMethods['betad_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def betavariate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_betad_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1715, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1705
 *         return GiacMethods['betad_cdf'](self,*args)
 * 
 *      def betad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.betad_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1717
 *         return GiacMethods['betad_icdf'](self,*args)
 * 
 *      def betavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betavariate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_283betavariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_282betavariate, "From Giac's documentation:\n        Help for betavariate:\n        betavariate(Real(a),Real(b))\n        Returns a random real according to the Beta distribution with parameters a>0 and b>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:betavariate(1,2)\n        Ex2:betavariate(1.5,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_283betavariate = {"betavariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_283betavariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_282betavariate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_283betavariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("betavariate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "betavariate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_282betavariate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_282betavariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("betavariate", 1);

  /* "giacpy/auto-methods.pxi":1727
 * 
 *         '''
 *         return GiacMethods['betavariate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def betweenness_centrality(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_betavariate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1727, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1717
 *         return GiacMethods['betad_icdf'](self,*args)
 * 
 *      def betavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betavariate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.betavariate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1729
 *         return GiacMethods['betavariate'](self,*args)
 * 
 *      def betweenness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betweenness_centrality:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_285betweenness_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_284betweenness_centrality, "From Giac's documentation:\n        Help for betweenness_centrality:\n        betweenness_centrality(Graph(G),[Vrtx(v)])\n        Returns the betweenness centrality of a vertex v in a graph G or the list of betweenness centralities of vertices in G.\n        See also: 1/ degree_centrality 2/ closeness_centrality 3/ harmonic_centrality 4/ information_centrality 5/ katz_centrality \n        Ex1:betweenness_centrality(graph(6,%{[0,2],[0,5],[1,3],[1,5],[2,5],[3,4],[3,5],[4,5]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_285betweenness_centrality = {"betweenness_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_285betweenness_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_284betweenness_centrality};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_285betweenness_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("betweenness_centrality (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "betweenness_centrality", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_284betweenness_centrality(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_284betweenness_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("betweenness_centrality", 1);

  /* "giacpy/auto-methods.pxi":1738
 * 
 *         '''
 *         return GiacMethods['betweenness_centrality'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bezier(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_betweenness_centrality); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1738, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1729
 *         return GiacMethods['betavariate'](self,*args)
 * 
 *      def betweenness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betweenness_centrality:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.betweenness_centrality", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1740
 *         return GiacMethods['betweenness_centrality'](self,*args)
 * 
 *      def bezier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezier:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_287bezier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_286bezier, "From Giac's documentation:\n        Help for bezier:\n        bezier(Lst,[plot])\n        Bezier curve defined by control points.\n        See also: 1/ parameq \n        Ex1:bezier(1,1+i,2+i,3-i,plot)\n        Ex2:bezier(point([0,0,0]),point([1,1,0]),point([0,1,1]),plot)\n        Ex3: parameq(bezier(1,1+i,2+i,3-i))\n        Ex4: parameq(bezier(point([0,0,0]),point([1,1,0]),point([0,1,1])))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_287bezier = {"bezier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_287bezier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_286bezier};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_287bezier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bezier (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bezier", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_286bezier(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_286bezier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bezier", 1);

  /* "giacpy/auto-methods.pxi":1752
 * 
 *         '''
 *         return GiacMethods['bezier'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bezout_entiers(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bezier); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1752, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1740
 *         return GiacMethods['betweenness_centrality'](self,*args)
 * 
 *      def bezier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezier:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bezier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1754
 *         return GiacMethods['bezier'](self,*args)
 * 
 *      def bezout_entiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezout_entiers:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_289bezout_entiers(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_288bezout_entiers, "From Giac's documentation:\n        Help for bezout_entiers:\n        bezout_entiers(Intg,Intg)\n        Extended greatest common divisor of 2 integers.\n        See also: 1/ gcd 2/ iabcuv 3/ egcd \n        Ex1:bezout_entiers(45,75)\n        Ex2:bezout_entiers(21,28)\n        Ex3:bezout_entiers(30,49)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_289bezout_entiers = {"bezout_entiers", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_289bezout_entiers, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_288bezout_entiers};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_289bezout_entiers(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bezout_entiers (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bezout_entiers", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_288bezout_entiers(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_288bezout_entiers(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bezout_entiers", 1);

  /* "giacpy/auto-methods.pxi":1765
 * 
 *         '''
 *         return GiacMethods['bezout_entiers'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bezoutian(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bezout_entiers); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1765, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1754
 *         return GiacMethods['bezier'](self,*args)
 * 
 *      def bezout_entiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezout_entiers:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bezout_entiers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1767
 *         return GiacMethods['bezout_entiers'](self,*args)
 * 
 *      def bezoutian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezoutian:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_291bezoutian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_290bezoutian, "From Giac's documentation:\n        Help for bezoutian:\n        bezoutian(Poly,Poly)\n        Bezoutian matrix of 2 polynomials\n        Ex1:bezoutian(5x^3-x,3x^2+1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_291bezoutian = {"bezoutian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_291bezoutian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_290bezoutian};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_291bezoutian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bezoutian (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bezoutian", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_290bezoutian(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_290bezoutian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bezoutian", 1);

  /* "giacpy/auto-methods.pxi":1775
 * 
 *         '''
 *         return GiacMethods['bezoutian'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def biconnected_components(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bezoutian); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1775, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1767
 *         return GiacMethods['bezout_entiers'](self,*args)
 * 
 *      def bezoutian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezoutian:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bezoutian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1777
 *         return GiacMethods['bezoutian'](self,*args)
 * 
 *      def biconnected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for biconnected_components:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_293biconnected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_292biconnected_components, "From Giac's documentation:\n        Help for biconnected_components:\n        biconnected_components(Graph(G))\n        Returns a list of lists of vertices, each sublist representing a biconnected component of G.\n        See also: 1/ articulation_points 2/ is_biconnected 3/ is_connected 4/ trail \n        Ex1:biconnected_components(graph(trail(1,2,3,4,2),trail(4,5,6,7,5)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_293biconnected_components = {"biconnected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_293biconnected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_292biconnected_components};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_293biconnected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("biconnected_components (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "biconnected_components", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_292biconnected_components(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_292biconnected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("biconnected_components", 1);

  /* "giacpy/auto-methods.pxi":1786
 * 
 *         '''
 *         return GiacMethods['biconnected_components'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def binomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_biconnected_components); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1786, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1777
 *         return GiacMethods['bezoutian'](self,*args)
 * 
 *      def biconnected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for biconnected_components:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.biconnected_components", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1788
 *         return GiacMethods['biconnected_components'](self,*args)
 * 
 *      def binomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_295binomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_294binomial, "From Giac's documentation:\n        Help for binomial:\n        binomial(Intg(n),Intg(k),[Real(p in 0..1)])\n        Returns comb(n,k)*p^k*(1-p)^(n-k) or comb(n,k) if no 3rd argument.\n        See also: 1/ binomial_cdf 2/ binomial_icdf 3/ multinomial 4/ randvector 5/ ranm \n        Ex1:binomial(4,2)\n        Ex2:binomial(4,0,0.5)\n        Ex3:binomial(4,2,0.5)\n        Ex4: assume(p>=0 and p<=1);binomial(4,2,p)\n        Ex5: assume(p>=0 and p<=1);binomial(4,p,2)\n        Ex6: randvector(6,binomial,4,0.2)\n        Ex7: ranm(4,6,binomial,4,0.7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_295binomial = {"binomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_295binomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_294binomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_295binomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("binomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "binomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_294binomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_294binomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("binomial", 1);

  /* "giacpy/auto-methods.pxi":1803
 * 
 *         '''
 *         return GiacMethods['binomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def binomial_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_binomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1803, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1788
 *         return GiacMethods['biconnected_components'](self,*args)
 * 
 *      def binomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.binomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1805
 *         return GiacMethods['binomial'](self,*args)
 * 
 *      def binomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_297binomial_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_296binomial_cdf, "From Giac's documentation:\n        Help for binomial_cdf:\n        binomial_cdf(Intg(n),Real(p),Real(x),[Real(y)])\n        Returns Proba(X<=x) or Proba(x<=X<=y) when X follows the B(n,p) law.\n        See also: 1/ binomial 2/ binomial_icdf \n        Ex1:binomial_cdf(4,0.5,2)\n        Ex2:binomial_cdf(4,0.1,2)\n        Ex3:binomial_cdf(4,0.5,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_297binomial_cdf = {"binomial_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_297binomial_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_296binomial_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_297binomial_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("binomial_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "binomial_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_296binomial_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_296binomial_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("binomial_cdf", 1);

  /* "giacpy/auto-methods.pxi":1816
 * 
 *         '''
 *         return GiacMethods['binomial_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def binomial_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_binomial_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1816, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1805
 *         return GiacMethods['binomial'](self,*args)
 * 
 *      def binomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.binomial_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1818
 *         return GiacMethods['binomial_cdf'](self,*args)
 * 
 *      def binomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_299binomial_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_298binomial_icdf, "From Giac's documentation:\n        Help for binomial_icdf:\n        binomial_icdf(Intg(n),Real(p),Real(t))\n        Returns h such as Proba(X<=h)=t when X follows the B(n,p) law.\n        See also: 1/ binomial 2/ binomial_cdf \n        Ex1:binomial_icdf(4,0.5,0.68)\n        Ex2:binomial_icdf(4,0.1,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_299binomial_icdf = {"binomial_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_299binomial_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_298binomial_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_299binomial_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("binomial_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "binomial_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_298binomial_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_298binomial_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("binomial_icdf", 1);

  /* "giacpy/auto-methods.pxi":1828
 * 
 *         '''
 *         return GiacMethods['binomial_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bins(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_binomial_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1828, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1818
 *         return GiacMethods['binomial_cdf'](self,*args)
 * 
 *      def binomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.binomial_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1830
 *         return GiacMethods['binomial_icdf'](self,*args)
 * 
 *      def bins(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bins:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_301bins(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_300bins, "From Giac's documentation:\n        Help for bins:\n        bins(Opt)\n        Option for the kernel_density command.\n        See also: 1/ kernel_density 2/ bandwidth \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_301bins = {"bins", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_301bins, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_300bins};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_301bins(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bins (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bins", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_300bins(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_300bins(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bins", 1);

  /* "giacpy/auto-methods.pxi":1838
 * 
 *         '''
 *         return GiacMethods['bins'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bipartite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bins); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1838, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1830
 *         return GiacMethods['binomial_icdf'](self,*args)
 * 
 *      def bins(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bins:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bins", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1840
 *         return GiacMethods['bins'](self,*args)
 * 
 *      def bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_303bipartite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_302bipartite, "From Giac's documentation:\n        Help for bipartite:\n        bipartite(Opt)\n        Option for the draw_graph command\n        See also: 1/ draw_graph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_303bipartite = {"bipartite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_303bipartite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_302bipartite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_303bipartite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bipartite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bipartite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_302bipartite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_302bipartite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bipartite", 1);

  /* "giacpy/auto-methods.pxi":1848
 * 
 *         '''
 *         return GiacMethods['bipartite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bipartite_matching(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bipartite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1848, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1840
 *         return GiacMethods['bins'](self,*args)
 * 
 *      def bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bipartite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1850
 *         return GiacMethods['bipartite'](self,*args)
 * 
 *      def bipartite_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite_matching:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_305bipartite_matching(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_304bipartite_matching, "From Giac's documentation:\n        Help for bipartite_matching:\n        bipartite_matching(Graph(G,[maximize||minimize,[epsilon=Real(eps)]]))\n        Returns the list of edges in a maximum matching of an undirected bipartite graph G. If G is weighted, output either minimum or maximum weighted matching, depending on the second attribute.\n        See also: 1/ is_bipartite 2/ maximum_matching \n        Ex1:bipartite_matching(graph(\"desargues\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_305bipartite_matching = {"bipartite_matching", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_305bipartite_matching, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_304bipartite_matching};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_305bipartite_matching(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bipartite_matching (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bipartite_matching", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_304bipartite_matching(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_304bipartite_matching(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bipartite_matching", 1);

  /* "giacpy/auto-methods.pxi":1859
 * 
 *         '''
 *         return GiacMethods['bipartite_matching'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bisection_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bipartite_matching); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1859, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1850
 *         return GiacMethods['bipartite'](self,*args)
 * 
 *      def bipartite_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite_matching:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bipartite_matching", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1861
 *         return GiacMethods['bipartite_matching'](self,*args)
 * 
 *      def bisection_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisection_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_307bisection_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_306bisection_solver, "From Giac's documentation:\n        Help for bisection_solver:\n        bisection_solver(Opt)\n        Argument for fsolve giving the method for solving a numerical equation.\n        See also: 1/ fsolve \n        Ex1: fsolve(cos(x)=x,x,0..1,bisection_solver)\n        Ex2: fsolve(cos(x)=x,x,0..1,brent_solver)\n        Ex3: fsolve(cos(x)=x,x,0..1,falsepos_solver)\n        Ex4: fsolve(cos(x)=x,x,0,newton_solver)\n        Ex5: fsolve(cos(x)=x,x,0,secant_solver)\n        Ex6: fsolve(cos(x)=x,x,0,steffenson_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_307bisection_solver = {"bisection_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_307bisection_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_306bisection_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_307bisection_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bisection_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bisection_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_306bisection_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_306bisection_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bisection_solver", 1);

  /* "giacpy/auto-methods.pxi":1875
 * 
 *         '''
 *         return GiacMethods['bisection_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bisector(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bisection_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1875, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1861
 *         return GiacMethods['bipartite_matching'](self,*args)
 * 
 *      def bisection_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisection_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bisection_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1877
 *         return GiacMethods['bisection_solver'](self,*args)
 * 
 *      def bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisector:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_309bisector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_308bisector, "From Giac's documentation:\n        Help for bisector:\n        bisector((Pnt(A) or Cplx),(Pnt(B) or Cplx),(Pnt(C) or Cplx))\n        Draws the bisector of the angle (AB,AC) given by 3 points A,B,C.\n        See also: 1/ angle 2/ exbisector \n        Ex1:bisector(0,1,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_309bisector = {"bisector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_309bisector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_308bisector};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_309bisector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bisector (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bisector", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_308bisector(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_308bisector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bisector", 1);

  /* "giacpy/auto-methods.pxi":1886
 * 
 *         '''
 *         return GiacMethods['bisector'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bit_depth(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bisector); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1886, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1877
 *         return GiacMethods['bisection_solver'](self,*args)
 * 
 *      def bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisector:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bisector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1888
 *         return GiacMethods['bisector'](self,*args)
 * 
 *      def bit_depth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bit_depth:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_311bit_depth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_310bit_depth, "From Giac's documentation:\n        Help for bit_depth:\n        bit_depth(Audio(clip)||Image(img))\n        Returns the bit depth of an audio clip or image object.\n        See also: 1/ channels 2/ channel_data 3/ duration 4/ samplerate \n        Ex1:bit_depth(readwav(\"/some/file\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_311bit_depth = {"bit_depth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_311bit_depth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_310bit_depth};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_311bit_depth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bit_depth (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bit_depth", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_310bit_depth(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_310bit_depth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bit_depth", 1);

  /* "giacpy/auto-methods.pxi":1897
 * 
 *         '''
 *         return GiacMethods['bit_depth'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bitand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bit_depth); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1897, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1888
 *         return GiacMethods['bisector'](self,*args)
 * 
 *      def bit_depth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bit_depth:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bit_depth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1899
 *         return GiacMethods['bit_depth'](self,*args)
 * 
 *      def bitand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_313bitand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_312bitand, "From Giac's documentation:\n        Help for bitand:\n        bitand(Intg,Intg)\n        Logical bit and.\n        See also: 1/ bitxor 2/ bitor \n        Ex1:bitand(0x12,0x38)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_313bitand = {"bitand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_313bitand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_312bitand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_313bitand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bitand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bitand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_312bitand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_312bitand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bitand", 1);

  /* "giacpy/auto-methods.pxi":1908
 * 
 *         '''
 *         return GiacMethods['bitand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bitor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bitand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1908, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1899
 *         return GiacMethods['bit_depth'](self,*args)
 * 
 *      def bitand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bitand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1910
 *         return GiacMethods['bitand'](self,*args)
 * 
 *      def bitor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_315bitor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_314bitor, "From Giac's documentation:\n        Help for bitor:\n        bitor(Intg,Intg)\n        Inclusive logical bit or.\n        See also: 1/ bitxor 2/ bitand \n        Ex1:bitor(0x12,0x38)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_315bitor = {"bitor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_315bitor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_314bitor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_315bitor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bitor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bitor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_314bitor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_314bitor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bitor", 1);

  /* "giacpy/auto-methods.pxi":1919
 * 
 *         '''
 *         return GiacMethods['bitor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bitxor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bitor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1919, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1910
 *         return GiacMethods['bitand'](self,*args)
 * 
 *      def bitor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bitor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1921
 *         return GiacMethods['bitor'](self,*args)
 * 
 *      def bitxor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitxor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_317bitxor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_316bitxor, "From Giac's documentation:\n        Help for bitxor:\n        bitxor(Intg,Intg)\n        Exclusive logical bit or.\n        See also: 1/ bitor 2/ bitand \n        Ex1:bitxor(0x12,0x38)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_317bitxor = {"bitxor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_317bitxor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_316bitxor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_317bitxor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bitxor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bitxor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_316bitxor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_316bitxor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bitxor", 1);

  /* "giacpy/auto-methods.pxi":1930
 * 
 *         '''
 *         return GiacMethods['bitxor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def blackman_harris_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bitxor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1930, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1921
 *         return GiacMethods['bitor'](self,*args)
 * 
 *      def bitxor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitxor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bitxor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1932
 *         return GiacMethods['bitxor'](self,*args)
 * 
 *      def blackman_harris_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_harris_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_319blackman_harris_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_318blackman_harris_window, "From Giac's documentation:\n        Help for blackman_harris_window:\n        blackman_harris_window(Lst,[Interval(n1..n2)])\n        Applies the Blackman-Harris windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ bartlett_hann_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(blackman_harris_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_319blackman_harris_window = {"blackman_harris_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_319blackman_harris_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_318blackman_harris_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_319blackman_harris_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("blackman_harris_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "blackman_harris_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_318blackman_harris_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_318blackman_harris_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("blackman_harris_window", 1);

  /* "giacpy/auto-methods.pxi":1941
 * 
 *         '''
 *         return GiacMethods['blackman_harris_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def blackman_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_blackman_harris_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1941, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1932
 *         return GiacMethods['bitxor'](self,*args)
 * 
 *      def blackman_harris_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_harris_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.blackman_harris_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1943
 *         return GiacMethods['blackman_harris_window'](self,*args)
 * 
 *      def blackman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_321blackman_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_320blackman_window, "From Giac's documentation:\n        Help for blackman_window:\n        blackman_window(Lst,[Real(a)],[Interval(n1..n2)])\n        Applies the Blackman windowing function with parameter a (by default a=0.16) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ bartlett_harris_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(blackman_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_321blackman_window = {"blackman_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_321blackman_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_320blackman_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_321blackman_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("blackman_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "blackman_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_320blackman_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_320blackman_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("blackman_window", 1);

  /* "giacpy/auto-methods.pxi":1952
 * 
 *         '''
 *         return GiacMethods['blackman_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def block_size(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_blackman_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1952, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1943
 *         return GiacMethods['blackman_harris_window'](self,*args)
 * 
 *      def blackman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.blackman_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1954
 *         return GiacMethods['blackman_window'](self,*args)
 * 
 *      def block_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for block_size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_323block_size(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_322block_size, "From Giac's documentation:\n        Help for block_size:\n        block_size(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_323block_size = {"block_size", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_323block_size, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_322block_size};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_323block_size(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("block_size (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "block_size", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_322block_size(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_322block_size(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("block_size", 1);

  /* "giacpy/auto-methods.pxi":1962
 * 
 *         '''
 *         return GiacMethods['block_size'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def blockmatrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_block_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1962, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1954
 *         return GiacMethods['blackman_window'](self,*args)
 * 
 *      def block_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for block_size:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.block_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1964
 *         return GiacMethods['block_size'](self,*args)
 * 
 *      def blockmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blockmatrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_325blockmatrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_324blockmatrix, "From Giac's documentation:\n        Help for blockmatrix:\n        blockmatrix(Intg(n),Intg(m),Lst)\n        Returns the matrix obtained from the list divided into n lists of dimension m.\n        See also: 1/ list2mat \n        Ex1:blockmatrix(2,3,[idn(2),idn(2),idn(2),idn(2),idn(2),idn(2)])\n        Ex2:blockmatrix(2,2,[idn(2),newMat(2,3),newMat(3,2),idn(3)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_325blockmatrix = {"blockmatrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_325blockmatrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_324blockmatrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_325blockmatrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("blockmatrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "blockmatrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_324blockmatrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_324blockmatrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("blockmatrix", 1);

  /* "giacpy/auto-methods.pxi":1974
 * 
 *         '''
 *         return GiacMethods['blockmatrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bohman_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_blockmatrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1974, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1964
 *         return GiacMethods['block_size'](self,*args)
 * 
 *      def blockmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blockmatrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.blockmatrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1976
 *         return GiacMethods['blockmatrix'](self,*args)
 * 
 *      def bohman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bohman_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_327bohman_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_326bohman_window, "From Giac's documentation:\n        Help for bohman_window:\n        bohman_window(Lst,[Interval(n1..n2)])\n        Applies the Bohman windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bartlett_hann_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(bohman_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_327bohman_window = {"bohman_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_327bohman_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_326bohman_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_327bohman_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bohman_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bohman_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_326bohman_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_326bohman_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bohman_window", 1);

  /* "giacpy/auto-methods.pxi":1985
 * 
 *         '''
 *         return GiacMethods['bohman_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def border(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bohman_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1985, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1976
 *         return GiacMethods['blockmatrix'](self,*args)
 * 
 *      def bohman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bohman_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bohman_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1987
 *         return GiacMethods['bohman_window'](self,*args)
 * 
 *      def border(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for border:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_329border(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_328border, "From Giac's documentation:\n        Help for border:\n        border(Mtrx(A),Lst(b))\n        Returns the matrix obtained by augmenting A with b as the last column, if nrows(A)=size(b), border(A,b)=tran(append(tran(A),b)).\n        See also: 1/ tran 2/ append 3/ augment \n        Ex1:border([[1,2,3,4],[4,5,6,8],[7,8,9,10]],[1,3,5])\n        Ex2:border([[1,2,3],[4,5,6],[7,8,9]],[1,0,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_329border = {"border", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_329border, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_328border};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_329border(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("border (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "border", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_328border(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_328border(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("border", 1);

  /* "giacpy/auto-methods.pxi":1997
 * 
 *         '''
 *         return GiacMethods['border'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def box_constraints(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_border); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 1997, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1987
 *         return GiacMethods['bohman_window'](self,*args)
 * 
 *      def border(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for border:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.border", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":1999
 *         return GiacMethods['border'](self,*args)
 * 
 *      def box_constraints(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for box_constraints:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_331box_constraints(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_330box_constraints, "From Giac's documentation:\n        Help for box_constraints:\n        box_constraints(Vect(x),Mtrx(bounds))\n        Converts variable bounds, given in matrix form, into interval form x=a..b,y=c..d,...\n        See also: 1/ nlpsolve 2/ minimize 3/ maximize \n        Ex1:box_constraints([x,y],[[-2,2],[-5,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_331box_constraints = {"box_constraints", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_331box_constraints, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_330box_constraints};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_331box_constraints(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("box_constraints (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "box_constraints", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_330box_constraints(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_330box_constraints(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("box_constraints", 1);

  /* "giacpy/auto-methods.pxi":2008
 * 
 *         '''
 *         return GiacMethods['box_constraints'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def boxcar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_box_constraints); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2008, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":1999
 *         return GiacMethods['border'](self,*args)
 * 
 *      def box_constraints(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for box_constraints:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.box_constraints", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2010
 *         return GiacMethods['box_constraints'](self,*args)
 * 
 *      def boxcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxcar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_333boxcar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_332boxcar, "From Giac's documentation:\n        Help for boxcar:\n        boxcar(Real(a),Real(b),Expr(x))\n        Returns the value at x of the boxcar function corresponding to a and b.\n        See also: 1/ rect 2/ Heaviside \n        Ex1:boxcar(1,2,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_333boxcar = {"boxcar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_333boxcar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_332boxcar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_333boxcar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("boxcar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "boxcar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_332boxcar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_332boxcar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("boxcar", 1);

  /* "giacpy/auto-methods.pxi":2019
 * 
 *         '''
 *         return GiacMethods['boxcar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def boxwhisker(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_boxcar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2019, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2010
 *         return GiacMethods['box_constraints'](self,*args)
 * 
 *      def boxcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxcar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.boxcar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2021
 *         return GiacMethods['boxcar'](self,*args)
 * 
 *      def boxwhisker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxwhisker:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_335boxwhisker(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_334boxwhisker, "From Giac's documentation:\n        Help for boxwhisker:\n        boxwhisker(Lst,[Lst],[x=a..b||y=a..b])\n        Box and Whisker plot for a statistical series.\n        See also: 1/ quartiles \n        Ex1:boxwhisker([-1,1,2,2.2,3,4,-2,5])\n        Ex2:boxwhisker([1,2,3,5,10,4],x=1..2)\n        Ex3:boxwhisker([1,2,3,5,10,4],[1,2,3,1,2,3])\n        Ex4:boxwhisker([[6,0,1,3,4,2,5],[0,1,3,4,2,5,6],[1,3,4,2,5,6,0],[3,4,2,5,6,0,1],[4,2,5,6,0,1,3],[2,5,6,0,1,3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_335boxwhisker = {"boxwhisker", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_335boxwhisker, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_334boxwhisker};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_335boxwhisker(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("boxwhisker (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "boxwhisker", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_334boxwhisker(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_334boxwhisker(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("boxwhisker", 1);

  /* "giacpy/auto-methods.pxi":2033
 * 
 *         '''
 *         return GiacMethods['boxwhisker'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def brent_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_boxwhisker); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2033, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2021
 *         return GiacMethods['boxcar'](self,*args)
 * 
 *      def boxwhisker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxwhisker:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.boxwhisker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2035
 *         return GiacMethods['boxwhisker'](self,*args)
 * 
 *      def brent_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brent_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_337brent_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_336brent_solver, "From Giac's documentation:\n        Help for brent_solver:\n        brent_solver(Opt)\n        Argument for fsolve giving the method for solving a numerical equation.\n        See also: 1/ fsolve \n        Ex1: fsolve(cos(x)=x,x,0..1,bisection_solver)\n        Ex2: fsolve(cos(x)=x,x,0..1,brent_solver)\n        Ex3: fsolve(cos(x)=x,x,0..1,falsepos_solver)\n        Ex4: fsolve(cos(x)=x,x,0,newton_solver)\n        Ex5: fsolve(cos(x)=x,x,0,secant_solver)\n        Ex6: fsolve(cos(x)=x,x,0,steffenson_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_337brent_solver = {"brent_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_337brent_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_336brent_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_337brent_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("brent_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "brent_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_336brent_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_336brent_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("brent_solver", 1);

  /* "giacpy/auto-methods.pxi":2049
 * 
 *         '''
 *         return GiacMethods['brent_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def brown(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_brent_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2049, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2035
 *         return GiacMethods['boxwhisker'](self,*args)
 * 
 *      def brent_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brent_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.brent_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2051
 *         return GiacMethods['brent_solver'](self,*args)
 * 
 *      def brown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brown:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_339brown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_338brown, "From Giac's documentation:\n        Help for brown:\n        brown(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_339brown = {"brown", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_339brown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_338brown};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_339brown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("brown (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "brown", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_338brown(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_338brown(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("brown", 1);

  /* "giacpy/auto-methods.pxi":2061
 * 
 *         '''
 *         return GiacMethods['brown'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bspline(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_brown); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2061, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2051
 *         return GiacMethods['brent_solver'](self,*args)
 * 
 *      def brown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brown:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.brown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2063
 *         return GiacMethods['brown'](self,*args)
 * 
 *      def bspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bspline:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_341bspline(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_340bspline, "From Giac's documentation:\n        Help for bspline:\n        bspline(Lst(c),[x[=Lst(t)||a..b],Intg(p)])\n        Returns the B-spline of degree p (default 3) defined by control points c and optionally |c|-p+1 breakpoints t in [a,b] (default a=0, b=1).\n        See also: 1/ spline 2/ bezier \n        Ex1:bspline([2i,1-2i,5-i,6-4i,8+2i,5+i],x=0..15)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_341bspline = {"bspline", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_341bspline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_340bspline};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_341bspline(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bspline (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bspline", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_340bspline(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_340bspline(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bspline", 1);

  /* "giacpy/auto-methods.pxi":2072
 * 
 *         '''
 *         return GiacMethods['bspline'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def bvpsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bspline); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2072, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2063
 *         return GiacMethods['brown'](self,*args)
 * 
 *      def bspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bspline:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bspline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2074
 *         return GiacMethods['bspline'](self,*args)
 * 
 *      def bvpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bvpsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_343bvpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_342bvpsolve, "From Giac's documentation:\n        Help for bvpsolve:\n        bvpsolve(Expr(f(x,y,y')),Lst(x=a..b,y),Lst(y(a),y(b),[y'(1)]),[options])\n        Returns an approximation of the function y (and optionally of y') on the interval a..b.\n        See also: 1/ odesolve \n        Ex1:bvpsolve((32+2x^3-y*diff(y(x),x))/8,[x=1..3,y],[17,43/3],20)\n        Ex2:bvpsolve((x^2*diff(y(x),x)^2-9y^2+4x^6)/x^5,[x=1..2,y],[0,ln(256),1],10,output=spline)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_343bvpsolve = {"bvpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_343bvpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_342bvpsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_343bvpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bvpsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bvpsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_342bvpsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_342bvpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bvpsolve", 1);

  /* "giacpy/auto-methods.pxi":2084
 * 
 *         '''
 *         return GiacMethods['bvpsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cFactor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_bvpsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2084, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2074
 *         return GiacMethods['bspline'](self,*args)
 * 
 *      def bvpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bvpsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.bvpsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2086
 *         return GiacMethods['bvpsolve'](self,*args)
 * 
 *      def cFactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cFactor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_345cFactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_344cFactor, "From Giac's documentation:\n        Help for cFactor:\n        cFactor(Expr)\n        Factorization of the expression in \342\204\202 (on the Gaussian integers if there are more than 2 variables).\n        See also: 1/ factor \n        Ex1:cFactor(x^2*y+y)\n        Ex2:cFactor(x^2*y^2+y^2+4*x^2+4)\n        Ex3:cFactor(x^2*y^2+y^2+2*x^2+2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_345cFactor = {"cFactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_345cFactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_344cFactor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_345cFactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cFactor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cFactor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_344cFactor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_344cFactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cFactor", 1);

  /* "giacpy/auto-methods.pxi":2097
 * 
 *         '''
 *         return GiacMethods['cFactor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cSolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cFactor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2097, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2086
 *         return GiacMethods['bvpsolve'](self,*args)
 * 
 *      def cFactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cFactor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cFactor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2099
 *         return GiacMethods['cFactor'](self,*args)
 * 
 *      def cSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cSolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_347cSolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_346cSolve, "From Giac's documentation:\n        Help for cSolve:\n        cSolve(LstEq,LstVar)\n        Returns the list of complex solutions of an equation or a matrix where the rows are \342\204\202-solutions of a system of polynomial equations.\n        See also: 1/ cZeros 2/ solve 3/ fslove \n        Ex1:cSolve(x^4-1,x)\n        Ex2:cSolve(x^4-y^4 and x+y=2,[x,y])\n        Ex3:cSolve(x^4-y^4 and x+y=0 and x^2=2*x,[x,y])\n        Ex4:cSolve(u*v-u=v and v^2=u,[u,v])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_347cSolve = {"cSolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_347cSolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_346cSolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_347cSolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cSolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cSolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_346cSolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_346cSolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cSolve", 1);

  /* "giacpy/auto-methods.pxi":2111
 * 
 *         '''
 *         return GiacMethods['cSolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cZeros(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cSolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2111, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2099
 *         return GiacMethods['cFactor'](self,*args)
 * 
 *      def cSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cSolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cSolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2113
 *         return GiacMethods['cSolve'](self,*args)
 * 
 *      def cZeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cZeros:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_349cZeros(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_348cZeros, "From Giac's documentation:\n        Help for cZeros:\n        cZeros(Expr(Xpr)||LstExpr, [Var||LstVar])\n        Returns the list of complex solutions of Xpr=0 or the matrix where the rows are the solutions of the system : Xpr1=0,Xpr2=0...\n        See also: 1/ solve \n        Ex1:cZeros(x^2-1)\n        Ex2:cZeros([x^2-1,x^2-y^2],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_349cZeros = {"cZeros", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_349cZeros, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_348cZeros};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_349cZeros(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cZeros (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cZeros", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_348cZeros(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_348cZeros(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cZeros", 1);

  /* "giacpy/auto-methods.pxi":2123
 * 
 *         '''
 *         return GiacMethods['cZeros'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def camembert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cZeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2123, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2113
 *         return GiacMethods['cSolve'](self,*args)
 * 
 *      def cZeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cZeros:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cZeros", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2125
 *         return GiacMethods['cZeros'](self,*args)
 * 
 *      def camembert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for camembert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_351camembert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_350camembert, "From Giac's documentation:\n        Help for camembert:\n        camembert(Mtrx)\n        Draws pie chart of a one variable statistical series.\n        See also: 1/ bar_plot \n        Ex1:camembert([[\"France\",6],[\"Allemagne\",12],[\"Suisse\",5]])\n        Ex2:camembert([3/2,2/3,5/4,4/5,7/6,6/7,9/8,8/9,11/10])\n        Ex3:camembert([[2,\"xyz\",\"abc\"],[\"A\",2,5],[\"B\",5,6],[\"C\",7,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_351camembert = {"camembert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_351camembert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_350camembert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_351camembert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("camembert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "camembert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_350camembert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_350camembert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("camembert", 1);

  /* "giacpy/auto-methods.pxi":2136
 * 
 *         '''
 *         return GiacMethods['camembert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def canonical_form(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_camembert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2136, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2125
 *         return GiacMethods['cZeros'](self,*args)
 * 
 *      def camembert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for camembert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.camembert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2138
 *         return GiacMethods['camembert'](self,*args)
 * 
 *      def canonical_form(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_form:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_353canonical_form(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_352canonical_form, "From Giac's documentation:\n        Help for canonical_form:\n        canonical_form(Trinom(a*x^2+b*x+c),[Var])\n        Canonical_form of a 2nd degree polynomial.\n        See also: 1/  \n        Ex1:canonical_form(2*x^2-12*x+1)\n        Ex2:canonical_form(2*a^2-12*a+1,a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_353canonical_form = {"canonical_form", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_353canonical_form, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_352canonical_form};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_353canonical_form(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("canonical_form (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "canonical_form", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_352canonical_form(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_352canonical_form(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("canonical_form", 1);

  /* "giacpy/auto-methods.pxi":2148
 * 
 *         '''
 *         return GiacMethods['canonical_form'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def canonical_labeling(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_canonical_form); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2148, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2138
 *         return GiacMethods['camembert'](self,*args)
 * 
 *      def canonical_form(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_form:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.canonical_form", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2150
 *         return GiacMethods['canonical_form'](self,*args)
 * 
 *      def canonical_labeling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_labeling:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_355canonical_labeling(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_354canonical_labeling, "From Giac's documentation:\n        Help for canonical_labeling:\n        canonical_labeling(Graph(G))\n        Returns the canonical labeling of G as a permutation.\n        See also: 1/ isomorphic_copy 2/ relabel_vertices \n        Ex1:canonical_labeling(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_355canonical_labeling = {"canonical_labeling", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_355canonical_labeling, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_354canonical_labeling};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_355canonical_labeling(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("canonical_labeling (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "canonical_labeling", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_354canonical_labeling(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_354canonical_labeling(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("canonical_labeling", 1);

  /* "giacpy/auto-methods.pxi":2159
 * 
 *         '''
 *         return GiacMethods['canonical_labeling'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cartesian_product(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_canonical_labeling); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2159, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2150
 *         return GiacMethods['canonical_form'](self,*args)
 * 
 *      def canonical_labeling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_labeling:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.canonical_labeling", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2161
 *         return GiacMethods['canonical_labeling'](self,*args)
 * 
 *      def cartesian_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cartesian_product:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_357cartesian_product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_356cartesian_product, "From Giac's documentation:\n        Help for cartesian_product:\n        cartesian_product(Seq(G1,G2,..))\n        Returns the Cartesian product of graphs G1, G2, ... with vertices labeled as \"u:v:...\" where u, v, ... are vertices from G1, G2, ..., respectively.\n        See also: 1/ tensor_product \n        Ex1:cartesian_product(graph(trail(1,2,3,4,5,2)),star_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_357cartesian_product = {"cartesian_product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_357cartesian_product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_356cartesian_product};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_357cartesian_product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cartesian_product (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cartesian_product", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_356cartesian_product(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_356cartesian_product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cartesian_product", 1);

  /* "giacpy/auto-methods.pxi":2170
 * 
 *         '''
 *         return GiacMethods['cartesian_product'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cauchy(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cartesian_product); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2170, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2161
 *         return GiacMethods['canonical_labeling'](self,*args)
 * 
 *      def cartesian_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cartesian_product:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cartesian_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2172
 *         return GiacMethods['cartesian_product'](self,*args)
 * 
 *      def cauchy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_359cauchy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_358cauchy, "From Giac's documentation:\n        Help for cauchy:\n        cauchy(Real(x0),Real(a),Real(x))\n        Returns the density of probability at x of the Cauchy law with parameters x0 and a (by default x0=0 and a=1).\n        See also: 1/ cauchy_cdf 2/ cauchy_icdf \n        Ex1:cauchy(0.0,2.0,1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_359cauchy = {"cauchy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_359cauchy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_358cauchy};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_359cauchy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cauchy (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cauchy", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_358cauchy(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_358cauchy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cauchy", 1);

  /* "giacpy/auto-methods.pxi":2181
 * 
 *         '''
 *         return GiacMethods['cauchy'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cauchy_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cauchy); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2181, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2172
 *         return GiacMethods['cartesian_product'](self,*args)
 * 
 *      def cauchy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cauchy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2183
 *         return GiacMethods['cauchy'](self,*args)
 * 
 *      def cauchy_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_361cauchy_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_360cauchy_cdf, "From Giac's documentation:\n        Help for cauchy_cdf:\n        cauchy_cdf(Real(x0),Real(a),Real(x),[Real(y)])\n        Returns the probability that a Cauchy random variable is less than x.\n        See also: 1/ cauchyd 2/ cauchy_icdf \n        Ex1:cauchy_cdf(0.0,2.0,2.1)\n        Ex2:cauchy_cdf(2,3,-1.9,1.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_361cauchy_cdf = {"cauchy_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_361cauchy_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_360cauchy_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_361cauchy_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cauchy_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cauchy_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_360cauchy_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_360cauchy_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cauchy_cdf", 1);

  /* "giacpy/auto-methods.pxi":2193
 * 
 *         '''
 *         return GiacMethods['cauchy_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cauchy_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cauchy_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2193, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2183
 *         return GiacMethods['cauchy'](self,*args)
 * 
 *      def cauchy_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cauchy_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2195
 *         return GiacMethods['cauchy_cdf'](self,*args)
 * 
 *      def cauchy_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_363cauchy_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_362cauchy_icdf, "From Giac's documentation:\n        Help for cauchy_icdf:\n        cauchy_icdf(Real(x0),Real(a),Real(p))\n        Returns h such that the probability that a Cauchy random variable is less than h is p (0<=p<=1).\n        See also: 1/ cauchy_cdf 2/ cauchy \n        Ex1:cauchy_icdf(0.0,2.0,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_363cauchy_icdf = {"cauchy_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_363cauchy_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_362cauchy_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_363cauchy_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cauchy_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cauchy_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_362cauchy_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_362cauchy_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cauchy_icdf", 1);

  /* "giacpy/auto-methods.pxi":2204
 * 
 *         '''
 *         return GiacMethods['cauchy_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cauchyd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cauchy_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2204, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2195
 *         return GiacMethods['cauchy_cdf'](self,*args)
 * 
 *      def cauchy_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cauchy_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2206
 *         return GiacMethods['cauchy_icdf'](self,*args)
 * 
 *      def cauchyd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_365cauchyd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_364cauchyd, "From Giac's documentation:\n        Help for cauchyd:\n        cauchyd(Real(x0),Real(a),Real(x))\n        Returns the density of probability at x of the Cauchy law with parameters x0 and a (by default x0=0 and a=1).\n        See also: 1/ cauchy_cdf 2/ cauchy_icdf \n        Ex1:cauchyd(0.0,2.0,1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_365cauchyd = {"cauchyd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_365cauchyd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_364cauchyd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_365cauchyd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cauchyd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cauchyd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_364cauchyd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_364cauchyd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cauchyd", 1);

  /* "giacpy/auto-methods.pxi":2215
 * 
 *         '''
 *         return GiacMethods['cauchyd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cauchyd_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cauchyd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2215, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2206
 *         return GiacMethods['cauchy_icdf'](self,*args)
 * 
 *      def cauchyd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cauchyd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2217
 *         return GiacMethods['cauchyd'](self,*args)
 * 
 *      def cauchyd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_367cauchyd_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_366cauchyd_cdf, "From Giac's documentation:\n        Help for cauchyd_cdf:\n        cauchyd_cdf(Real(x0),Real(a),Real(x),[Real(y)])\n        Returns the probability that a Cauchy random variable is less than x.\n        See also: 1/ cauchyd 2/ cauchy_icdf \n        Ex1:cauchyd_cdf(0.0,2.0,2.1)\n        Ex2:cauchyd_cdf(2,3,-1.9,1.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_367cauchyd_cdf = {"cauchyd_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_367cauchyd_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_366cauchyd_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_367cauchyd_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cauchyd_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cauchyd_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_366cauchyd_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_366cauchyd_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cauchyd_cdf", 1);

  /* "giacpy/auto-methods.pxi":2227
 * 
 *         '''
 *         return GiacMethods['cauchyd_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cauchyd_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cauchyd_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2227, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2217
 *         return GiacMethods['cauchyd'](self,*args)
 * 
 *      def cauchyd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cauchyd_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2229
 *         return GiacMethods['cauchyd_cdf'](self,*args)
 * 
 *      def cauchyd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_369cauchyd_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_368cauchyd_icdf, "From Giac's documentation:\n        Help for cauchyd_icdf:\n        cauchyd_icdf(Real(x0),Real(a),Real(p))\n        Returns h such that the probability that a Cauchy random variable is less than h is p (0<=p<=1).\n        See also: 1/ cauchy_cdf 2/ cauchy \n        Ex1:cauchyd_icdf(0.0,2.0,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_369cauchyd_icdf = {"cauchyd_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_369cauchyd_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_368cauchyd_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_369cauchyd_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cauchyd_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cauchyd_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_368cauchyd_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_368cauchyd_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cauchyd_icdf", 1);

  /* "giacpy/auto-methods.pxi":2238
 * 
 *         '''
 *         return GiacMethods['cauchyd_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cauchyd_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2238, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2229
 *         return GiacMethods['cauchyd_cdf'](self,*args)
 * 
 *      def cauchyd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cauchyd_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2240
 *         return GiacMethods['cauchyd_icdf'](self,*args)
 * 
 *      def cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_371cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_370cdf, "From Giac's documentation:\n        Help for cdf:\n        cdf(Func,FuncParams)\n        Cumulative distribution function.\n        See also: 1/ icdf 2/ binomial_cdf 3/ normald_cdf 4/ plotcdf \n        Ex1:cdf(binomial,10,0.5,4)\n        Ex2:cdf(normald,0.0,1.0,2.0)\n        Ex3:cdf([1,3,4,3,5,6],4)\n        Ex4:cdf([1,3,4,3,5,6],plot)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_371cdf = {"cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_371cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_370cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_371cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_370cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_370cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cdf", 1);

  /* "giacpy/auto-methods.pxi":2252
 * 
 *         '''
 *         return GiacMethods['cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ceil(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2252, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2240
 *         return GiacMethods['cauchyd_icdf'](self,*args)
 * 
 *      def cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2254
 *         return GiacMethods['cdf'](self,*args)
 * 
 *      def ceil(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceil:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_373ceil(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_372ceil, "From Giac's documentation:\n        Help for ceil:\n        ceil(Real or Cplx)\n        Returns the smallest integer >= to the argument.\n        See also: 1/ floor 2/ round \n        Ex1:ceil(-4.2)\n        Ex2:ceil(4.3+2.4*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_373ceil = {"ceil", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_373ceil, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_372ceil};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_373ceil(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ceil (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ceil", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_372ceil(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_372ceil(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ceil", 1);

  /* "giacpy/auto-methods.pxi":2264
 * 
 *         '''
 *         return GiacMethods['ceil'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ceiling(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ceil); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2264, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2254
 *         return GiacMethods['cdf'](self,*args)
 * 
 *      def ceil(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceil:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ceil", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2266
 *         return GiacMethods['ceil'](self,*args)
 * 
 *      def ceiling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceiling:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_375ceiling(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_374ceiling, "From Giac's documentation:\n        Help for ceiling:\n        ceiling(Real or Cplx)\n        Returns the smallest integer >= to the argument.\n        See also: 1/ floor 2/ round \n        Ex1:ceiling(-4.2)\n        Ex2:ceiling(4.3+2.4*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_375ceiling = {"ceiling", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_375ceiling, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_374ceiling};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_375ceiling(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ceiling (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ceiling", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_374ceiling(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_374ceiling(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ceiling", 1);

  /* "giacpy/auto-methods.pxi":2276
 * 
 *         '''
 *         return GiacMethods['ceiling'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def center(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ceiling); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2276, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2266
 *         return GiacMethods['ceil'](self,*args)
 * 
 *      def ceiling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceiling:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ceiling", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2278
 *         return GiacMethods['ceiling'](self,*args)
 * 
 *      def center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_377center(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_376center, "From Giac's documentation:\n        Help for center:\n        center(Crcle)\n        Returns the center of a circle or sphere. For ellipse or hyperbola, returns center, one focus and a point on the conic. For a parabola, returns focus and vertex.\n        See also: 1/ circle 2/ radius \n        Ex1:center(circle(1+i,2))\n        Ex2:center(circumcircle(0,1,1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_377center = {"center", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_377center, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_376center};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_377center(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("center (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "center", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_376center(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_376center(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("center", 1);

  /* "giacpy/auto-methods.pxi":2288
 * 
 *         '''
 *         return GiacMethods['center'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def center2interval(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_center); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2288, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2278
 *         return GiacMethods['ceiling'](self,*args)
 * 
 *      def center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.center", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2290
 *         return GiacMethods['center'](self,*args)
 * 
 *      def center2interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center2interval:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_379center2interval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_378center2interval, "From Giac's documentation:\n        Help for center2interval:\n        center2interval(LstVal(l),[Real(a0)])\n        Returns the list of intervals beginning with a0 and with l as centers.\n        See also: 1/ interval2center \n        Ex1:center2interval([2,5,9],1)\n        Ex2:center2interval([2,5,8])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_379center2interval = {"center2interval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_379center2interval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_378center2interval};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_379center2interval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("center2interval (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "center2interval", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_378center2interval(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_378center2interval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("center2interval", 1);

  /* "giacpy/auto-methods.pxi":2300
 * 
 *         '''
 *         return GiacMethods['center2interval'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def centered_cube(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_center2interval); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2300, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2290
 *         return GiacMethods['center'](self,*args)
 * 
 *      def center2interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center2interval:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.center2interval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2302
 *         return GiacMethods['center2interval'](self,*args)
 * 
 *      def centered_cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_cube:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_381centered_cube(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_380centered_cube, "From Giac's documentation:\n        Help for centered_cube:\n        centered_cube(Pnt(A),Pnt(B),Pnt(C))\n        Draws the direct cube with center A, vertex B and such that the plane ABC contains an axis of symmetry of the cube.\n        See also: 1/ parallelepiped 2/ cube 3/ icosahedron 4/ dodecahedron 5/ octahedron 6/ centered_tetrahedron \n        Ex1:centered_cube([0,0,0],[3,0,0],[0,0,1])\n        Ex2:centered_cube(evalf([0,0,0],[3,2,4],[1,1,0]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_381centered_cube = {"centered_cube", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_381centered_cube, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_380centered_cube};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_381centered_cube(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("centered_cube (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "centered_cube", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_380centered_cube(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_380centered_cube(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("centered_cube", 1);

  /* "giacpy/auto-methods.pxi":2312
 * 
 *         '''
 *         return GiacMethods['centered_cube'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def centered_tetrahedron(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_centered_cube); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2312, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2302
 *         return GiacMethods['center2interval'](self,*args)
 * 
 *      def centered_cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_cube:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.centered_cube", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2314
 *         return GiacMethods['centered_cube'](self,*args)
 * 
 *      def centered_tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_tetrahedron:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_383centered_tetrahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_382centered_tetrahedron, "From Giac's documentation:\n        Help for centered_tetrahedron:\n        centered_tetrahedron(Pnt(A),Pnt(B),Pnt(C))\n        Draws the regular direct pyramid with center A, vertex B and a vertex in the plane (A,B,C).\n        See also: 1/ cube 2/ tetrahedron 3/ icosahedron 4/ dodecahedron 5/ octahedron \n        Ex1:centered_tetrahedron([0,0,0],[3,0,0],[0,1,0])\n        Ex2:centered_tetrahedron(evalf([0,0,0],[3,2,4],[1,1,0]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_383centered_tetrahedron = {"centered_tetrahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_383centered_tetrahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_382centered_tetrahedron};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_383centered_tetrahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("centered_tetrahedron (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "centered_tetrahedron", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_382centered_tetrahedron(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_382centered_tetrahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("centered_tetrahedron", 1);

  /* "giacpy/auto-methods.pxi":2324
 * 
 *         '''
 *         return GiacMethods['centered_tetrahedron'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cfactor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_centered_tetrahedron); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2324, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2314
 *         return GiacMethods['centered_cube'](self,*args)
 * 
 *      def centered_tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_tetrahedron:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.centered_tetrahedron", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2326
 *         return GiacMethods['centered_tetrahedron'](self,*args)
 * 
 *      def cfactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfactor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_385cfactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_384cfactor, "From Giac's documentation:\n        Help for cfactor:\n        cfactor(Expr)\n        Factorization of the expression in \342\204\202 (on the Gaussian integers if there are more than 2 variables).\n        See also: 1/ factor \n        Ex1:cfactor(x^2*y+y)\n        Ex2:cfactor(x^2*y^2+y^2+4*x^2+4)\n        Ex3:cfactor(x^2*y^2+y^2+2*x^2+2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_385cfactor = {"cfactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_385cfactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_384cfactor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_385cfactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cfactor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cfactor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_384cfactor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_384cfactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cfactor", 1);

  /* "giacpy/auto-methods.pxi":2337
 * 
 *         '''
 *         return GiacMethods['cfactor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cfsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cfactor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2337, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2326
 *         return GiacMethods['centered_tetrahedron'](self,*args)
 * 
 *      def cfactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfactor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cfactor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2339
 *         return GiacMethods['cfactor'](self,*args)
 * 
 *      def cfsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_387cfsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_386cfsolve, "From Giac's documentation:\n        Help for cfsolve:\n        cfsolve(Expr,Var,[Guess or Interval],[Method])\n        Numerical solution of an equation or a system of equations on \342\204\202.\n        See also: 1/ fsolve 2/ nSolve 3/ csolve 4/ solve \n        Ex1:cfsolve(cos(x)=2)\n        Ex2:cfsolve([x^2+y+2,x+y^2+2],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_387cfsolve = {"cfsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_387cfsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_386cfsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_387cfsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cfsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cfsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_386cfsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_386cfsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cfsolve", 1);

  /* "giacpy/auto-methods.pxi":2349
 * 
 *         '''
 *         return GiacMethods['cfsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def changebase(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cfsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2349, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2339
 *         return GiacMethods['cfactor'](self,*args)
 * 
 *      def cfsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cfsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2351
 *         return GiacMethods['cfsolve'](self,*args)
 * 
 *      def changebase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for changebase:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_389changebase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_388changebase, "From Giac's documentation:\n        Help for changebase:\n        changebase(Mtrx(A),Mtrx(P))\n        Returns the matrix B=inv(P)*A*P.\n        See also: 1/  \n        Ex1:changebase([[1,2],[1,3]],[[1,1],[0,1]])\n        Ex2:changebase([[1,2],[1,3]],[[1,0],[1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_389changebase = {"changebase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_389changebase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_388changebase};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_389changebase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("changebase (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "changebase", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_388changebase(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_388changebase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("changebase", 1);

  /* "giacpy/auto-methods.pxi":2361
 * 
 *         '''
 *         return GiacMethods['changebase'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def channel_data(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_changebase); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2361, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2351
 *         return GiacMethods['cfsolve'](self,*args)
 * 
 *      def changebase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for changebase:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.changebase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2363
 *         return GiacMethods['changebase'](self,*args)
 * 
 *      def channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channel_data:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_391channel_data(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_390channel_data, "From Giac's documentation:\n        Help for channel_data:\n        channel_data(Audio(clip),[Intg(chn) or matrix],[range=a..b]||Image(img),Intg(chn),Intg(x),Intg(y),Intg(width),Intg(height))\n        Extracts the data from an audio clip (optionally specifying the channel and range) or image object (by specifying a rectangular portion).\n        See also: 1/ set_channel_data 2/ channels \n        Ex1:channel_data(readwav(\"/some/file\"))\n        Ex2:channel_data(readwav(\"/some/file\"),matrix)\n        Ex3:channel_data(readwav(\"/some/file\"),2)\n        Ex4:channel_data(readwav(\"/some/file\"),matrix,range=1.0..2.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_391channel_data = {"channel_data", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_391channel_data, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_390channel_data};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_391channel_data(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("channel_data (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "channel_data", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_390channel_data(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_390channel_data(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("channel_data", 1);

  /* "giacpy/auto-methods.pxi":2375
 * 
 *         '''
 *         return GiacMethods['channel_data'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def channels(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_channel_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2375, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2363
 *         return GiacMethods['changebase'](self,*args)
 * 
 *      def channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channel_data:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.channel_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2377
 *         return GiacMethods['channel_data'](self,*args)
 * 
 *      def channels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channels:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_393channels(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_392channels, "From Giac's documentation:\n        Help for channels:\n        channels(Audio(clip)||Image(img))\n        Returns the number of channels in an audio clip or image object.\n        See also: 1/ bit_depth 2/ channel_data 3/ duration 4/ samplerate \n        Ex1:channels(readwav(\"/some/file\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_393channels = {"channels", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_393channels, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_392channels};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_393channels(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("channels (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "channels", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_392channels(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_392channels(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("channels", 1);

  /* "giacpy/auto-methods.pxi":2386
 * 
 *         '''
 *         return GiacMethods['channels'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def char(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_channels); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2386, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2377
 *         return GiacMethods['channel_data'](self,*args)
 * 
 *      def channels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channels:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.channels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2388
 *         return GiacMethods['channels'](self,*args)
 * 
 *      def char(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for char:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_395char(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_394char, "From Giac's documentation:\n        Help for char:\n        char(Intg or Lst(Intg))\n        Returns the string corresponding to the character code of the argument.\n        See also: 1/ asc 2/ ord \n        Ex1:char(65)\n        Ex2:char([65,66,67])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_395char = {"char", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_395char, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_394char};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_395char(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("char (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "char", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_394char(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_394char(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("char", 1);

  /* "giacpy/auto-methods.pxi":2398
 * 
 *         '''
 *         return GiacMethods['char'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def charpoly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_char); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2398, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2388
 *         return GiacMethods['channels'](self,*args)
 * 
 *      def char(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for char:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.char", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2400
 *         return GiacMethods['char'](self,*args)
 * 
 *      def charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for charpoly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_397charpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_396charpoly, "From Giac's documentation:\n        Help for charpoly:\n        charpoly(Mtrx,[Var])\n        List of the coefficients of the characteristic polynomial of a matrix or characteristic polynomial of a matrix with the second argument as variable.\n        See also: 1/ jordan 2/ egv 3/ egvl 4/ companion 5/ rat_jordan 6/ pmin 7/ adjoint_matrix  \n        Ex1:charpoly([[1,2],[3,4]])\n        Ex2:charpoly([[1,2],[3,4]],x)\n        Ex3:charpoly([[1,2,3],[1,3,6],[2,5,7]])\n        Ex4:charpoly([[1,2,3],[1,3,6],[2,5,7]],z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_397charpoly = {"charpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_397charpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_396charpoly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_397charpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("charpoly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "charpoly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_396charpoly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_396charpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("charpoly", 1);

  /* "giacpy/auto-methods.pxi":2412
 * 
 *         '''
 *         return GiacMethods['charpoly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chinrem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_charpoly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2412, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2400
 *         return GiacMethods['char'](self,*args)
 * 
 *      def charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for charpoly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.charpoly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2414
 *         return GiacMethods['charpoly'](self,*args)
 * 
 *      def chinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chinrem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_399chinrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_398chinrem, "From Giac's documentation:\n        Help for chinrem:\n        chinrem([Lst||Expr,Lst||Expr],[Lst||Expr,Lst||Expr])\n        Chinese remainder for polynomials written as lists or no.\n        See also: 1/ ichinrem \n        Ex1:chinrem([x+2,x^2+1],[x+1,x^2+x+1])\n        Ex2:chinrem([[1,2],[1,0,1]],[[1,1],[1,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_399chinrem = {"chinrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_399chinrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_398chinrem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_399chinrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chinrem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chinrem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_398chinrem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_398chinrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chinrem", 1);

  /* "giacpy/auto-methods.pxi":2424
 * 
 *         '''
 *         return GiacMethods['chinrem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquare(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chinrem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2424, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2414
 *         return GiacMethods['charpoly'](self,*args)
 * 
 *      def chinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chinrem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chinrem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2426
 *         return GiacMethods['chinrem'](self,*args)
 * 
 *      def chisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_401chisquare(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_400chisquare, "From Giac's documentation:\n        Help for chisquare:\n        chisquare(Intg(n),Real(x0))\n        Returns the probability density of the Chi^2 law at x0 (n is the number of degrees of freedom).\n        See also: 1/ chisquare_cdf 2/ chisquare_icdf 3/ randvector 4/ ranm \n        Ex1:chisquare(2,3.2)\n        Ex2:chisquare(4,10.5)\n        Ex3: randvector(3,chisquare,2)\n        Ex4: ranm(4,3,chisquare,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_401chisquare = {"chisquare", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_401chisquare, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_400chisquare};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_401chisquare(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquare (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquare", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_400chisquare(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_400chisquare(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquare", 1);

  /* "giacpy/auto-methods.pxi":2438
 * 
 *         '''
 *         return GiacMethods['chisquare'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquare_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquare); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2438, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2426
 *         return GiacMethods['chinrem'](self,*args)
 * 
 *      def chisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquare", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2440
 *         return GiacMethods['chisquare'](self,*args)
 * 
 *      def chisquare_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_403chisquare_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_402chisquare_cdf, "From Giac's documentation:\n        Help for chisquare_cdf:\n        chisquare_cdf(Intg(n),Real(x0))\n        Returns the probability that a Chi^2 random variable is less than x0 (n is the number of degrees of freedom).\n        See also: 1/ UTPC 2/ chisquare_icdf 3/ chisquared \n        Ex1:chisquare_cdf(2,6.1)\n        Ex2:chisquare_cdf(4,6.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_403chisquare_cdf = {"chisquare_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_403chisquare_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_402chisquare_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_403chisquare_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquare_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquare_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_402chisquare_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_402chisquare_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquare_cdf", 1);

  /* "giacpy/auto-methods.pxi":2450
 * 
 *         '''
 *         return GiacMethods['chisquare_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquare_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquare_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2450, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2440
 *         return GiacMethods['chisquare'](self,*args)
 * 
 *      def chisquare_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquare_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2452
 *         return GiacMethods['chisquare_cdf'](self,*args)
 * 
 *      def chisquare_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_405chisquare_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_404chisquare_icdf, "From Giac's documentation:\n        Help for chisquare_icdf:\n        chisquare_icdf(Intg(n),Real(p))\n        Returns h such as the probability that a Chi^2 random variable is less than h is p (n is the number of degrees of freedom and 0<=p<=1).\n        See also: 1/ chisquare_cdf 2/ chisquared \n        Ex1:chisquare_icdf(2,0.95)\n        Ex2:chisquare_icdf(4,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_405chisquare_icdf = {"chisquare_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_405chisquare_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_404chisquare_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_405chisquare_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquare_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquare_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_404chisquare_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_404chisquare_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquare_icdf", 1);

  /* "giacpy/auto-methods.pxi":2462
 * 
 *         '''
 *         return GiacMethods['chisquare_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquared(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquare_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2462, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2452
 *         return GiacMethods['chisquare_cdf'](self,*args)
 * 
 *      def chisquare_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquare_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2464
 *         return GiacMethods['chisquare_icdf'](self,*args)
 * 
 *      def chisquared(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_407chisquared(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_406chisquared, "From Giac's documentation:\n        Help for chisquared:\n        chisquared(Intg(n),Real(x0))\n        Returns the probability density of the Chi^2 law at x0 (n is the number of degrees of freedom).\n        See also: 1/ chisquare_cdf 2/ chisquare_icdf 3/ randvector 4/ ranm \n        Ex1:chisquared(2,3.2)\n        Ex2:chisquared(4,10.5)\n        Ex3: randvector(3,chisquare,2)\n        Ex4: ranm(4,3,chisquare,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_407chisquared = {"chisquared", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_407chisquared, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_406chisquared};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_407chisquared(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquared (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquared", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_406chisquared(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_406chisquared(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquared", 1);

  /* "giacpy/auto-methods.pxi":2476
 * 
 *         '''
 *         return GiacMethods['chisquared'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquared_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquared); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2476, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2464
 *         return GiacMethods['chisquare_icdf'](self,*args)
 * 
 *      def chisquared(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquared", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2478
 *         return GiacMethods['chisquared'](self,*args)
 * 
 *      def chisquared_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_409chisquared_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_408chisquared_cdf, "From Giac's documentation:\n        Help for chisquared_cdf:\n        chisquared_cdf(Intg(n),Real(x0))\n        Returns the probability that a Chi^2 random variable is less than x0 (n is the number of degrees of freedom).\n        See also: 1/ UTPC 2/ chisquare_icdf 3/ chisquared \n        Ex1:chisquared_cdf(2,6.1)\n        Ex2:chisquared_cdf(4,6.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_409chisquared_cdf = {"chisquared_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_409chisquared_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_408chisquared_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_409chisquared_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquared_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquared_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_408chisquared_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_408chisquared_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquared_cdf", 1);

  /* "giacpy/auto-methods.pxi":2488
 * 
 *         '''
 *         return GiacMethods['chisquared_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquared_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquared_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2488, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2478
 *         return GiacMethods['chisquared'](self,*args)
 * 
 *      def chisquared_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquared_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2490
 *         return GiacMethods['chisquared_cdf'](self,*args)
 * 
 *      def chisquared_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_411chisquared_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_410chisquared_icdf, "From Giac's documentation:\n        Help for chisquared_icdf:\n        chisquared_icdf(Intg(n),Real(p))\n        Returns h such as the probability that a Chi^2 random variable is less than h is p (n is the number of degrees of freedom and 0<=p<=1).\n        See also: 1/ chisquare_cdf 2/ chisquared \n        Ex1:chisquared_icdf(2,0.95)\n        Ex2:chisquared_icdf(4,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_411chisquared_icdf = {"chisquared_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_411chisquared_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_410chisquared_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_411chisquared_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquared_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquared_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_410chisquared_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_410chisquared_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquared_icdf", 1);

  /* "giacpy/auto-methods.pxi":2500
 * 
 *         '''
 *         return GiacMethods['chisquared_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chisquaret(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquared_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2500, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2490
 *         return GiacMethods['chisquared_cdf'](self,*args)
 * 
 *      def chisquared_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquared_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2502
 *         return GiacMethods['chisquared_icdf'](self,*args)
 * 
 *      def chisquaret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquaret:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_413chisquaret(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_412chisquaret, "From Giac's documentation:\n        Help for chisquaret:\n        chisquaret(Data,[Func],[FuncParams])\n        Chi^2 test : fitness between 2 (or n) samples or between 1 sample and a distribution law (multinomial or given by a law).\n        See also: 1/ normalt 2/ studentt 3/ kolmogorovt \n        Ex1:chisquaret([57,54])\n        Ex2:chisquaret([1,1,1,1,1,0,0,1,0,0,1,1,1,0,1,1,0,1,1,0,0,0,0],[.4,.6])\n        Ex3:chisquaret([57,30],[.6,.4])\n        Ex4:chisquaret([17,15,12,15],[15,13,13,14])\n        Ex5:chisquaret(ranv(1000,binomial,10,.5),binomial)\n        Ex6:chisquaret(ranv(1000,binomial,10,.5),binomial,11,.5)\n        Ex7:chisquaret(ranv(1000,normald,0,.2),normald)\n        Ex8:chisquaret([11,16,17,22,14,10],[1/6,1/6,1/6,1/6,1/6,1/6])\n        Ex9:chisquaret([11,16,17,22,14,10],[(1/6)$6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_413chisquaret = {"chisquaret", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_413chisquaret, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_412chisquaret};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_413chisquaret(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chisquaret (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chisquaret", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_412chisquaret(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_412chisquaret(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chisquaret", 1);

  /* "giacpy/auto-methods.pxi":2519
 * 
 *         '''
 *         return GiacMethods['chisquaret'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def choice(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chisquaret); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2519, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2502
 *         return GiacMethods['chisquared_icdf'](self,*args)
 * 
 *      def chisquaret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquaret:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chisquaret", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2521
 *         return GiacMethods['chisquaret'](self,*args)
 * 
 *      def choice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for choice:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_415choice(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_414choice, "From Giac's documentation:\n        Help for choice:\n        choice(Lst(L))\n        choice(L)=rand(L)=one extracted element of L.\n        See also: 1/ rand  2/ sample \n        Ex1:choice([1,2,3,4,5,6])\n        Ex2:choice([\"r\",\"r\",\"r\",\"b\",\"n\"])\n        Ex3: L:=[1,2,3,4,5,6];L:=choice(L)\n        Ex4: L:=[1,2,3,4,5,6];L.choice()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_415choice = {"choice", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_415choice, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_414choice};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_415choice(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("choice (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "choice", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_414choice(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_414choice(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("choice", 1);

  /* "giacpy/auto-methods.pxi":2533
 * 
 *         '''
 *         return GiacMethods['choice'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cholesky(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_choice); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2533, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2521
 *         return GiacMethods['chisquaret'](self,*args)
 * 
 *      def choice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for choice:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.choice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2535
 *         return GiacMethods['choice'](self,*args)
 * 
 *      def cholesky(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cholesky:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_417cholesky(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_416cholesky, "From Giac's documentation:\n        Help for cholesky:\n        cholesky(Mtrx)\n        For a numerical symmetric matrix A, returns L matrix such that A=L*tran(L).\n        See also: 1/ lu 2/ qr 3/ gauss \n        Ex1:cholesky([[3,1],[1,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_417cholesky = {"cholesky", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_417cholesky, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_416cholesky};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_417cholesky(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cholesky (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cholesky", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_416cholesky(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_416cholesky(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cholesky", 1);

  /* "giacpy/auto-methods.pxi":2544
 * 
 *         '''
 *         return GiacMethods['cholesky'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cholesky); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2544, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2535
 *         return GiacMethods['choice'](self,*args)
 * 
 *      def cholesky(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cholesky:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cholesky", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2546
 *         return GiacMethods['cholesky'](self,*args)
 * 
 *      def chr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_419chr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_418chr, "From Giac's documentation:\n        Help for chr:\n        chr(Intg or Lst(Intg))\n        Returns the string corresponding to the character code of the argument.\n        See also: 1/ asc 2/ ord \n        Ex1:chr(65)\n        Ex2:chr([65,66,67])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_419chr = {"chr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_419chr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_418chr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_419chr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_418chr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_418chr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chr", 1);

  /* "giacpy/auto-methods.pxi":2556
 * 
 *         '''
 *         return GiacMethods['chr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chrem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2556, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2546
 *         return GiacMethods['cholesky'](self,*args)
 * 
 *      def chr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2558
 *         return GiacMethods['chr'](self,*args)
 * 
 *      def chrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chrem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_421chrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_420chrem, "From Giac's documentation:\n        Help for chrem:\n        chrem(LstIntg(a,b,c....),LstIntg(p,q,r,....))\n        Chinese remainders for integers or for polynomials.\n        See also: 1/ gcd 2/ fracmod 3/ chinrem 4/ ichinrem \n        Ex1:chrem(symbolique.)\n        Ex2:chrem([2,3],[7,5])\n        Ex3:chrem([2,4,6],[3,5,7])\n        Ex4:chrem([2,4,6,7],[3,5,7,11])\n        Ex5:chrem([2*x+1,4*x+2,6*x-1,x+1],[3,5,7,11])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_421chrem = {"chrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_421chrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_420chrem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_421chrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chrem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chrem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_420chrem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_420chrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chrem", 1);

  /* "giacpy/auto-methods.pxi":2571
 * 
 *         '''
 *         return GiacMethods['chrem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chromatic_index(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chrem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2571, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2558
 *         return GiacMethods['chr'](self,*args)
 * 
 *      def chrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chrem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chrem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2573
 *         return GiacMethods['chrem'](self,*args)
 * 
 *      def chromatic_index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_index:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_423chromatic_index(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_422chromatic_index, "From Giac's documentation:\n        Help for chromatic_index:\n        chromatic_index(Graph(G))\n        Returns the number of colors in a minimal edge coloring of G.\n        See also: 1/ minimal_edge_coloring 2/ chromatic_number \n        Ex1:chromatic_index(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_423chromatic_index = {"chromatic_index", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_423chromatic_index, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_422chromatic_index};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_423chromatic_index(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chromatic_index (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chromatic_index", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_422chromatic_index(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_422chromatic_index(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chromatic_index", 1);

  /* "giacpy/auto-methods.pxi":2582
 * 
 *         '''
 *         return GiacMethods['chromatic_index'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chromatic_number(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chromatic_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2582, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2573
 *         return GiacMethods['chrem'](self,*args)
 * 
 *      def chromatic_index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_index:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chromatic_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2584
 *         return GiacMethods['chromatic_index'](self,*args)
 * 
 *      def chromatic_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_number:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_425chromatic_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_424chromatic_number, "From Giac's documentation:\n        Help for chromatic_number:\n        chromatic_number(Graph(G))\n        Returns the chromatic number of G.\n        Ex1:chromatic_number(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_425chromatic_number = {"chromatic_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_425chromatic_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_424chromatic_number};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_425chromatic_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chromatic_number (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chromatic_number", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_424chromatic_number(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_424chromatic_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chromatic_number", 1);

  /* "giacpy/auto-methods.pxi":2592
 * 
 *         '''
 *         return GiacMethods['chromatic_number'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def chromatic_polynomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chromatic_number); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2592, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2584
 *         return GiacMethods['chromatic_index'](self,*args)
 * 
 *      def chromatic_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_number:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chromatic_number", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2594
 *         return GiacMethods['chromatic_number'](self,*args)
 * 
 *      def chromatic_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_polynomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_427chromatic_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_426chromatic_polynomial, "From Giac's documentation:\n        Help for chromatic_polynomial:\n        chromatic_polynomial(Graph(G),[Var(t)])\n        Returns the chromatic polynomial [or its value at point t] of an undirected unweighted graph G.\n        See also: 1/ flow_polynomial 2/ reliability_polynomial 3/ tutte_polynomial \n        Ex1:chromatic_polynomial(graph(\"petersen\"))\n        Ex2:chromatic_polynomial(graph(\"petersen\"),3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_427chromatic_polynomial = {"chromatic_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_427chromatic_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_426chromatic_polynomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_427chromatic_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chromatic_polynomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chromatic_polynomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_426chromatic_polynomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_426chromatic_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chromatic_polynomial", 1);

  /* "giacpy/auto-methods.pxi":2604
 * 
 *         '''
 *         return GiacMethods['chromatic_polynomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def circle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_chromatic_polynomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2604, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2594
 *         return GiacMethods['chromatic_number'](self,*args)
 * 
 *      def chromatic_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_polynomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.chromatic_polynomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2606
 *         return GiacMethods['chromatic_polynomial'](self,*args)
 * 
 *      def circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_429circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_428circle, "From Giac's documentation:\n        Help for circle:\n        circle((Pnt(M) or Cplx(M),(Pnt(N) or Cplx(zN)),[Real(a)],[Real(b)],[Var(A)],[Var(B)])\n        Define for 2-d a circle with a diameter MN (arg1=M or zM,arg2=N) or  with center and radius (arg1=M or zM,arg2=zN) and (center=M and radius=abs(zN)) [or the arc AB, A angle a, B angle b, (MN=angle 0) or M(M+zN)=angle 0] or by its equation and for 3-d with a diameter and a third point.\n        See also: 1/ circumcircle 2/ incircle 3/ excircle 4/ center 5/ radius 6/ sphere 7/ Circle \n        Ex1:circle(0,point(2*i))\n        Ex2:circle(i,i)\n        Ex3:circle(i,1)\n        Ex4:circle(0,i,pi/4,pi/2)\n        Ex5:circle(0,i,pi/4,pi/2,A,B)\n        Ex6:circle(x^2+y^2-x-y)\n        Ex7:circle(cercle(point([-1,0,0]),point([1,0,0]),point([0,2,0])))\n        Ex8:circle(cercle([-1,0,0],point([1,0,0]),[0,2,0]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_429circle = {"circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_429circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_428circle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_429circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("circle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "circle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_428circle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_428circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("circle", 1);

  /* "giacpy/auto-methods.pxi":2622
 * 
 *         '''
 *         return GiacMethods['circle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def circumcircle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_circle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2622, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2606
 *         return GiacMethods['chromatic_polynomial'](self,*args)
 * 
 *      def circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.circle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2624
 *         return GiacMethods['circle'](self,*args)
 * 
 *      def circumcircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circumcircle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_431circumcircle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_430circumcircle, "From Giac's documentation:\n        Help for circumcircle:\n        circumcircle((Pnt or Cplx),(Pnt or Cplx),((Pnt or Cplx))\n        circumcircle(A,B,C)=circumcircle of the triangle ABC.\n        See also: 1/ circle 2/ incircle 3/ excircle \n        Ex1:circumcircle(0,1,1+i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_431circumcircle = {"circumcircle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_431circumcircle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_430circumcircle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_431circumcircle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("circumcircle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "circumcircle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_430circumcircle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_430circumcircle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("circumcircle", 1);

  /* "giacpy/auto-methods.pxi":2633
 * 
 *         '''
 *         return GiacMethods['circumcircle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def classes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_circumcircle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2633, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2624
 *         return GiacMethods['circle'](self,*args)
 * 
 *      def circumcircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circumcircle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.circumcircle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2635
 *         return GiacMethods['circumcircle'](self,*args)
 * 
 *      def classes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for classes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_433classes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_432classes, "From Giac's documentation:\n        Help for classes:\n        classes(Lst(l),[ClassMin],[ClassSize||Lst(Center)])\n        Returns the matrix [[class,number],...] obtained with class_min and class_size: see init of geo or argument 2 and 3 or with the list of centers.\n        See also: 1/ histogram 2/ cumulated_frequencies 3/ bar_plot 4/ frequencies \n        Ex1:classes([1,1.2,1.4,1.6,1.8,2,2.5])\n        Ex2:classes([1,1.2,1.4,1.6,1.8,2,2.5],1.2,0.5)\n        Ex3:classes([1,1.2,1.4,1.6,1.8,2,2.5],1,[1.2,1.6,2,2.4])\n        Ex4:classes([1,1.2,1.4,1.6,1.8,2,2.5],1,[1.2,1.6,2.2])\n        Ex5:classes([0,0.5,1,1.5,2,2.5,3,3.5,4],[0..2,2..4,4..6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_433classes = {"classes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_433classes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_432classes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_433classes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("classes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "classes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_432classes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_432classes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("classes", 1);

  /* "giacpy/auto-methods.pxi":2648
 * 
 *         '''
 *         return GiacMethods['classes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def clear(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_classes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2648, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2635
 *         return GiacMethods['circumcircle'](self,*args)
 * 
 *      def classes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for classes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.classes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2650
 *         return GiacMethods['classes'](self,*args)
 * 
 *      def clear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clear:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_435clear(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_434clear, "From Giac's documentation:\n        Help for clear:\n        clear(NULL)\n        Clears the list of pixels.\n        See also: 1/ set_pixel 2/ show_pixels \n        Ex1:clear()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_435clear = {"clear", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_435clear, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_434clear};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_435clear(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "clear", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_434clear(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_434clear(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clear", 1);

  /* "giacpy/auto-methods.pxi":2659
 * 
 *         '''
 *         return GiacMethods['clear'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def clique_cover(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_clear); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2659, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2650
 *         return GiacMethods['classes'](self,*args)
 * 
 *      def clear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clear:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2661
 *         return GiacMethods['clear'](self,*args)
 * 
 *      def clique_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_437clique_cover(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_436clique_cover, "From Giac's documentation:\n        Help for clique_cover:\n        clique_cover(Graph(G),[Intg(k)])\n        Returns a clique vertex cover of G [containing at most k cliques].\n        See also: 1/ clique_cover_number 2/ maximal_cliques \n        Ex1:clique_cover(graph(\"petersen\"))\n        Ex2:clique_cover(cycle_graph(5))\n        Ex3:clique_cover(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_437clique_cover = {"clique_cover", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_437clique_cover, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_436clique_cover};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_437clique_cover(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clique_cover (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "clique_cover", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_436clique_cover(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_436clique_cover(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clique_cover", 1);

  /* "giacpy/auto-methods.pxi":2672
 * 
 *         '''
 *         return GiacMethods['clique_cover'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def clique_cover_number(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_clique_cover); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2672, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2661
 *         return GiacMethods['clear'](self,*args)
 * 
 *      def clique_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.clique_cover", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2674
 *         return GiacMethods['clique_cover'](self,*args)
 * 
 *      def clique_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover_number:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_439clique_cover_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_438clique_cover_number, "From Giac's documentation:\n        Help for clique_cover_number:\n        clique_cover_number(Graph(G))\n        Returns the clique cover number of G.\n        See also: 1/ clique_cover 3/ maximal_cliques \n        Ex1:clique_cover_number(graph(\"petersen\"))\n        Ex2:clique_cover_number(cycle_graph(5))\n        Ex3:clique_cover_number(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_439clique_cover_number = {"clique_cover_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_439clique_cover_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_438clique_cover_number};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_439clique_cover_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clique_cover_number (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "clique_cover_number", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_438clique_cover_number(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_438clique_cover_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clique_cover_number", 1);

  /* "giacpy/auto-methods.pxi":2685
 * 
 *         '''
 *         return GiacMethods['clique_cover_number'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def clique_number(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_clique_cover_number); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2685, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2674
 *         return GiacMethods['clique_cover'](self,*args)
 * 
 *      def clique_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover_number:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.clique_cover_number", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2687
 *         return GiacMethods['clique_cover_number'](self,*args)
 * 
 *      def clique_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_number:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_441clique_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_440clique_number, "From Giac's documentation:\n        Help for clique_number:\n        clique_number(Graph(G))\n        Returns the clique number of G, which is equal to the size of a maximum clique in G.\n        See also: 1/ maximum_clique \n        Ex1:clique_number(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_441clique_number = {"clique_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_441clique_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_440clique_number};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_441clique_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clique_number (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "clique_number", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_440clique_number(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_440clique_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clique_number", 1);

  /* "giacpy/auto-methods.pxi":2696
 * 
 *         '''
 *         return GiacMethods['clique_number'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def closeness_centrality(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_clique_number); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2696, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2687
 *         return GiacMethods['clique_cover_number'](self,*args)
 * 
 *      def clique_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_number:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.clique_number", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2698
 *         return GiacMethods['clique_number'](self,*args)
 * 
 *      def closeness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for closeness_centrality:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_443closeness_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_442closeness_centrality, "From Giac's documentation:\n        Help for closeness_centrality:\n        closeness_centrality(Graph(G),[Vrtx(v)])\n        Returns the closeness centrality of a vertex v in a graph G or the list of closeness centralities of vertices in G.\n        See also: 1/ degree_centrality 2/ betweenness_centrality 3/ harmonic_centrality 4/ information_centrality 5/ katz_centrality \n        Ex1:closeness_centrality(graph(6,%{[0,2],[0,5],[1,3],[1,5],[2,5],[3,4],[3,5],[4,5]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_443closeness_centrality = {"closeness_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_443closeness_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_442closeness_centrality};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_443closeness_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("closeness_centrality (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "closeness_centrality", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_442closeness_centrality(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_442closeness_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("closeness_centrality", 1);

  /* "giacpy/auto-methods.pxi":2707
 * 
 *         '''
 *         return GiacMethods['closeness_centrality'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cluster(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_closeness_centrality); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2707, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2698
 *         return GiacMethods['clique_number'](self,*args)
 * 
 *      def closeness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for closeness_centrality:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.closeness_centrality", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2709
 *         return GiacMethods['closeness_centrality'](self,*args)
 * 
 *      def cluster(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cluster:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_445cluster(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_444cluster, "From Giac's documentation:\n        Help for cluster:\n        cluster(Lst(data),[opts])\n        Perform hierarchical agglomerative clustering of the given data.\n        See also: 1/ kmeans 2/ levenshtein \n        Ex1:cluster([[1.1,1.5],[3.2,2.5],[1.5,0.9],[3.5,2.7],[0.8,1.1],[3.1,2.2]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_445cluster = {"cluster", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_445cluster, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_444cluster};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_445cluster(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cluster (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cluster", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_444cluster(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_444cluster(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cluster", 1);

  /* "giacpy/auto-methods.pxi":2718
 * 
 *         '''
 *         return GiacMethods['cluster'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def clustering_coefficient(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cluster); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2718, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2709
 *         return GiacMethods['closeness_centrality'](self,*args)
 * 
 *      def cluster(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cluster:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cluster", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2720
 *         return GiacMethods['cluster'](self,*args)
 * 
 *      def clustering_coefficient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clustering_coefficient:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_447clustering_coefficient(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_446clustering_coefficient, "From Giac's documentation:\n        Help for clustering_coefficient:\n        clustering_coefficient(Graph(G),[Vrtx(v)])\n        Returns the average clustering coefficient of an undirected graph G, or the local clustering coefficient of the vertex v in G.\n        See also: 1/ network_transitivity 2/ number_of_triangles \n        Ex1:clustering_coefficient(graph(%{[1,2],[2,3],[2,4],[3,4],[4,1]%}))\n        Ex2:clustering_coefficient(graph(%{[1,2],[2,3],[2,4],[3,4],[4,1]%}),2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_447clustering_coefficient = {"clustering_coefficient", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_447clustering_coefficient, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_446clustering_coefficient};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_447clustering_coefficient(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clustering_coefficient (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "clustering_coefficient", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_446clustering_coefficient(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_446clustering_coefficient(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clustering_coefficient", 1);

  /* "giacpy/auto-methods.pxi":2730
 * 
 *         '''
 *         return GiacMethods['clustering_coefficient'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def coeff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_clustering_coefficient); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2730, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2720
 *         return GiacMethods['cluster'](self,*args)
 * 
 *      def clustering_coefficient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clustering_coefficient:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.clustering_coefficient", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2732
 *         return GiacMethods['clustering_coefficient'](self,*args)
 * 
 *      def coeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_449coeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_448coeff, "From Giac's documentation:\n        Help for coeff:\n        coeff(Expr(P),[Var])\n        Returns the list of coefficients of a polynomial with respect to the 2nd argument or the coefficient of degree the 3rd argument.\n        See also: 1/ pcoeff 2/ fcoeff \n        Ex1:coeff(x*3+2)\n        Ex2:coeff(5*y^2-3,y)\n        Ex3:coeff(5*y^2-3,y,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_449coeff = {"coeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_449coeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_448coeff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_449coeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("coeff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "coeff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_448coeff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_448coeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coeff", 1);

  /* "giacpy/auto-methods.pxi":2743
 * 
 *         '''
 *         return GiacMethods['coeff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def coeffs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_coeff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2743, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2732
 *         return GiacMethods['clustering_coefficient'](self,*args)
 * 
 *      def coeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.coeff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2745
 *         return GiacMethods['coeff'](self,*args)
 * 
 *      def coeffs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeffs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_451coeffs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_450coeffs, "From Giac's documentation:\n        Help for coeffs:\n        coeffs(Expr(P),[Var])\n        Returns the list of coefficients of a polynomial with respect to the 2nd argument or the coefficient of degree the 3rd argument.\n        See also: 1/ pcoeff 2/ fcoeff \n        Ex1:coeffs(x*3+2)\n        Ex2:coeffs(5*y^2-3,y)\n        Ex3:coeffs(5*y^2-3,y,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_451coeffs = {"coeffs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_451coeffs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_450coeffs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_451coeffs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("coeffs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "coeffs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_450coeffs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_450coeffs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coeffs", 1);

  /* "giacpy/auto-methods.pxi":2756
 * 
 *         '''
 *         return GiacMethods['coeffs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def col(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_coeffs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2756, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2745
 *         return GiacMethods['coeff'](self,*args)
 * 
 *      def coeffs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeffs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.coeffs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2758
 *         return GiacMethods['coeffs'](self,*args)
 * 
 *      def col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for col:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_453col(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_452col, "From Giac's documentation:\n        Help for col:\n        col(Mtrx(A),Intg(n)||Interval(n1..n2))\n        Returns column n or the sequence of the columns n1..n2 of the matrix A, or optional argument of count,count_eq,count_inf,count_sup.\n        See also: 1/ row 2/ count 3/ count_eq 4/ count_inf 5/ count_sup \n        Ex1:col([[1,2,3],[4,5,6],[7,8,9]],1)\n        Ex2:col([[1,2,3],[4,5,6],[7,8,9]],0..1)\n        Ex3: count_eq(3,[[3,2,3],[4,3,2],[3,2,1]],col)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_453col = {"col", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_453col, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_452col};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_453col(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("col (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "col", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_452col(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_452col(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("col", 1);

  /* "giacpy/auto-methods.pxi":2769
 * 
 *         '''
 *         return GiacMethods['col'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colDim(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2769, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2758
 *         return GiacMethods['coeffs'](self,*args)
 * 
 *      def col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for col:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.col", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2771
 *         return GiacMethods['col'](self,*args)
 * 
 *      def colDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colDim:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_455colDim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_454colDim, "From Giac's documentation:\n        Help for colDim:\n        colDim(Mtrx)\n        Number of columns of a matrix.\n        See also: 1/ rowdim \n        Ex1:colDim([[1,2,3],[4,5,6]])\n        Ex2:colDim([[1,2],[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_455colDim = {"colDim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_455colDim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_454colDim};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_455colDim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colDim (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colDim", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_454colDim(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_454colDim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colDim", 1);

  /* "giacpy/auto-methods.pxi":2781
 * 
 *         '''
 *         return GiacMethods['colDim'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colNorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colDim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2781, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2771
 *         return GiacMethods['col'](self,*args)
 * 
 *      def colDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colDim:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colDim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2783
 *         return GiacMethods['colDim'](self,*args)
 * 
 *      def colNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colNorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_457colNorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_456colNorm, "From Giac's documentation:\n        Help for colNorm:\n        colNorm(Vect or Mtrx)\n        Returns the max of the l1_norm of the columns of a matrix: colNorm(a_{j,k})=max_k(sum_j(|a_{j,k}|)).\n        See also: 1/ norm \n        Ex1:colNorm([[1,2],[3,-4]])\n        Ex2:colNorm([[1,2,3,-4],[-5,3,2,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_457colNorm = {"colNorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_457colNorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_456colNorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_457colNorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colNorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colNorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_456colNorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_456colNorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colNorm", 1);

  /* "giacpy/auto-methods.pxi":2793
 * 
 *         '''
 *         return GiacMethods['colNorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colSwap(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colNorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2793, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2783
 *         return GiacMethods['colDim'](self,*args)
 * 
 *      def colNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colNorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colNorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2795
 *         return GiacMethods['colNorm'](self,*args)
 * 
 *      def colSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colSwap:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_459colSwap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_458colSwap, "From Giac's documentation:\n        Help for colSwap:\n        colSwap(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by swapping the n1-th column and the n2-th column.\n        See also: 1/ rowSwap \n        Ex1:colSwap([[1,2],[3,4],[5,6]],0,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_459colSwap = {"colSwap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_459colSwap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_458colSwap};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_459colSwap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colSwap (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colSwap", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_458colSwap(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_458colSwap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colSwap", 1);

  /* "giacpy/auto-methods.pxi":2804
 * 
 *         '''
 *         return GiacMethods['colSwap'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def coldim(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colSwap); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2804, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2795
 *         return GiacMethods['colNorm'](self,*args)
 * 
 *      def colSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colSwap:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colSwap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2806
 *         return GiacMethods['colSwap'](self,*args)
 * 
 *      def coldim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coldim:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_461coldim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_460coldim, "From Giac's documentation:\n        Help for coldim:\n        coldim(Mtrx)\n        Number of columns of a matrix.\n        See also: 1/ rowdim \n        Ex1:coldim([[1,2,3],[4,5,6]])\n        Ex2:coldim([[1,2],[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_461coldim = {"coldim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_461coldim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_460coldim};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_461coldim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("coldim (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "coldim", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_460coldim(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_460coldim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coldim", 1);

  /* "giacpy/auto-methods.pxi":2816
 * 
 *         '''
 *         return GiacMethods['coldim'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def collect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_coldim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2816, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2806
 *         return GiacMethods['colSwap'](self,*args)
 * 
 *      def coldim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coldim:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.coldim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2818
 *         return GiacMethods['coldim'](self,*args)
 * 
 *      def collect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for collect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_463collect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_462collect, "From Giac's documentation:\n        Help for collect:\n        collect(Poly or LstPoly)\n        Integer factorization of a polynomial (or of a list of poly).\n        See also: 1/ factor 2/ factors \n        Ex1:collect(x^2-4)\n        Ex2:collect(x^2-2)\n        Ex3:collect([x^2-2,x^2-4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_463collect = {"collect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_463collect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_462collect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_463collect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("collect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "collect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_462collect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_462collect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("collect", 1);

  /* "giacpy/auto-methods.pxi":2829
 * 
 *         '''
 *         return GiacMethods['collect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colnorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_collect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2829, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2818
 *         return GiacMethods['coldim'](self,*args)
 * 
 *      def collect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for collect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.collect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2831
 *         return GiacMethods['collect'](self,*args)
 * 
 *      def colnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colnorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_465colnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_464colnorm, "From Giac's documentation:\n        Help for colnorm:\n        colnorm(Vect or Mtrx)\n        Returns the max of the l1_norm of the columns of a matrix: colNorm(a_{j,k})=max_k(sum_j(|a_{j,k}|)).\n        See also: 1/ norm \n        Ex1:colnorm([[1,2],[3,-4]])\n        Ex2:colnorm([[1,2,3,-4],[-5,3,2,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_465colnorm = {"colnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_465colnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_464colnorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_465colnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colnorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colnorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_464colnorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_464colnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colnorm", 1);

  /* "giacpy/auto-methods.pxi":2841
 * 
 *         '''
 *         return GiacMethods['colnorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def color(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colnorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2841, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2831
 *         return GiacMethods['collect'](self,*args)
 * 
 *      def colnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colnorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colnorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2843
 *         return GiacMethods['colnorm'](self,*args)
 * 
 *      def color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for color:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_467color(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_466color, "From Giac's documentation:\n        Help for color:\n        color([GeoObj or legende],Intg)\n        Draws a geometrical object with colors black=0 red=1 green=2 yellow=3 blue=4, filled with the color in the interior of a closed curve,line_width_n (0<n<8) is for the width of the line and dash_line is for dotted line.\n        See also: 1/ -< 2/ legende \n        Ex1:color(A,1)\n        Ex2:color(F:=point(2+1.5*i),2)\n        Ex3:color(point(2+1.5*i),2)\n        Ex4:color(legende(1+i,\"abc\"),4)\n        Ex5:color(square(0,1),filled+red)\n        Ex6:color(carre(0,1),rempli+rouge)\n        Ex7:color(circle(0,1),filled)\n        Ex8:color(line(y=x),green+dash_line+line_width_2)\n        Ex9:color(red);square(0,1);\n        Ex10:color(red+filled);square(0,1);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_467color = {"color", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_467color, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_466color};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_467color(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("color (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "color", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_466color(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_466color(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("color", 1);

  /* "giacpy/auto-methods.pxi":2861
 * 
 *         '''
 *         return GiacMethods['color'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colormap(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_color); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2861, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2843
 *         return GiacMethods['colnorm'](self,*args)
 * 
 *      def color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for color:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.color", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2863
 *         return GiacMethods['color'](self,*args)
 * 
 *      def colormap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colormap:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_469colormap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_468colormap, "From Giac's documentation:\n        Help for colormap:\n        colormap(Str(palette)||Lst(palettes),[Intg(n)||Real(t)||Str(colorname)||display])\n        Return the colormap index for a given palette name or a extract specified color(s) or display selected colormap(s).\n        See also: 1/ color 2/ rgb 3/ hsv \n        Ex1:colormap(\"default\")\n        Ex2:colormap(\"inferno\")\n        Ex3:colormap(\"viridis\",25)\n        Ex4:colormap(\"discrete\",\"vivid\")\n        Ex5:colormap([\"cubic\",\"isoluminant\",\"haline\"],display)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_469colormap = {"colormap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_469colormap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_468colormap};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_469colormap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colormap (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colormap", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_468colormap(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_468colormap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colormap", 1);

  /* "giacpy/auto-methods.pxi":2876
 * 
 *         '''
 *         return GiacMethods['colormap'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colspace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colormap); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2876, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2863
 *         return GiacMethods['color'](self,*args)
 * 
 *      def colormap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colormap:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colormap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2878
 *         return GiacMethods['colormap'](self,*args)
 * 
 *      def colspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colspace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_471colspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_470colspace, "From Giac's documentation:\n        Help for colspace:\n        colspace(Mtrx(A), [Var(d)])\n        Returns a matrix where the columns are a basis of the vector space generated by the columns of the matrix A [d is the dimension of this space].\n        See also: 1/ rowspace \n        Ex1:colspace([[1,2,3],[1,2,3],[1,2,4],[1,2,5]])\n        Ex2:colspace([[1,2,3],[1,3,6],[2,5,9]],d)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_471colspace = {"colspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_471colspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_470colspace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_471colspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colspace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colspace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_470colspace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_470colspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colspace", 1);

  /* "giacpy/auto-methods.pxi":2888
 * 
 *         '''
 *         return GiacMethods['colspace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def colswap(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colspace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2888, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2878
 *         return GiacMethods['colormap'](self,*args)
 * 
 *      def colspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colspace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colspace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2890
 *         return GiacMethods['colspace'](self,*args)
 * 
 *      def colswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colswap:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_473colswap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_472colswap, "From Giac's documentation:\n        Help for colswap:\n        colswap(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by swapping the n1-th column and the n2-th column.\n        See also: 1/ rowSwap \n        Ex1:colswap([[1,2],[3,4],[5,6]],0,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_473colswap = {"colswap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_473colswap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_472colswap};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_473colswap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("colswap (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "colswap", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_472colswap(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_472colswap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("colswap", 1);

  /* "giacpy/auto-methods.pxi":2899
 * 
 *         '''
 *         return GiacMethods['colswap'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def comDenom(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_colswap); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2899, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2890
 *         return GiacMethods['colspace'](self,*args)
 * 
 *      def colswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colswap:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.colswap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2901
 *         return GiacMethods['colswap'](self,*args)
 * 
 *      def comDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comDenom:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_475comDenom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_474comDenom, "From Giac's documentation:\n        Help for comDenom:\n        comDenom(Expr,[Var(Var)])\n        Returns the expression after reduction to the same denominator : the numerator and the denominator are developed [according to the powers of the variable var].\n        See also: 1/ normal \n        Ex1:comDenom(1/x+1/y^2+1)\n        Ex2:comDenom(1/x+1/y^2+1,y)\n        Ex3:comDenom(1/x+1/y^2+1,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_475comDenom = {"comDenom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_475comDenom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_474comDenom};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_475comDenom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("comDenom (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "comDenom", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_474comDenom(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_474comDenom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("comDenom", 1);

  /* "giacpy/auto-methods.pxi":2912
 * 
 *         '''
 *         return GiacMethods['comDenom'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def comb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_comDenom); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2912, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2901
 *         return GiacMethods['colswap'](self,*args)
 * 
 *      def comDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comDenom:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.comDenom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2914
 *         return GiacMethods['comDenom'](self,*args)
 * 
 *      def comb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_477comb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_476comb, "From Giac's documentation:\n        Help for comb:\n        comb(Intg(n),Intg(r))\n        comb(n,r)=number of combinations of r objects taken among n : n!/(r!(n-r)!) (If n<0 comb(n,r)=n(n-1)..(n-r+1)/r!).\n        See also: 1/ factorial 2/ perm \n        Ex1:comb(4,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_477comb = {"comb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_477comb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_476comb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_477comb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("comb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "comb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_476comb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_476comb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("comb", 1);

  /* "giacpy/auto-methods.pxi":2923
 * 
 *         '''
 *         return GiacMethods['comb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def combine(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_comb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2923, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2914
 *         return GiacMethods['comDenom'](self,*args)
 * 
 *      def comb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.comb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2925
 *         return GiacMethods['comb'](self,*args)
 * 
 *      def combine(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for combine:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_479combine(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_478combine, "From Giac's documentation:\n        Help for combine:\n        combine(Expr(Xpr),Fnc(f).)\n        Combines terms in Xpr according to a [class of] function f (2nd argument).\n        See also: 1/ lncollect 2/ lin 3/ tlin 4/ tcollect \n        Ex1:combine(exp(x)*exp(y),exp)\n        Ex2:combine(sin(x)*cos(x),trig)\n        Ex3:combine(ln(x)+ln(y),ln)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_479combine = {"combine", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_479combine, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_478combine};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_479combine(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("combine (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "combine", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_478combine(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_478combine(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("combine", 1);

  /* "giacpy/auto-methods.pxi":2936
 * 
 *         '''
 *         return GiacMethods['combine'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def comment(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2936, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2925
 *         return GiacMethods['comb'](self,*args)
 * 
 *      def combine(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for combine:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.combine", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2938
 *         return GiacMethods['combine'](self,*args)
 * 
 *      def comment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comment:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_481comment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_480comment, "From Giac's documentation:\n        Help for comment:\n        comment(Expr)\n        Comment in a program.\n        See also: 1/  \n        Ex1:comment(\"my_comment\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_481comment = {"comment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_481comment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_480comment};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_481comment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("comment (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "comment", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_480comment(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_480comment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("comment", 1);

  /* "giacpy/auto-methods.pxi":2947
 * 
 *         '''
 *         return GiacMethods['comment'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def common_perpendicular(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_comment); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2947, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2938
 *         return GiacMethods['combine'](self,*args)
 * 
 *      def comment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comment:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.comment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2949
 *         return GiacMethods['comment'](self,*args)
 * 
 *      def common_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for common_perpendicular:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_483common_perpendicular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_482common_perpendicular, "From Giac's documentation:\n        Help for common_perpendicular:\n        common_perpendicular(Line(D1),Line(D2))\n        Draws the common perpendicular of the lines D1 and D2.\n        See also: 1/ altitude 2/ perpendicular \n        Ex1:common_perpendicular(line([0,0,0],[0,5,5]),line([5,0,0],[0,0,5]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_483common_perpendicular = {"common_perpendicular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_483common_perpendicular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_482common_perpendicular};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_483common_perpendicular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("common_perpendicular (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "common_perpendicular", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_482common_perpendicular(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_482common_perpendicular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("common_perpendicular", 1);

  /* "giacpy/auto-methods.pxi":2958
 * 
 *         '''
 *         return GiacMethods['common_perpendicular'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def companion(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_common_perpendicular); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2958, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2949
 *         return GiacMethods['comment'](self,*args)
 * 
 *      def common_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for common_perpendicular:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.common_perpendicular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2960
 *         return GiacMethods['common_perpendicular'](self,*args)
 * 
 *      def companion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for companion:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_485companion(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_484companion, "From Giac's documentation:\n        Help for companion:\n        companion(Poly,Var)\n        Companion matrix of a polynomial (an=1).\n        See also: 1/ pcar 2/ rat_jordan \n        Ex1:companion(x^2+5x-7,x)\n        Ex2:companion(-pcar([[1,0,1],[0,2,-1],[1,-1,1]],x),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_485companion = {"companion", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_485companion, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_484companion};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_485companion(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("companion (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "companion", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_484companion(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_484companion(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("companion", 1);

  /* "giacpy/auto-methods.pxi":2970
 * 
 *         '''
 *         return GiacMethods['companion'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def compare(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_companion); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2970, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2960
 *         return GiacMethods['common_perpendicular'](self,*args)
 * 
 *      def companion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for companion:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.companion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2972
 *         return GiacMethods['companion'](self,*args)
 * 
 *      def compare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for compare:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_487compare(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_486compare, "From Giac's documentation:\n        Help for compare:\n        compare(Obj(arg1),Obj(arg2))\n        Returns 1 if type(arg1)<type(arg2) or if type(arg1)=type(arg2) and arg1<arg2, else returns 0.\n        See also: 1/ type \n        Ex1:compare(1,2)\n        Ex2:compare(1.0,2)\n        Ex3:compare(\"ab\",\"cd\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_487compare = {"compare", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_487compare, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_486compare};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_487compare(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compare (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "compare", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_486compare(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_486compare(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compare", 1);

  /* "giacpy/auto-methods.pxi":2983
 * 
 *         '''
 *         return GiacMethods['compare'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def complete_binary_tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_compare); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2983, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2972
 *         return GiacMethods['companion'](self,*args)
 * 
 *      def compare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for compare:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.compare", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2985
 *         return GiacMethods['compare'](self,*args)
 * 
 *      def complete_binary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_binary_tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_489complete_binary_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_488complete_binary_tree, "From Giac's documentation:\n        Help for complete_binary_tree:\n        complete_binary_tree(Intg(n))\n        Returns a complete binary tree with depth n.\n        See also: 1/ complete_kary_tree 2/ is_tree 3/ random_tree \n        Ex1:complete_binary_tree(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_489complete_binary_tree = {"complete_binary_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_489complete_binary_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_488complete_binary_tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_489complete_binary_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("complete_binary_tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "complete_binary_tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_488complete_binary_tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_488complete_binary_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("complete_binary_tree", 1);

  /* "giacpy/auto-methods.pxi":2994
 * 
 *         '''
 *         return GiacMethods['complete_binary_tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def complete_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_complete_binary_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 2994, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2985
 *         return GiacMethods['compare'](self,*args)
 * 
 *      def complete_binary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_binary_tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.complete_binary_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":2996
 *         return GiacMethods['complete_binary_tree'](self,*args)
 * 
 *      def complete_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_491complete_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_490complete_graph, "From Giac's documentation:\n        Help for complete_graph:\n        complete_graph(Intg(n)||Lst(V)||Seq(n1,n2,...,nk))\n        Returns a complete graph with vertices from list V or enumerated with first n integers or, when two or more positive integers n1,n2,...,nk are given, a complete k-partite graph with partition sizes n1,n2,...,nk.\n        See also: 1/ edges \n        Ex1:complete_graph(4)\n        Ex2:complete_graph([\"one\",\"two\",\"three\"])\n        Ex3:complete_graph(2,3,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_491complete_graph = {"complete_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_491complete_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_490complete_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_491complete_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("complete_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "complete_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_490complete_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_490complete_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("complete_graph", 1);

  /* "giacpy/auto-methods.pxi":3007
 * 
 *         '''
 *         return GiacMethods['complete_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def complete_kary_tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_complete_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3007, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":2996
 *         return GiacMethods['complete_binary_tree'](self,*args)
 * 
 *      def complete_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.complete_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3009
 *         return GiacMethods['complete_graph'](self,*args)
 * 
 *      def complete_kary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_kary_tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_493complete_kary_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_492complete_kary_tree, "From Giac's documentation:\n        Help for complete_kary_tree:\n        complete_kary_tree(Intg(k),Intg(n))\n        Returns a complete k-ary tree with depth n.\n        See also: 1/ complete_binary_tree 2/ is_tree 3/ random_tree \n        Ex1:complete_kary_tree(2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_493complete_kary_tree = {"complete_kary_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_493complete_kary_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_492complete_kary_tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_493complete_kary_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("complete_kary_tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "complete_kary_tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_492complete_kary_tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_492complete_kary_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("complete_kary_tree", 1);

  /* "giacpy/auto-methods.pxi":3018
 * 
 *         '''
 *         return GiacMethods['complete_kary_tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def complex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_complete_kary_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3018, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3009
 *         return GiacMethods['complete_graph'](self,*args)
 * 
 *      def complete_kary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_kary_tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.complete_kary_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3020
 *         return GiacMethods['complete_kary_tree'](self,*args)
 * 
 *      def complex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_495complex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_494complex, "From Giac's documentation:\n        Help for complex:\n        complex(Opt)\n        DOM_COMPLEX or complex is the type of a complex or of a complex variable, as returned by the type command. It is also an option of the assume command.\n        See also: 1/ type 2/ assume 3/ DOM_INT 4/ DOM_FLOAT \n        Ex1: assume(a,complex)\n        Ex2: assume(a,DOM_COMPLEX)\n        Ex3: a:=1+i;type(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_495complex = {"complex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_495complex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_494complex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_495complex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("complex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "complex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_494complex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_494complex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("complex", 1);

  /* "giacpy/auto-methods.pxi":3031
 * 
 *         '''
 *         return GiacMethods['complex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def complex_variables(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_complex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3031, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3020
 *         return GiacMethods['complete_kary_tree'](self,*args)
 * 
 *      def complex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.complex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3033
 *         return GiacMethods['complex'](self,*args)
 * 
 *      def complex_variables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex_variables:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_497complex_variables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_496complex_variables, "From Giac's documentation:\n        Help for complex_variables:\n        complex_variables(:=Intg(0 or 1))\n        Pseudo-variable to work with complex variables (complex_variables:=1) or with real variables (complex_variables:=0).\n        See also: 1/ cas_setup \n        Ex1: complex_variables:=1\n        Ex2: complex_variables:=0\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_497complex_variables = {"complex_variables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_497complex_variables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_496complex_variables};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_497complex_variables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("complex_variables (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "complex_variables", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_496complex_variables(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_496complex_variables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("complex_variables", 1);

  /* "giacpy/auto-methods.pxi":3043
 * 
 *         '''
 *         return GiacMethods['complex_variables'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def complexroot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_complex_variables); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3043, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3033
 *         return GiacMethods['complex'](self,*args)
 * 
 *      def complex_variables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex_variables:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.complex_variables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3045
 *         return GiacMethods['complex_variables'](self,*args)
 * 
 *      def complexroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complexroot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_499complexroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_498complexroot, "From Giac's documentation:\n        Help for complexroot:\n        complexroot(Poly(P),Real(l),[Cplx(a)],[Cplx(b)])\n        Returns the list of complex intervals of size<=l containing the roots of P (for example i[1.1,1.2]+i[2,2.4]*i pour [1.1,1.2]x[2,2.4] with optionally a=1+2*i,b=2+3*i) with multiplicities.\n        See also: 1/ proot 2/ froot 3/ realroot 4/ rationalroot 5/ crationalroot \n        Ex1:complexroot(x^4+1,1e-50,0.7+i*0.7,0.8+i*0.8)\n        Ex2:complexroot(x^5-2*x^4+x^3+i,0.1)\n        Ex3:complexroot(x^3+8,1e-5,0,2+2*i)\n        Ex4:complexroot(x^5-2*x^4+x^3+i,0.1,1+0.5*i,1.1+0.7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_499complexroot = {"complexroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_499complexroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_498complexroot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_499complexroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("complexroot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "complexroot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_498complexroot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_498complexroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("complexroot", 1);

  /* "giacpy/auto-methods.pxi":3057
 * 
 *         '''
 *         return GiacMethods['complexroot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def concat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_complexroot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3057, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3045
 *         return GiacMethods['complex_variables'](self,*args)
 * 
 *      def complexroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complexroot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.complexroot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3059
 *         return GiacMethods['complexroot'](self,*args)
 * 
 *      def concat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for concat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_501concat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_500concat, "From Giac's documentation:\n        Help for concat:\n        concat(Lst,Lst||Seq,Seq||Str,Str||Mtrx,Mtrx)\n        Concatenates two lists or two strings or two sequences or 2 matrices; L:=concat(L,L1) or L.concat(L1).\n        See also: 1/ append 2/ cat 3/ semi_augment 4/ border 5/ + \n        Ex1:concat([1,2],[3,4,5])\n        Ex2:concat(\"bon\",\"jour\")\n        Ex3:concat([[1,2],[3,4]],[[4,5,6],[6,7,8]])\n        Ex4: L:=[1,2];L.concat([3,4,5])\n        Ex5: S:=\"abcd\";S.concat(\"efghi\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_501concat = {"concat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_501concat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_500concat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_501concat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("concat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "concat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_500concat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_500concat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("concat", 1);

  /* "giacpy/auto-methods.pxi":3072
 * 
 *         '''
 *         return GiacMethods['concat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cond(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_concat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3072, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3059
 *         return GiacMethods['complexroot'](self,*args)
 * 
 *      def concat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for concat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.concat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3074
 *         return GiacMethods['concat'](self,*args)
 * 
 *      def cond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cond:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_503cond(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_502cond, "From Giac's documentation:\n        Help for cond:\n        cond(Mtrx,[2]||[inf])\n        Condition number of a matrix, use COND(.,1) for l1, COND(.,2) for l2 norm and COND(.,inf) for linf (1 by default).\n        See also: 1/ SVL \n        Ex1:cond([[1,2],[1,4]])\n        Ex2:cond([[1,2],[1,4]],1)\n        Ex3:cond([[1,2],[1,4]],2)\n        Ex4:cond([[1,2],[1,4]],inf)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_503cond = {"cond", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_503cond, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_502cond};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_503cond(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cond (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cond", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_502cond(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_502cond(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cond", 1);

  /* "giacpy/auto-methods.pxi":3086
 * 
 *         '''
 *         return GiacMethods['cond'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def condensation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cond); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3086, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3074
 *         return GiacMethods['concat'](self,*args)
 * 
 *      def cond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cond:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cond", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3088
 *         return GiacMethods['cond'](self,*args)
 * 
 *      def condensation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for condensation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_505condensation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_504condensation, "From Giac's documentation:\n        Help for condensation:\n        condensation(Graph(G))\n        Returns the graph obtained by contracting strongly connected components of the digraph G to single vertices.\n        See also: 1/ strongly_connected_components \n        Ex1:condensation(digraph(%{[1,2],[1,3],[3,1],[1,4],[2,3],[4,3],[4,5],[5,3],[5,6],[7,6],[8,6],[8,7]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_505condensation = {"condensation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_505condensation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_504condensation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_505condensation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("condensation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "condensation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_504condensation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_504condensation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("condensation", 1);

  /* "giacpy/auto-methods.pxi":3097
 * 
 *         '''
 *         return GiacMethods['condensation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cone(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_condensation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3097, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3088
 *         return GiacMethods['cond'](self,*args)
 * 
 *      def condensation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for condensation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.condensation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3099
 *         return GiacMethods['condensation'](self,*args)
 * 
 *      def cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cone:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_507cone(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_506cone, "From Giac's documentation:\n        Help for cone:\n        cone(Pnt(A),Vect(v),Real(t),[Real(h)])\n        Draws a cone with vertex A, direction v, and with half_angle t [and with altitudes h and -h].\n        See also: 1/ half_cone 2/ cylinder \n        Ex1:cone([0,0,0],[0,0,1],pi/6)\n        Ex2:cone([0,0,0],[0,1,1],pi/6,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_507cone = {"cone", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_507cone, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_506cone};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_507cone(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cone (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cone", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_506cone(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_506cone(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cone", 1);

  /* "giacpy/auto-methods.pxi":3109
 * 
 *         '''
 *         return GiacMethods['cone'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def confrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cone); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3109, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3099
 *         return GiacMethods['condensation'](self,*args)
 * 
 *      def cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cone:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3111
 *         return GiacMethods['cone'](self,*args)
 * 
 *      def confrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for confrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_509confrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_508confrac, "From Giac's documentation:\n        Help for confrac:\n        confrac(Opt)\n        Option of the convert or convertir command (ex id L:=dfc(sqrt(2),1e-10)).\n        See also: 1/ convert \n        Ex1: convert(sqrt(2),confrac,'L'),L\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_509confrac = {"confrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_509confrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_508confrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_509confrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("confrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "confrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_508confrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_508confrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("confrac", 1);

  /* "giacpy/auto-methods.pxi":3120
 * 
 *         '''
 *         return GiacMethods['confrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def conic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_confrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3120, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3111
 *         return GiacMethods['cone'](self,*args)
 * 
 *      def confrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for confrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.confrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3122
 *         return GiacMethods['confrac'](self,*args)
 * 
 *      def conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_511conic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_510conic, "From Giac's documentation:\n        Help for conic:\n        conic(Expr,[LstVar])\n        Defines a conic by its equation with x,y as default variables and draws it.\n        See also: 1/ circle 2/ ellipse 3/ hyperbola 4/ parabola 5/ reduced_conic \n        Ex1:conic(x^2+y^2-x*y-3)\n        Ex2:conic(x^2+2*y^2-x*y-3,x,y)\n        Ex3:conic(u^2-2*v^2-2*u*v-1,[u,v])\n        Ex4:conic(y^2-x*y+3,[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_511conic = {"conic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_511conic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_510conic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_511conic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("conic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "conic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_510conic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_510conic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("conic", 1);

  /* "giacpy/auto-methods.pxi":3134
 * 
 *         '''
 *         return GiacMethods['conic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def conj(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_conic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3134, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3122
 *         return GiacMethods['confrac'](self,*args)
 * 
 *      def conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.conic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3136
 *         return GiacMethods['conic'](self,*args)
 * 
 *      def conj(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conj:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_513conj(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_512conj, "From Giac's documentation:\n        Help for conj:\n        conj(Cplx)\n        Returns the conjugate of a complex number.\n        See also: 1/ re 2/ im 3/ tran \n        Ex1:conj(1+i)\n        Ex2:conj(1+2*i)\n        Ex3:conj((1+2*i)^2)\n        Ex4:conj([[1+i,2,3],[1,3,6],[2,5,9-i]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_513conj = {"conj", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_513conj, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_512conj};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_513conj(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("conj (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "conj", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_512conj(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_512conj(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("conj", 1);

  /* "giacpy/auto-methods.pxi":3148
 * 
 *         '''
 *         return GiacMethods['conj'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def conjugate_equation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_conj); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3148, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3136
 *         return GiacMethods['conic'](self,*args)
 * 
 *      def conj(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conj:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.conj", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3150
 *         return GiacMethods['conj'](self,*args)
 * 
 *      def conjugate_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_equation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_515conjugate_equation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_514conjugate_equation, "From Giac's documentation:\n        Help for conjugate_equation:\n        conjugate_equation(Expr(y0),Lst(P),Lst(V),Var(x),Real(a))\n        Returns the expression which is zero for a point x1 conjugate to x (a is the left or the right bound for x) with respect to the function y0 depending on two parameters in P with values in V.\n        See also: 1/ jacobi_equation 2/ euler_lagrange \n        Ex1:conjugate_equation(A*sin(t)+B*cos(t),[A,B],[1,0],t,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_515conjugate_equation = {"conjugate_equation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_515conjugate_equation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_514conjugate_equation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_515conjugate_equation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("conjugate_equation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "conjugate_equation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_514conjugate_equation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_514conjugate_equation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("conjugate_equation", 1);

  /* "giacpy/auto-methods.pxi":3159
 * 
 *         '''
 *         return GiacMethods['conjugate_equation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def conjugate_gradient(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_conjugate_equation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3159, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3150
 *         return GiacMethods['conj'](self,*args)
 * 
 *      def conjugate_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_equation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.conjugate_equation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3161
 *         return GiacMethods['conjugate_equation'](self,*args)
 * 
 *      def conjugate_gradient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_gradient:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_517conjugate_gradient(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_516conjugate_gradient, "From Giac's documentation:\n        Help for conjugate_gradient:\n        conjugate_gradient(Mtrx(A),Vect(y),[Vect(x0),Real(eps)])\n        Conjugate gradient algorithm to solve A*x=y approximately (precision eps) where A is a symmetric positive definite matrix, x0 an optional initial guess.\n        See also: 1/ linsolve \n        Ex1:conjugate_gradient([[2,1],[1,5]],[1,0])\n        Ex2:conjugate_gradient([[4,1+i],[1-i,5]],[1,0])\n        Ex3:conjugate_gradient([[2,1],[1,5]],[1,0],[0.55,-0.11],1e-2)\n        Ex4:conjugate_gradient([[2,1],[1,5]],[1,0],[0.55,-0.11],1e-10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_517conjugate_gradient = {"conjugate_gradient", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_517conjugate_gradient, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_516conjugate_gradient};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_517conjugate_gradient(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("conjugate_gradient (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "conjugate_gradient", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_516conjugate_gradient(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_516conjugate_gradient(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("conjugate_gradient", 1);

  /* "giacpy/auto-methods.pxi":3173
 * 
 *         '''
 *         return GiacMethods['conjugate_gradient'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def connected(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_conjugate_gradient); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3173, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3161
 *         return GiacMethods['conjugate_equation'](self,*args)
 * 
 *      def conjugate_gradient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_gradient:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.conjugate_gradient", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3175
 *         return GiacMethods['conjugate_gradient'](self,*args)
 * 
 *      def connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_519connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_518connected, "From Giac's documentation:\n        Help for connected:\n        connected(Opt)\n        Option for the random_regular_graph command.\n        See also: 1/ directed 2/ weighted 3/ random_regular_graph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_519connected = {"connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_519connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_518connected};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_519connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connected (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "connected", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_518connected(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_518connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("connected", 1);

  /* "giacpy/auto-methods.pxi":3183
 * 
 *         '''
 *         return GiacMethods['connected'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def connected_components(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_connected); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3183, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3175
 *         return GiacMethods['conjugate_gradient'](self,*args)
 * 
 *      def connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.connected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3185
 *         return GiacMethods['connected'](self,*args)
 * 
 *      def connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected_components:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_521connected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_520connected_components, "From Giac's documentation:\n        Help for connected_components:\n        connected_components(Graph(G))\n        Returns a list of lists of vertices, each sublist representing a connected component of G.\n        See also: 1/ articulation_points 2/ is_biconnected 3/ is_strongly_connected 4/ strongly_connected_components 5/ underlying_graph \n        Ex1:connected_components(graph_complement(cycle_graph(4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_521connected_components = {"connected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_521connected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_520connected_components};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_521connected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connected_components (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "connected_components", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_520connected_components(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_520connected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("connected_components", 1);

  /* "giacpy/auto-methods.pxi":3194
 * 
 *         '''
 *         return GiacMethods['connected_components'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cont(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_connected_components); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3194, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3185
 *         return GiacMethods['connected'](self,*args)
 * 
 *      def connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected_components:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.connected_components", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3196
 *         return GiacMethods['connected_components'](self,*args)
 * 
 *      def cont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cont:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_523cont(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_522cont, "From Giac's documentation:\n        Help for cont:\n        cont(NULL)\n        Continues execution of a stopped program.\n        See also: 1/ continue \n        Ex1:cont()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_523cont = {"cont", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_523cont, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_522cont};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_523cont(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cont (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cont", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_522cont(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_522cont(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cont", 1);

  /* "giacpy/auto-methods.pxi":3205
 * 
 *         '''
 *         return GiacMethods['cont'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def contains(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cont); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3205, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3196
 *         return GiacMethods['connected_components'](self,*args)
 * 
 *      def cont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cont:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cont", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3207
 *         return GiacMethods['cont'](self,*args)
 * 
 *      def contains(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contains:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_525contains(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_524contains, "From Giac's documentation:\n        Help for contains:\n        contains((Lst(l) or Set(l)),Elem(e))\n        Tests if a set contains an expression (returns the index+1 or 1 for intervals or 0).\n        See also: 1/ inString 2/ member 3/ est_element \n        Ex1:contains(%{0,1,2,3%},2)\n        Ex2:contains([0,1,2,3],4)\n        Ex3:contains([1..2],1.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_525contains = {"contains", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_525contains, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_524contains};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_525contains(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("contains (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "contains", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_524contains(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_524contains(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("contains", 1);

  /* "giacpy/auto-methods.pxi":3218
 * 
 *         '''
 *         return GiacMethods['contains'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def content(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_contains); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3218, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3207
 *         return GiacMethods['cont'](self,*args)
 * 
 *      def contains(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contains:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.contains", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3220
 *         return GiacMethods['contains'](self,*args)
 * 
 *      def content(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for content:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_527content(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_526content, "From Giac's documentation:\n        Help for content:\n        content(Poly(P),[Var])\n        Returns the gcd of the coefficients of the polynomial P given as argument.\n        See also: 1/ primpart 2/ lgcd \n        Ex1:content(2*x^2+10*x+6)\n        Ex2:content([2,10,6])\n        Ex3:content(2*t^2+10*t+6,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_527content = {"content", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_527content, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_526content};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_527content(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("content (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "content", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_526content(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_526content(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("content", 1);

  /* "giacpy/auto-methods.pxi":3231
 * 
 *         '''
 *         return GiacMethods['content'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def contourplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_content); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3231, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3220
 *         return GiacMethods['contains'](self,*args)
 * 
 *      def content(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for content:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.content", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3233
 *         return GiacMethods['content'](self,*args)
 * 
 *      def contourplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contourplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_529contourplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_528contourplot, "From Giac's documentation:\n        Help for contourplot:\n        contourplot(Expr(Xpr),[LstVar],[LstVal])\n        Draws 11 equirepartited contour-lines z=z_min,,...z=z_max of the surface z=Xpr, or the contour-lines defined by the 3-rd argument.\n        See also: 1/ plotdensity 2/ plotimplicit \n        Ex1:contourplot(x^2+y^2)\n        Ex2:contourplot(x^2+y^2,[x,y])\n        Ex3:contourplot(x^2+2*y^2-2,[x,y],[1.0,2.0,3.0])\n        Ex4:contourplot(x^2-y^2,[x=-4..4,y=-4..4],seq(k,k,-11,11,3),xstep=0.1,ystep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_529contourplot = {"contourplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_529contourplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_528contourplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_529contourplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("contourplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "contourplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_528contourplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_528contourplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("contourplot", 1);

  /* "giacpy/auto-methods.pxi":3245
 * 
 *         '''
 *         return GiacMethods['contourplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def contract_edge(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_contourplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3245, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3233
 *         return GiacMethods['content'](self,*args)
 * 
 *      def contourplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contourplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.contourplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3247
 *         return GiacMethods['contourplot'](self,*args)
 * 
 *      def contract_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_edge:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_531contract_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_530contract_edge, "From Giac's documentation:\n        Help for contract_edge:\n        contract_edge(Graph(G),Edge(e))\n        Returns a modified copy of an undirected graph G with the edge e contracted into one of its endpoints (to contract more edges apply the foldl command).\n        See also: 1/ delete_edge 2/ delete_vertex 3/ foldl \n        Ex1:contract_edge(complete_graph(4),[1,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_531contract_edge = {"contract_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_531contract_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_530contract_edge};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_531contract_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("contract_edge (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "contract_edge", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_530contract_edge(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_530contract_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("contract_edge", 1);

  /* "giacpy/auto-methods.pxi":3256
 * 
 *         '''
 *         return GiacMethods['contract_edge'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def contract_subgraph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_contract_edge); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3256, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3247
 *         return GiacMethods['contourplot'](self,*args)
 * 
 *      def contract_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_edge:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.contract_edge", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3258
 *         return GiacMethods['contract_edge'](self,*args)
 * 
 *      def contract_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_subgraph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_533contract_subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_532contract_subgraph, "From Giac's documentation:\n        Help for contract_subgraph:\n        contract_subgraph(Graph(G),Lst(S),[lb])\n        Returns a copy of G in which the subgraph induced by S is contracted into a single vertex (optionally labeled by lb).\n        See also: 1/ contract_edge 2/ condensation 3/ delete_vertex 4/ subgraph \n        Ex1:contract_subgraph(cycle_graph(6),[0,1,5],\"newLabel\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_533contract_subgraph = {"contract_subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_533contract_subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_532contract_subgraph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_533contract_subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("contract_subgraph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "contract_subgraph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_532contract_subgraph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_532contract_subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("contract_subgraph", 1);

  /* "giacpy/auto-methods.pxi":3267
 * 
 *         '''
 *         return GiacMethods['contract_subgraph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def convert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_contract_subgraph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3267, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3258
 *         return GiacMethods['contract_edge'](self,*args)
 * 
 *      def contract_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_subgraph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.contract_subgraph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3269
 *         return GiacMethods['contract_subgraph'](self,*args)
 * 
 *      def convert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_535convert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_534convert, "From Giac's documentation:\n        Help for convert:\n        convert(Expr(Xpr),Cmd(cmd))\n        Returns the value of cmd(Xpr), cmd is the name of a command specified by the 2nd argument (for ex option sin=command trigsin).\n        See also: 1/ mksa 2/ list 3/ polynom 4/ table \n        Ex1:convert(cos(x)^2,sin)\n        Ex2:convert(exp(i*x),sincos)\n        Ex3:convert(1/(x^4-1),parfrac)\n        Ex4:convert(series(sin(x),x=0,6),polynom)\n        Ex5:convert([[1,[2,0]],[2,[1,1]],[1,[0,2]]],polynom)\n        Ex6:convert(%%%{1,[2,0]%%%}+%%%{2,[1,1]%%%}+%%%{1,[0,2]%%%},list)\n        Ex7:convert(cos(x)^2+1,sin)\n        Ex8:convert(3e10 _m,_au)\n        Ex9:convert(pi _rad,_deg)\n        Ex10:convert(9976/6961,confrac,'l');l\n        Ex11:convert(sqrt(2),confrac,'dev');dev\n        Ex12:convert(123,base,8)\n        Ex13:convert([3,7,1],base,8)\n        Ex14:convert([1,2,3],set[])\n        Ex15:convert(pi,interval,20)\n        Ex16: A[2,1]:=1;convert(A,array)\n        Ex17: B[0..1,1..2]:=1;B[2,2]:=2;convert(B,array)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_535convert = {"convert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_535convert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_534convert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_535convert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "convert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_534convert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_534convert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert", 1);

  /* "giacpy/auto-methods.pxi":3294
 * 
 *         '''
 *         return GiacMethods['convert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def convertir(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_convert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3294, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3269
 *         return GiacMethods['contract_subgraph'](self,*args)
 * 
 *      def convert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.convert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3296
 *         return GiacMethods['convert'](self,*args)
 * 
 *      def convertir(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convertir:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_537convertir(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_536convertir, "From Giac's documentation:\n        Help for convertir:\n        convertir(Expr(Xpr),Cmd(cmd))\n        Returns the value of cmd(Xpr), cmd is the name of a command specified by the 2nd argument (for ex option sin=command trigsin).\n        See also: 1/ mksa 2/ list 3/ polynom 4/ table \n        Ex1:convertir(cos(x)^2,sin)\n        Ex2:convertir(exp(i*x),sincos)\n        Ex3:convertir(1/(x^4-1),parfrac)\n        Ex4:convertir(series(sin(x),x=0,6),polynom)\n        Ex5:convertir([[1,[2,0]],[2,[1,1]],[1,[0,2]]],polynom)\n        Ex6:convertir(%%%{1,[2,0]%%%}+%%%{2,[1,1]%%%}+%%%{1,[0,2]%%%},list)\n        Ex7:convertir(cos(x)^2+1,sin)\n        Ex8:convertir(3e10 _m,_au)\n        Ex9:convertir(pi _rad,_deg)\n        Ex10:convertir(9976/6961,confrac,'l');l\n        Ex11:convertir(sqrt(2),confrac,'dev');dev\n        Ex12:convertir(123,base,8)\n        Ex13:convertir([3,7,1],base,8)\n        Ex14:convertir([1,2,3],set[])\n        Ex15:convertir(pi,interval,20)\n        Ex16: A[2,1]:=1;convert(A,array)\n        Ex17: B[0..1,1..2]:=1;B[2,2]:=2;convert(B,array)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_537convertir = {"convertir", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_537convertir, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_536convertir};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_537convertir(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convertir (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "convertir", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_536convertir(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_536convertir(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convertir", 1);

  /* "giacpy/auto-methods.pxi":3321
 * 
 *         '''
 *         return GiacMethods['convertir'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def convex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_convertir); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3321, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3296
 *         return GiacMethods['convert'](self,*args)
 * 
 *      def convertir(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convertir:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.convertir", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3323
 *         return GiacMethods['convertir'](self,*args)
 * 
 *      def convex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_539convex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_538convex, "From Giac's documentation:\n        Help for convex:\n        convex(Expr(f),Lst(x,y,..),[simplify])\n        Returns a list of conditions under which f(x,y,..) is convex.\n        See also: 1/ hessian \n        Ex1:convex(3*exp(x)+5x^4-ln(x),x)\n        Ex2:convex(x^2+y^2+3z^2-x*y+2x*z+y*z,[x,y,z])\n        Ex3:convex(x1^3+2x1^2+2*x1*x2+x2^2/2-8x1-2x2-8,[x1,x2],simplify)\n        Ex4:convex(x1^2+2x2^2+a*x3^2-2x1*x2+2x1*x3-6x2*x3,[x1,x2,x3],simplify)\n        Ex5:convex(sqrt((1+(u')^2)/(2*g*u)),u(t),simplify)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_539convex = {"convex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_539convex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_538convex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_539convex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "convex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_538convex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_538convex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convex", 1);

  /* "giacpy/auto-methods.pxi":3336
 * 
 *         '''
 *         return GiacMethods['convex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def convexhull(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_convex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3336, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3323
 *         return GiacMethods['convertir'](self,*args)
 * 
 *      def convex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.convex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3338
 *         return GiacMethods['convex'](self,*args)
 * 
 *      def convexhull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convexhull:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_541convexhull(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_540convexhull, "From Giac's documentation:\n        Help for convexhull:\n        convexhull(Lst)\n        Convex hull of a list of 2-d points.\n        See also: 1/ polygon \n        Ex1:convexhull(0,1,1+i,1+2i,-1-i,1-3i,-2+i)\n        Ex2:convexhull([0,1,1+i,1+2i,-1-i,1-3i,-2+i])\n        Ex3: polygon(convexhull(0,1,1+i,1+2i,-1-i,1-3i,-2+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_541convexhull = {"convexhull", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_541convexhull, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_540convexhull};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_541convexhull(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convexhull (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "convexhull", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_540convexhull(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_540convexhull(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convexhull", 1);

  /* "giacpy/auto-methods.pxi":3349
 * 
 *         '''
 *         return GiacMethods['convexhull'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def convolution(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_convexhull); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3349, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3338
 *         return GiacMethods['convex'](self,*args)
 * 
 *      def convexhull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convexhull:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.convexhull", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3351
 *         return GiacMethods['convexhull'](self,*args)
 * 
 *      def convolution(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convolution:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_543convolution(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_542convolution, "From Giac's documentation:\n        Help for convolution:\n        convolution(Lst(u),Lst(v))\n        Returns the convolution of two signals or causal functions u and v.\n        See also: 1/ fft 2/ cross_correlation \n        Ex1:convolution([1,2,3],[1,-1,1,-1])\n        Ex2:convolution(25*exp(2*x),x*exp(-3*x),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_543convolution = {"convolution", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_543convolution, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_542convolution};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_543convolution(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("convolution (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "convolution", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_542convolution(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_542convolution(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convolution", 1);

  /* "giacpy/auto-methods.pxi":3361
 * 
 *         '''
 *         return GiacMethods['convolution'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def coordinates(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_convolution); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3361, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3351
 *         return GiacMethods['convexhull'](self,*args)
 * 
 *      def convolution(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convolution:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.convolution", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3363
 *         return GiacMethods['convolution'](self,*args)
 * 
 *      def coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coordinates:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_545coordinates(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_544coordinates, "From Giac's documentation:\n        Help for coordinates:\n        coordinates(Pnt or Cplx or Vect)\n        Returns the list (resp matrix) of the abscissa and of the ordinate of a point or a vector (resp of points or vectors).\n        See also: 1/ abscissa 2/ ordinate 3/ cote 4/ vecteur \n        Ex1:coordinates(point(1+2*i))\n        Ex2:coordinates(1+2*i)\n        Ex3:coordinates(point(i),point(1+2*i))\n        Ex4:coordinates(vecteur(point(i),point(1+2*i)))\n        Ex5:coordinates(point(1+2*i)-point(i))\n        Ex6:coordinates(-1-i)\n        Ex7:coordinates(point(1,2,3))\n        Ex8:coordinates(vecteur([1,2,3],[4,5,6]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_545coordinates = {"coordinates", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_545coordinates, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_544coordinates};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_545coordinates(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("coordinates (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "coordinates", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_544coordinates(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_544coordinates(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("coordinates", 1);

  /* "giacpy/auto-methods.pxi":3379
 * 
 *         '''
 *         return GiacMethods['coordinates'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def copy(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3379, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3363
 *         return GiacMethods['convolution'](self,*args)
 * 
 *      def coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coordinates:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.coordinates", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3381
 *         return GiacMethods['coordinates'](self,*args)
 * 
 *      def copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for copy:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_547copy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_546copy, "From Giac's documentation:\n        Help for copy:\n        copy(Mtrx,Var)\n        A:=copy(B) clones the list or matrix B into A.\n        See also: 1/ =< \n        Ex1: A:=copy(B)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_547copy = {"copy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_547copy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_546copy};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_547copy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_546copy(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_546copy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "giacpy/auto-methods.pxi":3390
 * 
 *         '''
 *         return GiacMethods['copy'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def correlation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3390, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3381
 *         return GiacMethods['coordinates'](self,*args)
 * 
 *      def copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for copy:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3392
 *         return GiacMethods['copy'](self,*args)
 * 
 *      def correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for correlation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_549correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_548correlation, "From Giac's documentation:\n        Help for correlation:\n        correlation(Lst||Mtrx,[Lst])\n        Returns the correlation of the elements of its argument.\n        See also: 1/ covariance 2/ covariance_correlation \n        Ex1:correlation([[1,2],[1,1],[4,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_549correlation = {"correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_549correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_548correlation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_549correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("correlation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "correlation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_548correlation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_548correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("correlation", 1);

  /* "giacpy/auto-methods.pxi":3401
 * 
 *         '''
 *         return GiacMethods['correlation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_correlation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3401, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3392
 *         return GiacMethods['copy'](self,*args)
 * 
 *      def correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for correlation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.correlation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3403
 *         return GiacMethods['correlation'](self,*args)
 * 
 *      def cos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_551cos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_550cos, "From Giac's documentation:\n        Help for cos:\n        cos(Expr or Opt)\n        Cosine or option of the convert or convertir command (id trigcos).\n        See also: 1/ acos 2/ convert 3/ trigsin \n        Ex1:cos(0)\n        Ex2: convert(cos(x)^4+sin(x)^2,cos)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_551cos = {"cos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_551cos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_550cos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_551cos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_550cos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_550cos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cos", 1);

  /* "giacpy/auto-methods.pxi":3413
 * 
 *         '''
 *         return GiacMethods['cos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cos2sintan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3413, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3403
 *         return GiacMethods['correlation'](self,*args)
 * 
 *      def cos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3415
 *         return GiacMethods['cos'](self,*args)
 * 
 *      def cos2sintan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos2sintan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_553cos2sintan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_552cos2sintan, "From Giac's documentation:\n        Help for cos2sintan:\n        cos2sintan(Expr)\n        Replaces cos(x) by sin(x)/tan(x) in the argument.\n        See also: 1/ tan2sincos 2/ sin2costan 3/ tan2sincos2 4/ tan2cossin2 \n        Ex1:cos2sintan(cos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_553cos2sintan = {"cos2sintan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_553cos2sintan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_552cos2sintan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_553cos2sintan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cos2sintan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cos2sintan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_552cos2sintan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_552cos2sintan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cos2sintan", 1);

  /* "giacpy/auto-methods.pxi":3424
 * 
 *         '''
 *         return GiacMethods['cos2sintan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cosh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cos2sintan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3424, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3415
 *         return GiacMethods['cos'](self,*args)
 * 
 *      def cos2sintan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos2sintan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cos2sintan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3426
 *         return GiacMethods['cos2sintan'](self,*args)
 * 
 *      def cosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_555cosh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_554cosh, "From Giac's documentation:\n        Help for cosh:\n        cosh(Expr)\n        Hyperbolic cosine.\n        See also: 1/ acosh \n        Ex1:cosh(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_555cosh = {"cosh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_555cosh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_554cosh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_555cosh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cosh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cosh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_554cosh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_554cosh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cosh", 1);

  /* "giacpy/auto-methods.pxi":3435
 * 
 *         '''
 *         return GiacMethods['cosh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cosine_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cosh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3435, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3426
 *         return GiacMethods['cos2sintan'](self,*args)
 * 
 *      def cosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cosh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3437
 *         return GiacMethods['cosh'](self,*args)
 * 
 *      def cosine_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosine_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_557cosine_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_556cosine_window, "From Giac's documentation:\n        Help for cosine_window:\n        cosine_window(Lst,[Real(a)],[Interval(n1..n2)])\n        Applies the cosine windowing function with parameter a>0 (by default a=1 for sine window) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ bartlett_hann_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(cosine_window(randvector(1000,0..1),1.5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_557cosine_window = {"cosine_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_557cosine_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_556cosine_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_557cosine_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cosine_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cosine_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_556cosine_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_556cosine_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cosine_window", 1);

  /* "giacpy/auto-methods.pxi":3446
 * 
 *         '''
 *         return GiacMethods['cosine_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cosine_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3446, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3437
 *         return GiacMethods['cosh'](self,*args)
 * 
 *      def cosine_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosine_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cosine_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3448
 *         return GiacMethods['cosine_window'](self,*args)
 * 
 *      def cot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_559cot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_558cot, "From Giac's documentation:\n        Help for cot:\n        cot(Expr)\n        Cotangent.\n        See also: 1/ acot 2/ tan \n        Ex1:cot(pi/2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_559cot = {"cot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_559cot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_558cot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_559cot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_558cot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_558cot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cot", 1);

  /* "giacpy/auto-methods.pxi":3457
 * 
 *         '''
 *         return GiacMethods['cot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cote(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3457, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3448
 *         return GiacMethods['cosine_window'](self,*args)
 * 
 *      def cot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3459
 *         return GiacMethods['cot'](self,*args)
 * 
 *      def cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cote:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_561cote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_560cote, "From Giac's documentation:\n        Help for cote:\n        cote(Vect)\n        Third coordinate (z) of a 3-d point.\n        See also: 1/ abscissa 2/ ordinate 3/ coordinates \n        Ex1:cote(point[1,2,3])\n        Ex2:cote(point(1,2,3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_561cote = {"cote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_561cote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_560cote};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_561cote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cote (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cote", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_560cote(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_560cote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cote", 1);

  /* "giacpy/auto-methods.pxi":3469
 * 
 *         '''
 *         return GiacMethods['cote'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def count(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cote); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3469, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3459
 *         return GiacMethods['cot'](self,*args)
 * 
 *      def cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cote:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cote", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3471
 *         return GiacMethods['cote'](self,*args)
 * 
 *      def count(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_563count(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_562count, "From Giac's documentation:\n        Help for count:\n        count(Fnc(f)||LstIntg,(Lst||Mtrx)(l),[Opt(row||col)])\n        Returns f(l[0])+f(l[1])+...+f(l[size(l)-1]) or counts the number of occurrences if the argument is a vector of integers.\n        See also: 1/ count_eq 2/ count_inf 3/ count_sup \n        Ex1:count(id,[-2/5,-1,0,1,2,3/5])\n        Ex2:count(1,[-2,-1,0,1,2,3])\n        Ex3:count([1,3,1,1,2,10,3])\n        Ex4:count((x)->x>2,[3/2,5/2,8/3])\n        Ex5:count((x)->x==1,[-2,1,0,1,2,3])\n        Ex6:count((x)->x>2,[[3,5/2],[4,1]])\n        Ex7:count((x)->x>2,[[3,5/2],[4,1]],row)\n        Ex8:count((x)->x>2,[[3,5/2],[4,1]],col)\n        Ex9:count((x)->x>2 && x<4,[[3,9/2],[4,1]])\n        Ex10:count((x)->x<2 || x>4,[[3,9/2],[4,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_563count = {"count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_563count, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_562count};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_563count(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "count", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_562count(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_562count(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("count", 1);

  /* "giacpy/auto-methods.pxi":3489
 * 
 *         '''
 *         return GiacMethods['count'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def count_eq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_count); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3489, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3471
 *         return GiacMethods['cote'](self,*args)
 * 
 *      def count(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3491
 *         return GiacMethods['count'](self,*args)
 * 
 *      def count_eq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_eq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_565count_eq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_564count_eq, "From Giac's documentation:\n        Help for count_eq:\n        count_eq(Real(a),(Lst||Mtrx)(L),[Opt(row||col)])\n        Returns the number of elements of L equal to a.\n        See also: 1/ count 2/ count_inf 3/ count_sup \n        Ex1:count_eq(1,[-2,1,0,1,2,-3])\n        Ex2:count_eq(4,[[3,4],[4,1]])\n        Ex3:count_eq(4,[[3,4],[4,1]],row)\n        Ex4:count_eq(4,[[3,4],[4,1]],col)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_565count_eq = {"count_eq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_565count_eq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_564count_eq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_565count_eq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("count_eq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "count_eq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_564count_eq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_564count_eq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("count_eq", 1);

  /* "giacpy/auto-methods.pxi":3503
 * 
 *         '''
 *         return GiacMethods['count_eq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def count_inf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_count_eq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3503, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3491
 *         return GiacMethods['count'](self,*args)
 * 
 *      def count_eq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_eq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.count_eq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3505
 *         return GiacMethods['count_eq'](self,*args)
 * 
 *      def count_inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_inf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_567count_inf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_566count_inf, "From Giac's documentation:\n        Help for count_inf:\n        count_inf(Real(a),(Lst||Mtrx)(L),[Opt(row||col)])\n        Returns the number of elements of L strictly less than a.\n        See also: 1/ count 2/ count_eq 3/ count_sup \n        Ex1:count_inf(1,[-2,-1,0,1,2,3])\n        Ex2:count_inf(4,[[3,5],[4,1]])\n        Ex3:count_inf(4,[[3,5],[4,1]],row)\n        Ex4:count_inf(4,[[3,5],[4,1]],col)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_567count_inf = {"count_inf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_567count_inf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_566count_inf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_567count_inf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("count_inf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "count_inf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_566count_inf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_566count_inf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("count_inf", 1);

  /* "giacpy/auto-methods.pxi":3517
 * 
 *         '''
 *         return GiacMethods['count_inf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def count_sup(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_count_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3517, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3505
 *         return GiacMethods['count_eq'](self,*args)
 * 
 *      def count_inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_inf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.count_inf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3519
 *         return GiacMethods['count_inf'](self,*args)
 * 
 *      def count_sup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_sup:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_569count_sup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_568count_sup, "From Giac's documentation:\n        Help for count_sup:\n        count_sup(Real(a),(Lst||Mtrx)(L),[Opt(row||col)])\n        Returns the number of elements of L strictly greater than a.\n        See also: 1/ count 2/ count_inf 3/ count_eq \n        Ex1:count_sup(1,[-2,-1,0,1,2,3])\n        Ex2:count_sup(3,[[3,5],[4,1]])\n        Ex3:count_sup(3,[[3,5],[4,1]],row)\n        Ex4:count_sup(3,[[3,5],[4,1]],col)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_569count_sup = {"count_sup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_569count_sup, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_568count_sup};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_569count_sup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("count_sup (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "count_sup", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_568count_sup(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_568count_sup(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("count_sup", 1);

  /* "giacpy/auto-methods.pxi":3531
 * 
 *         '''
 *         return GiacMethods['count_sup'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def courbe_parametrique(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_count_sup); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3531, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3519
 *         return GiacMethods['count_inf'](self,*args)
 * 
 *      def count_sup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_sup:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.count_sup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3533
 *         return GiacMethods['count_sup'](self,*args)
 * 
 *      def courbe_parametrique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_parametrique:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_571courbe_parametrique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_570courbe_parametrique, "From Giac's documentation:\n        Help for courbe_parametrique:\n        courbe_parametrique(Cplx||Lst,Var||Lst(Var))\n        plotparam(a(x)+i*b(x),x=x0..x1) draws the curve X=a(x),Y=b(x) x=x0..x1 or plotparam([a(u,v),b(u,v),c(u,v)],[u=u0..u1,v=v0..v1]) draws the surface X=a(u,v),Y=b(u,v),Z=c(u,v) u=u0..u1 and v=v0..v1.\n        See also: 1/ plotfunc 2/ plotpolar 3/ arc \n        Ex1:courbe_parametrique(sin(t)+i*cos(t),t)\n        Ex2:courbe_parametrique(exp(i*t),t=0..pi/2,affichage=1)\n        Ex3:courbe_parametrique(exp(i*t),t=0..pi/2,affichage=1+rempli)\n        Ex4:courbe_parametrique([sin(x),cos(x)],x=0..1)\n        Ex5:courbe_parametrique([sin(x),cos(x)],x=0..1,affichage=rouge)\n        Ex6:courbe_parametrique(sin(x)+i*cos(x),x=0..1,tstep=0.01)\n        Ex7:courbe_parametrique([v*cos(u),v*sin(u),v],[u,v])\n        Ex8:courbe_parametrique([v*cos(u),v*sin(u),v],[u=0..pi,v=0..3],ustep=0.1,vstep=0.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_571courbe_parametrique = {"courbe_parametrique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_571courbe_parametrique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_570courbe_parametrique};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_571courbe_parametrique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("courbe_parametrique (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "courbe_parametrique", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_570courbe_parametrique(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_570courbe_parametrique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("courbe_parametrique", 1);

  /* "giacpy/auto-methods.pxi":3549
 * 
 *         '''
 *         return GiacMethods['courbe_parametrique'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def courbe_polaire(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_courbe_parametrique); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3549, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3533
 *         return GiacMethods['count_sup'](self,*args)
 * 
 *      def courbe_parametrique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_parametrique:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.courbe_parametrique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3551
 *         return GiacMethods['courbe_parametrique'](self,*args)
 * 
 *      def courbe_polaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_polaire:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_573courbe_polaire(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_572courbe_polaire, "From Giac's documentation:\n        Help for courbe_polaire:\n        courbe_polaire(Expr,Var,VarMin,VarMax)\n        plotpolar(f(x),x,a,b) draws the polar curve r=f(x) for x in [a,b].\n        See also: 1/ plotparam 2/ plotfunc 3/ plotpolar \n        Ex1:courbe_polaire(sin(2*x),x,0,pi)\n        Ex2:courbe_polaire(sin(2*x),x,0,pi,tstep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_573courbe_polaire = {"courbe_polaire", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_573courbe_polaire, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_572courbe_polaire};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_573courbe_polaire(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("courbe_polaire (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "courbe_polaire", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_572courbe_polaire(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_572courbe_polaire(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("courbe_polaire", 1);

  /* "giacpy/auto-methods.pxi":3561
 * 
 *         '''
 *         return GiacMethods['courbe_polaire'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def covariance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_courbe_polaire); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3561, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3551
 *         return GiacMethods['courbe_parametrique'](self,*args)
 * 
 *      def courbe_polaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_polaire:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.courbe_polaire", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3563
 *         return GiacMethods['courbe_polaire'](self,*args)
 * 
 *      def covariance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_575covariance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_574covariance, "From Giac's documentation:\n        Help for covariance:\n        covariance(Lst||Mtrx,[Lst])\n        Returns the covariance of the elements of its argument.\n        See also: 1/ correlation 2/ covariance_correlation \n        Ex1:covariance([[1,2],[1,1],[4,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_575covariance = {"covariance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_575covariance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_574covariance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_575covariance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("covariance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "covariance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_574covariance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_574covariance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("covariance", 1);

  /* "giacpy/auto-methods.pxi":3572
 * 
 *         '''
 *         return GiacMethods['covariance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def covariance_correlation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_covariance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3572, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3563
 *         return GiacMethods['courbe_polaire'](self,*args)
 * 
 *      def covariance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.covariance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3574
 *         return GiacMethods['covariance'](self,*args)
 * 
 *      def covariance_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance_correlation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_577covariance_correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_576covariance_correlation, "From Giac's documentation:\n        Help for covariance_correlation:\n        covariance_correlation(Lst||Mtrx,[Lst])\n        Returns the list of the covariance and the correlation of the elements of its argument.\n        See also: 1/ covariance 2/ correlation \n        Ex1:covariance_correlation([[1,2],[1,1],[4,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_577covariance_correlation = {"covariance_correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_577covariance_correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_576covariance_correlation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_577covariance_correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("covariance_correlation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "covariance_correlation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_576covariance_correlation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_576covariance_correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("covariance_correlation", 1);

  /* "giacpy/auto-methods.pxi":3583
 * 
 *         '''
 *         return GiacMethods['covariance_correlation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cpartfrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_covariance_correlation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3583, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3574
 *         return GiacMethods['covariance'](self,*args)
 * 
 *      def covariance_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance_correlation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.covariance_correlation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3585
 *         return GiacMethods['covariance_correlation'](self,*args)
 * 
 *      def cpartfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cpartfrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_579cpartfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_578cpartfrac, "From Giac's documentation:\n        Help for cpartfrac:\n        cpartfrac(RatFrac)\n        Performs partial fraction decomposition in \342\204\202 of a fraction.\n        See also: 1/ factor 2/ normal \n        Ex1:cpartfrac((x)/(4-x^2))\n        Ex2:cpartfrac((x^2-2*x+3)/(x^2-3*x+2))\n        Ex3:cpartfrac(a/(z*(z-b)),z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_579cpartfrac = {"cpartfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_579cpartfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_578cpartfrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_579cpartfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cpartfrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cpartfrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_578cpartfrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_578cpartfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cpartfrac", 1);

  /* "giacpy/auto-methods.pxi":3596
 * 
 *         '''
 *         return GiacMethods['cpartfrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def crationalroot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cpartfrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3596, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3585
 *         return GiacMethods['covariance_correlation'](self,*args)
 * 
 *      def cpartfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cpartfrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cpartfrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3598
 *         return GiacMethods['cpartfrac'](self,*args)
 * 
 *      def crationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crationalroot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_581crationalroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_580crationalroot, "From Giac's documentation:\n        Help for crationalroot:\n        crationalroot(Poly(P))\n        Returns the list of complex rational roots of P without indicating the multiplicity.\n        See also: 1/ proot 2/ froot 3/ complexroot 4/ rationalroot 5/ realroot \n        Ex1:crationalroot(2*x^3+(-5-7*i)*x^2+(-4+14*i)*x+8-4*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_581crationalroot = {"crationalroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_581crationalroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_580crationalroot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_581crationalroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("crationalroot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "crationalroot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_580crationalroot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_580crationalroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("crationalroot", 1);

  /* "giacpy/auto-methods.pxi":3607
 * 
 *         '''
 *         return GiacMethods['crationalroot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def crayon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_crationalroot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3607, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3598
 *         return GiacMethods['cpartfrac'](self,*args)
 * 
 *      def crationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crationalroot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.crationalroot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3609
 *         return GiacMethods['crationalroot'](self,*args)
 * 
 *      def crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crayon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_583crayon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_582crayon, "From Giac's documentation:\n        Help for crayon:\n        crayon(Color)\n        Changes the color of the pencil (without parameter, returns the current color).\n        See also: 1/ leve_crayon 2/ baisse_crayon \n        Ex1: crayon vert\n        Ex2:crayon(rouge)\n        Ex3:crayon(5)\n        Ex4:crayon(gomme)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_583crayon = {"crayon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_583crayon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_582crayon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_583crayon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("crayon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "crayon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_582crayon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_582crayon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("crayon", 1);

  /* "giacpy/auto-methods.pxi":3621
 * 
 *         '''
 *         return GiacMethods['crayon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def createwav(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_crayon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3621, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3609
 *         return GiacMethods['crationalroot'](self,*args)
 * 
 *      def crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crayon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.crayon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3623
 *         return GiacMethods['crayon'](self,*args)
 * 
 *      def createwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for createwav:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_585createwav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_584createwav, "From Giac's documentation:\n        Help for createwav:\n        createwav(Lst(data),[opts])\n        Returns an audio clip created from data, optionally setting channel count, bit depth, sample rate, duration and/or normalization level.\n        See also: 1/ readwav 2/ writewav 3/ playsnd \n        Ex1:createwav(duration=3.5)\n        Ex2:createwav(sin(2*pi*440*soundsec(2)),samplerate=48000)\n        Ex3:createwav(sin(2*pi*440*soundsec(2)),bit_depth=8)\n        Ex4:createwav(10*sin(2*pi*440*soundsec(2)),normalize=-3)\n        Ex5: t:=soundsec(3):;L,R:=sin(2*pi*440*t),sin(2*pi*445*t):;createwav([L,R])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_585createwav = {"createwav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_585createwav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_584createwav};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_585createwav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("createwav (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "createwav", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_584createwav(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_584createwav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("createwav", 1);

  /* "giacpy/auto-methods.pxi":3636
 * 
 *         '''
 *         return GiacMethods['createwav'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cross(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_createwav); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3636, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3623
 *         return GiacMethods['crayon'](self,*args)
 * 
 *      def createwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for createwav:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.createwav", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3638
 *         return GiacMethods['createwav'](self,*args)
 * 
 *      def cross(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_587cross(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_586cross, "From Giac's documentation:\n        Help for cross:\n        cross(Vect(v1),Vect(v2))\n        Wedge product.\n        See also: 1/ dot \n        Ex1:cross([1,2],[3,4])\n        Ex2:cross([1,2,3],[4,5,6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_587cross = {"cross", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_587cross, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_586cross};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_587cross(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cross (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cross", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_586cross(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_586cross(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cross", 1);

  /* "giacpy/auto-methods.pxi":3648
 * 
 *         '''
 *         return GiacMethods['cross'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def crossP(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cross); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3648, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3638
 *         return GiacMethods['createwav'](self,*args)
 * 
 *      def cross(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cross", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3650
 *         return GiacMethods['cross'](self,*args)
 * 
 *      def crossP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossP:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_589crossP(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_588crossP, "From Giac's documentation:\n        Help for crossP:\n        crossP(Vect(v1),Vect(v2))\n        Wedge product.\n        See also: 1/ dot \n        Ex1:crossP([1,2],[3,4])\n        Ex2:crossP([1,2,3],[4,5,6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_589crossP = {"crossP", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_589crossP, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_588crossP};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_589crossP(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("crossP (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "crossP", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_588crossP(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_588crossP(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("crossP", 1);

  /* "giacpy/auto-methods.pxi":3660
 * 
 *         '''
 *         return GiacMethods['crossP'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cross_correlation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_crossP); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3660, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3650
 *         return GiacMethods['cross'](self,*args)
 * 
 *      def crossP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossP:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.crossP", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3662
 *         return GiacMethods['crossP'](self,*args)
 * 
 *      def cross_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_correlation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_591cross_correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_590cross_correlation, "From Giac's documentation:\n        Help for cross_correlation:\n        cross_correlation(cross_correlation(Lst(u),Lst(v)))\n        Returns the cross_correlation of two signals u and v.\n        See also: 1/ auto_correlation 2/ correlation \n        Ex1:cross_correlation([1,2],[3,4,5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_591cross_correlation = {"cross_correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_591cross_correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_590cross_correlation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_591cross_correlation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cross_correlation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cross_correlation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_590cross_correlation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_590cross_correlation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cross_correlation", 1);

  /* "giacpy/auto-methods.pxi":3671
 * 
 *         '''
 *         return GiacMethods['cross_correlation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cross_entropy(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cross_correlation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3671, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3662
 *         return GiacMethods['crossP'](self,*args)
 * 
 *      def cross_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_correlation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cross_correlation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3673
 *         return GiacMethods['cross_correlation'](self,*args)
 * 
 *      def cross_entropy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_entropy:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_593cross_entropy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_592cross_entropy, "From Giac's documentation:\n        Help for cross_entropy:\n        cross_entropy(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_593cross_entropy = {"cross_entropy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_593cross_entropy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_592cross_entropy};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_593cross_entropy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cross_entropy (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cross_entropy", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_592cross_entropy(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_592cross_entropy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cross_entropy", 1);

  /* "giacpy/auto-methods.pxi":3681
 * 
 *         '''
 *         return GiacMethods['cross_entropy'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cross_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cross_entropy); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3681, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3673
 *         return GiacMethods['cross_correlation'](self,*args)
 * 
 *      def cross_entropy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_entropy:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cross_entropy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3683
 *         return GiacMethods['cross_entropy'](self,*args)
 * 
 *      def cross_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_595cross_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_594cross_point, "From Giac's documentation:\n        Help for cross_point:\n        cross_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_595cross_point = {"cross_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_595cross_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_594cross_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_595cross_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cross_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cross_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_594cross_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_594cross_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cross_point", 1);

  /* "giacpy/auto-methods.pxi":3693
 * 
 *         '''
 *         return GiacMethods['cross_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cross_ratio(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cross_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3693, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3683
 *         return GiacMethods['cross_entropy'](self,*args)
 * 
 *      def cross_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cross_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3695
 *         return GiacMethods['cross_point'](self,*args)
 * 
 *      def cross_ratio(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_ratio:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_597cross_ratio(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_596cross_ratio, "From Giac's documentation:\n        Help for cross_ratio:\n        cross_ratio(Pnt or Cplx(a),Pnt or Cplx(b),Pnt or Cplx(c),Pnt or Cplx(d))\n        Returns the complex number equal to ((c-a)/(c-b))/((d-a)/(d-b)).\n        See also: 1/ harmonic_conjugate 2/ is_conjugate \n        Ex1:cross_ratio(i,2+i,3/2+i,3+i)\n        Ex2:cross_ratio(0,1+i,1,i)\n        Ex3:cross_ratio(0,1,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_597cross_ratio = {"cross_ratio", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_597cross_ratio, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_596cross_ratio};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_597cross_ratio(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cross_ratio (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cross_ratio", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_596cross_ratio(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_596cross_ratio(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cross_ratio", 1);

  /* "giacpy/auto-methods.pxi":3706
 * 
 *         '''
 *         return GiacMethods['cross_ratio'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def crossproduct(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cross_ratio); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3706, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3695
 *         return GiacMethods['cross_point'](self,*args)
 * 
 *      def cross_ratio(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_ratio:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cross_ratio", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3708
 *         return GiacMethods['cross_ratio'](self,*args)
 * 
 *      def crossproduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossproduct:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_599crossproduct(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_598crossproduct, "From Giac's documentation:\n        Help for crossproduct:\n        crossproduct(Vect(v1),Vect(v2))\n        Wedge product.\n        See also: 1/ dot \n        Ex1:crossproduct([1,2],[3,4])\n        Ex2:crossproduct([1,2,3],[4,5,6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_599crossproduct = {"crossproduct", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_599crossproduct, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_598crossproduct};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_599crossproduct(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("crossproduct (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "crossproduct", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_598crossproduct(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_598crossproduct(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("crossproduct", 1);

  /* "giacpy/auto-methods.pxi":3718
 * 
 *         '''
 *         return GiacMethods['crossproduct'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def csc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_crossproduct); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3718, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3708
 *         return GiacMethods['cross_ratio'](self,*args)
 * 
 *      def crossproduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossproduct:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.crossproduct", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3720
 *         return GiacMethods['crossproduct'](self,*args)
 * 
 *      def csc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_601csc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_600csc, "From Giac's documentation:\n        Help for csc:\n        csc(Expr)\n        Cosecant: csc(x)=1/sin(x).\n        See also: 1/ sin 2/ acsc \n        Ex1:csc(pi/2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_601csc = {"csc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_601csc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_600csc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_601csc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("csc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "csc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_600csc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_600csc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("csc", 1);

  /* "giacpy/auto-methods.pxi":3729
 * 
 *         '''
 *         return GiacMethods['csc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def csolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_csc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3729, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3720
 *         return GiacMethods['crossproduct'](self,*args)
 * 
 *      def csc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.csc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3731
 *         return GiacMethods['csc'](self,*args)
 * 
 *      def csolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_603csolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_602csolve, "From Giac's documentation:\n        Help for csolve:\n        csolve(LstEq,LstVar)\n        Returns the list of complex solutions of an equation or a matrix where the rows are \342\204\202-solutions of a system of polynomial equations.\n        See also: 1/ cZeros 2/ solve 3/ fslove \n        Ex1:csolve(x^4-1,x)\n        Ex2:csolve(x^4-y^4 and x+y=2,[x,y])\n        Ex3:csolve(x^4-y^4 and x+y=0 and x^2=2*x,[x,y])\n        Ex4:csolve(u*v-u=v and v^2=u,[u,v])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_603csolve = {"csolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_603csolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_602csolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_603csolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("csolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "csolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_602csolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_602csolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("csolve", 1);

  /* "giacpy/auto-methods.pxi":3743
 * 
 *         '''
 *         return GiacMethods['csolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def csv2gen(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_csolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3743, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3731
 *         return GiacMethods['csc'](self,*args)
 * 
 *      def csolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.csolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3745
 *         return GiacMethods['csolve'](self,*args)
 * 
 *      def csv2gen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csv2gen:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_605csv2gen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_604csv2gen, "From Giac's documentation:\n        Help for csv2gen:\n        csv2gen(Strng(filename),Strng(sep),Strng(nl),Strng(decsep),Strng(eof),[string])\n        Reads a file (or string) in CSV format.\n        See also: 1/ read \n        Ex1:csv2gen(\"mat.txt\",\",\",char(10),\".\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_605csv2gen = {"csv2gen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_605csv2gen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_604csv2gen};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_605csv2gen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("csv2gen (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "csv2gen", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_604csv2gen(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_604csv2gen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("csv2gen", 1);

  /* "giacpy/auto-methods.pxi":3754
 * 
 *         '''
 *         return GiacMethods['csv2gen'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cube(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_csv2gen); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3754, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3745
 *         return GiacMethods['csolve'](self,*args)
 * 
 *      def csv2gen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csv2gen:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.csv2gen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3756
 *         return GiacMethods['csv2gen'](self,*args)
 * 
 *      def cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cube:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_607cube(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_606cube, "From Giac's documentation:\n        Help for cube:\n        cube(Pnt(A),Pnt(B),Pnt(C))\n        Draws the direct cube with vertices A,B with a face in the plane (A,B,C).\n        See also: 1/ parallelepiped 2/ cylinder 3/ icosahedron 4/ dodecahedron 5/ octahedron 6/ tetrahedron 7/ centered_cube \n        Ex1:cube([0,0,0],[3,0,0],[0,0,1]) \n        Ex2: A,B,C:=point(1,0,0),point(1,1,0),point(0,1,0);c:=cube(A,B,C);A,B,C,D,E,F,G,H:=sommets(c); \n        Ex3: A,B,K:=point(1,0,0),point(1,1,0),point(0,2,0);c:=cube(A,B,C);A,B,C,D,E,F,G,H:=sommets(c); \n        Ex4: c:=cube([0,0,0],[1,0,0],[0,1,0]);c1,c2,c4,c3,c5,c6,c7,c8:=sommets(c); \n        Ex5: c:=cube([0,0,0],[0,2,0],[0,0,1]);c1,c2,c4,c3,c5,c6,c7,c8:=sommets(c); \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_607cube = {"cube", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_607cube, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_606cube};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_607cube(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cube (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cube", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_606cube(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_606cube(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cube", 1);

  /* "giacpy/auto-methods.pxi":3769
 * 
 *         '''
 *         return GiacMethods['cube'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cumSum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cube); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3769, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3756
 *         return GiacMethods['csv2gen'](self,*args)
 * 
 *      def cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cube:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cube", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3771
 *         return GiacMethods['cube'](self,*args)
 * 
 *      def cumSum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumSum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_609cumSum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_608cumSum, "From Giac's documentation:\n        Help for cumSum:\n        cumSum(Lst(l)||Seq||Str)\n        Returns the list (or the sequence or the string) lr where the elements are the cumulative sum of the list l: lr[k]=sum(l[j],j=0..k) (or lr=sum(l[j],j=0..k)$(k=0..size(l)-1)).\n        See also: 1/ sum \n        Ex1:cumSum([0,1,2,3,4])\n        Ex2:cumSum(1.2,3,4.5,6)\n        Ex3:cumSum(\"a\",\"b\",\"c\",\"d\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_609cumSum = {"cumSum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_609cumSum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_608cumSum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_609cumSum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cumSum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cumSum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_608cumSum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_608cumSum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cumSum", 1);

  /* "giacpy/auto-methods.pxi":3782
 * 
 *         '''
 *         return GiacMethods['cumSum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cumsum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cumSum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3782, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3771
 *         return GiacMethods['cube'](self,*args)
 * 
 *      def cumSum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumSum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cumSum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3784
 *         return GiacMethods['cumSum'](self,*args)
 * 
 *      def cumsum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumsum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_611cumsum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_610cumsum, "From Giac's documentation:\n        Help for cumsum:\n        cumsum(Lst(l)||Seq||Str)\n        Returns the list (or the sequence or the string) lr where the elements are the cumulative sum of the list l: lr[k]=sum(l[j],j=0..k) (or lr=sum(l[j],j=0..k)$(k=0..size(l)-1)).\n        See also: 1/ sum \n        Ex1:cumsum([0,1,2,3,4])\n        Ex2:cumsum(1.2,3,4.5,6)\n        Ex3:cumsum(\"a\",\"b\",\"c\",\"d\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_611cumsum = {"cumsum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_611cumsum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_610cumsum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_611cumsum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cumsum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cumsum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_610cumsum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_610cumsum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cumsum", 1);

  /* "giacpy/auto-methods.pxi":3795
 * 
 *         '''
 *         return GiacMethods['cumsum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cumulated_frequencies(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cumsum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3795, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3784
 *         return GiacMethods['cumSum'](self,*args)
 * 
 *      def cumsum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumsum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cumsum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3797
 *         return GiacMethods['cumsum'](self,*args)
 * 
 *      def cumulated_frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumulated_frequencies:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_613cumulated_frequencies(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_612cumulated_frequencies, "From Giac's documentation:\n        Help for cumulated_frequencies:\n        cumulated_frequencies(Lst || Mtrx)\n        Draws the diagram of the cumulated frequencies (rows=[value,frequencies])\n        See also: 1/ histogram 2/ classes 3/ bar_plot \n        Ex1:cumulated_frequencies([1,2,1,1,2,1,2,4,3,3])\n        Ex2:cumulated_frequencies([(rand(6)+1)$(k=1..100)])\n        Ex3:cumulated_frequencies([[1,0.3],[2,0.5],[3,0.2]])\n        Ex4:cumulated_frequencies([[1..2,0.3],[2..3,0.5],[3..4,0.2]])\n        Ex5:cumulated_frequencies([[1..2,0.3,0.5],[2..3,0.5,0.2],[3..4,0.2,0.3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_613cumulated_frequencies = {"cumulated_frequencies", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_613cumulated_frequencies, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_612cumulated_frequencies};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_613cumulated_frequencies(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cumulated_frequencies (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cumulated_frequencies", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_612cumulated_frequencies(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_612cumulated_frequencies(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cumulated_frequencies", 1);

  /* "giacpy/auto-methods.pxi":3810
 * 
 *         '''
 *         return GiacMethods['cumulated_frequencies'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def curl(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cumulated_frequencies); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3810, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3797
 *         return GiacMethods['cumsum'](self,*args)
 * 
 *      def cumulated_frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumulated_frequencies:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cumulated_frequencies", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3812
 *         return GiacMethods['cumulated_frequencies'](self,*args)
 * 
 *      def curl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curl:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_615curl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_614curl, "From Giac's documentation:\n        Help for curl:\n        curl(Lst(A,B,C),Lst(x,y,z))\n        curl([A,B,C],[x,y,z])=[dC/dy-dB/dz,dA/dz-dC/dx,dB/dx-dA/dy].\n        See also: 1/ derive 2/ divergence \n        Ex1:curl([2*x*y,x*z,y*z],[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_615curl = {"curl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_615curl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_614curl};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_615curl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("curl (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "curl", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_614curl(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_614curl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("curl", 1);

  /* "giacpy/auto-methods.pxi":3821
 * 
 *         '''
 *         return GiacMethods['curl'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def current_sheet(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_curl); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3821, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3812
 *         return GiacMethods['cumulated_frequencies'](self,*args)
 * 
 *      def curl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curl:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.curl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3823
 *         return GiacMethods['curl'](self,*args)
 * 
 *      def current_sheet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for current_sheet:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_617current_sheet(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_616current_sheet, "From Giac's documentation:\n        Help for current_sheet:\n        current_sheet([Intg||Inter],[Intg||Letter],[Letter])\n        Content of the matrix editor or spreadsheet.\n        Ex1:current_sheet(1,2)\n        Ex2:current_sheet(A1..A5,B,G)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_617current_sheet = {"current_sheet", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_617current_sheet, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_616current_sheet};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_617current_sheet(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("current_sheet (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "current_sheet", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_616current_sheet(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_616current_sheet(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("current_sheet", 1);

  /* "giacpy/auto-methods.pxi":3832
 * 
 *         '''
 *         return GiacMethods['current_sheet'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def curvature(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_current_sheet); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3832, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3823
 *         return GiacMethods['curl'](self,*args)
 * 
 *      def current_sheet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for current_sheet:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.current_sheet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3834
 *         return GiacMethods['current_sheet'](self,*args)
 * 
 *      def curvature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curvature:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_619curvature(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_618curvature, "From Giac's documentation:\n        Help for curvature:\n        curvature(Curve,Point)\n        Curvature of curve C at point M.\n        See also: 1/ osculating_circle 2/ evolute \n        Ex1:curvature(plot(x^2),point(1,1))\n        Ex2:curvature([5*cos(t),5*sin(t)],t)\n        Ex3:curvature([t,t^2],t)\n        Ex4:curvature([t,t^2],t,1)\n        Ex5:curvature([3*exp(t/2)*cos(t),3*exp(t/2)*sin(t)],t)\n        Ex6:curvature([3*exp(t/2)*cos(t),3*exp(t/2)*sin(t)],t,7)\n        Ex7: trigcos(curvature([2*cos(t),2*sin(t),3*t],t))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_619curvature = {"curvature", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_619curvature, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_618curvature};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_619curvature(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("curvature (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "curvature", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_618curvature(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_618curvature(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("curvature", 1);

  /* "giacpy/auto-methods.pxi":3849
 * 
 *         '''
 *         return GiacMethods['curvature'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def curve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_curvature); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3849, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3834
 *         return GiacMethods['current_sheet'](self,*args)
 * 
 *      def curvature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curvature:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.curvature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3851
 *         return GiacMethods['curvature'](self,*args)
 * 
 *      def curve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_621curve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_620curve, "From Giac's documentation:\n        Help for curve:\n        curve(Expr)\n        Reserved word.\n        See also: 1/  \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_621curve = {"curve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_621curve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_620curve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_621curve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("curve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "curve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_620curve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_620curve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("curve", 1);

  /* "giacpy/auto-methods.pxi":3859
 * 
 *         '''
 *         return GiacMethods['curve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cyan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_curve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3859, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3851
 *         return GiacMethods['curvature'](self,*args)
 * 
 *      def curve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.curve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3861
 *         return GiacMethods['curve'](self,*args)
 * 
 *      def cyan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_623cyan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_622cyan, "From Giac's documentation:\n        Help for cyan:\n        cyan(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_623cyan = {"cyan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_623cyan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_622cyan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_623cyan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cyan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cyan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_622cyan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_622cyan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cyan", 1);

  /* "giacpy/auto-methods.pxi":3871
 * 
 *         '''
 *         return GiacMethods['cyan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cycle2perm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cyan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3871, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3861
 *         return GiacMethods['curve'](self,*args)
 * 
 *      def cyan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cyan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3873
 *         return GiacMethods['cyan'](self,*args)
 * 
 *      def cycle2perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle2perm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_625cycle2perm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_624cycle2perm, "From Giac's documentation:\n        Help for cycle2perm:\n        cycle2perm(Cycle)\n        Converts the cycle c to a permutation.\n        See also: 1/ cycles2permu 2/ permu2cycles \n        Ex1:cycle2perm([1,3,5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_625cycle2perm = {"cycle2perm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_625cycle2perm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_624cycle2perm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_625cycle2perm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cycle2perm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cycle2perm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_624cycle2perm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_624cycle2perm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cycle2perm", 1);

  /* "giacpy/auto-methods.pxi":3882
 * 
 *         '''
 *         return GiacMethods['cycle2perm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cycle_basis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cycle2perm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3882, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3873
 *         return GiacMethods['cyan'](self,*args)
 * 
 *      def cycle2perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle2perm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cycle2perm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3884
 *         return GiacMethods['cycle2perm'](self,*args)
 * 
 *      def cycle_basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_basis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_627cycle_basis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_626cycle_basis, "From Giac's documentation:\n        Help for cycle_basis:\n        cycle_basis(Graph(G))\n        Returns the list of fundamental cycles in an undirected graph G.\n        See also: 1/ find_cycles 2/ fundamental_cycle \n        Ex1:cycle_basis(graph(\"octahedron\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_627cycle_basis = {"cycle_basis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_627cycle_basis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_626cycle_basis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_627cycle_basis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cycle_basis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cycle_basis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_626cycle_basis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_626cycle_basis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cycle_basis", 1);

  /* "giacpy/auto-methods.pxi":3893
 * 
 *         '''
 *         return GiacMethods['cycle_basis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cycle_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cycle_basis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3893, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3884
 *         return GiacMethods['cycle2perm'](self,*args)
 * 
 *      def cycle_basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_basis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cycle_basis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3895
 *         return GiacMethods['cycle_basis'](self,*args)
 * 
 *      def cycle_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_629cycle_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_628cycle_graph, "From Giac's documentation:\n        Help for cycle_graph:\n        cycle_graph(Intg(n)||Lst(V))\n        Returns a cyclic graph on n vertices (or with vertices from list V).\n        See also: 1/ graph 2/ path_graph \n        Ex1:cycle_graph(4)\n        Ex2:cycle_graph([\"one\",\"two\",\"three\",\"four\",\"five\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_629cycle_graph = {"cycle_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_629cycle_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_628cycle_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_629cycle_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cycle_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cycle_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_628cycle_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_628cycle_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cycle_graph", 1);

  /* "giacpy/auto-methods.pxi":3905
 * 
 *         '''
 *         return GiacMethods['cycle_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cycleinv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cycle_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3905, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3895
 *         return GiacMethods['cycle_basis'](self,*args)
 * 
 *      def cycle_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cycle_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3907
 *         return GiacMethods['cycle_graph'](self,*args)
 * 
 *      def cycleinv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycleinv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_631cycleinv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_630cycleinv, "From Giac's documentation:\n        Help for cycleinv:\n        cycleinv(Cycle(c))\n        Returns the inverse cycle of the cycle c.\n        See also: 1/ perminv \n        Ex1:cycleinv([1,3,5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_631cycleinv = {"cycleinv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_631cycleinv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_630cycleinv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_631cycleinv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cycleinv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cycleinv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_630cycleinv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_630cycleinv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cycleinv", 1);

  /* "giacpy/auto-methods.pxi":3916
 * 
 *         '''
 *         return GiacMethods['cycleinv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cycles2permu(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cycleinv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3916, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3907
 *         return GiacMethods['cycle_graph'](self,*args)
 * 
 *      def cycleinv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycleinv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cycleinv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3918
 *         return GiacMethods['cycleinv'](self,*args)
 * 
 *      def cycles2permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycles2permu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_633cycles2permu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_632cycles2permu, "From Giac's documentation:\n        Help for cycles2permu:\n        cycles2permu(Lst(Cycle))\n        Converts a product of cycles into a permutation.\n        See also: 1/ permu2cycles 2/ cycle2perm \n        Ex1:cycles2permu([[1,3,5],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_633cycles2permu = {"cycles2permu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_633cycles2permu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_632cycles2permu};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_633cycles2permu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cycles2permu (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cycles2permu", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_632cycles2permu(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_632cycles2permu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cycles2permu", 1);

  /* "giacpy/auto-methods.pxi":3927
 * 
 *         '''
 *         return GiacMethods['cycles2permu'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cyclotomic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cycles2permu); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3927, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3918
 *         return GiacMethods['cycleinv'](self,*args)
 * 
 *      def cycles2permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycles2permu:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cycles2permu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3929
 *         return GiacMethods['cycles2permu'](self,*args)
 * 
 *      def cyclotomic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyclotomic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_635cyclotomic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_634cyclotomic, "From Giac's documentation:\n        Help for cyclotomic:\n        cyclotomic(Expr)\n        N-th cyclotomic polynomial.\n        See also: 1/ none \n        Ex1:cyclotomic(20)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_635cyclotomic = {"cyclotomic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_635cyclotomic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_634cyclotomic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_635cyclotomic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cyclotomic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cyclotomic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_634cyclotomic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_634cyclotomic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cyclotomic", 1);

  /* "giacpy/auto-methods.pxi":3938
 * 
 *         '''
 *         return GiacMethods['cyclotomic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def cylinder(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cyclotomic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3938, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3929
 *         return GiacMethods['cycles2permu'](self,*args)
 * 
 *      def cyclotomic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyclotomic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cyclotomic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3940
 *         return GiacMethods['cyclotomic'](self,*args)
 * 
 *      def cylinder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cylinder:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_637cylinder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_636cylinder, "From Giac's documentation:\n        Help for cylinder:\n        cylinder(Pnt(A),Vect(v),Real(r),[Real(h)])\n        Draws a cylinder with axis (A,v), with radius r [and with altitude h].\n        See also: 1/ half_cone 2/ cone \n        Ex1:cylinder([0,0,0],[0,1,0],2)\n        Ex2:cylinder([0,0,0],[0,1,0],2,-3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_637cylinder = {"cylinder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_637cylinder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_636cylinder};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_637cylinder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cylinder (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cylinder", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_636cylinder(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_636cylinder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cylinder", 1);

  /* "giacpy/auto-methods.pxi":3950
 * 
 *         '''
 *         return GiacMethods['cylinder'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dash_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_cylinder); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3950, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3940
 *         return GiacMethods['cyclotomic'](self,*args)
 * 
 *      def cylinder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cylinder:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.cylinder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3952
 *         return GiacMethods['cylinder'](self,*args)
 * 
 *      def dash_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dash_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_639dash_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_638dash_line, "From Giac's documentation:\n        Help for dash_line:\n        dash_line(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_639dash_line = {"dash_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_639dash_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_638dash_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_639dash_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dash_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dash_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_638dash_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_638dash_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dash_line", 1);

  /* "giacpy/auto-methods.pxi":3962
 * 
 *         '''
 *         return GiacMethods['dash_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dashdot_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dash_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3962, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3952
 *         return GiacMethods['cylinder'](self,*args)
 * 
 *      def dash_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dash_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dash_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3964
 *         return GiacMethods['dash_line'](self,*args)
 * 
 *      def dashdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdot_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_641dashdot_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_640dashdot_line, "From Giac's documentation:\n        Help for dashdot_line:\n        dashdot_line(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_641dashdot_line = {"dashdot_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_641dashdot_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_640dashdot_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_641dashdot_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dashdot_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dashdot_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_640dashdot_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_640dashdot_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dashdot_line", 1);

  /* "giacpy/auto-methods.pxi":3974
 * 
 *         '''
 *         return GiacMethods['dashdot_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dashdotdot_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dashdot_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3974, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3964
 *         return GiacMethods['dash_line'](self,*args)
 * 
 *      def dashdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdot_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dashdot_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3976
 *         return GiacMethods['dashdot_line'](self,*args)
 * 
 *      def dashdotdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdotdot_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_643dashdotdot_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_642dashdotdot_line, "From Giac's documentation:\n        Help for dashdotdot_line:\n        dashdotdot_line(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_643dashdotdot_line = {"dashdotdot_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_643dashdotdot_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_642dashdotdot_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_643dashdotdot_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dashdotdot_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dashdotdot_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_642dashdotdot_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_642dashdotdot_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dashdotdot_line", 1);

  /* "giacpy/auto-methods.pxi":3986
 * 
 *         '''
 *         return GiacMethods['dashdotdot_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dayofweek(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dashdotdot_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3986, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3976
 *         return GiacMethods['dashdot_line'](self,*args)
 * 
 *      def dashdotdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdotdot_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dashdotdot_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3988
 *         return GiacMethods['dashdotdot_line'](self,*args)
 * 
 *      def dayofweek(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dayofweek:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_645dayofweek(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_644dayofweek, "From Giac's documentation:\n        Help for dayofweek:\n        dayofweek(Int,Int,Int)\n        dayofweek(d,m,y) returns the day of the given date (day,month,year) : 0 for sunday, 1 for monday ...6 for saturday.\n        Ex1:dayofweek(21,4,2014)\n        Ex2:dayofweek(15,10,1582)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_645dayofweek = {"dayofweek", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_645dayofweek, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_644dayofweek};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_645dayofweek(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dayofweek (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dayofweek", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_644dayofweek(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_644dayofweek(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dayofweek", 1);

  /* "giacpy/auto-methods.pxi":3997
 * 
 *         '''
 *         return GiacMethods['dayofweek'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def deSolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dayofweek); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 3997, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3988
 *         return GiacMethods['dashdotdot_line'](self,*args)
 * 
 *      def dayofweek(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dayofweek:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dayofweek", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":3999
 *         return GiacMethods['dayofweek'](self,*args)
 * 
 *      def deSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deSolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_647deSolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_646deSolve, "From Giac's documentation:\n        Help for deSolve:\n        deSolve(Eq,[TimeVar],FncVar)\n        Solves a differential equation or a differential linear system with constant coefficients.\n        See also: 1/ integrate 2/ diff 3/ odesolve 4/ plotode 5/ plotfiefd \n        Ex1:deSolve(y'+x*y=0)\n        Ex2:deSolve(y'+x*y=0,y)\n        Ex3:deSolve(y'+x*y=0,[0,1])\n        Ex4:deSolve([y'+x*y=0,y(0)=1],y)\n        Ex5:deSolve([y'=[[1,2],[2,1]]*y+[x,x+1],y(0)=[1,2]]) \n        Ex6:deSolve(y''+y=0,y)\n        Ex7:deSolve([y''+y=sin(x),y(0)=1,y'(0)=2],y)\n        Ex8:deSolve([y''+y=sin(x),y(0)=1,y'(0)=2],x,y)\n        Ex9:deSolve([y''+y=sin(x),y(0)=1,y'(0)=2],[x,y])\n        Ex10:deSolve(diff(y(t),t)+t*y(t)=0,t,y)\n        Ex11:deSolve(diff(y(t),t)+t*y(t)=0,[t,y])\n        Ex12:deSolve((y''+y=sin(x)) and (y(0)=1) and (y'(0)=2),y)\n        Ex13:deSolve([z''+2*z'+z,z(0)=1,z'(0)=0],u,z)\n        Ex14:deSolve([z''+2*z'+z,z(0)=1,z'(0)=0],z(u))\n        Ex15:deSolve([z'=[[1,2],[2,1]]*z+[t,t+1],z(0)=[1,2]],t,z)\n        Ex16:deSolve([z'=[[1,2],[2,1]]*z+[t,t+1],z(0)=[1,2]],z(t))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_647deSolve = {"deSolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_647deSolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_646deSolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_647deSolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("deSolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "deSolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_646deSolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_646deSolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("deSolve", 1);

  /* "giacpy/auto-methods.pxi":4023
 * 
 *         '''
 *         return GiacMethods['deSolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def debut_enregistrement(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_deSolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4023, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":3999
 *         return GiacMethods['dayofweek'](self,*args)
 * 
 *      def deSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deSolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.deSolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4025
 *         return GiacMethods['deSolve'](self,*args)
 * 
 *      def debut_enregistrement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for debut_enregistrement:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_649debut_enregistrement(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_648debut_enregistrement, "From Giac's documentation:\n        Help for debut_enregistrement:\n        debut_enregistrement(Var(nom_du_dessin))\n        Begins recording the commands making up the drawing; the name of the resulting procedure is the argument.\n        See also: 1/ fin_enregistrement \n        Ex1:debut_enregistrement(maison)\n        Ex2:debut_enregistrement(arbre)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_649debut_enregistrement = {"debut_enregistrement", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_649debut_enregistrement, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_648debut_enregistrement};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_649debut_enregistrement(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("debut_enregistrement (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "debut_enregistrement", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_648debut_enregistrement(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_648debut_enregistrement(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("debut_enregistrement", 1);

  /* "giacpy/auto-methods.pxi":4035
 * 
 *         '''
 *         return GiacMethods['debut_enregistrement'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_debut_enregistrement); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4035, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4025
 *         return GiacMethods['deSolve'](self,*args)
 * 
 *      def debut_enregistrement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for debut_enregistrement:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.debut_enregistrement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4037
 *         return GiacMethods['debut_enregistrement'](self,*args)
 * 
 *      def degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_651degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_650degree, "From Giac's documentation:\n        Help for degree:\n        degree(Poly(P),Var(Var))\n        Degree of the polynomial P with respect to the second argument.\n        See also: 1/ valuation 2/ size 3/ total_degree \n        Ex1:degree(x^3+x)\n        Ex2:degree([1,0,1,0])\n        Ex3:degree(x^3+x*y,y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_651degree = {"degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_651degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_650degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_651degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_650degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_650degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("degree", 1);

  /* "giacpy/auto-methods.pxi":4048
 * 
 *         '''
 *         return GiacMethods['degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def degree_centrality(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4048, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4037
 *         return GiacMethods['debut_enregistrement'](self,*args)
 * 
 *      def degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4050
 *         return GiacMethods['degree'](self,*args)
 * 
 *      def degree_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_centrality:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_653degree_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_652degree_centrality, "From Giac's documentation:\n        Help for degree_centrality:\n        degree_centrality(Graph(G),[Vrtx(v)])\n        Returns the degree centrality of a vertex v in a graph G or the list of degree centralities of vertices in G.\n        See also: 1/ betweenness_centrality 2/ closeness_centrality 3/ harmonic_centrality 4/ information_centrality 5/ katz_centrality \n        Ex1:degree_centrality(graph(6,%{[0,2],[0,5],[1,3],[1,5],[2,5],[3,4],[3,5],[4,5]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_653degree_centrality = {"degree_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_653degree_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_652degree_centrality};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_653degree_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("degree_centrality (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "degree_centrality", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_652degree_centrality(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_652degree_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("degree_centrality", 1);

  /* "giacpy/auto-methods.pxi":4059
 * 
 *         '''
 *         return GiacMethods['degree_centrality'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def degree_sequence(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_degree_centrality); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4059, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4050
 *         return GiacMethods['degree'](self,*args)
 * 
 *      def degree_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_centrality:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.degree_centrality", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4061
 *         return GiacMethods['degree_centrality'](self,*args)
 * 
 *      def degree_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_sequence:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_655degree_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_654degree_sequence, "From Giac's documentation:\n        Help for degree_sequence:\n        degree_sequence(Graph(G))\n        Returns the list of degrees of the vertices of G (arc directions are ignored).\n        See also: 1/ is_graphic_sequence 2/ is_regular 2/ sequence_graph 3/ vertex_degree \n        Ex1:degree_sequence(graph(trail(1,2,3,4,2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_655degree_sequence = {"degree_sequence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_655degree_sequence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_654degree_sequence};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_655degree_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("degree_sequence (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "degree_sequence", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_654degree_sequence(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_654degree_sequence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("degree_sequence", 1);

  /* "giacpy/auto-methods.pxi":4070
 * 
 *         '''
 *         return GiacMethods['degree_sequence'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def degrees(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_degree_sequence); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4070, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4061
 *         return GiacMethods['degree_centrality'](self,*args)
 * 
 *      def degree_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_sequence:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.degree_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4072
 *         return GiacMethods['degree_sequence'](self,*args)
 * 
 *      def degrees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degrees:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_657degrees(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_656degrees, "From Giac's documentation:\n        Help for degrees:\n        degrees(Real(rad))\n        Converts radians to degrees (inexact).\n        See also: 1/ radians \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_657degrees = {"degrees", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_657degrees, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_656degrees};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_657degrees(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("degrees (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "degrees", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_656degrees(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_656degrees(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("degrees", 1);

  /* "giacpy/auto-methods.pxi":4080
 * 
 *         '''
 *         return GiacMethods['degrees'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def delcols(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_degrees); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4080, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4072
 *         return GiacMethods['degree_sequence'](self,*args)
 * 
 *      def degrees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degrees:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.degrees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4082
 *         return GiacMethods['degrees'](self,*args)
 * 
 *      def delcols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delcols:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_659delcols(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_658delcols, "From Giac's documentation:\n        Help for delcols:\n        delcols(Mtrx(A),Interval(n1..n2)||n1)\n        Returns the matrix where the columns n1..n2 (or n1) of the matrix A are deleted.\n        See also: 1/ delrows \n        Ex1:delcols([[1,2,3],[4,5,6],[7,8,9]],1..1)\n        Ex2:delcols([[1,2,3],[4,5,6],[7,8,9]],0..1)\n        Ex3:delcols([[1,2,3],[4,5,6],[7,8,9]],1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_659delcols = {"delcols", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_659delcols, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_658delcols};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_659delcols(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delcols (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "delcols", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_658delcols(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_658delcols(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delcols", 1);

  /* "giacpy/auto-methods.pxi":4093
 * 
 *         '''
 *         return GiacMethods['delcols'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def delete_arc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_delcols); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4093, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4082
 *         return GiacMethods['degrees'](self,*args)
 * 
 *      def delcols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delcols:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.delcols", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4095
 *         return GiacMethods['delcols'](self,*args)
 * 
 *      def delete_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_arc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_661delete_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_660delete_arc, "From Giac's documentation:\n        Help for delete_arc:\n        delete_arc(Graph(G),Edge(e)||Trail(T)||Lst(E))\n        Returns a modified copy of a digraph G with the arc e (or trail T or list of arcs E) removed from G.\n        See also: 1/ add_arc 2/ delete_edge 3/ digraph 4/ edges 5/ has_arc 6/ trail \n        Ex1:delete_arc(digraph(trail(1,2,3,4,5,1)),[5,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_661delete_arc = {"delete_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_661delete_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_660delete_arc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_661delete_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delete_arc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "delete_arc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_660delete_arc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_660delete_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delete_arc", 1);

  /* "giacpy/auto-methods.pxi":4104
 * 
 *         '''
 *         return GiacMethods['delete_arc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def delete_edge(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_delete_arc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4104, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4095
 *         return GiacMethods['delcols'](self,*args)
 * 
 *      def delete_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_arc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.delete_arc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4106
 *         return GiacMethods['delete_arc'](self,*args)
 * 
 *      def delete_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_edge:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_663delete_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_662delete_edge, "From Giac's documentation:\n        Help for delete_edge:\n        delete_edge(Graph(G),Edge(e)||Trail(T)||Lst(E))\n        Returns a modified copy of an undirected graph G with the edge e (or trail T or list of edges E) removed from G.\n        See also: 1/ add_edge 2/ delete_arc 3/ edges 4/ graph 5/ has_edge 6/ trail \n        Ex1:delete_edge(cycle_graph(4),[1,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_663delete_edge = {"delete_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_663delete_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_662delete_edge};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_663delete_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delete_edge (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "delete_edge", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_662delete_edge(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_662delete_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delete_edge", 1);

  /* "giacpy/auto-methods.pxi":4115
 * 
 *         '''
 *         return GiacMethods['delete_edge'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def delete_vertex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_delete_edge); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4115, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4106
 *         return GiacMethods['delete_arc'](self,*args)
 * 
 *      def delete_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_edge:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.delete_edge", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4117
 *         return GiacMethods['delete_edge'](self,*args)
 * 
 *      def delete_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_vertex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_665delete_vertex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_664delete_vertex, "From Giac's documentation:\n        Help for delete_vertex:\n        delete_vertex(Graph(G),Vrtx(v)||Lst(V))\n        Returns a modified copy of G with the vertex v (or vertices from V) removed.\n        See also: 1/ add_vertex 2/ induced_subgraph \n        Ex1:delete_vertex(cycle_graph(5),[1,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_665delete_vertex = {"delete_vertex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_665delete_vertex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_664delete_vertex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_665delete_vertex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delete_vertex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "delete_vertex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_664delete_vertex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_664delete_vertex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delete_vertex", 1);

  /* "giacpy/auto-methods.pxi":4126
 * 
 *         '''
 *         return GiacMethods['delete_vertex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def delrows(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_delete_vertex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4126, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4117
 *         return GiacMethods['delete_edge'](self,*args)
 * 
 *      def delete_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_vertex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.delete_vertex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4128
 *         return GiacMethods['delete_vertex'](self,*args)
 * 
 *      def delrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delrows:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_667delrows(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_666delrows, "From Giac's documentation:\n        Help for delrows:\n        delrows(Mtrx(A),Interval(n1..n2)||n1)\n        Returns the matrix where the rows n1..n2 (or n1) of the matrix A are deleted.\n        See also: 1/ delcols \n        Ex1:delrows([[1,2,3],[4,5,6],[7,8,9]],1..1)\n        Ex2:delrows([[1,2,3],[4,5,6],[7,8,9]],0..1)\n        Ex3:delrows([[1,2,3],[4,5,6],[7,8,9]],1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_667delrows = {"delrows", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_667delrows, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_666delrows};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_667delrows(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delrows (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "delrows", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_666delrows(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_666delrows(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delrows", 1);

  /* "giacpy/auto-methods.pxi":4139
 * 
 *         '''
 *         return GiacMethods['delrows'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def deltalist(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_delrows); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4139, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4128
 *         return GiacMethods['delete_vertex'](self,*args)
 * 
 *      def delrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delrows:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.delrows", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4141
 *         return GiacMethods['delrows'](self,*args)
 * 
 *      def deltalist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deltalist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_669deltalist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_668deltalist, "From Giac's documentation:\n        Help for deltalist:\n        deltalist(Lst)\n        Returns the list of the differences of two terms in succession.\n        See also: 1/  \n        Ex1:deltalist([1,4,8,9])\n        Ex2:deltalist([1,8,4,9])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_669deltalist = {"deltalist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_669deltalist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_668deltalist};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_669deltalist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("deltalist (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "deltalist", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_668deltalist(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_668deltalist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("deltalist", 1);

  /* "giacpy/auto-methods.pxi":4151
 * 
 *         '''
 *         return GiacMethods['deltalist'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def denom(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_deltalist); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4151, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4141
 *         return GiacMethods['delrows'](self,*args)
 * 
 *      def deltalist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deltalist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.deltalist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4153
 *         return GiacMethods['deltalist'](self,*args)
 * 
 *      def denom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for denom:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_671denom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_670denom, "From Giac's documentation:\n        Help for denom:\n        denom(Frac(a/b) or RatFrac)\n        Returns the denominator of the simplified fraction.\n        See also: 1/ getDenom 2/ getNum 3/ numer 4/ f2nd \n        Ex1:denom(25/15)\n        Ex2:denom((x^3-1)/(x^2-1))\n        Ex3:denom(1+(x^3-1)/x^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_671denom = {"denom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_671denom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_670denom};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_671denom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("denom (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "denom", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_670denom(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_670denom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("denom", 1);

  /* "giacpy/auto-methods.pxi":4164
 * 
 *         '''
 *         return GiacMethods['denom'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def densityplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_denom); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4164, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4153
 *         return GiacMethods['deltalist'](self,*args)
 * 
 *      def denom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for denom:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.denom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4166
 *         return GiacMethods['denom'](self,*args)
 * 
 *      def densityplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for densityplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_673densityplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_672densityplot, "From Giac's documentation:\n        Help for densityplot:\n        densityplot(Expr,[x=xrange,y=yrange],[z],[xstep],[ystep])\n        Shows in the plane with colors the graph of an expression of 2 variables.\n        See also: 1/ plotfunc 2/ plotcontour \n        Ex1:densityplot(x^2-y^2,[x=-2..2,y=-2..2],xstep=0.1,ystep=0.1)\n        Ex2:densityplot(x^2-y^2,[x=-2..2,y=-2..2],z=-2..2,xstep=0.1,ystep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_673densityplot = {"densityplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_673densityplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_672densityplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_673densityplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("densityplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "densityplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_672densityplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_672densityplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("densityplot", 1);

  /* "giacpy/auto-methods.pxi":4176
 * 
 *         '''
 *         return GiacMethods['densityplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def departures(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_densityplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4176, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4166
 *         return GiacMethods['denom'](self,*args)
 * 
 *      def densityplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for densityplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.densityplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4178
 *         return GiacMethods['densityplot'](self,*args)
 * 
 *      def departures(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for departures:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_675departures(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_674departures, "From Giac's documentation:\n        Help for departures:\n        departures(Graph(G),[Vrtx(v)])\n        Returns the list of vertices of digraph G which are connected to v with arcs pointing away from v. If v is omitted, a list of departures is computed for every vertex in G.\n        See also: 1/ out_degree \n        Ex1:departures(digraph(%{[1,2],[1,3],[2,3]%}),1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_675departures = {"departures", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_675departures, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_674departures};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_675departures(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("departures (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "departures", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_674departures(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_674departures(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("departures", 1);

  /* "giacpy/auto-methods.pxi":4187
 * 
 *         '''
 *         return GiacMethods['departures'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def derive(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_departures); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4187, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4178
 *         return GiacMethods['densityplot'](self,*args)
 * 
 *      def departures(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for departures:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.departures", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4189
 *         return GiacMethods['departures'](self,*args)
 * 
 *      def derive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for derive:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_677derive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_676derive, "From Giac's documentation:\n        Help for derive:\n        derive(Expr or Fnc,[SeqVar or LstVar],[n])\n        Returns the derivative with respect to the 2nd argument.\n        See also: 1/ ' 2/ function_diff 3/ integrate 4/ taux_accroissement 5/ implicitdiff \n        Ex1:derive(x^3-x)\n        Ex2:derive(x^3-x,x,3)\n        Ex3:derive(x^3-x,quote(x)$3)\n        Ex4:derive((diff@@3)('x^3-x'))\n        Ex5:derive(x*y+z*y,y)\n        Ex6:derive(x*y+z*y,y,z)\n        Ex7:derive(x*y+z*y,[y,z])\n        Ex8: f(x):=sin(2x);g:=diff(f);h:=diff(diff(f))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_677derive = {"derive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_677derive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_676derive};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_677derive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("derive (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "derive", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_676derive(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_676derive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("derive", 1);

  /* "giacpy/auto-methods.pxi":4205
 * 
 *         '''
 *         return GiacMethods['derive'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def deriver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_derive); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4205, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4189
 *         return GiacMethods['departures'](self,*args)
 * 
 *      def derive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for derive:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.derive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4207
 *         return GiacMethods['derive'](self,*args)
 * 
 *      def deriver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deriver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_679deriver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_678deriver, "From Giac's documentation:\n        Help for deriver:\n        deriver(Expr or Fnc,[SeqVar or LstVar],[n])\n        Returns the derivative with respect to the 2nd argument.\n        See also: 1/ ' 2/ function_diff 3/ integrate 4/ taux_accroissement 5/ implicitdiff \n        Ex1:deriver(x^3-x)\n        Ex2:deriver(x^3-x,x,3)\n        Ex3:deriver(x^3-x,quote(x)$3)\n        Ex4:deriver((diff@@3)('x^3-x'))\n        Ex5:deriver(x*y+z*y,y)\n        Ex6:deriver(x*y+z*y,y,z)\n        Ex7:deriver(x*y+z*y,[y,z])\n        Ex8: f(x):=sin(2x);g:=diff(f);h:=diff(diff(f))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_679deriver = {"deriver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_679deriver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_678deriver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_679deriver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("deriver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "deriver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_678deriver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_678deriver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("deriver", 1);

  /* "giacpy/auto-methods.pxi":4223
 * 
 *         '''
 *         return GiacMethods['deriver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def desolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_deriver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4223, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4207
 *         return GiacMethods['derive'](self,*args)
 * 
 *      def deriver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deriver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.deriver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4225
 *         return GiacMethods['deriver'](self,*args)
 * 
 *      def desolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for desolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_681desolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_680desolve, "From Giac's documentation:\n        Help for desolve:\n        desolve(Eq,[TimeVar],FncVar)\n        Solves a differential equation or a differential linear system with constant coefficients.\n        See also: 1/ integrate 2/ diff 3/ odesolve 4/ plotode 5/ plotfiefd \n        Ex1:desolve(y'+x*y=0)\n        Ex2:desolve(y'+x*y=0,y)\n        Ex3:desolve(y'+x*y=0,[0,1])\n        Ex4:desolve([y'+x*y=0,y(0)=1],y)\n        Ex5:desolve([y'=[[1,2],[2,1]]*y+[x,x+1],y(0)=[1,2]]) \n        Ex6:desolve(y''+y=0,y)\n        Ex7:desolve([y''+y=sin(x),y(0)=1,y'(0)=2],y)\n        Ex8:desolve([y''+y=sin(x),y(0)=1,y'(0)=2],x,y)\n        Ex9:desolve([y''+y=sin(x),y(0)=1,y'(0)=2],[x,y])\n        Ex10:desolve(diff(y(t),t)+t*y(t)=0,t,y)\n        Ex11:desolve(diff(y(t),t)+t*y(t)=0,[t,y])\n        Ex12:desolve((y''+y=sin(x)) and (y(0)=1) and (y'(0)=2),y)\n        Ex13:desolve([z''+2*z'+z,z(0)=1,z'(0)=0],u,z)\n        Ex14:desolve([z''+2*z'+z,z(0)=1,z'(0)=0],z(u))\n        Ex15:desolve([z'=[[1,2],[2,1]]*z+[t,t+1],z(0)=[1,2]],t,z)\n        Ex16:desolve([z'=[[1,2],[2,1]]*z+[t,t+1],z(0)=[1,2]],z(t))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_681desolve = {"desolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_681desolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_680desolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_681desolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("desolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "desolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_680desolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_680desolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("desolve", 1);

  /* "giacpy/auto-methods.pxi":4249
 * 
 *         '''
 *         return GiacMethods['desolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dessine_tortue(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_desolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4249, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4225
 *         return GiacMethods['deriver'](self,*args)
 * 
 *      def desolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for desolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.desolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4251
 *         return GiacMethods['desolve'](self,*args)
 * 
 *      def dessine_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dessine_tortue:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_683dessine_tortue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_682dessine_tortue, "From Giac's documentation:\n        Help for dessine_tortue:\n        dessine_tortue([Intg(n)])\n        Draws the full (or not full if n=1) triangle representing the turtle.\n        See also: 1/ crayon \n        Ex1:dessine_tortue()\n        Ex2:dessine_tortue(0)\n        Ex3:dessine_tortue(1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_683dessine_tortue = {"dessine_tortue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_683dessine_tortue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_682dessine_tortue};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_683dessine_tortue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dessine_tortue (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dessine_tortue", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_682dessine_tortue(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_682dessine_tortue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dessine_tortue", 1);

  /* "giacpy/auto-methods.pxi":4262
 * 
 *         '''
 *         return GiacMethods['dessine_tortue'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def det(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dessine_tortue); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4262, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4251
 *         return GiacMethods['desolve'](self,*args)
 * 
 *      def dessine_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dessine_tortue:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dessine_tortue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4264
 *         return GiacMethods['dessine_tortue'](self,*args)
 * 
 *      def det(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_685det(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_684det, "From Giac's documentation:\n        Help for det:\n        det(Mtrx)\n        Determinant of a square matrix M.\n        See also: 1/ rref 2/ det_minor 3/ Det \n        Ex1:det([[1,2],[3,4]])\n        Ex2:det([[1,2,3],[1,3,6],[2,5,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_685det = {"det", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_685det, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_684det};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_685det(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("det (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "det", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_684det(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_684det(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("det", 1);

  /* "giacpy/auto-methods.pxi":4274
 * 
 *         '''
 *         return GiacMethods['det'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def det_minor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_det); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4274, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4264
 *         return GiacMethods['dessine_tortue'](self,*args)
 * 
 *      def det(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.det", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4276
 *         return GiacMethods['det'](self,*args)
 * 
 *      def det_minor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det_minor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_687det_minor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_686det_minor, "From Giac's documentation:\n        Help for det_minor:\n        det_minor(Mtrx(A))\n        Returns the determinant calculated with the calculus of minors.\n        See also: 1/ det \n        Ex1:det_minor([[1,2],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_687det_minor = {"det_minor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_687det_minor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_686det_minor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_687det_minor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("det_minor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "det_minor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_686det_minor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_686det_minor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("det_minor", 1);

  /* "giacpy/auto-methods.pxi":4285
 * 
 *         '''
 *         return GiacMethods['det_minor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def developper(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_det_minor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4285, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4276
 *         return GiacMethods['det'](self,*args)
 * 
 *      def det_minor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det_minor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.det_minor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4287
 *         return GiacMethods['det_minor'](self,*args)
 * 
 *      def developper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_689developper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_688developper, "From Giac's documentation:\n        Help for developper:\n        developper(Expr)\n        Full distribution of * and / over + and -.\n        See also: 1/ texpand 2/ normal 3/ simplify 4/ ratnormal \n        Ex1:developper((x+y)*(z+1))\n        Ex2:developper((a+b+c)/d)\n        Ex3:developper((y+x)*(z+y)*(x+z))\n        Ex4:developper((x+3)^4)\n        Ex5:developper((2*x-2*1)*(x^2-3*x+2)+(x^2-2*x+3)*(2*x-3*1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_689developper = {"developper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_689developper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_688developper};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_689developper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("developper (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "developper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_688developper(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_688developper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("developper", 1);

  /* "giacpy/auto-methods.pxi":4300
 * 
 *         '''
 *         return GiacMethods['developper'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def developper_transcendant(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_developper); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4300, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4287
 *         return GiacMethods['det_minor'](self,*args)
 * 
 *      def developper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.developper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4302
 *         return GiacMethods['developper'](self,*args)
 * 
 *      def developper_transcendant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper_transcendant:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_691developper_transcendant(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_690developper_transcendant, "From Giac's documentation:\n        Help for developper_transcendant:\n        developper_transcendant(Expr)\n        Expands transcendental expressions.\n        See also: 1/ tcollect 2/ tlin 3/ lin 4/ trigexpand \n        Ex1:developper_transcendant(sin(2*x)+exp(x+y))\n        Ex2:developper_transcendant(cos(x+y))\n        Ex3:developper_transcendant(cos(3*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_691developper_transcendant = {"developper_transcendant", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_691developper_transcendant, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_690developper_transcendant};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_691developper_transcendant(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("developper_transcendant (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "developper_transcendant", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_690developper_transcendant(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_690developper_transcendant(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("developper_transcendant", 1);

  /* "giacpy/auto-methods.pxi":4313
 * 
 *         '''
 *         return GiacMethods['developper_transcendant'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dfc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_developper_transcendant); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4313, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4302
 *         return GiacMethods['developper'](self,*args)
 * 
 *      def developper_transcendant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper_transcendant:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.developper_transcendant", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4315
 *         return GiacMethods['developper_transcendant'](self,*args)
 * 
 *      def dfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_693dfc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_692dfc, "From Giac's documentation:\n        Help for dfc:\n        dfc(Real(x0),Int(n)||Real(eps))\n        Returns the continued fraction development at x0 of order n or with precision eps.\n        See also: 1/ dfc2f 2/ convert \n        Ex1:dfc(sqrt(2),5)\n        Ex2:dfc(pi,4)\n        Ex3:dfc(evalf(pi),1e-09)\n        Ex4: convert(sqrt(2),confrac,'dev');dev\n        Ex5: convert(9976/6961,confrac,'l');l\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_693dfc = {"dfc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_693dfc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_692dfc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_693dfc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dfc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dfc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_692dfc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_692dfc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dfc", 1);

  /* "giacpy/auto-methods.pxi":4328
 * 
 *         '''
 *         return GiacMethods['dfc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dfc2f(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dfc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4328, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4315
 *         return GiacMethods['developper_transcendant'](self,*args)
 * 
 *      def dfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dfc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4330
 *         return GiacMethods['dfc'](self,*args)
 * 
 *      def dfc2f(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc2f:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_695dfc2f(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_694dfc2f, "From Giac's documentation:\n        Help for dfc2f:\n        dfc2f(LstFrac_Cont))\n        Converts a continued fraction into a real.\n        See also: 1/ dfc 2/ convert \n        Ex1:dfc2f([1,1,1])\n        Ex2:dfc2f([1,2,[2]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_695dfc2f = {"dfc2f", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_695dfc2f, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_694dfc2f};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_695dfc2f(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dfc2f (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dfc2f", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_694dfc2f(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_694dfc2f(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dfc2f", 1);

  /* "giacpy/auto-methods.pxi":4340
 * 
 *         '''
 *         return GiacMethods['dfc2f'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def diag(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dfc2f); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4340, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4330
 *         return GiacMethods['dfc'](self,*args)
 * 
 *      def dfc2f(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc2f:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dfc2f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4342
 *         return GiacMethods['dfc2f'](self,*args)
 * 
 *      def diag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diag:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_697diag(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_696diag, "From Giac's documentation:\n        Help for diag:\n        diag(Lst(l)||(Mtrx(A),[left||right||lu])||Lst(l),Lst(d),Lst(u))\n        With 1 argument returns either the diagonal matrix with diagonal l or the diagonal of A, with 2 arguments returns the large left (lower) triangular part of A or the large right (upper) triangular part of A or factors A into 3 parts : strict left (lower) triangular, diagonal, strict right (upper) triangular and with 3 arguments returns the tridiagonal matrix with diagonals l,d,u.\n        See also: 1/ identity 2/ lu 3/ BlockDiagonal 4/ upper 5/ lower \n        Ex1:diag([[1,2],[3,4]])\n        Ex2:diag([1,2,3])\n        Ex3:diag([[1,2],[3,4]],left)\n        Ex4:diag([[1,2],[3,4]],right)\n        Ex5:diag([[1,2],[3,4]],lu)\n        Ex6:diag([1,2],[3,4,5],[6,7])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_697diag = {"diag", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_697diag, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_696diag};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_697diag(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("diag (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "diag", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_696diag(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_696diag(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("diag", 1);

  /* "giacpy/auto-methods.pxi":4356
 * 
 *         '''
 *         return GiacMethods['diag'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def diff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_diag); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4356, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4342
 *         return GiacMethods['dfc2f'](self,*args)
 * 
 *      def diag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diag:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.diag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4358
 *         return GiacMethods['diag'](self,*args)
 * 
 *      def diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_699diff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_698diff, "From Giac's documentation:\n        Help for diff:\n        diff(Expr or Fnc,[SeqVar or LstVar],[n])\n        Returns the derivative with respect to the 2nd argument.\n        See also: 1/ ' 2/ function_diff 3/ integrate 4/ taux_accroissement 5/ implicitdiff \n        Ex1:diff(x^3-x)\n        Ex2:diff(x^3-x,x,3)\n        Ex3:diff(x^3-x,quote(x)$3)\n        Ex4:diff((diff@@3)('x^3-x'))\n        Ex5:diff(x*y+z*y,y)\n        Ex6:diff(x*y+z*y,y,z)\n        Ex7:diff(x*y+z*y,[y,z])\n        Ex8: f(x):=sin(2x);g:=diff(f);h:=diff(diff(f))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_699diff = {"diff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_699diff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_698diff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_699diff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("diff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "diff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_698diff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_698diff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("diff", 1);

  /* "giacpy/auto-methods.pxi":4374
 * 
 *         '''
 *         return GiacMethods['diff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def digraph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_diff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4374, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4358
 *         return GiacMethods['diag'](self,*args)
 * 
 *      def diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.diff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4376
 *         return GiacMethods['diff'](self,*args)
 * 
 *      def digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for digraph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_701digraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_700digraph, "From Giac's documentation:\n        Help for digraph:\n        digraph([Lst(V)],[Set(E)],[Mtrx(A)],[options])\n        Create a directed (un)weighted graph from vertices V, edges E and/or adjacency or weight matrix A. All parameters are optional.\n        See also: 1/ graph 2/ trail \n        Ex1:digraph(%{[1,2],[2,3],[3,4],[4,1]%})\n        Ex2:digraph([a,b,c,d],%{[[a,b],1.0],[[a,c],2.3],[[b,d],3.1],[[c,d],4]%})\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_701digraph = {"digraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_701digraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_700digraph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_701digraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("digraph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "digraph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_700digraph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_700digraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("digraph", 1);

  /* "giacpy/auto-methods.pxi":4386
 * 
 *         '''
 *         return GiacMethods['digraph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dijkstra(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_digraph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4386, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4376
 *         return GiacMethods['diff'](self,*args)
 * 
 *      def digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for digraph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.digraph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4388
 *         return GiacMethods['digraph'](self,*args)
 * 
 *      def dijkstra(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dijkstra:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_703dijkstra(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_702dijkstra, "From Giac's documentation:\n        Help for dijkstra:\n        dijkstra(Graph(G),Vrtx(v),[Vrtx(w)||Lst(W)])\n        Returns the cheapest weighted path from the vertex v to w (or to vertices from W) in an undirected graph G. The output is a list [[v1,v2,...,vk],d] (or a list of such lists) where v1,v2,...,vk are vertices along the path and d is the path weight.\n        See also: 1/ allpairs_distance 2/ shortest_path \n        Ex1:dijkstra(graph(%{[[1,2],1],[[2,3],3],[[3,4],7],[[4,5],3],[[5,6],3],[[1,6],3]%}),1,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_703dijkstra = {"dijkstra", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_703dijkstra, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_702dijkstra};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_703dijkstra(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dijkstra (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dijkstra", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_702dijkstra(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_702dijkstra(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dijkstra", 1);

  /* "giacpy/auto-methods.pxi":4397
 * 
 *         '''
 *         return GiacMethods['dijkstra'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dim(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dijkstra); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4397, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4388
 *         return GiacMethods['digraph'](self,*args)
 * 
 *      def dijkstra(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dijkstra:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dijkstra", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4399
 *         return GiacMethods['dijkstra'](self,*args)
 * 
 *      def dim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dim:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_705dim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_704dim, "From Giac's documentation:\n        Help for dim:\n        dim(Mtrx)\n        Returns the list which gives the dimension of the matrix specified as argument.\n        See also: 1/ rowdim 2/ coldim 3/ sizes 4/ size \n        Ex1:dim([[1,2,3],[4,5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_705dim = {"dim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_705dim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_704dim};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_705dim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dim (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dim", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_704dim(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_704dim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dim", 1);

  /* "giacpy/auto-methods.pxi":4408
 * 
 *         '''
 *         return GiacMethods['dim'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def directed(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4408, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4399
 *         return GiacMethods['dijkstra'](self,*args)
 * 
 *      def dim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dim:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4410
 *         return GiacMethods['dim'](self,*args)
 * 
 *      def directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for directed:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_707directed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_706directed, "From Giac's documentation:\n        Help for directed:\n        directed(Opt)\n        Option for graph and digraph commands.\n        See also: 1/ weighted 2/ graph 3/ digraph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_707directed = {"directed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_707directed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_706directed};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_707directed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("directed (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "directed", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_706directed(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_706directed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("directed", 1);

  /* "giacpy/auto-methods.pxi":4418
 * 
 *         '''
 *         return GiacMethods['directed'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def discard_edge_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_directed); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4418, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4410
 *         return GiacMethods['dim'](self,*args)
 * 
 *      def directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for directed:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.directed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4420
 *         return GiacMethods['directed'](self,*args)
 * 
 *      def discard_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_edge_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_709discard_edge_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_708discard_edge_attribute, "From Giac's documentation:\n        Help for discard_edge_attribute:\n        discard_edge_attribute(Graph(G),Edge(e),Seq(tag1=value1,tag2=value2,..))\n        Discards the attributes with tags tag1, tag2, ... assigned to the edge e in G and returns a modified copy of G.\n        See also: 1/ get_edge_attribute 2/ set_edge_attribute 3/ list_edge_attributes \n        Ex1:discard_edge_attribute(cycle_graph(3),[1,2],\"cost\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_709discard_edge_attribute = {"discard_edge_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_709discard_edge_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_708discard_edge_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_709discard_edge_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("discard_edge_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "discard_edge_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_708discard_edge_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_708discard_edge_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("discard_edge_attribute", 1);

  /* "giacpy/auto-methods.pxi":4429
 * 
 *         '''
 *         return GiacMethods['discard_edge_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def discard_graph_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_discard_edge_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4429, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4420
 *         return GiacMethods['directed'](self,*args)
 * 
 *      def discard_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_edge_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.discard_edge_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4431
 *         return GiacMethods['discard_edge_attribute'](self,*args)
 * 
 *      def discard_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_graph_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_711discard_graph_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_710discard_graph_attribute, "From Giac's documentation:\n        Help for discard_graph_attribute:\n        discard_graph_attribute(Graph(G),Seq(tag1=value1,tag2=value2,..))\n        Discards the graph attributes with tags tag1, tag2, ... and returns a modified copy of G.\n        See also: 1/ get_graph_attribute 2/ set_graph_attribute 3/ list_graph_attributes \n        Ex1:discard_graph_attribute(cycle_graph(3),\"name\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_711discard_graph_attribute = {"discard_graph_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_711discard_graph_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_710discard_graph_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_711discard_graph_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("discard_graph_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "discard_graph_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_710discard_graph_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_710discard_graph_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("discard_graph_attribute", 1);

  /* "giacpy/auto-methods.pxi":4440
 * 
 *         '''
 *         return GiacMethods['discard_graph_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def discard_vertex_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_discard_graph_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4440, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4431
 *         return GiacMethods['discard_edge_attribute'](self,*args)
 * 
 *      def discard_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_graph_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.discard_graph_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4442
 *         return GiacMethods['discard_graph_attribute'](self,*args)
 * 
 *      def discard_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_vertex_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_713discard_vertex_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_712discard_vertex_attribute, "From Giac's documentation:\n        Help for discard_vertex_attribute:\n        discard_vertex_attribute(Graph(G),Vrtx(v),Seq(tag1=value1,tag2=value2,..))\n        Discards the attributes with tags tag1, tag2, ... assigned to the vertex v in G and returns a modified copy of G.\n        See also: 1/ get_vertex_attribute 2/ set_vertex_attribute 3/ list_vertex_attributes \n        Ex1:discard_vertex_attribute(cycle_graph(3),1,\"supply\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_713discard_vertex_attribute = {"discard_vertex_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_713discard_vertex_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_712discard_vertex_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_713discard_vertex_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("discard_vertex_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "discard_vertex_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_712discard_vertex_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_712discard_vertex_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("discard_vertex_attribute", 1);

  /* "giacpy/auto-methods.pxi":4451
 * 
 *         '''
 *         return GiacMethods['discard_vertex_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def disjoint_union(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_discard_vertex_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4451, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4442
 *         return GiacMethods['discard_graph_attribute'](self,*args)
 * 
 *      def discard_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_vertex_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.discard_vertex_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4453
 *         return GiacMethods['discard_vertex_attribute'](self,*args)
 * 
 *      def disjoint_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disjoint_union:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_715disjoint_union(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_714disjoint_union, "From Giac's documentation:\n        Help for disjoint_union:\n        disjoint_union(Seq(G1,G2,...))\n        Returns the disjoint union of graphs G1, G2, ... Vertices in the resulting graph are labelled with \"k:v\", where k is index of the corresponding k-th graph Gk and v is vertex in Gk.\n        See also: 1/ graph_join 2/ graph_union \n        Ex1:disjoint_union(is_connected(disjoint_union(cycle_graph(5),path_graph(4))))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_715disjoint_union = {"disjoint_union", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_715disjoint_union, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_714disjoint_union};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_715disjoint_union(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("disjoint_union (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "disjoint_union", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_714disjoint_union(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_714disjoint_union(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("disjoint_union", 1);

  /* "giacpy/auto-methods.pxi":4462
 * 
 *         '''
 *         return GiacMethods['disjoint_union'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def display(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_disjoint_union); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4462, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4453
 *         return GiacMethods['discard_vertex_attribute'](self,*args)
 * 
 *      def disjoint_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disjoint_union:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.disjoint_union", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4464
 *         return GiacMethods['disjoint_union'](self,*args)
 * 
 *      def display(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for display:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_717display(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_716display, "From Giac's documentation:\n        Help for display:\n        display([GeoObj or legende],Intg)\n        Draws a geometrical object with colors black=0 red=1 green=2 yellow=3 blue=4, filled with the color in the interior of a closed curve,line_width_n (0<n<8) is for the width of the line and dash_line is for dotted line.\n        See also: 1/ -< 2/ legende \n        Ex1:display(A,1)\n        Ex2:display(F:=point(2+1.5*i),2)\n        Ex3:display(point(2+1.5*i),2)\n        Ex4:display(legende(1+i,\"abc\"),4)\n        Ex5:display(square(0,1),filled+red)\n        Ex6:display(carre(0,1),rempli+rouge)\n        Ex7:display(circle(0,1),filled)\n        Ex8:display(line(y=x),green+dash_line+line_width_2)\n        Ex9:display(red);square(0,1);\n        Ex10:display(red+filled);square(0,1);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_717display = {"display", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_717display, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_716display};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_717display(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("display (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "display", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_716display(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_716display(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("display", 1);

  /* "giacpy/auto-methods.pxi":4482
 * 
 *         '''
 *         return GiacMethods['display'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def disque(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_display); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4482, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4464
 *         return GiacMethods['disjoint_union'](self,*args)
 * 
 *      def display(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for display:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.display", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4484
 *         return GiacMethods['display'](self,*args)
 * 
 *      def disque(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_719disque(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_718disque, "From Giac's documentation:\n        Help for disque:\n        disque(Real(r),[Real(a)],[Real(b)])\n        Draws a disk with radius r (resp a sector with angle (0,a) or (a,b)), tangent at the turtle position.\n        See also: 1/ rond \n        Ex1: disque 30\n        Ex2:disque(40)\n        Ex3:disque(40,90)\n        Ex4:disque(40,10,100)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_719disque = {"disque", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_719disque, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_718disque};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_719disque(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("disque (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "disque", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_718disque(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_718disque(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("disque", 1);

  /* "giacpy/auto-methods.pxi":4496
 * 
 *         '''
 *         return GiacMethods['disque'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def disque_centre(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_disque); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4496, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4484
 *         return GiacMethods['display'](self,*args)
 * 
 *      def disque(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.disque", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4498
 *         return GiacMethods['disque'](self,*args)
 * 
 *      def disque_centre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque_centre:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_721disque_centre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_720disque_centre, "From Giac's documentation:\n        Help for disque_centre:\n        disque_centre(Real(r),[Real(a)],[Real(b)])\n        Draws a disk with radius r (resp a sector with angle (0,a) or (a,b)) with center at the turtle position.\n        See also: 1/ rond \n        Ex1: disque_centre 30\n        Ex2:disque_centre(40)\n        Ex3:disque_centre(40,90)\n        Ex4:disque_centre(40,10,100)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_721disque_centre = {"disque_centre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_721disque_centre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_720disque_centre};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_721disque_centre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("disque_centre (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "disque_centre", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_720disque_centre(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_720disque_centre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("disque_centre", 1);

  /* "giacpy/auto-methods.pxi":4510
 * 
 *         '''
 *         return GiacMethods['disque_centre'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def distance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_disque_centre); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4510, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4498
 *         return GiacMethods['disque'](self,*args)
 * 
 *      def disque_centre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque_centre:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.disque_centre", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4512
 *         return GiacMethods['disque_centre'](self,*args)
 * 
 *      def distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_723distance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_722distance, "From Giac's documentation:\n        Help for distance:\n        distance((Pnt or Cplx),(Pnt or Cplx or Curve))\n        Calculates the distance between 2 points or a point and a curve.\n        See also: 1/ distance2 2/ distanceat 3/ distanceatraw \n        Ex1:distance(point(0),point(1+i))\n        Ex2:distance(1+i,segment(1-i,i))\n        Ex3:distance(0,1+i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_723distance = {"distance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_723distance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_722distance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_723distance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("distance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "distance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_722distance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_722distance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("distance", 1);

  /* "giacpy/auto-methods.pxi":4523
 * 
 *         '''
 *         return GiacMethods['distance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def distance2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_distance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4523, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4512
 *         return GiacMethods['disque_centre'](self,*args)
 * 
 *      def distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4525
 *         return GiacMethods['distance'](self,*args)
 * 
 *      def distance2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_725distance2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_724distance2, "From Giac's documentation:\n        Help for distance2:\n        distance2((Pnt or Cplx),(Pnt or Cplx or Curve))\n        Calculates the square of the distance between 2 points or a point and a curve.\n        See also: 1/ distance \n        Ex1:distance2(point(0),point(1+i))\n        Ex2:distance2(1+i,segment(1-i,i))\n        Ex3:distance2(0,1+i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_725distance2 = {"distance2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_725distance2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_724distance2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_725distance2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("distance2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "distance2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_724distance2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_724distance2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("distance2", 1);

  /* "giacpy/auto-methods.pxi":4536
 * 
 *         '''
 *         return GiacMethods['distance2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def distanceat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_distance2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4536, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4525
 *         return GiacMethods['distance'](self,*args)
 * 
 *      def distance2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.distance2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4538
 *         return GiacMethods['distance2'](self,*args)
 * 
 *      def distanceat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_727distanceat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_726distanceat, "From Giac's documentation:\n        Help for distanceat:\n        distanceat(GeoObj(A),GeoObj(B),(Pnt or Cplx))\n        distanceat(A,B,z0) displays at point(z0), with a legend, the distance between 2 geometrical objects\n        See also: 1/ distance 2/ distanceatraw \n        Ex1: A:=point(0);B:=point(1+i);distanceat(A,B,(1+i)/2)\n        Ex2: A:=point(0);s:=segment(1-i,i);distanceat(A,s,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_727distanceat = {"distanceat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_727distanceat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_726distanceat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_727distanceat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("distanceat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "distanceat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_726distanceat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_726distanceat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("distanceat", 1);

  /* "giacpy/auto-methods.pxi":4548
 * 
 *         '''
 *         return GiacMethods['distanceat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def distanceatraw(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_distanceat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4548, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4538
 *         return GiacMethods['distance2'](self,*args)
 * 
 *      def distanceat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.distanceat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4550
 *         return GiacMethods['distanceat'](self,*args)
 * 
 *      def distanceatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceatraw:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_729distanceatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_728distanceatraw, "From Giac's documentation:\n        Help for distanceatraw:\n        distanceatraw(GeoObj(A),GeoObj(B),(Pnt or Cplx(z0)))\n        distanceatraw(A,B,z0) displays at the point(z0), the distance between 2 geometrical objects.\n        See also: 1/ distance 2/ distanceat \n        Ex1: A:=point(0);B:=point(1+i);distanceatraw(A,B,(1+i)/2)\n        Ex2: A:=point(0);s:=segment(1-i,i);distanceatraw(A,s,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_729distanceatraw = {"distanceatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_729distanceatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_728distanceatraw};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_729distanceatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("distanceatraw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "distanceatraw", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_728distanceatraw(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_728distanceatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("distanceatraw", 1);

  /* "giacpy/auto-methods.pxi":4560
 * 
 *         '''
 *         return GiacMethods['distanceatraw'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def divergence(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_distanceatraw); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4560, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4550
 *         return GiacMethods['distanceat'](self,*args)
 * 
 *      def distanceatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceatraw:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.distanceatraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4562
 *         return GiacMethods['distanceatraw'](self,*args)
 * 
 *      def divergence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divergence:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_731divergence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_730divergence, "From Giac's documentation:\n        Help for divergence:\n        divergence(Lst(A,B,C),Lst(x,y,z))\n        divergence([A,B,C],[x,y,z])=dA/dx+dB/dy+dC/dz.\n        See also: 1/ derive 2/ curl \n        Ex1:divergence([x^2+y,x+z+y,z^3+x^2],[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_731divergence = {"divergence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_731divergence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_730divergence};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_731divergence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("divergence (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "divergence", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_730divergence(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_730divergence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("divergence", 1);

  /* "giacpy/auto-methods.pxi":4571
 * 
 *         '''
 *         return GiacMethods['divergence'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def divide(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_divergence); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4571, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4562
 *         return GiacMethods['distanceatraw'](self,*args)
 * 
 *      def divergence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divergence:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.divergence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4573
 *         return GiacMethods['divergence'](self,*args)
 * 
 *      def divide(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divide:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_733divide(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_732divide, "From Giac's documentation:\n        Help for divide:\n        divide((Vect or Poly),(Vect or Poly),[Var])\n        Euclidean quotient and remainder of 2 polynomials.\n        See also: 1/ rem 2/ quo 3/ iquorem \n        Ex1:divide([1,2,3,4],[-1,2])\n        Ex2:divide(x^3+2x^2+3x+4,-x+2)\n        Ex3:divide(t^3+2t^2+3t+4,-t+2,t)\n        Ex4:divide(t^4-1,(t+1)^2,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_733divide = {"divide", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_733divide, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_732divide};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_733divide(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("divide (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "divide", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_732divide(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_732divide(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("divide", 1);

  /* "giacpy/auto-methods.pxi":4585
 * 
 *         '''
 *         return GiacMethods['divide'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def divis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_divide); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4585, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4573
 *         return GiacMethods['divergence'](self,*args)
 * 
 *      def divide(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divide:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.divide", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4587
 *         return GiacMethods['divide'](self,*args)
 * 
 *      def divis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_735divis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_734divis, "From Giac's documentation:\n        Help for divis:\n        divis(Poly(P) or LstPoly)\n        Returns the list of divisors of a polynomial.\n        See also: 1/ idivis 2/ factors 3/ poly2symb \n        Ex1:divis(x^2-1)\n        Ex2:divis(x^4-1)\n        Ex3:divis(t^4-1)\n        Ex4:divis([x^4-1,x^2-1])\n        Ex5:divis([x^4-1,t^2-1])\n        Ex6:divis(poly2symb([1,0,0,0,-1],x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_735divis = {"divis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_735divis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_734divis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_735divis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("divis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "divis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_734divis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_734divis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("divis", 1);

  /* "giacpy/auto-methods.pxi":4601
 * 
 *         '''
 *         return GiacMethods['divis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def division_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_divis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4601, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4587
 *         return GiacMethods['divide'](self,*args)
 * 
 *      def divis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.divis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4603
 *         return GiacMethods['divis'](self,*args)
 * 
 *      def division_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for division_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_737division_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_736division_point, "From Giac's documentation:\n        Help for division_point:\n        division_point(Pnt or Cplx(a),Pnt or Cplx(b),Cplx(k))\n        Returns the point M such that (z-a)=k*(z-b) and z=affix of M (MA=k*MB).\n        See also: 1/ harmonic_conjugate 2/ is_conjugate \n        Ex1:division_point(i,2+i,3+i)\n        Ex2:division_point(i,2+i,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_737division_point = {"division_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_737division_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_736division_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_737division_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("division_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "division_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_736division_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_736division_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("division_point", 1);

  /* "giacpy/auto-methods.pxi":4613
 * 
 *         '''
 *         return GiacMethods['division_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def divisors(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_division_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4613, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4603
 *         return GiacMethods['divis'](self,*args)
 * 
 *      def division_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for division_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.division_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4615
 *         return GiacMethods['division_point'](self,*args)
 * 
 *      def divisors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divisors:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_739divisors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_738divisors, "From Giac's documentation:\n        Help for divisors:\n        divisors(Intg(a) or LstIntg)\n        Returns the list of divisors of an integer.\n        See also: 1/ divis 2/ ifactors \n        Ex1:divisors(36)\n        Ex2:divisors([36,49])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_739divisors = {"divisors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_739divisors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_738divisors};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_739divisors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("divisors (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "divisors", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_738divisors(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_738divisors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("divisors", 1);

  /* "giacpy/auto-methods.pxi":4625
 * 
 *         '''
 *         return GiacMethods['divisors'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def divmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_divisors); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4625, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4615
 *         return GiacMethods['division_point'](self,*args)
 * 
 *      def divisors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divisors:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.divisors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4627
 *         return GiacMethods['divisors'](self,*args)
 * 
 *      def divmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_741divmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_740divmod, "From Giac's documentation:\n        Help for divmod:\n        divmod(Intg(a),Intg(b))\n        Euclidean quotient and remainder of 2 integers.\n        See also: 1/ irem 2/ iquo 3/ quorem \n        Ex1:divmod(125,15)\n        Ex2:divmod(125,41)\n        Ex3:divmod(25+12*i,5+7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_741divmod = {"divmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_741divmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_740divmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_741divmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("divmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "divmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_740divmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_740divmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("divmod", 1);

  /* "giacpy/auto-methods.pxi":4638
 * 
 *         '''
 *         return GiacMethods['divmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def divpc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_divmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4638, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4627
 *         return GiacMethods['divisors'](self,*args)
 * 
 *      def divmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.divmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4640
 *         return GiacMethods['divmod'](self,*args)
 * 
 *      def divpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divpc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_743divpc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_742divpc, "From Giac's documentation:\n        Help for divpc:\n        divpc(Poly,Poly,Intg(n))\n        nth-degree Taylor-poly for the quotient of 2 polynomials.\n        See also: 1/ series 2/ quorem \n        Ex1:divpc(x^4+x+2,x^2+1,5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_743divpc = {"divpc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_743divpc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_742divpc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_743divpc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("divpc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "divpc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_742divpc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_742divpc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("divpc", 1);

  /* "giacpy/auto-methods.pxi":4649
 * 
 *         '''
 *         return GiacMethods['divpc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dnewton_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_divpc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4649, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4640
 *         return GiacMethods['divmod'](self,*args)
 * 
 *      def divpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divpc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.divpc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4651
 *         return GiacMethods['divpc'](self,*args)
 * 
 *      def dnewton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dnewton_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_745dnewton_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_744dnewton_solver, "From Giac's documentation:\n        Help for dnewton_solver:\n        dnewton_solver(Opt)\n        Argument for fsolve giving the method for solving a system of numerical equations.\n        See also: 1/ fsolve \n        Ex1: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],dnewton_solver)\n        Ex2: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrid_solver)\n        Ex3: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrids_solver)\n        Ex4: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridj_solver)\n        Ex5: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridsj_solver)\n        Ex6: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],newtonj_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_745dnewton_solver = {"dnewton_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_745dnewton_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_744dnewton_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_745dnewton_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dnewton_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dnewton_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_744dnewton_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_744dnewton_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dnewton_solver", 1);

  /* "giacpy/auto-methods.pxi":4665
 * 
 *         '''
 *         return GiacMethods['dnewton_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dodecahedron(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dnewton_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4665, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4651
 *         return GiacMethods['divpc'](self,*args)
 * 
 *      def dnewton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dnewton_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dnewton_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4667
 *         return GiacMethods['dnewton_solver'](self,*args)
 * 
 *      def dodecahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dodecahedron:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_747dodecahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_746dodecahedron, "From Giac's documentation:\n        Help for dodecahedron:\n        dodecahedron(Pnt(A),Pnt(B),Pnt(C))\n        Draws a dodecahedron with center A, vertex B and such that the plane ABC contains an axis of symmetry of the dodecahedron.\n        See also: 1/ icosahedron 2/ octahedron 3/ cube 4/ tetrahedron \n        Ex1:dodecahedron([0,0,0],[0,2,sqrt(5)/2+3/2],[0,0,1])\n        Ex2:dodecahedron(evalf([0,0,0],[3,2,4],[1,1,0]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_747dodecahedron = {"dodecahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_747dodecahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_746dodecahedron};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_747dodecahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dodecahedron (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dodecahedron", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_746dodecahedron(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_746dodecahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dodecahedron", 1);

  /* "giacpy/auto-methods.pxi":4677
 * 
 *         '''
 *         return GiacMethods['dodecahedron'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def domain(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dodecahedron); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4677, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4667
 *         return GiacMethods['dnewton_solver'](self,*args)
 * 
 *      def dodecahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dodecahedron:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dodecahedron", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4679
 *         return GiacMethods['dodecahedron'](self,*args)
 * 
 *      def domain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for domain:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_749domain(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_748domain, "From Giac's documentation:\n        Help for domain:\n        domain(Expr)\n        Returns the definition domain of an expression.\n        Ex1:domain(log(x+1))\n        Ex2:domain(log(x)+asin(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_749domain = {"domain", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_749domain, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_748domain};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_749domain(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("domain (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "domain", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_748domain(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_748domain(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("domain", 1);

  /* "giacpy/auto-methods.pxi":4688
 * 
 *         '''
 *         return GiacMethods['domain'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_domain); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4688, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4679
 *         return GiacMethods['dodecahedron'](self,*args)
 * 
 *      def domain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for domain:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.domain", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4690
 *         return GiacMethods['domain'](self,*args)
 * 
 *      def dot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_751dot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_750dot, "From Giac's documentation:\n        Help for dot:\n        dot(Vect(v1),Vect(v2))\n        Scalar product.\n        See also: 1/ * 2/ cross 3/ .* 4/ hadamard \n        Ex1:dot([1,2],[3,4])\n        Ex2:dot([3,2,4],[3,2,4])\n        Ex3:dot([[1,2],[3,4]],[[3,2],[4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_751dot = {"dot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_751dot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_750dot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_751dot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_750dot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_750dot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dot", 1);

  /* "giacpy/auto-methods.pxi":4701
 * 
 *         '''
 *         return GiacMethods['dot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dotP(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4701, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4690
 *         return GiacMethods['domain'](self,*args)
 * 
 *      def dot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4703
 *         return GiacMethods['dot'](self,*args)
 * 
 *      def dotP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotP:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_753dotP(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_752dotP, "From Giac's documentation:\n        Help for dotP:\n        dotP(Vect(v1),Vect(v2))\n        Scalar product.\n        See also: 1/ * 2/ cross 3/ .* 4/ hadamard \n        Ex1:dotP([1,2],[3,4])\n        Ex2:dotP([3,2,4],[3,2,4])\n        Ex3:dotP([[1,2],[3,4]],[[3,2],[4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_753dotP = {"dotP", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_753dotP, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_752dotP};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_753dotP(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dotP (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dotP", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_752dotP(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_752dotP(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dotP", 1);

  /* "giacpy/auto-methods.pxi":4714
 * 
 *         '''
 *         return GiacMethods['dotP'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dot_paper(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dotP); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4714, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4703
 *         return GiacMethods['dot'](self,*args)
 * 
 *      def dotP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotP:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dotP", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4716
 *         return GiacMethods['dotP'](self,*args)
 * 
 *      def dot_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot_paper:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_755dot_paper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_754dot_paper, "From Giac's documentation:\n        Help for dot_paper:\n        dot_paper(Real(ux),Real(uy),Real(t))\n        Draws in the rectangle [xmin..xmax]*[ymin..ymax], the vertices of the grid formed by the lines y=n*uy and the lines x=u*ux at an angle of t!=0 with the horizontal.\n        Ex1:dot_paper(1,pi/3,sqrt(3)/2)\n        Ex2:dot_paper(1,pi/3,sqrt(3)/2,x=-1..4,y=-2..2)\n        Ex3:dot_paper(0.5,3*pi/4,0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_755dot_paper = {"dot_paper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_755dot_paper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_754dot_paper};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_755dot_paper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dot_paper (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dot_paper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_754dot_paper(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_754dot_paper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dot_paper", 1);

  /* "giacpy/auto-methods.pxi":4726
 * 
 *         '''
 *         return GiacMethods['dot_paper'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dotprod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dot_paper); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4726, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4716
 *         return GiacMethods['dotP'](self,*args)
 * 
 *      def dot_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot_paper:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dot_paper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4728
 *         return GiacMethods['dot_paper'](self,*args)
 * 
 *      def dotprod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotprod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_757dotprod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_756dotprod, "From Giac's documentation:\n        Help for dotprod:\n        dotprod(Vect(v1),Vect(v2))\n        Scalar product.\n        See also: 1/ * 2/ cross 3/ .* 4/ hadamard \n        Ex1:dotprod([1,2],[3,4])\n        Ex2:dotprod([3,2,4],[3,2,4])\n        Ex3:dotprod([[1,2],[3,4]],[[3,2],[4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_757dotprod = {"dotprod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_757dotprod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_756dotprod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_757dotprod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dotprod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dotprod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_756dotprod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_756dotprod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dotprod", 1);

  /* "giacpy/auto-methods.pxi":4739
 * 
 *         '''
 *         return GiacMethods['dotprod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_arc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dotprod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4739, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4728
 *         return GiacMethods['dot_paper'](self,*args)
 * 
 *      def dotprod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotprod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dotprod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4741
 *         return GiacMethods['dotprod'](self,*args)
 * 
 *      def draw_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_arc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_759draw_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_758draw_arc, "From Giac's documentation:\n        Help for draw_arc:\n        draw_arc(Intg(x),Intg(y),Intg(rx),Intg(ry),Real(theta1),Real(theta2),Intg(col))\n        Pixelised ellipsis arc.\n        See also: 1/ draw_pixel 2/ draw_circle \n        Ex1: clear(); draw_arc(100,80,40,20,0,pi,blue); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_759draw_arc = {"draw_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_759draw_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_758draw_arc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_759draw_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_arc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_arc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_758draw_arc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_758draw_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_arc", 1);

  /* "giacpy/auto-methods.pxi":4750
 * 
 *         '''
 *         return GiacMethods['draw_arc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_circle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_arc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4750, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4741
 *         return GiacMethods['dotprod'](self,*args)
 * 
 *      def draw_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_arc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_arc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4752
 *         return GiacMethods['draw_arc'](self,*args)
 * 
 *      def draw_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_circle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_761draw_circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_760draw_circle, "From Giac's documentation:\n        Help for draw_circle:\n        draw_circle(Intg(x),Intg(y),Intg(r),Intg(col))\n        Pixelised circle, add filled to the color to fill the circle.\n        See also: 1/ draw_pixel 2/ draw_arc \n        Ex1: clear(); draw_circle(100,60,20,blue); show_pixels();\n        Ex2: clear(); draw_circle(100,60,20,blue+filled); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_761draw_circle = {"draw_circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_761draw_circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_760draw_circle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_761draw_circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_circle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_circle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_760draw_circle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_760draw_circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_circle", 1);

  /* "giacpy/auto-methods.pxi":4762
 * 
 *         '''
 *         return GiacMethods['draw_circle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_circle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4762, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4752
 *         return GiacMethods['draw_arc'](self,*args)
 * 
 *      def draw_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_circle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_circle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4764
 *         return GiacMethods['draw_circle'](self,*args)
 * 
 *      def draw_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_763draw_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_762draw_graph, "From Giac's documentation:\n        Help for draw_graph:\n        draw_graph(Graph(G),[opts])\n        Returns the graphic representation of G obtained by using various algorithms (which can optionally be fine tuned by appending a sequence of options after the first argument).\n        See also: 1/ highlight_edges 2/ highlight_subgraph 3/ highlight_trail 4/ highlight_vertex 5/ set_vertex_positions 6/ get_vertex_positions \n        Ex1:draw_graph(graph(\"petersen\"))\n        Ex2:draw_graph(graph(\"petersen\"),spring)\n        Ex3:draw_graph(random_tree(30))\n        Ex4:draw_graph(sierpinski_graph(5,3,at_triangle))\n        Ex5:draw_graph(graph(\"soccerball\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_763draw_graph = {"draw_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_763draw_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_762draw_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_763draw_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_762draw_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_762draw_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_graph", 1);

  /* "giacpy/auto-methods.pxi":4777
 * 
 *         '''
 *         return GiacMethods['draw_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4777, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4764
 *         return GiacMethods['draw_circle'](self,*args)
 * 
 *      def draw_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4779
 *         return GiacMethods['draw_graph'](self,*args)
 * 
 *      def draw_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_765draw_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_764draw_line, "From Giac's documentation:\n        Help for draw_line:\n        draw_line(Intg(x1),Intg(y1),Intg(x2),Intg(y2),Intg(col))\n        Pixelised segment.\n        See also: 1/ draw_pixel 2/ draw_rectangle 3/ draw_polygon \n        Ex1: clear(); draw_line(10,10,60,60,blue); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_765draw_line = {"draw_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_765draw_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_764draw_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_765draw_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_764draw_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_764draw_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_line", 1);

  /* "giacpy/auto-methods.pxi":4788
 * 
 *         '''
 *         return GiacMethods['draw_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_pixel(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4788, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4779
 *         return GiacMethods['draw_graph'](self,*args)
 * 
 *      def draw_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4790
 *         return GiacMethods['draw_line'](self,*args)
 * 
 *      def draw_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_pixel:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_767draw_pixel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_766draw_pixel, "From Giac's documentation:\n        Help for draw_pixel:\n        draw_pixel(Intg(x),Intg(y),Intg(col))\n        Pixel on and adds to the list of pixels. Run set_pixel() or show_pixels() to display, set_pixel(n) to zoom.\n        See also: 1/ clear 2/ show_pixels 3/ draw_line 4/ draw_rectangle 5/ draw_polygon \n        Ex1: clear(); set_pixel(4); draw_pixel(1,2,red); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_767draw_pixel = {"draw_pixel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_767draw_pixel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_766draw_pixel};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_767draw_pixel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_pixel (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_pixel", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_766draw_pixel(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_766draw_pixel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_pixel", 1);

  /* "giacpy/auto-methods.pxi":4799
 * 
 *         '''
 *         return GiacMethods['draw_pixel'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_polygon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_pixel); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4799, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4790
 *         return GiacMethods['draw_line'](self,*args)
 * 
 *      def draw_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_pixel:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_pixel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4801
 *         return GiacMethods['draw_pixel'](self,*args)
 * 
 *      def draw_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_polygon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_769draw_polygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_768draw_polygon, "From Giac's documentation:\n        Help for draw_polygon:\n        draw_polygon(Lst(l),Intg(col))\n        Pixelised polygon, add filled to the color to fill the rectangle.\n        See also: 1/ draw_pixel 2/ draw_line 3/ draw_rectangle \n        Ex1: clear(); draw_polygon([[50,30],[100,10],[20,70]],red); show_pixels();\n        Ex2: clear(); draw_polygon([[50,30],[100,10],[20,70]],red+filled); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_769draw_polygon = {"draw_polygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_769draw_polygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_768draw_polygon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_769draw_polygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_polygon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_polygon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_768draw_polygon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_768draw_polygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_polygon", 1);

  /* "giacpy/auto-methods.pxi":4811
 * 
 *         '''
 *         return GiacMethods['draw_polygon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def draw_rectangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_polygon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4811, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4801
 *         return GiacMethods['draw_pixel'](self,*args)
 * 
 *      def draw_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_polygon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_polygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4813
 *         return GiacMethods['draw_polygon'](self,*args)
 * 
 *      def draw_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_rectangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_771draw_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_770draw_rectangle, "From Giac's documentation:\n        Help for draw_rectangle:\n        draw_rectangle(Intg(x),Intg(y),Intg(w),Intg(h),Intg(col))\n        Pixelised rectangle, add filled to the color to fill the rectangle.\n        See also: 1/ draw_pixel 2/ draw_line 3/ draw_polygon \n        Ex1: clear(); draw_rectangle(10,20,30,40,red); show_pixels();\n        Ex2: clear(); draw_rectangle(10,20,30,40,red+filled); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_771draw_rectangle = {"draw_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_771draw_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_770draw_rectangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_771draw_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("draw_rectangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "draw_rectangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_770draw_rectangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_770draw_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("draw_rectangle", 1);

  /* "giacpy/auto-methods.pxi":4823
 * 
 *         '''
 *         return GiacMethods['draw_rectangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def droit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_draw_rectangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4823, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4813
 *         return GiacMethods['draw_polygon'](self,*args)
 * 
 *      def draw_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_rectangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.draw_rectangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4825
 *         return GiacMethods['draw_rectangle'](self,*args)
 * 
 *      def droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_773droit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_772droit, "From Giac's documentation:\n        Help for droit:\n        droit(Equal(a=b) or Interval(a..b) or Str,Intg)\n        Returns the right part of an equality, of an interval, of a list or of a string.\n        See also: 1/ left 2/ mid 3/ tail 4/ head \n        Ex1:droit(a=b)\n        Ex2:droit(x^2+1=5)\n        Ex3:droit(1..5)\n        Ex4:droit(\"abcdefg\",3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_773droit = {"droit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_773droit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_772droit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_773droit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("droit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "droit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_772droit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_772droit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("droit", 1);

  /* "giacpy/auto-methods.pxi":4837
 * 
 *         '''
 *         return GiacMethods['droit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def droite_tangente(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_droit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4837, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4825
 *         return GiacMethods['draw_rectangle'](self,*args)
 * 
 *      def droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.droit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4839
 *         return GiacMethods['droit'](self,*args)
 * 
 *      def droite_tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droite_tangente:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_775droite_tangente(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_774droite_tangente, "From Giac's documentation:\n        Help for droite_tangente:\n        droite_tangente(Expr(f(x)),[Var],Expr(a))\n        Draws the tangent to y=f(x) at x=a.\n        See also: 1/ tangent 2/ LineTan \n        Ex1:droite_tangente(sin(x),pi/4)\n        Ex2:droite_tangente(sin(t),t=pi/4)\n        Ex3:droite_tangente(sin(t),t,pi/4)\n        Ex4:droite_tangente(x^2-x,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_775droite_tangente = {"droite_tangente", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_775droite_tangente, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_774droite_tangente};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_775droite_tangente(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("droite_tangente (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "droite_tangente", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_774droite_tangente(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_774droite_tangente(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("droite_tangente", 1);

  /* "giacpy/auto-methods.pxi":4851
 * 
 *         '''
 *         return GiacMethods['droite_tangente'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_droite_tangente); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4851, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4839
 *         return GiacMethods['droit'](self,*args)
 * 
 *      def droite_tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droite_tangente:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.droite_tangente", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4853
 *         return GiacMethods['droite_tangente'](self,*args)
 * 
 *      def dsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_777dsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_776dsolve, "From Giac's documentation:\n        Help for dsolve:\n        dsolve(Eq,[TimeVar],FncVar)\n        Solves a differential equation or a differential linear system with constant coefficients.\n        See also: 1/ integrate 2/ diff 3/ odesolve 4/ plotode 5/ plotfiefd \n        Ex1:dsolve(y'+x*y=0)\n        Ex2:dsolve(y'+x*y=0,y)\n        Ex3:dsolve(y'+x*y=0,[0,1])\n        Ex4:dsolve([y'+x*y=0,y(0)=1],y)\n        Ex5:dsolve([y'=[[1,2],[2,1]]*y+[x,x+1],y(0)=[1,2]]) \n        Ex6:dsolve(y''+y=0,y)\n        Ex7:dsolve([y''+y=sin(x),y(0)=1,y'(0)=2],y)\n        Ex8:dsolve([y''+y=sin(x),y(0)=1,y'(0)=2],x,y)\n        Ex9:dsolve([y''+y=sin(x),y(0)=1,y'(0)=2],[x,y])\n        Ex10:dsolve(diff(y(t),t)+t*y(t)=0,t,y)\n        Ex11:dsolve(diff(y(t),t)+t*y(t)=0,[t,y])\n        Ex12:dsolve((y''+y=sin(x)) and (y(0)=1) and (y'(0)=2),y)\n        Ex13:dsolve([z''+2*z'+z,z(0)=1,z'(0)=0],u,z)\n        Ex14:dsolve([z''+2*z'+z,z(0)=1,z'(0)=0],z(u))\n        Ex15:dsolve([z'=[[1,2],[2,1]]*z+[t,t+1],z(0)=[1,2]],t,z)\n        Ex16:dsolve([z'=[[1,2],[2,1]]*z+[t,t+1],z(0)=[1,2]],z(t))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_777dsolve = {"dsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_777dsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_776dsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_777dsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_776dsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_776dsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dsolve", 1);

  /* "giacpy/auto-methods.pxi":4877
 * 
 *         '''
 *         return GiacMethods['dsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def duration(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4877, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4853
 *         return GiacMethods['droite_tangente'](self,*args)
 * 
 *      def dsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4879
 *         return GiacMethods['dsolve'](self,*args)
 * 
 *      def duration(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for duration:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_779duration(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_778duration, "From Giac's documentation:\n        Help for duration:\n        duration(Audio(clip))\n        Returns the duration of an audio clip, in seconds.\n        See also: 1/ bit_depth 2/ channels 3/ channel_data 4/ samplerate \n        Ex1:duration(readwav(\"/some/file\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_779duration = {"duration", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_779duration, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_778duration};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_779duration(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("duration (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "duration", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_778duration(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_778duration(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duration", 1);

  /* "giacpy/auto-methods.pxi":4888
 * 
 *         '''
 *         return GiacMethods['duration'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def dwt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_duration); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4888, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4879
 *         return GiacMethods['dsolve'](self,*args)
 * 
 *      def duration(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for duration:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.duration", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4890
 *         return GiacMethods['duration'](self,*args)
 * 
 *      def dwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dwt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_781dwt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_780dwt, "From Giac's documentation:\n        Help for dwt:\n        dwt((Lst||Mtrx)(data),[opts])\n        Returns the discrete wavelet transform of data (either 1D or 2D), optionally with a sequence of options.\n        See also: 1/ idwt 2/ fft 3/ ifft \n        Ex1:dwt([0.0,0.5,0.25,1.0,0.75,-0.25,-0.5,0.0])\n        Ex2:dwt([[15,25,5,70],[21,33,12,7],[64,18,50,10],[5,17,35,28]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_781dwt = {"dwt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_781dwt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_780dwt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_781dwt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dwt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dwt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_780dwt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_780dwt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dwt", 1);

  /* "giacpy/auto-methods.pxi":4900
 * 
 *         '''
 *         return GiacMethods['dwt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def e(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_dwt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4900, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4890
 *         return GiacMethods['duration'](self,*args)
 * 
 *      def dwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dwt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.dwt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4902
 *         return GiacMethods['dwt'](self,*args)
 * 
 *      def e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_783e(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_782e, "From Giac's documentation:\n        Help for e:\n        e()\n        exp(1).\n        See also: 1/ i 2/ pi \n        Ex1: evalf(e)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_783e = {"e", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_783e, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_782e};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_783e(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("e (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "e", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_782e(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_782e(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("e", 1);

  /* "giacpy/auto-methods.pxi":4911
 * 
 *         '''
 *         return GiacMethods['e'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def e2r(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4911, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4902
 *         return GiacMethods['dwt'](self,*args)
 * 
 *      def e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.e", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4913
 *         return GiacMethods['e'](self,*args)
 * 
 *      def e2r(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e2r:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_785e2r(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_784e2r, "From Giac's documentation:\n        Help for e2r:\n        e2r(Expr, LstVar or [Var])\n        Returns the coefficients of a polynomial with respect to the 2nd argument or if the second argument is a list the internal format of the polynomial.\n        See also: 1/ poly2symb 2/ r2e \n        Ex1:e2r(x*3+2.1)\n        Ex2:e2r(3*x*y+2*y+1,y)\n        Ex3:e2r(3*x*y+2*y+1,x,y)\n        Ex4:e2r(3*x*y+2*y+1,[x,y])\n        Ex5:e2r(-x^4+x*3*y+2+y^2*z,[x,y,z])\n        Ex6:e2r(-x^4+x*3*y+2+y^2*z,[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_785e2r = {"e2r", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_785e2r, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_784e2r};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_785e2r(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("e2r (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "e2r", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_784e2r(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_784e2r(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("e2r", 1);

  /* "giacpy/auto-methods.pxi":4927
 * 
 *         '''
 *         return GiacMethods['e2r'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ecart_type(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_e2r); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4927, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4913
 *         return GiacMethods['e'](self,*args)
 * 
 *      def e2r(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e2r:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.e2r", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4929
 *         return GiacMethods['e2r'](self,*args)
 * 
 *      def ecart_type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_787ecart_type(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_786ecart_type, "From Giac's documentation:\n        Help for ecart_type:\n        ecart_type(Lst||Mtrx,[Lst])\n        Returns the standard deviation of the elements of its argument with an optional second argument as weight or the list of standard deviations of the columns of a matrix.\n        See also: 1/ mean 2/ variance 3/ stddevp \n        Ex1:ecart_type([1,2,3])\n        Ex2:ecart_type([1,2,3],[1,2,1])\n        Ex3:ecart_type([[1,2,3],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_787ecart_type = {"ecart_type", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_787ecart_type, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_786ecart_type};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_787ecart_type(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ecart_type (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ecart_type", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_786ecart_type(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_786ecart_type(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ecart_type", 1);

  /* "giacpy/auto-methods.pxi":4940
 * 
 *         '''
 *         return GiacMethods['ecart_type'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ecart_type_population(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ecart_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4940, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4929
 *         return GiacMethods['e2r'](self,*args)
 * 
 *      def ecart_type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ecart_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4942
 *         return GiacMethods['ecart_type'](self,*args)
 * 
 *      def ecart_type_population(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type_population:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_789ecart_type_population(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_788ecart_type_population, "From Giac's documentation:\n        Help for ecart_type_population:\n        ecart_type_population(Lst||Mtrx,[Lst])\n        Returns an unbiased estimate of the population standard deviation of the sample (first argument) with an optional list of weight as second argument.\n        See also: 1/ mean 2/ stddev \n        Ex1:ecart_type_population([1,2,3])\n        Ex2:ecart_type_population([1,2,3],[1,2,1])\n        Ex3:ecart_type_population([[1,2,3],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_789ecart_type_population = {"ecart_type_population", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_789ecart_type_population, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_788ecart_type_population};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_789ecart_type_population(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ecart_type_population (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ecart_type_population", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_788ecart_type_population(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_788ecart_type_population(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ecart_type_population", 1);

  /* "giacpy/auto-methods.pxi":4953
 * 
 *         '''
 *         return GiacMethods['ecart_type_population'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ecef2geodetic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ecart_type_population); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4953, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4942
 *         return GiacMethods['ecart_type'](self,*args)
 * 
 *      def ecart_type_population(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type_population:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ecart_type_population", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4955
 *         return GiacMethods['ecart_type_population'](self,*args)
 * 
 *      def ecef2geodetic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecef2geodetic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_791ecef2geodetic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_790ecef2geodetic, "From Giac's documentation:\n        Help for ecef2geodetic:\n        ecef2geodetic(Real(x),Real(y),Real(z))\n        Converts ECEF coordinates to geodetic LLA (WGS84 standard).\n        See also: 1/ geodetic2ecef \n        Ex1:ecef2geodetic(4293457.10728,1360697.85689,4501106.55299)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_791ecef2geodetic = {"ecef2geodetic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_791ecef2geodetic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_790ecef2geodetic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_791ecef2geodetic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ecef2geodetic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ecef2geodetic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_790ecef2geodetic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_790ecef2geodetic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ecef2geodetic", 1);

  /* "giacpy/auto-methods.pxi":4964
 * 
 *         '''
 *         return GiacMethods['ecef2geodetic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ecm_factor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ecef2geodetic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4964, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4955
 *         return GiacMethods['ecart_type_population'](self,*args)
 * 
 *      def ecef2geodetic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecef2geodetic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ecef2geodetic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4966
 *         return GiacMethods['ecef2geodetic'](self,*args)
 * 
 *      def ecm_factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecm_factor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_793ecm_factor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_792ecm_factor, "From Giac's documentation:\n        Help for ecm_factor:\n        ecm_factor(Intg(a),[Intg(B1)])\n        Factorization of integer n by the Elliptic Curve Method algorithm, B1 smoothness optional parameter.\n        Ex1:ecm_factor(1000000000000000003000000000000000000000000000000000031000000000000000093)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_793ecm_factor = {"ecm_factor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_793ecm_factor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_792ecm_factor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_793ecm_factor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ecm_factor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ecm_factor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_792ecm_factor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_792ecm_factor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ecm_factor", 1);

  /* "giacpy/auto-methods.pxi":4974
 * 
 *         '''
 *         return GiacMethods['ecm_factor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def edge_connectivity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ecm_factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4974, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4966
 *         return GiacMethods['ecef2geodetic'](self,*args)
 * 
 *      def ecm_factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecm_factor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ecm_factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4976
 *         return GiacMethods['ecm_factor'](self,*args)
 * 
 *      def edge_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edge_connectivity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_795edge_connectivity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_794edge_connectivity, "From Giac's documentation:\n        Help for edge_connectivity:\n        edge_connectivity(graph(G))\n        Returns the largest integer k such that an undirected connected graph G remains connected after fewer than k edges are removed.\n        See also: 1/ is_two_edge_connected 2/ is_edge_cut 3/ vertex_connectivity \n        Ex1:edge_connectivity(graph(\"petersen\"))\n        Ex2:edge_connectivity(graph(\"clebsch\"))\n        Ex3:edge_connectivity(complete_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_795edge_connectivity = {"edge_connectivity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_795edge_connectivity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_794edge_connectivity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_795edge_connectivity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("edge_connectivity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "edge_connectivity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_794edge_connectivity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_794edge_connectivity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("edge_connectivity", 1);

  /* "giacpy/auto-methods.pxi":4987
 * 
 *         '''
 *         return GiacMethods['edge_connectivity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def edges(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_edge_connectivity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4987, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4976
 *         return GiacMethods['ecm_factor'](self,*args)
 * 
 *      def edge_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edge_connectivity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.edge_connectivity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":4989
 *         return GiacMethods['edge_connectivity'](self,*args)
 * 
 *      def edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edges:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_797edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_796edges, "From Giac's documentation:\n        Help for edges:\n        edges(Graph(G),[weights])\n        Return the list of edges in G [including weights].\n        See also: 1/ add_edge 2/ incident_edges 3/ set_edge_weight 4/ get_edge_weight \n        Ex1:edges(complete_graph(4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_797edges = {"edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_797edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_796edges};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_797edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("edges (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "edges", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_796edges(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_796edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("edges", 1);

  /* "giacpy/auto-methods.pxi":4998
 * 
 *         '''
 *         return GiacMethods['edges'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def egcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_edges); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 4998, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":4989
 *         return GiacMethods['edge_connectivity'](self,*args)
 * 
 *      def edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edges:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.edges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5000
 *         return GiacMethods['edges'](self,*args)
 * 
 *      def egcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_799egcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_798egcd, "From Giac's documentation:\n        Help for egcd:\n        egcd((Poly or Lst),(Poly or Lst),[Var])\n        Extended greatest common divisor of 2 polynomials.\n        See also: 1/ gcd 2/ iegcd \n        Ex1:egcd((x-1)^2,x^3-1)\n        Ex2:egcd((X-1)^2,X^3-1,X)\n        Ex3:egcd([1,-2,1],[1,0,0,-1])\n        Ex4:egcd([1,-2,1],[1,-1,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_799egcd = {"egcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_799egcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_798egcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_799egcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("egcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "egcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_798egcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_798egcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("egcd", 1);

  /* "giacpy/auto-methods.pxi":5012
 * 
 *         '''
 *         return GiacMethods['egcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def egv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_egcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5012, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5000
 *         return GiacMethods['edges'](self,*args)
 * 
 *      def egcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.egcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5014
 *         return GiacMethods['egcd'](self,*args)
 * 
 *      def egv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_801egv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_800egv, "From Giac's documentation:\n        Help for egv:\n        egv(Mtrx)\n        Computes the eigenvectors of a diagonalizable matrix.\n        See also: 1/ egvl 2/ jordan \n        Ex1:egv([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex2:egv([[1,1,3],[1,3,1],[3,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_801egv = {"egv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_801egv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_800egv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_801egv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("egv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "egv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_800egv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_800egv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("egv", 1);

  /* "giacpy/auto-methods.pxi":5024
 * 
 *         '''
 *         return GiacMethods['egv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def egvl(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_egv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5024, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5014
 *         return GiacMethods['egcd'](self,*args)
 * 
 *      def egv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.egv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5026
 *         return GiacMethods['egv'](self,*args)
 * 
 *      def egvl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egvl:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_803egvl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_802egvl, "From Giac's documentation:\n        Help for egvl:\n        egvl(Mtrx(A))\n        Returns the Jordan matrix associated to A when the eigenvalues are calculable.\n        See also: 1/ egv 2/ jordan \n        Ex1:egvl([[4,1],[-4,0]])\n        Ex2:egvl([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex3:egvl([[1,1,3],[1,3,1],[3,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_803egvl = {"egvl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_803egvl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_802egvl};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_803egvl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("egvl (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "egvl", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_802egvl(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_802egvl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("egvl", 1);

  /* "giacpy/auto-methods.pxi":5037
 * 
 *         '''
 *         return GiacMethods['egvl'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eigVc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_egvl); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5037, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5026
 *         return GiacMethods['egv'](self,*args)
 * 
 *      def egvl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egvl:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.egvl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5039
 *         return GiacMethods['egvl'](self,*args)
 * 
 *      def eigVc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_805eigVc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_804eigVc, "From Giac's documentation:\n        Help for eigVc:\n        eigVc(Mtrx)\n        Computes the eigenvectors of a diagonalizable matrix.\n        See also: 1/ egvl 2/ jordan \n        Ex1:eigVc([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex2:eigVc([[1,1,3],[1,3,1],[3,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_805eigVc = {"eigVc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_805eigVc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_804eigVc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_805eigVc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eigVc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eigVc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_804eigVc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_804eigVc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eigVc", 1);

  /* "giacpy/auto-methods.pxi":5049
 * 
 *         '''
 *         return GiacMethods['eigVc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eigVl(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eigVc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5049, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5039
 *         return GiacMethods['egvl'](self,*args)
 * 
 *      def eigVc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eigVc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5051
 *         return GiacMethods['eigVc'](self,*args)
 * 
 *      def eigVl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVl:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_807eigVl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_806eigVl, "From Giac's documentation:\n        Help for eigVl:\n        eigVl(Mtrx(A))\n        Returns the Jordan matrix associated to A when the eigenvalues are calculable.\n        See also: 1/ egv 2/ jordan \n        Ex1:eigVl([[4,1],[-4,0]])\n        Ex2:eigVl([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex3:eigVl([[1,1,3],[1,3,1],[3,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_807eigVl = {"eigVl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_807eigVl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_806eigVl};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_807eigVl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eigVl (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eigVl", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_806eigVl(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_806eigVl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eigVl", 1);

  /* "giacpy/auto-methods.pxi":5062
 * 
 *         '''
 *         return GiacMethods['eigVl'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eigenvals(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eigVl); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5062, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5051
 *         return GiacMethods['eigVc'](self,*args)
 * 
 *      def eigVl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVl:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eigVl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5064
 *         return GiacMethods['eigVl'](self,*args)
 * 
 *      def eigenvals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvals:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_809eigenvals(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_808eigenvals, "From Giac's documentation:\n        Help for eigenvals:\n        eigenvals(Mtrx)\n        Returns the sequence of the (calculable) eigenvalues of a matrix.\n        See also: 1/ egv 2/ jordan \n        Ex1:eigenvals([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex2:eigenvals([[1,1,3],[1,3,1],[3,1,1]])\n        Ex3:eigenvals([[4,1],[-4,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_809eigenvals = {"eigenvals", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_809eigenvals, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_808eigenvals};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_809eigenvals(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eigenvals (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eigenvals", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_808eigenvals(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_808eigenvals(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eigenvals", 1);

  /* "giacpy/auto-methods.pxi":5075
 * 
 *         '''
 *         return GiacMethods['eigenvals'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eigenvalues(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eigenvals); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5075, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5064
 *         return GiacMethods['eigVl'](self,*args)
 * 
 *      def eigenvals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvals:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eigenvals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5077
 *         return GiacMethods['eigenvals'](self,*args)
 * 
 *      def eigenvalues(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvalues:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_811eigenvalues(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_810eigenvalues, "From Giac's documentation:\n        Help for eigenvalues:\n        eigenvalues(Mtrx)\n        Returns the sequence of the (calculable) eigenvalues of a matrix.\n        See also: 1/ egv 2/ jordan \n        Ex1:eigenvalues([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex2:eigenvalues([[1,1,3],[1,3,1],[3,1,1]])\n        Ex3:eigenvalues([[4,1],[-4,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_811eigenvalues = {"eigenvalues", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_811eigenvalues, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_810eigenvalues};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_811eigenvalues(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eigenvalues (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eigenvalues", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_810eigenvalues(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_810eigenvalues(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eigenvalues", 1);

  /* "giacpy/auto-methods.pxi":5088
 * 
 *         '''
 *         return GiacMethods['eigenvalues'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eigenvectors(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eigenvalues); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5088, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5077
 *         return GiacMethods['eigenvals'](self,*args)
 * 
 *      def eigenvalues(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvalues:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eigenvalues", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5090
 *         return GiacMethods['eigenvalues'](self,*args)
 * 
 *      def eigenvectors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvectors:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_813eigenvectors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_812eigenvectors, "From Giac's documentation:\n        Help for eigenvectors:\n        eigenvectors(Mtrx)\n        Computes the eigenvectors of a diagonalizable matrix.\n        See also: 1/ egvl 2/ jordan \n        Ex1:eigenvectors([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex2:eigenvectors([[1,1,3],[1,3,1],[3,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_813eigenvectors = {"eigenvectors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_813eigenvectors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_812eigenvectors};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_813eigenvectors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eigenvectors (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eigenvectors", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_812eigenvectors(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_812eigenvectors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eigenvectors", 1);

  /* "giacpy/auto-methods.pxi":5100
 * 
 *         '''
 *         return GiacMethods['eigenvectors'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eigenvects(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eigenvectors); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5100, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5090
 *         return GiacMethods['eigenvalues'](self,*args)
 * 
 *      def eigenvectors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvectors:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eigenvectors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5102
 *         return GiacMethods['eigenvectors'](self,*args)
 * 
 *      def eigenvects(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvects:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_815eigenvects(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_814eigenvects, "From Giac's documentation:\n        Help for eigenvects:\n        eigenvects(Mtrx)\n        Computes the eigenvectors of a diagonalizable matrix.\n        See also: 1/ egvl 2/ jordan \n        Ex1:eigenvects([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex2:eigenvects([[1,1,3],[1,3,1],[3,1,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_815eigenvects = {"eigenvects", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_815eigenvects, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_814eigenvects};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_815eigenvects(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eigenvects (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eigenvects", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_814eigenvects(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_814eigenvects(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eigenvects", 1);

  /* "giacpy/auto-methods.pxi":5112
 * 
 *         '''
 *         return GiacMethods['eigenvects'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def element(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eigenvects); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5112, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5102
 *         return GiacMethods['eigenvectors'](self,*args)
 * 
 *      def eigenvects(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvects:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eigenvects", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5114
 *         return GiacMethods['eigenvects'](self,*args)
 * 
 *      def element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for element:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_817element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_816element, "From Giac's documentation:\n        Help for element:\n        element((Curve or Real_interval),[Val])\n        Shows a point chosen on a curve or a real chosen in an interval\n        See also: 1/ is_element \n        Ex1: t:=element(0..1)\n        Ex2: t:=element(0..1,0.3)\n        Ex3: t:=element(0..1,0.3,0.02)\n        Ex4: P:=element(circle(i,1),t)\n        Ex5: M:=element(circle(i,1))\n        Ex6: N:=element(circle(i,1),pi/2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_817element = {"element", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_817element, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_816element};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_817element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("element (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "element", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_816element(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_816element(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("element", 1);

  /* "giacpy/auto-methods.pxi":5128
 * 
 *         '''
 *         return GiacMethods['element'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eliminate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_element); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5128, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5114
 *         return GiacMethods['eigenvects'](self,*args)
 * 
 *      def element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for element:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5130
 *         return GiacMethods['element'](self,*args)
 * 
 *      def eliminate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eliminate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_819eliminate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_818eliminate, "From Giac's documentation:\n        Help for eliminate:\n        eliminate(LstEq(eqs),LstVar(vars))\n        Eliminates the variables vars in a list of algebraic equations.\n        Ex1:eliminate([x=v0*t,y=y0-g*t^2],t)\n        Ex2:eliminate([x+y+z+t-2,x*y*t=1,x^2+t^2=z^2],[x,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_819eliminate = {"eliminate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_819eliminate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_818eliminate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_819eliminate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eliminate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eliminate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_818eliminate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_818eliminate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eliminate", 1);

  /* "giacpy/auto-methods.pxi":5139
 * 
 *         '''
 *         return GiacMethods['eliminate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ellipse(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eliminate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5139, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5130
 *         return GiacMethods['element'](self,*args)
 * 
 *      def eliminate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eliminate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eliminate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5141
 *         return GiacMethods['eliminate'](self,*args)
 * 
 *      def ellipse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ellipse:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_821ellipse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_820ellipse, "From Giac's documentation:\n        Help for ellipse:\n        ellipse(Pnt(F1),Pnt(F2),(Pnt(M) or Real(a)))\n        ellipse(F1,F2,M)=ellipse with foci F1,F2 through M or such that MF1+MF2=2*a (geo2d) and ellipse(p(x,y)) draws the conic if deg(p)=2.\n        See also: 1/ hyperbola 2/ parabola \n        Ex1:ellipse(-1,1,point(1+i))\n        Ex2:ellipse(-1,1,1+sqrt(5))\n        Ex3:ellipse(2x^2+3y^2-x*y-10)\n        Ex4:ellipse(point(-1,0,0),point(1,0,0),point(1,1,1))\n        Ex5:ellipse(x^2+2y^2-y-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_821ellipse = {"ellipse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_821ellipse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_820ellipse};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_821ellipse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ellipse (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ellipse", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_820ellipse(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_820ellipse(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ellipse", 1);

  /* "giacpy/auto-methods.pxi":5154
 * 
 *         '''
 *         return GiacMethods['ellipse'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def emd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ellipse); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5141
 *         return GiacMethods['eliminate'](self,*args)
 * 
 *      def ellipse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ellipse:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ellipse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5156
 *         return GiacMethods['ellipse'](self,*args)
 * 
 *      def emd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for emd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_823emd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_822emd, "From Giac's documentation:\n        Help for emd:\n        emd(Lst(data),[opts])\n        Empirical mode decomposition of a discrete real signal.\n        See also: 1/ imfplot 2/ hht \n        Ex1:emd(apply(x->cos(10*x^2*pi),linspace(-pi,pi)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_823emd = {"emd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_823emd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_822emd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_823emd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("emd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "emd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_822emd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_822emd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("emd", 1);

  /* "giacpy/auto-methods.pxi":5165
 * 
 *         '''
 *         return GiacMethods['emd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def entry(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_emd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5165, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5156
 *         return GiacMethods['ellipse'](self,*args)
 * 
 *      def emd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for emd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.emd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5167
 *         return GiacMethods['emd'](self,*args)
 * 
 *      def entry(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for entry:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_825entry(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_824entry, "From Giac's documentation:\n        Help for entry:\n        entry(Intg(n))\n        Returns the (n+1)th question of the command history if n>=0 or, the (-n)th previous question if n<0 (by default n=-1 for the previous question).\n        See also: 1/ ans \n        Ex1:entry()\n        Ex2:entry(2)\n        Ex3:entry(-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_825entry = {"entry", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_825entry, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_824entry};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_825entry(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("entry (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "entry", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_824entry(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_824entry(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("entry", 1);

  /* "giacpy/auto-methods.pxi":5178
 * 
 *         '''
 *         return GiacMethods['entry'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def envelope(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_entry); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5178, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5167
 *         return GiacMethods['emd'](self,*args)
 * 
 *      def entry(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for entry:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.entry", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5180
 *         return GiacMethods['entry'](self,*args)
 * 
 *      def envelope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for envelope:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_827envelope(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_826envelope, "From Giac's documentation:\n        Help for envelope:\n        envelope(Expr(Xpr),Var(t)||[x,y,t])\n        Returns the envelope of the curves with equation Xpr=0 as t varies.\n        See also: 1/ tangent 2/ locus \n        Ex1:envelope(y+x*tan(t)-2*sin(t),t)\n        Ex2:envelope(v+u*tan(t)-3*sin(t),[u,v,t])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_827envelope = {"envelope", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_827envelope, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_826envelope};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_827envelope(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("envelope (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "envelope", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_826envelope(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_826envelope(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("envelope", 1);

  /* "giacpy/auto-methods.pxi":5190
 * 
 *         '''
 *         return GiacMethods['envelope'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def epsilon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_envelope); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5190, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5180
 *         return GiacMethods['entry'](self,*args)
 * 
 *      def envelope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for envelope:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.envelope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5192
 *         return GiacMethods['envelope'](self,*args)
 * 
 *      def epsilon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_829epsilon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_828epsilon, "From Giac's documentation:\n        Help for epsilon:\n        epsilon(NULL)\n        Returns the value of epsilon of the CAS configuration.\n        See also: 1/  epsilon2zero \n        Ex1:epsilon()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_829epsilon = {"epsilon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_829epsilon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_828epsilon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_829epsilon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("epsilon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "epsilon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_828epsilon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_828epsilon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("epsilon", 1);

  /* "giacpy/auto-methods.pxi":5201
 * 
 *         '''
 *         return GiacMethods['epsilon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def epsilon2zero(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_epsilon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5201, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5192
 *         return GiacMethods['envelope'](self,*args)
 * 
 *      def epsilon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.epsilon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5203
 *         return GiacMethods['epsilon'](self,*args)
 * 
 *      def epsilon2zero(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon2zero:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_831epsilon2zero(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_830epsilon2zero, "From Giac's documentation:\n        Help for epsilon2zero:\n        epsilon2zero(Expr)\n        Values < epsilon are replaced by zero.\n        See also: 1/ evalf \n        Ex1:epsilon2zero(1e-13+x+5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_831epsilon2zero = {"epsilon2zero", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_831epsilon2zero, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_830epsilon2zero};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_831epsilon2zero(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("epsilon2zero (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "epsilon2zero", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_830epsilon2zero(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_830epsilon2zero(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("epsilon2zero", 1);

  /* "giacpy/auto-methods.pxi":5212
 * 
 *         '''
 *         return GiacMethods['epsilon2zero'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def equal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_epsilon2zero); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5212, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5203
 *         return GiacMethods['epsilon'](self,*args)
 * 
 *      def epsilon2zero(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon2zero:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.epsilon2zero", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5214
 *         return GiacMethods['epsilon2zero'](self,*args)
 * 
 *      def equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_833equal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_832equal, "From Giac's documentation:\n        Help for equal:\n        equal(Expr,Expr)\n        Prefixed version of =.\n        See also: 1/ = 2/ equal2diff 3/ equal2list 4/ left 5/ right \n        Ex1: 2*x=4\n        Ex2:equal(2*x,4)\n        Ex3:equal(x^2-3x+2,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_833equal = {"equal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_833equal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_832equal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_833equal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "equal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_832equal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_832equal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equal", 1);

  /* "giacpy/auto-methods.pxi":5225
 * 
 *         '''
 *         return GiacMethods['equal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def equal2diff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_equal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5225, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5214
 *         return GiacMethods['epsilon2zero'](self,*args)
 * 
 *      def equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.equal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5227
 *         return GiacMethods['equal'](self,*args)
 * 
 *      def equal2diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2diff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_835equal2diff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_834equal2diff, "From Giac's documentation:\n        Help for equal2diff:\n        equal2diff(Equal)\n        A=B or equal(A,B) is converted into the difference A-B.\n        See also: 1/ left 2/ right 3/ equal2list 4/ equal 5/ = \n        Ex1:equal2diff(x=2)\n        Ex2:equal2diff(equal(x,2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_835equal2diff = {"equal2diff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_835equal2diff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_834equal2diff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_835equal2diff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equal2diff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "equal2diff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_834equal2diff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_834equal2diff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equal2diff", 1);

  /* "giacpy/auto-methods.pxi":5237
 * 
 *         '''
 *         return GiacMethods['equal2diff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def equal2list(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_equal2diff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5237, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5227
 *         return GiacMethods['equal'](self,*args)
 * 
 *      def equal2diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2diff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.equal2diff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5239
 *         return GiacMethods['equal2diff'](self,*args)
 * 
 *      def equal2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2list:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_837equal2list(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_836equal2list, "From Giac's documentation:\n        Help for equal2list:\n        equal2list(Equal)\n        A=B or equal(A,B) is converted into the list [A,B].\n        See also: 1/ left 2/ right 3/ equal2diff 4/ equal 5/ = \n        Ex1:equal2list(x=2)\n        Ex2:equal2list(equal(x,2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_837equal2list = {"equal2list", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_837equal2list, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_836equal2list};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_837equal2list(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equal2list (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "equal2list", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_836equal2list(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_836equal2list(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equal2list", 1);

  /* "giacpy/auto-methods.pxi":5249
 * 
 *         '''
 *         return GiacMethods['equal2list'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def equation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_equal2list); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5249, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5239
 *         return GiacMethods['equal2diff'](self,*args)
 * 
 *      def equal2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2list:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.equal2list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5251
 *         return GiacMethods['equal2list'](self,*args)
 * 
 *      def equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_839equation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_838equation, "From Giac's documentation:\n        Help for equation:\n        equation(GeoObj, VectParam)\n        equation returns the cartesian equation of a curve.\n        See also: 1/ parameq \n        Ex1:equation(line(1-i,i),[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_839equation = {"equation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_839equation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_838equation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_839equation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "equation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_838equation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_838equation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equation", 1);

  /* "giacpy/auto-methods.pxi":5260
 * 
 *         '''
 *         return GiacMethods['equation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def equilateral_triangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_equation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5260, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5251
 *         return GiacMethods['equal2list'](self,*args)
 * 
 *      def equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.equation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5262
 *         return GiacMethods['equation'](self,*args)
 * 
 *      def equilateral_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equilateral_triangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_841equilateral_triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_840equilateral_triangle, "From Giac's documentation:\n        Help for equilateral_triangle:\n        equilateral_triangle((Pnt(A) or Cplx),(Pnt(B) or Cplx),[Pnt(P)],[Var(C)])\n        equilateral_triangle(A,B) (resp equilateral_triangle(A,B,P)) draws the direct equilateral triangle ABC with side AB (resp in the half-plane ABP).\n        See also: 1/ triangle \n        Ex1:equilateral_triangle(point(1+i),0)\n        Ex2:equilateral_triangle(0,1+i,C)\n        Ex3:equilateral_triangle(point(0,0,0),point(3,3,3),point(0,0,3))\n        Ex4:equilateral_triangle(point(0,0,0),point(3,3,3),point(0,0,3),C)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_841equilateral_triangle = {"equilateral_triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_841equilateral_triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_840equilateral_triangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_841equilateral_triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equilateral_triangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "equilateral_triangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_840equilateral_triangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_840equilateral_triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equilateral_triangle", 1);

  /* "giacpy/auto-methods.pxi":5274
 * 
 *         '''
 *         return GiacMethods['equilateral_triangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def erf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_equilateral_triangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5274, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5262
 *         return GiacMethods['equation'](self,*args)
 * 
 *      def equilateral_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equilateral_triangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.equilateral_triangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5276
 *         return GiacMethods['equilateral_triangle'](self,*args)
 * 
 *      def erf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_843erf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_842erf, "From Giac's documentation:\n        Help for erf:\n        erf(Real(x0))\n        Returns the approximate value of 2/sqrt(pi)*int(exp(-t^2),t,0,x0).\n        See also: 1/ erfc \n        Ex1:erf(1)\n        Ex2:erf(1/(sqrt(2)))*1/2\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_843erf = {"erf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_843erf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_842erf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_843erf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("erf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "erf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_842erf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_842erf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("erf", 1);

  /* "giacpy/auto-methods.pxi":5286
 * 
 *         '''
 *         return GiacMethods['erf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def erfc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_erf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5286, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5276
 *         return GiacMethods['equilateral_triangle'](self,*args)
 * 
 *      def erf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.erf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5288
 *         return GiacMethods['erf'](self,*args)
 * 
 *      def erfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erfc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_845erfc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_844erfc, "From Giac's documentation:\n        Help for erfc:\n        erfc(Real(x0))\n        Returns the approximate value of 2/sqrt(pi)*int(exp(-t^2),t,x0,+infinity).\n        See also: 1/ erf \n        Ex1:erfc(1)\n        Ex2:erfc(1/(sqrt(2)))*1/2\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_845erfc = {"erfc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_845erfc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_844erfc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_845erfc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("erfc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "erfc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_844erfc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_844erfc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("erfc", 1);

  /* "giacpy/auto-methods.pxi":5298
 * 
 *         '''
 *         return GiacMethods['erfc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def error(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_erfc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5298, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5288
 *         return GiacMethods['erf'](self,*args)
 * 
 *      def erfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erfc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.erfc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5300
 *         return GiacMethods['erfc'](self,*args)
 * 
 *      def error(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for error:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_847error(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_846error, "From Giac's documentation:\n        Help for error:\n        error(Str)\n        Generates the display of an error in a program.\n        See also: 1/ try 2/ catch \n        Ex1:error(\"Argument should be integer\")\n        Ex2:error(\"je provoque une erreur\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_847error = {"error", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_847error, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_846error};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_847error(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("error (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "error", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_846error(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_846error(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("error", 1);

  /* "giacpy/auto-methods.pxi":5310
 * 
 *         '''
 *         return GiacMethods['error'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def est_permu(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_error); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5310, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5300
 *         return GiacMethods['erfc'](self,*args)
 * 
 *      def error(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for error:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5312
 *         return GiacMethods['error'](self,*args)
 * 
 *      def est_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for est_permu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_849est_permu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_848est_permu, "From Giac's documentation:\n        Help for est_permu:\n        est_permu(Lst)\n        Returns 1 if the argument is a permutation and 0 otherwise.\n        See also: 1/ is_cycle 2/ permu2cycles \n        Ex1:est_permu([4,2,3,1])\n        Ex2:est_permu([4,2,3,1,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_849est_permu = {"est_permu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_849est_permu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_848est_permu};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_849est_permu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("est_permu (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "est_permu", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_848est_permu(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_848est_permu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("est_permu", 1);

  /* "giacpy/auto-methods.pxi":5322
 * 
 *         '''
 *         return GiacMethods['est_permu'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def euler(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_est_permu); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5322, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5312
 *         return GiacMethods['error'](self,*args)
 * 
 *      def est_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for est_permu:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.est_permu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5324
 *         return GiacMethods['est_permu'](self,*args)
 * 
 *      def euler(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_851euler(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_850euler, "From Giac's documentation:\n        Help for euler:\n        euler(Intg(n))\n        Euler's function (euler(n)=card({p<n,gcd(n,p)=1})).\n        See also: 1/ gcd \n        Ex1:euler(11)\n        Ex2:euler(6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_851euler = {"euler", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_851euler, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_850euler};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_851euler(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("euler (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "euler", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_850euler(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_850euler(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("euler", 1);

  /* "giacpy/auto-methods.pxi":5334
 * 
 *         '''
 *         return GiacMethods['euler'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def euler_gamma(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_euler); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5334, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5324
 *         return GiacMethods['est_permu'](self,*args)
 * 
 *      def euler(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.euler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5336
 *         return GiacMethods['euler'](self,*args)
 * 
 *      def euler_gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_gamma:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_853euler_gamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_852euler_gamma, "From Giac's documentation:\n        Help for euler_gamma:\n        euler_gamma()\n        Euler's constant=euler_gamma=limit(sum(1/k,k,1,n)-ln(n),n,+infinity).\n        Ex1: evalf(euler_gamma)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_853euler_gamma = {"euler_gamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_853euler_gamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_852euler_gamma};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_853euler_gamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("euler_gamma (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "euler_gamma", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_852euler_gamma(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_852euler_gamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("euler_gamma", 1);

  /* "giacpy/auto-methods.pxi":5344
 * 
 *         '''
 *         return GiacMethods['euler_gamma'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def euler_lagrange(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_euler_gamma); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5344, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5336
 *         return GiacMethods['euler'](self,*args)
 * 
 *      def euler_gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_gamma:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.euler_gamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5346
 *         return GiacMethods['euler_gamma'](self,*args)
 * 
 *      def euler_lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_lagrange:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_855euler_lagrange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_854euler_lagrange, "From Giac's documentation:\n        Help for euler_lagrange:\n        euler_lagrange(Expr(f),[(Var(x),[Var||Lst(y)]) || y(x) || Lst(y(x))])\n        Returns the (system of) Euler-Lagrange equation(s) for the functional F=int(f,x=a..b).\n        See also: 1/ dsolve 2/ bvpsolve 3/ convex 4/ jacobi_equation 5/ conjugate_equation \n        Ex1:euler_lagrange(x^2*y'^2+y^2)\n        Ex2:euler_lagrange(sqrt(x'^2+y'^2),[x(t),y(t)])\n        Ex3: assume(y>=0):; euler_lagrange(sqrt((1+y'^2)/y),t,y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_855euler_lagrange = {"euler_lagrange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_855euler_lagrange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_854euler_lagrange};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_855euler_lagrange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("euler_lagrange (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "euler_lagrange", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_854euler_lagrange(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_854euler_lagrange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("euler_lagrange", 1);

  /* "giacpy/auto-methods.pxi":5357
 * 
 *         '''
 *         return GiacMethods['euler_lagrange'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def eval_level(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_euler_lagrange); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5357, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5346
 *         return GiacMethods['euler_gamma'](self,*args)
 * 
 *      def euler_lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_lagrange:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.euler_lagrange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5359
 *         return GiacMethods['euler_lagrange'](self,*args)
 * 
 *      def eval_level(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eval_level:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_857eval_level(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_856eval_level, "From Giac's documentation:\n        Help for eval_level:\n        eval_level([Intg(n)])\n        Evaluation level in interactive mode.\n        Ex1:eval_level()\n        Ex2:eval_level(1)\n        Ex3: purge(a,b,c);eval_level(1);a:=b+1; b:=c+1;c:=3;\n        Ex4: purge(a,b,c);eval_level(2);a:=b+1; b:=c+1;c:=3;\n        Ex5: purge(a,b,c);eval_level(3);a:=b+1; b:=c+1;c:=3;\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_857eval_level = {"eval_level", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_857eval_level, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_856eval_level};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_857eval_level(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eval_level (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eval_level", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_856eval_level(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_856eval_level(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eval_level", 1);

  /* "giacpy/auto-methods.pxi":5371
 * 
 *         '''
 *         return GiacMethods['eval_level'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def evala(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_eval_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5371, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5359
 *         return GiacMethods['euler_lagrange'](self,*args)
 * 
 *      def eval_level(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eval_level:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.eval_level", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5373
 *         return GiacMethods['eval_level'](self,*args)
 * 
 *      def evala(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evala:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_859evala(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_858evala, "From Giac's documentation:\n        Help for evala:\n        evala(Expr)\n        Simplifies the expression.\n        See also: 1/ simplify \n        Ex1:evala(2*x+y=1)\n        Ex2:evala(2*x*2)\n        Ex3:evala((2*x+1)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_859evala = {"evala", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_859evala, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_858evala};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_859evala(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evala (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "evala", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_858evala(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_858evala(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("evala", 1);

  /* "giacpy/auto-methods.pxi":5384
 * 
 *         '''
 *         return GiacMethods['evala'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def evalb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_evala); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5384, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5373
 *         return GiacMethods['eval_level'](self,*args)
 * 
 *      def evala(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evala:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.evala", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5386
 *         return GiacMethods['evala'](self,*args)
 * 
 *      def evalb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_861evalb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_860evalb, "From Giac's documentation:\n        Help for evalb:\n        evalb(Expr)\n        Boolean evaluation of the argument.\n        See also: 1/ evalf 2/ eval \n        Ex1:evalb(a==2)\n        Ex2:evalb(sqrt(2)+pi>a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_861evalb = {"evalb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_861evalb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_860evalb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_861evalb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evalb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "evalb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_860evalb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_860evalb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("evalb", 1);

  /* "giacpy/auto-methods.pxi":5396
 * 
 *         '''
 *         return GiacMethods['evalb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def evalc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_evalb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5396, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5386
 *         return GiacMethods['evala'](self,*args)
 * 
 *      def evalb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.evalb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5398
 *         return GiacMethods['evalb'](self,*args)
 * 
 *      def evalc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_863evalc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_862evalc, "From Giac's documentation:\n        Help for evalc:\n        evalc(Expr)\n        Returns a complex expression simplified to the format real+i*imag.\n        See also: 1/ normal \n        Ex1:evalc(-3+4*i+exp(i))\n        Ex2:evalc(1/(x+y*i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_863evalc = {"evalc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_863evalc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_862evalc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_863evalc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evalc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "evalc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_862evalc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_862evalc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("evalc", 1);

  /* "giacpy/auto-methods.pxi":5408
 * 
 *         '''
 *         return GiacMethods['evalc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def evalf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_evalc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5408, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5398
 *         return GiacMethods['evalb'](self,*args)
 * 
 *      def evalc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.evalc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5410
 *         return GiacMethods['evalc'](self,*args)
 * 
 *      def evalf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_865evalf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_864evalf, "From Giac's documentation:\n        Help for evalf:\n        evalf(Expr,[Int])\n        Numerical evaluation of the first argument (we can give the number of digits as second argument).\n        See also: 1/ evalb 2/ eval \n        Ex1:evalf(2/3)\n        Ex2:evalf(2/3,2)\n        Ex3:evalf(2*sin(1))\n        Ex4:evalf(2*sin(1),40)\n        Ex5:evalf(sqrt(2)+pi)\n        Ex6:evalf(sqrt(2)+pi,30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_865evalf = {"evalf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_865evalf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_864evalf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_865evalf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evalf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "evalf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_864evalf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_864evalf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("evalf", 1);

  /* "giacpy/auto-methods.pxi":5424
 * 
 *         '''
 *         return GiacMethods['evalf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def evalm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_evalf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5424, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5410
 *         return GiacMethods['evalc'](self,*args)
 * 
 *      def evalf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.evalf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5426
 *         return GiacMethods['evalf'](self,*args)
 * 
 *      def evalm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_867evalm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_866evalm, "From Giac's documentation:\n        Help for evalm:\n        evalm(Expr)\n        Evaluates its argument.\n        See also: 1/ evalf \n        Ex1:evalm(2*sin(pi))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_867evalm = {"evalm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_867evalm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_866evalm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_867evalm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evalm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "evalm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_866evalm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_866evalm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("evalm", 1);

  /* "giacpy/auto-methods.pxi":5435
 * 
 *         '''
 *         return GiacMethods['evalm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def even(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_evalm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5435, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5426
 *         return GiacMethods['evalf'](self,*args)
 * 
 *      def evalm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.evalm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5437
 *         return GiacMethods['evalm'](self,*args)
 * 
 *      def even(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for even:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_869even(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_868even, "From Giac's documentation:\n        Help for even:\n        even(Intg(n))\n        Returns 1 if the integer is even, else returns 0.\n        See also: 1/ odd \n        Ex1:even(6)\n        Ex2:even(1251)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_869even = {"even", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_869even, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_868even};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_869even(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("even (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "even", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_868even(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_868even(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("even", 1);

  /* "giacpy/auto-methods.pxi":5447
 * 
 *         '''
 *         return GiacMethods['even'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def evolute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_even); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5447, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5437
 *         return GiacMethods['evalm'](self,*args)
 * 
 *      def even(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for even:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.even", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5449
 *         return GiacMethods['even'](self,*args)
 * 
 *      def evolute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evolute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_871evolute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_870evolute, "From Giac's documentation:\n        Help for evolute:\n        evolute(Curve)\n        Evolute of a curve C.\n        See also: 1/ curvature 2/ osculating_circle \n        Ex1:evolute(plot(x^2))\n        Ex2:evolute([t,t^2],t)\n        Ex3:evolute([3*exp(t/2)*cos(t),3*exp(t/2)*sin(t)],t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_871evolute = {"evolute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_871evolute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_870evolute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_871evolute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("evolute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "evolute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_870evolute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_870evolute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("evolute", 1);

  /* "giacpy/auto-methods.pxi":5460
 * 
 *         '''
 *         return GiacMethods['evolute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exact(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_evolute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5460, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5449
 *         return GiacMethods['even'](self,*args)
 * 
 *      def evolute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evolute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.evolute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5462
 *         return GiacMethods['evolute'](self,*args)
 * 
 *      def exact(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exact:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_873exact(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_872exact, "From Giac's documentation:\n        Help for exact:\n        exact(Expr)\n        Converts the expression to a rational or real expression.\n        See also: 1/  \n        Ex1:exact(-2)\n        Ex2:exact(1.5)\n        Ex3:exact(1.4141)\n        Ex4:exact(0.156381102937)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_873exact = {"exact", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_873exact, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_872exact};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_873exact(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exact (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exact", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_872exact(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_872exact(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exact", 1);

  /* "giacpy/auto-methods.pxi":5474
 * 
 *         '''
 *         return GiacMethods['exact'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exbisector(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exact); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5474, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5462
 *         return GiacMethods['evolute'](self,*args)
 * 
 *      def exact(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exact:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exact", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5476
 *         return GiacMethods['exact'](self,*args)
 * 
 *      def exbisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exbisector:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_875exbisector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_874exbisector, "From Giac's documentation:\n        Help for exbisector:\n        exbisector((Pnt(A) or Cplx),(Pnt(B) or Cplx),(Pnt(C) or Cplx))\n        Draws the exterior bisector of the angle (AB,AC) given by 3 points A,B,C.\n        See also: 1/ angle 2/ bisector \n        Ex1:exbisector(0,1,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_875exbisector = {"exbisector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_875exbisector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_874exbisector};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_875exbisector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exbisector (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exbisector", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_874exbisector(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_874exbisector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exbisector", 1);

  /* "giacpy/auto-methods.pxi":5485
 * 
 *         '''
 *         return GiacMethods['exbisector'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def excircle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exbisector); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5485, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5476
 *         return GiacMethods['exact'](self,*args)
 * 
 *      def exbisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exbisector:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exbisector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5487
 *         return GiacMethods['exbisector'](self,*args)
 * 
 *      def excircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for excircle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_877excircle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_876excircle, "From Giac's documentation:\n        Help for excircle:\n        excircle((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        excircle(A,B,C) draws the A-excircle of the triangle ABC.\n        See also: 1/ incircle 2/ circumcircle \n        Ex1:excircle(0,1,1+i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_877excircle = {"excircle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_877excircle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_876excircle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_877excircle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("excircle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "excircle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_876excircle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_876excircle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("excircle", 1);

  /* "giacpy/auto-methods.pxi":5496
 * 
 *         '''
 *         return GiacMethods['excircle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def execute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_excircle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5496, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5487
 *         return GiacMethods['exbisector'](self,*args)
 * 
 *      def excircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for excircle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.excircle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5498
 *         return GiacMethods['excircle'](self,*args)
 * 
 *      def execute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for execute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_879execute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_878execute, "From Giac's documentation:\n        Help for execute:\n        execute(Str)\n        Instruction transforming a string into a command or into a number.\n        See also: 1/ string \n        Ex1:execute(\"ifactor(54)\")\n        Ex2:execute(\"123\")\n        Ex3:execute(\"0123\")\n        Ex4:execute(sin,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_879execute = {"execute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_879execute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_878execute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_879execute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("execute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "execute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_878execute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_878execute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("execute", 1);

  /* "giacpy/auto-methods.pxi":5510
 * 
 *         '''
 *         return GiacMethods['execute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_execute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5510, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5498
 *         return GiacMethods['excircle'](self,*args)
 * 
 *      def execute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for execute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.execute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5512
 *         return GiacMethods['execute'](self,*args)
 * 
 *      def exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_881exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_880exp, "From Giac's documentation:\n        Help for exp:\n        exp(Expr or Opt)\n        Exponential or option of the convert or convertir command (id trig2exp).\n        See also: 1/ ln 2/ convert 3/ trig2exp \n        Ex1:exp(0)\n        Ex2: convert(cos(x),exp)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_881exp = {"exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_881exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_880exp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_881exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_880exp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_880exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exp", 1);

  /* "giacpy/auto-methods.pxi":5522
 * 
 *         '''
 *         return GiacMethods['exp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exp2list(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5522, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5512
 *         return GiacMethods['execute'](self,*args)
 * 
 *      def exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5524
 *         return GiacMethods['exp'](self,*args)
 * 
 *      def exp2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2list:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_883exp2list(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_882exp2list, "From Giac's documentation:\n        Help for exp2list:\n        exp2list(Expr)\n        Returns the list made with the righthand member of (var=expr0 or var=expr1), to be used after solve in TI mode.\n        See also: 1/ list2exp \n        Ex1:exp2list((x=2) or (x=0))\n        Ex2:exp2list((x=3 and y=9) or (x=-1 and y=1) )\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_883exp2list = {"exp2list", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_883exp2list, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_882exp2list};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_883exp2list(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exp2list (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exp2list", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_882exp2list(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_882exp2list(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exp2list", 1);

  /* "giacpy/auto-methods.pxi":5534
 * 
 *         '''
 *         return GiacMethods['exp2list'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exp2pow(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exp2list); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5534, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5524
 *         return GiacMethods['exp'](self,*args)
 * 
 *      def exp2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2list:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exp2list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5536
 *         return GiacMethods['exp2list'](self,*args)
 * 
 *      def exp2pow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2pow:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_885exp2pow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_884exp2pow, "From Giac's documentation:\n        Help for exp2pow:\n        exp2pow(Expr)\n        Transforms exp(n*ln(x)) to x^n.\n        See also: 1/ pow2exp \n        Ex1:exp2pow(exp(3*ln(x)))\n        Ex2:exp2pow(exp(x*ln(x)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_885exp2pow = {"exp2pow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_885exp2pow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_884exp2pow};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_885exp2pow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exp2pow (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exp2pow", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_884exp2pow(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_884exp2pow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exp2pow", 1);

  /* "giacpy/auto-methods.pxi":5546
 * 
 *         '''
 *         return GiacMethods['exp2pow'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exp2trig(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exp2pow); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5546, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5536
 *         return GiacMethods['exp2list'](self,*args)
 * 
 *      def exp2pow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2pow:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exp2pow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5548
 *         return GiacMethods['exp2pow'](self,*args)
 * 
 *      def exp2trig(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2trig:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_887exp2trig(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_886exp2trig, "From Giac's documentation:\n        Help for exp2trig:\n        exp2trig(Expr)\n        Transforms the complex exponential into sine and cosine.\n        See also: 1/ trig2exp 2/ atrig2ln \n        Ex1:exp2trig(exp(i*x))\n        Ex2:exp2trig(exp(-i*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_887exp2trig = {"exp2trig", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_887exp2trig, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_886exp2trig};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_887exp2trig(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exp2trig (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exp2trig", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_886exp2trig(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_886exp2trig(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exp2trig", 1);

  /* "giacpy/auto-methods.pxi":5558
 * 
 *         '''
 *         return GiacMethods['exp2trig'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def expand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exp2trig); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5558, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5548
 *         return GiacMethods['exp2pow'](self,*args)
 * 
 *      def exp2trig(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2trig:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exp2trig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5560
 *         return GiacMethods['exp2trig'](self,*args)
 * 
 *      def expand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_889expand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_888expand, "From Giac's documentation:\n        Help for expand:\n        expand(Expr)\n        Full distribution of * and / over + and -.\n        See also: 1/ texpand 2/ normal 3/ simplify 4/ ratnormal \n        Ex1:expand((x+y)*(z+1))\n        Ex2:expand((a+b+c)/d)\n        Ex3:expand((y+x)*(z+y)*(x+z))\n        Ex4:expand((x+3)^4)\n        Ex5:expand((2*x-2*1)*(x^2-3*x+2)+(x^2-2*x+3)*(2*x-3*1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_889expand = {"expand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_889expand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_888expand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_889expand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "expand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_888expand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_888expand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expand", 1);

  /* "giacpy/auto-methods.pxi":5573
 * 
 *         '''
 *         return GiacMethods['expand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def expexpand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_expand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5573, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5560
 *         return GiacMethods['exp2trig'](self,*args)
 * 
 *      def expand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.expand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5575
 *         return GiacMethods['expand'](self,*args)
 * 
 *      def expexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expexpand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_891expexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_890expexpand, "From Giac's documentation:\n        Help for expexpand:\n        expexpand(Expr)\n        Expands exponentials.\n        See also: 1/ texpand 2/ lnexpand 3/ trigexpand \n        Ex1:expexpand(exp(3*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_891expexpand = {"expexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_891expexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_890expexpand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_891expexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expexpand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "expexpand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_890expexpand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_890expexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expexpand", 1);

  /* "giacpy/auto-methods.pxi":5584
 * 
 *         '''
 *         return GiacMethods['expexpand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def expln(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_expexpand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5584, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5575
 *         return GiacMethods['expand'](self,*args)
 * 
 *      def expexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expexpand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.expexpand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5586
 *         return GiacMethods['expexpand'](self,*args)
 * 
 *      def expln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expln:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_893expln(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_892expln, "From Giac's documentation:\n        Help for expln:\n        expln(Opt)\n        Option of the convert or convertir command (id trig2exp).\n        See also: 1/ exp 2/ ln 3/ convert 4/ trig2exp \n        Ex1: convert(cos(x),expln)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_893expln = {"expln", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_893expln, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_892expln};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_893expln(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expln (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "expln", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_892expln(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_892expln(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expln", 1);

  /* "giacpy/auto-methods.pxi":5595
 * 
 *         '''
 *         return GiacMethods['expln'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponential(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_expln); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5595, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5586
 *         return GiacMethods['expexpand'](self,*args)
 * 
 *      def expln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expln:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.expln", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5597
 *         return GiacMethods['expln'](self,*args)
 * 
 *      def exponential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_895exponential(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_894exponential, "From Giac's documentation:\n        Help for exponential:\n        exponential(Real(lambda),Real(x))\n        Returns the probability density at x of the exponential law of parameter lambda.\n        See also: 1/ exponential_cdf 2/ exponential_icdf 3/ randvector 4/ ranm \n        Ex1:exponential(2.1,3.5)\n        Ex2:exponential(2.1,0.5)\n        Ex3: randvector(3,exponential,1.2)\n        Ex4: ranm(4,3,exponential,1.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_895exponential = {"exponential", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_895exponential, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_894exponential};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_895exponential(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponential (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponential", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_894exponential(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_894exponential(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponential", 1);

  /* "giacpy/auto-methods.pxi":5609
 * 
 *         '''
 *         return GiacMethods['exponential'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponential_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponential); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5609, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5597
 *         return GiacMethods['expln'](self,*args)
 * 
 *      def exponential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponential", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5611
 *         return GiacMethods['exponential'](self,*args)
 * 
 *      def exponential_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_897exponential_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_896exponential_cdf, "From Giac's documentation:\n        Help for exponential_cdf:\n        exponential_cdf(Real(lambda),Real(x0),[Real(y0)])\n        Returns the probability that a exponential random variable of parameter lambda is less than x0 (or between x0 and y0).\n        See also: 1/ exponentiald 2/ exponential_icdf \n        Ex1:exponential_cdf(4.2,2.1)\n        Ex2:exponential_cdf(4.2,2.1,3.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_897exponential_cdf = {"exponential_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_897exponential_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_896exponential_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_897exponential_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponential_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponential_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_896exponential_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_896exponential_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponential_cdf", 1);

  /* "giacpy/auto-methods.pxi":5621
 * 
 *         '''
 *         return GiacMethods['exponential_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponential_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponential_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5621, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5611
 *         return GiacMethods['exponential'](self,*args)
 * 
 *      def exponential_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponential_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5623
 *         return GiacMethods['exponential_cdf'](self,*args)
 * 
 *      def exponential_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_899exponential_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_898exponential_icdf, "From Giac's documentation:\n        Help for exponential_icdf:\n        exponential_icdf(Real(lambda),Real(x0),Real(p))\n        Returns h such that the probability that a exponential random variable of parameter lambda is less than h is p (0<=p<=1).\n        See also: 1/ exponential_cdf 2/ exponentiald \n        Ex1:exponential_icdf(4.2,0.95)\n        Ex2:exponential_icdf(4.2,0.6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_899exponential_icdf = {"exponential_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_899exponential_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_898exponential_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_899exponential_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponential_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponential_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_898exponential_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_898exponential_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponential_icdf", 1);

  /* "giacpy/auto-methods.pxi":5633
 * 
 *         '''
 *         return GiacMethods['exponential_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponential_regression(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponential_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5633, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5623
 *         return GiacMethods['exponential_cdf'](self,*args)
 * 
 *      def exponential_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponential_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5635
 *         return GiacMethods['exponential_icdf'](self,*args)
 * 
 *      def exponential_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_901exponential_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_900exponential_regression, "From Giac's documentation:\n        Help for exponential_regression:\n        exponential_regression(Lst||Mtrx(A),[Lst])\n        Returns the coefficients (a,b) of y=b*a^x : it is the best exponential which approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ logarithmic_regression \n        Ex1:exponential_regression([[1.0,2.0],[0.0,1.0],[4.0,7.0]])\n        Ex2:exponential_regression([1.0,0.0,4.0],[2.0,1.0,7.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_901exponential_regression = {"exponential_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_901exponential_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_900exponential_regression};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_901exponential_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponential_regression (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponential_regression", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_900exponential_regression(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_900exponential_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponential_regression", 1);

  /* "giacpy/auto-methods.pxi":5645
 * 
 *         '''
 *         return GiacMethods['exponential_regression'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponential_regression_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponential_regression); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5645, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5635
 *         return GiacMethods['exponential_icdf'](self,*args)
 * 
 *      def exponential_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponential_regression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5647
 *         return GiacMethods['exponential_regression'](self,*args)
 * 
 *      def exponential_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_903exponential_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_902exponential_regression_plot, "From Giac's documentation:\n        Help for exponential_regression_plot:\n        exponential_regression_plot(Lst||Mtrx(A),[Lst])\n        Returns the plot of y=b*a^x : it is the best exponential which approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ logarithmic_regression_plot \n        Ex1:exponential_regression_plot([[1.0,2.0],[0.0,1.0],[4.0,7.0]])\n        Ex2:exponential_regression_plot([1.0,0.0,4.0],[2.0,1.0,7.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_903exponential_regression_plot = {"exponential_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_903exponential_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_902exponential_regression_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_903exponential_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponential_regression_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponential_regression_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_902exponential_regression_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_902exponential_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponential_regression_plot", 1);

  /* "giacpy/auto-methods.pxi":5657
 * 
 *         '''
 *         return GiacMethods['exponential_regression_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponentiald(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponential_regression_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5657, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5647
 *         return GiacMethods['exponential_regression'](self,*args)
 * 
 *      def exponential_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponential_regression_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5659
 *         return GiacMethods['exponential_regression_plot'](self,*args)
 * 
 *      def exponentiald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_905exponentiald(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_904exponentiald, "From Giac's documentation:\n        Help for exponentiald:\n        exponentiald(Real(lambda),Real(x))\n        Returns the probability density at x of the exponential law of parameter lambda.\n        See also: 1/ exponential_cdf 2/ exponential_icdf 3/ randvector 4/ ranm \n        Ex1:exponentiald(2.1,3.5)\n        Ex2:exponentiald(2.1,0.5)\n        Ex3: randvector(3,exponential,1.2)\n        Ex4: ranm(4,3,exponential,1.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_905exponentiald = {"exponentiald", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_905exponentiald, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_904exponentiald};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_905exponentiald(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponentiald (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponentiald", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_904exponentiald(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_904exponentiald(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponentiald", 1);

  /* "giacpy/auto-methods.pxi":5671
 * 
 *         '''
 *         return GiacMethods['exponentiald'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponentiald_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponentiald); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5671, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5659
 *         return GiacMethods['exponential_regression_plot'](self,*args)
 * 
 *      def exponentiald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponentiald", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5673
 *         return GiacMethods['exponentiald'](self,*args)
 * 
 *      def exponentiald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_907exponentiald_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_906exponentiald_cdf, "From Giac's documentation:\n        Help for exponentiald_cdf:\n        exponentiald_cdf(Real(lambda),Real(x0),[Real(y0)])\n        Returns the probability that a exponential random variable of parameter lambda is less than x0 (or between x0 and y0).\n        See also: 1/ exponentiald 2/ exponential_icdf \n        Ex1:exponentiald_cdf(4.2,2.1)\n        Ex2:exponentiald_cdf(4.2,2.1,3.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_907exponentiald_cdf = {"exponentiald_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_907exponentiald_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_906exponentiald_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_907exponentiald_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponentiald_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponentiald_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_906exponentiald_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_906exponentiald_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponentiald_cdf", 1);

  /* "giacpy/auto-methods.pxi":5683
 * 
 *         '''
 *         return GiacMethods['exponentiald_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def exponentiald_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponentiald_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5683, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5673
 *         return GiacMethods['exponentiald'](self,*args)
 * 
 *      def exponentiald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponentiald_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5685
 *         return GiacMethods['exponentiald_cdf'](self,*args)
 * 
 *      def exponentiald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_909exponentiald_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_908exponentiald_icdf, "From Giac's documentation:\n        Help for exponentiald_icdf:\n        exponentiald_icdf(Real(lambda),Real(x0),Real(p))\n        Returns h such that the probability that a exponential random variable of parameter lambda is less than h is p (0<=p<=1).\n        See also: 1/ exponential_cdf 2/ exponentiald \n        Ex1:exponentiald_icdf(4.2,0.95)\n        Ex2:exponentiald_icdf(4.2,0.6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_909exponentiald_icdf = {"exponentiald_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_909exponentiald_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_908exponentiald_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_909exponentiald_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("exponentiald_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "exponentiald_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_908exponentiald_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_908exponentiald_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("exponentiald_icdf", 1);

  /* "giacpy/auto-methods.pxi":5695
 * 
 *         '''
 *         return GiacMethods['exponentiald_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def export_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_exponentiald_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5695, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5685
 *         return GiacMethods['exponentiald_cdf'](self,*args)
 * 
 *      def exponentiald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.exponentiald_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5697
 *         return GiacMethods['exponentiald_icdf'](self,*args)
 * 
 *      def export_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_911export_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_910export_graph, "From Giac's documentation:\n        Help for export_graph:\n        export_graph(Graph(G),Str(\"filename\"),[opts])\n        Writes G to the file 'filename' in dot/lst/LaTeX format, returns 1 on success and 0 on failure.\n        See also: 1/ import_graph \n        Ex1:export_graph(complete_graph(5),\"K5.dot\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_911export_graph = {"export_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_911export_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_910export_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_911export_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("export_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "export_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_910export_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_910export_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("export_graph", 1);

  /* "giacpy/auto-methods.pxi":5706
 * 
 *         '''
 *         return GiacMethods['export_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def export_mathml(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_export_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5706, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5697
 *         return GiacMethods['exponentiald_icdf'](self,*args)
 * 
 *      def export_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.export_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5708
 *         return GiacMethods['export_graph'](self,*args)
 * 
 *      def export_mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_mathml:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_913export_mathml(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_912export_mathml, "From Giac's documentation:\n        Help for export_mathml:\n        export_mathml(Expr,[display||content])\n        Converts an expression to presentation or content MathML block.\n        See also: 1/ mathml 2/ latex \n        Ex1:export_mathml(a+2*b)\n        Ex2:export_mathml(a+2*b,display)\n        Ex3:export_mathml(a+2*b,content)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_913export_mathml = {"export_mathml", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_913export_mathml, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_912export_mathml};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_913export_mathml(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("export_mathml (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "export_mathml", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_912export_mathml(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_912export_mathml(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("export_mathml", 1);

  /* "giacpy/auto-methods.pxi":5719
 * 
 *         '''
 *         return GiacMethods['export_mathml'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def expovariate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_export_mathml); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5719, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5708
 *         return GiacMethods['export_graph'](self,*args)
 * 
 *      def export_mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_mathml:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.export_mathml", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5721
 *         return GiacMethods['export_mathml'](self,*args)
 * 
 *      def expovariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expovariate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_915expovariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_914expovariate, "From Giac's documentation:\n        Help for expovariate:\n        expovariate(Real(a))\n        Returns a random real according to the exponential distribution with parameter a>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:expovariate(1)\n        Ex2:expovariate(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_915expovariate = {"expovariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_915expovariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_914expovariate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_915expovariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expovariate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "expovariate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_914expovariate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_914expovariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expovariate", 1);

  /* "giacpy/auto-methods.pxi":5731
 * 
 *         '''
 *         return GiacMethods['expovariate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def expr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_expovariate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5731, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5721
 *         return GiacMethods['export_mathml'](self,*args)
 * 
 *      def expovariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expovariate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.expovariate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5733
 *         return GiacMethods['expovariate'](self,*args)
 * 
 *      def expr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_917expr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_916expr, "From Giac's documentation:\n        Help for expr:\n        expr(Str)\n        Instruction transforming a string into a command or into a number.\n        See also: 1/ string \n        Ex1:expr(\"ifactor(54)\")\n        Ex2:expr(\"123\")\n        Ex3:expr(\"0123\")\n        Ex4:expr(sin,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_917expr = {"expr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_917expr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_916expr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_917expr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "expr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_916expr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_916expr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expr", 1);

  /* "giacpy/auto-methods.pxi":5745
 * 
 *         '''
 *         return GiacMethods['expr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def extend(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5745, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5733
 *         return GiacMethods['expovariate'](self,*args)
 * 
 *      def expr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.expr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5747
 *         return GiacMethods['expr'](self,*args)
 * 
 *      def extend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extend:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_919extend(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_918extend, "From Giac's documentation:\n        Help for extend:\n        extend(Lst,Lst||Seq,Seq||Str,Str||Mtrx,Mtrx)\n        Concatenates two lists or two strings or two sequences or 2 matrices; L:=concat(L,L1) or L.concat(L1).\n        See also: 1/ append 2/ cat 3/ semi_augment 4/ border 5/ + \n        Ex1:extend([1,2],[3,4,5])\n        Ex2:extend(\"bon\",\"jour\")\n        Ex3:extend([[1,2],[3,4]],[[4,5,6],[6,7,8]])\n        Ex4: L:=[1,2];L.concat([3,4,5])\n        Ex5: S:=\"abcd\";S.concat(\"efghi\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_919extend = {"extend", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_919extend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_918extend};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_919extend(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extend (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "extend", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_918extend(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_918extend(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "giacpy/auto-methods.pxi":5760
 * 
 *         '''
 *         return GiacMethods['extend'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def extract_measure(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_extend); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5760, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5747
 *         return GiacMethods['expr'](self,*args)
 * 
 *      def extend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extend:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5762
 *         return GiacMethods['extend'](self,*args)
 * 
 *      def extract_measure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extract_measure:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_921extract_measure(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_920extract_measure, "From Giac's documentation:\n        Help for extract_measure:\n        extract_measure(Var)\n        extract_measure gives as answer the value calculated by the argument.\n        See also: 1/ angleatraw 2/ distanceatraw 3/ angleat 4/ distanceat 5/ slopeatraw 6/ areaatraw 7/ perimeteratraw 8/ slopeat 5/ areaat 10/ perimeterat \n        Ex1:extract_measure(distanceatraw(0,1+i,(1+i)/2))\n        Ex2:extract_measure(angleatraw(0,1,1+i,1))\n        Ex3: A:=point(0);B:=point(1+i);a:=distanceatraw(A,B,(1+i)/2);extract_measure(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_921extract_measure = {"extract_measure", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_921extract_measure, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_920extract_measure};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_921extract_measure(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extract_measure (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "extract_measure", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_920extract_measure(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_920extract_measure(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extract_measure", 1);

  /* "giacpy/auto-methods.pxi":5773
 * 
 *         '''
 *         return GiacMethods['extract_measure'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def extrema(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_extract_measure); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5773, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5762
 *         return GiacMethods['extend'](self,*args)
 * 
 *      def extract_measure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extract_measure:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.extract_measure", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5775
 *         return GiacMethods['extract_measure'](self,*args)
 * 
 *      def extrema(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extrema:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_923extrema(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_922extrema, "From Giac's documentation:\n        Help for extrema:\n        extrema(Expr,[Var])\n        Search extrema of an expression.\n        Ex1:extrema(-2*cos(x)-cos(x)^2,x)\n        Ex2:extrema((x^3-1)^4/(2x^3+1)^4,x=0..inf)\n        Ex3:extrema(exp(x^2-2x)*ln(x)*ln(1-x),x=0.5)\n        Ex4:extrema(x^2+y^2,x*y=1,[x=0..inf,y=0..inf])\n        Ex5: assume(a>0):;extrema(x/a^2+a*y^2,x+y=a,[x,y])\n        Ex6:extrema(x*y*z,x+y+z=1,[x,y,z])\n        Ex7:extrema(x2^4-x1^4-x2^8+x1^10,[x1,x2],order=1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_923extrema = {"extrema", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_923extrema, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_922extrema};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_923extrema(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("extrema (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "extrema", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_922extrema(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_922extrema(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extrema", 1);

  /* "giacpy/auto-methods.pxi":5789
 * 
 *         '''
 *         return GiacMethods['extrema'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ezgcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_extrema); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5789, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5775
 *         return GiacMethods['extract_measure'](self,*args)
 * 
 *      def extrema(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extrema:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.extrema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5791
 *         return GiacMethods['extrema'](self,*args)
 * 
 *      def ezgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ezgcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_925ezgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_924ezgcd, "From Giac's documentation:\n        Help for ezgcd:\n        ezgcd(Poly,Poly)\n        GCD of 2 polynomials with at least 2 variables, with the ezgcd algorithm.\n        See also: 1/ gcd 2/ modgcd 3/ heugcd 4/ psrgcd \n        Ex1:ezgcd(x^2-2*xy+y^2-1,x-y)\n        Ex2:ezgcd((x+1)^4-y^4,(x+1-y)^2)\n        Ex3:ezgcd((x+y-1)*(x+y+1),(x+y+1)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_925ezgcd = {"ezgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_925ezgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_924ezgcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_925ezgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ezgcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ezgcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_924ezgcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_924ezgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ezgcd", 1);

  /* "giacpy/auto-methods.pxi":5802
 * 
 *         '''
 *         return GiacMethods['ezgcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def f2nd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ezgcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5802, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5791
 *         return GiacMethods['extrema'](self,*args)
 * 
 *      def ezgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ezgcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ezgcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5804
 *         return GiacMethods['ezgcd'](self,*args)
 * 
 *      def f2nd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for f2nd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_927f2nd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_926f2nd, "From Giac's documentation:\n        Help for f2nd:\n        f2nd(Frac or RatFrac)\n        Returns the list built with the numerator and the denominator of the simplified fraction.\n        See also: 1/ simp2 2/ numer 3/ denom 4/ getNum 5/ getDenom \n        Ex1:f2nd(42/12)\n        Ex2:f2nd((x^2+2*x+1)/(x^2-1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_927f2nd = {"f2nd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_927f2nd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_926f2nd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_927f2nd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("f2nd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "f2nd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_926f2nd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_926f2nd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("f2nd", 1);

  /* "giacpy/auto-methods.pxi":5814
 * 
 *         '''
 *         return GiacMethods['f2nd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fMax(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_f2nd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5814, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5804
 *         return GiacMethods['ezgcd'](self,*args)
 * 
 *      def f2nd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for f2nd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.f2nd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5816
 *         return GiacMethods['f2nd'](self,*args)
 * 
 *      def fMax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMax:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_929fMax(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_928fMax, "From Giac's documentation:\n        Help for fMax:\n        fMax(Expr,[Var])\n        Returns the abscissa of the maximum of the expression.\n        See also: 1/ fMin \n        Ex1:fMax(-x^2+2*x+1,x)\n        Ex2:fMax(-x^2+2*x+1,x=1..2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_929fMax = {"fMax", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_929fMax, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_928fMax};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_929fMax(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fMax (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fMax", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_928fMax(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_928fMax(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fMax", 1);

  /* "giacpy/auto-methods.pxi":5826
 * 
 *         '''
 *         return GiacMethods['fMax'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fMin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fMax); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5826, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5816
 *         return GiacMethods['f2nd'](self,*args)
 * 
 *      def fMax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMax:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fMax", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5828
 *         return GiacMethods['fMax'](self,*args)
 * 
 *      def fMin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_931fMin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_930fMin, "From Giac's documentation:\n        Help for fMin:\n        fMin(Expr,[Var])\n        Returns the abscissa of the minimum of the expression.\n        See also: 1/ fMax \n        Ex1:fMin(x^2-2*x+1,x)\n        Ex2:fMin(x^2-2*x+1,x=1..2)\n        Ex3:fMin((x-3)^2+(y-5)^2+1,[],[x,y],[1,1])\n        Ex4:fMin((x-3)^2+(y-5)^2+1,[x+y^2=1],[x,y],[1,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_931fMin = {"fMin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_931fMin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_930fMin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_931fMin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fMin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fMin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_930fMin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_930fMin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fMin", 1);

  /* "giacpy/auto-methods.pxi":5840
 * 
 *         '''
 *         return GiacMethods['fMin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fPart(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fMin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5840, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5828
 *         return GiacMethods['fMax'](self,*args)
 * 
 *      def fMin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fMin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5842
 *         return GiacMethods['fMin'](self,*args)
 * 
 *      def fPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fPart:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_933fPart(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_932fPart, "From Giac's documentation:\n        Help for fPart:\n        fPart(Real||LstReal)\n        Returns the fractional part (if x<0 then frac(x)+floor(x)+1=x else frac(x)+floor(x)=x).\n        See also: 1/ floor 2/ iPart 3/ trunc \n        Ex1:fPart(1/2)\n        Ex2:fPart(-1/2)\n        Ex3:fPart(1.2)\n        Ex4:fPart(-1.2)\n        Ex5:fPart([3.4,sqrt(2)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_933fPart = {"fPart", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_933fPart, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_932fPart};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_933fPart(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fPart (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fPart", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_932fPart(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_932fPart(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fPart", 1);

  /* "giacpy/auto-methods.pxi":5855
 * 
 *         '''
 *         return GiacMethods['fPart'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def faces(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fPart); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5855, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5842
 *         return GiacMethods['fMin'](self,*args)
 * 
 *      def fPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fPart:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fPart", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5857
 *         return GiacMethods['fPart'](self,*args)
 * 
 *      def faces(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for faces:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_935faces(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_934faces, "From Giac's documentation:\n        Help for faces:\n        faces(Polygon or Polyedr(P))\n        Returns the list of the faces (1 face=matrix(n,3) where the n rows are the n vertices of the face) of the polyhedron P.\n        See also: 1/ polyhedron \n        Ex1:faces(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))\n        Ex2:faces(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))[2]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_935faces = {"faces", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_935faces, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_934faces};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_935faces(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("faces (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "faces", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_934faces(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_934faces(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("faces", 1);

  /* "giacpy/auto-methods.pxi":5867
 * 
 *         '''
 *         return GiacMethods['faces'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def facteurs_premiers(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_faces); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5867, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5857
 *         return GiacMethods['fPart'](self,*args)
 * 
 *      def faces(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for faces:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.faces", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5869
 *         return GiacMethods['faces'](self,*args)
 * 
 *      def facteurs_premiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for facteurs_premiers:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_937facteurs_premiers(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_936facteurs_premiers, "From Giac's documentation:\n        Help for facteurs_premiers:\n        facteurs_premiers(Intg(a) or LstIntg)\n        Returns the list of prime factors of an integer (each factor is followed by its multiplicity).\n        See also: 1/ ifactor 2/ factors \n        Ex1:facteurs_premiers(36)\n        Ex2:facteurs_premiers([36,52])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_937facteurs_premiers = {"facteurs_premiers", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_937facteurs_premiers, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_936facteurs_premiers};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_937facteurs_premiers(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("facteurs_premiers (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "facteurs_premiers", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_936facteurs_premiers(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_936facteurs_premiers(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("facteurs_premiers", 1);

  /* "giacpy/auto-methods.pxi":5879
 * 
 *         '''
 *         return GiacMethods['facteurs_premiers'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_facteurs_premiers); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5879, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5869
 *         return GiacMethods['faces'](self,*args)
 * 
 *      def facteurs_premiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for facteurs_premiers:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.facteurs_premiers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5881
 *         return GiacMethods['facteurs_premiers'](self,*args)
 * 
 *      def factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_939factor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_938factor, "From Giac's documentation:\n        Help for factor:\n        factor(Expr)\n        Factors a polynomial.\n        See also: 1/ ifactor 2/ cfactor 3/ partfrac 4/ normal \n        Ex1:factor(x^4-1)\n        Ex2:factor(x^4-4,sqrt(2))\n        Ex3:factor(x^4+12*x^3+54*x^2+108*x+81)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_939factor = {"factor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_939factor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_938factor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_939factor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_938factor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_938factor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factor", 1);

  /* "giacpy/auto-methods.pxi":5892
 * 
 *         '''
 *         return GiacMethods['factor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factor_xn(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5892, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5881
 *         return GiacMethods['facteurs_premiers'](self,*args)
 * 
 *      def factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5894
 *         return GiacMethods['factor'](self,*args)
 * 
 *      def factor_xn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor_xn:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_941factor_xn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_940factor_xn, "From Giac's documentation:\n        Help for factor_xn:\n        factor_xn(Poly(P))\n        Factors x^n in P (n=degree of polynomial P).\n        See also: 1/ ifactor 2/ partfrac 3/ normal \n        Ex1:factor_xn(x^4-1)\n        Ex2:factor_xn(x^4+12*x^3+54*x^2+108*x+81)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_941factor_xn = {"factor_xn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_941factor_xn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_940factor_xn};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_941factor_xn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factor_xn (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factor_xn", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_940factor_xn(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_940factor_xn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factor_xn", 1);

  /* "giacpy/auto-methods.pxi":5904
 * 
 *         '''
 *         return GiacMethods['factor_xn'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factorial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factor_xn); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5904, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5894
 *         return GiacMethods['factor'](self,*args)
 * 
 *      def factor_xn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor_xn:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factor_xn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5906
 *         return GiacMethods['factor_xn'](self,*args)
 * 
 *      def factorial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factorial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_943factorial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_942factorial, "From Giac's documentation:\n        Help for factorial:\n        factorial(Intg(n)|| Real(a))\n        factorial(n)=n!. For non-integers, factorial(a)=a! = G(a + 1). This calculates the Gamma function.\n        See also: 1/ comb 2/ perm \n        Ex1:factorial(4)\n        Ex2:factorial(1.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_943factorial = {"factorial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_943factorial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_942factorial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_943factorial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factorial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_942factorial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_942factorial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorial", 1);

  /* "giacpy/auto-methods.pxi":5916
 * 
 *         '''
 *         return GiacMethods['factorial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factoriser(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factorial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5916, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5906
 *         return GiacMethods['factor_xn'](self,*args)
 * 
 *      def factorial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factorial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factorial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5918
 *         return GiacMethods['factorial'](self,*args)
 * 
 *      def factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_945factoriser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_944factoriser, "From Giac's documentation:\n        Help for factoriser:\n        factoriser(Expr)\n        Factors a polynomial.\n        See also: 1/ ifactor 2/ cfactor 3/ partfrac 4/ normal \n        Ex1:factoriser(x^4-1)\n        Ex2:factoriser(x^4-4,sqrt(2))\n        Ex3:factoriser(x^4+12*x^3+54*x^2+108*x+81)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_945factoriser = {"factoriser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_945factoriser, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_944factoriser};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_945factoriser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factoriser (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factoriser", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_944factoriser(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_944factoriser(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factoriser", 1);

  /* "giacpy/auto-methods.pxi":5929
 * 
 *         '''
 *         return GiacMethods['factoriser'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factoriser_entier(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factoriser); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5929, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5918
 *         return GiacMethods['factorial'](self,*args)
 * 
 *      def factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factoriser", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5931
 *         return GiacMethods['factoriser'](self,*args)
 * 
 *      def factoriser_entier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_entier:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_947factoriser_entier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_946factoriser_entier, "From Giac's documentation:\n        Help for factoriser_entier:\n        factoriser_entier(Intg(a))\n        Factorization of an integer into prime factors.\n        See also: 1/ factor 2/ ecm_factor \n        Ex1:factoriser_entier(50)\n        Ex2:factoriser_entier(123456789)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_947factoriser_entier = {"factoriser_entier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_947factoriser_entier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_946factoriser_entier};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_947factoriser_entier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factoriser_entier (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factoriser_entier", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_946factoriser_entier(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_946factoriser_entier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factoriser_entier", 1);

  /* "giacpy/auto-methods.pxi":5941
 * 
 *         '''
 *         return GiacMethods['factoriser_entier'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factoriser_sur_C(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factoriser_entier); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5941, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5931
 *         return GiacMethods['factoriser'](self,*args)
 * 
 *      def factoriser_entier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_entier:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factoriser_entier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5943
 *         return GiacMethods['factoriser_entier'](self,*args)
 * 
 *      def factoriser_sur_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_sur_C:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_949factoriser_sur_C(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_948factoriser_sur_C, "From Giac's documentation:\n        Help for factoriser_sur_C:\n        factoriser_sur_C(Expr)\n        Factorization of the expression in \342\204\202 (on the Gaussian integers if there are more than 2 variables).\n        See also: 1/ factor \n        Ex1:factoriser_sur_C(x^2*y+y)\n        Ex2:factoriser_sur_C(x^2*y^2+y^2+4*x^2+4)\n        Ex3:factoriser_sur_C(x^2*y^2+y^2+2*x^2+2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_949factoriser_sur_C = {"factoriser_sur_C", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_949factoriser_sur_C, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_948factoriser_sur_C};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_949factoriser_sur_C(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factoriser_sur_C (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factoriser_sur_C", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_948factoriser_sur_C(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_948factoriser_sur_C(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factoriser_sur_C", 1);

  /* "giacpy/auto-methods.pxi":5954
 * 
 *         '''
 *         return GiacMethods['factoriser_sur_C'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def factors(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factoriser_sur_C); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5954, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5943
 *         return GiacMethods['factoriser_entier'](self,*args)
 * 
 *      def factoriser_sur_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_sur_C:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factoriser_sur_C", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5956
 *         return GiacMethods['factoriser_sur_C'](self,*args)
 * 
 *      def factors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factors:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_951factors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_950factors, "From Giac's documentation:\n        Help for factors:\n        factors(Poly or LstPoly)\n        Returns the list of prime factors of a polynomial (each factor is followed by its multiplicity).\n        See also: 1/ factor 2/ ifactors \n        Ex1:factors(x^4-1)\n        Ex2:factors([x^2,x^2-1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_951factors = {"factors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_951factors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_950factors};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_951factors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factors (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "factors", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_950factors(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_950factors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factors", 1);

  /* "giacpy/auto-methods.pxi":5966
 * 
 *         '''
 *         return GiacMethods['factors'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fadeev(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_factors); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5966, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5956
 *         return GiacMethods['factoriser_sur_C'](self,*args)
 * 
 *      def factors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factors:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.factors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5968
 *         return GiacMethods['factors'](self,*args)
 * 
 *      def fadeev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fadeev:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_953fadeev(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_952fadeev, "From Giac's documentation:\n        Help for fadeev:\n        fadeev(Opt)\n        Option of the pcar or charpoly command to specify the algorithm.\n        See also: 1/ pcar \n        Ex1: pcar([[4,1,-2],[1,2,-1],[2,1,0]],fadeev)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_953fadeev = {"fadeev", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_953fadeev, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_952fadeev};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_953fadeev(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fadeev (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fadeev", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_952fadeev(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_952fadeev(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fadeev", 1);

  /* "giacpy/auto-methods.pxi":5977
 * 
 *         '''
 *         return GiacMethods['fadeev'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def false(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fadeev); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5977, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5968
 *         return GiacMethods['factors'](self,*args)
 * 
 *      def fadeev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fadeev:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fadeev", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5979
 *         return GiacMethods['fadeev'](self,*args)
 * 
 *      def false(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for false:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_955false(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_954false, "From Giac's documentation:\n        Help for false:\n        false()\n        Boolean equal to false or 0.\n        See also: 1/ true \n        Ex1: a:=false\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_955false = {"false", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_955false, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_954false};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_955false(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("false (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "false", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_954false(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_954false(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("false", 1);

  /* "giacpy/auto-methods.pxi":5988
 * 
 *         '''
 *         return GiacMethods['false'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def falsepos_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_false); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 5988, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5979
 *         return GiacMethods['fadeev'](self,*args)
 * 
 *      def false(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for false:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.false", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":5990
 *         return GiacMethods['false'](self,*args)
 * 
 *      def falsepos_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for falsepos_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_957falsepos_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_956falsepos_solver, "From Giac's documentation:\n        Help for falsepos_solver:\n        falsepos_solver(Opt)\n        Argument for fsolve giving the method for solving a numerical equation.\n        See also: 1/ fsolve \n        Ex1: fsolve(cos(x)=x,x,0..1,bisection_solver)\n        Ex2: fsolve(cos(x)=x,x,0..1,brent_solver)\n        Ex3: fsolve(cos(x)=x,x,0..1,falsepos_solver)\n        Ex4: fsolve(cos(x)=x,x,0,newton_solver)\n        Ex5: fsolve(cos(x)=x,x,0,secant_solver)\n        Ex6: fsolve(cos(x)=x,x,0,steffenson_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_957falsepos_solver = {"falsepos_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_957falsepos_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_956falsepos_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_957falsepos_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("falsepos_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "falsepos_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_956falsepos_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_956falsepos_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("falsepos_solver", 1);

  /* "giacpy/auto-methods.pxi":6004
 * 
 *         '''
 *         return GiacMethods['falsepos_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fclose(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_falsepos_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6004, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":5990
 *         return GiacMethods['false'](self,*args)
 * 
 *      def falsepos_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for falsepos_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.falsepos_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6006
 *         return GiacMethods['falsepos_solver'](self,*args)
 * 
 *      def fclose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fclose:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_959fclose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_958fclose, "From Giac's documentation:\n        Help for fclose:\n        fclose(File(f))\n        Closes the file f.\n        See also: 1/ fprint 2/ fopen \n        Ex1:fclose(f)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_959fclose = {"fclose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_959fclose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_958fclose};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_959fclose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fclose (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fclose", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_958fclose(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_958fclose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fclose", 1);

  /* "giacpy/auto-methods.pxi":6015
 * 
 *         '''
 *         return GiacMethods['fclose'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fcoeff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fclose); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6015, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6006
 *         return GiacMethods['falsepos_solver'](self,*args)
 * 
 *      def fclose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fclose:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fclose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6017
 *         return GiacMethods['fclose'](self,*args)
 * 
 *      def fcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fcoeff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_961fcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_960fcoeff, "From Giac's documentation:\n        Help for fcoeff:\n        fcoeff(Lst(root||pole,order))\n        Returns the polynomial described by the list (root or pole, order).\n        See also: 1/ pcoeff 2/ froot 3/ proot \n        Ex1:fcoeff([1,2,0,1,3,-1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_961fcoeff = {"fcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_961fcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_960fcoeff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_961fcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fcoeff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fcoeff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_960fcoeff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_960fcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fcoeff", 1);

  /* "giacpy/auto-methods.pxi":6026
 * 
 *         '''
 *         return GiacMethods['fcoeff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fdistrib(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fcoeff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6026, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6017
 *         return GiacMethods['fclose'](self,*args)
 * 
 *      def fcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fcoeff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fcoeff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6028
 *         return GiacMethods['fcoeff'](self,*args)
 * 
 *      def fdistrib(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fdistrib:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_963fdistrib(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_962fdistrib, "From Giac's documentation:\n        Help for fdistrib:\n        fdistrib(Expr)\n        Full distribution of * and / over + and -.\n        See also: 1/ texpand 2/ normal 3/ simplify 4/ ratnormal \n        Ex1:fdistrib((x+y)*(z+1))\n        Ex2:fdistrib((a+b+c)/d)\n        Ex3:fdistrib((y+x)*(z+y)*(x+z))\n        Ex4:fdistrib((x+3)^4)\n        Ex5:fdistrib((2*x-2*1)*(x^2-3*x+2)+(x^2-2*x+3)*(2*x-3*1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_963fdistrib = {"fdistrib", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_963fdistrib, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_962fdistrib};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_963fdistrib(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fdistrib (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fdistrib", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_962fdistrib(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_962fdistrib(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fdistrib", 1);

  /* "giacpy/auto-methods.pxi":6041
 * 
 *         '''
 *         return GiacMethods['fdistrib'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fft(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fdistrib); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6041, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6028
 *         return GiacMethods['fcoeff'](self,*args)
 * 
 *      def fdistrib(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fdistrib:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fdistrib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6043
 *         return GiacMethods['fdistrib'](self,*args)
 * 
 *      def fft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fft:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_965fft(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_964fft, "From Giac's documentation:\n        Help for fft:\n        fft(Vect or (Vect(L),Intg(a),Intg(p))\n        Fast Fourier Transform in \342\204\235 or in the field \342\204\244/p\342\204\244, with a as primitive n-th root of 1 (n=size(L)).\n        See also: 1/ ifft \n        Ex1:fft([1,2,3,4,0,0,0,0])\n        Ex2:fft(ranm(128),22798,35969)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_965fft = {"fft", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_965fft, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_964fft};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_965fft(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fft (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fft", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_964fft(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_964fft(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fft", 1);

  /* "giacpy/auto-methods.pxi":6053
 * 
 *         '''
 *         return GiacMethods['fft'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fieldplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fft); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6053, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6043
 *         return GiacMethods['fdistrib'](self,*args)
 * 
 *      def fft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fft:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fft", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6055
 *         return GiacMethods['fft'](self,*args)
 * 
 *      def fieldplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fieldplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_967fieldplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_966fieldplot, "From Giac's documentation:\n        Help for fieldplot:\n        fieldplot(Expr,VectVar,[Opt])\n        plotfield(f(t,y),[t,y]) draws the plotfield of the diff equation y'=f(t,y).\n        See also: 1/ interactive_plotode 2/ odeplot 3/ odesolve 4/ desolve \n        Ex1:fieldplot(sin(t*y),[t=-5..5,y=-3..3],xstep=0.5,ystep=0.5)\n        Ex2:fieldplot(-t*y,[t,y])\n        Ex3:fieldplot(-t*y,[t,y],normalize)\n        Ex4:fieldplot(-t*y,[t,y],normalize,xstep=0.5,ystep=0.5)\n        Ex5:fieldplot(-t*y,[t=-6.868..6.868,y=-6.868..6.868],normalize)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_967fieldplot = {"fieldplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_967fieldplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_966fieldplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_967fieldplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fieldplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fieldplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_966fieldplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_966fieldplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fieldplot", 1);

  /* "giacpy/auto-methods.pxi":6068
 * 
 *         '''
 *         return GiacMethods['fieldplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def find(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fieldplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6068, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6055
 *         return GiacMethods['fft'](self,*args)
 * 
 *      def fieldplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fieldplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fieldplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6070
 *         return GiacMethods['fieldplot'](self,*args)
 * 
 *      def find(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_969find(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_968find, "From Giac's documentation:\n        Help for find:\n        find(Expr,Vect)\n        List of positions of an object in a list, a string or a set.\n        See also: 1/ index 2/ member \n        Ex1:find(1,[3,x,1,2,1,3])\n        Ex2:find(2,[0,1,3,2,4,2,5])[0]\n        Ex3:find(\"a\",\"abracadabrant\")\n        Ex4:find(\"ab\",\"abracadabrant\")\n        Ex5:find(1,%{4,3,1,2%})\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_969find = {"find", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_969find, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_968find};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_969find(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "find", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_968find(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_968find(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find", 1);

  /* "giacpy/auto-methods.pxi":6083
 * 
 *         '''
 *         return GiacMethods['find'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def find_cliques(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_find); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6083, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6070
 *         return GiacMethods['fieldplot'](self,*args)
 * 
 *      def find(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.find", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6085
 *         return GiacMethods['find'](self,*args)
 * 
 *      def find_cliques(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cliques:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_971find_cliques(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_970find_cliques, "From Giac's documentation:\n        Help for find_cliques:\n        find_cliques(Graph(G),[Intg(k)||Intrv(m..n)])\n        Returns the list of numbers of maximal cliques of size s in an undirected graph G for each s. If parameter k is given, the number of k-cliques is returned. If an interval m..n is given, only cliques with size between m and n (inclusive) are counted (m also may be +infinity).\n        See also: 1/ maximum_clique 2/ clique_cover \n        Ex1:find_cliques(random_graph(50,0.5))\n        Ex2:find_cliques(random_graph(50,0.5),5)\n        Ex3:find_cliques(random_graph(50,0.5),3..5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_971find_cliques = {"find_cliques", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_971find_cliques, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_970find_cliques};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_971find_cliques(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_cliques (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "find_cliques", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_970find_cliques(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_970find_cliques(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_cliques", 1);

  /* "giacpy/auto-methods.pxi":6096
 * 
 *         '''
 *         return GiacMethods['find_cliques'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def find_cycles(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_find_cliques); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6096, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6085
 *         return GiacMethods['find'](self,*args)
 * 
 *      def find_cliques(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cliques:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.find_cliques", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6098
 *         return GiacMethods['find_cliques'](self,*args)
 * 
 *      def find_cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cycles:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_973find_cycles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_972find_cycles, "From Giac's documentation:\n        Help for find_cycles:\n        find_cycles(Graph(G,[length=k||l..u]))\n        Returns the list of elementary cycles of the digraph G. If option \"length\" is specified, only cycles of length k resp. of length between l and u are returned.\n        See also: 1/ is_acyclic 2/ cycle_basis \n        Ex1:find_cycles(digraph(%{[1,2],[1,3],[3,1],[1,4],[2,3],[4,3],[4,5],[5,3],[5,6],[7,6],[8,6],[8,7]%}))\n        Ex2:find_cycles(digraph(%{[1,2],[1,3],[3,1],[1,4],[2,3],[4,3],[4,5],[5,3],[5,6],[7,6],[8,6],[8,7]%}),length=3)\n        Ex3:find_cycles(digraph(%{[1,2],[1,3],[3,1],[1,4],[2,3],[4,3],[4,5],[5,3],[5,6],[7,6],[8,6],[8,7]%}),length=3..4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_973find_cycles = {"find_cycles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_973find_cycles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_972find_cycles};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_973find_cycles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_cycles (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "find_cycles", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_972find_cycles(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_972find_cycles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_cycles", 1);

  /* "giacpy/auto-methods.pxi":6109
 * 
 *         '''
 *         return GiacMethods['find_cycles'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def find_minimum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_find_cycles); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6109, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6098
 *         return GiacMethods['find_cliques'](self,*args)
 * 
 *      def find_cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cycles:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.find_cycles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6111
 *         return GiacMethods['find_cycles'](self,*args)
 * 
 *      def find_minimum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_minimum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_975find_minimum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_974find_minimum, "From Giac's documentation:\n        Help for find_minimum:\n        find_minimum((Expr||Func)(f),Real(a),Real(b),[Real(eps),Intg(maxiter)])\n        Returns the point of global minimum of continuous univariate function or expression f within segment [a,b].\n        See also: 1/ fMin 2/ minimize 3/ nlpsolve \n        Ex1:find_minimum(cosh(x),-1,1)\n        Ex2:find_minimum(cosh(x),-1,1,1e-5,20)\n        Ex3:find_minimum(Airy_Ai(x+sin(x))+cos(x^2),-5,5)\n        Ex4:find_minimum(besselJ(x,2)/Gamma(x+1)+(x+1)^sin(x),0,10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_975find_minimum = {"find_minimum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_975find_minimum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_974find_minimum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_975find_minimum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_minimum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "find_minimum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_974find_minimum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_974find_minimum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_minimum", 1);

  /* "giacpy/auto-methods.pxi":6123
 * 
 *         '''
 *         return GiacMethods['find_minimum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def find_vertex_cover(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_find_minimum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6123, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6111
 *         return GiacMethods['find_cycles'](self,*args)
 * 
 *      def find_minimum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_minimum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.find_minimum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6125
 *         return GiacMethods['find_minimum'](self,*args)
 * 
 *      def find_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_vertex_cover:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_977find_vertex_cover(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_976find_vertex_cover, "From Giac's documentation:\n        Help for find_vertex_cover:\n        find_vertex_cover(Graph(G),[Intg(k)])\n        Returns a list of (k) vertices which comprise a vertex cover in an undirected graph G.\n        See also: 1/ minimum_vertex_cover 2/ vertex_cover_number \n        Ex1:find_vertex_cover(complete_graph(3,4))\n        Ex2:find_vertex_cover(complete_graph(3,4),4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_977find_vertex_cover = {"find_vertex_cover", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_977find_vertex_cover, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_976find_vertex_cover};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_977find_vertex_cover(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_vertex_cover (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "find_vertex_cover", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_976find_vertex_cover(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_976find_vertex_cover(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_vertex_cover", 1);

  /* "giacpy/auto-methods.pxi":6135
 * 
 *         '''
 *         return GiacMethods['find_vertex_cover'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def findhelp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_find_vertex_cover); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6135, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6125
 *         return GiacMethods['find_minimum'](self,*args)
 * 
 *      def find_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_vertex_cover:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.find_vertex_cover", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6137
 *         return GiacMethods['find_vertex_cover'](self,*args)
 * 
 *      def findhelp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for findhelp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_979findhelp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_978findhelp, "From Giac's documentation:\n        Help for findhelp:\n        findhelp(Cmd)\n        Returns help about the command (if ? is infixed see when) .\n        See also: 1/ ifte 2/ when \n        Ex1:findhelp(ifactor)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_979findhelp = {"findhelp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_979findhelp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_978findhelp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_979findhelp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("findhelp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "findhelp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_978findhelp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_978findhelp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("findhelp", 1);

  /* "giacpy/auto-methods.pxi":6146
 * 
 *         '''
 *         return GiacMethods['findhelp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fisher(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_findhelp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6146, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6137
 *         return GiacMethods['find_vertex_cover'](self,*args)
 * 
 *      def findhelp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for findhelp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.findhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6148
 *         return GiacMethods['findhelp'](self,*args)
 * 
 *      def fisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_981fisher(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_980fisher, "From Giac's documentation:\n        Help for fisher:\n        fisher(Intg(n),Intg(m),Real(x0))\n        Returns the probability density of the Fisher-Snedecor law (n and m are the numbers of degrees of freedom).\n        See also: 1/ fisher_cdf 2/ fisher_icdf 3/ randvector 4/ ranm \n        Ex1:fisher(4,10,2.1)\n        Ex2:fisher(4,4,2.1)\n        Ex3: randvector(5,fisher,4,6)\n        Ex4: ranm(2,3,fisher,4,6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_981fisher = {"fisher", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_981fisher, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_980fisher};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_981fisher(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fisher (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fisher", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_980fisher(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_980fisher(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fisher", 1);

  /* "giacpy/auto-methods.pxi":6160
 * 
 *         '''
 *         return GiacMethods['fisher'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fisher_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fisher); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6160, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6148
 *         return GiacMethods['findhelp'](self,*args)
 * 
 *      def fisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fisher", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6162
 *         return GiacMethods['fisher'](self,*args)
 * 
 *      def fisher_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_983fisher_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_982fisher_cdf, "From Giac's documentation:\n        Help for fisher_cdf:\n        fisher_cdf(Intg(n),Intg(m),Real(x0))\n        Returns the probability that a Fisher-Snedecor random variable is less than x0 (n and m are the numbers of degrees of freedom).\n        See also: 1/ UTPF 2/ fisher_icdf 3/ fisherd \n        Ex1:fisher_cdf(4,4,2.1)\n        Ex2:fisher_cdf(4,10,3.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_983fisher_cdf = {"fisher_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_983fisher_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_982fisher_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_983fisher_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fisher_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fisher_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_982fisher_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_982fisher_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fisher_cdf", 1);

  /* "giacpy/auto-methods.pxi":6172
 * 
 *         '''
 *         return GiacMethods['fisher_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fisher_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fisher_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6172, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6162
 *         return GiacMethods['fisher'](self,*args)
 * 
 *      def fisher_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fisher_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6174
 *         return GiacMethods['fisher_cdf'](self,*args)
 * 
 *      def fisher_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_985fisher_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_984fisher_icdf, "From Giac's documentation:\n        Help for fisher_icdf:\n        fisher_icdf(Intg(n),Intg(m),Real(p))\n        Returns h such as the probability that a Fisher-Snedecor random variable is less than h is p (n and m are the numbers of degrees of freedom and 0<=p<=1).\n        See also: 1/ fisher_cdf 2/ fisherd \n        Ex1:fisher_icdf(4,10,0.95)\n        Ex2:fisher_icdf(4,10,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_985fisher_icdf = {"fisher_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_985fisher_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_984fisher_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_985fisher_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fisher_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fisher_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_984fisher_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_984fisher_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fisher_icdf", 1);

  /* "giacpy/auto-methods.pxi":6184
 * 
 *         '''
 *         return GiacMethods['fisher_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fisherd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fisher_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6184, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6174
 *         return GiacMethods['fisher_cdf'](self,*args)
 * 
 *      def fisher_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fisher_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6186
 *         return GiacMethods['fisher_icdf'](self,*args)
 * 
 *      def fisherd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_987fisherd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_986fisherd, "From Giac's documentation:\n        Help for fisherd:\n        fisherd(Intg(n),Intg(m),Real(x0))\n        Returns the probability density of the Fisher-Snedecor law (n and m are the numbers of degrees of freedom).\n        See also: 1/ fisher_cdf 2/ fisher_icdf 3/ randvector 4/ ranm \n        Ex1:fisherd(4,10,2.1)\n        Ex2:fisherd(4,4,2.1)\n        Ex3: randvector(5,fisher,4,6)\n        Ex4: ranm(2,3,fisher,4,6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_987fisherd = {"fisherd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_987fisherd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_986fisherd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_987fisherd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fisherd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fisherd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_986fisherd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_986fisherd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fisherd", 1);

  /* "giacpy/auto-methods.pxi":6198
 * 
 *         '''
 *         return GiacMethods['fisherd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fisherd_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fisherd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6198, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6186
 *         return GiacMethods['fisher_icdf'](self,*args)
 * 
 *      def fisherd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fisherd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6200
 *         return GiacMethods['fisherd'](self,*args)
 * 
 *      def fisherd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_989fisherd_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_988fisherd_cdf, "From Giac's documentation:\n        Help for fisherd_cdf:\n        fisherd_cdf(Intg(n),Intg(m),Real(x0))\n        Returns the probability that a Fisher-Snedecor random variable is less than x0 (n and m are the numbers of degrees of freedom).\n        See also: 1/ UTPF 2/ fisher_icdf 3/ fisherd \n        Ex1:fisherd_cdf(4,4,2.1)\n        Ex2:fisherd_cdf(4,10,3.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_989fisherd_cdf = {"fisherd_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_989fisherd_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_988fisherd_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_989fisherd_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fisherd_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fisherd_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_988fisherd_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_988fisherd_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fisherd_cdf", 1);

  /* "giacpy/auto-methods.pxi":6210
 * 
 *         '''
 *         return GiacMethods['fisherd_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fisherd_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fisherd_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6210, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6200
 *         return GiacMethods['fisherd'](self,*args)
 * 
 *      def fisherd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fisherd_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6212
 *         return GiacMethods['fisherd_cdf'](self,*args)
 * 
 *      def fisherd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_991fisherd_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_990fisherd_icdf, "From Giac's documentation:\n        Help for fisherd_icdf:\n        fisherd_icdf(Intg(n),Intg(m),Real(p))\n        Returns h such as the probability that a Fisher-Snedecor random variable is less than h is p (n and m are the numbers of degrees of freedom and 0<=p<=1).\n        See also: 1/ fisher_cdf 2/ fisherd \n        Ex1:fisherd_icdf(4,10,0.95)\n        Ex2:fisherd_icdf(4,10,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_991fisherd_icdf = {"fisherd_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_991fisherd_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_990fisherd_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_991fisherd_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fisherd_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fisherd_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_990fisherd_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_990fisherd_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fisherd_icdf", 1);

  /* "giacpy/auto-methods.pxi":6222
 * 
 *         '''
 *         return GiacMethods['fisherd_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fitdistr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fisherd_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6222, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6212
 *         return GiacMethods['fisherd_cdf'](self,*args)
 * 
 *      def fisherd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fisherd_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6224
 *         return GiacMethods['fisherd_icdf'](self,*args)
 * 
 *      def fitdistr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitdistr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_993fitdistr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_992fitdistr, "From Giac's documentation:\n        Help for fitdistr:\n        fitdistr(Lst(L),Fnc(D))\n        Returns the distribution of type D which fits most closely to the i.i.d. samples in the list L.\n        See also: 1/ normald 2/ poisson 3/ exponentiald 4/ geometric 5/ gammad 6/ betad 7/ cauchyd 8/ weibulld 9/ sample 10/ randvector 11/ randvar \n        Ex1:fitdistr(randvector(1000,weibulld,1/2,1),weibull)\n        Ex2: X:=randvar(normal,stddev=9.5):;Y:=randvar(normal,stddev=1.5):;S:=sample(eval(X/Y,0),1000):;Z:=fitdistr(S,cauchy)\n        Ex3: X:=randvar(normal,mean=5,variance=2):;S:=sample(exp(X),1000):;fitdistr(log(S),normal)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_993fitdistr = {"fitdistr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_993fitdistr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_992fitdistr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_993fitdistr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fitdistr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fitdistr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_992fitdistr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_992fitdistr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fitdistr", 1);

  /* "giacpy/auto-methods.pxi":6235
 * 
 *         '''
 *         return GiacMethods['fitdistr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fitpoly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fitdistr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6235, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6224
 *         return GiacMethods['fisherd_icdf'](self,*args)
 * 
 *      def fitdistr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitdistr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fitdistr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6237
 *         return GiacMethods['fitdistr'](self,*args)
 * 
 *      def fitpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitpoly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_995fitpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_994fitpoly, "From Giac's documentation:\n        Help for fitpoly:\n        fitpoly(Expr||Mtrx||Seq(Lst(x),Lst(y)),[Var[=Real(a)..Real(b)]],[Options])\n        Returns the polynomial of suitable degree which best fits the data or function in the sense of least squares.\n        See also: 1/ polynomial_regression 2/ minimax \n        Ex1:fitpoly(x*cos(x),x=0..pi/2)\n        Ex2: x:=[(k*0.1)$(k=0..10)]:;y:=[0.25,1.12,1.89,2.63,3.19,3.47,3.53,3.18,2.64,1.71,0.09]:;fitpoly(x,y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_995fitpoly = {"fitpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_995fitpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_994fitpoly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_995fitpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fitpoly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fitpoly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_994fitpoly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_994fitpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fitpoly", 1);

  /* "giacpy/auto-methods.pxi":6247
 * 
 *         '''
 *         return GiacMethods['fitpoly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fitspline(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fitpoly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6247, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6237
 *         return GiacMethods['fitdistr'](self,*args)
 * 
 *      def fitpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitpoly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fitpoly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6249
 *         return GiacMethods['fitpoly'](self,*args)
 * 
 *      def fitspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitspline:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_997fitspline(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_996fitspline, "From Giac's documentation:\n        Help for fitspline:\n        fitspline(Mtrx(data),(Var||Lst)(x),[opts])\n        Returns the B-spline which fits data most closely in the least-squares sense.\n        See also: 1/ bspline 2/ fitpoly \n        Ex1: t:=linspace(0,10,50):;x:=apply(u->(u^2*sin(u)+u-1)/(1+u*sqrt(u)),t):;y:=apply(u->(u^2*cos(u)-u+1)/(1+u*sqrt(u)),t):;listplot(fitspline(tran([t,x,y]),linspace(0,10,500))),scatterplot(x,y,color=blue)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_997fitspline = {"fitspline", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_997fitspline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_996fitspline};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_997fitspline(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fitspline (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fitspline", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_996fitspline(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_996fitspline(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fitspline", 1);

  /* "giacpy/auto-methods.pxi":6258
 * 
 *         '''
 *         return GiacMethods['fitspline'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def flatten(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fitspline); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6258, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6249
 *         return GiacMethods['fitpoly'](self,*args)
 * 
 *      def fitspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitspline:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fitspline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6260
 *         return GiacMethods['fitspline'](self,*args)
 * 
 *      def flatten(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flatten:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_999flatten(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_998flatten, "From Giac's documentation:\n        Help for flatten:\n        flatten(Lst||Image)\n        Recursively flatten a list containing lists or an image object.\n        See also: 1/ mat2list \n        Ex1:flatten([[1,[2,3],4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_999flatten = {"flatten", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_999flatten, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_998flatten};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_999flatten(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("flatten (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "flatten", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_998flatten(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_998flatten(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("flatten", 1);

  /* "giacpy/auto-methods.pxi":6269
 * 
 *         '''
 *         return GiacMethods['flatten'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def float2rational(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_flatten); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6269, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6260
 *         return GiacMethods['fitspline'](self,*args)
 * 
 *      def flatten(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flatten:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.flatten", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6271
 *         return GiacMethods['flatten'](self,*args)
 * 
 *      def float2rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for float2rational:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1001float2rational(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1000float2rational, "From Giac's documentation:\n        Help for float2rational:\n        float2rational(Expr)\n        Converts the expression to a rational or real expression.\n        See also: 1/  \n        Ex1:float2rational(-2)\n        Ex2:float2rational(1.5)\n        Ex3:float2rational(1.4141)\n        Ex4:float2rational(0.156381102937)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1001float2rational = {"float2rational", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1001float2rational, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1000float2rational};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1001float2rational(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("float2rational (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "float2rational", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1000float2rational(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1000float2rational(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("float2rational", 1);

  /* "giacpy/auto-methods.pxi":6283
 * 
 *         '''
 *         return GiacMethods['float2rational'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def floor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_float2rational); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6283, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6271
 *         return GiacMethods['flatten'](self,*args)
 * 
 *      def float2rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for float2rational:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.float2rational", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6285
 *         return GiacMethods['float2rational'](self,*args)
 * 
 *      def floor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for floor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1003floor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1002floor, "From Giac's documentation:\n        Help for floor:\n        floor(Real or Cplx)\n        Returns the greatest integer <= to the argument.\n        See also: 1/ round 2/ ceil 3/ iPart 4/ trunc \n        Ex1:floor(-2.5)\n        Ex2:floor(2.5-4.2*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1003floor = {"floor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1003floor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1002floor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1003floor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("floor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "floor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1002floor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1002floor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("floor", 1);

  /* "giacpy/auto-methods.pxi":6295
 * 
 *         '''
 *         return GiacMethods['floor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def flow_polynomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_floor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6295, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6285
 *         return GiacMethods['float2rational'](self,*args)
 * 
 *      def floor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for floor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.floor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6297
 *         return GiacMethods['floor'](self,*args)
 * 
 *      def flow_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flow_polynomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1005flow_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1004flow_polynomial, "From Giac's documentation:\n        Help for flow_polynomial:\n        flow_polynomial(Graph(G),[Var(x)])\n        Returns the flow polynomial [or its value at point x] of an undirected unweighted graph G.\n        See also: 1/ chromatic_polynomial 2/ reliability_polynomial 3/ tutte_polynomial \n        Ex1:flow_polynomial(graph(\"tetrahedron\"))\n        Ex2:flow_polynomial(graph(\"tetrahedron\"),5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1005flow_polynomial = {"flow_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1005flow_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1004flow_polynomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1005flow_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("flow_polynomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "flow_polynomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1004flow_polynomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1004flow_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("flow_polynomial", 1);

  /* "giacpy/auto-methods.pxi":6307
 * 
 *         '''
 *         return GiacMethods['flow_polynomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def flower_snark(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_flow_polynomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6307, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6297
 *         return GiacMethods['floor'](self,*args)
 * 
 *      def flow_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flow_polynomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.flow_polynomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6309
 *         return GiacMethods['flow_polynomial'](self,*args)
 * 
 *      def flower_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flower_snark:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1007flower_snark(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1006flower_snark, "From Giac's documentation:\n        Help for flower_snark:\n        flower_snark(Intg(n))\n        Returns the n-th flower snark, where n>2 is odd.\n        See also: 1/ goldberg_snark \n        Ex1:flower_snark(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1007flower_snark = {"flower_snark", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1007flower_snark, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1006flower_snark};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1007flower_snark(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("flower_snark (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "flower_snark", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1006flower_snark(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1006flower_snark(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("flower_snark", 1);

  /* "giacpy/auto-methods.pxi":6318
 * 
 *         '''
 *         return GiacMethods['flower_snark'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_flower_snark); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6318, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6309
 *         return GiacMethods['flow_polynomial'](self,*args)
 * 
 *      def flower_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flower_snark:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.flower_snark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6320
 *         return GiacMethods['flower_snark'](self,*args)
 * 
 *      def fmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1009fmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1008fmod, "From Giac's documentation:\n        Help for fmod:\n        fmod(Real(a),Real(b))\n        Returns a mod b for a and b floats.\n        See also: 1/ mod \n        Ex1:fmod(10.0,pi)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1009fmod = {"fmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1009fmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1008fmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1009fmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1008fmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1008fmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fmod", 1);

  /* "giacpy/auto-methods.pxi":6329
 * 
 *         '''
 *         return GiacMethods['fmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def foldl(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6329, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6320
 *         return GiacMethods['flower_snark'](self,*args)
 * 
 *      def fmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6331
 *         return GiacMethods['fmod'](self,*args)
 * 
 *      def foldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldl:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1011foldl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1010foldl, "From Giac's documentation:\n        Help for foldl:\n        foldl(op,id,Seq(r1,r2,...))\n        Returns the composition of the binary operator or function op, with an identity or initial value id onto its arguments r1, r2, ..., associating from the left.\n        See also: 1/ apply 2/ foldr 3/ map \n        Ex1:foldl(F,init,a,b,c)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1011foldl = {"foldl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1011foldl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1010foldl};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1011foldl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("foldl (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "foldl", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1010foldl(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1010foldl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("foldl", 1);

  /* "giacpy/auto-methods.pxi":6340
 * 
 *         '''
 *         return GiacMethods['foldl'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def foldr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_foldl); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6340, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6331
 *         return GiacMethods['fmod'](self,*args)
 * 
 *      def foldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldl:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.foldl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6342
 *         return GiacMethods['foldl'](self,*args)
 * 
 *      def foldr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1013foldr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1012foldr, "From Giac's documentation:\n        Help for foldr:\n        foldr(op,id,Seq(r1,r2,...))\n        Returns the composition of the binary operator or function op, with an identity or initial value id onto its arguments r1, r2, ..., associating from the right.\n        See also: 1/ apply 2/ foldl 3/ map \n        Ex1:foldr(F,init,a,b,c)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1013foldr = {"foldr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1013foldr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1012foldr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1013foldr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("foldr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "foldr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1012foldr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1012foldr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("foldr", 1);

  /* "giacpy/auto-methods.pxi":6351
 * 
 *         '''
 *         return GiacMethods['foldr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fonction_derivee(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_foldr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6351, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6342
 *         return GiacMethods['foldl'](self,*args)
 * 
 *      def foldr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.foldr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6353
 *         return GiacMethods['foldr'](self,*args)
 * 
 *      def fonction_derivee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fonction_derivee:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1015fonction_derivee(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1014fonction_derivee, "From Giac's documentation:\n        Help for fonction_derivee:\n        fonction_derivee(Fnc(f))\n        Returns the derivative function of the function f.\n        See also: 1/ diff 2/ ' 3/ @ \n        Ex1:fonction_derivee(sin+id)\n        Ex2:fonction_derivee(sq@sin+id)\n        Ex3:fonction_derivee(ln)(x,y)\n        Ex4:fonction_derivee(ln)([x,y])\n        Ex5: (function_diff @@3)(ln)('x') \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1015fonction_derivee = {"fonction_derivee", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1015fonction_derivee, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1014fonction_derivee};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1015fonction_derivee(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fonction_derivee (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fonction_derivee", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1014fonction_derivee(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1014fonction_derivee(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fonction_derivee", 1);

  /* "giacpy/auto-methods.pxi":6366
 * 
 *         '''
 *         return GiacMethods['fonction_derivee'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def forward(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fonction_derivee); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6366, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6353
 *         return GiacMethods['foldr'](self,*args)
 * 
 *      def fonction_derivee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fonction_derivee:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fonction_derivee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6368
 *         return GiacMethods['fonction_derivee'](self,*args)
 * 
 *      def forward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for forward:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1017forward(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1016forward, "From Giac's documentation:\n        Help for forward:\n        forward(NULL or Real(n))\n        The turtle takes n steps forward (by default n=10).\n        See also: 1/ recule 2/ saute \n        Ex1: avance 30\n        Ex2:forward(30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1017forward = {"forward", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1017forward, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1016forward};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1017forward(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("forward (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "forward", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1016forward(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1016forward(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("forward", 1);

  /* "giacpy/auto-methods.pxi":6378
 * 
 *         '''
 *         return GiacMethods['forward'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fourier(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_forward); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6378, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6368
 *         return GiacMethods['fonction_derivee'](self,*args)
 * 
 *      def forward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for forward:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.forward", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6380
 *         return GiacMethods['forward'](self,*args)
 * 
 *      def fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1019fourier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1018fourier, "From Giac's documentation:\n        Help for fourier:\n        fourier(Expr(f(x)),[Var(x),[Var(s)]])\n        Returns the Fourier transform F(s) of f(x).\n        See also: 1/ ifourier 2/ Fourier 3/ fourier_cn 4/ fft \n        Ex1:fourier(x/(x^3-19x+30),x,s)\n        Ex2:fourier(atan(t-4))\n        Ex3:fourier(BesselJ(3,x),x,s)\n        Ex4:fourier(sin(x)*sign(x),x,s)\n        Ex5:fourier(log(abs(x)),x,s)\n        Ex6:fourier(rect(x),x,s)\n        Ex7:fourier(piecewise(t<=-1,exp(t+1),t<=1,1,exp(2-2t)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1019fourier = {"fourier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1019fourier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1018fourier};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1019fourier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fourier (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fourier", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1018fourier(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1018fourier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fourier", 1);

  /* "giacpy/auto-methods.pxi":6395
 * 
 *         '''
 *         return GiacMethods['fourier'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fourier_an(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fourier); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6395, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6380
 *         return GiacMethods['forward'](self,*args)
 * 
 *      def fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fourier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6397
 *         return GiacMethods['fourier'](self,*args)
 * 
 *      def fourier_an(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_an:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1021fourier_an(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1020fourier_an, "From Giac's documentation:\n        Help for fourier_an:\n        fourier_an(Expr(f(x)),Var(x),Period(T),Intg(n),Real(a))\n        Returns the n-th Fourier coefficient an=2/T*integrate(f(x)*cos(2*pi*n*x/T),a,a+T).\n        See also: 1/ fourier_cn 2/ fourier_bn 3/ assume \n        Ex1:fourier_an(x^2,x,2,0,-1)\n        Ex2:fourier_an(x^2,x,2,n,-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1021fourier_an = {"fourier_an", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1021fourier_an, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1020fourier_an};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1021fourier_an(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fourier_an (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fourier_an", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1020fourier_an(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1020fourier_an(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fourier_an", 1);

  /* "giacpy/auto-methods.pxi":6407
 * 
 *         '''
 *         return GiacMethods['fourier_an'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fourier_bn(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fourier_an); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6407, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6397
 *         return GiacMethods['fourier'](self,*args)
 * 
 *      def fourier_an(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_an:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fourier_an", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6409
 *         return GiacMethods['fourier_an'](self,*args)
 * 
 *      def fourier_bn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_bn:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1023fourier_bn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1022fourier_bn, "From Giac's documentation:\n        Help for fourier_bn:\n        fourier_bn(Expr(f(x)),Var(x),Period(T),Intg(n),Real(a))\n        Returns the n-th Fourier coefficient bn=2/T*integrate(f(x)*sin(2*pi*n*x/T),a,a+T).\n        See also: 1/ fourier_cn 2/ fourier_an 3/ assume \n        Ex1:fourier_bn(x^2,x,2,0,-1)\n        Ex2:fourier_bn(x^2,x,2,n,-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1023fourier_bn = {"fourier_bn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1023fourier_bn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1022fourier_bn};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1023fourier_bn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fourier_bn (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fourier_bn", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1022fourier_bn(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1022fourier_bn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fourier_bn", 1);

  /* "giacpy/auto-methods.pxi":6419
 * 
 *         '''
 *         return GiacMethods['fourier_bn'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fourier_cn(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fourier_bn); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6419, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6409
 *         return GiacMethods['fourier_an'](self,*args)
 * 
 *      def fourier_bn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_bn:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fourier_bn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6421
 *         return GiacMethods['fourier_bn'](self,*args)
 * 
 *      def fourier_cn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_cn:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1025fourier_cn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1024fourier_cn, "From Giac's documentation:\n        Help for fourier_cn:\n        fourier_cn(Expr(f(x)),Var(x),Period(T),Intg(n),Real(a))\n        Returns the n-th Fourier coefficient cn=1/T*integrate(f(x)*exp(-2*i*pi*n*x/T),a,a+T).\n        See also: 1/ fourier_an 2/ fourier_bn 3/ assume \n        Ex1:fourier_cn(x^2,x,2,0,-1)\n        Ex2:fourier_cn(x^2,x,2,n,-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1025fourier_cn = {"fourier_cn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1025fourier_cn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1024fourier_cn};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1025fourier_cn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fourier_cn (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fourier_cn", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1024fourier_cn(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1024fourier_cn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fourier_cn", 1);

  /* "giacpy/auto-methods.pxi":6431
 * 
 *         '''
 *         return GiacMethods['fourier_cn'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fprint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fourier_cn); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6431, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6421
 *         return GiacMethods['fourier_bn'](self,*args)
 * 
 *      def fourier_cn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_cn:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fourier_cn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6433
 *         return GiacMethods['fourier_cn'](self,*args)
 * 
 *      def fprint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fprint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1027fprint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1026fprint, "From Giac's documentation:\n        Help for fprint:\n        fprint(File(f),Var,[Var,Var...])\n        Writes in the file f some data.\n        See also: 1/ fopen 2/ fclose \n        Ex1:fprint(f,x+1,\"2\")\n        Ex2:fprint(f,\"blabla\")\n        Ex3:fprint(f,Unquoted,\"blabla\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1027fprint = {"fprint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1027fprint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1026fprint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1027fprint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fprint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fprint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1026fprint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1026fprint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fprint", 1);

  /* "giacpy/auto-methods.pxi":6444
 * 
 *         '''
 *         return GiacMethods['fprint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def frac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fprint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6444, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6433
 *         return GiacMethods['fourier_cn'](self,*args)
 * 
 *      def fprint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fprint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fprint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6446
 *         return GiacMethods['fprint'](self,*args)
 * 
 *      def frac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1029frac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1028frac, "From Giac's documentation:\n        Help for frac:\n        frac(Real||LstReal)\n        Returns the fractional part (if x<0 then frac(x)+floor(x)+1=x else frac(x)+floor(x)=x).\n        See also: 1/ floor 2/ iPart 3/ trunc \n        Ex1:frac(1/2)\n        Ex2:frac(-1/2)\n        Ex3:frac(1.2)\n        Ex4:frac(-1.2)\n        Ex5:frac([3.4,sqrt(2)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1029frac = {"frac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1029frac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1028frac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1029frac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("frac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "frac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1028frac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1028frac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("frac", 1);

  /* "giacpy/auto-methods.pxi":6459
 * 
 *         '''
 *         return GiacMethods['frac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fracmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_frac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6459, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6446
 *         return GiacMethods['fprint'](self,*args)
 * 
 *      def frac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.frac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6461
 *         return GiacMethods['frac'](self,*args)
 * 
 *      def fracmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fracmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1031fracmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1030fracmod, "From Giac's documentation:\n        Help for fracmod:\n        fracmod(Expr(Xpr),Intg(n))\n        Returns the fraction a/b such as b*Xpr=a mod n, -sqrt(n)/2<a<=sqrt(n)/2 and 0<=b<sqrt(n)/2.\n        See also: 1/ mod 2/ smod \n        Ex1:fracmod(41,121)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1031fracmod = {"fracmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1031fracmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1030fracmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1031fracmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fracmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fracmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1030fracmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1030fracmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fracmod", 1);

  /* "giacpy/auto-methods.pxi":6470
 * 
 *         '''
 *         return GiacMethods['fracmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def frame_2d(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fracmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6470, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6461
 *         return GiacMethods['frac'](self,*args)
 * 
 *      def fracmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fracmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fracmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6472
 *         return GiacMethods['fracmod'](self,*args)
 * 
 *      def frame_2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frame_2d:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1033frame_2d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1032frame_2d, "From Giac's documentation:\n        Help for frame_2d:\n        frame_2d(NULL)\n        frame_2d() draws the axes of the 2-d graphic-screen.\n        See also: 1/ frame_3d 2/ Ox_2d_unit_vector 3/ Oy_2d_unit_vector \n        Ex1:frame_2d()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1033frame_2d = {"frame_2d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1033frame_2d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1032frame_2d};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1033frame_2d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("frame_2d (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "frame_2d", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1032frame_2d(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1032frame_2d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("frame_2d", 1);

  /* "giacpy/auto-methods.pxi":6481
 * 
 *         '''
 *         return GiacMethods['frame_2d'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def frank_wolfe(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_frame_2d); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6481, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6472
 *         return GiacMethods['fracmod'](self,*args)
 * 
 *      def frame_2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frame_2d:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.frame_2d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6483
 *         return GiacMethods['frame_2d'](self,*args)
 * 
 *      def frank_wolfe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frank_wolfe:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1035frank_wolfe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1034frank_wolfe, "From Giac's documentation:\n        Help for frank_wolfe:\n        frank_wolfe(Expr(f),Mtrx(A),[opts])\n        Returns a point in conv(A) which minimizes f, where A is a list of points.\n        See also: 1/ find_minimum 2/ nlpsolve 3/ fMin \n        Ex1:frank_wolfe((x1-2/3)^2/3+(x2-2/3)^2/5,[[1,0],[0,1],[-1,0],[0,-1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1035frank_wolfe = {"frank_wolfe", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1035frank_wolfe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1034frank_wolfe};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1035frank_wolfe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("frank_wolfe (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "frank_wolfe", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1034frank_wolfe(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1034frank_wolfe(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("frank_wolfe", 1);

  /* "giacpy/auto-methods.pxi":6492
 * 
 *         '''
 *         return GiacMethods['frank_wolfe'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def frequencies(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_frank_wolfe); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6492, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6483
 *         return GiacMethods['frame_2d'](self,*args)
 * 
 *      def frank_wolfe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frank_wolfe:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.frank_wolfe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6494
 *         return GiacMethods['frank_wolfe'](self,*args)
 * 
 *      def frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frequencies:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1037frequencies(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1036frequencies, "From Giac's documentation:\n        Help for frequencies:\n        frequencies(Lst)\n        Returns the frequencies of a list of values.\n        See also: 1/ histogram 2/ cumulated_frequencies 3/ bar_plot 4/ classes \n        Ex1:frequencies([1,2,1,1,2,1,2,4,3,3])\n        Ex2:frequencies([(rand(6)+1)$(k=1..100)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1037frequencies = {"frequencies", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1037frequencies, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1036frequencies};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1037frequencies(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("frequencies (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "frequencies", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1036frequencies(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1036frequencies(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("frequencies", 1);

  /* "giacpy/auto-methods.pxi":6504
 * 
 *         '''
 *         return GiacMethods['frequencies'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def frobenius_norm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_frequencies); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6504, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6494
 *         return GiacMethods['frank_wolfe'](self,*args)
 * 
 *      def frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frequencies:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.frequencies", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6506
 *         return GiacMethods['frequencies'](self,*args)
 * 
 *      def frobenius_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frobenius_norm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1039frobenius_norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1038frobenius_norm, "From Giac's documentation:\n        Help for frobenius_norm:\n        frobenius_norm(Mtrx)\n        Frobenius norm of a matrix A (=sqrt(sum |aij|^2)).\n        See also: 1/ l1norm 2/ l2 norm 3/ linfnorm 4/ matrix_norm \n        Ex1:frobenius_norm([[1,2,3],[3,-9,6],[4,5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1039frobenius_norm = {"frobenius_norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1039frobenius_norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1038frobenius_norm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1039frobenius_norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("frobenius_norm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "frobenius_norm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1038frobenius_norm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1038frobenius_norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("frobenius_norm", 1);

  /* "giacpy/auto-methods.pxi":6515
 * 
 *         '''
 *         return GiacMethods['frobenius_norm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def froot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_frobenius_norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6515, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6506
 *         return GiacMethods['frequencies'](self,*args)
 * 
 *      def frobenius_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frobenius_norm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.frobenius_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6517
 *         return GiacMethods['frobenius_norm'](self,*args)
 * 
 *      def froot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for froot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1041froot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1040froot, "From Giac's documentation:\n        Help for froot:\n        froot(RatPoly(F))\n        Returns the list of roots and poles of F with their multiplicity.\n        See also: 1/ proot 2/ fcoeff 3/ pcoeff 4/ realroot 5/ complexroot 6/ rationalroot 7/ crationalroot \n        Ex1:froot((x^5-2*x^4+x^3)/(x-3))\n        Ex2:froot((x^5-2*x^4+x^3)/(x-1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1041froot = {"froot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1041froot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1040froot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1041froot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("froot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "froot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1040froot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1040froot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("froot", 1);

  /* "giacpy/auto-methods.pxi":6527
 * 
 *         '''
 *         return GiacMethods['froot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_froot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6527, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6517
 *         return GiacMethods['frobenius_norm'](self,*args)
 * 
 *      def froot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for froot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.froot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6529
 *         return GiacMethods['froot'](self,*args)
 * 
 *      def fsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1043fsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1042fsolve, "From Giac's documentation:\n        Help for fsolve:\n        fsolve(Expr,Var,[Guess or Interval],[Method])\n        Numerical solution of an equation or a system of equations.\n        See also: 1/ cfsolve 2/ nSolve 3/ solve 4/ csolve 5/ lpsolve 6/ nlpsolve \n        Ex1:fsolve(cos(x)=x,x,-1..1,bisection_solver)\n        Ex2:fsolve(cos(x)=x,x,0,newton_solver)\n        Ex3:fsolve([x^2+y-2,x+y^2-2],[x,y],[0,0],newtonj_solver)\n        Ex4:fsolve([x^2+y-2,x+y^2-2],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1043fsolve = {"fsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1043fsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1042fsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1043fsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1042fsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1042fsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fsolve", 1);

  /* "giacpy/auto-methods.pxi":6541
 * 
 *         '''
 *         return GiacMethods['fsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fullparfrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6541, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6529
 *         return GiacMethods['froot'](self,*args)
 * 
 *      def fsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6543
 *         return GiacMethods['fsolve'](self,*args)
 * 
 *      def fullparfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fullparfrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1045fullparfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1044fullparfrac, "From Giac's documentation:\n        Help for fullparfrac:\n        fullparfrac(Opt)\n        Option of the convert or convertir command (id at the option partfrac).\n        See also: 1/ convert \n        Ex1: convert(1/(x^2-1),parfrac)\n        Ex2: convert(1/(x^2-1),fullparfrac)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1045fullparfrac = {"fullparfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1045fullparfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1044fullparfrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1045fullparfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fullparfrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fullparfrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1044fullparfrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1044fullparfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fullparfrac", 1);

  /* "giacpy/auto-methods.pxi":6553
 * 
 *         '''
 *         return GiacMethods['fullparfrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def funcplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fullparfrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6553, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6543
 *         return GiacMethods['fsolve'](self,*args)
 * 
 *      def fullparfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fullparfrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fullparfrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6555
 *         return GiacMethods['fullparfrac'](self,*args)
 * 
 *      def funcplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for funcplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1047funcplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1046funcplot, "From Giac's documentation:\n        Help for funcplot:\n        funcplot(Expr,[Var(x) or VectVar] ,[Intg(color)])\n        Plots a 1 variable or 2 variables expression with superposition.\n        See also: 1/ plot 2/ plot3d 3/ plotparam 4/ animate 5/ animate3d 6/ plotdensity \n        Ex1:funcplot(-2*x+1,x=1..2,color=red)\n        Ex2:funcplot([-2*x+1,x^2-2],x=-2..2,color=[red,yellow],xstep=0.2)\n        Ex3:funcplot(x^2-y^2,[x,y],xstep=0.5,ystep=0.3)\n        Ex4:funcplot(x^2+y^2,[x=-1..1,y=-2..2],nstep=900)\n        Ex5:funcplot((x+i*y)^2,[x=-1..1,y=-2..2],nstep=900,affichage=rempli)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1047funcplot = {"funcplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1047funcplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1046funcplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1047funcplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("funcplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "funcplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1046funcplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1046funcplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("funcplot", 1);

  /* "giacpy/auto-methods.pxi":6568
 * 
 *         '''
 *         return GiacMethods['funcplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def function_diff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_funcplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6568, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6555
 *         return GiacMethods['fullparfrac'](self,*args)
 * 
 *      def funcplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for funcplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.funcplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6570
 *         return GiacMethods['funcplot'](self,*args)
 * 
 *      def function_diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for function_diff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1049function_diff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1048function_diff, "From Giac's documentation:\n        Help for function_diff:\n        function_diff(Fnc(f))\n        Returns the derivative function of the function f.\n        See also: 1/ diff 2/ ' 3/ @ \n        Ex1:function_diff(sin+id)\n        Ex2:function_diff(sq@sin+id)\n        Ex3:function_diff(ln)(x,y)\n        Ex4:function_diff(ln)([x,y])\n        Ex5: (function_diff @@3)(ln)('x') \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1049function_diff = {"function_diff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1049function_diff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1048function_diff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1049function_diff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("function_diff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "function_diff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1048function_diff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1048function_diff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("function_diff", 1);

  /* "giacpy/auto-methods.pxi":6583
 * 
 *         '''
 *         return GiacMethods['function_diff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fundamental_cycle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_function_diff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6583, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6570
 *         return GiacMethods['funcplot'](self,*args)
 * 
 *      def function_diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for function_diff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.function_diff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6585
 *         return GiacMethods['function_diff'](self,*args)
 * 
 *      def fundamental_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fundamental_cycle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1051fundamental_cycle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1050fundamental_cycle, "From Giac's documentation:\n        Help for fundamental_cycle:\n        fundamental_cycle(Graph(G))\n        Returns the fundamental cycle of an unicyclic undirected connected graph G.\n        See also: 1/ cycle_basis 2/ find_cycles \n        Ex1:fundamental_cycle(graph(trail(1,2,3,4,5,2,6)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1051fundamental_cycle = {"fundamental_cycle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1051fundamental_cycle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1050fundamental_cycle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1051fundamental_cycle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fundamental_cycle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fundamental_cycle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1050fundamental_cycle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1050fundamental_cycle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fundamental_cycle", 1);

  /* "giacpy/auto-methods.pxi":6594
 * 
 *         '''
 *         return GiacMethods['fundamental_cycle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def fxnd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fundamental_cycle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6594, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6585
 *         return GiacMethods['function_diff'](self,*args)
 * 
 *      def fundamental_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fundamental_cycle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fundamental_cycle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6596
 *         return GiacMethods['fundamental_cycle'](self,*args)
 * 
 *      def fxnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fxnd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1053fxnd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1052fxnd, "From Giac's documentation:\n        Help for fxnd:\n        fxnd(Frac or RatFrac)\n        Returns the list built with the numerator and the denominator of the simplified fraction.\n        See also: 1/ simp2 2/ numer 3/ denom 4/ getNum 5/ getDenom \n        Ex1:fxnd(42/12)\n        Ex2:fxnd((x^2+2*x+1)/(x^2-1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1053fxnd = {"fxnd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1053fxnd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1052fxnd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1053fxnd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fxnd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "fxnd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1052fxnd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1052fxnd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fxnd", 1);

  /* "giacpy/auto-methods.pxi":6606
 * 
 *         '''
 *         return GiacMethods['fxnd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gammad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_fxnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6606, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6596
 *         return GiacMethods['fundamental_cycle'](self,*args)
 * 
 *      def fxnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fxnd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.fxnd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6608
 *         return GiacMethods['fxnd'](self,*args)
 * 
 *      def gammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1055gammad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1054gammad, "From Giac's documentation:\n        Help for gammad:\n        gammad(Real(a>0),Real(b>0),Real(x>=0))\n        Returns the probability density of the Gamma law (=x^(a-1)*exp(-b*x)*b^a/Gamma(a)).\n        See also: 1/ gammad_cdf; 2/ gammad_icdf \n        Ex1:gammad(2.2,1.5,0.8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1055gammad = {"gammad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1055gammad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1054gammad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1055gammad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gammad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gammad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1054gammad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1054gammad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gammad", 1);

  /* "giacpy/auto-methods.pxi":6617
 * 
 *         '''
 *         return GiacMethods['gammad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gammad_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gammad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6617, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6608
 *         return GiacMethods['fxnd'](self,*args)
 * 
 *      def gammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gammad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6619
 *         return GiacMethods['gammad'](self,*args)
 * 
 *      def gammad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1057gammad_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1056gammad_cdf, "From Giac's documentation:\n        Help for gammad_cdf:\n        gammad_cdf(Real(a>0),Real(b>0),Real(x0>=0),[Real(y0>=0)])\n        Returns the probability that a Gamma random variable (with a and b as parameters) is less than x0 or between x0 and y0.\n        See also: 1/ gammad 2/ gammad_icdf \n        Ex1:gammad_cdf(2,1,2.96)\n        Ex2:gammad_cdf(2,1,1.4,2.96)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1057gammad_cdf = {"gammad_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1057gammad_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1056gammad_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1057gammad_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gammad_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gammad_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1056gammad_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1056gammad_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gammad_cdf", 1);

  /* "giacpy/auto-methods.pxi":6629
 * 
 *         '''
 *         return GiacMethods['gammad_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gammad_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gammad_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6629, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6619
 *         return GiacMethods['gammad'](self,*args)
 * 
 *      def gammad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gammad_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6631
 *         return GiacMethods['gammad_cdf'](self,*args)
 * 
 *      def gammad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1059gammad_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1058gammad_icdf, "From Giac's documentation:\n        Help for gammad_icdf:\n        gammad_icdf(Real(a>0),Real(b>0),Real(0<=p<=1))\n        Returns h such that the probability that a Gamma random variable is less than h is p (0<=p<=1).\n        See also: 1/ gammad_cdf 2/ gammad \n        Ex1:gammad_icdf(2,1,0.95)\n        Ex2:gammad_icdf(2,1,0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1059gammad_icdf = {"gammad_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1059gammad_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1058gammad_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1059gammad_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gammad_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gammad_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1058gammad_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1058gammad_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gammad_icdf", 1);

  /* "giacpy/auto-methods.pxi":6641
 * 
 *         '''
 *         return GiacMethods['gammad_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gammavariate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gammad_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6641, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6631
 *         return GiacMethods['gammad_cdf'](self,*args)
 * 
 *      def gammad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gammad_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6643
 *         return GiacMethods['gammad_icdf'](self,*args)
 * 
 *      def gammavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammavariate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1061gammavariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1060gammavariate, "From Giac's documentation:\n        Help for gammavariate:\n        gammavariate(Real(a),Real(b))\n        Returns a random real according to the Gamma distribution with parameters a>0 and b>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:gammavariate(1,2)\n        Ex2:gammavariate(1.5,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1061gammavariate = {"gammavariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1061gammavariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1060gammavariate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1061gammavariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gammavariate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gammavariate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1060gammavariate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1060gammavariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gammavariate", 1);

  /* "giacpy/auto-methods.pxi":6653
 * 
 *         '''
 *         return GiacMethods['gammavariate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gauss(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gammavariate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6653, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6643
 *         return GiacMethods['gammad_icdf'](self,*args)
 * 
 *      def gammavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammavariate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gammavariate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6655
 *         return GiacMethods['gammavariate'](self,*args)
 * 
 *      def gauss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1063gauss(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1062gauss, "From Giac's documentation:\n        Help for gauss:\n        gauss(Expr,VectVar)\n        Splits a quadratic form as a sum/difference of squares.\n        See also: 1/ cholesky \n        Ex1:gauss(x^2+2*a*x*y,[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1063gauss = {"gauss", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1063gauss, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1062gauss};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1063gauss(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gauss (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gauss", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1062gauss(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1062gauss(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gauss", 1);

  /* "giacpy/auto-methods.pxi":6664
 * 
 *         '''
 *         return GiacMethods['gauss'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gauss15(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gauss); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6664, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6655
 *         return GiacMethods['gammavariate'](self,*args)
 * 
 *      def gauss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gauss", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6666
 *         return GiacMethods['gauss'](self,*args)
 * 
 *      def gauss15(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss15:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1065gauss15(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1064gauss15, "From Giac's documentation:\n        Help for gauss15:\n        gauss15(Opt)\n        Option of the area command.\n        See also: 1/ area \n        Ex1: area(x^2,x=0..1,5,simpson)\n        Ex2: area(x^2,x=0..1,5,rombergt)\n        Ex3: area(x^2,x=0..1,5,rombergm)\n        Ex4:gauss15(area(x^2,x=0..1,5,gauss15))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1065gauss15 = {"gauss15", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1065gauss15, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1064gauss15};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1065gauss15(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gauss15 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gauss15", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1064gauss15(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1064gauss15(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gauss15", 1);

  /* "giacpy/auto-methods.pxi":6678
 * 
 *         '''
 *         return GiacMethods['gauss15'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gauss_seidel_linsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gauss15); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6678, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6666
 *         return GiacMethods['gauss'](self,*args)
 * 
 *      def gauss15(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss15:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gauss15", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6680
 *         return GiacMethods['gauss15'](self,*args)
 * 
 *      def gauss_seidel_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss_seidel_linsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1067gauss_seidel_linsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1066gauss_seidel_linsolve, "From Giac's documentation:\n        Help for gauss_seidel_linsolve:\n        gauss_seidel_linsolve([Real(omega)],Mtrx(A),Vect(b),Real(eps),[Int(maxiter)])\n        Resolution of a linear system A*X=b by the iterative Gauss-Seidel method (by defaut omega=1) or by relaxation method, with eps as error margin and a number of iterations less than maxiter.\n        See also: 1/ jacobi_linsolve 2/ linsolve \n        Ex1: a:=[[100,2],[2,100]];gauss_seidel_linsolve(a,[0,1],1e-12);\n        Ex2: a:=[[100,2],[2,100]];gauss_seidel_linsolve(table(a),[0,1],1e-12); \n        Ex3: a:=[[100,2],[2,100]];gauss_seidel_linsolve(1.5,a,[0,1],1e-12);\n        Ex4: a:=[[100,2],[2,100]];gauss_seidel_linsolve(1.5,table(a),[0,1],1e-12); \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1067gauss_seidel_linsolve = {"gauss_seidel_linsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1067gauss_seidel_linsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1066gauss_seidel_linsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1067gauss_seidel_linsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gauss_seidel_linsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gauss_seidel_linsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1066gauss_seidel_linsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1066gauss_seidel_linsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gauss_seidel_linsolve", 1);

  /* "giacpy/auto-methods.pxi":6692
 * 
 *         '''
 *         return GiacMethods['gauss_seidel_linsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gaussian_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gauss_seidel_linsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6692, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6680
 *         return GiacMethods['gauss15'](self,*args)
 * 
 *      def gauss_seidel_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss_seidel_linsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gauss_seidel_linsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6694
 *         return GiacMethods['gauss_seidel_linsolve'](self,*args)
 * 
 *      def gaussian_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussian_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1069gaussian_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1068gaussian_window, "From Giac's documentation:\n        Help for gaussian_window:\n        gaussian_window(Lst,[Real(a)],[Interval(n1..n2)])\n        Applies the Gaussian windowing function with parameter 0<a<=0.5 (by default a=0.1) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ bartlett_hann_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(gaussian_window(randvector(1000,0..1),0.4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1069gaussian_window = {"gaussian_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1069gaussian_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1068gaussian_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1069gaussian_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gaussian_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gaussian_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1068gaussian_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1068gaussian_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gaussian_window", 1);

  /* "giacpy/auto-methods.pxi":6703
 * 
 *         '''
 *         return GiacMethods['gaussian_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gaussjord(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gaussian_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6703, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6694
 *         return GiacMethods['gauss_seidel_linsolve'](self,*args)
 * 
 *      def gaussian_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussian_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gaussian_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6705
 *         return GiacMethods['gaussian_window'](self,*args)
 * 
 *      def gaussjord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussjord:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1071gaussjord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1070gaussjord, "From Giac's documentation:\n        Help for gaussjord:\n        gaussjord(Mtrx(M),[Intg(k)]||Opt)\n        Row reduction to echelon form of AX=b (M=A|(-b)) [Reduction on columns 0..k-1].\n        See also: 1/ ker 2/ image 3/ det 4/ Rref 5/ pivot 6/ ref 7/ keep_pivot \n        Ex1:gaussjord([[3,1,-2],[3,2,2]])\n        Ex2:gaussjord([[2,1,1,-1],[1,1,2,-1],[1,2,1,-4]])\n        Ex3:gaussjord([[2,1,1,-1],[1,1,2,-1],[1,2,1,-4]],2)\n        Ex4:gaussjord([[1,1,0,0,-a1],[0,1,1,0,-a2],[0,0,1,1,-a3],[1,0,0,1,-a4]],keep_pivot)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1071gaussjord = {"gaussjord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1071gaussjord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1070gaussjord};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1071gaussjord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gaussjord (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gaussjord", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1070gaussjord(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1070gaussjord(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gaussjord", 1);

  /* "giacpy/auto-methods.pxi":6717
 * 
 *         '''
 *         return GiacMethods['gaussjord'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gaussquad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gaussjord); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6717, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6705
 *         return GiacMethods['gaussian_window'](self,*args)
 * 
 *      def gaussjord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussjord:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gaussjord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6719
 *         return GiacMethods['gaussjord'](self,*args)
 * 
 *      def gaussquad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussquad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1073gaussquad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1072gaussquad, "From Giac's documentation:\n        Help for gaussquad:\n        gaussquad(Expr(f(x)),Var(x),Real(a),Real(b))\n        Returns the approximate value of integrate(f(x),x,a,b) by adaptive Gaussian quadratures with 15 points.\n        See also: 1/ integrate 2/ romberg \n        Ex1:gaussquad(exp(x^2),x,0,1)\n        Ex2:gaussquad(x^2,x,0,1)\n        Ex3:gaussquad(exp(-x^2),x,-1,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1073gaussquad = {"gaussquad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1073gaussquad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1072gaussquad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1073gaussquad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gaussquad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gaussquad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1072gaussquad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1072gaussquad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gaussquad", 1);

  /* "giacpy/auto-methods.pxi":6730
 * 
 *         '''
 *         return GiacMethods['gaussquad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gbasis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gaussquad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6730, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6719
 *         return GiacMethods['gaussjord'](self,*args)
 * 
 *      def gaussquad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussquad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gaussquad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6732
 *         return GiacMethods['gaussquad'](self,*args)
 * 
 *      def gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1075gbasis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1074gbasis, "From Giac's documentation:\n        Help for gbasis:\n        gbasis(LstPoly,LstVar,[order])\n        Groebner basis of the ideal spanned by the list of polynomials. The optional rur argument may be used to compute a rational univariate representation.\n        See also: 1/ greduce 2/ gbasis_max_pairs 3/ gbasis_simult_primes \n        Ex1:gbasis([x^2-y^3,x+y^2],[x,y])\n        Ex2:gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3])\n        Ex3:gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3],tdeg)\n        Ex4:gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3],plex)\n        Ex5:gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1] mod 29,[x1,x2,x3])\n        Ex6:gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3],rur)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1075gbasis = {"gbasis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1075gbasis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1074gbasis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1075gbasis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gbasis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gbasis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1074gbasis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1074gbasis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gbasis", 1);

  /* "giacpy/auto-methods.pxi":6746
 * 
 *         '''
 *         return GiacMethods['gbasis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gbasis_max_pairs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gbasis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6746, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6732
 *         return GiacMethods['gaussquad'](self,*args)
 * 
 *      def gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gbasis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6748
 *         return GiacMethods['gbasis'](self,*args)
 * 
 *      def gbasis_max_pairs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_max_pairs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1077gbasis_max_pairs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1076gbasis_max_pairs, "From Giac's documentation:\n        Help for gbasis_max_pairs:\n        gbasis_max_pairs(Intg)\n        Gbasis fine-tuning: maximal number of S-pairs to be reduced simultaneously inside F4 algorithm (default 32768, 0 means no limit). Set it to a smaller value if short in memory.\n        See also: 1/ gbasis 2/ gbasis_simult_primes 3/ gbasis_reinject \n        Ex1:gbasis_max_pairs(4096)\n        Ex2:gbasis_max_pairs(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1077gbasis_max_pairs = {"gbasis_max_pairs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1077gbasis_max_pairs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1076gbasis_max_pairs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1077gbasis_max_pairs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gbasis_max_pairs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gbasis_max_pairs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1076gbasis_max_pairs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1076gbasis_max_pairs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gbasis_max_pairs", 1);

  /* "giacpy/auto-methods.pxi":6758
 * 
 *         '''
 *         return GiacMethods['gbasis_max_pairs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gbasis_reinject(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gbasis_max_pairs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6758, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6748
 *         return GiacMethods['gbasis'](self,*args)
 * 
 *      def gbasis_max_pairs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_max_pairs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gbasis_max_pairs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6760
 *         return GiacMethods['gbasis_max_pairs'](self,*args)
 * 
 *      def gbasis_reinject(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_reinject:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1079gbasis_reinject(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1078gbasis_reinject, "From Giac's documentation:\n        Help for gbasis_reinject:\n        gbasis_reinject(Real(a),[Real(b)])\n        Gbasis fine-tuning: in the modular algorithm of a gbasis over Q, adds a partial reconstruction of the basis if the ratio of new elements is greater than a and the speed ratio of the 2nd run/1st run is >= b (default a=0.2 and b=1/6.)\n        See also: 1/ gbasis 2/ gbasis_max_pairs 3/ gbasis_reinject  \n        Ex1:gbasis_reinject(0.1)\n        Ex2:gbasis_reinject(0.1,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1079gbasis_reinject = {"gbasis_reinject", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1079gbasis_reinject, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1078gbasis_reinject};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1079gbasis_reinject(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gbasis_reinject (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gbasis_reinject", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1078gbasis_reinject(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1078gbasis_reinject(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gbasis_reinject", 1);

  /* "giacpy/auto-methods.pxi":6770
 * 
 *         '''
 *         return GiacMethods['gbasis_reinject'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gbasis_simult_primes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gbasis_reinject); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6770, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6760
 *         return GiacMethods['gbasis_max_pairs'](self,*args)
 * 
 *      def gbasis_reinject(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_reinject:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gbasis_reinject", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6772
 *         return GiacMethods['gbasis_reinject'](self,*args)
 * 
 *      def gbasis_simult_primes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_simult_primes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1081gbasis_simult_primes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1080gbasis_simult_primes, "From Giac's documentation:\n        Help for gbasis_simult_primes:\n        gbasis_simult_primes(Intg)\n        Gbasis fine-tuning: maximal number of Groebner basis modulo a prime that are computed simultaneously to rebuild a Groebner basis over Q (default 16). Set it to a smaller value if short in memory.\n        See also: 1/ gbasis 2/ gbasis_max_pairs 3/ gbasis_reinject  \n        Ex1:gbasis_simult_primes(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1081gbasis_simult_primes = {"gbasis_simult_primes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1081gbasis_simult_primes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1080gbasis_simult_primes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1081gbasis_simult_primes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gbasis_simult_primes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gbasis_simult_primes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1080gbasis_simult_primes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1080gbasis_simult_primes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gbasis_simult_primes", 1);

  /* "giacpy/auto-methods.pxi":6781
 * 
 *         '''
 *         return GiacMethods['gbasis_simult_primes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gbasis_simult_primes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6781, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6772
 *         return GiacMethods['gbasis_reinject'](self,*args)
 * 
 *      def gbasis_simult_primes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_simult_primes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gbasis_simult_primes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6783
 *         return GiacMethods['gbasis_simult_primes'](self,*args)
 * 
 *      def gcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1083gcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1082gcd, "From Giac's documentation:\n        Help for gcd:\n        gcd((Intg(a) or Poly),(Intg(b) or Poly))\n        Returns the greatest common divisor of 2 polynomials of several variables or of 2 integers or of 2 rationals.\n        See also: 1/ lcm 2/ euler 2/ modgcd 3/ ezgcd 4/ psrgcd 5/ heugcd 6/ Gcd \n        Ex1:gcd(45,75)\n        Ex2:gcd(15/7,50/9)\n        Ex3:gcd(x^2-2*x+1,x^3-1)\n        Ex4:gcd(t^2-2*t+1,t^2+t-2)\n        Ex5:gcd((x^2-1)*(y^2-1)*z^2,x^3*y^3*z+(-(y^3))*z+x^3*z-z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1083gcd = {"gcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1083gcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1082gcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1083gcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1082gcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1082gcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gcd", 1);

  /* "giacpy/auto-methods.pxi":6796
 * 
 *         '''
 *         return GiacMethods['gcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gcdex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6796, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6783
 *         return GiacMethods['gbasis_simult_primes'](self,*args)
 * 
 *      def gcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6798
 *         return GiacMethods['gcd'](self,*args)
 * 
 *      def gcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcdex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1085gcdex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1084gcdex, "From Giac's documentation:\n        Help for gcdex:\n        gcdex((Poly or Lst),(Poly or Lst),[Var])\n        Extended greatest common divisor of 2 polynomials.\n        See also: 1/ gcd 2/ iegcd \n        Ex1:gcdex((x-1)^2,x^3-1)\n        Ex2:gcdex((X-1)^2,X^3-1,X)\n        Ex3:gcdex([1,-2,1],[1,0,0,-1])\n        Ex4:gcdex([1,-2,1],[1,-1,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1085gcdex = {"gcdex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1085gcdex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1084gcdex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1085gcdex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gcdex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gcdex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1084gcdex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1084gcdex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gcdex", 1);

  /* "giacpy/auto-methods.pxi":6810
 * 
 *         '''
 *         return GiacMethods['gcdex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def genpoly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gcdex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6810, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6798
 *         return GiacMethods['gcd'](self,*args)
 * 
 *      def gcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcdex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gcdex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6812
 *         return GiacMethods['gcdex'](self,*args)
 * 
 *      def genpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for genpoly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1087genpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1086genpoly, "From Giac's documentation:\n        Help for genpoly:\n        genpoly(Poly(P),Intg(b),Var)\n        Returns the reconstruction of a n-variables polynomial Q(-b/2<=coef<=b/2) from an (n-1)-variable polynomial P and a base b (subst(Q,var=b)=P).\n        See also: 1/  \n        Ex1:genpoly(15,4,x)\n        Ex2:genpoly(7*y+5,6,x)\n        Ex3:genpoly(7*y-5*z,10,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1087genpoly = {"genpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1087genpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1086genpoly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1087genpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genpoly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "genpoly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1086genpoly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1086genpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genpoly", 1);

  /* "giacpy/auto-methods.pxi":6823
 * 
 *         '''
 *         return GiacMethods['genpoly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def geodetic2ecef(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_genpoly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6823, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6812
 *         return GiacMethods['gcdex'](self,*args)
 * 
 *      def genpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for genpoly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.genpoly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6825
 *         return GiacMethods['genpoly'](self,*args)
 * 
 *      def geodetic2ecef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geodetic2ecef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1089geodetic2ecef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1088geodetic2ecef, "From Giac's documentation:\n        Help for geodetic2ecef:\n        geodetic2ecef(Real(latitude),Real(longitude),Real(height))\n        Converts geodetic LLA coordinates to ECEF (WGS84 standard).\n        See also: 1/ ecef2geodetic \n        Ex1:geodetic2ecef(45.174536,17.584637,89.462)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1089geodetic2ecef = {"geodetic2ecef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1089geodetic2ecef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1088geodetic2ecef};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1089geodetic2ecef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("geodetic2ecef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "geodetic2ecef", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1088geodetic2ecef(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1088geodetic2ecef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("geodetic2ecef", 1);

  /* "giacpy/auto-methods.pxi":6834
 * 
 *         '''
 *         return GiacMethods['geodetic2ecef'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def geometric(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_geodetic2ecef); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6834, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6825
 *         return GiacMethods['genpoly'](self,*args)
 * 
 *      def geodetic2ecef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geodetic2ecef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.geodetic2ecef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6836
 *         return GiacMethods['geodetic2ecef'](self,*args)
 * 
 *      def geometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1091geometric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1090geometric, "From Giac's documentation:\n        Help for geometric:\n        geometric(Real(p),Intg(k))\n        Returns the value at k of the geometric law with parameter p (0<p<1).\n        See also: 1/ geometric_cdf 2/ geometric_icdf 3/ randvector 4/ ranm \n        Ex1:geometric(0.3,4)\n        Ex2:geometric(0.5,5)\n        Ex3: randvector(3,geometric,0.3)\n        Ex4: ranm(4,3,geometric,0.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1091geometric = {"geometric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1091geometric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1090geometric};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1091geometric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("geometric (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "geometric", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1090geometric(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1090geometric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("geometric", 1);

  /* "giacpy/auto-methods.pxi":6848
 * 
 *         '''
 *         return GiacMethods['geometric'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def geometric_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_geometric); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6848, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6836
 *         return GiacMethods['geodetic2ecef'](self,*args)
 * 
 *      def geometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.geometric", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6850
 *         return GiacMethods['geometric'](self,*args)
 * 
 *      def geometric_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1093geometric_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1092geometric_cdf, "From Giac's documentation:\n        Help for geometric_cdf:\n        geometric_cdf(Real(p),Intg(k),[Intg(m)])\n        Returns the probability that a geometric random variable of parameter p (0<p<1) is less than k (or between k and m).\n        See also: 1/ geometric 2/ geometric_icdf \n        Ex1:geometric_cdf(0.3,4)\n        Ex2:geometric_cdf(0.3,4,5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1093geometric_cdf = {"geometric_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1093geometric_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1092geometric_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1093geometric_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("geometric_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "geometric_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1092geometric_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1092geometric_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("geometric_cdf", 1);

  /* "giacpy/auto-methods.pxi":6860
 * 
 *         '''
 *         return GiacMethods['geometric_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def geometric_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_geometric_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6860, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6850
 *         return GiacMethods['geometric'](self,*args)
 * 
 *      def geometric_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.geometric_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6862
 *         return GiacMethods['geometric_cdf'](self,*args)
 * 
 *      def geometric_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1095geometric_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1094geometric_icdf, "From Giac's documentation:\n        Help for geometric_icdf:\n        geometric_icdf(Real(p),Real(x))\n        Returns h such that the probability that a geometric random variable with parameter p (0<p<1) is less than h is x (0<=x<=1).\n        See also: 1/ geometric_cdf 2/ geometric \n        Ex1:geometric_icdf(0.3,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1095geometric_icdf = {"geometric_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1095geometric_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1094geometric_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1095geometric_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("geometric_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "geometric_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1094geometric_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1094geometric_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("geometric_icdf", 1);

  /* "giacpy/auto-methods.pxi":6871
 * 
 *         '''
 *         return GiacMethods['geometric_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def getDenom(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_geometric_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6871, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6862
 *         return GiacMethods['geometric_cdf'](self,*args)
 * 
 *      def geometric_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.geometric_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6873
 *         return GiacMethods['geometric_icdf'](self,*args)
 * 
 *      def getDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getDenom:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1097getDenom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1096getDenom, "From Giac's documentation:\n        Help for getDenom:\n        getDenom(Expr)\n        Returns the denominator of the unsimplified expression (except for rational number).\n        See also: 1/ denom 2/ getNum 3/ numer 4/ f2nd \n        Ex1:getDenom(25/15)\n        Ex2:getDenom((x^3-1)/(x^2-1))\n        Ex3:getDenom(1+(x^3-1)/x^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1097getDenom = {"getDenom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1097getDenom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1096getDenom};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1097getDenom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDenom (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "getDenom", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1096getDenom(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1096getDenom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDenom", 1);

  /* "giacpy/auto-methods.pxi":6884
 * 
 *         '''
 *         return GiacMethods['getDenom'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def getKey(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_getDenom); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6884, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6873
 *         return GiacMethods['geometric_icdf'](self,*args)
 * 
 *      def getDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getDenom:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.getDenom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6886
 *         return GiacMethods['getDenom'](self,*args)
 * 
 *      def getKey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getKey:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1099getKey(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1098getKey, "From Giac's documentation:\n        Help for getKey:\n        getKey(NULL)\n        Instruction in a program, returns 0 if no key is pressed and otherwise returns the ascii code of the pressed key.\n        See also: 1/ getType \n        Ex1:getKey()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1099getKey = {"getKey", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1099getKey, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1098getKey};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1099getKey(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getKey (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "getKey", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1098getKey(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1098getKey(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getKey", 1);

  /* "giacpy/auto-methods.pxi":6895
 * 
 *         '''
 *         return GiacMethods['getKey'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def getNum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_getKey); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6895, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6886
 *         return GiacMethods['getDenom'](self,*args)
 * 
 *      def getKey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getKey:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.getKey", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6897
 *         return GiacMethods['getKey'](self,*args)
 * 
 *      def getNum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getNum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1101getNum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1100getNum, "From Giac's documentation:\n        Help for getNum:\n        getNum(Expr)\n        Returns the numerator of the unsimplified expression (except for rational number).\n        See also: 1/ numer 2/ denom 3/ getDenom 4/ f2nd \n        Ex1:getNum(25/15)\n        Ex2:getNum((x^3-1)/(x^2-1))\n        Ex3:getNum(1+(x^3-1)/x^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1101getNum = {"getNum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1101getNum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1100getNum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1101getNum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "getNum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1100getNum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1100getNum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNum", 1);

  /* "giacpy/auto-methods.pxi":6908
 * 
 *         '''
 *         return GiacMethods['getNum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def getType(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_getNum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6908, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6897
 *         return GiacMethods['getKey'](self,*args)
 * 
 *      def getNum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getNum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.getNum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6910
 *         return GiacMethods['getNum'](self,*args)
 * 
 *      def getType(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getType:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1103getType(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1102getType, "From Giac's documentation:\n        Help for getType:\n        getType(Expr)\n        Returns the type of the argument (STR,EXPR,FUNC,NUM,LIST,MAT,VAR,NONE,PIC...).\n        See also: 1/ getKey \n        Ex1:getType(\"aze\")\n        Ex2:getType(2+i)\n        Ex3:getType(x->cos(2*x))\n        Ex4:getType(1.414)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1103getType = {"getType", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1103getType, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1102getType};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1103getType(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getType (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "getType", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1102getType(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1102getType(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getType", 1);

  /* "giacpy/auto-methods.pxi":6922
 * 
 *         '''
 *         return GiacMethods['getType'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def get_edge_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_getType); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6922, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6910
 *         return GiacMethods['getNum'](self,*args)
 * 
 *      def getType(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getType:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.getType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6924
 *         return GiacMethods['getType'](self,*args)
 * 
 *      def get_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1105get_edge_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1104get_edge_attribute, "From Giac's documentation:\n        Help for get_edge_attribute:\n        get_edge_attribute(Graph(G),Edge(e),Seq(tag1=value1,tag2=value2,..))\n        Returns the attributes tag1, tag2, ... assigned to edge e in G as a sequence of the corresponding values.\n        See also: 1/ discard_edge_attribute 2/ set_edge_attribute 3/ list_edge_attributes \n        Ex1:get_edge_attribute(cycle_graph(3),[1,2],\"cost\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1105get_edge_attribute = {"get_edge_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1105get_edge_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1104get_edge_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1105get_edge_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_edge_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_edge_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1104get_edge_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1104get_edge_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_edge_attribute", 1);

  /* "giacpy/auto-methods.pxi":6933
 * 
 *         '''
 *         return GiacMethods['get_edge_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def get_edge_weight(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_get_edge_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6933, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6924
 *         return GiacMethods['getType'](self,*args)
 * 
 *      def get_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.get_edge_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6935
 *         return GiacMethods['get_edge_attribute'](self,*args)
 * 
 *      def get_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_weight:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1107get_edge_weight(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1106get_edge_weight, "From Giac's documentation:\n        Help for get_edge_weight:\n        get_edge_weight(Graph(G),Edge(e))\n        Returns the weight of the edge e in a weighted graph G.\n        See also: 1/ is_weighted 2/ make_weighted 3/ set_edge_weight 4/ weight_matrix \n        Ex1:get_edge_weight(graph(%{[[1,2],5],[[2,3],6]%}),[1,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1107get_edge_weight = {"get_edge_weight", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1107get_edge_weight, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1106get_edge_weight};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1107get_edge_weight(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_edge_weight (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_edge_weight", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1106get_edge_weight(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1106get_edge_weight(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_edge_weight", 1);

  /* "giacpy/auto-methods.pxi":6944
 * 
 *         '''
 *         return GiacMethods['get_edge_weight'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def get_graph_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_get_edge_weight); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6944, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6935
 *         return GiacMethods['get_edge_attribute'](self,*args)
 * 
 *      def get_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_weight:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.get_edge_weight", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6946
 *         return GiacMethods['get_edge_weight'](self,*args)
 * 
 *      def get_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_graph_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1109get_graph_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1108get_graph_attribute, "From Giac's documentation:\n        Help for get_graph_attribute:\n        get_graph_attribute(Graph(G),Seq(tag1=value1,tag2=value2,..))\n        Return the graph attributes tag1, tag2, ..., as a sequence of the corresponding values.\n        See also: 1/ discard_graph_attribute 2/ set_graph_attribute 3/ list_graph_attributes \n        Ex1:get_graph_attribute(cycle_graph(3),\"name\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1109get_graph_attribute = {"get_graph_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1109get_graph_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1108get_graph_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1109get_graph_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_graph_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_graph_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1108get_graph_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1108get_graph_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_graph_attribute", 1);

  /* "giacpy/auto-methods.pxi":6955
 * 
 *         '''
 *         return GiacMethods['get_graph_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def get_vertex_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_get_graph_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6955, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6946
 *         return GiacMethods['get_edge_weight'](self,*args)
 * 
 *      def get_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_graph_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.get_graph_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6957
 *         return GiacMethods['get_graph_attribute'](self,*args)
 * 
 *      def get_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_vertex_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1111get_vertex_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1110get_vertex_attribute, "From Giac's documentation:\n        Help for get_vertex_attribute:\n        get_vertex_attribute(Graph(G),Vrtx(v),Seq(tag1=value1,tag2=value2,..))\n        Returns the attributes tag1, tag2, ... assigned to the vertex v in G as a sequence of the corresponding values.\n        See also: 1/ discard_vertex_attribute 2/ set_vertex_attribute 3/ list_vertex_attributes \n        Ex1:get_vertex_attribute(cycle_graph(3),1,\"supply\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1111get_vertex_attribute = {"get_vertex_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1111get_vertex_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1110get_vertex_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1111get_vertex_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_vertex_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_vertex_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1110get_vertex_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1110get_vertex_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_vertex_attribute", 1);

  /* "giacpy/auto-methods.pxi":6966
 * 
 *         '''
 *         return GiacMethods['get_vertex_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def girth(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_get_vertex_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6966, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6957
 *         return GiacMethods['get_graph_attribute'](self,*args)
 * 
 *      def get_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_vertex_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.get_vertex_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6968
 *         return GiacMethods['get_vertex_attribute'](self,*args)
 * 
 *      def girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for girth:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1113girth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1112girth, "From Giac's documentation:\n        Help for girth:\n        girth(Graph(G))\n        Returns the length of a shortest cycle in an undirected unweighted graph G.\n        See also: 1/ odd_girth \n        Ex1:girth(graph(\"petersen\"))\n        Ex2:girth(hypercube_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1113girth = {"girth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1113girth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1112girth};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1113girth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("girth (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "girth", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1112girth(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1112girth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("girth", 1);

  /* "giacpy/auto-methods.pxi":6978
 * 
 *         '''
 *         return GiacMethods['girth'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gl_showaxes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_girth); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6978, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6968
 *         return GiacMethods['get_vertex_attribute'](self,*args)
 * 
 *      def girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for girth:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.girth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6980
 *         return GiacMethods['girth'](self,*args)
 * 
 *      def gl_showaxes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gl_showaxes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1115gl_showaxes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1114gl_showaxes, "From Giac's documentation:\n        Help for gl_showaxes:\n        gl_showaxes(Opt=Boolean)\n        Option that shows or hides axes.\n        See also: 1/ switch_axes 2/ axes \n        Ex1: gl_showaxes=true;plot(sin(x))\n        Ex2: gl_showaxes=false;plot(sin(x)) \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1115gl_showaxes = {"gl_showaxes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1115gl_showaxes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1114gl_showaxes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1115gl_showaxes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gl_showaxes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gl_showaxes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1114gl_showaxes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1114gl_showaxes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gl_showaxes", 1);

  /* "giacpy/auto-methods.pxi":6990
 * 
 *         '''
 *         return GiacMethods['gl_showaxes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gold(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gl_showaxes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 6990, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6980
 *         return GiacMethods['girth'](self,*args)
 * 
 *      def gl_showaxes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gl_showaxes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gl_showaxes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":6992
 *         return GiacMethods['gl_showaxes'](self,*args)
 * 
 *      def gold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gold:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1117gold(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1116gold, "From Giac's documentation:\n        Help for gold:\n        gold(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1117gold = {"gold", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1117gold, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1116gold};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1117gold(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gold (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gold", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1116gold(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1116gold(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gold", 1);

  /* "giacpy/auto-methods.pxi":7002
 * 
 *         '''
 *         return GiacMethods['gold'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def goldberg_snark(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gold); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7002, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":6992
 *         return GiacMethods['gl_showaxes'](self,*args)
 * 
 *      def gold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gold:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gold", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7004
 *         return GiacMethods['gold'](self,*args)
 * 
 *      def goldberg_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for goldberg_snark:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1119goldberg_snark(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1118goldberg_snark, "From Giac's documentation:\n        Help for goldberg_snark:\n        goldberg_snark(Intg(n))\n        Returns the Goldberg snark on 8n vertices, where n>2 is odd.\n        See also: 1/ flower_snark \n        Ex1:goldberg_snark(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1119goldberg_snark = {"goldberg_snark", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1119goldberg_snark, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1118goldberg_snark};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1119goldberg_snark(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("goldberg_snark (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "goldberg_snark", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1118goldberg_snark(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1118goldberg_snark(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("goldberg_snark", 1);

  /* "giacpy/auto-methods.pxi":7013
 * 
 *         '''
 *         return GiacMethods['goldberg_snark'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def grad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_goldberg_snark); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7013, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7004
 *         return GiacMethods['gold'](self,*args)
 * 
 *      def goldberg_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for goldberg_snark:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.goldberg_snark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7015
 *         return GiacMethods['goldberg_snark'](self,*args)
 * 
 *      def grad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1121grad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1120grad, "From Giac's documentation:\n        Help for grad:\n        grad(Expr(Xpr),LstVar)\n        Returns the gradient of the expression Xpr.\n        See also: 1/ hessian \n        Ex1:grad(2*x^2*y-x*z^3,[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1121grad = {"grad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1121grad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1120grad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1121grad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("grad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "grad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1120grad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1120grad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("grad", 1);

  /* "giacpy/auto-methods.pxi":7024
 * 
 *         '''
 *         return GiacMethods['grad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def gramschmidt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_grad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7024, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7015
 *         return GiacMethods['goldberg_snark'](self,*args)
 * 
 *      def grad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.grad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7026
 *         return GiacMethods['grad'](self,*args)
 * 
 *      def gramschmidt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gramschmidt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1123gramschmidt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1122gramschmidt, "From Giac's documentation:\n        Help for gramschmidt:\n        gramschmidt(Basis(B),ScalarProd(Sp))\n        Returns an orthonormal basis of E with basis B for the scalar product Sp.\n        See also: 1/  \n        Ex1:gramschmidt(-2)\n        Ex2:gramschmidt([1,1+x],(p,q)->integrate(p*q,x,-1,1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1123gramschmidt = {"gramschmidt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1123gramschmidt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1122gramschmidt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1123gramschmidt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gramschmidt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gramschmidt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1122gramschmidt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1122gramschmidt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gramschmidt", 1);

  /* "giacpy/auto-methods.pxi":7036
 * 
 *         '''
 *         return GiacMethods['gramschmidt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_gramschmidt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7036, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7026
 *         return GiacMethods['grad'](self,*args)
 * 
 *      def gramschmidt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gramschmidt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.gramschmidt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7038
 *         return GiacMethods['gramschmidt'](self,*args)
 * 
 *      def graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1125graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1124graph, "From Giac's documentation:\n        Help for graph:\n        graph([Lst(V)],[Set(E)],[Mtrx(A)],[options])\n        Create an (un)directed (un)weighted graph from vertices V, edges E, and/or adjacency or weight matrix A. All parameters are optional.\n        See also: 1/ digraph 2/ trail \n        Ex1:graph(5)\n        Ex2:graph([a,b,c])\n        Ex3:graph([1,2,3],%{[1,2],[2,3],[3,1]%})\n        Ex4:graph(trail(1,2,3,4,1),directed=true)\n        Ex5:graph([a,b,c],[[0,2,0],[2,0,3],[0,3,0]])\n        Ex6:graph(\"petersen\")\n        Ex7:graph([[0,1,1,0],[1,0,0,1],[1,0,0,0],[0,1,0,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1125graph = {"graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1125graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1124graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1125graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1124graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1124graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph", 1);

  /* "giacpy/auto-methods.pxi":7053
 * 
 *         '''
 *         return GiacMethods['graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_automorphisms(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7053, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7038
 *         return GiacMethods['gramschmidt'](self,*args)
 * 
 *      def graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7055
 *         return GiacMethods['graph'](self,*args)
 * 
 *      def graph_automorphisms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_automorphisms:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1127graph_automorphisms(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1126graph_automorphisms, "From Giac's documentation:\n        Help for graph_automorphisms:\n        graph_automorphisms(Graph(G))\n        Returns the sequence of generators of Aut(G), the automorphism group of G. Each element is a permutation in the form of a list of disjoint cycles.\n        See also: 1/ cycles2permu 2/ isomorphic_copy 3/ permute_vertices \n        Ex1:graph_automorphisms(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1127graph_automorphisms = {"graph_automorphisms", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1127graph_automorphisms, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1126graph_automorphisms};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1127graph_automorphisms(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_automorphisms (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_automorphisms", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1126graph_automorphisms(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1126graph_automorphisms(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_automorphisms", 1);

  /* "giacpy/auto-methods.pxi":7064
 * 
 *         '''
 *         return GiacMethods['graph_automorphisms'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_charpoly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_automorphisms); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7064, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7055
 *         return GiacMethods['graph'](self,*args)
 * 
 *      def graph_automorphisms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_automorphisms:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_automorphisms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7066
 *         return GiacMethods['graph_automorphisms'](self,*args)
 * 
 *      def graph_charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_charpoly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1129graph_charpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1128graph_charpoly, "From Giac's documentation:\n        Help for graph_charpoly:\n        graph_charpoly(Graph(G),[Var(x)])\n        Returns the value p(x) of the characteristic polynomial p of G. If x is omitted, the list of coefficients of p is returned.\n        See also: 1/ graph_spectrum 2/ charpoly \n        Ex1:graph_charpoly(graph(%{[1,2],[2,3]%}))\n        Ex2:graph_charpoly(graph(\"shrikhande\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1129graph_charpoly = {"graph_charpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1129graph_charpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1128graph_charpoly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1129graph_charpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_charpoly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_charpoly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1128graph_charpoly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1128graph_charpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_charpoly", 1);

  /* "giacpy/auto-methods.pxi":7076
 * 
 *         '''
 *         return GiacMethods['graph_charpoly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_complement(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_charpoly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7076, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7066
 *         return GiacMethods['graph_automorphisms'](self,*args)
 * 
 *      def graph_charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_charpoly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_charpoly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7078
 *         return GiacMethods['graph_charpoly'](self,*args)
 * 
 *      def graph_complement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_complement:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1131graph_complement(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1130graph_complement, "From Giac's documentation:\n        Help for graph_complement:\n        graph_complement(Graph(G))\n        Return the graph with the same vertex set as in G, but whose edge (arc) set consists of the edges (arcs) not present in G.\n        See also: 1/ edges \n        Ex1:graph_complement(cycle_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1131graph_complement = {"graph_complement", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1131graph_complement, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1130graph_complement};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1131graph_complement(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_complement (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_complement", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1130graph_complement(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1130graph_complement(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_complement", 1);

  /* "giacpy/auto-methods.pxi":7087
 * 
 *         '''
 *         return GiacMethods['graph_complement'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_diameter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_complement); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7087, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7078
 *         return GiacMethods['graph_charpoly'](self,*args)
 * 
 *      def graph_complement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_complement:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_complement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7089
 *         return GiacMethods['graph_complement'](self,*args)
 * 
 *      def graph_diameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_diameter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1133graph_diameter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1132graph_diameter, "From Giac's documentation:\n        Help for graph_diameter:\n        graph_diameter(Graph(G))\n        Returns the maximum distance between a pair of vertices in G or +infinity if G is disconnected.\n        See also: 1/ allpairs_distance 2/ dijkstra 3/ shortest_path 4/ vertex_distance \n        Ex1:graph_diameter(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1133graph_diameter = {"graph_diameter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1133graph_diameter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1132graph_diameter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1133graph_diameter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_diameter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_diameter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1132graph_diameter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1132graph_diameter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_diameter", 1);

  /* "giacpy/auto-methods.pxi":7098
 * 
 *         '''
 *         return GiacMethods['graph_diameter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_equal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_diameter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7098, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7089
 *         return GiacMethods['graph_complement'](self,*args)
 * 
 *      def graph_diameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_diameter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_diameter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7100
 *         return GiacMethods['graph_diameter'](self,*args)
 * 
 *      def graph_equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_equal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1135graph_equal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1134graph_equal, "From Giac's documentation:\n        Help for graph_equal:\n        graph_equal(Graph(G1),Graph(G2))\n        Returns true iff input graphs G1 and G2 are equal, that is when the sets of vertices and edges of G1 and G2, as well as the orderings of vertices in both graphs, coincide. If the graphs are weighted (they must both be (un)weighted and (un)directed), weights given to the same edge in two graphs must be equal.\n        See also: 1/ edges 2/ graph_vertices \n        Ex1:graph_equal(graph([1,2,3],%{[1,2],[2,3],[3,1]%}),graph(trail(1,2,3,1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1135graph_equal = {"graph_equal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1135graph_equal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1134graph_equal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1135graph_equal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_equal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_equal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1134graph_equal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1134graph_equal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_equal", 1);

  /* "giacpy/auto-methods.pxi":7109
 * 
 *         '''
 *         return GiacMethods['graph_equal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_join(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_equal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7109, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7100
 *         return GiacMethods['graph_diameter'](self,*args)
 * 
 *      def graph_equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_equal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_equal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7111
 *         return GiacMethods['graph_equal'](self,*args)
 * 
 *      def graph_join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_join:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1137graph_join(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1136graph_join, "From Giac's documentation:\n        Help for graph_join:\n        graph_join(Graph(G),Graph(H))\n        Returns the graph obtained by connecting every vertex in G to every vertex in H. The vertex labels in the resulting graph are strings in the form \"1:u\" resp. \"2:v\", where u and v are vertices from G and H, respectively.\n        See also: 1/ disjoint_union 2/ graph_union \n        Ex1:graph_join(edges(graph_join(cycle_graph(3),graph(2))))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1137graph_join = {"graph_join", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1137graph_join, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1136graph_join};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1137graph_join(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_join (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_join", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1136graph_join(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1136graph_join(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_join", 1);

  /* "giacpy/auto-methods.pxi":7120
 * 
 *         '''
 *         return GiacMethods['graph_join'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_power(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_join); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7120, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7111
 *         return GiacMethods['graph_equal'](self,*args)
 * 
 *      def graph_join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_join:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_join", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7122
 *         return GiacMethods['graph_join'](self,*args)
 * 
 *      def graph_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_power:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1139graph_power(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1138graph_power, "From Giac's documentation:\n        Help for graph_power:\n        graph_power(Graph(G),Intg(k))\n        Returns the k-th power of G, where two vertices are connected iff there exists a path of length at most k in the original graph.\n        See also: 1/ adjacency matrix 2/ graph_diameter 3/ shortest_path \n        Ex1:graph_power(edges(graph_power(path_graph(5),3)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1139graph_power = {"graph_power", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1139graph_power, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1138graph_power};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1139graph_power(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_power (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_power", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1138graph_power(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1138graph_power(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_power", 1);

  /* "giacpy/auto-methods.pxi":7131
 * 
 *         '''
 *         return GiacMethods['graph_power'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_rank(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_power); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7131, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7122
 *         return GiacMethods['graph_join'](self,*args)
 * 
 *      def graph_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_power:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_power", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7133
 *         return GiacMethods['graph_power'](self,*args)
 * 
 *      def graph_rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_rank:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1141graph_rank(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1140graph_rank, "From Giac's documentation:\n        Help for graph_rank:\n        graph_rank(Graph(G),[Lst(E)])\n        Returns the graph rank of G. If an optional set E of edges is given, the rank of the spanning subgraph of G with edge set E is returned.\n        See also: 1/ connected_components 2/ number_of_vertices \n        Ex1:graph_rank(graph(%{[1,2],[3,4],[4,5]%}))\n        Ex2:graph_rank(graph(%{[1,2],[3,4],[4,5]%}),[[1,2],[3,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1141graph_rank = {"graph_rank", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1141graph_rank, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1140graph_rank};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1141graph_rank(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_rank (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_rank", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1140graph_rank(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1140graph_rank(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_rank", 1);

  /* "giacpy/auto-methods.pxi":7143
 * 
 *         '''
 *         return GiacMethods['graph_rank'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_spectrum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_rank); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7143, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7133
 *         return GiacMethods['graph_power'](self,*args)
 * 
 *      def graph_rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_rank:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_rank", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7145
 *         return GiacMethods['graph_rank'](self,*args)
 * 
 *      def graph_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_spectrum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1143graph_spectrum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1142graph_spectrum, "From Giac's documentation:\n        Help for graph_spectrum:\n        graph_spectrum(Graph(G))\n        Returns the graph spectrum of G as a list of lists with two elements, each containing an eigenvalue and its multiplicity.\n        See also: 1/ graph_charpoly 2/ seidel_spectrum 3/ is_integer_graph \n        Ex1:graph_spectrum(cycle_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1143graph_spectrum = {"graph_spectrum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1143graph_spectrum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1142graph_spectrum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1143graph_spectrum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_spectrum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_spectrum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1142graph_spectrum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1142graph_spectrum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_spectrum", 1);

  /* "giacpy/auto-methods.pxi":7154
 * 
 *         '''
 *         return GiacMethods['graph_spectrum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_union(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7145
 *         return GiacMethods['graph_rank'](self,*args)
 * 
 *      def graph_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_spectrum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_spectrum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7156
 *         return GiacMethods['graph_spectrum'](self,*args)
 * 
 *      def graph_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_union:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1145graph_union(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1144graph_union, "From Giac's documentation:\n        Help for graph_union:\n        graph_union(Seq(G1,G2,...))\n        Returns the union of graphs G1, G2, ... The set of vertices of the resulting graph is the union of the sets of vertices of the input graphs and the set of edges of the resulting graph is the union of sets of edges of the input graphs. If the input graphs are weighted, the weight of any common edge is the sum of the weights of that edge in G1, G2, ...\n        See also: 1/ disjoint_union 2/ graph_join \n        Ex1:graph_union(edges(graph_union(cycle_graph(4),path_graph(5))))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1145graph_union = {"graph_union", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1145graph_union, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1144graph_union};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1145graph_union(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_union (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_union", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1144graph_union(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1144graph_union(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_union", 1);

  /* "giacpy/auto-methods.pxi":7165
 * 
 *         '''
 *         return GiacMethods['graph_union'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def graph_vertices(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_union); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7165, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7156
 *         return GiacMethods['graph_spectrum'](self,*args)
 * 
 *      def graph_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_union:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_union", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7167
 *         return GiacMethods['graph_union'](self,*args)
 * 
 *      def graph_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_vertices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1147graph_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1146graph_vertices, "From Giac's documentation:\n        Help for graph_vertices:\n        graph_vertices(Graph(G))\n        Return the list of vertices in G.\n        See also: 1/ add_vertex 2/ graph 3/ neighbors 4/ permute_vertices 5/ relabel_vertices \n        Ex1:graph_vertices(graph(%{[a,c],[b,c],[a,b]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1147graph_vertices = {"graph_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1147graph_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1146graph_vertices};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1147graph_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("graph_vertices (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "graph_vertices", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1146graph_vertices(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1146graph_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("graph_vertices", 1);

  /* "giacpy/auto-methods.pxi":7176
 * 
 *         '''
 *         return GiacMethods['graph_vertices'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def greduce(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_graph_vertices); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7176, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7167
 *         return GiacMethods['graph_union'](self,*args)
 * 
 *      def graph_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_vertices:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.graph_vertices", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7178
 *         return GiacMethods['graph_vertices'](self,*args)
 * 
 *      def greduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greduce:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1149greduce(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1148greduce, "From Giac's documentation:\n        Help for greduce:\n        greduce(Poly,LstPoly,LstVar,[order])\n        Returns the remainder of the division of a polynomial by a Groebner basis. Add quo as last argument to get the quotients also.\n        See also: 1/ gbasis \n        Ex1:greduce(x*y-1,[x^2-y^2,2*x*y-y^2,y^3],[x,y])\n        Ex2:greduce(x*y-1,[x^2-y^2,2*x*y-y^2,y^3],[x,y],quo)\n        Ex3:greduce(x1^2*x3^2,[x3^3-1,-x2^2-x2*x3-x3^2,x1+x2+x3],[x1,x2,x3],tdeg)\n        Ex4:greduce(x1^2*x3^2-x2,[x3^3-1,-x2^2-x2*x3-x3^2,x1+x2+x3],[x1,x2,x3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1149greduce = {"greduce", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1149greduce, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1148greduce};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1149greduce(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("greduce (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "greduce", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1148greduce(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1148greduce(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("greduce", 1);

  /* "giacpy/auto-methods.pxi":7190
 * 
 *         '''
 *         return GiacMethods['greduce'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def greedy_clique(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_greduce); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7190, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7178
 *         return GiacMethods['graph_vertices'](self,*args)
 * 
 *      def greduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greduce:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.greduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7192
 *         return GiacMethods['greduce'](self,*args)
 * 
 *      def greedy_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_clique:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1151greedy_clique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1150greedy_clique, "From Giac's documentation:\n        Help for greedy_clique:\n        greedy_clique(Graph(G),[Intg(n)])\n        Returns a large clique in an undirected graph G using the GRASP algorithm with n iterations (default 5).\n        See also: 1/ maximum_clique \n        Ex1:greedy_clique(random_regular_graph(100,30))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1151greedy_clique = {"greedy_clique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1151greedy_clique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1150greedy_clique};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1151greedy_clique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("greedy_clique (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "greedy_clique", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1150greedy_clique(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1150greedy_clique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("greedy_clique", 1);

  /* "giacpy/auto-methods.pxi":7201
 * 
 *         '''
 *         return GiacMethods['greedy_clique'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def greedy_color(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_greedy_clique); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7201, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7192
 *         return GiacMethods['greduce'](self,*args)
 * 
 *      def greedy_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_clique:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.greedy_clique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7203
 *         return GiacMethods['greedy_clique'](self,*args)
 * 
 *      def greedy_color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_color:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1153greedy_color(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1152greedy_color, "From Giac's documentation:\n        Help for greedy_color:\n        greedy_color(Graph(G),[Permu(p)])\n        Returns the list of vertex colors (positive integers) obtained by coloring vertices one at a time [in the order given by permutation p], assigning to it the smallest available color.\n        See also: 1/ is_vertex_colorable 2/ chromatic_number \n        Ex1:greedy_color(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1153greedy_color = {"greedy_color", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1153greedy_color, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1152greedy_color};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1153greedy_color(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("greedy_color (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "greedy_color", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1152greedy_color(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1152greedy_color(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("greedy_color", 1);

  /* "giacpy/auto-methods.pxi":7212
 * 
 *         '''
 *         return GiacMethods['greedy_color'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def greedy_independent_set(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_greedy_color); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7212, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7203
 *         return GiacMethods['greedy_clique'](self,*args)
 * 
 *      def greedy_color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_color:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.greedy_color", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7214
 *         return GiacMethods['greedy_color'](self,*args)
 * 
 *      def greedy_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_independent_set:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1155greedy_independent_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1154greedy_independent_set, "From Giac's documentation:\n        Help for greedy_independent_set:\n        greedy_independent_set(Graph(G),[Intg(n)])\n        Returns a large independent set in an undirected graph G using the GRASP algorithm with n iterations (default 5).\n        See also: 1/ maximum_independent_set \n        Ex1:greedy_independent_set(random_regular_graph(100,30))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1155greedy_independent_set = {"greedy_independent_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1155greedy_independent_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1154greedy_independent_set};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1155greedy_independent_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("greedy_independent_set (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "greedy_independent_set", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1154greedy_independent_set(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1154greedy_independent_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("greedy_independent_set", 1);

  /* "giacpy/auto-methods.pxi":7223
 * 
 *         '''
 *         return GiacMethods['greedy_independent_set'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def grey(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_greedy_independent_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7223, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7214
 *         return GiacMethods['greedy_color'](self,*args)
 * 
 *      def greedy_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_independent_set:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.greedy_independent_set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7225
 *         return GiacMethods['greedy_independent_set'](self,*args)
 * 
 *      def grey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grey:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1157grey(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1156grey, "From Giac's documentation:\n        Help for grey:\n        grey(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1157grey = {"grey", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1157grey, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1156grey};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1157grey(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("grey (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "grey", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1156grey(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1156grey(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("grey", 1);

  /* "giacpy/auto-methods.pxi":7235
 * 
 *         '''
 *         return GiacMethods['grey'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def grid_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_grey); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7235, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7225
 *         return GiacMethods['greedy_independent_set'](self,*args)
 * 
 *      def grey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grey:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.grey", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7237
 *         return GiacMethods['grey'](self,*args)
 * 
 *      def grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grid_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1159grid_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1158grid_graph, "From Giac's documentation:\n        Help for grid_graph:\n        grid_graph(Intg(m),Intg(n),[triangle])\n        Returns a [triangular] grid graph on m*n vertices, where m,n>=2.\n        See also: 1/ torus_grid_graph \n        Ex1:grid_graph(5,8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1159grid_graph = {"grid_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1159grid_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1158grid_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1159grid_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("grid_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "grid_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1158grid_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1158grid_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("grid_graph", 1);

  /* "giacpy/auto-methods.pxi":7246
 * 
 *         '''
 *         return GiacMethods['grid_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def groupermu(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_grid_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7246, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7237
 *         return GiacMethods['grey'](self,*args)
 * 
 *      def grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grid_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.grid_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7248
 *         return GiacMethods['grid_graph'](self,*args)
 * 
 *      def groupermu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for groupermu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1161groupermu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1160groupermu, "From Giac's documentation:\n        Help for groupermu:\n        groupermu(Permut(a),Permut(b))\n        Returns the group of permutations generated by a and b.\n        See also: 1/  \n        Ex1:groupermu([1,2,0],[3,1,2,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1161groupermu = {"groupermu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1161groupermu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1160groupermu};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1161groupermu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("groupermu (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "groupermu", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1160groupermu(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1160groupermu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("groupermu", 1);

  /* "giacpy/auto-methods.pxi":7257
 * 
 *         '''
 *         return GiacMethods['groupermu'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def haar_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_groupermu); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7257, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7248
 *         return GiacMethods['grid_graph'](self,*args)
 * 
 *      def groupermu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for groupermu:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.groupermu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7259
 *         return GiacMethods['groupermu'](self,*args)
 * 
 *      def haar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for haar_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1163haar_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1162haar_graph, "From Giac's documentation:\n        Help for haar_graph:\n        haar_graph(Intg(n))\n        Returns the Haar graph with index n.\n        See also: 1/ graph 2/ is_bipartite \n        Ex1:haar_graph(7)\n        Ex2: is_isomorphic(haar_graph(133),graph(\"moebius-kantor\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1163haar_graph = {"haar_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1163haar_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1162haar_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1163haar_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("haar_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "haar_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1162haar_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1162haar_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("haar_graph", 1);

  /* "giacpy/auto-methods.pxi":7269
 * 
 *         '''
 *         return GiacMethods['haar_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hadamard(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_haar_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7269, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7259
 *         return GiacMethods['groupermu'](self,*args)
 * 
 *      def haar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for haar_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.haar_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7271
 *         return GiacMethods['haar_graph'](self,*args)
 * 
 *      def hadamard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hadamard:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1165hadamard(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1164hadamard, "From Giac's documentation:\n        Help for hadamard:\n        hadamard(Mtrx,Mtrx)\n        Hadamard bound of a matrix or element by element multiplication of 2 matrices.\n        See also: 1/ .* 2/ * \n        Ex1:hadamard([[1,2],[3,4]])\n        Ex2:hadamard([[1,2],[3,4]],[[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1165hadamard = {"hadamard", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1165hadamard, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1164hadamard};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1165hadamard(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hadamard (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hadamard", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1164hadamard(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1164hadamard(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hadamard", 1);

  /* "giacpy/auto-methods.pxi":7281
 * 
 *         '''
 *         return GiacMethods['hadamard'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def half_cone(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hadamard); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7281, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7271
 *         return GiacMethods['haar_graph'](self,*args)
 * 
 *      def hadamard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hadamard:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hadamard", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7283
 *         return GiacMethods['hadamard'](self,*args)
 * 
 *      def half_cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_cone:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1167half_cone(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1166half_cone, "From Giac's documentation:\n        Help for half_cone:\n        half_cone(Pnt(A),Vect(v),Real(t),[Real(h)])\n        Draws a half-cone with vertex A, direction v and with half_angle=t [and with altitude h].\n        See also: 1/ cone 2/ cylinder \n        Ex1:half_cone([0,0,0],[0,0,1],pi/6)\n        Ex2:half_cone([0,0,0],[0,1,1],pi/6,-4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1167half_cone = {"half_cone", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1167half_cone, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1166half_cone};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1167half_cone(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("half_cone (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "half_cone", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1166half_cone(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1166half_cone(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("half_cone", 1);

  /* "giacpy/auto-methods.pxi":7293
 * 
 *         '''
 *         return GiacMethods['half_cone'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def half_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_half_cone); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7293, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7283
 *         return GiacMethods['hadamard'](self,*args)
 * 
 *      def half_cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_cone:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.half_cone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7295
 *         return GiacMethods['half_cone'](self,*args)
 * 
 *      def half_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1169half_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1168half_line, "From Giac's documentation:\n        Help for half_line:\n        half_line((Pnt or Cplx),(Pnt or Cplx))\n        half_line(A,B) draws the half-line AB with A as origin.\n        See also: 1/ line \n        Ex1:half_line(i,1+i)\n        Ex2:half_line(point(i),point(1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1169half_line = {"half_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1169half_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1168half_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1169half_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("half_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "half_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1168half_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1168half_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("half_line", 1);

  /* "giacpy/auto-methods.pxi":7305
 * 
 *         '''
 *         return GiacMethods['half_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def halftan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_half_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7305, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7295
 *         return GiacMethods['half_cone'](self,*args)
 * 
 *      def half_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.half_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7307
 *         return GiacMethods['half_line'](self,*args)
 * 
 *      def halftan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1171halftan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1170halftan, "From Giac's documentation:\n        Help for halftan:\n        halftan(Expr)\n        Transforms sin(x),cos(x) and tan(x) to functions of tan(x/2).\n        Ex1:halftan(sin(x))\n        Ex2:halftan(cos(x))\n        Ex3:halftan(tan(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1171halftan = {"halftan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1171halftan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1170halftan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1171halftan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("halftan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "halftan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1170halftan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1170halftan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("halftan", 1);

  /* "giacpy/auto-methods.pxi":7317
 * 
 *         '''
 *         return GiacMethods['halftan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def halftan_hyp2exp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_halftan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7317, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7307
 *         return GiacMethods['half_line'](self,*args)
 * 
 *      def halftan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.halftan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7319
 *         return GiacMethods['halftan'](self,*args)
 * 
 *      def halftan_hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan_hyp2exp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1173halftan_hyp2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1172halftan_hyp2exp, "From Giac's documentation:\n        Help for halftan_hyp2exp:\n        halftan_hyp2exp(ExprTrig)\n        Transforms the trigonometric functions in tan(x/2) and hyperbolic functions to exp.\n        See also: 1/ hyp2exp 2/ halftan \n        Ex1:halftan_hyp2exp(sin(x)+sinh(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1173halftan_hyp2exp = {"halftan_hyp2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1173halftan_hyp2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1172halftan_hyp2exp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1173halftan_hyp2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("halftan_hyp2exp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "halftan_hyp2exp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1172halftan_hyp2exp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1172halftan_hyp2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("halftan_hyp2exp", 1);

  /* "giacpy/auto-methods.pxi":7328
 * 
 *         '''
 *         return GiacMethods['halftan_hyp2exp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def halt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_halftan_hyp2exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7328, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7319
 *         return GiacMethods['halftan'](self,*args)
 * 
 *      def halftan_hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan_hyp2exp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.halftan_hyp2exp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7330
 *         return GiacMethods['halftan_hyp2exp'](self,*args)
 * 
 *      def halt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1175halt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1174halt, "From Giac's documentation:\n        Help for halt:\n        halt(NULL)\n        Puts a program in step-by-step debug mode.\n        See also: 1/  \n        Ex1:halt()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1175halt = {"halt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1175halt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1174halt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1175halt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("halt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "halt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1174halt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1174halt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("halt", 1);

  /* "giacpy/auto-methods.pxi":7339
 * 
 *         '''
 *         return GiacMethods['halt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hamdist(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_halt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7339, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7330
 *         return GiacMethods['halftan_hyp2exp'](self,*args)
 * 
 *      def halt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.halt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7341
 *         return GiacMethods['halt'](self,*args)
 * 
 *      def hamdist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamdist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1177hamdist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1176hamdist, "From Giac's documentation:\n        Help for hamdist:\n        hamdist(Intg,Intg)\n        Bitwise Hamming distance.\n        Ex1:hamdist(0x12,0x38)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1177hamdist = {"hamdist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1177hamdist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1176hamdist};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1177hamdist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hamdist (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hamdist", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1176hamdist(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1176hamdist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hamdist", 1);

  /* "giacpy/auto-methods.pxi":7349
 * 
 *         '''
 *         return GiacMethods['hamdist'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hamming(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hamdist); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7349, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7341
 *         return GiacMethods['halt'](self,*args)
 * 
 *      def hamdist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamdist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hamdist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7351
 *         return GiacMethods['hamdist'](self,*args)
 * 
 *      def hamming(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1179hamming(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1178hamming, "From Giac's documentation:\n        Help for hamming:\n        hamming(Str(s1)||Lst(s1),Str(s2)||Lst(s2))\n        Hamming distance between two vectors or strings of equal lengths.\n        See also: 1/ hamdist 2/ levenshtein \n        Ex1:hamming(\"cats\",\"dogs\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1179hamming = {"hamming", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1179hamming, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1178hamming};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1179hamming(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hamming (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hamming", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1178hamming(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1178hamming(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hamming", 1);

  /* "giacpy/auto-methods.pxi":7360
 * 
 *         '''
 *         return GiacMethods['hamming'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hamming_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hamming); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7360, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7351
 *         return GiacMethods['hamdist'](self,*args)
 * 
 *      def hamming(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hamming", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7362
 *         return GiacMethods['hamming'](self,*args)
 * 
 *      def hamming_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1181hamming_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1180hamming_window, "From Giac's documentation:\n        Help for hamming_window:\n        hamming_window(Lst,[Interval(n1..n2)])\n        Applies the Hamming windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ bartlett_hann_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(hamming_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1181hamming_window = {"hamming_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1181hamming_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1180hamming_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1181hamming_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hamming_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hamming_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1180hamming_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1180hamming_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hamming_window", 1);

  /* "giacpy/auto-methods.pxi":7371
 * 
 *         '''
 *         return GiacMethods['hamming_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hann_poisson_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hamming_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7371, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7362
 *         return GiacMethods['hamming'](self,*args)
 * 
 *      def hamming_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hamming_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7373
 *         return GiacMethods['hamming_window'](self,*args)
 * 
 *      def hann_poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_poisson_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1183hann_poisson_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1182hann_poisson_window, "From Giac's documentation:\n        Help for hann_poisson_window:\n        hann_poisson_window(Lst,[Interval(n1..n2)])\n        Applies the Hann-Poisson windowing function with parameter a (by default a=1) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ bartlett_hann_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(hann_poisson_window(randvector(1000,0..1),2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1183hann_poisson_window = {"hann_poisson_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1183hann_poisson_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1182hann_poisson_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1183hann_poisson_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hann_poisson_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hann_poisson_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1182hann_poisson_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1182hann_poisson_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hann_poisson_window", 1);

  /* "giacpy/auto-methods.pxi":7382
 * 
 *         '''
 *         return GiacMethods['hann_poisson_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hann_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hann_poisson_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7382, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7373
 *         return GiacMethods['hamming_window'](self,*args)
 * 
 *      def hann_poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_poisson_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hann_poisson_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7384
 *         return GiacMethods['hann_poisson_window'](self,*args)
 * 
 *      def hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1185hann_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1184hann_window, "From Giac's documentation:\n        Help for hann_window:\n        hann_window(Lst,[Interval(n1..n2)])\n        Applies the Hann windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ bartlett_hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(hann_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1185hann_window = {"hann_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1185hann_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1184hann_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1185hann_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hann_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hann_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1184hann_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1184hann_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hann_window", 1);

  /* "giacpy/auto-methods.pxi":7393
 * 
 *         '''
 *         return GiacMethods['hann_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def harmonic_centrality(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hann_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7393, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7384
 *         return GiacMethods['hann_poisson_window'](self,*args)
 * 
 *      def hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hann_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7395
 *         return GiacMethods['hann_window'](self,*args)
 * 
 *      def harmonic_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_centrality:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1187harmonic_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1186harmonic_centrality, "From Giac's documentation:\n        Help for harmonic_centrality:\n        harmonic_centrality(Graph(G),[Vrtx(v)])\n        Returns the harmonic centrality of a vertex v in a graph G or the list of harmonic centralities of vertices in G.\n        See also: 1/ degree_centrality 2/ betweenness_centrality 3/ closeness_centrality 4/ information_centrality 5/ katz_centrality \n        Ex1:harmonic_centrality(graph(6,%{[0,2],[0,5],[1,3],[1,5],[2,5],[3,4],[3,5],[4,5]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1187harmonic_centrality = {"harmonic_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1187harmonic_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1186harmonic_centrality};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1187harmonic_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("harmonic_centrality (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "harmonic_centrality", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1186harmonic_centrality(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1186harmonic_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("harmonic_centrality", 1);

  /* "giacpy/auto-methods.pxi":7404
 * 
 *         '''
 *         return GiacMethods['harmonic_centrality'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def harmonic_conjugate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_harmonic_centrality); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7404, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7395
 *         return GiacMethods['hann_window'](self,*args)
 * 
 *      def harmonic_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_centrality:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.harmonic_centrality", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7406
 *         return GiacMethods['harmonic_centrality'](self,*args)
 * 
 *      def harmonic_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_conjugate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1189harmonic_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1188harmonic_conjugate, "From Giac's documentation:\n        Help for harmonic_conjugate:\n        harmonic_conjugate(Line or Pnt(A),Line or Pnt(B),Line or Pnt(C))\n        Returns the harmonic conjugate C with respect to A and B of 3 points or of 3 parallel or concurrent lines or the line of conjugates of a point with respect to 2 lines.\n        See also: 1/ is_harmonic 2/ harmonic_division \n        Ex1:harmonic_conjugate(0,2,3/2)\n        Ex2:harmonic_conjugate(0,1+i,2+2*i)\n        Ex3:harmonic_conjugate(line(0,1+i),line(0,3+i),line(0,i))\n        Ex4:harmonic_conjugate(line(0,1+i),line(0,3+i),point(3/2+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1189harmonic_conjugate = {"harmonic_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1189harmonic_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1188harmonic_conjugate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1189harmonic_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("harmonic_conjugate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "harmonic_conjugate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1188harmonic_conjugate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1188harmonic_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("harmonic_conjugate", 1);

  /* "giacpy/auto-methods.pxi":7418
 * 
 *         '''
 *         return GiacMethods['harmonic_conjugate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def harmonic_division(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_harmonic_conjugate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7418, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7406
 *         return GiacMethods['harmonic_centrality'](self,*args)
 * 
 *      def harmonic_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_conjugate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.harmonic_conjugate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7420
 *         return GiacMethods['harmonic_conjugate'](self,*args)
 * 
 *      def harmonic_division(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_division:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1191harmonic_division(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1190harmonic_division, "From Giac's documentation:\n        Help for harmonic_division:\n        harmonic_division(Pnt or Line,Pnt or Line,Pnt or Line,Var)\n        Returns 4 points (resp lines) and affects the last argument, such that the 4 points (resp lines) are in a harmonic division and assigns the fourth point to the variable name.\n        See also: 1/ harmonic_conjugate 2/ is_harmonic \n        Ex1:harmonic_division(0,2,3/2,D)\n        Ex2:harmonic_division(0,1+i,2+2*i,D)\n        Ex3:harmonic_division(line(i,0),line(i,1+i),line(i,3+2*i),D)\n        Ex4:harmonic_division(line(0,1+i),line(0,3+i),line(0,i),D)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1191harmonic_division = {"harmonic_division", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1191harmonic_division, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1190harmonic_division};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1191harmonic_division(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("harmonic_division (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "harmonic_division", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1190harmonic_division(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1190harmonic_division(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("harmonic_division", 1);

  /* "giacpy/auto-methods.pxi":7432
 * 
 *         '''
 *         return GiacMethods['harmonic_division'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def has(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_harmonic_division); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7432, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7420
 *         return GiacMethods['harmonic_conjugate'](self,*args)
 * 
 *      def harmonic_division(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_division:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.harmonic_division", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7434
 *         return GiacMethods['harmonic_division'](self,*args)
 * 
 *      def has(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1193has(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1192has, "From Giac's documentation:\n        Help for has:\n        has(Expr,Var)\n        Checks if a variable is in an expression.\n        See also: 1/ lname 2/ lvar \n        Ex1:has(x+y,x)\n        Ex2:has(x+y,n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1193has = {"has", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1193has, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1192has};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1193has(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("has (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "has", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1192has(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1192has(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("has", 1);

  /* "giacpy/auto-methods.pxi":7444
 * 
 *         '''
 *         return GiacMethods['has'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def has_arc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_has); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7444, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7434
 *         return GiacMethods['harmonic_division'](self,*args)
 * 
 *      def has(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.has", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7446
 *         return GiacMethods['has'](self,*args)
 * 
 *      def has_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_arc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1195has_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1194has_arc, "From Giac's documentation:\n        Help for has_arc:\n        has_arc(Graph(G),Edge(e))\n        Returns true iff the arc e=[i,j] is contained in a digraph G or, if e={i,j} is a set, iff G has both edges [i,j] and [j,i].\n        See also: 1/ edges 2/ has_edge \n        Ex1:has_arc(digraph(trail(1,2,3,4,1)),[4,2])\n        Ex2:has_arc(digraph(trail(1,2,3,4,1)),%{4,2%})\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1195has_arc = {"has_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1195has_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1194has_arc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1195has_arc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("has_arc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "has_arc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1194has_arc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1194has_arc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("has_arc", 1);

  /* "giacpy/auto-methods.pxi":7456
 * 
 *         '''
 *         return GiacMethods['has_arc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def has_edge(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_has_arc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7456, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7446
 *         return GiacMethods['has'](self,*args)
 * 
 *      def has_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_arc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.has_arc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7458
 *         return GiacMethods['has_arc'](self,*args)
 * 
 *      def has_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_edge:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1197has_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1196has_edge, "From Giac's documentation:\n        Help for has_edge:\n        has_edge(Graph(G),Edge(e))\n        Returns true iff the edge e=[i,j] is contained in an undirected graph G.\n        See also: 1/ edges 2/ has_arc \n        Ex1:has_edge(graph(trail(1,2,3,4,1)),[2,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1197has_edge = {"has_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1197has_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1196has_edge};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1197has_edge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("has_edge (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "has_edge", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1196has_edge(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1196has_edge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("has_edge", 1);

  /* "giacpy/auto-methods.pxi":7467
 * 
 *         '''
 *         return GiacMethods['has_edge'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hasard(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_has_edge); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7467, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7458
 *         return GiacMethods['has_arc'](self,*args)
 * 
 *      def has_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_edge:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.has_edge", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7469
 *         return GiacMethods['has_edge'](self,*args)
 * 
 *      def hasard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hasard:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1199hasard(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1198hasard, "From Giac's documentation:\n        Help for hasard:\n        hasard(Intg(n) or Interval(p..n) or NULL,[Intg(b1) or Lst(L)],[Intg(b2)])\n        (hasard n)=a random integer (resp (hasard p,n)=a real or hasard(p..n)=a real function) with uniform distribution in 0..n-1 (resp in [p;n])(hasard= (hasard 0,1)=a random real in [0,1[) or hasard(n,b1,b2)=n integers between b1 and b2 or hasard(n,L)=n elements of L. If hasard has only one argument, () are not necessary (compatibility with turtle language).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ srand \n        Ex1: hasard 4\n        Ex2: hasard(4)\n        Ex3:hasard(0,2)\n        Ex4: hasard 0..2\n        Ex5: f:=hasard 0..2\n        Ex6:hasard(3,1,10)\n        Ex7:hasard(3,[\"r\",\"r\",\"r\",\"b\",\"n\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1199hasard = {"hasard", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1199hasard, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1198hasard};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1199hasard(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hasard (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hasard", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1198hasard(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1198hasard(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hasard", 1);

  /* "giacpy/auto-methods.pxi":7484
 * 
 *         '''
 *         return GiacMethods['hasard'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def head(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hasard); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7484, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7469
 *         return GiacMethods['has_edge'](self,*args)
 * 
 *      def hasard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hasard:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hasard", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7486
 *         return GiacMethods['hasard'](self,*args)
 * 
 *      def head(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for head:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1201head(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1200head, "From Giac's documentation:\n        Help for head:\n        head(Vect or Seq or Str)\n        Shows the first element of a vector or a sequence or a string.\n        See also: 1/ back 2/ tail 3/ mid 4/ left 5/ right \n        Ex1:head(1,2,3)\n        Ex2:head([1,2,3])\n        Ex3:head(\"bonjour\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1201head = {"head", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1201head, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1200head};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1201head(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("head (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "head", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1200head(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1200head(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("head", 1);

  /* "giacpy/auto-methods.pxi":7497
 * 
 *         '''
 *         return GiacMethods['head'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def heading(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_head); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7497, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7486
 *         return GiacMethods['hasard'](self,*args)
 * 
 *      def head(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for head:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.head", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7499
 *         return GiacMethods['head'](self,*args)
 * 
 *      def heading(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heading:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1203heading(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1202heading, "From Giac's documentation:\n        Help for heading:\n        heading(NULL or Real)\n        Returns the turtle cap in degrees or turns the turtle in the direction given by the argument.\n        See also: 1/ position 2/ initialise \n        Ex1: cap\n        Ex2:heading()\n        Ex3:heading(cap 90)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1203heading = {"heading", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1203heading, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1202heading};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1203heading(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("heading (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "heading", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1202heading(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1202heading(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("heading", 1);

  /* "giacpy/auto-methods.pxi":7510
 * 
 *         '''
 *         return GiacMethods['heading'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def heapify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_heading); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7510, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7499
 *         return GiacMethods['head'](self,*args)
 * 
 *      def heading(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heading:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.heading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7512
 *         return GiacMethods['heading'](self,*args)
 * 
 *      def heapify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heapify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1205heapify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1204heapify, "From Giac's documentation:\n        Help for heapify:\n        heapify(List)\n        Partial ordering of a list as a heap.\n        See also: 1/ heappush 2/ heappop \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1205heapify = {"heapify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1205heapify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1204heapify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1205heapify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("heapify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "heapify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1204heapify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1204heapify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("heapify", 1);

  /* "giacpy/auto-methods.pxi":7520
 * 
 *         '''
 *         return GiacMethods['heapify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def heappop(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_heapify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7520, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7512
 *         return GiacMethods['heading'](self,*args)
 * 
 *      def heapify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heapify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.heapify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7522
 *         return GiacMethods['heapify'](self,*args)
 * 
 *      def heappop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappop:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1207heappop(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1206heappop, "From Giac's documentation:\n        Help for heappop:\n        heappop(List)\n        Removes and returns the root node of a heap.\n        See also: 1/ heapify 2/ heappush \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1207heappop = {"heappop", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1207heappop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1206heappop};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1207heappop(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("heappop (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "heappop", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1206heappop(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1206heappop(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("heappop", 1);

  /* "giacpy/auto-methods.pxi":7530
 * 
 *         '''
 *         return GiacMethods['heappop'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def heappush(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_heappop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7530, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7522
 *         return GiacMethods['heapify'](self,*args)
 * 
 *      def heappop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappop:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.heappop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7532
 *         return GiacMethods['heappop'](self,*args)
 * 
 *      def heappush(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappush:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1209heappush(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1208heappush, "From Giac's documentation:\n        Help for heappush:\n        heappush(List,Object)\n        Adds an object in a heap.\n        See also: 1/ heapify 2/ heappop \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1209heappush = {"heappush", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1209heappush, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1208heappush};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1209heappush(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("heappush (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "heappush", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1208heappush(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1208heappush(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("heappush", 1);

  /* "giacpy/auto-methods.pxi":7540
 * 
 *         '''
 *         return GiacMethods['heappush'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hermite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_heappush); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7540, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7532
 *         return GiacMethods['heappop'](self,*args)
 * 
 *      def heappush(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappush:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.heappush", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7542
 *         return GiacMethods['heappush'](self,*args)
 * 
 *      def hermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hermite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1211hermite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1210hermite, "From Giac's documentation:\n        Help for hermite:\n        hermite(Intg(n)||Matr(A))\n        Returns the Hermite polynomial of degree n or the Hermite normal form for a matrix with polynomial coefficients (I,U such that I*A=U).\n        See also: 1/ legendre 2/ laguerre 3/ smith 4/ ihermite 5/ ismith \n        Ex1:hermite(3)\n        Ex2: n:=5; a:=ranm(n,n) % 17; l,u:=hermite(x-a);normal(l*(x-a)-u);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1211hermite = {"hermite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1211hermite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1210hermite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1211hermite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hermite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hermite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1210hermite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1210hermite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hermite", 1);

  /* "giacpy/auto-methods.pxi":7552
 * 
 *         '''
 *         return GiacMethods['hermite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hessenberg(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hermite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7552, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7542
 *         return GiacMethods['heappush'](self,*args)
 * 
 *      def hermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hermite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hermite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7554
 *         return GiacMethods['hermite'](self,*args)
 * 
 *      def hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessenberg:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1213hessenberg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1212hessenberg, "From Giac's documentation:\n        Help for hessenberg:\n        hessenberg(Mtrx(A),[Intg(n)])\n        Matrix reduction to Hessenberg form. Returns [P,B] such that B=inv(P)*A*P, by default n=0 the result is exact else the result is numeric. For n=-1 B is triangular, n=-2 P is orthogonal and if n is prime the result is mod n.\n        See also: 1/ SCHUR \n        Ex1:hessenberg([[1,2,3],[4,5,6],[7,8,1]])\n        Ex2:hessenberg([[1,2,3,4],[4,5,6,7],[7,8,9,0],[0,1,2,3]])\n        Ex3:hessenberg([[1,2,3],[4,5,6],[7,8,1]],-1)\n        Ex4:hessenberg([[1,2,3],[4,5,6],[7,8,1]],-2)\n        Ex5:hessenberg([[1,2,3],[4,5,6],[7,8,1]],3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1213hessenberg = {"hessenberg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1213hessenberg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1212hessenberg};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1213hessenberg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hessenberg (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hessenberg", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1212hessenberg(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1212hessenberg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hessenberg", 1);

  /* "giacpy/auto-methods.pxi":7567
 * 
 *         '''
 *         return GiacMethods['hessenberg'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hessian(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hessenberg); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7567, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7554
 *         return GiacMethods['hermite'](self,*args)
 * 
 *      def hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessenberg:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hessenberg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7569
 *         return GiacMethods['hessenberg'](self,*args)
 * 
 *      def hessian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessian:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1215hessian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1214hessian, "From Giac's documentation:\n        Help for hessian:\n        hessian(Expr(Xpr),LstVar)\n        Returns the hessian of the expression Xpr.\n        See also: 1/ grad \n        Ex1:hessian(2*x^2*y-x*z,[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1215hessian = {"hessian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1215hessian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1214hessian};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1215hessian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hessian (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hessian", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1214hessian(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1214hessian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hessian", 1);

  /* "giacpy/auto-methods.pxi":7578
 * 
 *         '''
 *         return GiacMethods['hessian'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def heugcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hessian); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7578, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7569
 *         return GiacMethods['hessenberg'](self,*args)
 * 
 *      def hessian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessian:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hessian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7580
 *         return GiacMethods['hessian'](self,*args)
 * 
 *      def heugcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heugcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1217heugcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1216heugcd, "From Giac's documentation:\n        Help for heugcd:\n        heugcd(Poly,Poly)\n        GCD of 2 polynomials, with the algorithm called heuristic pgcd.\n        See also: 1/ gcd 2/ modgcd 3/ ezgcd 4/ psrgcd \n        Ex1:heugcd(x^4-1,(x-1)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1217heugcd = {"heugcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1217heugcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1216heugcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1217heugcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("heugcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "heugcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1216heugcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1216heugcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("heugcd", 1);

  /* "giacpy/auto-methods.pxi":7589
 * 
 *         '''
 *         return GiacMethods['heugcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hexagon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_heugcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7589, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7580
 *         return GiacMethods['hessian'](self,*args)
 * 
 *      def heugcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heugcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.heugcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7591
 *         return GiacMethods['heugcd'](self,*args)
 * 
 *      def hexagon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hexagon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1219hexagon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1218hexagon, "From Giac's documentation:\n        Help for hexagon:\n        hexagon(Pnt(A)||Cplx,Pnt(B)||Cplx,[Pnt(P)],[Var(C)],[Var(D)],[Var(E)],[Var(F)])\n        Returns and draws the hexagon of side AB (ABCDEF is direct) (in the plane ABP).\n        See also: 1/ isopolygon 2/ polygon \n        Ex1:hexagon(i,1+i)\n        Ex2:hexagon(i,1+i,C,D,E,F)\n        Ex3:hexagon(point(0,0,0),point(3,3,3),point(0,0,3))\n        Ex4:hexagon(point(0,0,0),point(3,3,3),point(0,0,3),C,D,E,F)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1219hexagon = {"hexagon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1219hexagon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1218hexagon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1219hexagon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hexagon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hexagon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1218hexagon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1218hexagon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hexagon", 1);

  /* "giacpy/auto-methods.pxi":7603
 * 
 *         '''
 *         return GiacMethods['hexagon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hht(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hexagon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7603, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7591
 *         return GiacMethods['heugcd'](self,*args)
 * 
 *      def hexagon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hexagon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hexagon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7605
 *         return GiacMethods['hexagon'](self,*args)
 * 
 *      def hht(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hht:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1221hht(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1220hht, "From Giac's documentation:\n        Help for hht:\n        hht(Lst(data)||Mtrx(imf),[opts])\n        Hilbert-Huang transform.\n        See also: 1/ emd 2/ colormap \n        Ex1:hht(apply(x->cos(10*x^2*pi),linspace(-pi,pi,500)),color=false,frequencies=0.1..2.5,output=plot)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1221hht = {"hht", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1221hht, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1220hht};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1221hht(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hht (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hht", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1220hht(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1220hht(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hht", 1);

  /* "giacpy/auto-methods.pxi":7614
 * 
 *         '''
 *         return GiacMethods['hht'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def highlight_edges(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hht); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7614, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7605
 *         return GiacMethods['hexagon'](self,*args)
 * 
 *      def hht(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hht:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hht", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7616
 *         return GiacMethods['hht'](self,*args)
 * 
 *      def highlight_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_edges:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1223highlight_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1222highlight_edges, "From Giac's documentation:\n        Help for highlight_edges:\n        highlight_edges(Graph(G),Edge(e)||Lst(E),[Color(c)||Lst(C)])\n        Changes color of edge e resp. colors of edges in E of the input graph G to c resp. C (by default red) and returns a modified copy of G.\n        See also: 1/ highlight_vertex 2/ highlight_subgraph 3/ highlight_trail \n        Ex1: draw_graph(highlight_edges(cycle_graph(3),[1,2]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1223highlight_edges = {"highlight_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1223highlight_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1222highlight_edges};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1223highlight_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("highlight_edges (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "highlight_edges", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1222highlight_edges(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1222highlight_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("highlight_edges", 1);

  /* "giacpy/auto-methods.pxi":7625
 * 
 *         '''
 *         return GiacMethods['highlight_edges'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def highlight_subgraph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_highlight_edges); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7625, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7616
 *         return GiacMethods['hht'](self,*args)
 * 
 *      def highlight_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_edges:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.highlight_edges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7627
 *         return GiacMethods['highlight_edges'](self,*args)
 * 
 *      def highlight_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_subgraph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1225highlight_subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1224highlight_subgraph, "From Giac's documentation:\n        Help for highlight_subgraph:\n        highlight_subgraph(Graph(G),Graph(S)||Lst(S1,S2,..),Seq(c1,c2))\n        Changes the colors of edges and vertices from a sugbraph S or subgraphs S1, S2, ... of G to c1 and c2, respectively (red and green by default), and returns a modified copy of G.\n        See also: 1/ highlight_edges 2/ highlight_vertex 3/ highlight_trail \n        Ex1: draw_graph(highlight_subgraph(cycle_graph(5),path_graph(3)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1225highlight_subgraph = {"highlight_subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1225highlight_subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1224highlight_subgraph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1225highlight_subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("highlight_subgraph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "highlight_subgraph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1224highlight_subgraph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1224highlight_subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("highlight_subgraph", 1);

  /* "giacpy/auto-methods.pxi":7636
 * 
 *         '''
 *         return GiacMethods['highlight_subgraph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def highlight_trail(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_highlight_subgraph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7636, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7627
 *         return GiacMethods['highlight_edges'](self,*args)
 * 
 *      def highlight_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_subgraph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.highlight_subgraph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7638
 *         return GiacMethods['highlight_subgraph'](self,*args)
 * 
 *      def highlight_trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_trail:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1227highlight_trail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1226highlight_trail, "From Giac's documentation:\n        Help for highlight_trail:\n        highlight_trail(Graph(G),Trail(t)||Lst(T),[Color(c)||Lst(C)])\n        Changes the colors of edges in G which lie along a trail t resp. trails in T to c resp. C (by default red) and returns a modified copy of G.\n        See also: 1/ highlight_edges 2/ highlight_subgraph 3/ highlight_vertex \n        Ex1: draw_graph(highlight_trail(cycle_graph(5),trail(1,2,3),green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1227highlight_trail = {"highlight_trail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1227highlight_trail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1226highlight_trail};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1227highlight_trail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("highlight_trail (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "highlight_trail", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1226highlight_trail(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1226highlight_trail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("highlight_trail", 1);

  /* "giacpy/auto-methods.pxi":7647
 * 
 *         '''
 *         return GiacMethods['highlight_trail'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def highlight_vertex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_highlight_trail); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7647, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7638
 *         return GiacMethods['highlight_subgraph'](self,*args)
 * 
 *      def highlight_trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_trail:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.highlight_trail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7649
 *         return GiacMethods['highlight_trail'](self,*args)
 * 
 *      def highlight_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_vertex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1229highlight_vertex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1228highlight_vertex, "From Giac's documentation:\n        Help for highlight_vertex:\n        highlight_vertex(Graph(G),Vrtx(v)||Lst(V),[Color(c)||Lst(C)])\n        Changes the color of vertex v resp. colors of vertices from V in G to c resp. C (green by default) and returns a modified copy of G.\n        See also: 1/ highlight_edges 2/ highlight_subgraph 3/ highlight_trail \n        Ex1: draw_graph(highlight_vertex(cycle_graph(3),1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1229highlight_vertex = {"highlight_vertex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1229highlight_vertex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1228highlight_vertex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1229highlight_vertex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("highlight_vertex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "highlight_vertex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1228highlight_vertex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1228highlight_vertex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("highlight_vertex", 1);

  /* "giacpy/auto-methods.pxi":7658
 * 
 *         '''
 *         return GiacMethods['highlight_vertex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def highpass(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_highlight_vertex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7658, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7649
 *         return GiacMethods['highlight_trail'](self,*args)
 * 
 *      def highlight_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_vertex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.highlight_vertex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7660
 *         return GiacMethods['highlight_vertex'](self,*args)
 * 
 *      def highpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highpass:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1231highpass(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1230highpass, "From Giac's documentation:\n        Help for highpass:\n        highpass(Lst(s),Real(c),[Intg(samplerate)])\n        Returns the result of applying a simple first-order highpass RC filter with cutoff frequency c (the default samplerate is 44100) to the given signal s.\n        See also: 1/ lowpass 2/ moving_average \n        Ex1: f:=unapply(periodic(sign(x),x,-1/880,1/880),x):;s:=createwav(apply(f,soundsec(1))):;playsnd(highpass(s,5000))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1231highpass = {"highpass", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1231highpass, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1230highpass};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1231highpass(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("highpass (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "highpass", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1230highpass(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1230highpass(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("highpass", 1);

  /* "giacpy/auto-methods.pxi":7669
 * 
 *         '''
 *         return GiacMethods['highpass'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hilbert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_highpass); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7669, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7660
 *         return GiacMethods['highlight_vertex'](self,*args)
 * 
 *      def highpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highpass:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.highpass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7671
 *         return GiacMethods['highpass'](self,*args)
 * 
 *      def hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hilbert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1233hilbert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1232hilbert, "From Giac's documentation:\n        Help for hilbert:\n        hilbert(Intg(n)||(Expr(f),[Var(x)])||Lst(u))\n        Returns the order n Hilbert matrix Hjk=1/(j+k+1), j,k=1..n, or the Hilbert transform of an expression f(x) or the analytic representation of a discrete real signal u.\n        See also: 1/ Hilbert 2/ fft 3/ fourier \n        Ex1:hilbert(4)\n        Ex2:hilbert(1/(1+t^2),t)\n        Ex3:hilbert(sinc(x))\n        Ex4:hilbert([0.7,0.2,-0.5,-0.6,-0.2,0.3,0.5,-0.1,-0.3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1233hilbert = {"hilbert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1233hilbert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1232hilbert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1233hilbert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hilbert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hilbert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1232hilbert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1232hilbert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hilbert", 1);

  /* "giacpy/auto-methods.pxi":7683
 * 
 *         '''
 *         return GiacMethods['hilbert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def histogram(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hilbert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7683, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7671
 *         return GiacMethods['highpass'](self,*args)
 * 
 *      def hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hilbert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hilbert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7685
 *         return GiacMethods['hilbert'](self,*args)
 * 
 *      def histogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for histogram:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1235histogram(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1234histogram, "From Giac's documentation:\n        Help for histogram:\n        histogram(Lst(data),[Lst(eff) || Intg(nc) || Real(classmin)],[Real(classsize)])\n        Draws the histogram of data, optional arguments are eff (number of data for each data element) or nc the number of classes or the classes minimum and size.\n        See also: 1/ cumulated_frequencies 2/ classes 3/ bar_plot 4/ frequencies \n        Ex1:histogram([1,2,1,1,2,1,2,4,3,3])\n        Ex2:histogram([1,2,1,1,2,1,2,4,3,3],0.5,1)\n        Ex3:histogram(seq(rand(1000),k,0,100),0,100)\n        Ex4:histogram(binomial,10,.5)\n        Ex5:histogram([[0,1],[1,4],[2,3],[3,2],[4,1]])\n        Ex6:histogram([[1.5..1.65,50],[1.65..1.7,20],[1.7..1.8,30]])\n        Ex7:histogram(seq(rand(1000),k,0,100),0,100)\n        Ex8:histogram(seq(rand(1000),k,0,100),10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1235histogram = {"histogram", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1235histogram, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1234histogram};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1235histogram(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("histogram (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "histogram", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1234histogram(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1234histogram(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("histogram", 1);

  /* "giacpy/auto-methods.pxi":7701
 * 
 *         '''
 *         return GiacMethods['histogram'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hold(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_histogram); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7701, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7685
 *         return GiacMethods['hilbert'](self,*args)
 * 
 *      def histogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for histogram:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.histogram", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7703
 *         return GiacMethods['histogram'](self,*args)
 * 
 *      def hold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hold:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1237hold(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1236hold, "From Giac's documentation:\n        Help for hold:\n        hold(Expr)\n        Returns its argument unevaluated (and also a:=quote(a) purges a).\n        See also: 1/  \n        Ex1:hold(1+2)\n        Ex2:hold(1/x+1/(x-1))\n        Ex3:hold((x+1)*(x-1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1237hold = {"hold", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1237hold, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1236hold};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1237hold(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hold (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hold", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1236hold(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1236hold(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hold", 1);

  /* "giacpy/auto-methods.pxi":7714
 * 
 *         '''
 *         return GiacMethods['hold'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def homogeneize(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hold); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7714, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7703
 *         return GiacMethods['histogram'](self,*args)
 * 
 *      def hold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hold:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hold", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7716
 *         return GiacMethods['hold'](self,*args)
 * 
 *      def homogeneize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homogeneize:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1239homogeneize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1238homogeneize, "From Giac's documentation:\n        Help for homogeneize:\n        homogeneize(Expr(P),[Var(t)])\n        Make P homogeneous by adding a variable (by default t)\n        Ex1:homogeneize(x^2-1)\n        Ex2:homogeneize(x^2-y,z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1239homogeneize = {"homogeneize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1239homogeneize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1238homogeneize};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1239homogeneize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("homogeneize (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "homogeneize", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1238homogeneize(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1238homogeneize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("homogeneize", 1);

  /* "giacpy/auto-methods.pxi":7725
 * 
 *         '''
 *         return GiacMethods['homogeneize'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def homothety(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_homogeneize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7725, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7716
 *         return GiacMethods['hold'](self,*args)
 * 
 *      def homogeneize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homogeneize:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.homogeneize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7727
 *         return GiacMethods['homogeneize'](self,*args)
 * 
 *      def homothety(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homothety:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1241homothety(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1240homothety, "From Giac's documentation:\n        Help for homothety:\n        homothety(Pnt(C),Real(k),Pnt(A))\n        homothety(C,k,A)=point A1 such as vect(C,A1)=k*vect(C,A) i.e in 2d it is the similarity with center C, coeff abs(k) and angle arg(k).\n        See also: 1/ similarity 2/ inversion \n        Ex1:homothety(1+i,1/3,i)\n        Ex2:homothety(point(1,1,1),1/3,point(0,1,0))\n        Ex3: h:=homothety(1+i,1/3);h(i)\n        Ex4: h:=homothety(point(1,1,1),1/3);h(point(0,1,0))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1241homothety = {"homothety", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1241homothety, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1240homothety};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1241homothety(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("homothety (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "homothety", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1240homothety(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1240homothety(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("homothety", 1);

  /* "giacpy/auto-methods.pxi":7739
 * 
 *         '''
 *         return GiacMethods['homothety'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def horner(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_homothety); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7739, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7727
 *         return GiacMethods['homogeneize'](self,*args)
 * 
 *      def homothety(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homothety:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.homothety", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7741
 *         return GiacMethods['homothety'](self,*args)
 * 
 *      def horner(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for horner:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1243horner(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1242horner, "From Giac's documentation:\n        Help for horner:\n        horner(Poly(P),Real(a))\n        Returns the value of P(a) calculated with Horner's method. With horner(list_alpha_i,list_x_i,x), evals an interpolation polynomial from the divided differences of x.\n        See also: 1/ convert 2/ base 3/ revlist \n        Ex1:horner(x^2+1,2)\n        Ex2:horner([1,0,1],2)\n        Ex3:horner(x^2+y*x+y^3-1,2,y)\n        Ex4: X:=[0.0,1.0,2.0]; A:=lagrange(X,exp,lagrange); horner(A,X,1.5);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1243horner = {"horner", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1243horner, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1242horner};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1243horner(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("horner (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "horner", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1242horner(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1242horner(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("horner", 1);

  /* "giacpy/auto-methods.pxi":7753
 * 
 *         '''
 *         return GiacMethods['horner'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hsv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_horner); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7753, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7741
 *         return GiacMethods['homothety'](self,*args)
 * 
 *      def horner(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for horner:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.horner", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7755
 *         return GiacMethods['horner'](self,*args)
 * 
 *      def hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1245hsv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1244hsv, "From Giac's documentation:\n        Help for hsv:\n        hsv(Lst(h,s,v)||Color(c))\n        Convert a HSV specification [h,s,v] to xcas color or return the HSV specification of a xcas color c.\n        See also: 1/ rgb 2/ hsv2rgb 3/ rgb2hsv \n        Ex1:hsv(220,90,100)\n        Ex2:hsv([0.3,0.7,0.5])\n        Ex3:hsv(teal)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1245hsv = {"hsv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1245hsv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1244hsv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1245hsv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hsv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hsv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1244hsv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1244hsv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hsv", 1);

  /* "giacpy/auto-methods.pxi":7766
 * 
 *         '''
 *         return GiacMethods['hsv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hsv2rgb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hsv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7766, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7755
 *         return GiacMethods['horner'](self,*args)
 * 
 *      def hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hsv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7768
 *         return GiacMethods['hsv'](self,*args)
 * 
 *      def hsv2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv2rgb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1247hsv2rgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1246hsv2rgb, "From Giac's documentation:\n        Help for hsv2rgb:\n        hsv2rgb(Lst(h,s,v))\n        Convert HSV to RGB.\n        See also: 1/ rgb2hsv 2/ rgb 3/ hsv \n        Ex1:hsv2rgb(220,75,49)\n        Ex2:hsv2rgb([0.0833,0.67,0.3])\n        Ex3:hsv2rgb(0.0833,0.67,0.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1247hsv2rgb = {"hsv2rgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1247hsv2rgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1246hsv2rgb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1247hsv2rgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hsv2rgb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hsv2rgb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1246hsv2rgb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1246hsv2rgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hsv2rgb", 1);

  /* "giacpy/auto-methods.pxi":7779
 * 
 *         '''
 *         return GiacMethods['hsv2rgb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hybrid_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hsv2rgb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7779, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7768
 *         return GiacMethods['hsv'](self,*args)
 * 
 *      def hsv2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv2rgb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hsv2rgb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7781
 *         return GiacMethods['hsv2rgb'](self,*args)
 * 
 *      def hybrid_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrid_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1249hybrid_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1248hybrid_solver, "From Giac's documentation:\n        Help for hybrid_solver:\n        hybrid_solver(Opt)\n        Argument for fsolve giving the method for solving a system of numerical equations.\n        See also: 1/ fsolve \n        Ex1: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],dnewton_solver)\n        Ex2: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrid_solver)\n        Ex3: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrids_solver)\n        Ex4: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridj_solver)\n        Ex5: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridsj_solver)\n        Ex6: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],newtonj_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1249hybrid_solver = {"hybrid_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1249hybrid_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1248hybrid_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1249hybrid_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hybrid_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hybrid_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1248hybrid_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1248hybrid_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hybrid_solver", 1);

  /* "giacpy/auto-methods.pxi":7795
 * 
 *         '''
 *         return GiacMethods['hybrid_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hybridj_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hybrid_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7795, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7781
 *         return GiacMethods['hsv2rgb'](self,*args)
 * 
 *      def hybrid_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrid_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hybrid_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7797
 *         return GiacMethods['hybrid_solver'](self,*args)
 * 
 *      def hybridj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridj_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1251hybridj_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1250hybridj_solver, "From Giac's documentation:\n        Help for hybridj_solver:\n        hybridj_solver(Opt)\n        Argument for fsolve giving the method for solving a system of numerical equations.\n        See also: 1/ fsolve \n        Ex1: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],dnewton_solver)\n        Ex2: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrid_solver)\n        Ex3: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrids_solver)\n        Ex4: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridj_solver)\n        Ex5: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridsj_solver)\n        Ex6: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],newtonj_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1251hybridj_solver = {"hybridj_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1251hybridj_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1250hybridj_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1251hybridj_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hybridj_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hybridj_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1250hybridj_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1250hybridj_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hybridj_solver", 1);

  /* "giacpy/auto-methods.pxi":7811
 * 
 *         '''
 *         return GiacMethods['hybridj_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hybrids_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hybridj_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7811, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7797
 *         return GiacMethods['hybrid_solver'](self,*args)
 * 
 *      def hybridj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridj_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hybridj_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7813
 *         return GiacMethods['hybridj_solver'](self,*args)
 * 
 *      def hybrids_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrids_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1253hybrids_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1252hybrids_solver, "From Giac's documentation:\n        Help for hybrids_solver:\n        hybrids_solver(Opt)\n        Argument for fsolve giving the method for solving a system of numerical equations.\n        See also: 1/ fsolve \n        Ex1: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],dnewton_solver)\n        Ex2: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrid_solver)\n        Ex3: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrids_solver)\n        Ex4: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridj_solver)\n        Ex5: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridsj_solver)\n        Ex6: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],newtonj_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1253hybrids_solver = {"hybrids_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1253hybrids_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1252hybrids_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1253hybrids_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hybrids_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hybrids_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1252hybrids_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1252hybrids_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hybrids_solver", 1);

  /* "giacpy/auto-methods.pxi":7827
 * 
 *         '''
 *         return GiacMethods['hybrids_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hybridsj_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hybrids_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7827, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7813
 *         return GiacMethods['hybridj_solver'](self,*args)
 * 
 *      def hybrids_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrids_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hybrids_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7829
 *         return GiacMethods['hybrids_solver'](self,*args)
 * 
 *      def hybridsj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridsj_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1255hybridsj_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1254hybridsj_solver, "From Giac's documentation:\n        Help for hybridsj_solver:\n        hybridsj_solver(Opt)\n        Argument for fsolve giving the method for solving a system of numerical equations.\n        See also: 1/ fsolve \n        Ex1: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],dnewton_solver)\n        Ex2: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrid_solver)\n        Ex3: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrids_solver)\n        Ex4: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridj_solver)\n        Ex5: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridsj_solver)\n        Ex6: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],newtonj_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1255hybridsj_solver = {"hybridsj_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1255hybridsj_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1254hybridsj_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1255hybridsj_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hybridsj_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hybridsj_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1254hybridsj_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1254hybridsj_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hybridsj_solver", 1);

  /* "giacpy/auto-methods.pxi":7843
 * 
 *         '''
 *         return GiacMethods['hybridsj_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hyp2exp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hybridsj_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7843, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7829
 *         return GiacMethods['hybrids_solver'](self,*args)
 * 
 *      def hybridsj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridsj_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hybridsj_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7845
 *         return GiacMethods['hybridsj_solver'](self,*args)
 * 
 *      def hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyp2exp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1257hyp2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1256hyp2exp, "From Giac's documentation:\n        Help for hyp2exp:\n        hyp2exp(ExprHyperb)\n        Transforms the hyperbolic functions to the exponential function.\n        See also: 1/ halftan_hyp2exp \n        Ex1:hyp2exp(cosh(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1257hyp2exp = {"hyp2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1257hyp2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1256hyp2exp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1257hyp2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hyp2exp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hyp2exp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1256hyp2exp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1256hyp2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hyp2exp", 1);

  /* "giacpy/auto-methods.pxi":7854
 * 
 *         '''
 *         return GiacMethods['hyp2exp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hyperbola(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hyp2exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7854, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7845
 *         return GiacMethods['hybridsj_solver'](self,*args)
 * 
 *      def hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyp2exp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hyp2exp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7856
 *         return GiacMethods['hyp2exp'](self,*args)
 * 
 *      def hyperbola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyperbola:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1259hyperbola(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1258hyperbola, "From Giac's documentation:\n        Help for hyperbola:\n        hyperbola(Focus(F1),Focus(F2),(Pnt(M) or Real(a)))\n        hyperbola(F1,F2,M)=hyperbola with foci F1,F2 through M or (|MF1-MF2|=2*a geo2d) and hyperbola(p(x,y)) draws the conic if deg(p)=2.\n        See also: 1/ ellipse 2/ parabola \n        Ex1:hyperbola(-1,1,point(1+i))\n        Ex2:hyperbola(-1,1,sqrt(5)-1)\n        Ex3:hyperbola(point(-1,0,0),point(1,0,0),point(1,1,1))\n        Ex4:hyperbola(x^2-y^2+y+2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1259hyperbola = {"hyperbola", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1259hyperbola, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1258hyperbola};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1259hyperbola(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hyperbola (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hyperbola", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1258hyperbola(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1258hyperbola(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hyperbola", 1);

  /* "giacpy/auto-methods.pxi":7868
 * 
 *         '''
 *         return GiacMethods['hyperbola'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def hypercube_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hyperbola); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7868, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7856
 *         return GiacMethods['hyp2exp'](self,*args)
 * 
 *      def hyperbola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyperbola:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hyperbola", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7870
 *         return GiacMethods['hyperbola'](self,*args)
 * 
 *      def hypercube_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hypercube_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1261hypercube_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1260hypercube_graph, "From Giac's documentation:\n        Help for hypercube_graph:\n        hypercube_graph(Intg(n))\n        Constructs and returns a hypercube graph in dimension n (with 2^n vertices).\n        See also: 1/ graph \n        Ex1:hypercube_graph(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1261hypercube_graph = {"hypercube_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1261hypercube_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1260hypercube_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1261hypercube_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("hypercube_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "hypercube_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1260hypercube_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1260hypercube_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("hypercube_graph", 1);

  /* "giacpy/auto-methods.pxi":7879
 * 
 *         '''
 *         return GiacMethods['hypercube_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def iPart(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_hypercube_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7879, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7870
 *         return GiacMethods['hyperbola'](self,*args)
 * 
 *      def hypercube_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hypercube_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.hypercube_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7881
 *         return GiacMethods['hypercube_graph'](self,*args)
 * 
 *      def iPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iPart:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1263iPart(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1262iPart, "From Giac's documentation:\n        Help for iPart:\n        iPart(Real||LstReal)\n        Returns the argument without its fractional part (type=DOM_FLOAT).\n        See also: 1/ fPart 2/ floor 3/ trunc \n        Ex1:iPart(4.3)\n        Ex2:iPart(sqrt(2))\n        Ex3:iPart(4.3,sqrt(2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1263iPart = {"iPart", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1263iPart, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1262iPart};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1263iPart(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iPart (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "iPart", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1262iPart(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1262iPart(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iPart", 1);

  /* "giacpy/auto-methods.pxi":7892
 * 
 *         '''
 *         return GiacMethods['iPart'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def iabcuv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_iPart); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7892, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7881
 *         return GiacMethods['hypercube_graph'](self,*args)
 * 
 *      def iPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iPart:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.iPart", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7894
 *         return GiacMethods['iPart'](self,*args)
 * 
 *      def iabcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iabcuv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1265iabcuv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1264iabcuv, "From Giac's documentation:\n        Help for iabcuv:\n        iabcuv(Intg(a),Intg(b),Intg(c))\n        Returns [u,v] such that au+bv=c for 3 integers a,b,c.\n        See also: 1/ iegcd 2/ abcuv \n        Ex1:iabcuv(21,28,7)\n        Ex2:iabcuv(21,28,14)\n        Ex3:iabcuv(21,28,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1265iabcuv = {"iabcuv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1265iabcuv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1264iabcuv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1265iabcuv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iabcuv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "iabcuv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1264iabcuv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1264iabcuv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iabcuv", 1);

  /* "giacpy/auto-methods.pxi":7905
 * 
 *         '''
 *         return GiacMethods['iabcuv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ibasis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_iabcuv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7905, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7894
 *         return GiacMethods['iPart'](self,*args)
 * 
 *      def iabcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iabcuv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.iabcuv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7907
 *         return GiacMethods['iabcuv'](self,*args)
 * 
 *      def ibasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibasis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1267ibasis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1266ibasis, "From Giac's documentation:\n        Help for ibasis:\n        ibasis(Lst(Vect,..,Vect),Lst(Vect,..,Vect))\n        Basis of the intersection of two vector spaces.\n        See also: 1/ basis \n        Ex1:ibasis([[1,0,0],[0,1,0]],[[1,1,1],[0,0,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1267ibasis = {"ibasis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1267ibasis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1266ibasis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1267ibasis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ibasis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ibasis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1266ibasis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1266ibasis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ibasis", 1);

  /* "giacpy/auto-methods.pxi":7916
 * 
 *         '''
 *         return GiacMethods['ibasis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ibpdv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ibasis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7916, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7907
 *         return GiacMethods['iabcuv'](self,*args)
 * 
 *      def ibasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibasis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ibasis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7918
 *         return GiacMethods['ibasis'](self,*args)
 * 
 *      def ibpdv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpdv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1269ibpdv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1268ibpdv, "From Giac's documentation:\n        Help for ibpdv:\n        ibpdv(Expr(f(x)),Expr(v(x)),[Var(x)],[Real(a)],[Real(b)])\n        Integration by parts of f(x)=u(x)*v'(x) with f(x) as 1st argument and v(x) (or 0) as 2nd argument. You can specify a variable of integration and also calculate the integral (bounds a and b).\n        See also: 1/ ibpu 2/ int \n        Ex1:ibpdv(ln(x),x)\n        Ex2:ibpdv(ln(x),x,x,1,3)\n        Ex3:ibpdv(x*ln(x),x^2/2)\n        Ex4:ibpdv([x*ln(x),-1],0)\n        Ex5:ibpdv(ibpdv(ln(x),x,x,2,3),0,x,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1269ibpdv = {"ibpdv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1269ibpdv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1268ibpdv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1269ibpdv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ibpdv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ibpdv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1268ibpdv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1268ibpdv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ibpdv", 1);

  /* "giacpy/auto-methods.pxi":7931
 * 
 *         '''
 *         return GiacMethods['ibpdv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ibpu(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ibpdv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7931, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7918
 *         return GiacMethods['ibasis'](self,*args)
 * 
 *      def ibpdv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpdv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ibpdv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7933
 *         return GiacMethods['ibpdv'](self,*args)
 * 
 *      def ibpu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1271ibpu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1270ibpu, "From Giac's documentation:\n        Help for ibpu:\n        ibpu(Expr(f(x)),Expr(u(x)),[Var(x)],[Real(a)],[Real(b)])\n        Integration by parts of f(x)=u(x)*v'(x) with f(x) as 1st argument and u(x) (or 0) as 2nd argument. You can specify a variable of integration and also calculate the integral (bounds a and b).\n        See also: 1/ ibpdv 2/ int \n        Ex1:ibpu(ln(x),ln(x))\n        Ex2:ibpu(ln(x),ln(x),x,1,3)\n        Ex3:ibpu(x*ln(x),ln(x))\n        Ex4:ibpu([x*ln(x),-1],0)\n        Ex5:ibpu(ibpu(ln(x),ln(x),x,2,3),0,x,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1271ibpu = {"ibpu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1271ibpu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1270ibpu};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1271ibpu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ibpu (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ibpu", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1270ibpu(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1270ibpu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ibpu", 1);

  /* "giacpy/auto-methods.pxi":7946
 * 
 *         '''
 *         return GiacMethods['ibpu'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ibpu); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7946, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7933
 *         return GiacMethods['ibpdv'](self,*args)
 * 
 *      def ibpu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpu:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ibpu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7948
 *         return GiacMethods['ibpu'](self,*args)
 * 
 *      def icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1273icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1272icdf, "From Giac's documentation:\n        Help for icdf:\n        icdf(Func,FuncParams)\n        Inverse cumulative distribution function.\n        See also: 1/ cdf 2/ binomial_icdf 3/ normald_icdf \n        Ex1:icdf(binomial,10,0.5,0.6)\n        Ex2:icdf(normald,0.0,1.0,0.975)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1273icdf = {"icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1273icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1272icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1273icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1272icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1272icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("icdf", 1);

  /* "giacpy/auto-methods.pxi":7958
 * 
 *         '''
 *         return GiacMethods['icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ichinrem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7958, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7948
 *         return GiacMethods['ibpu'](self,*args)
 * 
 *      def icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7960
 *         return GiacMethods['icdf'](self,*args)
 * 
 *      def ichinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichinrem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1275ichinrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1274ichinrem, "From Giac's documentation:\n        Help for ichinrem:\n        ichinrem(LstIntg(a,p),LstIntg(b,q))\n        Chinese remainders for integers.\n        See also: 1/ gcd 2/ fracmod 3/ chinrem 4/ chrem \n        Ex1:ichinrem([2,7],[3,5])\n        Ex2:ichinrem([2%7,3%5])\n        Ex3:ichinrem([2%7,3%5,1%9])\n        Ex4:ichinrem([(x+1)%2,(x+2)%3,(3*x-1)%5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1275ichinrem = {"ichinrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1275ichinrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1274ichinrem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1275ichinrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ichinrem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ichinrem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1274ichinrem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1274ichinrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ichinrem", 1);

  /* "giacpy/auto-methods.pxi":7972
 * 
 *         '''
 *         return GiacMethods['ichinrem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ichrem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ichinrem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7972, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7960
 *         return GiacMethods['icdf'](self,*args)
 * 
 *      def ichinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichinrem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ichinrem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7974
 *         return GiacMethods['ichinrem'](self,*args)
 * 
 *      def ichrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichrem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1277ichrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1276ichrem, "From Giac's documentation:\n        Help for ichrem:\n        ichrem(LstIntg(a,p),LstIntg(b,q))\n        Chinese remainders for integers.\n        See also: 1/ gcd 2/ fracmod 3/ chinrem 4/ chrem \n        Ex1:ichrem([2,7],[3,5])\n        Ex2:ichrem([2%7,3%5])\n        Ex3:ichrem([2%7,3%5,1%9])\n        Ex4:ichrem([(x+1)%2,(x+2)%3,(3*x-1)%5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1277ichrem = {"ichrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1277ichrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1276ichrem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1277ichrem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ichrem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ichrem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1276ichrem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1276ichrem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ichrem", 1);

  /* "giacpy/auto-methods.pxi":7986
 * 
 *         '''
 *         return GiacMethods['ichrem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def icomp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ichrem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7986, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7974
 *         return GiacMethods['ichinrem'](self,*args)
 * 
 *      def ichrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichrem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ichrem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":7988
 *         return GiacMethods['ichrem'](self,*args)
 * 
 *      def icomp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icomp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1279icomp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1278icomp, "From Giac's documentation:\n        Help for icomp:\n        icomp(Intg(n),Intg(k),[zeros=true||false])\n        Returns the list of compositions of n into k parts.\n        See also: 1/ sum \n        Ex1:icomp(4,2)\n        Ex2:icomp(6,3,zeros=false)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1279icomp = {"icomp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1279icomp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1278icomp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1279icomp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("icomp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "icomp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1278icomp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1278icomp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("icomp", 1);

  /* "giacpy/auto-methods.pxi":7998
 * 
 *         '''
 *         return GiacMethods['icomp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def icontent(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_icomp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 7998, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":7988
 *         return GiacMethods['ichrem'](self,*args)
 * 
 *      def icomp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icomp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.icomp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8000
 *         return GiacMethods['icomp'](self,*args)
 * 
 *      def icontent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icontent:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1281icontent(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1280icontent, "From Giac's documentation:\n        Help for icontent:\n        icontent(Poly,[Var])\n        GCD of the integer coefficients of a polynomial.\n        See also: 1/  \n        Ex1:icontent(24x^3+6x^2-12x+18)\n        Ex2:icontent(24t^3+6t^2-12t+18,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1281icontent = {"icontent", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1281icontent, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1280icontent};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1281icontent(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("icontent (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "icontent", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1280icontent(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1280icontent(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("icontent", 1);

  /* "giacpy/auto-methods.pxi":8010
 * 
 *         '''
 *         return GiacMethods['icontent'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def icosahedron(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_icontent); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8010, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8000
 *         return GiacMethods['icomp'](self,*args)
 * 
 *      def icontent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icontent:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.icontent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8012
 *         return GiacMethods['icontent'](self,*args)
 * 
 *      def icosahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icosahedron:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1283icosahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1282icosahedron, "From Giac's documentation:\n        Help for icosahedron:\n        icosahedron(Pnt(A),Pnt(B),Pnt(C))\n        Draws an icosahedron with center A, vertex B and such that the plane ABC contains one vertex among the 5 nearest vertices from B.\n        See also: 1/ octahedron 2/ dodecahedron 3/ cube 4/ tetrahedron \n        Ex1:icosahedron([0,0,0],[sqrt(5),0,0],[1,2,0])\n        Ex2:icosahedron(evalf([0,0,0],[3,2,4],[1,1,0]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1283icosahedron = {"icosahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1283icosahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1282icosahedron};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1283icosahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("icosahedron (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "icosahedron", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1282icosahedron(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1282icosahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("icosahedron", 1);

  /* "giacpy/auto-methods.pxi":8022
 * 
 *         '''
 *         return GiacMethods['icosahedron'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def id(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_icosahedron); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8022, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8012
 *         return GiacMethods['icontent'](self,*args)
 * 
 *      def icosahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icosahedron:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.icosahedron", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8024
 *         return GiacMethods['icosahedron'](self,*args)
 * 
 *      def id(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for id:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1285id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1284id, "From Giac's documentation:\n        Help for id:\n        id(Seq)\n        The name of the identity function (\342\204\235^n -> \342\204\235^n).\n        See also: 1/ sq 2/ sqrt \n        Ex1:id(1,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1285id = {"id", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1285id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1284id};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1285id(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("id (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "id", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1284id(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1284id(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("id", 1);

  /* "giacpy/auto-methods.pxi":8033
 * 
 *         '''
 *         return GiacMethods['id'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def identify_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_id); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8033, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8024
 *         return GiacMethods['icosahedron'](self,*args)
 * 
 *      def id(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for id:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8035
 *         return GiacMethods['id'](self,*args)
 * 
 *      def identify_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identify_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1287identify_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1286identify_graph, "From Giac's documentation:\n        Help for identify_graph:\n        identify_graph(Graph(G))\n        Returns the list of named graphs known to Giac which are isomorphic to G.\n        See also: 1/ is_isomorphic 2/ graph \n        Ex1:identify_graph(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1287identify_graph = {"identify_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1287identify_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1286identify_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1287identify_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("identify_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "identify_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1286identify_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1286identify_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("identify_graph", 1);

  /* "giacpy/auto-methods.pxi":8044
 * 
 *         '''
 *         return GiacMethods['identify_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def identity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_identify_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8044, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8035
 *         return GiacMethods['id'](self,*args)
 * 
 *      def identify_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identify_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.identify_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8046
 *         return GiacMethods['identify_graph'](self,*args)
 * 
 *      def identity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1289identity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1288identity, "From Giac's documentation:\n        Help for identity:\n        identity(Intg(n))\n        Returns the identity matrix of specified dimension n.\n        See also: 1/ ranm \n        Ex1:identity(3)\n        Ex2:identity(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1289identity = {"identity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1289identity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1288identity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1289identity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("identity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "identity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1288identity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1288identity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("identity", 1);

  /* "giacpy/auto-methods.pxi":8056
 * 
 *         '''
 *         return GiacMethods['identity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def idivis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_identity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8056, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8046
 *         return GiacMethods['identify_graph'](self,*args)
 * 
 *      def identity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.identity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8058
 *         return GiacMethods['identity'](self,*args)
 * 
 *      def idivis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idivis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1291idivis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1290idivis, "From Giac's documentation:\n        Help for idivis:\n        idivis(Intg(a) or LstIntg)\n        Returns the list of divisors of an integer.\n        See also: 1/ divis 2/ ifactors \n        Ex1:idivis(36)\n        Ex2:idivis([36,49])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1291idivis = {"idivis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1291idivis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1290idivis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1291idivis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("idivis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "idivis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1290idivis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1290idivis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("idivis", 1);

  /* "giacpy/auto-methods.pxi":8068
 * 
 *         '''
 *         return GiacMethods['idivis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def idn(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_idivis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8068, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8058
 *         return GiacMethods['identity'](self,*args)
 * 
 *      def idivis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idivis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.idivis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8070
 *         return GiacMethods['idivis'](self,*args)
 * 
 *      def idn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idn:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1293idn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1292idn, "From Giac's documentation:\n        Help for idn:\n        idn(Intg(n))\n        Returns the identity matrix of specified dimension n.\n        See also: 1/ ranm \n        Ex1:idn(3)\n        Ex2:idn(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1293idn = {"idn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1293idn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1292idn};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1293idn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("idn (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "idn", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1292idn(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1292idn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("idn", 1);

  /* "giacpy/auto-methods.pxi":8080
 * 
 *         '''
 *         return GiacMethods['idn'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def idwt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_idn); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8080, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8070
 *         return GiacMethods['idivis'](self,*args)
 * 
 *      def idn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idn:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.idn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8082
 *         return GiacMethods['idn'](self,*args)
 * 
 *      def idwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idwt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1295idwt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1294idwt, "From Giac's documentation:\n        Help for idwt:\n        idwt((Lst||Mtrx)(T),[opts])\n        Returns the original data from its discrete wavelet transform if called with the same options.\n        See also: 1/ dwt 2/ fft 3/ ifft \n        Ex1: t:=dwt([0.0,0.5,0.25,1.0,0.75,-0.25,-0.5,0.0]):;idwt(t)\n        Ex2: t:=dwt([[15,25,5,70],[21,33,12,7],[64,18,50,10],[5,17,35,28]]):;idwt(t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1295idwt = {"idwt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1295idwt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1294idwt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1295idwt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("idwt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "idwt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1294idwt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1294idwt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("idwt", 1);

  /* "giacpy/auto-methods.pxi":8092
 * 
 *         '''
 *         return GiacMethods['idwt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def iegcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_idwt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8092, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8082
 *         return GiacMethods['idn'](self,*args)
 * 
 *      def idwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idwt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.idwt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8094
 *         return GiacMethods['idwt'](self,*args)
 * 
 *      def iegcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iegcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1297iegcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1296iegcd, "From Giac's documentation:\n        Help for iegcd:\n        iegcd(Intg,Intg)\n        Extended greatest common divisor of 2 integers.\n        See also: 1/ gcd 2/ iabcuv 3/ egcd \n        Ex1:iegcd(45,75)\n        Ex2:iegcd(21,28)\n        Ex3:iegcd(30,49)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1297iegcd = {"iegcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1297iegcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1296iegcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1297iegcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iegcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "iegcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1296iegcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1296iegcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iegcd", 1);

  /* "giacpy/auto-methods.pxi":8105
 * 
 *         '''
 *         return GiacMethods['iegcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ifactor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_iegcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8105, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8094
 *         return GiacMethods['idwt'](self,*args)
 * 
 *      def iegcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iegcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.iegcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8107
 *         return GiacMethods['iegcd'](self,*args)
 * 
 *      def ifactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1299ifactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1298ifactor, "From Giac's documentation:\n        Help for ifactor:\n        ifactor(Intg(a))\n        Factorization of an integer into prime factors.\n        See also: 1/ factor 2/ ecm_factor \n        Ex1:ifactor(50)\n        Ex2:ifactor(123456789)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1299ifactor = {"ifactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1299ifactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1298ifactor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1299ifactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ifactor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ifactor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1298ifactor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1298ifactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ifactor", 1);

  /* "giacpy/auto-methods.pxi":8117
 * 
 *         '''
 *         return GiacMethods['ifactor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ifactors(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ifactor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8117, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8107
 *         return GiacMethods['iegcd'](self,*args)
 * 
 *      def ifactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ifactor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8119
 *         return GiacMethods['ifactor'](self,*args)
 * 
 *      def ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactors:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1301ifactors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1300ifactors, "From Giac's documentation:\n        Help for ifactors:\n        ifactors(Intg(a) or LstIntg)\n        Returns the list of prime factors of an integer (each factor is followed by its multiplicity).\n        See also: 1/ ifactor 2/ factors \n        Ex1:ifactors(36)\n        Ex2:ifactors([36,52])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1301ifactors = {"ifactors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1301ifactors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1300ifactors};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1301ifactors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ifactors (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ifactors", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1300ifactors(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1300ifactors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ifactors", 1);

  /* "giacpy/auto-methods.pxi":8129
 * 
 *         '''
 *         return GiacMethods['ifactors'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ifourier(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ifactors); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8129, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8119
 *         return GiacMethods['ifactor'](self,*args)
 * 
 *      def ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactors:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ifactors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8131
 *         return GiacMethods['ifactors'](self,*args)
 * 
 *      def ifourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifourier:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1303ifourier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1302ifourier, "From Giac's documentation:\n        Help for ifourier:\n        ifourier(Expr(F(s)),[Var(s),[Var(x)]])\n        Returns the inverse Fourier transform f(x) of F(s).\n        See also: 1/ fourier 2/ fourier_cn 3/ ifft \n        Ex1:ifourier(2*pi*(Dirac(s)-sign(s)*sin(s)),s,x)\n        Ex2:ifourier(-2/(s^2-1),s,x)\n        Ex3:ifourier(pi/(exp(pi*s/4)+exp(-pi*s/4)),s,x)\n        Ex4:ifourier(6*pi*exp(-exp(-3*s)-3*s),s,x)\n        Ex5:ifourier(pi*ugamma(0,4*abs(s)),s,x)\n        Ex6:ifourier(fourier(exp(-abs(x)),x,s)^2,s,x)\n        Ex7:ifourier(sinc(s),s,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1303ifourier = {"ifourier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1303ifourier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1302ifourier};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1303ifourier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ifourier (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ifourier", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1302ifourier(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1302ifourier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ifourier", 1);

  /* "giacpy/auto-methods.pxi":8146
 * 
 *         '''
 *         return GiacMethods['ifourier'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def igamma(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ifourier); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8146, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8131
 *         return GiacMethods['ifactors'](self,*args)
 * 
 *      def ifourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifourier:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ifourier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8148
 *         return GiacMethods['ifourier'](self,*args)
 * 
 *      def igamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igamma:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1305igamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1304igamma, "From Giac's documentation:\n        Help for igamma:\n        igamma(Real(a),Real(x),[1])\n        Calculates of gamma at a point (a,x). If a and x>0, igamma(a,x)=int(e^{-t}*t^{a-1},t=0..x), (igamma(a,x,1)=igamma(a,x)/Gamma(a)).\n        See also: 1/ Psi 2/ Beta 3/ Gamma 3/ ugamma \n        Ex1:igamma(5.0,2.0)\n        Ex2:igamma(-5.1,2.1)\n        Ex3:igamma(5.0,2.0,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1305igamma = {"igamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1305igamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1304igamma};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1305igamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("igamma (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "igamma", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1304igamma(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1304igamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("igamma", 1);

  /* "giacpy/auto-methods.pxi":8159
 * 
 *         '''
 *         return GiacMethods['igamma'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def igcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_igamma); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8159, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8148
 *         return GiacMethods['ifourier'](self,*args)
 * 
 *      def igamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igamma:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.igamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8161
 *         return GiacMethods['igamma'](self,*args)
 * 
 *      def igcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1307igcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1306igcd, "From Giac's documentation:\n        Help for igcd:\n        igcd((Intg(a) or Poly),(Intg(b) or Poly))\n        Returns the greatest common divisor of 2 polynomials of several variables or of 2 integers or of 2 rationals.\n        See also: 1/ lcm 2/ euler 2/ modgcd 3/ ezgcd 4/ psrgcd 5/ heugcd 6/ Gcd \n        Ex1:igcd(45,75)\n        Ex2:igcd(15/7,50/9)\n        Ex3:igcd(x^2-2*x+1,x^3-1)\n        Ex4:igcd(t^2-2*t+1,t^2+t-2)\n        Ex5:igcd((x^2-1)*(y^2-1)*z^2,x^3*y^3*z+(-(y^3))*z+x^3*z-z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1307igcd = {"igcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1307igcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1306igcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1307igcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("igcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "igcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1306igcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1306igcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("igcd", 1);

  /* "giacpy/auto-methods.pxi":8174
 * 
 *         '''
 *         return GiacMethods['igcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def igcdex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_igcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8174, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8161
 *         return GiacMethods['igamma'](self,*args)
 * 
 *      def igcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.igcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8176
 *         return GiacMethods['igcd'](self,*args)
 * 
 *      def igcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcdex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1309igcdex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1308igcdex, "From Giac's documentation:\n        Help for igcdex:\n        igcdex(Intg,Intg)\n        Extended greatest common divisor of 2 integers.\n        See also: 1/ gcd 2/ iabcuv 3/ egcd \n        Ex1:igcdex(45,75)\n        Ex2:igcdex(21,28)\n        Ex3:igcdex(30,49)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1309igcdex = {"igcdex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1309igcdex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1308igcdex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1309igcdex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("igcdex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "igcdex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1308igcdex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1308igcdex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("igcdex", 1);

  /* "giacpy/auto-methods.pxi":8187
 * 
 *         '''
 *         return GiacMethods['igcdex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ihermite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_igcdex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8187, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8176
 *         return GiacMethods['igcd'](self,*args)
 * 
 *      def igcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcdex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.igcdex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8189
 *         return GiacMethods['igcdex'](self,*args)
 * 
 *      def ihermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ihermite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1311ihermite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1310ihermite, "From Giac's documentation:\n        Help for ihermite:\n        ihermite(Mtrx(A))\n        Hermite normal form of a matrix with coefficients in \342\204\244 : returns L,U such that L is invertible in \342\204\244, U is upper triangular and U=L*A.\n        See also: 1/ ismith \n        Ex1:ihermite([[9,-36,30], [-36,192,-180], [30,-180,180]])\n        Ex2:ihermite([[1,2,3],[4,5,6],[7,8,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1311ihermite = {"ihermite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1311ihermite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1310ihermite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1311ihermite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ihermite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ihermite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1310ihermite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1310ihermite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ihermite", 1);

  /* "giacpy/auto-methods.pxi":8199
 * 
 *         '''
 *         return GiacMethods['ihermite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ilaplace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ihermite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8199, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8189
 *         return GiacMethods['igcdex'](self,*args)
 * 
 *      def ihermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ihermite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ihermite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8201
 *         return GiacMethods['ihermite'](self,*args)
 * 
 *      def ilaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ilaplace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1313ilaplace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1312ilaplace, "From Giac's documentation:\n        Help for ilaplace:\n        ilaplace(Expr,[Var],[IlapVar])\n        Inverse Laplace transform of a rational fraction.\n        See also: 1/ laplace 2/ ztrans 3/ invztrans 4/ Heaviside \n        Ex1:ilaplace(1/(x^2+1)^2)\n        Ex2:ilaplace(s/(s^4-1),s,x)\n        Ex3:ilaplace(exp(-s)/s,s,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1313ilaplace = {"ilaplace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1313ilaplace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1312ilaplace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1313ilaplace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ilaplace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ilaplace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1312ilaplace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1312ilaplace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ilaplace", 1);

  /* "giacpy/auto-methods.pxi":8212
 * 
 *         '''
 *         return GiacMethods['ilaplace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def im(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ilaplace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8212, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8201
 *         return GiacMethods['ihermite'](self,*args)
 * 
 *      def ilaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ilaplace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ilaplace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8214
 *         return GiacMethods['ilaplace'](self,*args)
 * 
 *      def im(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for im:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1315im(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1314im, "From Giac's documentation:\n        Help for im:\n        im(Cplx)\n        Returns the imaginary part of a complex number.\n        See also: 1/ re 2/ conj \n        Ex1:im(1+2*i)\n        Ex2:im((1+2*i)^2)\n        Ex3:im([1+2*i,(1+2*i)^2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1315im = {"im", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1315im, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1314im};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1315im(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("im (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "im", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1314im(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1314im(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("im", 1);

  /* "giacpy/auto-methods.pxi":8225
 * 
 *         '''
 *         return GiacMethods['im'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def imag(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_im); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8225, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8214
 *         return GiacMethods['ilaplace'](self,*args)
 * 
 *      def im(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for im:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.im", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8227
 *         return GiacMethods['im'](self,*args)
 * 
 *      def imag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imag:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1317imag(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1316imag, "From Giac's documentation:\n        Help for imag:\n        imag(Cplx)\n        Returns the imaginary part of a complex number.\n        See also: 1/ re 2/ conj \n        Ex1:imag(1+2*i)\n        Ex2:imag((1+2*i)^2)\n        Ex3:imag([1+2*i,(1+2*i)^2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1317imag = {"imag", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1317imag, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1316imag};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1317imag(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("imag (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "imag", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1316imag(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1316imag(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("imag", 1);

  /* "giacpy/auto-methods.pxi":8238
 * 
 *         '''
 *         return GiacMethods['imag'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def image(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_imag); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8238, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8227
 *         return GiacMethods['im'](self,*args)
 * 
 *      def imag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imag:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.imag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8240
 *         return GiacMethods['imag'](self,*args)
 * 
 *      def image(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for image:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1319image(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1318image, "From Giac's documentation:\n        Help for image:\n        image(Mtrx(M)||Strng(imgfname))\n        Returns the image of a linear map with matrix M or an image object loaded from file imgfname.\n        See also: 1/ ker 2/ rref \n        Ex1:image([[1,2],[3,6]])\n        Ex2:image([[1,2,3],[1,3,6],[2,5,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1319image = {"image", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1319image, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1318image};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1319image(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("image (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "image", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1318image(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1318image(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("image", 1);

  /* "giacpy/auto-methods.pxi":8250
 * 
 *         '''
 *         return GiacMethods['image'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def imfplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_image); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8250, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8240
 *         return GiacMethods['imag'](self,*args)
 * 
 *      def image(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for image:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.image", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8252
 *         return GiacMethods['image'](self,*args)
 * 
 *      def imfplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imfplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1321imfplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1320imfplot, "From Giac's documentation:\n        Help for imfplot:\n        imfplot(Lst(imf),[opts])\n        Displays selected intrinsic mode functions in a stacked layout.\n        See also: 1/ emd \n        Ex1:imfplot(emd(apply(x->cos(10*x^2*pi),linspace(-pi,pi)),residue=false))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1321imfplot = {"imfplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1321imfplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1320imfplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1321imfplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("imfplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "imfplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1320imfplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1320imfplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("imfplot", 1);

  /* "giacpy/auto-methods.pxi":8261
 * 
 *         '''
 *         return GiacMethods['imfplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def implicitdiff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_imfplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8261, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8252
 *         return GiacMethods['image'](self,*args)
 * 
 *      def imfplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imfplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.imfplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8263
 *         return GiacMethods['imfplot'](self,*args)
 * 
 *      def implicitdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitdiff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1323implicitdiff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1322implicitdiff, "From Giac's documentation:\n        Help for implicitdiff:\n        implicitdiff(constr,[depvars],y,diffvars)\n        Implicit differentiation.\n        See also: 1/ diff \n        Ex1:implicitdiff(x^2*y+y^2=1,y,x)\n        Ex2:implicitdiff(R=P*V/T,P,T)\n        Ex3:implicitdiff([x^2+y=z,x+y*z=1],[y(x),z(x)],[y,z],x)\n        Ex4:implicitdiff(x*y,-2x^3+15x^2*y+11y^3-24y=0,y(x),x$2)\n        Ex5:implicitdiff((x-u)^2+(y-v)^2,[x^2/4+y^2/9=1,(u-3)^2+(v+5)^2=1],[v(u,x),y(u,x)],u,x)\n        Ex6:implicitdiff(x*y*z,-2x^3+15x^2*y+11y^3-24y=0,[x,z,y],order=1)\n        Ex7:implicitdiff(x*y*z,-2x^3+15x^2*y+11y^3-24y=0,[x,z,y],order=2,[1,-1,0])\n        Ex8: pd:=implicitdiff(x*y*z,-2x^3+15x^2*y+11y^3-24y=0,[x,z,y],order=4,[0,z,0]);pd[4,0,0]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1323implicitdiff = {"implicitdiff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1323implicitdiff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1322implicitdiff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1323implicitdiff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("implicitdiff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "implicitdiff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1322implicitdiff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1322implicitdiff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("implicitdiff", 1);

  /* "giacpy/auto-methods.pxi":8279
 * 
 *         '''
 *         return GiacMethods['implicitdiff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def implicitplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_implicitdiff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8279, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8263
 *         return GiacMethods['imfplot'](self,*args)
 * 
 *      def implicitdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitdiff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.implicitdiff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8281
 *         return GiacMethods['implicitdiff'](self,*args)
 * 
 *      def implicitplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1325implicitplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1324implicitplot, "From Giac's documentation:\n        Help for implicitplot:\n        implicitplot(Expr,Var1,Var2)\n        plotimplicit(f(x,y),x,y) or plotimplicit(f(x,y),[x,y]) draws graph of f(x,y)=0.\n        See also: 1/ plotcontour 2/ unfactored 3/ plotinequation \n        Ex1:implicitplot(x^2+y^2-1,x,y)\n        Ex2:implicitplot(x^4+y^4=x^2-y^2)\n        Ex3:implicitplot(x^2+y^2-1,x,y,unfactored)\n        Ex4:implicitplot(x^2+4*y^3-1)\n        Ex5:implicitplot(x^2+4*y^3-k)$(k=-5..5)\n        Ex6:implicitplot(y^3=x^3-x^2,x,y,xstep=0.1,ystep=0.1)\n        Ex7:implicitplot(y^3=x^3-x^2,[x,y],xstep=0.1,ystep=0.1)\n        Ex8:implicitplot((x+5)^2+(y+4)^2-1,x=-6..-4,y=-5..-3)\n        Ex9:implicitplot((x+5)^2+(y+4)^2-1,[x=-6..-4,y=-5..-3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1325implicitplot = {"implicitplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1325implicitplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1324implicitplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1325implicitplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("implicitplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "implicitplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1324implicitplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1324implicitplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("implicitplot", 1);

  /* "giacpy/auto-methods.pxi":8298
 * 
 *         '''
 *         return GiacMethods['implicitplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def import_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_implicitplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8298, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8281
 *         return GiacMethods['implicitdiff'](self,*args)
 * 
 *      def implicitplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.implicitplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8300
 *         return GiacMethods['implicitplot'](self,*args)
 * 
 *      def import_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for import_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1327import_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1326import_graph, "From Giac's documentation:\n        Help for import_graph:\n        import_graph(Str(\"filename\"),[opts])\n        Returns the graph constructed from instructions in the file 'filename' in dot/lst format, or \"undef\" on failure.\n        Ex1:import_graph(\"K5.dot\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1327import_graph = {"import_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1327import_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1326import_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1327import_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("import_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "import_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1326import_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1326import_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_graph", 1);

  /* "giacpy/auto-methods.pxi":8308
 * 
 *         '''
 *         return GiacMethods['import_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inString(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_import_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8308, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8300
 *         return GiacMethods['implicitplot'](self,*args)
 * 
 *      def import_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for import_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.import_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8310
 *         return GiacMethods['import_graph'](self,*args)
 * 
 *      def inString(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inString:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1329inString(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1328inString, "From Giac's documentation:\n        Help for inString:\n        inString(Str(l),Elem(e))\n        Tests if e is in the string l (returns -1 or k if l[k]=e).\n        See also: 1/ contains \n        Ex1:inString(\"abcd\",\"b\")\n        Ex2:inString(\"abcd\",\"e\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1329inString = {"inString", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1329inString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1328inString};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1329inString(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inString (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inString", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1328inString(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1328inString(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inString", 1);

  /* "giacpy/auto-methods.pxi":8320
 * 
 *         '''
 *         return GiacMethods['inString'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def in_ideal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inString); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8320, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8310
 *         return GiacMethods['import_graph'](self,*args)
 * 
 *      def inString(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inString:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8322
 *         return GiacMethods['inString'](self,*args)
 * 
 *      def in_ideal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for in_ideal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1331in_ideal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1330in_ideal, "From Giac's documentation:\n        Help for in_ideal:\n        in_ideal(Poly,Lst,LstVar,[order])\n        Checks whether a polynomial or list of polynomials belongs to an ideal given by a Grobner basis (2nd argument) with respect to a variable list.\n        See also: 1/ gbasis 2/ greduce \n        Ex1:in_ideal((x+y)^2,[y^2,x^2+2*x*y],[x,y])\n        Ex2:in_ideal(x+y,[y^2,x^2+2*x*y],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1331in_ideal = {"in_ideal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1331in_ideal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1330in_ideal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1331in_ideal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("in_ideal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "in_ideal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1330in_ideal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1330in_ideal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("in_ideal", 1);

  /* "giacpy/auto-methods.pxi":8332
 * 
 *         '''
 *         return GiacMethods['in_ideal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def incidence_matrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_in_ideal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8332, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8322
 *         return GiacMethods['inString'](self,*args)
 * 
 *      def in_ideal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for in_ideal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.in_ideal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8334
 *         return GiacMethods['in_ideal'](self,*args)
 * 
 *      def incidence_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incidence_matrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1333incidence_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1332incidence_matrix, "From Giac's documentation:\n        Help for incidence_matrix:\n        incidence_matrix(Graph(G))\n        Returns the incidence matrix of G whose rows are indexed by the vertices and columns by the edges (in order defined by the commands 'vertices' and 'edges', respectively).\n        See also: 1/ incident_edges \n        Ex1:incidence_matrix(graph(\"tetrahedron\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1333incidence_matrix = {"incidence_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1333incidence_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1332incidence_matrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1333incidence_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("incidence_matrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "incidence_matrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1332incidence_matrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1332incidence_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("incidence_matrix", 1);

  /* "giacpy/auto-methods.pxi":8343
 * 
 *         '''
 *         return GiacMethods['incidence_matrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def incident_edges(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_incidence_matrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8343, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8334
 *         return GiacMethods['in_ideal'](self,*args)
 * 
 *      def incidence_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incidence_matrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.incidence_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8345
 *         return GiacMethods['incidence_matrix'](self,*args)
 * 
 *      def incident_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incident_edges:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1335incident_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1334incident_edges, "From Giac's documentation:\n        Help for incident_edges:\n        incident_edges(Graph(G),Vrtx(v))\n        Returns the list of all edges incident to the vertex v in G (or to the vertices in the list v).\n        See also: 1/ adjacency_matrix 2/ vertex_degree 3/ incidence_matrix 4/ neighbors \n        Ex1:incident_edges(cycle_graph(8),[1,5,7])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1335incident_edges = {"incident_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1335incident_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1334incident_edges};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1335incident_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("incident_edges (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "incident_edges", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1334incident_edges(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1334incident_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("incident_edges", 1);

  /* "giacpy/auto-methods.pxi":8354
 * 
 *         '''
 *         return GiacMethods['incident_edges'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def incircle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_incident_edges); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8354, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8345
 *         return GiacMethods['incidence_matrix'](self,*args)
 * 
 *      def incident_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incident_edges:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.incident_edges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8356
 *         return GiacMethods['incident_edges'](self,*args)
 * 
 *      def incircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incircle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1337incircle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1336incircle, "From Giac's documentation:\n        Help for incircle:\n        incircle((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        incircle(A,B,C) draws the incircle of the triangle ABC.\n        See also: 1/ excircle 2/ circumcircle \n        Ex1:incircle(0,1,1+i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1337incircle = {"incircle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1337incircle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1336incircle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1337incircle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("incircle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "incircle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1336incircle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1336incircle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("incircle", 1);

  /* "giacpy/auto-methods.pxi":8365
 * 
 *         '''
 *         return GiacMethods['incircle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def increasing_power(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_incircle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8365, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8356
 *         return GiacMethods['incident_edges'](self,*args)
 * 
 *      def incircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incircle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.incircle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8367
 *         return GiacMethods['incircle'](self,*args)
 * 
 *      def increasing_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for increasing_power:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1339increasing_power(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1338increasing_power, "From Giac's documentation:\n        Help for increasing_power:\n        increasing_power(:=Intg(0 or 1))\n        Pseudo-variable to control the display of polynomials.\n        See also: 1/ cas_setup \n        Ex1: increasing_power:=1\n        Ex2: increasing_power:=0\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1339increasing_power = {"increasing_power", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1339increasing_power, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1338increasing_power};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1339increasing_power(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("increasing_power (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "increasing_power", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1338increasing_power(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1338increasing_power(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("increasing_power", 1);

  /* "giacpy/auto-methods.pxi":8377
 * 
 *         '''
 *         return GiacMethods['increasing_power'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def independence_number(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_increasing_power); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8377, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8367
 *         return GiacMethods['incircle'](self,*args)
 * 
 *      def increasing_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for increasing_power:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.increasing_power", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8379
 *         return GiacMethods['increasing_power'](self,*args)
 * 
 *      def independence_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for independence_number:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1341independence_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1340independence_number, "From Giac's documentation:\n        Help for independence_number:\n        independence_number(Graph(G))\n        Returns the independence number of G.\n        See also: 1/ clique_number 2/ graph_complement 3/ maximum_clique 4/ maximum_independent_set \n        Ex1:independence_number(complete_graph(3,4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1341independence_number = {"independence_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1341independence_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1340independence_number};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1341independence_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("independence_number (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "independence_number", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1340independence_number(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1340independence_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("independence_number", 1);

  /* "giacpy/auto-methods.pxi":8388
 * 
 *         '''
 *         return GiacMethods['independence_number'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def indets(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_independence_number); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8388, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8379
 *         return GiacMethods['increasing_power'](self,*args)
 * 
 *      def independence_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for independence_number:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.independence_number", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8390
 *         return GiacMethods['independence_number'](self,*args)
 * 
 *      def indets(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for indets:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1343indets(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1342indets, "From Giac's documentation:\n        Help for indets:\n        indets(Expr)\n        List of variables in the expression.\n        See also: 1/ has 2/ lvar \n        Ex1:indets(exp(x)*2*sin(y))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1343indets = {"indets", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1343indets, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1342indets};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1343indets(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("indets (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "indets", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1342indets(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1342indets(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("indets", 1);

  /* "giacpy/auto-methods.pxi":8399
 * 
 *         '''
 *         return GiacMethods['indets'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def index(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_indets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8399, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8390
 *         return GiacMethods['independence_number'](self,*args)
 * 
 *      def indets(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for indets:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.indets", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8401
 *         return GiacMethods['indets'](self,*args)
 * 
 *      def index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for index:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1345index(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1344index, "From Giac's documentation:\n        Help for index:\n        index(Vect,Expr)\n        Index of the first position of an object in a list, a string or a set or returns an error message.\n        See also: 1/ find 2/ member \n        Ex1:index([3,x,1,2,1,3],1)\n        Ex2:index([0,1,3,2,4,2,5],2)\n        Ex3:index(%{4,3,1,2%},1)\n        Ex4:index(\"abracadabrant\",\"c\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1345index = {"index", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1345index, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1344index};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1345index(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("index (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "index", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1344index(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1344index(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("index", 1);

  /* "giacpy/auto-methods.pxi":8413
 * 
 *         '''
 *         return GiacMethods['index'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def induced_subgraph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8413, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8401
 *         return GiacMethods['indets'](self,*args)
 * 
 *      def index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for index:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8415
 *         return GiacMethods['index'](self,*args)
 * 
 *      def induced_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for induced_subgraph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1347induced_subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1346induced_subgraph, "From Giac's documentation:\n        Help for induced_subgraph:\n        induced_subgraph(Graph(G),Lst(V))\n        Returns the subgraph of G induced by the vertices in list V.\n        See also: 1/ subgraph \n        Ex1:induced_subgraph(cycle_graph(6),[1,2,6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1347induced_subgraph = {"induced_subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1347induced_subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1346induced_subgraph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1347induced_subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("induced_subgraph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "induced_subgraph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1346induced_subgraph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1346induced_subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("induced_subgraph", 1);

  /* "giacpy/auto-methods.pxi":8424
 * 
 *         '''
 *         return GiacMethods['induced_subgraph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inequationplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_induced_subgraph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8424, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8415
 *         return GiacMethods['index'](self,*args)
 * 
 *      def induced_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for induced_subgraph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.induced_subgraph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8426
 *         return GiacMethods['induced_subgraph'](self,*args)
 * 
 *      def inequationplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inequationplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1349inequationplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1348inequationplot, "From Giac's documentation:\n        Help for inequationplot:\n        inequationplot(Expr,[x=xrange,y=yrange],[xstep],[ystep])\n        Shows the graph of the solutions of inequalities with 2 variables.\n        See also: 1/ plotfunc 2/ plotcontour 3/ plotdensity 4/ plotimplicit \n        Ex1:inequationplot(x^2-y^2<3)\n        Ex2:inequationplot(x^2-y^2<3,[x=-2..2,y=-2..2],xstep=0.1,ystep=0.1)\n        Ex3:inequationplot(3-(x^2-y^2),[x=-2..2,y=-2..2],xstep=0.1,ystep=0.1)\n        Ex4:inequationplot([x+y>3,x^2<y],[x,y],xstep=0.2,ystep=0.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1349inequationplot = {"inequationplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1349inequationplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1348inequationplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1349inequationplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inequationplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inequationplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1348inequationplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1348inequationplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inequationplot", 1);

  /* "giacpy/auto-methods.pxi":8438
 * 
 *         '''
 *         return GiacMethods['inequationplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inertia(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inequationplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8438, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8426
 *         return GiacMethods['induced_subgraph'](self,*args)
 * 
 *      def inequationplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inequationplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inequationplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8440
 *         return GiacMethods['inequationplot'](self,*args)
 * 
 *      def inertia(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inertia:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1351inertia(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1350inertia, "From Giac's documentation:\n        Help for inertia:\n        inertia(Mtrx(A),[B,[p0]])\n        Returns the triplet [p,n,z] of nonnegative integers indicating the number of\n        See also: 1/ ldl \n        Ex1:inertia(positive, negative, and zero eigenvalues of the real symmetric matrix A,)\n        Ex2:inertia(optionally alongside the solution to X*tran(A)=B if z=0 (and p=p0).)\n        Ex3:inertia([[1,-1,2],[-1,4,3],[2,3,-5]])\n        Ex4:inertia([[1,-1,2],[-1,4,3],[2,3,-5]],[[1,2,3],[4,5,6]])\n        Ex5:inertia([[1,-1,2],[-1,4,3],[2,3,-5]],[[1,2,3],[4,5,6]],2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1351inertia = {"inertia", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1351inertia, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1350inertia};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1351inertia(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inertia (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inertia", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1350inertia(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1350inertia(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inertia", 1);

  /* "giacpy/auto-methods.pxi":8453
 * 
 *         '''
 *         return GiacMethods['inertia'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inertia); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8453, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8440
 *         return GiacMethods['inequationplot'](self,*args)
 * 
 *      def inertia(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inertia:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inertia", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8455
 *         return GiacMethods['inertia'](self,*args)
 * 
 *      def inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1353inf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1352inf, "From Giac's documentation:\n        Help for inf:\n        inf()\n        Plus infinity.\n        See also: 1/ infinity 2/ -infinity 3/ isinf \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1353inf = {"inf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1353inf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1352inf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1353inf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1352inf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1352inf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inf", 1);

  /* "giacpy/auto-methods.pxi":8463
 * 
 *         '''
 *         return GiacMethods['inf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def infinity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8463, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8455
 *         return GiacMethods['inertia'](self,*args)
 * 
 *      def inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8465
 *         return GiacMethods['inf'](self,*args)
 * 
 *      def infinity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for infinity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1355infinity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1354infinity, "From Giac's documentation:\n        Help for infinity:\n        infinity()\n        Unsigned infinity.\n        See also: 1/ +infinity 2/ -infinity 3/ isinf \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1355infinity = {"infinity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1355infinity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1354infinity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1355infinity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("infinity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "infinity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1354infinity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1354infinity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("infinity", 1);

  /* "giacpy/auto-methods.pxi":8473
 * 
 *         '''
 *         return GiacMethods['infinity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def information_centrality(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_infinity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8473, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8465
 *         return GiacMethods['inf'](self,*args)
 * 
 *      def infinity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for infinity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.infinity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8475
 *         return GiacMethods['infinity'](self,*args)
 * 
 *      def information_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for information_centrality:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1357information_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1356information_centrality, "From Giac's documentation:\n        Help for information_centrality:\n        information_centrality(Graph(G),[Vrtx(v)],[approx])\n        Returns the information centrality of a vertex v in a graph G or the list of information centralities of vertices in G.\n        See also: 1/ degree_centrality 2/ betweenness_centrality 3/ closeness_centrality 4/ harmonic_centrality 5/ katz_centrality \n        Ex1:information_centrality(graph(6,%{[0,2],[0,5],[1,3],[1,5],[2,5],[3,4],[3,5],[4,5]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1357information_centrality = {"information_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1357information_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1356information_centrality};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1357information_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("information_centrality (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "information_centrality", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1356information_centrality(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1356information_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("information_centrality", 1);

  /* "giacpy/auto-methods.pxi":8484
 * 
 *         '''
 *         return GiacMethods['information_centrality'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def insert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_information_centrality); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8484, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8475
 *         return GiacMethods['infinity'](self,*args)
 * 
 *      def information_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for information_centrality:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.information_centrality", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8486
 *         return GiacMethods['information_centrality'](self,*args)
 * 
 *      def insert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1359insert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1358insert, "From Giac's documentation:\n        Help for insert:\n        insert(Vect(l)||Str(l),Intg(n),Val(b))\n        Returns l where the element b is of index n.\n        See also: 1/ tail 2/ mid 3/ remove 4/ suppress \n        Ex1:insert([0,1,2,3],2,5)\n        Ex2:insert(\"0123\",2,\"5\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1359insert = {"insert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1359insert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1358insert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1359insert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "insert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1358insert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1358insert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insert", 1);

  /* "giacpy/auto-methods.pxi":8496
 * 
 *         '''
 *         return GiacMethods['insert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def insmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_insert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8496, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8486
 *         return GiacMethods['information_centrality'](self,*args)
 * 
 *      def insert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.insert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8498
 *         return GiacMethods['insert'](self,*args)
 * 
 *      def insmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1361insmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1360insmod, "From Giac's documentation:\n        Help for insmod:\n        insmod(Str(pwd))\n        Installs a dynamic module (by entering the pwd of this file), creates the commands that are, for example, in the file libprogfr\n        See also: 1/ rmmod 2/ lsmod \n        Ex1:insmod(\"/home/parisse/giac/src/libprogfr.so\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1361insmod = {"insmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1361insmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1360insmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1361insmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("insmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "insmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1360insmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1360insmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("insmod", 1);

  /* "giacpy/auto-methods.pxi":8507
 * 
 *         '''
 *         return GiacMethods['insmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def instfreq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_insmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8507, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8498
 *         return GiacMethods['insert'](self,*args)
 * 
 *      def insmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.insmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8509
 *         return GiacMethods['insmod'](self,*args)
 * 
 *      def instfreq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instfreq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1363instfreq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1362instfreq, "From Giac's documentation:\n        Help for instfreq:\n        instfreq(Vect(u)||Expr(u),[Var(x)])\n        Returns the instantaneous angular frequency of an analytic signal u.\n        See also: 1/ hilbert 2/ instphase \n        Ex1:instfreq(hilbert([0.7,0.2,-0.5,-0.6,-0.2,0.3,0.5,-0.1,-0.3]))\n        Ex2: u:=(t-3+(t-2)^2)/(1+(t-2)^4):;instfreq(u+i*hilbert(u,t),t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1363instfreq = {"instfreq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1363instfreq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1362instfreq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1363instfreq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("instfreq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "instfreq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1362instfreq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1362instfreq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("instfreq", 1);

  /* "giacpy/auto-methods.pxi":8519
 * 
 *         '''
 *         return GiacMethods['instfreq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def instphase(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_instfreq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8519, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8509
 *         return GiacMethods['insmod'](self,*args)
 * 
 *      def instfreq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instfreq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.instfreq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8521
 *         return GiacMethods['instfreq'](self,*args)
 * 
 *      def instphase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instphase:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1365instphase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1364instphase, "From Giac's documentation:\n        Help for instphase:\n        instphase(Vect(u)||Expr(u),[Var(x)])\n        Returns the instantaneous phase of an analytic signal u.\n        See also: 1/ hilbert 2/ instfreq \n        Ex1:instphase(hilbert([0.7,0.2,-0.5,-0.6,-0.2,0.3,0.5,-0.1,-0.3]))\n        Ex2: u:=(t-3+(t-2)^2)/(1+(t-2)^4):;instphase(u+i*hilbert(u,t),t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1365instphase = {"instphase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1365instphase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1364instphase};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1365instphase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("instphase (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "instphase", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1364instphase(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1364instphase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("instphase", 1);

  /* "giacpy/auto-methods.pxi":8531
 * 
 *         '''
 *         return GiacMethods['instphase'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def int(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_instphase); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8531, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8521
 *         return GiacMethods['instfreq'](self,*args)
 * 
 *      def instphase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instphase:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.instphase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8533
 *         return GiacMethods['instphase'](self,*args)
 * 
 *      def int(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for int:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1367int(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1366int, "From Giac's documentation:\n        Help for int:\n        int(Expr,[Var(x)],[Real(a)],[Real(b)])\n        Indefinite integral, you can specify a variable of integration or calculate the integral (bounds a and b).\n        See also: 1/ Int 2/ diff 3/ plotarea 4/ romberg 5/ gaussquad \n        Ex1:int(1/x)\n        Ex2:int(1/(4+t^2),t)\n        Ex3:int(1/(1-x^4),x,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1367int = {"int", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1367int, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1366int};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1367int(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("int (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "int", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1366int(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1366int(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("int", 1);

  /* "giacpy/auto-methods.pxi":8544
 * 
 *         '''
 *         return GiacMethods['int'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def intDiv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_int); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8544, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8533
 *         return GiacMethods['instphase'](self,*args)
 * 
 *      def int(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for int:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8546
 *         return GiacMethods['int'](self,*args)
 * 
 *      def intDiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for intDiv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1369intDiv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1368intDiv, "From Giac's documentation:\n        Help for intDiv:\n        intDiv(Intg(a),Intg(b))\n        Euclidean quotient of 2 integers.\n        See also: 1/ irem 2/ smod 3/ quo \n        Ex1:intDiv(125,15)\n        Ex2:intDiv(125,41)\n        Ex3:intDiv(-7,3)\n        Ex4:intDiv(25+12*i,5+7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1369intDiv = {"intDiv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1369intDiv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1368intDiv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1369intDiv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("intDiv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "intDiv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1368intDiv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1368intDiv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("intDiv", 1);

  /* "giacpy/auto-methods.pxi":8558
 * 
 *         '''
 *         return GiacMethods['intDiv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def integer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_intDiv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8558, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8546
 *         return GiacMethods['int'](self,*args)
 * 
 *      def intDiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for intDiv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.intDiv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8560
 *         return GiacMethods['intDiv'](self,*args)
 * 
 *      def integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1371integer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1370integer, "From Giac's documentation:\n        Help for integer:\n        integer(Opt)\n        DOM_INT or integer or DOM_int is an integer which is the type of an integer variable, it is the value of the type command. DOM_INT is used for integers < 2^31. It is also an option of the assume command.\n        See also: 1/ type 2/ assume 3/ DOM_FLOAT 4/ DOM_SYMBOLIC \n        Ex1: type(2^31)\n        Ex2: DOM_INT+0\n        Ex3: assume(a,DOM_INT)\n        Ex4: assume(a,integer)\n        Ex5: a:=2;type(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1371integer = {"integer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1371integer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1370integer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1371integer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("integer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "integer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1370integer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1370integer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("integer", 1);

  /* "giacpy/auto-methods.pxi":8573
 * 
 *         '''
 *         return GiacMethods['integer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def integrate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_integer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8573, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8560
 *         return GiacMethods['intDiv'](self,*args)
 * 
 *      def integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.integer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8575
 *         return GiacMethods['integer'](self,*args)
 * 
 *      def integrate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1373integrate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1372integrate, "From Giac's documentation:\n        Help for integrate:\n        integrate(Expr,[Var(x)],[Real(a)],[Real(b)])\n        Indefinite integral, you can specify a variable of integration or calculate the integral (bounds a and b).\n        See also: 1/ Int 2/ diff 3/ plotarea 4/ romberg 5/ gaussquad \n        Ex1:integrate(1/x)\n        Ex2:integrate(1/(4+t^2),t)\n        Ex3:integrate(1/(1-x^4),x,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1373integrate = {"integrate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1373integrate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1372integrate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1373integrate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("integrate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "integrate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1372integrate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1372integrate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("integrate", 1);

  /* "giacpy/auto-methods.pxi":8586
 * 
 *         '''
 *         return GiacMethods['integrate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def integrer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_integrate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8586, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8575
 *         return GiacMethods['integer'](self,*args)
 * 
 *      def integrate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.integrate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8588
 *         return GiacMethods['integrate'](self,*args)
 * 
 *      def integrer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1375integrer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1374integrer, "From Giac's documentation:\n        Help for integrer:\n        integrer(Expr,[Var(x)],[Real(a)],[Real(b)])\n        Indefinite integral, you can specify a variable of integration or calculate the integral (bounds a and b).\n        See also: 1/ Int 2/ diff 3/ plotarea 4/ romberg 5/ gaussquad \n        Ex1:integrer(1/x)\n        Ex2:integrer(1/(4+t^2),t)\n        Ex3:integrer(1/(1-x^4),x,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1375integrer = {"integrer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1375integrer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1374integrer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1375integrer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("integrer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "integrer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1374integrer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1374integrer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("integrer", 1);

  /* "giacpy/auto-methods.pxi":8599
 * 
 *         '''
 *         return GiacMethods['integrer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_integrer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8599, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8588
 *         return GiacMethods['integrate'](self,*args)
 * 
 *      def integrer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.integrer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8601
 *         return GiacMethods['integrer'](self,*args)
 * 
 *      def inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1377inter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1376inter, "From Giac's documentation:\n        Help for inter:\n        inter(Curve,Curve,[Pnt])\n        With 2 arguments (resp 3 arguments) gives the intersection of 2 curves or surfaces as a vector (resp a point close to the point given as third argument).\n        See also: 1/ intersect 2/ head \n        Ex1:inter(line(i,1-i),circle(0,1))\n        Ex2:inter(line(i,1-i),circle(0,1),point(-i))\n        Ex3:inter(plane(x=y+3),cone([0,0,0],[0,0,1],pi/6))\n        Ex4:inter(plane(x=y+3),cone([0,0,0],[0,0,1],pi/6))\n        Ex5:inter(line(i,1-i),circle(0,1))[0]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1377inter = {"inter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1377inter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1376inter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1377inter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1376inter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1376inter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inter", 1);

  /* "giacpy/auto-methods.pxi":8614
 * 
 *         '''
 *         return GiacMethods['inter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def interactive_odeplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8614, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8601
 *         return GiacMethods['integrer'](self,*args)
 * 
 *      def inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8616
 *         return GiacMethods['inter'](self,*args)
 * 
 *      def interactive_odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_odeplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1379interactive_odeplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1378interactive_odeplot, "From Giac's documentation:\n        Help for interactive_odeplot:\n        interactive_odeplot(Expr,VectVar)\n        Draws (in DispG) a solution for each point t0+i*y0 clicked with the mouse (Esc=halt).\n        See also: 1/ odeplot 2/ plotfield 3/ odesolve 4/ desolve \n        Ex1:interactive_odeplot(sin(t*y),[t,y])\n        Ex2:interactive_odeplot(-t*y,[t,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1379interactive_odeplot = {"interactive_odeplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1379interactive_odeplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1378interactive_odeplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1379interactive_odeplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interactive_odeplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "interactive_odeplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1378interactive_odeplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1378interactive_odeplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interactive_odeplot", 1);

  /* "giacpy/auto-methods.pxi":8626
 * 
 *         '''
 *         return GiacMethods['interactive_odeplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def interactive_plotode(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_interactive_odeplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8626, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8616
 *         return GiacMethods['inter'](self,*args)
 * 
 *      def interactive_odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_odeplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.interactive_odeplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8628
 *         return GiacMethods['interactive_odeplot'](self,*args)
 * 
 *      def interactive_plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_plotode:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1381interactive_plotode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1380interactive_plotode, "From Giac's documentation:\n        Help for interactive_plotode:\n        interactive_plotode(Expr,VectVar)\n        Draws (in DispG) a solution for each point t0+i*y0 clicked with the mouse (Esc=halt).\n        See also: 1/ odeplot 2/ plotfield 3/ odesolve 4/ desolve \n        Ex1:interactive_plotode(sin(t*y),[t,y])\n        Ex2:interactive_plotode(-t*y,[t,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1381interactive_plotode = {"interactive_plotode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1381interactive_plotode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1380interactive_plotode};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1381interactive_plotode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interactive_plotode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "interactive_plotode", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1380interactive_plotode(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1380interactive_plotode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interactive_plotode", 1);

  /* "giacpy/auto-methods.pxi":8638
 * 
 *         '''
 *         return GiacMethods['interactive_plotode'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def interp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_interactive_plotode); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8638, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8628
 *         return GiacMethods['interactive_odeplot'](self,*args)
 * 
 *      def interactive_plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_plotode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.interactive_plotode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8640
 *         return GiacMethods['interactive_plotode'](self,*args)
 * 
 *      def interp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1383interp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1382interp, "From Giac's documentation:\n        Help for interp:\n        interp(Lst(colors)||Seq(Image(A),Image(B)||Color(c))||Seq(Lst(x0),Lst(y0),Lst(x))||Seq(Lst(x),Lst(y)))\n        Interpolates between colors or two images or image and color, or computes numerical spline interpolation, or computes the Lagrange polynomial.\n        See also: 1/ lagrange \n        Ex1:interp([blue,red,yellow],20)\n        Ex2:interp(red,blue,0.5)\n        Ex3: listplot(interp([0,1.2,3.7,4.5,6.2,8.1],[-0.1,0.2,0.5,0.3,0.1,0.0],[1,2,3,4,5,6,7,8]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1383interp = {"interp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1383interp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1382interp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1383interp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "interp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1382interp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1382interp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interp", 1);

  /* "giacpy/auto-methods.pxi":8651
 * 
 *         '''
 *         return GiacMethods['interp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def interval(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_interp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8651, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8640
 *         return GiacMethods['interactive_plotode'](self,*args)
 * 
 *      def interp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.interp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8653
 *         return GiacMethods['interp'](self,*args)
 * 
 *      def interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1385interval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1384interval, "From Giac's documentation:\n        Help for interval:\n        interval(Opt)\n        Option of the convert or convertir command.\n        See also: 1/ interval \n        Ex1: convert(sqrt(2),interval)\n        Ex2: convert(sqrt(2),interval,20)\n        Ex3: convert(sqrt(2)*sin(2)+sqrt(2)*cos(2),interval,20)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1385interval = {"interval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1385interval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1384interval};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1385interval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interval (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "interval", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1384interval(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1384interval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interval", 1);

  /* "giacpy/auto-methods.pxi":8664
 * 
 *         '''
 *         return GiacMethods['interval'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def interval2center(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_interval); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8664, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8653
 *         return GiacMethods['interp'](self,*args)
 * 
 *      def interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.interval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8666
 *         return GiacMethods['interval'](self,*args)
 * 
 *      def interval2center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval2center:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1387interval2center(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1386interval2center, "From Giac's documentation:\n        Help for interval2center:\n        interval2center(Interval or Real)\n        Returns the center of the interval or the object.\n        See also: 1/ center2interval \n        Ex1:interval2center(2..5)\n        Ex2:interval2center(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1387interval2center = {"interval2center", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1387interval2center, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1386interval2center};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1387interval2center(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interval2center (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "interval2center", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1386interval2center(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1386interval2center(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interval2center", 1);

  /* "giacpy/auto-methods.pxi":8676
 * 
 *         '''
 *         return GiacMethods['interval2center'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def interval_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_interval2center); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8676, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8666
 *         return GiacMethods['interval'](self,*args)
 * 
 *      def interval2center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval2center:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.interval2center", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8678
 *         return GiacMethods['interval2center'](self,*args)
 * 
 *      def interval_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1389interval_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1388interval_graph, "From Giac's documentation:\n        Help for interval_graph:\n        interval_graph(Seq||Lst(a..b,c..d,...))\n        Returns an interval graph with respect to the intervals a..b, c..d, ... on the real line. It has one vertex per interval and two vertices are connected iff the corresponding intervals intersect.\n        See also: 1/ graph 2/ kneser_graph \n        Ex1:interval_graph([0..8,1..pi,exp(1)..20,7..18,11..14,17..24,23..25])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1389interval_graph = {"interval_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1389interval_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1388interval_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1389interval_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("interval_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "interval_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1388interval_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1388interval_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("interval_graph", 1);

  /* "giacpy/auto-methods.pxi":8687
 * 
 *         '''
 *         return GiacMethods['interval_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_interval_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8687, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8678
 *         return GiacMethods['interval2center'](self,*args)
 * 
 *      def interval_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.interval_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8689
 *         return GiacMethods['interval_graph'](self,*args)
 * 
 *      def inv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1391inv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1390inv, "From Giac's documentation:\n        Help for inv:\n        inv(Expr||Mtrx||Image||Audio)\n        Returns the inverse of an expression or matrix or returns a negative of an image object or inverts channels in an audio clip.\n        See also: 1/ Inv \n        Ex1:inv(9/5)\n        Ex2:inv([[1,2],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1391inv = {"inv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1391inv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1390inv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1391inv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1390inv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1390inv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inv", 1);

  /* "giacpy/auto-methods.pxi":8699
 * 
 *         '''
 *         return GiacMethods['inv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inverse(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8699, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8689
 *         return GiacMethods['interval_graph'](self,*args)
 * 
 *      def inv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8701
 *         return GiacMethods['inv'](self,*args)
 * 
 *      def inverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inverse:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1393inverse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1392inverse, "From Giac's documentation:\n        Help for inverse:\n        inverse(Expr||Mtrx||Image||Audio)\n        Returns the inverse of an expression or matrix or returns a negative of an image object or inverts channels in an audio clip.\n        See also: 1/ Inv \n        Ex1:inverse(9/5)\n        Ex2:inverse([[1,2],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1393inverse = {"inverse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1393inverse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1392inverse};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1393inverse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inverse (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inverse", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1392inverse(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1392inverse(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inverse", 1);

  /* "giacpy/auto-methods.pxi":8711
 * 
 *         '''
 *         return GiacMethods['inverse'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def inversion(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inverse); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8711, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8701
 *         return GiacMethods['inv'](self,*args)
 * 
 *      def inverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inverse:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inverse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8713
 *         return GiacMethods['inverse'](self,*args)
 * 
 *      def inversion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inversion:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1395inversion(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1394inversion, "From Giac's documentation:\n        Help for inversion:\n        inversion(Pnt(C),Real(k),Pnt(A))\n        inversion(C,k,A)=point A1 such that A1 is on line(C,A) and algebraic mesure of (CA1*CA)=k.\n        See also: 1/ homothety \n        Ex1:inversion(i,1/2,1+i)\n        Ex2:inversion([1,1,1],-1/2,point(-1,-1,-1))\n        Ex3: inver:=inversion(i,1/2);inver(i)\n        Ex4: inver:=inversion([1,1,1],-1/2);inver(point(-1,-1,-1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1395inversion = {"inversion", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1395inversion, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1394inversion};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1395inversion(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inversion (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "inversion", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1394inversion(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1394inversion(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inversion", 1);

  /* "giacpy/auto-methods.pxi":8725
 * 
 *         '''
 *         return GiacMethods['inversion'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def invisible_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_inversion); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8725, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8713
 *         return GiacMethods['inverse'](self,*args)
 * 
 *      def inversion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inversion:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.inversion", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8727
 *         return GiacMethods['inversion'](self,*args)
 * 
 *      def invisible_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invisible_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1397invisible_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1396invisible_point, "From Giac's documentation:\n        Help for invisible_point:\n        invisible_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1397invisible_point = {"invisible_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1397invisible_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1396invisible_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1397invisible_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("invisible_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "invisible_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1396invisible_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1396invisible_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("invisible_point", 1);

  /* "giacpy/auto-methods.pxi":8737
 * 
 *         '''
 *         return GiacMethods['invisible_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def invlaplace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_invisible_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8737, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8727
 *         return GiacMethods['inversion'](self,*args)
 * 
 *      def invisible_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invisible_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.invisible_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8739
 *         return GiacMethods['invisible_point'](self,*args)
 * 
 *      def invlaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invlaplace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1399invlaplace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1398invlaplace, "From Giac's documentation:\n        Help for invlaplace:\n        invlaplace(Expr,[Var],[IlapVar])\n        Inverse Laplace transform of a rational fraction.\n        See also: 1/ laplace 2/ ztrans 3/ invztrans 4/ Heaviside \n        Ex1:invlaplace(1/(x^2+1)^2)\n        Ex2:invlaplace(s/(s^4-1),s,x)\n        Ex3:invlaplace(exp(-s)/s,s,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1399invlaplace = {"invlaplace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1399invlaplace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1398invlaplace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1399invlaplace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("invlaplace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "invlaplace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1398invlaplace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1398invlaplace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("invlaplace", 1);

  /* "giacpy/auto-methods.pxi":8750
 * 
 *         '''
 *         return GiacMethods['invlaplace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def invztrans(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_invlaplace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8750, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8739
 *         return GiacMethods['invisible_point'](self,*args)
 * 
 *      def invlaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invlaplace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.invlaplace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8752
 *         return GiacMethods['invlaplace'](self,*args)
 * 
 *      def invztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invztrans:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1401invztrans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1400invztrans, "From Giac's documentation:\n        Help for invztrans:\n        invztrans(Expr,[Var],[InvZtransVar])\n        Inverse z transform of a rational fraction.\n        See also: 1/ ztrans 2/ laplace 3/ invlaplace \n        Ex1:invztrans(1/(x^2+1)^2)\n        Ex2:invztrans(z/(z^4-1),z,n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1401invztrans = {"invztrans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1401invztrans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1400invztrans};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1401invztrans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("invztrans (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "invztrans", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1400invztrans(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1400invztrans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("invztrans", 1);

  /* "giacpy/auto-methods.pxi":8762
 * 
 *         '''
 *         return GiacMethods['invztrans'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def iquo(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_invztrans); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8762, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8752
 *         return GiacMethods['invlaplace'](self,*args)
 * 
 *      def invztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invztrans:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.invztrans", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8764
 *         return GiacMethods['invztrans'](self,*args)
 * 
 *      def iquo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquo:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1403iquo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1402iquo, "From Giac's documentation:\n        Help for iquo:\n        iquo(Intg(a),Intg(b))\n        Euclidean quotient of 2 integers.\n        See also: 1/ irem 2/ smod 3/ quo \n        Ex1:iquo(125,15)\n        Ex2:iquo(125,41)\n        Ex3:iquo(-7,3)\n        Ex4:iquo(25+12*i,5+7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1403iquo = {"iquo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1403iquo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1402iquo};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1403iquo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iquo (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "iquo", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1402iquo(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1402iquo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iquo", 1);

  /* "giacpy/auto-methods.pxi":8776
 * 
 *         '''
 *         return GiacMethods['iquo'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def iquorem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_iquo); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8776, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8764
 *         return GiacMethods['invztrans'](self,*args)
 * 
 *      def iquo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquo:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.iquo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8778
 *         return GiacMethods['iquo'](self,*args)
 * 
 *      def iquorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquorem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1405iquorem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1404iquorem, "From Giac's documentation:\n        Help for iquorem:\n        iquorem(Intg(a),Intg(b))\n        Euclidean quotient and remainder of 2 integers.\n        See also: 1/ irem 2/ iquo 3/ quorem \n        Ex1:iquorem(125,15)\n        Ex2:iquorem(125,41)\n        Ex3:iquorem(25+12*i,5+7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1405iquorem = {"iquorem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1405iquorem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1404iquorem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1405iquorem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iquorem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "iquorem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1404iquorem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1404iquorem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iquorem", 1);

  /* "giacpy/auto-methods.pxi":8789
 * 
 *         '''
 *         return GiacMethods['iquorem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def iratrecon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_iquorem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8789, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8778
 *         return GiacMethods['iquo'](self,*args)
 * 
 *      def iquorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquorem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.iquorem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8791
 *         return GiacMethods['iquorem'](self,*args)
 * 
 *      def iratrecon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iratrecon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1407iratrecon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1406iratrecon, "From Giac's documentation:\n        Help for iratrecon:\n        iratrecon(Expr(Xpr),Intg(n))\n        Returns the fraction a/b such as b*Xpr=a mod n, -sqrt(n)/2<a<=sqrt(n)/2 and 0<=b<sqrt(n)/2.\n        See also: 1/ mod 2/ smod \n        Ex1:iratrecon(41,121)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1407iratrecon = {"iratrecon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1407iratrecon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1406iratrecon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1407iratrecon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iratrecon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "iratrecon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1406iratrecon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1406iratrecon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iratrecon", 1);

  /* "giacpy/auto-methods.pxi":8800
 * 
 *         '''
 *         return GiacMethods['iratrecon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def irem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_iratrecon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8800, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8791
 *         return GiacMethods['iquorem'](self,*args)
 * 
 *      def iratrecon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iratrecon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.iratrecon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8802
 *         return GiacMethods['iratrecon'](self,*args)
 * 
 *      def irem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for irem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1409irem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1408irem, "From Giac's documentation:\n        Help for irem:\n        irem(Intg(a),Intg(b))\n        Euclidean remainder of 2 integers.\n        See also: 1/ iquo 2/ smod 3/ rem 4/ mod \n        Ex1:irem(125,15)\n        Ex2:irem(125,41)\n        Ex3:irem(-7,3)\n        Ex4:irem(25+12*i,5+7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1409irem = {"irem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1409irem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1408irem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1409irem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("irem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "irem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1408irem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1408irem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("irem", 1);

  /* "giacpy/auto-methods.pxi":8814
 * 
 *         '''
 *         return GiacMethods['irem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isPrime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_irem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8814, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8802
 *         return GiacMethods['iratrecon'](self,*args)
 * 
 *      def irem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for irem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.irem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8816
 *         return GiacMethods['irem'](self,*args)
 * 
 *      def isPrime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isPrime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1411isPrime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1410isPrime, "From Giac's documentation:\n        Help for isPrime:\n        isPrime(Intg(a))\n        Primality testing (=true or false).\n        See also: 1/ prevprime 2/ nextprime 3/ is_prime 4/ is_pseudoprime \n        Ex1:isPrime(1999)\n        Ex2:isPrime(9856989898997)\n        Ex3:isPrime(9856989898997789789)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1411isPrime = {"isPrime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1411isPrime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1410isPrime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1411isPrime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isPrime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isPrime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1410isPrime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1410isPrime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isPrime", 1);

  /* "giacpy/auto-methods.pxi":8827
 * 
 *         '''
 *         return GiacMethods['isPrime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_acyclic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isPrime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8827, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8816
 *         return GiacMethods['irem'](self,*args)
 * 
 *      def isPrime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isPrime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isPrime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8829
 *         return GiacMethods['isPrime'](self,*args)
 * 
 *      def is_acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_acyclic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1413is_acyclic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1412is_acyclic, "From Giac's documentation:\n        Help for is_acyclic:\n        is_acyclic(Graph(G))\n        Returns true iff a digraph G contains no directed cycles.\n        See also: 1/ topologic_sort 2/ topological_sort \n        Ex1:is_acyclic(digraph(%{[c,a],[c,b],[c,d],[a,d],[b,d],[a,b]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1413is_acyclic = {"is_acyclic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1413is_acyclic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1412is_acyclic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1413is_acyclic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_acyclic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_acyclic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1412is_acyclic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1412is_acyclic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_acyclic", 1);

  /* "giacpy/auto-methods.pxi":8838
 * 
 *         '''
 *         return GiacMethods['is_acyclic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_arborescence(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_acyclic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8838, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8829
 *         return GiacMethods['isPrime'](self,*args)
 * 
 *      def is_acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_acyclic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_acyclic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8840
 *         return GiacMethods['is_acyclic'](self,*args)
 * 
 *      def is_arborescence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_arborescence:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1415is_arborescence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1414is_arborescence, "From Giac's documentation:\n        Help for is_arborescence:\n        is_arborescence(Graph(G))\n        Returns true iff a directed graph G is an arborescence.\n        See also: 1/ is_acyclic 2/ is_forest 3/ is_tree \n        Ex1:is_arborescence(digraph(%{[1,2],[1,3]%}))\n        Ex2:is_arborescence(digraph(%{[1,2],[2,3],[3,1]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1415is_arborescence = {"is_arborescence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1415is_arborescence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1414is_arborescence};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1415is_arborescence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_arborescence (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_arborescence", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1414is_arborescence(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1414is_arborescence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_arborescence", 1);

  /* "giacpy/auto-methods.pxi":8850
 * 
 *         '''
 *         return GiacMethods['is_arborescence'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_biconnected(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_arborescence); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8850, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8840
 *         return GiacMethods['is_acyclic'](self,*args)
 * 
 *      def is_arborescence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_arborescence:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_arborescence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8852
 *         return GiacMethods['is_arborescence'](self,*args)
 * 
 *      def is_biconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_biconnected:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1417is_biconnected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1416is_biconnected, "From Giac's documentation:\n        Help for is_biconnected:\n        is_biconnected(Graph(G))\n        Returns true iff G is biconnected.\n        See also: 1/ biconnected_components 2/ is_connected 3/ is_triconnected \n        Ex1:is_biconnected(path_graph(5))\n        Ex2:is_biconnected(cycle_graph(5))\n        Ex3:is_biconnected(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1417is_biconnected = {"is_biconnected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1417is_biconnected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1416is_biconnected};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1417is_biconnected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_biconnected (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_biconnected", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1416is_biconnected(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1416is_biconnected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_biconnected", 1);

  /* "giacpy/auto-methods.pxi":8863
 * 
 *         '''
 *         return GiacMethods['is_biconnected'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_bipartite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_biconnected); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8863, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8852
 *         return GiacMethods['is_arborescence'](self,*args)
 * 
 *      def is_biconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_biconnected:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_biconnected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8865
 *         return GiacMethods['is_biconnected'](self,*args)
 * 
 *      def is_bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_bipartite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1419is_bipartite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1418is_bipartite, "From Giac's documentation:\n        Help for is_bipartite:\n        is_bipartite(Graph(G),[Var(P)])\n        Returns true iff G is a bipartite graph [and assigns to P the corresponding vertex partition].\n        See also: 1/ random_bipartite_graph 2/ draw_graph \n        Ex1:is_bipartite(graph(\"desargues\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1419is_bipartite = {"is_bipartite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1419is_bipartite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1418is_bipartite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1419is_bipartite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_bipartite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_bipartite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1418is_bipartite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1418is_bipartite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_bipartite", 1);

  /* "giacpy/auto-methods.pxi":8874
 * 
 *         '''
 *         return GiacMethods['is_bipartite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_clique(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_bipartite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8874, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8865
 *         return GiacMethods['is_biconnected'](self,*args)
 * 
 *      def is_bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_bipartite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_bipartite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8876
 *         return GiacMethods['is_bipartite'](self,*args)
 * 
 *      def is_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_clique:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1421is_clique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1420is_clique, "From Giac's documentation:\n        Help for is_clique:\n        is_clique(Graph(G))\n        Returns true iff an undirected graph G is complete.\n        See also: 1/ clique_number 2/ induced_subgraph 3/ maximum_clique \n        Ex1:is_clique(complete_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1421is_clique = {"is_clique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1421is_clique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1420is_clique};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1421is_clique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_clique (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_clique", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1420is_clique(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1420is_clique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_clique", 1);

  /* "giacpy/auto-methods.pxi":8885
 * 
 *         '''
 *         return GiacMethods['is_clique'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_collinear(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_clique); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8885, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8876
 *         return GiacMethods['is_bipartite'](self,*args)
 * 
 *      def is_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_clique:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_clique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8887
 *         return GiacMethods['is_clique'](self,*args)
 * 
 *      def is_collinear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_collinear:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1423is_collinear(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1422is_collinear, "From Giac's documentation:\n        Help for is_collinear:\n        is_collinear(LstPnt)\n        Returns 1 if the points are aligned, 2 if the points are the same and 0 otherwise.\n        See also: 1/ is_concyclic \n        Ex1:is_collinear(0,i,1+i,2*i)\n        Ex2:is_collinear(point(0),point(1+i),point(2,2),point(-1-i))\n        Ex3:is_collinear(point(0,0,0),point(1,1,0),point(2,2,0),point(-1,-1,1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1423is_collinear = {"is_collinear", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1423is_collinear, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1422is_collinear};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1423is_collinear(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_collinear (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_collinear", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1422is_collinear(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1422is_collinear(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_collinear", 1);

  /* "giacpy/auto-methods.pxi":8898
 * 
 *         '''
 *         return GiacMethods['is_collinear'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_concyclic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_collinear); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8898, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8887
 *         return GiacMethods['is_clique'](self,*args)
 * 
 *      def is_collinear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_collinear:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_collinear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8900
 *         return GiacMethods['is_collinear'](self,*args)
 * 
 *      def is_concyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_concyclic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1425is_concyclic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1424is_concyclic, "From Giac's documentation:\n        Help for is_concyclic:\n        is_concyclic(LstPnt)\n        Returns 1 if the points are on a circle and 0 otherwise.\n        See also: 1/ is_collinear \n        Ex1:is_concyclic(0,i,1+i,1,1/2+i*(1/2+sqrt(2)/2))\n        Ex2:is_concyclic(1,-1,i,-i,1+i,-1-i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1425is_concyclic = {"is_concyclic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1425is_concyclic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1424is_concyclic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1425is_concyclic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_concyclic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_concyclic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1424is_concyclic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1424is_concyclic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_concyclic", 1);

  /* "giacpy/auto-methods.pxi":8910
 * 
 *         '''
 *         return GiacMethods['is_concyclic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_conjugate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_concyclic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8910, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8900
 *         return GiacMethods['is_collinear'](self,*args)
 * 
 *      def is_concyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_concyclic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_concyclic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8912
 *         return GiacMethods['is_concyclic'](self,*args)
 * 
 *      def is_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_conjugate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1427is_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1426is_conjugate, "From Giac's documentation:\n        Help for is_conjugate:\n        is_conjugate(Crcle||Line,Pnt||Line,Pnt||Line,[Pnt||Line])\n        Returns 1 if the 3 (resp 4) arguments are conjugate with repect to the circle (resp 2 lines) and 0 otherwise.\n        See also: 1/ harmonic_conjugate 2/ pole 3/ polar \n        Ex1:is_conjugate(circle(0,1+i),point(1-i),point(3+i))\n        Ex2:is_conjugate(circle(0,1),point((1+i)/2),line(1+i,2))\n        Ex3:is_conjugate(circle(0,1),line(1+i,2),point((1+i)/2))\n        Ex4:is_conjugate(circle(0,1),line(1+i,2),line((1+i)/2,0))\n        Ex5:is_conjugate(point(1+i),point(3+i),point(i),point(3/2+i))\n        Ex6:is_conjugate(line(0,1+i),line(2,3+i),line(3,4+i),line(3/2,5/2+i))\n        Ex7:is_conjugate(line(0,1+i),line(0,3+i),line(0,i),line(0,3/2+i))\n        Ex8:is_conjugate(line(0,1+i),line(0,3+i),line(0,i),point(3/2+i))\n        Ex9:is_conjugate(line(0,1+i),line(0,3+i),point(3/2+i),line(0,i))\n        Ex10:is_conjugate(line(0,1+i),line(0,3+i),point(i),point(3/2+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1427is_conjugate = {"is_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1427is_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1426is_conjugate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1427is_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_conjugate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_conjugate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1426is_conjugate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1426is_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_conjugate", 1);

  /* "giacpy/auto-methods.pxi":8930
 * 
 *         '''
 *         return GiacMethods['is_conjugate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_connected(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_conjugate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8930, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8912
 *         return GiacMethods['is_concyclic'](self,*args)
 * 
 *      def is_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_conjugate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_conjugate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8932
 *         return GiacMethods['is_conjugate'](self,*args)
 * 
 *      def is_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_connected:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1429is_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1428is_connected, "From Giac's documentation:\n        Help for is_connected:\n        is_connected(Graph(G))\n        Returns true iff G is connected.\n        See also: 1/ connected_components 2/ is_biconnected 3/ is_triconnected \n        Ex1:is_connected(path_graph(5))\n        Ex2:is_connected(cycle_graph(5))\n        Ex3:is_connected(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1429is_connected = {"is_connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1429is_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1428is_connected};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1429is_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_connected (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_connected", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1428is_connected(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1428is_connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_connected", 1);

  /* "giacpy/auto-methods.pxi":8943
 * 
 *         '''
 *         return GiacMethods['is_connected'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_coplanar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_connected); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8943, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8932
 *         return GiacMethods['is_conjugate'](self,*args)
 * 
 *      def is_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_connected:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_connected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8945
 *         return GiacMethods['is_connected'](self,*args)
 * 
 *      def is_coplanar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_coplanar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1431is_coplanar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1430is_coplanar, "From Giac's documentation:\n        Help for is_coplanar:\n        is_coplanar(Pnt,Pnt,Pnt,Pnt)\n        Test if 4 points are in the same plane.\n        Ex1:is_coplanar([0,0,0],[1,2,-3],[1,1,-2],[2,1,-3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1431is_coplanar = {"is_coplanar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1431is_coplanar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1430is_coplanar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1431is_coplanar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_coplanar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_coplanar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1430is_coplanar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1430is_coplanar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_coplanar", 1);

  /* "giacpy/auto-methods.pxi":8953
 * 
 *         '''
 *         return GiacMethods['is_coplanar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_cospherical(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_coplanar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8953, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8945
 *         return GiacMethods['is_connected'](self,*args)
 * 
 *      def is_coplanar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_coplanar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_coplanar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8955
 *         return GiacMethods['is_coplanar'](self,*args)
 * 
 *      def is_cospherical(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cospherical:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1433is_cospherical(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1432is_cospherical, "From Giac's documentation:\n        Help for is_cospherical:\n        is_cospherical(Pnt,Pnt,Pnt,Pnt)\n        Test if 5 points are on the same sphere.\n        Ex1:is_cospherical([-1,0,0],[1,0,0],[0,1,0],[0,-1,0],[0,0,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1433is_cospherical = {"is_cospherical", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1433is_cospherical, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1432is_cospherical};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1433is_cospherical(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_cospherical (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_cospherical", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1432is_cospherical(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1432is_cospherical(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_cospherical", 1);

  /* "giacpy/auto-methods.pxi":8963
 * 
 *         '''
 *         return GiacMethods['is_cospherical'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_cut_set(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_cospherical); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8963, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8955
 *         return GiacMethods['is_coplanar'](self,*args)
 * 
 *      def is_cospherical(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cospherical:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_cospherical", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8965
 *         return GiacMethods['is_cospherical'](self,*args)
 * 
 *      def is_cut_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cut_set:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1435is_cut_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1434is_cut_set, "From Giac's documentation:\n        Help for is_cut_set:\n        is_cut_set(Graph(G),Lst(E))\n        Returns true iff removing edges in the list E from G increases the number of connected components of G.\n        See also: 1/ connected_components 2/ delete_edge \n        Ex1:is_cut_set(graph(trail(1,2,3,4,5,6,4,1,3)),[[1,4],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1435is_cut_set = {"is_cut_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1435is_cut_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1434is_cut_set};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1435is_cut_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_cut_set (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_cut_set", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1434is_cut_set(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1434is_cut_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_cut_set", 1);

  /* "giacpy/auto-methods.pxi":8974
 * 
 *         '''
 *         return GiacMethods['is_cut_set'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_cycle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_cut_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8974, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8965
 *         return GiacMethods['is_cospherical'](self,*args)
 * 
 *      def is_cut_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cut_set:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_cut_set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8976
 *         return GiacMethods['is_cut_set'](self,*args)
 * 
 *      def is_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cycle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1437is_cycle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1436is_cycle, "From Giac's documentation:\n        Help for is_cycle:\n        is_cycle(Lst)\n        Returns 1 if the argument is a cycle and 0 otherwise.\n        See also: 1/ is_permu 2/ cycle2perm 3/ cycles2permu \n        Ex1:is_cycle([1,0,5])\n        Ex2:is_cycle([1,0,5,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1437is_cycle = {"is_cycle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1437is_cycle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1436is_cycle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1437is_cycle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_cycle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_cycle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1436is_cycle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1436is_cycle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_cycle", 1);

  /* "giacpy/auto-methods.pxi":8986
 * 
 *         '''
 *         return GiacMethods['is_cycle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_directed(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_cycle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8986, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8976
 *         return GiacMethods['is_cut_set'](self,*args)
 * 
 *      def is_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cycle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_cycle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8988
 *         return GiacMethods['is_cycle'](self,*args)
 * 
 *      def is_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_directed:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1439is_directed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1438is_directed, "From Giac's documentation:\n        Help for is_directed:\n        is_directed(Graph(G))\n        Returns true iff G is a digraph.\n        See also: 1/ is_weighted 2/ digraph 3/ make_directed \n        Ex1:is_directed(digraph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1439is_directed = {"is_directed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1439is_directed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1438is_directed};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1439is_directed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_directed (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_directed", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1438is_directed(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1438is_directed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_directed", 1);

  /* "giacpy/auto-methods.pxi":8997
 * 
 *         '''
 *         return GiacMethods['is_directed'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_element(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_directed); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 8997, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 8997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8988
 *         return GiacMethods['is_cycle'](self,*args)
 * 
 *      def is_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_directed:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_directed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":8999
 *         return GiacMethods['is_directed'](self,*args)
 * 
 *      def is_element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_element:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1441is_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1440is_element, "From Giac's documentation:\n        Help for is_element:\n        is_element(Pnt,GeoObj)\n        Returns 1 if the point is on the geometric object and 0 otherwise.\n        See also: 1/ element 2/ member 3/ contains \n        Ex1:is_element(point(i),square(0,1))\n        Ex2:is_element(point(i),circle(point(0),point(2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1441is_element = {"is_element", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1441is_element, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1440is_element};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1441is_element(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_element (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_element", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1440is_element(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1440is_element(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_element", 1);

  /* "giacpy/auto-methods.pxi":9009
 * 
 *         '''
 *         return GiacMethods['is_element'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_equilateral(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_element); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9009, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":8999
 *         return GiacMethods['is_directed'](self,*args)
 * 
 *      def is_element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_element:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_element", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9011
 *         return GiacMethods['is_element'](self,*args)
 * 
 *      def is_equilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_equilateral:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1443is_equilateral(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1442is_equilateral, "From Giac's documentation:\n        Help for is_equilateral:\n        is_equilateral(Pnt||Cplx,Pnt||Cplx,Pnt||Cplx)\n        Returns 1 if the 3 points (or the object) form an equilateral triangle and 0 otherwise.\n        See also: 1/ is_isosceles 2/ is_rectangle \n        Ex1:is_equilateral(0,2,1+i*sqrt(3))\n        Ex2:is_equilateral(point(0),point(1+i),point(2,2))\n        Ex3:is_equilateral(triangle(0,2,1+i*sqrt(3)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1443is_equilateral = {"is_equilateral", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1443is_equilateral, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1442is_equilateral};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1443is_equilateral(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_equilateral (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_equilateral", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1442is_equilateral(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1442is_equilateral(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_equilateral", 1);

  /* "giacpy/auto-methods.pxi":9022
 * 
 *         '''
 *         return GiacMethods['is_equilateral'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_eulerian(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_equilateral); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9022, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9011
 *         return GiacMethods['is_element'](self,*args)
 * 
 *      def is_equilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_equilateral:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_equilateral", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9024
 *         return GiacMethods['is_equilateral'](self,*args)
 * 
 *      def is_eulerian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_eulerian:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1445is_eulerian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1444is_eulerian, "From Giac's documentation:\n        Help for is_eulerian:\n        is_eulerian(Graph(G),[Var(T)])\n        Returns true iff G is Eulerian [and writes the corresponding Eulerian trail to T].\n        See also: 1/ path_graph 2/ trail \n        Ex1:is_eulerian(complete_graph(4))\n        Ex2:is_eulerian(complete_graph(5))\n        Ex3:is_eulerian(graph(trail(1,2,3,1,4,3,5,4)),T)\n        Ex4:is_eulerian(digraph(%{[1,4],[1,3],[2,1],[3,2],[4,5],[5,1]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1445is_eulerian = {"is_eulerian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1445is_eulerian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1444is_eulerian};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1445is_eulerian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_eulerian (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_eulerian", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1444is_eulerian(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1444is_eulerian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_eulerian", 1);

  /* "giacpy/auto-methods.pxi":9036
 * 
 *         '''
 *         return GiacMethods['is_eulerian'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_forest(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_eulerian); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9036, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9024
 *         return GiacMethods['is_equilateral'](self,*args)
 * 
 *      def is_eulerian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_eulerian:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_eulerian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9038
 *         return GiacMethods['is_eulerian'](self,*args)
 * 
 *      def is_forest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_forest:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1447is_forest(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1446is_forest, "From Giac's documentation:\n        Help for is_forest:\n        is_forest(Graph(G))\n        Returns true iff G is a forest (disjoint union of trees).\n        See also: 1/ is_tree \n        Ex1:is_forest(graph(trail(1,2,3,4),trail(5,2,6,7),trail(8,9,10)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1447is_forest = {"is_forest", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1447is_forest, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1446is_forest};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1447is_forest(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_forest (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_forest", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1446is_forest(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1446is_forest(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_forest", 1);

  /* "giacpy/auto-methods.pxi":9047
 * 
 *         '''
 *         return GiacMethods['is_forest'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_graphic_sequence(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_forest); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9047, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9038
 *         return GiacMethods['is_eulerian'](self,*args)
 * 
 *      def is_forest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_forest:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_forest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9049
 *         return GiacMethods['is_forest'](self,*args)
 * 
 *      def is_graphic_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_graphic_sequence:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1449is_graphic_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1448is_graphic_sequence, "From Giac's documentation:\n        Help for is_graphic_sequence:\n        is_graphic_sequence(Lst(L))\n        Returns true iff there exists a graph with degree sequence equal to L.\n        See also: 1/ degree_sequence 2/ sequence_graph \n        Ex1:is_graphic_sequence([3,2,4,2,3,4,5,7])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1449is_graphic_sequence = {"is_graphic_sequence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1449is_graphic_sequence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1448is_graphic_sequence};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1449is_graphic_sequence(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_graphic_sequence (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_graphic_sequence", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1448is_graphic_sequence(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1448is_graphic_sequence(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_graphic_sequence", 1);

  /* "giacpy/auto-methods.pxi":9058
 * 
 *         '''
 *         return GiacMethods['is_graphic_sequence'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_hamiltonian(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_graphic_sequence); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9058, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9049
 *         return GiacMethods['is_forest'](self,*args)
 * 
 *      def is_graphic_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_graphic_sequence:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_graphic_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9060
 *         return GiacMethods['is_graphic_sequence'](self,*args)
 * 
 *      def is_hamiltonian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_hamiltonian:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1451is_hamiltonian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1450is_hamiltonian, "From Giac's documentation:\n        Help for is_hamiltonian:\n        is_hamiltonian(Graph(G),[Var(hc)])\n        Returns true iff G is a Hamiltonian graph [and assigns a Hamiltonian circuit to an unassigned identifier hc].\n        See also: 1/ traveling_salesman \n        Ex1:is_hamiltonian(graph(\"petersen\"))\n        Ex2:is_hamiltonian(hypercube_graph(5),C)\n        Ex3:is_hamiltonian(digraph(%{[1,2],[1,3],[2,3],[2,4],[3,2],[3,4],[4,1]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1451is_hamiltonian = {"is_hamiltonian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1451is_hamiltonian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1450is_hamiltonian};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1451is_hamiltonian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_hamiltonian (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_hamiltonian", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1450is_hamiltonian(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1450is_hamiltonian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_hamiltonian", 1);

  /* "giacpy/auto-methods.pxi":9071
 * 
 *         '''
 *         return GiacMethods['is_hamiltonian'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_harmonic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_hamiltonian); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9071, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9060
 *         return GiacMethods['is_graphic_sequence'](self,*args)
 * 
 *      def is_hamiltonian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_hamiltonian:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_hamiltonian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9073
 *         return GiacMethods['is_hamiltonian'](self,*args)
 * 
 *      def is_harmonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1453is_harmonic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1452is_harmonic, "From Giac's documentation:\n        Help for is_harmonic:\n        is_harmonic(Pnt or Cplx,Pnt or Cplx,Pnt or Cplx,Pnt or Cplx)\n        Returns 1 if the 4 points are in a harmonic division and 0 otherwise.\n        See also: 1/ is_conjugate \n        Ex1:is_harmonic(0,2,3/2,3)\n        Ex2:is_harmonic(0,1+i,1,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1453is_harmonic = {"is_harmonic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1453is_harmonic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1452is_harmonic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1453is_harmonic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_harmonic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_harmonic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1452is_harmonic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1452is_harmonic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_harmonic", 1);

  /* "giacpy/auto-methods.pxi":9083
 * 
 *         '''
 *         return GiacMethods['is_harmonic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_harmonic_circle_bundle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_harmonic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9083, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9073
 *         return GiacMethods['is_hamiltonian'](self,*args)
 * 
 *      def is_harmonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_harmonic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9085
 *         return GiacMethods['is_harmonic'](self,*args)
 * 
 *      def is_harmonic_circle_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_circle_bundle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1455is_harmonic_circle_bundle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1454is_harmonic_circle_bundle, "From Giac's documentation:\n        Help for is_harmonic_circle_bundle:\n        is_harmonic_circle_bundle(Lst(Crcle))\n        Returns 1 if the circles have a common point, 2 if they have the same center, 3 if they are the same and 0 otherwise.\n        See also: 1/ is_harmonic_line_bundle \n        Ex1:is_harmonic_circle_bundle([circle(0,i),circle(4,i),circle(0,point(1/2))])\n        Ex2:is_harmonic_circle_bundle([circle(0,1+i),circle(2,1+i),circle(1+i,point(1-i))])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1455is_harmonic_circle_bundle = {"is_harmonic_circle_bundle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1455is_harmonic_circle_bundle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1454is_harmonic_circle_bundle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1455is_harmonic_circle_bundle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_harmonic_circle_bundle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_harmonic_circle_bundle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1454is_harmonic_circle_bundle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1454is_harmonic_circle_bundle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_harmonic_circle_bundle", 1);

  /* "giacpy/auto-methods.pxi":9095
 * 
 *         '''
 *         return GiacMethods['is_harmonic_circle_bundle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_harmonic_line_bundle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_harmonic_circle_bundle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9095, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9085
 *         return GiacMethods['is_harmonic'](self,*args)
 * 
 *      def is_harmonic_circle_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_circle_bundle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_harmonic_circle_bundle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9097
 *         return GiacMethods['is_harmonic_circle_bundle'](self,*args)
 * 
 *      def is_harmonic_line_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_line_bundle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1457is_harmonic_line_bundle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1456is_harmonic_line_bundle, "From Giac's documentation:\n        Help for is_harmonic_line_bundle:\n        is_harmonic_line_bundle(Lst(Line))\n        Returns 1 if the lines have a common point, 2 if they are parallels, 3 if they are the same and 0 otherwise.\n        See also: 1/ is_harmonic_circle_bundle \n        Ex1:is_harmonic_line_bundle([line(0,1+i),line(0,2+i),line(0,1),line(0,3+i)])\n        Ex2:is_harmonic_line_bundle([line(0,1+i),line(2,3+i),line(3,4+i),line(-1,i)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1457is_harmonic_line_bundle = {"is_harmonic_line_bundle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1457is_harmonic_line_bundle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1456is_harmonic_line_bundle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1457is_harmonic_line_bundle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_harmonic_line_bundle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_harmonic_line_bundle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1456is_harmonic_line_bundle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1456is_harmonic_line_bundle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_harmonic_line_bundle", 1);

  /* "giacpy/auto-methods.pxi":9107
 * 
 *         '''
 *         return GiacMethods['is_harmonic_line_bundle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_inside(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_harmonic_line_bundle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9107, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9097
 *         return GiacMethods['is_harmonic_circle_bundle'](self,*args)
 * 
 *      def is_harmonic_line_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_line_bundle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_harmonic_line_bundle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9109
 *         return GiacMethods['is_harmonic_line_bundle'](self,*args)
 * 
 *      def is_inside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_inside:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1459is_inside(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1458is_inside, "From Giac's documentation:\n        Help for is_inside:\n        is_inside(Pnt,Polygon or Circle)\n        Checks whether a point is inside a polygon or a circle.\n        See also: 1/ is_element \n        Ex1:is_inside(point(0),circle(-1,1))\n        Ex2:is_inside(point(1-i),triangle([1,2-i,3+i]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1459is_inside = {"is_inside", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1459is_inside, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1458is_inside};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1459is_inside(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_inside (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_inside", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1458is_inside(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1458is_inside(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_inside", 1);

  /* "giacpy/auto-methods.pxi":9119
 * 
 *         '''
 *         return GiacMethods['is_inside'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_integer_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_inside); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9119, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9109
 *         return GiacMethods['is_harmonic_line_bundle'](self,*args)
 * 
 *      def is_inside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_inside:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_inside", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9121
 *         return GiacMethods['is_inside'](self,*args)
 * 
 *      def is_integer_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_integer_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1461is_integer_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1460is_integer_graph, "From Giac's documentation:\n        Help for is_integer_graph:\n        is_integer_graph(Graph(G))\n        Returns true iff the spectrum of G consists only of integers.\n        See also: 1/ graph_spectrum \n        Ex1:is_integer_graph(graph(\"levi\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1461is_integer_graph = {"is_integer_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1461is_integer_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1460is_integer_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1461is_integer_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_integer_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_integer_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1460is_integer_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1460is_integer_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_integer_graph", 1);

  /* "giacpy/auto-methods.pxi":9130
 * 
 *         '''
 *         return GiacMethods['is_integer_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_irreducible(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_integer_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9130, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9121
 *         return GiacMethods['is_inside'](self,*args)
 * 
 *      def is_integer_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_integer_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_integer_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9132
 *         return GiacMethods['is_integer_graph'](self,*args)
 * 
 *      def is_irreducible(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_irreducible:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1463is_irreducible(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1462is_irreducible, "From Giac's documentation:\n        Help for is_irreducible:\n        is_irreducible(Polynomial)\n        Polynomial irreducibility test\n        See also: 1/ factor 2/ factors \n        Ex1:is_irreducible(x^2+1)\n        Ex2:is_irreducible(x^3+x+1 mod 7)\n        Ex3:is_irreducible(x^3+3x+1 mod 7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1463is_irreducible = {"is_irreducible", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1463is_irreducible, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1462is_irreducible};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1463is_irreducible(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_irreducible (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_irreducible", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1462is_irreducible(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1462is_irreducible(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_irreducible", 1);

  /* "giacpy/auto-methods.pxi":9143
 * 
 *         '''
 *         return GiacMethods['is_irreducible'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_isomorphic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_irreducible); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9143, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9132
 *         return GiacMethods['is_integer_graph'](self,*args)
 * 
 *      def is_irreducible(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_irreducible:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_irreducible", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9145
 *         return GiacMethods['is_irreducible'](self,*args)
 * 
 *      def is_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isomorphic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1465is_isomorphic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1464is_isomorphic, "From Giac's documentation:\n        Help for is_isomorphic:\n        is_isomorphic(Graph(G1),Graph(G2),[Var(I)])\n        Returns true iff G1 and G2 are isomorphic graphs. If an unassigned identifier 'I' is given, the isomorphism is assigned to it as a permutation.\n        See also: 1/ isomorphic_copy 2/ permute_vertices \n        Ex1: G1:=graph(\"petersen\"); G2:=kneser_graph(5,2); is_isomorphic(G1,G2,I)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1465is_isomorphic = {"is_isomorphic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1465is_isomorphic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1464is_isomorphic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1465is_isomorphic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_isomorphic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_isomorphic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1464is_isomorphic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1464is_isomorphic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_isomorphic", 1);

  /* "giacpy/auto-methods.pxi":9154
 * 
 *         '''
 *         return GiacMethods['is_isomorphic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_isosceles(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_isomorphic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9145
 *         return GiacMethods['is_irreducible'](self,*args)
 * 
 *      def is_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isomorphic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_isomorphic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9156
 *         return GiacMethods['is_isomorphic'](self,*args)
 * 
 *      def is_isosceles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isosceles:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1467is_isosceles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1466is_isosceles, "From Giac's documentation:\n        Help for is_isosceles:\n        is_isosceles(Pnt or Cplx,Pnt or Cplx,Pnt or Cplx)\n        Returns 1, 2 or 3 if the 3 points (or the object) form an isosceles triangle with equal sides at vertex 1, 2, or 3, returns 4 if the 3 points (or the object) form an equilateral triangle and 0 otherwise.\n        See also: 1/ is_equilateral 2/ is_right_triangle \n        Ex1:is_isosceles(0,i,1+i)\n        Ex2:is_isosceles(point(0),point(1+i),point(2,2))\n        Ex3:is_isosceles(triangle(0,i,1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1467is_isosceles = {"is_isosceles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1467is_isosceles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1466is_isosceles};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1467is_isosceles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_isosceles (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_isosceles", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1466is_isosceles(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1466is_isosceles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_isosceles", 1);

  /* "giacpy/auto-methods.pxi":9167
 * 
 *         '''
 *         return GiacMethods['is_isosceles'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_network(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_isosceles); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9167, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9156
 *         return GiacMethods['is_isomorphic'](self,*args)
 * 
 *      def is_isosceles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isosceles:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_isosceles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9169
 *         return GiacMethods['is_isosceles'](self,*args)
 * 
 *      def is_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_network:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1469is_network(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1468is_network, "From Giac's documentation:\n        Help for is_network:\n        is_network(Graph(G),[Vrtx(s),Vrtx(t)])\n        Returns true iff G is a network with the source s and sink t. If s and t are not provided, the output is a sequence of two sets of vertices: sources and sinks.\n        See also: 1/ random_network 2/ maxflow \n        Ex1:is_network(digraph(trail(1,2,3,4,5,6,4,7)))\n        Ex2:is_network(digraph(trail(1,2,3,4,5,6,4,7)),1,7)\n        Ex3:is_network(digraph(trail(1,2,3,4,5,6,4,1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1469is_network = {"is_network", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1469is_network, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1468is_network};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1469is_network(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_network (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_network", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1468is_network(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1468is_network(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_network", 1);

  /* "giacpy/auto-methods.pxi":9180
 * 
 *         '''
 *         return GiacMethods['is_network'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_orthogonal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_network); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9180, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9169
 *         return GiacMethods['is_isosceles'](self,*args)
 * 
 *      def is_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_network:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_network", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9182
 *         return GiacMethods['is_network'](self,*args)
 * 
 *      def is_orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_orthogonal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1471is_orthogonal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1470is_orthogonal, "From Giac's documentation:\n        Help for is_orthogonal:\n        is_orthogonal(Line||Crcle,Line||Crcle)\n        Returns 1 if the 2 circles are orthogonal (orthogonal tangents at a point of intersection) or if the 2 lines are orthogonal and 0 otherwise.\n        See also: 1/ is_parallel 2/ is_perpendicular \n        Ex1:is_orthogonal(line(0,1+i),line(1,i))\n        Ex2:is_orthogonal(circle(0,1+i),circle(2,1+i))\n        Ex3:is_orthogonal(line([2,3,-2],[-1,-1,-1]),line([1,0,0],[1,2,8]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1471is_orthogonal = {"is_orthogonal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1471is_orthogonal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1470is_orthogonal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1471is_orthogonal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_orthogonal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_orthogonal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1470is_orthogonal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1470is_orthogonal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_orthogonal", 1);

  /* "giacpy/auto-methods.pxi":9193
 * 
 *         '''
 *         return GiacMethods['is_orthogonal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_parallel(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_orthogonal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9193, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9182
 *         return GiacMethods['is_network'](self,*args)
 * 
 *      def is_orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_orthogonal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_orthogonal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9195
 *         return GiacMethods['is_orthogonal'](self,*args)
 * 
 *      def is_parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallel:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1473is_parallel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1472is_parallel, "From Giac's documentation:\n        Help for is_parallel:\n        is_parallel(Line or Plan ,Line or Plan)\n        Returns 1 if 2 lines are parallel and 0 otherwise.\n        See also: 1/ is_perpendicular \n        Ex1:is_parallel(line(0,i),line(1,1+i))\n        Ex2:is_parallel(line([2,3,-2],[-1,-1,-1]),plane([-1,-1,-1],[1,2,-3],[0,0,0]))\n        Ex3:is_parallel(line([0,0,0],[-1,-1,-1]),line([2,3,-2],[-1,-1,-1]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1473is_parallel = {"is_parallel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1473is_parallel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1472is_parallel};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1473is_parallel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_parallel (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_parallel", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1472is_parallel(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1472is_parallel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_parallel", 1);

  /* "giacpy/auto-methods.pxi":9206
 * 
 *         '''
 *         return GiacMethods['is_parallel'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_parallelogram(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_parallel); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9206, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9195
 *         return GiacMethods['is_orthogonal'](self,*args)
 * 
 *      def is_parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallel:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_parallel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9208
 *         return GiacMethods['is_parallel'](self,*args)
 * 
 *      def is_parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallelogram:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1475is_parallelogram(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1474is_parallelogram, "From Giac's documentation:\n        Help for is_parallelogram:\n        is_parallelogram(Pnt or Cplx,Pnt or Cplx,Pnt or Cplx,Pnt or Cplx)\n        Returns 1,2,3 or 4 if the 4 points (or the object) form a parallelogram, (2 for a rhombus, 3 for a rectangle, 4 for a square) and 0 otherwise.\n        See also: 1/ est_rectangle 2/ is_square 3/ is_rhombus \n        Ex1:is_parallelogram(0,i,1+i,1)\n        Ex2:is_parallelogram(1,-1,i,-i)\n        Ex3:is_parallelogram(sommets(parallelogram(1,-1,-i,C)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1475is_parallelogram = {"is_parallelogram", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1475is_parallelogram, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1474is_parallelogram};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1475is_parallelogram(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_parallelogram (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_parallelogram", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1474is_parallelogram(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1474is_parallelogram(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_parallelogram", 1);

  /* "giacpy/auto-methods.pxi":9219
 * 
 *         '''
 *         return GiacMethods['is_parallelogram'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_permu(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_parallelogram); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9219, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9208
 *         return GiacMethods['is_parallel'](self,*args)
 * 
 *      def is_parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallelogram:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_parallelogram", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9221
 *         return GiacMethods['is_parallelogram'](self,*args)
 * 
 *      def is_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_permu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1477is_permu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1476is_permu, "From Giac's documentation:\n        Help for is_permu:\n        is_permu(Lst)\n        Returns 1 if the argument is a permutation and 0 otherwise.\n        See also: 1/ is_cycle 2/ permu2cycles \n        Ex1:is_permu([4,2,3,1])\n        Ex2:is_permu([4,2,3,1,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1477is_permu = {"is_permu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1477is_permu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1476is_permu};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1477is_permu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_permu (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_permu", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1476is_permu(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1476is_permu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_permu", 1);

  /* "giacpy/auto-methods.pxi":9231
 * 
 *         '''
 *         return GiacMethods['is_permu'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_perpendicular(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_permu); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9231, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9221
 *         return GiacMethods['is_parallelogram'](self,*args)
 * 
 *      def is_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_permu:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_permu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9233
 *         return GiacMethods['is_permu'](self,*args)
 * 
 *      def is_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_perpendicular:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1479is_perpendicular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1478is_perpendicular, "From Giac's documentation:\n        Help for is_perpendicular:\n        is_perpendicular(Line or Plan,Line or Plan)\n        Returns 1 if 2 lines are perpendicular.\n        See also: 1/ is_parallel 2/ is_orthogonal \n        Ex1:is_perpendicular(line(0,i),line(1,1+i))\n        Ex2:is_perpendicular(line([2,3,-2],[-1,-1,-1]),line([1,0,0],[1,2,8]))\n        Ex3:is_perpendicular(plane([0,0,0],[1,2,-3],[1,1,-2]),plane([-1,-1,-1],[1,2,-3],[0,0,0]))\n        Ex4:is_perpendicular(line([2,3,-2],[-1,-1,-1]),plane([0,0,0],[1,2,-3],[1,1,-2]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1479is_perpendicular = {"is_perpendicular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1479is_perpendicular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1478is_perpendicular};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1479is_perpendicular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_perpendicular (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_perpendicular", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1478is_perpendicular(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1478is_perpendicular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_perpendicular", 1);

  /* "giacpy/auto-methods.pxi":9245
 * 
 *         '''
 *         return GiacMethods['is_perpendicular'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_planar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_perpendicular); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9245, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9233
 *         return GiacMethods['is_permu'](self,*args)
 * 
 *      def is_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_perpendicular:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_perpendicular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9247
 *         return GiacMethods['is_perpendicular'](self,*args)
 * 
 *      def is_planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_planar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1481is_planar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1480is_planar, "From Giac's documentation:\n        Help for is_planar:\n        is_planar(Graph(G))\n        Returns true iff G is planar.\n        See also: 1/ draw_graph 2/ random_planar \n        Ex1:is_planar(complete_graph(4))\n        Ex2:is_planar(complete_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1481is_planar = {"is_planar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1481is_planar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1480is_planar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1481is_planar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_planar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_planar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1480is_planar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1480is_planar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_planar", 1);

  /* "giacpy/auto-methods.pxi":9257
 * 
 *         '''
 *         return GiacMethods['is_planar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_prime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_planar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9257, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9247
 *         return GiacMethods['is_perpendicular'](self,*args)
 * 
 *      def is_planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_planar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_planar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9259
 *         return GiacMethods['is_planar'](self,*args)
 * 
 *      def is_prime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_prime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1483is_prime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1482is_prime, "From Giac's documentation:\n        Help for is_prime:\n        is_prime(Intg,[1 || 2])\n        Mixed or \"p-1\" Pocklington [1] or APRCL test [2] (returns the coefficients for a proof of primality, 1 or 0).\n        See also: 1/ prevprime 2/ nextprime 3/ is_pseudoprime 4/ isprime \n        Ex1:is_prime(1999)\n        Ex2:is_prime(9856989898997)\n        Ex3:is_prime(9856989898997789789)\n        Ex4:is_prime(9856989898997789789,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1483is_prime = {"is_prime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1483is_prime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1482is_prime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1483is_prime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_prime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_prime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1482is_prime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1482is_prime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_prime", 1);

  /* "giacpy/auto-methods.pxi":9271
 * 
 *         '''
 *         return GiacMethods['is_prime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_pseudoprime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_prime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9271, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9259
 *         return GiacMethods['is_planar'](self,*args)
 * 
 *      def is_prime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_prime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_prime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9273
 *         return GiacMethods['is_prime'](self,*args)
 * 
 *      def is_pseudoprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_pseudoprime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1485is_pseudoprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1484is_pseudoprime, "From Giac's documentation:\n        Help for is_pseudoprime:\n        is_pseudoprime(Intg)\n        Pseudo-prime test (0 not prime, 1 probably prime, 2 prime).\n        See also: 1/ prevprime 2/ nextprime 3/ is_prime \n        Ex1:is_pseudoprime(1999)\n        Ex2:is_pseudoprime(9856989898997)\n        Ex3:is_pseudoprime(9856989898997789789)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1485is_pseudoprime = {"is_pseudoprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1485is_pseudoprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1484is_pseudoprime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1485is_pseudoprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_pseudoprime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_pseudoprime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1484is_pseudoprime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1484is_pseudoprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_pseudoprime", 1);

  /* "giacpy/auto-methods.pxi":9284
 * 
 *         '''
 *         return GiacMethods['is_pseudoprime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_reachable(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_pseudoprime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9284, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9273
 *         return GiacMethods['is_prime'](self,*args)
 * 
 *      def is_pseudoprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_pseudoprime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_pseudoprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9286
 *         return GiacMethods['is_pseudoprime'](self,*args)
 * 
 *      def is_reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_reachable:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1487is_reachable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1486is_reachable, "From Giac's documentation:\n        Help for is_reachable:\n        is_reachable(Graph(G),Vrtx(u),Vrtx(v))\n        Returns true iff there exists a path from u to v in a (di)graph G.\n        See also: 1/ reachable 2/ shortest_path \n        Ex1: G:=graph_complement(complete_graph(3,4)):;is_reachable(G,3,2)\n        Ex2: G:=graph_complement(complete_graph(3,4)):;is_reachable(G,3,5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1487is_reachable = {"is_reachable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1487is_reachable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1486is_reachable};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1487is_reachable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_reachable (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_reachable", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1486is_reachable(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1486is_reachable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_reachable", 1);

  /* "giacpy/auto-methods.pxi":9296
 * 
 *         '''
 *         return GiacMethods['is_reachable'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_rectangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_reachable); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9296, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9286
 *         return GiacMethods['is_pseudoprime'](self,*args)
 * 
 *      def is_reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_reachable:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_reachable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9298
 *         return GiacMethods['is_reachable'](self,*args)
 * 
 *      def is_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rectangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1489is_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1488is_rectangle, "From Giac's documentation:\n        Help for is_rectangle:\n        is_rectangle(Pnt||Cplx,Pnt||Cplx,Pnt||Cplx,[Pnt||Cplx])\n        Returns 1, 2 or 3 if the 3 points (or the object) form a right triangle with right angle at vertex 1, 2 or 3 and 0 otherwise [or 1 if the 4 points (or the object) form a rectangle, 2 if the 4 points (or the object) form a square and 0 otherwise].\n        See also: 1/ is_equilateral 2/ is_isosceles 3/ is_parallelogram 4/ is_rhombus 5/ is_square \n        Ex1:is_rectangle(0,i,1+i)\n        Ex2:is_rectangle(point(0),point(1+i),point(2,2))\n        Ex3:is_rectangle(triangle(0,i,1+i))\n        Ex4:is_rectangle(point(0),point(2,2),point(1,3),point(-1,1))\n        Ex5:is_rectangle(rectangle(point(0),point(2,2),1/2))\n        Ex6:is_rectangle(sommets(rectangle(point(0),point(2,2),1/2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1489is_rectangle = {"is_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1489is_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1488is_rectangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1489is_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_rectangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_rectangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1488is_rectangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1488is_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_rectangle", 1);

  /* "giacpy/auto-methods.pxi":9312
 * 
 *         '''
 *         return GiacMethods['is_rectangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_regular(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_rectangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9312, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9298
 *         return GiacMethods['is_reachable'](self,*args)
 * 
 *      def is_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rectangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_rectangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9314
 *         return GiacMethods['is_rectangle'](self,*args)
 * 
 *      def is_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_regular:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1491is_regular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1490is_regular, "From Giac's documentation:\n        Help for is_regular:\n        is_regular(Graph(G))\n        Returns true iff the max and min degrees of G are equal (if G is directed then out- and in-degrees must be pairwise equal for each vertex of G).\n        See also: 1/ degree_sequence 2/ maximum_degree 3/ minimum_degree 4/ random_regular_graph 5/ vertex_degree \n        Ex1:is_regular(complete_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1491is_regular = {"is_regular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1491is_regular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1490is_regular};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1491is_regular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_regular (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_regular", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1490is_regular(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1490is_regular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_regular", 1);

  /* "giacpy/auto-methods.pxi":9323
 * 
 *         '''
 *         return GiacMethods['is_regular'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_rhombus(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_regular); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9323, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9314
 *         return GiacMethods['is_rectangle'](self,*args)
 * 
 *      def is_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_regular:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_regular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9325
 *         return GiacMethods['is_regular'](self,*args)
 * 
 *      def is_rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rhombus:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1493is_rhombus(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1492is_rhombus, "From Giac's documentation:\n        Help for is_rhombus:\n        is_rhombus(Pnt or Cplx,Pnt or Cplx,Pnt or Cplx,Pnt or Cplx)\n        Returns 1 or 2 if the 4 points (or the object) form a rhombus (2 for a square) and 0 otherwise.\n        See also: 1/ est_rectangle 2/ is_parallelogram 3/ is_square \n        Ex1:is_rhombus(0,i,1+i,1)\n        Ex2:is_rhombus(1,-1,i,-i)\n        Ex3:is_rhombus(sommets(rhombus(1,-1,pi/4,C,D)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1493is_rhombus = {"is_rhombus", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1493is_rhombus, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1492is_rhombus};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1493is_rhombus(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_rhombus (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_rhombus", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1492is_rhombus(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1492is_rhombus(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_rhombus", 1);

  /* "giacpy/auto-methods.pxi":9336
 * 
 *         '''
 *         return GiacMethods['is_rhombus'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_split_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_rhombus); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9336, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9325
 *         return GiacMethods['is_regular'](self,*args)
 * 
 *      def is_rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rhombus:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_rhombus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9338
 *         return GiacMethods['is_rhombus'](self,*args)
 * 
 *      def is_split_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_split_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1495is_split_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1494is_split_graph, "From Giac's documentation:\n        Help for is_split_graph:\n        is_split_graph(Graph(G),[part])\n        Returns true iff the vertex set of G can be partitioned into a clique and an independent set. These are also returned if the keyword 'part' is provided.\n        See also: 1/ degree_sequence 2/ maximum_clique 3/ maximum_independent_set \n        Ex1:is_split_graph(graph(5,%{[0,1],[0,2],[1,2],[1,3],[2,3],[3,4]%}),part)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1495is_split_graph = {"is_split_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1495is_split_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1494is_split_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1495is_split_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_split_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_split_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1494is_split_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1494is_split_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_split_graph", 1);

  /* "giacpy/auto-methods.pxi":9347
 * 
 *         '''
 *         return GiacMethods['is_split_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_square(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_split_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9347, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9338
 *         return GiacMethods['is_rhombus'](self,*args)
 * 
 *      def is_split_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_split_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_split_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9349
 *         return GiacMethods['is_split_graph'](self,*args)
 * 
 *      def is_square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_square:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1497is_square(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1496is_square, "From Giac's documentation:\n        Help for is_square:\n        is_square(Pnt,Pnt,Pnt,Pnt)\n        Returns 1 if the 4 points form a square and 0 otherwise.\n        See also: 1/ est_rectangle 2/ is_parallelogram 3/ is_rhombus \n        Ex1:is_square(0,i,1+i,1)\n        Ex2:is_square(1,-1,i,-i)\n        Ex3:is_square(sommets(square(0,i,C,D)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1497is_square = {"is_square", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1497is_square, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1496is_square};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1497is_square(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_square (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_square", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1496is_square(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1496is_square(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_square", 1);

  /* "giacpy/auto-methods.pxi":9360
 * 
 *         '''
 *         return GiacMethods['is_square'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_strongly_connected(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_square); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9360, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9349
 *         return GiacMethods['is_split_graph'](self,*args)
 * 
 *      def is_square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_square:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_square", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9362
 *         return GiacMethods['is_square'](self,*args)
 * 
 *      def is_strongly_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_connected:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1499is_strongly_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1498is_strongly_connected, "From Giac's documentation:\n        Help for is_strongly_connected:\n        is_strongly_connected(Graph(G))\n        Returns true iff a digraph G is strongly connected.\n        See also: 1/ connected_components 2/ is_connected 3/ strongly_connected_components \n        Ex1:is_strongly_connected(digraph([1,2,3],%{[1,2],[1,3],[2,3],[3,2]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1499is_strongly_connected = {"is_strongly_connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1499is_strongly_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1498is_strongly_connected};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1499is_strongly_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_strongly_connected (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_strongly_connected", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1498is_strongly_connected(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1498is_strongly_connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_strongly_connected", 1);

  /* "giacpy/auto-methods.pxi":9371
 * 
 *         '''
 *         return GiacMethods['is_strongly_connected'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_strongly_regular(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_strongly_connected); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9371, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9362
 *         return GiacMethods['is_square'](self,*args)
 * 
 *      def is_strongly_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_connected:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_strongly_connected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9373
 *         return GiacMethods['is_strongly_connected'](self,*args)
 * 
 *      def is_strongly_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_regular:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1501is_strongly_regular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1500is_strongly_regular, "From Giac's documentation:\n        Help for is_strongly_regular:\n        is_strongly_regular(Graph(G),[Var(srg)])\n        Returns true iff G is strongly regular and optionally outputs srg=[k,l,m] where k is the vertex degree and l resp. m is the number of common neighbors for adjacent resp. non-adjacent vertices.\n        See also: 1/ is_regular 2/ adjacency_matrix 3/ seidel_spectrum \n        Ex1:is_strongly_regular(graph(\"clebsch\"))\n        Ex2:is_strongly_regular(graph(\"shrikhande\"),s); s\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1501is_strongly_regular = {"is_strongly_regular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1501is_strongly_regular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1500is_strongly_regular};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1501is_strongly_regular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_strongly_regular (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_strongly_regular", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1500is_strongly_regular(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1500is_strongly_regular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_strongly_regular", 1);

  /* "giacpy/auto-methods.pxi":9383
 * 
 *         '''
 *         return GiacMethods['is_strongly_regular'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_subgraph_isomorphic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_strongly_regular); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9383, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9373
 *         return GiacMethods['is_strongly_connected'](self,*args)
 * 
 *      def is_strongly_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_regular:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_strongly_regular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9385
 *         return GiacMethods['is_strongly_regular'](self,*args)
 * 
 *      def is_subgraph_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_subgraph_isomorphic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1503is_subgraph_isomorphic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1502is_subgraph_isomorphic, "From Giac's documentation:\n        Help for is_subgraph_isomorphic:\n        is_subgraph_isomorphic(Graph(G1),Graph(G2),[opts])\n        Returns true iff G1 is isomorphic to a subgraph of G2.\n        See also: 1/ is_isomorphic 2/ subgraph \n        Ex1:is_subgraph_isomorphic(cycle_graph(5),flower_snark(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1503is_subgraph_isomorphic = {"is_subgraph_isomorphic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1503is_subgraph_isomorphic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1502is_subgraph_isomorphic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1503is_subgraph_isomorphic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_subgraph_isomorphic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_subgraph_isomorphic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1502is_subgraph_isomorphic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1502is_subgraph_isomorphic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_subgraph_isomorphic", 1);

  /* "giacpy/auto-methods.pxi":9394
 * 
 *         '''
 *         return GiacMethods['is_subgraph_isomorphic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_tournament(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_subgraph_isomorphic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9394, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9385
 *         return GiacMethods['is_strongly_regular'](self,*args)
 * 
 *      def is_subgraph_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_subgraph_isomorphic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_subgraph_isomorphic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9396
 *         return GiacMethods['is_subgraph_isomorphic'](self,*args)
 * 
 *      def is_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tournament:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1505is_tournament(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1504is_tournament, "From Giac's documentation:\n        Help for is_tournament:\n        is_tournament(Graph(G))\n        Returns true iff G is a tournament.\n        See also: 1/ has_edge 2/ random_tournament \n        Ex1:is_tournament(digraph(%{[1,2],[2,3],[3,1]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1505is_tournament = {"is_tournament", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1505is_tournament, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1504is_tournament};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1505is_tournament(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_tournament (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_tournament", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1504is_tournament(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1504is_tournament(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_tournament", 1);

  /* "giacpy/auto-methods.pxi":9405
 * 
 *         '''
 *         return GiacMethods['is_tournament'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_tournament); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9405, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9396
 *         return GiacMethods['is_subgraph_isomorphic'](self,*args)
 * 
 *      def is_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tournament:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_tournament", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9407
 *         return GiacMethods['is_tournament'](self,*args)
 * 
 *      def is_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1507is_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1506is_tree, "From Giac's documentation:\n        Help for is_tree:\n        is_tree(Graph(G))\n        Returns true iff G is a tree.\n        See also: 1/ is_forest 2/ random_tree 3/ tree_height \n        Ex1:is_tree(random_tree(15))\n        Ex2:is_tree(path_graph(4))\n        Ex3:is_tree(cycle_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1507is_tree = {"is_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1507is_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1506is_tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1507is_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1506is_tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1506is_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_tree", 1);

  /* "giacpy/auto-methods.pxi":9418
 * 
 *         '''
 *         return GiacMethods['is_tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_triconnected(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9418, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9407
 *         return GiacMethods['is_tournament'](self,*args)
 * 
 *      def is_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9420
 *         return GiacMethods['is_tree'](self,*args)
 * 
 *      def is_triconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_triconnected:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1509is_triconnected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1508is_triconnected, "From Giac's documentation:\n        Help for is_triconnected:\n        is_triconnected(Graph(G))\n        Returns true iff G is triconnected.\n        See also: 1/ is_connected 2/ is_biconnected \n        Ex1:is_triconnected(graph(\"soccerball\"))\n        Ex2:is_triconnected(graph(\"petersen\"))\n        Ex3:is_triconnected(cycle_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1509is_triconnected = {"is_triconnected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1509is_triconnected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1508is_triconnected};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1509is_triconnected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_triconnected (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_triconnected", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1508is_triconnected(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1508is_triconnected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_triconnected", 1);

  /* "giacpy/auto-methods.pxi":9431
 * 
 *         '''
 *         return GiacMethods['is_triconnected'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_two_edge_connected(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_triconnected); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9431, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9420
 *         return GiacMethods['is_tree'](self,*args)
 * 
 *      def is_triconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_triconnected:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_triconnected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9433
 *         return GiacMethods['is_triconnected'](self,*args)
 * 
 *      def is_two_edge_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_two_edge_connected:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1511is_two_edge_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1510is_two_edge_connected, "From Giac's documentation:\n        Help for is_two_edge_connected:\n        is_two_edge_connected(Graph(G))\n        Returns true iff an undirected graph G contains no bridges.\n        See also: 1/ two_edge_connected_components 2/ edge_connectivity \n        Ex1:is_two_edge_connected(cycle_graph(4))\n        Ex2:is_two_edge_connected(path_graph(4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1511is_two_edge_connected = {"is_two_edge_connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1511is_two_edge_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1510is_two_edge_connected};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1511is_two_edge_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_two_edge_connected (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_two_edge_connected", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1510is_two_edge_connected(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1510is_two_edge_connected(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_two_edge_connected", 1);

  /* "giacpy/auto-methods.pxi":9443
 * 
 *         '''
 *         return GiacMethods['is_two_edge_connected'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_vertex_colorable(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_two_edge_connected); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9443, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9433
 *         return GiacMethods['is_triconnected'](self,*args)
 * 
 *      def is_two_edge_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_two_edge_connected:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_two_edge_connected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9445
 *         return GiacMethods['is_two_edge_connected'](self,*args)
 * 
 *      def is_vertex_colorable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_vertex_colorable:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1513is_vertex_colorable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1512is_vertex_colorable, "From Giac's documentation:\n        Help for is_vertex_colorable:\n        is_vertex_colorable(Graph(G),Intg(k),[Var(col)])\n        Returns true iff the vertices of G can be colored by using at most k colors. If true is returned and an identifier col is given, the colors of the vertices are stored there.\n        See also: 1/ greedy_color 2/ chromatic_number \n        Ex1:is_vertex_colorable(graph(\"petersen\"),2)\n        Ex2:is_vertex_colorable(graph(\"petersen\"),3,cols)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1513is_vertex_colorable = {"is_vertex_colorable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1513is_vertex_colorable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1512is_vertex_colorable};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1513is_vertex_colorable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_vertex_colorable (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_vertex_colorable", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1512is_vertex_colorable(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1512is_vertex_colorable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_vertex_colorable", 1);

  /* "giacpy/auto-methods.pxi":9455
 * 
 *         '''
 *         return GiacMethods['is_vertex_colorable'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def is_weighted(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_vertex_colorable); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9455, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9445
 *         return GiacMethods['is_two_edge_connected'](self,*args)
 * 
 *      def is_vertex_colorable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_vertex_colorable:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_vertex_colorable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9457
 *         return GiacMethods['is_vertex_colorable'](self,*args)
 * 
 *      def is_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_weighted:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1515is_weighted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1514is_weighted, "From Giac's documentation:\n        Help for is_weighted:\n        is_weighted(Graph(G))\n        Returns true iff G is weighted.\n        See also: 1/ get_edge_weight 2/ make_weighted 3/ set_edge_weight 4/ weight_matrix \n        Ex1:is_weighted(graph(%{[a,b],[b,c]%})\n        Ex2:is_weighted(graph(%{[[a,b],2],[[b,c],3]%})\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1515is_weighted = {"is_weighted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1515is_weighted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1514is_weighted};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1515is_weighted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_weighted (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_weighted", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1514is_weighted(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1514is_weighted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_weighted", 1);

  /* "giacpy/auto-methods.pxi":9467
 * 
 *         '''
 *         return GiacMethods['is_weighted'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isinf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_is_weighted); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9467, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9457
 *         return GiacMethods['is_vertex_colorable'](self,*args)
 * 
 *      def is_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_weighted:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.is_weighted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9469
 *         return GiacMethods['is_weighted'](self,*args)
 * 
 *      def isinf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isinf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1517isinf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1516isinf, "From Giac's documentation:\n        Help for isinf:\n        isinf(Expr)\n        Return true if the argument is an infinity, else return false.\n        See also: 1/ infinity 2/ inf \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1517isinf = {"isinf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1517isinf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1516isinf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1517isinf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isinf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isinf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1516isinf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1516isinf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isinf", 1);

  /* "giacpy/auto-methods.pxi":9477
 * 
 *         '''
 *         return GiacMethods['isinf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ismith(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isinf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9477, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9469
 *         return GiacMethods['is_weighted'](self,*args)
 * 
 *      def isinf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isinf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isinf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9479
 *         return GiacMethods['isinf'](self,*args)
 * 
 *      def ismith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ismith:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1519ismith(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1518ismith, "From Giac's documentation:\n        Help for ismith:\n        ismith(Mtrx(A))\n        Smith normal form of a matrix with coefficients in \342\204\244 : returns U,B,V such that U and V are invertible in \342\204\244, B is diagonal, B[j,j] divides B[j+1,j+1] and B=U*A*V.\n        See also: 1/ ihermite 2/ smith \n        Ex1:ismith([[9,-36,30],[-36,192,-180],[30,-180,180]])\n        Ex2:ismith([[1,2,3],[4,5,6],[7,8,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1519ismith = {"ismith", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1519ismith, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1518ismith};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1519ismith(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ismith (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ismith", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1518ismith(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1518ismith(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismith", 1);

  /* "giacpy/auto-methods.pxi":9489
 * 
 *         '''
 *         return GiacMethods['ismith'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isnan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ismith); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9489, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9479
 *         return GiacMethods['isinf'](self,*args)
 * 
 *      def ismith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ismith:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ismith", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9491
 *         return GiacMethods['ismith'](self,*args)
 * 
 *      def isnan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isnan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1521isnan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1520isnan, "From Giac's documentation:\n        Help for isnan:\n        isnan(Expr)\n        Return true if the argument is undefined, else return false.\n        See also: 1/ undef \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1521isnan = {"isnan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1521isnan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1520isnan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1521isnan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isnan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isnan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1520isnan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1520isnan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isnan", 1);

  /* "giacpy/auto-methods.pxi":9499
 * 
 *         '''
 *         return GiacMethods['isnan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isobarycenter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isnan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9499, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9491
 *         return GiacMethods['ismith'](self,*args)
 * 
 *      def isnan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isnan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isnan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9501
 *         return GiacMethods['isnan'](self,*args)
 * 
 *      def isobarycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isobarycenter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1523isobarycenter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1522isobarycenter, "From Giac's documentation:\n        Help for isobarycenter:\n        isobarycenter((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        isobarycenter(A,B,C,...) draws the isobarycenter of the n points A,B,C,...\n        See also: 1/ barycenter 2/ midpoint \n        Ex1:isobarycenter(-1,1-i,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1523isobarycenter = {"isobarycenter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1523isobarycenter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1522isobarycenter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1523isobarycenter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isobarycenter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isobarycenter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1522isobarycenter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1522isobarycenter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isobarycenter", 1);

  /* "giacpy/auto-methods.pxi":9510
 * 
 *         '''
 *         return GiacMethods['isobarycenter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isobarycenter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9510, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9501
 *         return GiacMethods['isnan'](self,*args)
 * 
 *      def isobarycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isobarycenter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isobarycenter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9512
 *         return GiacMethods['isobarycenter'](self,*args)
 * 
 *      def isolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1525isolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1524isolve, "From Giac's documentation:\n        Help for isolve:\n        isolve(Eqn||List(Eqn),[Intg(n)||(Idnt(Z1),Idnt(Z2),...)])\n        Solve diophantine equation.\n        See also: 1/ solve 2/ rsolve \n        Ex1:isolve(4x-3y=7)\n        Ex2:isolve([x+y-z=4,x-2y+3z=3],m)\n        Ex3:isolve(x^2-23y^2=1,n)\n        Ex4:isolve(x^2-23y^2=1,seq=false)\n        Ex5:isolve(x^2+11y^2-3z^2=0,A,B,C)\n        Ex6:isolve(x^2-3x*y+y^2-x=2,n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1525isolve = {"isolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1525isolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1524isolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1525isolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1524isolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1524isolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isolve", 1);

  /* "giacpy/auto-methods.pxi":9526
 * 
 *         '''
 *         return GiacMethods['isolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isom(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9526, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9512
 *         return GiacMethods['isobarycenter'](self,*args)
 * 
 *      def isolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9528
 *         return GiacMethods['isolve'](self,*args)
 * 
 *      def isom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isom:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1527isom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1526isom, "From Giac's documentation:\n        Help for isom:\n        isom(Mtrx)\n        Finds elements of a 2-d or 3-d isometry.\n        See also: 1/ mkisom \n        Ex1:isom([[0,1],[1,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1527isom = {"isom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1527isom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1526isom};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1527isom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isom (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isom", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1526isom(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1526isom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isom", 1);

  /* "giacpy/auto-methods.pxi":9537
 * 
 *         '''
 *         return GiacMethods['isom'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isomorphic_copy(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isom); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9537, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9528
 *         return GiacMethods['isolve'](self,*args)
 * 
 *      def isom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isom:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9539
 *         return GiacMethods['isom'](self,*args)
 * 
 *      def isomorphic_copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isomorphic_copy:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1529isomorphic_copy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1528isomorphic_copy, "From Giac's documentation:\n        Help for isomorphic_copy:\n        isomorphic_copy(Graph(G),Permu(sigma))\n        Returns a copy of G with the neighborhood structure of each vertex reordered according to sigma.\n        See also: 1/ graph_vertices 2/ permute_vertices 3/ relabel_vertices \n        Ex1:isomorphic_copy(cycle_graph(5),randperm(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1529isomorphic_copy = {"isomorphic_copy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1529isomorphic_copy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1528isomorphic_copy};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1529isomorphic_copy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isomorphic_copy (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isomorphic_copy", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1528isomorphic_copy(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1528isomorphic_copy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isomorphic_copy", 1);

  /* "giacpy/auto-methods.pxi":9548
 * 
 *         '''
 *         return GiacMethods['isomorphic_copy'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isopolygon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isomorphic_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9548, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9539
 *         return GiacMethods['isom'](self,*args)
 * 
 *      def isomorphic_copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isomorphic_copy:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isomorphic_copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9550
 *         return GiacMethods['isomorphic_copy'](self,*args)
 * 
 *      def isopolygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isopolygon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1531isopolygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1530isopolygon, "From Giac's documentation:\n        Help for isopolygon:\n        isopolygon(Pnt,Pnt,[Pnt],Intg(n))\n        Draws a regular polygon having abs(n) vertices, given by 2 vertices (or 2 vertices and 1 point of the plane) if n<0 by its center and 1 vertex (or its center, 1 vertex and 1 point of the plane) if n<0.\n        See also: 1/ polygon 2/ hexagon \n        Ex1:isopolygon(0,1,5)\n        Ex2:isopolygon(0,1,-5)\n        Ex3:isopolygon(point(0,0,0),point(3,3,3),point(0,0,3),5)\n        Ex4:isopolygon(point(0,0,0),point(3,3,3),point(0,0,3),-5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1531isopolygon = {"isopolygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1531isopolygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1530isopolygon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1531isopolygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isopolygon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isopolygon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1530isopolygon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1530isopolygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isopolygon", 1);

  /* "giacpy/auto-methods.pxi":9562
 * 
 *         '''
 *         return GiacMethods['isopolygon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isosceles_triangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isopolygon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9562, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9550
 *         return GiacMethods['isomorphic_copy'](self,*args)
 * 
 *      def isopolygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isopolygon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isopolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9564
 *         return GiacMethods['isopolygon'](self,*args)
 * 
 *      def isosceles_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isosceles_triangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1533isosceles_triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1532isosceles_triangle, "From Giac's documentation:\n        Help for isosceles_triangle:\n        isosceles_triangle((Pnt(A) or Cplx),(Pnt(B) or Cplx),(Angle(t) or Pnt(P) or Lst(P,t)),[Var(C)])\n        Draws the isosceles triangle ABC AB=AC and angle(AB,AC)=t (or in the plane ABP angle(AB,AC)=angle(AB,AP) or angle(AB,AC)=t).\n        See also: 1/ triangle \n        Ex1:isosceles_triangle(i,1,pi/4)\n        Ex2:isosceles_triangle(1,i,pi/4,C)\n        Ex3:isosceles_triangle(point(0,0,0),point(3,3,3),point(0,0,3))\n        Ex4:isosceles_triangle(point(0,0,0),point(3,3,3),[point(0,0,3),pi/4],C)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1533isosceles_triangle = {"isosceles_triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1533isosceles_triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1532isosceles_triangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1533isosceles_triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isosceles_triangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isosceles_triangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1532isosceles_triangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1532isosceles_triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isosceles_triangle", 1);

  /* "giacpy/auto-methods.pxi":9576
 * 
 *         '''
 *         return GiacMethods['isosceles_triangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isposdef(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isosceles_triangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9576, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9564
 *         return GiacMethods['isopolygon'](self,*args)
 * 
 *      def isosceles_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isosceles_triangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isosceles_triangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9578
 *         return GiacMethods['isosceles_triangle'](self,*args)
 * 
 *      def isposdef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isposdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1535isposdef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1534isposdef, "From Giac's documentation:\n        Help for isposdef:\n        isposdef(Mtrx(A))\n        Returns 1 if symmetric matrix A is positive definite and 0 otherwise.\n        See also: 1/ cholesky 2/ ldl \n        Ex1:isposdef([[1,-1,2],[-1,4,3],[2,3,-5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1535isposdef = {"isposdef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1535isposdef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1534isposdef};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1535isposdef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isposdef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isposdef", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1534isposdef(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1534isposdef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isposdef", 1);

  /* "giacpy/auto-methods.pxi":9587
 * 
 *         '''
 *         return GiacMethods['isposdef'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def isprime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isposdef); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9587, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9578
 *         return GiacMethods['isosceles_triangle'](self,*args)
 * 
 *      def isposdef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isposdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isposdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9589
 *         return GiacMethods['isposdef'](self,*args)
 * 
 *      def isprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isprime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1537isprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1536isprime, "From Giac's documentation:\n        Help for isprime:\n        isprime(Intg(a))\n        Primality testing (=true or false).\n        See also: 1/ prevprime 2/ nextprime 3/ is_prime 4/ is_pseudoprime \n        Ex1:isprime(1999)\n        Ex2:isprime(9856989898997)\n        Ex3:isprime(9856989898997789789)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1537isprime = {"isprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1537isprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1536isprime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1537isprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isprime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "isprime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1536isprime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1536isprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isprime", 1);

  /* "giacpy/auto-methods.pxi":9600
 * 
 *         '''
 *         return GiacMethods['isprime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def istft(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_isprime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9600, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9589
 *         return GiacMethods['isposdef'](self,*args)
 * 
 *      def isprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isprime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.isprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9602
 *         return GiacMethods['isprime'](self,*args)
 * 
 *      def istft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for istft:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1539istft(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1538istft, "From Giac's documentation:\n        Help for istft:\n        istft(Mtrx(data))\n        Inverse short-time Fourier transform.\n        See also: 1/ stft 2/ ifft \n        Ex1: data:=ranv(2^15,normald(0,0.1)):;t:=stft(data):;d:=istft(t):;correlation(data,d)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1539istft = {"istft", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1539istft, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1538istft};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1539istft(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("istft (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "istft", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1538istft(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1538istft(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("istft", 1);

  /* "giacpy/auto-methods.pxi":9611
 * 
 *         '''
 *         return GiacMethods['istft'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ithprime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_istft); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9611, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9602
 *         return GiacMethods['isprime'](self,*args)
 * 
 *      def istft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for istft:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.istft", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9613
 *         return GiacMethods['istft'](self,*args)
 * 
 *      def ithprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ithprime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1541ithprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1540ithprime, "From Giac's documentation:\n        Help for ithprime:\n        ithprime(Intg(n))\n        Returns the n-th prime number less than 2*10^8.\n        See also: 1/ nextprime 2/ prevprime \n        Ex1:ithprime(1229)\n        Ex2:ithprime(1000)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1541ithprime = {"ithprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1541ithprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1540ithprime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1541ithprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ithprime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ithprime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1540ithprime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1540ithprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ithprime", 1);

  /* "giacpy/auto-methods.pxi":9623
 * 
 *         '''
 *         return GiacMethods['ithprime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def jacobi_equation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ithprime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9623, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9613
 *         return GiacMethods['istft'](self,*args)
 * 
 *      def ithprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ithprime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ithprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9625
 *         return GiacMethods['ithprime'](self,*args)
 * 
 *      def jacobi_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_equation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1543jacobi_equation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1542jacobi_equation, "From Giac's documentation:\n        Help for jacobi_equation:\n        jacobi_equation(Expr(f),Var(x),Var(y),Expr(y0),Var(h),Real(a))\n        Returns the Jacobi equation for stationary function y0(x) in a problem of minimizing the functional int(f(x,y,y'),x=a..b).\n        See also: 1/ conjugate_equation 2/ euler_lagrange \n        Ex1:jacobi_equation(-1/2*y'(t)^2+y(t)^2/2,t,y,sin(t),h,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1543jacobi_equation = {"jacobi_equation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1543jacobi_equation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1542jacobi_equation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1543jacobi_equation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jacobi_equation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "jacobi_equation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1542jacobi_equation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1542jacobi_equation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("jacobi_equation", 1);

  /* "giacpy/auto-methods.pxi":9634
 * 
 *         '''
 *         return GiacMethods['jacobi_equation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def jacobi_linsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_jacobi_equation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9634, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9625
 *         return GiacMethods['ithprime'](self,*args)
 * 
 *      def jacobi_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_equation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.jacobi_equation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9636
 *         return GiacMethods['jacobi_equation'](self,*args)
 * 
 *      def jacobi_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_linsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1545jacobi_linsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1544jacobi_linsolve, "From Giac's documentation:\n        Help for jacobi_linsolve:\n        jacobi_linsolve(Mtrx(A),Vect(b),Real(eps),[Int(maxiter)])\n        Resolution of a linear system A*X=b by the iterative Jacobi method with eps as error margin and a number of iterations less than maxiter.\n        See also: 1/ gauss_seidel_linsolve 2/ linsolve \n        Ex1: a:=[[100,2],[2,100]];jacobi_linsolve(a,[0,1],1e-12);\n        Ex2: a:=[[100,2],[2,100]];jacobi_linsolve(table(a),[0,1],1e-12); \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1545jacobi_linsolve = {"jacobi_linsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1545jacobi_linsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1544jacobi_linsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1545jacobi_linsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jacobi_linsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "jacobi_linsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1544jacobi_linsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1544jacobi_linsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("jacobi_linsolve", 1);

  /* "giacpy/auto-methods.pxi":9646
 * 
 *         '''
 *         return GiacMethods['jacobi_linsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def jacobi_symbol(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_jacobi_linsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9646, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9636
 *         return GiacMethods['jacobi_equation'](self,*args)
 * 
 *      def jacobi_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_linsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.jacobi_linsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9648
 *         return GiacMethods['jacobi_linsolve'](self,*args)
 * 
 *      def jacobi_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_symbol:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1547jacobi_symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1546jacobi_symbol, "From Giac's documentation:\n        Help for jacobi_symbol:\n        jacobi_symbol(Intg,Intg)\n        Jacobi symbol.\n        See also: 1/ legendre_symbol \n        Ex1:jacobi_symbol(132,5)\n        Ex2:jacobi_symbol(132,25)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1547jacobi_symbol = {"jacobi_symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1547jacobi_symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1546jacobi_symbol};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1547jacobi_symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jacobi_symbol (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "jacobi_symbol", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1546jacobi_symbol(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1546jacobi_symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("jacobi_symbol", 1);

  /* "giacpy/auto-methods.pxi":9658
 * 
 *         '''
 *         return GiacMethods['jacobi_symbol'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def johnson_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_jacobi_symbol); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9658, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9648
 *         return GiacMethods['jacobi_linsolve'](self,*args)
 * 
 *      def jacobi_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_symbol:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.jacobi_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9660
 *         return GiacMethods['jacobi_symbol'](self,*args)
 * 
 *      def johnson_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for johnson_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1549johnson_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1548johnson_graph, "From Giac's documentation:\n        Help for johnson_graph:\n        johnson_graph(Intg(n),Intg(k))\n        Returns the Johnson graph J(n,k) with comb(n,k) vertices (n<=20).\n        See also: 1/ kneser_graph \n        Ex1:johnson_graph(5,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1549johnson_graph = {"johnson_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1549johnson_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1548johnson_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1549johnson_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("johnson_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "johnson_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1548johnson_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1548johnson_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("johnson_graph", 1);

  /* "giacpy/auto-methods.pxi":9669
 * 
 *         '''
 *         return GiacMethods['johnson_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def join(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_johnson_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9669, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9660
 *         return GiacMethods['jacobi_symbol'](self,*args)
 * 
 *      def johnson_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for johnson_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.johnson_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9671
 *         return GiacMethods['johnson_graph'](self,*args)
 * 
 *      def join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for join:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1551join(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1550join, "From Giac's documentation:\n        Help for join:\n        join(Str(sep),Lst(strlst))\n        Returns the string obtained by concatenating strings from a list after inserting a separator string between adjacent elements.\n        See also: 1/ split 2/ concat \n        Ex1:join(\" \",[\"This\",\"is\",\"a\",\"phrase\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1551join = {"join", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1551join, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1550join};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1551join(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("join (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "join", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1550join(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1550join(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("join", 1);

  /* "giacpy/auto-methods.pxi":9680
 * 
 *         '''
 *         return GiacMethods['join'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def jordan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_join); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9680, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9671
 *         return GiacMethods['johnson_graph'](self,*args)
 * 
 *      def join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for join:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.join", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9682
 *         return GiacMethods['join'](self,*args)
 * 
 *      def jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jordan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1553jordan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1552jordan, "From Giac's documentation:\n        Help for jordan:\n        jordan(Mtrx)\n        Returns the list made by the transition matrix and the Jordan form of a matrix.\n        See also: 1/ egv 2/ egvl 3/ rat_jordan \n        Ex1:jordan([[0,2],[1,0]])\n        Ex2:jordan([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex3:jordan([[1,1,-1,2,-1],[2,0,1,-4,-1],[0,1,1,1,1],[0,1,2,0,1],[0,0,-3,3,-1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1553jordan = {"jordan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1553jordan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1552jordan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1553jordan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("jordan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "jordan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1552jordan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1552jordan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("jordan", 1);

  /* "giacpy/auto-methods.pxi":9693
 * 
 *         '''
 *         return GiacMethods['jordan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def katz_centrality(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_jordan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9693, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9682
 *         return GiacMethods['join'](self,*args)
 * 
 *      def jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jordan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.jordan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9695
 *         return GiacMethods['jordan'](self,*args)
 * 
 *      def katz_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for katz_centrality:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1555katz_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1554katz_centrality, "From Giac's documentation:\n        Help for katz_centrality:\n        katz_centrality(Graph(G),Real(alpha),[Vrtx(v)])\n        Returns the Katz centrality of a vertex v in a graph G or the list of Katz centralities of vertices in G, where alpha is the attenuation factor.\n        See also: 1/ degree_centrality 2/ betweenness_centrality 3/ closeness_centrality 4/ harmonic_centrality 5/ information_centrality \n        Ex1:katz_centrality(graph(6,%{[0,2],[0,5],[1,3],[1,5],[2,5],[3,4],[3,5],[4,5]%}),0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1555katz_centrality = {"katz_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1555katz_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1554katz_centrality};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1555katz_centrality(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("katz_centrality (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "katz_centrality", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1554katz_centrality(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1554katz_centrality(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("katz_centrality", 1);

  /* "giacpy/auto-methods.pxi":9704
 * 
 *         '''
 *         return GiacMethods['katz_centrality'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kde(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_katz_centrality); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9704, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9695
 *         return GiacMethods['jordan'](self,*args)
 * 
 *      def katz_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for katz_centrality:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.katz_centrality", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9706
 *         return GiacMethods['katz_centrality'](self,*args)
 * 
 *      def kde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kde:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1557kde(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1556kde, "From Giac's documentation:\n        Help for kde:\n        kde(Lst(L),[options])\n        Estimates the probability density function from which the (presumably independent) samples in list L are drawn.\n        See also: 1/ random_variable 2/ sample \n        Ex1:kde([1,2,3,2],bandwidth=1/4,exact)\n        Ex2: X:=randvar(gammad,mean=5,stddev=2):;kernel_density(sample(X,500),bins=50)\n        Ex3: Y:=randvar(normal,mean=5,stddev=1.5):;plot(kernel_density(sample(Y,1000),bins=50,piecewise),x=0..10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1557kde = {"kde", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1557kde, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1556kde};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1557kde(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kde (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kde", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1556kde(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1556kde(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kde", 1);

  /* "giacpy/auto-methods.pxi":9717
 * 
 *         '''
 *         return GiacMethods['kde'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def keep_pivot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kde); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9717, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9706
 *         return GiacMethods['katz_centrality'](self,*args)
 * 
 *      def kde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kde:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kde", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9719
 *         return GiacMethods['kde'](self,*args)
 * 
 *      def keep_pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for keep_pivot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1559keep_pivot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1558keep_pivot, "From Giac's documentation:\n        Help for keep_pivot:\n        keep_pivot(Opt)\n        Option of the rref command.\n        See also: 1/ rref \n        Ex1: rref([[1,1,0,0,-a1],[0,1,1,0,-a2],[0,0,1,1,-a3],[1,0,0,1,-a4]],keep_pivot)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1559keep_pivot = {"keep_pivot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1559keep_pivot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1558keep_pivot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1559keep_pivot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("keep_pivot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "keep_pivot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1558keep_pivot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1558keep_pivot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("keep_pivot", 1);

  /* "giacpy/auto-methods.pxi":9728
 * 
 *         '''
 *         return GiacMethods['keep_pivot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ker(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_keep_pivot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9728, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9719
 *         return GiacMethods['kde'](self,*args)
 * 
 *      def keep_pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for keep_pivot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.keep_pivot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9730
 *         return GiacMethods['keep_pivot'](self,*args)
 * 
 *      def ker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ker:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1561ker(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1560ker, "From Giac's documentation:\n        Help for ker:\n        ker(Mtrx)\n        Kernel of a linear map with matrix M.\n        See also: 1/ image 2/ rref 3/ Nullspace \n        Ex1:ker([[1,2],[3,6]])\n        Ex2:ker([[1,2,3],[1,3,6],[2,5,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1561ker = {"ker", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1561ker, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1560ker};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1561ker(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ker (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ker", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1560ker(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1560ker(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ker", 1);

  /* "giacpy/auto-methods.pxi":9740
 * 
 *         '''
 *         return GiacMethods['ker'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kernel(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ker); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9740, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9730
 *         return GiacMethods['keep_pivot'](self,*args)
 * 
 *      def ker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ker:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ker", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9742
 *         return GiacMethods['ker'](self,*args)
 * 
 *      def kernel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1563kernel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1562kernel, "From Giac's documentation:\n        Help for kernel:\n        kernel(Mtrx)\n        Kernel of a linear map with matrix M.\n        See also: 1/ image 2/ rref 3/ Nullspace \n        Ex1:kernel([[1,2],[3,6]])\n        Ex2:kernel([[1,2,3],[1,3,6],[2,5,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1563kernel = {"kernel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1563kernel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1562kernel};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1563kernel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kernel (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kernel", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1562kernel(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1562kernel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kernel", 1);

  /* "giacpy/auto-methods.pxi":9752
 * 
 *         '''
 *         return GiacMethods['kernel'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kernel_density(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kernel); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9752, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9742
 *         return GiacMethods['ker'](self,*args)
 * 
 *      def kernel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kernel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9754
 *         return GiacMethods['kernel'](self,*args)
 * 
 *      def kernel_density(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel_density:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1565kernel_density(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1564kernel_density, "From Giac's documentation:\n        Help for kernel_density:\n        kernel_density(Lst(L),[options])\n        Estimates the probability density function from which the (presumably independent) samples in list L are drawn.\n        See also: 1/ random_variable 2/ sample \n        Ex1:kernel_density([1,2,3,2],bandwidth=1/4,exact)\n        Ex2: X:=randvar(gammad,mean=5,stddev=2):;kernel_density(sample(X,500),bins=50)\n        Ex3: Y:=randvar(normal,mean=5,stddev=1.5):;plot(kernel_density(sample(Y,1000),bins=50,piecewise),x=0..10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1565kernel_density = {"kernel_density", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1565kernel_density, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1564kernel_density};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1565kernel_density(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kernel_density (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kernel_density", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1564kernel_density(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1564kernel_density(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kernel_density", 1);

  /* "giacpy/auto-methods.pxi":9765
 * 
 *         '''
 *         return GiacMethods['kernel_density'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kmeans(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kernel_density); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9765, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9754
 *         return GiacMethods['kernel'](self,*args)
 * 
 *      def kernel_density(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel_density:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kernel_density", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9767
 *         return GiacMethods['kernel_density'](self,*args)
 * 
 *      def kmeans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kmeans:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1567kmeans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1566kmeans, "From Giac's documentation:\n        Help for kmeans:\n        kmeans(Mtrx||Lst(data),[opts])\n        Cluster the given Euclidean data by using k-means algorithm.\n        See also: 1/ cluster \n        Ex1:kmeans([[1.1,1.5],[3.2,2.5],[1.5,0.9],[3.5,2.7],[0.8,1.1],[3.1,2.2]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1567kmeans = {"kmeans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1567kmeans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1566kmeans};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1567kmeans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kmeans (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kmeans", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1566kmeans(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1566kmeans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kmeans", 1);

  /* "giacpy/auto-methods.pxi":9776
 * 
 *         '''
 *         return GiacMethods['kmeans'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kneser_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kmeans); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9776, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9767
 *         return GiacMethods['kernel_density'](self,*args)
 * 
 *      def kmeans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kmeans:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kmeans", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9778
 *         return GiacMethods['kmeans'](self,*args)
 * 
 *      def kneser_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kneser_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1569kneser_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1568kneser_graph, "From Giac's documentation:\n        Help for kneser_graph:\n        kneser_graph(Intg(n),Intg(k))\n        Returns the Kneser graph K(n,k) with comb(n,k) vertices (n<=20).\n        See also: 1/ odd_graph 2/ johnson_graph \n        Ex1:kneser_graph(5,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1569kneser_graph = {"kneser_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1569kneser_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1568kneser_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1569kneser_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kneser_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kneser_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1568kneser_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1568kneser_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kneser_graph", 1);

  /* "giacpy/auto-methods.pxi":9787
 * 
 *         '''
 *         return GiacMethods['kneser_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kolmogorovd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kneser_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9787, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9778
 *         return GiacMethods['kmeans'](self,*args)
 * 
 *      def kneser_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kneser_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kneser_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9789
 *         return GiacMethods['kneser_graph'](self,*args)
 * 
 *      def kolmogorovd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1571kolmogorovd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1570kolmogorovd, "From Giac's documentation:\n        Help for kolmogorovd:\n        kolmogorovd(Real(x))\n        Kolmogorov-Smirnov distribution, 1-2*sum((-1)^(k-1)*exp(-k^2*x^2),k,1,inf).\n        Ex1:kolmogorovd(1.36)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1571kolmogorovd = {"kolmogorovd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1571kolmogorovd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1570kolmogorovd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1571kolmogorovd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kolmogorovd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kolmogorovd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1570kolmogorovd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1570kolmogorovd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kolmogorovd", 1);

  /* "giacpy/auto-methods.pxi":9797
 * 
 *         '''
 *         return GiacMethods['kolmogorovd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kolmogorovt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kolmogorovd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9797, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9789
 *         return GiacMethods['kneser_graph'](self,*args)
 * 
 *      def kolmogorovd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kolmogorovd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9799
 *         return GiacMethods['kolmogorovd'](self,*args)
 * 
 *      def kolmogorovt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1573kolmogorovt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1572kolmogorovt, "From Giac's documentation:\n        Help for kolmogorovt:\n        kolmogorovt(Lst(l1),Lst(l2) || DistribLaw(s))\n        Kolmogorov-Smirnov fitness test to a continuous distribution law, between 2 samples l1 l2 (unknown law) or between a sample l1 and a distribution law s.\n        See also: 1/ chisquaret 2/ normalt 3/ studentt \n        Ex1:kolmogorovt(randvector(100,normald,0,1),randvector(100,normald,0,1))\n        Ex2:kolmogorovt(randvector(100,normald,0,1),randvector(100,normald,3,1))\n        Ex3:kolmogorovt(randvector(100,normald,0,1),normald(0,1))\n        Ex4:kolmogorovt(randvector(100,normald,0,1),student(2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1573kolmogorovt = {"kolmogorovt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1573kolmogorovt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1572kolmogorovt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1573kolmogorovt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kolmogorovt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kolmogorovt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1572kolmogorovt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1572kolmogorovt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kolmogorovt", 1);

  /* "giacpy/auto-methods.pxi":9811
 * 
 *         '''
 *         return GiacMethods['kolmogorovt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kovacicsols(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kolmogorovt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9811, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9799
 *         return GiacMethods['kolmogorovd'](self,*args)
 * 
 *      def kolmogorovt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kolmogorovt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9813
 *         return GiacMethods['kolmogorovt'](self,*args)
 * 
 *      def kovacicsols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kovacicsols:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1575kovacicsols(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1574kovacicsols, "From Giac's documentation:\n        Help for kovacicsols:\n        kovacicsols(Expr||Lst(eq),[Var(x),[Var(y)]])\n        Solves a linear homogeneous second-order ODE eq for y(x) with rational coefficients in variable x.\n        See also: 1/ desolve \n        Ex1:kovacicsols(y''=y*(1/x-3/16/x^2))\n        Ex2:kovacicsols(y''-y*27/(36*(x-1)^2),x,y)\n        Ex3:kovacicsols(x''+3*(t^2-t+1)/(16*(t-1)^2*t^2)*x,t,x)\n        Ex4:kovacicsols(y''+y'=6y/x^2)\n        Ex5:kovacicsols(y''+(19-x^2)*y=0,x,y)\n        Ex6:kovacicsols((1+x^2)^2*y''+3y=0,x,y)\n        Ex7:kovacicsols([48t*(t+1)*(5t-4),8*(25t+16)*(t-2),-(5t+68)],t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1575kovacicsols = {"kovacicsols", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1575kovacicsols, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1574kovacicsols};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1575kovacicsols(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kovacicsols (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kovacicsols", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1574kovacicsols(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1574kovacicsols(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kovacicsols", 1);

  /* "giacpy/auto-methods.pxi":9828
 * 
 *         '''
 *         return GiacMethods['kovacicsols'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def kspaths(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kovacicsols); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9828, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9813
 *         return GiacMethods['kolmogorovt'](self,*args)
 * 
 *      def kovacicsols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kovacicsols:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kovacicsols", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9830
 *         return GiacMethods['kovacicsols'](self,*args)
 * 
 *      def kspaths(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kspaths:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1577kspaths(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1576kspaths, "From Giac's documentation:\n        Help for kspaths:\n        kspaths(Graph(G),Vrtx(s),Vrtx(t),Intg(k))\n        Returns a list of k shortest paths from s to t in the (weighted) (di)graph G.\n        See also: 1/ dijkstra 2/ shortest_path \n        Ex1:kspaths(digraph(%{[[\"C\",\"D\"],3],[[\"C\",\"E\"],2],[[\"D\",\"F\"],4],[[\"E\",\"D\"],1],[[\"E\",\"F\"],2],[[\"E\",\"G\"],3],[[\"F\",\"G\"],2],[[\"F\",\"H\"],1],[[\"G\",\"H\"],2]%}),\"C\",\"H\",5)\n        Ex2:kspaths(graph(\"soccerball\"),3,33,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1577kspaths = {"kspaths", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1577kspaths, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1576kspaths};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1577kspaths(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kspaths (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "kspaths", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1576kspaths(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1576kspaths(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("kspaths", 1);

  /* "giacpy/auto-methods.pxi":9840
 * 
 *         '''
 *         return GiacMethods['kspaths'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def l1norm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_kspaths); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9840, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9830
 *         return GiacMethods['kovacicsols'](self,*args)
 * 
 *      def kspaths(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kspaths:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.kspaths", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9842
 *         return GiacMethods['kspaths'](self,*args)
 * 
 *      def l1norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l1norm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1579l1norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1578l1norm, "From Giac's documentation:\n        Help for l1norm:\n        l1norm(Vect)\n        Returns the l1 norm of the vector=sum of the absolute values of its coordinates or matrix norm according to l1.\n        See also: 1/ l2norm 2/ maxnorm 3/ matrix_norm \n        Ex1:l1norm(ou triple norme d'une matrice selon l1.)\n        Ex2:l1norm([3,-4,2])\n        Ex3:l1norm([[1,2,3],[3,-9,6],[4,5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1579l1norm = {"l1norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1579l1norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1578l1norm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1579l1norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("l1norm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "l1norm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1578l1norm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1578l1norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("l1norm", 1);

  /* "giacpy/auto-methods.pxi":9853
 * 
 *         '''
 *         return GiacMethods['l1norm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def l2norm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_l1norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9853, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9842
 *         return GiacMethods['kspaths'](self,*args)
 * 
 *      def l1norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l1norm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.l1norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9855
 *         return GiacMethods['l1norm'](self,*args)
 * 
 *      def l2norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l2norm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1581l2norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1580l2norm, "From Giac's documentation:\n        Help for l2norm:\n        l2norm(Vect or Mtrx)\n        Returns the l2 norm of a vector = sqrt(x1^2+x2^2+...xn^2) or matrix norm induced by l2 norm.\n        See also: 1/ maxnorm 2/ l1norm \n        Ex1:l2norm([1,2])\n        Ex2:l2norm([1,2,3,-4])\n        Ex3:l2norm([[1,2],[3,-4]])\n        Ex4:l2norm([[1,2,3],[3,-9,6],[4,5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1581l2norm = {"l2norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1581l2norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1580l2norm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1581l2norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("l2norm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "l2norm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1580l2norm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1580l2norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("l2norm", 1);

  /* "giacpy/auto-methods.pxi":9867
 * 
 *         '''
 *         return GiacMethods['l2norm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lagrange(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_l2norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9867, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9855
 *         return GiacMethods['l1norm'](self,*args)
 * 
 *      def l2norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l2norm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.l2norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9869
 *         return GiacMethods['l2norm'](self,*args)
 * 
 *      def lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lagrange:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1583lagrange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1582lagrange, "From Giac's documentation:\n        Help for lagrange:\n        lagrange((Lst_xk,Lst_yk)||Mtrx_2*n||(Lst_xk,Fnc(f)),[Var||[]||lagrange])\n        Returns the polynomial of degree n-1 such that P(xk)=yk=f(x_k) k=0..n-1 or the list of divided differences if the last argument is lagrange.\n        See also: 1/ spline 2/ interp \n        Ex1:lagrange([1,3,4],[0,1,2])\n        Ex2:lagrange([1,3,4],[0,1,2],t)\n        Ex3: f(x):=exp(-x); lagrange([1,3,4],f)\n        Ex4:lagrange([[1,3,4],[0,1,2]])\n        Ex5:lagrange([1,3,4],[0,1,2],[])\n        Ex6: X:=[1,3,4]; divdiff:=lagrange(X,[0,1,2],lagrange); horner(divdiff,X,5);\n        Ex7:lagrange([[1,3,4],[0,1,2]],y)\n        Ex8:lagrange([-1,0,1],[1/e-1,0,e-1])\n        Ex9: f(x):=exp(x)-1;lagrange([-1,0,1],f)\n        Ex10:lagrange([0,1,2],[1,exp(1),exp(2)],lagrange)\n        Ex11:lagrange([0,1,2],exp,lagrange)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1583lagrange = {"lagrange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1583lagrange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1582lagrange};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1583lagrange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lagrange (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lagrange", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1582lagrange(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1582lagrange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lagrange", 1);

  /* "giacpy/auto-methods.pxi":9888
 * 
 *         '''
 *         return GiacMethods['lagrange'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def laguerre(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lagrange); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9888, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9869
 *         return GiacMethods['l2norm'](self,*args)
 * 
 *      def lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lagrange:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lagrange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9890
 *         return GiacMethods['lagrange'](self,*args)
 * 
 *      def laguerre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laguerre:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1585laguerre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1584laguerre, "From Giac's documentation:\n        Help for laguerre:\n        laguerre(Intg(n))\n        Returns the n-th Laguerre polynomial.\n        See also: 1/ legendre 2/ hermite \n        Ex1:laguerre(4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1585laguerre = {"laguerre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1585laguerre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1584laguerre};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1585laguerre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("laguerre (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "laguerre", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1584laguerre(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1584laguerre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("laguerre", 1);

  /* "giacpy/auto-methods.pxi":9899
 * 
 *         '''
 *         return GiacMethods['laguerre'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def laplace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_laguerre); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9899, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9890
 *         return GiacMethods['lagrange'](self,*args)
 * 
 *      def laguerre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laguerre:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.laguerre", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9901
 *         return GiacMethods['laguerre'](self,*args)
 * 
 *      def laplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1587laplace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1586laplace, "From Giac's documentation:\n        Help for laplace:\n        laplace(Expr,[Var],[LapVar])\n        Laplace transform.\n        See also: 1/ invlaplace 2/ ztrans 3/ invztrans 4/ Heaviside \n        Ex1:laplace(exp(x)*sin(x))\n        Ex2:laplace(sin(x)^2,x,s)\n        Ex3:laplace(Heaviside(x-1),x,s)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1587laplace = {"laplace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1587laplace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1586laplace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1587laplace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("laplace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "laplace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1586laplace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1586laplace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("laplace", 1);

  /* "giacpy/auto-methods.pxi":9912
 * 
 *         '''
 *         return GiacMethods['laplace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def laplacian(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_laplace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9912, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9901
 *         return GiacMethods['laguerre'](self,*args)
 * 
 *      def laplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.laplace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9914
 *         return GiacMethods['laplace'](self,*args)
 * 
 *      def laplacian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1589laplacian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1588laplacian, "From Giac's documentation:\n        Help for laplacian:\n        laplacian(Expr(Xpr),LstVar)\n        Returns the Laplacian of the expression Xpr with respect to the list of variables and laplacian(n) for integer n returns the matrix of size n of the discrete laplacian in dimension 1.\n        See also: 1/  \n        Ex1:laplacian(-2)\n        Ex2:laplacian(exp(z)*cos(x*y),[x,y,z])\n        Ex3:laplacian(3)\n        Ex4:laplacian(3.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1589laplacian = {"laplacian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1589laplacian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1588laplacian};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1589laplacian(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("laplacian (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "laplacian", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1588laplacian(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1588laplacian(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("laplacian", 1);

  /* "giacpy/auto-methods.pxi":9926
 * 
 *         '''
 *         return GiacMethods['laplacian'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def laplacian_matrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_laplacian); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9926, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9914
 *         return GiacMethods['laplace'](self,*args)
 * 
 *      def laplacian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.laplacian", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9928
 *         return GiacMethods['laplacian'](self,*args)
 * 
 *      def laplacian_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian_matrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1591laplacian_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1590laplacian_matrix, "From Giac's documentation:\n        Help for laplacian_matrix:\n        laplacian_matrix(Graph(G),[normal])\n        Returns the Laplacian matrix L=D-A of an undirected graph G where D resp. A is the degree matrix resp. the adjacency matrix of G.\n        See also: 1/ adjacency_matrix 2/ degree_sequence 3/ number_of_spanning_trees \n        Ex1:laplacian_matrix(graph(trail(1,2,3,4,5,2)))\n        Ex2:laplacian_matrix(graph(trail(1,2,3,4,5,2)),normal)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1591laplacian_matrix = {"laplacian_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1591laplacian_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1590laplacian_matrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1591laplacian_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("laplacian_matrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "laplacian_matrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1590laplacian_matrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1590laplacian_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("laplacian_matrix", 1);

  /* "giacpy/auto-methods.pxi":9938
 * 
 *         '''
 *         return GiacMethods['laplacian_matrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def latex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_laplacian_matrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9938, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9928
 *         return GiacMethods['laplacian'](self,*args)
 * 
 *      def laplacian_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian_matrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.laplacian_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9940
 *         return GiacMethods['laplacian_matrix'](self,*args)
 * 
 *      def latex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for latex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1593latex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1592latex, "From Giac's documentation:\n        Help for latex:\n        latex(Expr)\n        Returns the evaluated expression written in latex.\n        See also: 1/ mathml \n        Ex1:latex(1/2)\n        Ex2:latex((x^4-1)/(x^2+3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1593latex = {"latex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1593latex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1592latex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1593latex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("latex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "latex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1592latex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1592latex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("latex", 1);

  /* "giacpy/auto-methods.pxi":9950
 * 
 *         '''
 *         return GiacMethods['latex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lcf_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_latex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9950, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9940
 *         return GiacMethods['laplacian_matrix'](self,*args)
 * 
 *      def latex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for latex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.latex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9952
 *         return GiacMethods['latex'](self,*args)
 * 
 *      def lcf_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcf_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1595lcf_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1594lcf_graph, "From Giac's documentation:\n        Help for lcf_graph:\n        lcf_graph(Lst(J),[Intg(k)])\n        Returns a graph constructed from the LCF notation J[^k] given the list of integers J [and a positive integer k, by default 1].\n        See also: 1/ graph \n        Ex1:lcf_graph([-3,3],4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1595lcf_graph = {"lcf_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1595lcf_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1594lcf_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1595lcf_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lcf_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lcf_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1594lcf_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1594lcf_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lcf_graph", 1);

  /* "giacpy/auto-methods.pxi":9961
 * 
 *         '''
 *         return GiacMethods['lcf_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lcm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lcf_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9961, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9952
 *         return GiacMethods['latex'](self,*args)
 * 
 *      def lcf_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcf_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lcf_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9963
 *         return GiacMethods['lcf_graph'](self,*args)
 * 
 *      def lcm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1597lcm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1596lcm, "From Giac's documentation:\n        Help for lcm:\n        lcm((Intg or Poly),(Intg or Poly))\n        Returns the lowest common multiple of 2 polynomials of several variables or of 2 integers or of 2 rationals.\n        See also: 1/ gcd \n        Ex1:lcm(6,4)\n        Ex2:lcm(1251,123)\n        Ex3:lcm(5/7,50/9)\n        Ex4:lcm(x^2-2*x+1,x^3-1)\n        Ex5:lcm(t^2-2*t+1,t^2+t-2)\n        Ex6:lcm((x^2-1)*(y^2-1)*z^2,x^3*y^3*z+(-(y^3))*z+x^3*z-z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1597lcm = {"lcm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1597lcm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1596lcm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1597lcm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lcm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lcm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1596lcm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1596lcm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lcm", 1);

  /* "giacpy/auto-methods.pxi":9977
 * 
 *         '''
 *         return GiacMethods['lcm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lcoeff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lcm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9977, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9963
 *         return GiacMethods['lcf_graph'](self,*args)
 * 
 *      def lcm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lcm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9979
 *         return GiacMethods['lcm'](self,*args)
 * 
 *      def lcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcoeff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1599lcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1598lcoeff, "From Giac's documentation:\n        Help for lcoeff:\n        lcoeff(Poly||Lst)\n        Returns the coefficient of the term of highest degree of a polynomial (l=leading).\n        See also: 1/ tcoeff \n        Ex1:lcoeff(-2*x^3+x^2+7*x)\n        Ex2:lcoeff([-2,1,7,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1599lcoeff = {"lcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1599lcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1598lcoeff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1599lcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lcoeff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lcoeff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1598lcoeff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1598lcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lcoeff", 1);

  /* "giacpy/auto-methods.pxi":9989
 * 
 *         '''
 *         return GiacMethods['lcoeff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ldegree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lcoeff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 9989, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 9989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 9989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9979
 *         return GiacMethods['lcm'](self,*args)
 * 
 *      def lcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcoeff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lcoeff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":9991
 *         return GiacMethods['lcoeff'](self,*args)
 * 
 *      def ldegree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldegree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1601ldegree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1600ldegree, "From Giac's documentation:\n        Help for ldegree:\n        ldegree(Poly(P))\n        Returns the valuation (degree of the term of lowest degree) of the polynomial P.\n        See also: 1/ degree 2/ tcoeff \n        Ex1:ldegree(x^4+x^3)\n        Ex2:ldegree([1,1,0,0,0])\n        Ex3:ldegree(130,5)\n        Ex4:ldegree(x^5+3*x^2)\n        Ex5:ldegree([5,0,0,3,0,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1601ldegree = {"ldegree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1601ldegree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1600ldegree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1601ldegree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ldegree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ldegree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1600ldegree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1600ldegree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ldegree", 1);

  /* "giacpy/auto-methods.pxi":10004
 * 
 *         '''
 *         return GiacMethods['ldegree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ldl(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ldegree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10004, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":9991
 *         return GiacMethods['lcoeff'](self,*args)
 * 
 *      def ldegree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldegree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ldegree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10006
 *         return GiacMethods['ldegree'](self,*args)
 * 
 *      def ldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldl:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1603ldl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1602ldl, "From Giac's documentation:\n        Help for ldl:\n        ldl(Mtrx(A),[opts])\n        Returns the sequence p,L,D such that P*A*tran(P) = L*D*tran(L), where A is symmetric\n        See also: 1/ lu 2/ inertia \n        Ex1:ldl(or Hermitian matrix.)\n        Ex2:ldl([[1,-1,2],[-1,4,3],[2,3,-5]])\n        Ex3:ldl([[1,-i,2],[i,4,3],[2,3,-5]],hermite)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1603ldl = {"ldl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1603ldl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1602ldl};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1603ldl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ldl (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ldl", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1602ldl(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1602ldl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ldl", 1);

  /* "giacpy/auto-methods.pxi":10017
 * 
 *         '''
 *         return GiacMethods['ldl'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def learning_rate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ldl); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10017, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10006
 *         return GiacMethods['ldegree'](self,*args)
 * 
 *      def ldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldl:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ldl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10019
 *         return GiacMethods['ldl'](self,*args)
 * 
 *      def learning_rate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for learning_rate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1605learning_rate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1604learning_rate, "From Giac's documentation:\n        Help for learning_rate:\n        learning_rate(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1605learning_rate = {"learning_rate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1605learning_rate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1604learning_rate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1605learning_rate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("learning_rate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "learning_rate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1604learning_rate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1604learning_rate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("learning_rate", 1);

  /* "giacpy/auto-methods.pxi":10027
 * 
 *         '''
 *         return GiacMethods['learning_rate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def left(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_learning_rate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10027, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10019
 *         return GiacMethods['ldl'](self,*args)
 * 
 *      def learning_rate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for learning_rate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.learning_rate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10029
 *         return GiacMethods['learning_rate'](self,*args)
 * 
 *      def left(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1607left(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1606left, "From Giac's documentation:\n        Help for left:\n        left(Equal(a=b) or Interval(a..b) or Str,Intg)\n        Returns the left part of an equality, of an interval, of a list or of a string.\n        See also: 1/ right 2/ mid 3/ tail 4/ head \n        Ex1:left(a=b)\n        Ex2:left(x^2+1=5)\n        Ex3:left(1..5)\n        Ex4:left(\"abcdefg\",3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1607left = {"left", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1607left, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1606left};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1607left(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("left (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "left", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1606left(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1606left(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("left", 1);

  /* "giacpy/auto-methods.pxi":10041
 * 
 *         '''
 *         return GiacMethods['left'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def left_rectangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_left); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10041, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10029
 *         return GiacMethods['learning_rate'](self,*args)
 * 
 *      def left(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.left", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10043
 *         return GiacMethods['left'](self,*args)
 * 
 *      def left_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left_rectangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1609left_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1608left_rectangle, "From Giac's documentation:\n        Help for left_rectangle:\n        left_rectangle(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1609left_rectangle = {"left_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1609left_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1608left_rectangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1609left_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("left_rectangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "left_rectangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1608left_rectangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1608left_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("left_rectangle", 1);

  /* "giacpy/auto-methods.pxi":10057
 * 
 *         '''
 *         return GiacMethods['left_rectangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def legend(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_left_rectangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10057, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10043
 *         return GiacMethods['left'](self,*args)
 * 
 *      def left_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left_rectangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.left_rectangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10059
 *         return GiacMethods['left_rectangle'](self,*args)
 * 
 *      def legend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legend:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1611legend(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1610legend, "From Giac's documentation:\n        Help for legend:\n        legend(Cplx or Lst,Str)\n        legend(za,\"here\") (or legend([20,60],\"here\")) \"here\" is written at the point of affix za (or at the pixel position [20,60]) and legend=[\"m\",\"s\"] writes \"m\",\"s\" as units on the axis.\n        See also: 1/ labels 2/ angle \n        Ex1:legend(1+i,\"Hello\")\n        Ex2:legend(point([0,2,3],\"Hello\")\n        Ex3:legend(point(0,1),\"Hello\",vert)\n        Ex4:legend(point(0,1,0),\"Hello\",vert)\n        Ex5:legend(1+i,\"Hello\",quadrant4,red)\n        Ex6:legend([30,20],\"bonjour\")\n        Ex7: r:=evalf(sqrt(2));legend([30,20],string(r))\n        Ex8: r:=evalf(sqrt(2));legend([30,20],r)\n        Ex9: legende=[\"m\",\"s\"];point(1,1);\n        Ex10: display(legend(1+i,\"A\"),red)\n        Ex11: point(2+i,legend=\"2+i\",display=quadrant2+red)\n        Ex12: point([2,2*i],legend=\"1+i\",display=quadrant2+red)\n        Ex13: polygon(2,1,i,2*i,legend=\"1+i\",display=quadrant2+red)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1611legend = {"legend", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1611legend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1610legend};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1611legend(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("legend (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "legend", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1610legend(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1610legend(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("legend", 1);

  /* "giacpy/auto-methods.pxi":10080
 * 
 *         '''
 *         return GiacMethods['legend'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def legendre(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_legend); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10080, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10059
 *         return GiacMethods['left_rectangle'](self,*args)
 * 
 *      def legend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legend:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.legend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10082
 *         return GiacMethods['legend'](self,*args)
 * 
 *      def legendre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1613legendre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1612legendre, "From Giac's documentation:\n        Help for legendre:\n        legendre(Intg(n))\n        Returns the n-th Legendre polynomial.\n        See also: 1/  \n        Ex1:legendre(4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1613legendre = {"legendre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1613legendre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1612legendre};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1613legendre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("legendre (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "legendre", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1612legendre(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1612legendre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("legendre", 1);

  /* "giacpy/auto-methods.pxi":10091
 * 
 *         '''
 *         return GiacMethods['legendre'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def legendre_symbol(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_legendre); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10091, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10082
 *         return GiacMethods['legend'](self,*args)
 * 
 *      def legendre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.legendre", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10093
 *         return GiacMethods['legendre'](self,*args)
 * 
 *      def legendre_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre_symbol:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1615legendre_symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1614legendre_symbol, "From Giac's documentation:\n        Help for legendre_symbol:\n        legendre_symbol(Intg,Intg)\n        Legendre symbol.\n        See also: 1/ jacobi_symbol \n        Ex1:legendre_symbol(132,5)\n        Ex2:legendre_symbol(132,25)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1615legendre_symbol = {"legendre_symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1615legendre_symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1614legendre_symbol};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1615legendre_symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("legendre_symbol (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "legendre_symbol", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1614legendre_symbol(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1614legendre_symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("legendre_symbol", 1);

  /* "giacpy/auto-methods.pxi":10103
 * 
 *         '''
 *         return GiacMethods['legendre_symbol'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def length(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_legendre_symbol); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10103, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10093
 *         return GiacMethods['legendre'](self,*args)
 * 
 *      def legendre_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre_symbol:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.legendre_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10105
 *         return GiacMethods['legendre_symbol'](self,*args)
 * 
 *      def length(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for length:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1617length(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1616length, "From Giac's documentation:\n        Help for length:\n        length(Lst||Str||Seq||Image||Audio)\n        Returns the size of a list, a string, a sequence, an image object or an audio clip.\n        See also: 1/ sizes 2/ dim 3/ degree \n        Ex1:length([1,2,3])\n        Ex2:length(\"bonjour\")\n        Ex3:length(1,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1617length = {"length", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1617length, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1616length};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1617length(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("length (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "length", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1616length(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1616length(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("length", 1);

  /* "giacpy/auto-methods.pxi":10116
 * 
 *         '''
 *         return GiacMethods['length'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def levenshtein(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10116, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10105
 *         return GiacMethods['legendre_symbol'](self,*args)
 * 
 *      def length(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for length:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10118
 *         return GiacMethods['length'](self,*args)
 * 
 *      def levenshtein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for levenshtein:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1619levenshtein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1618levenshtein, "From Giac's documentation:\n        Help for levenshtein:\n        levenshtein(Str(s1)||Lst(s1),Str(s2)||Lst(s2))\n        Levenshtein distance between two vectors or strings.\n        See also: 1/ hamming \n        Ex1:levenshtein(\"kitten\",\"sitting\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1619levenshtein = {"levenshtein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1619levenshtein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1618levenshtein};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1619levenshtein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("levenshtein (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "levenshtein", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1618levenshtein(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1618levenshtein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("levenshtein", 1);

  /* "giacpy/auto-methods.pxi":10127
 * 
 *         '''
 *         return GiacMethods['levenshtein'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lgcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_levenshtein); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10127, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10118
 *         return GiacMethods['length'](self,*args)
 * 
 *      def levenshtein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for levenshtein:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.levenshtein", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10129
 *         return GiacMethods['levenshtein'](self,*args)
 * 
 *      def lgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lgcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1621lgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1620lgcd, "From Giac's documentation:\n        Help for lgcd:\n        lgcd(Seq or Lst)\n        Returns the greatest common divisor of a list of polynomials or of integers.\n        See also: 1/ gcd 2/ lcm 3/ euler 4/ content \n        Ex1:lgcd([45,75,20,15])\n        Ex2:lgcd([x^2-2*x+1,x^3-1,x-1])\n        Ex3:lgcd(x^2-2*x+1,x^3-1,x-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1621lgcd = {"lgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1621lgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1620lgcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1621lgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lgcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lgcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1620lgcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1620lgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lgcd", 1);

  /* "giacpy/auto-methods.pxi":10140
 * 
 *         '''
 *         return GiacMethods['lgcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lhs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lgcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10140, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10129
 *         return GiacMethods['levenshtein'](self,*args)
 * 
 *      def lgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lgcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lgcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10142
 *         return GiacMethods['lgcd'](self,*args)
 * 
 *      def lhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lhs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1623lhs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1622lhs, "From Giac's documentation:\n        Help for lhs:\n        lhs(Equal(a=b) or Interval(a..b) or Str,Intg)\n        Returns the left part of an equality, of an interval, of a list or of a string.\n        See also: 1/ right 2/ mid 3/ tail 4/ head \n        Ex1:lhs(a=b)\n        Ex2:lhs(x^2+1=5)\n        Ex3:lhs(1..5)\n        Ex4:lhs(\"abcdefg\",3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1623lhs = {"lhs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1623lhs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1622lhs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1623lhs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lhs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lhs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1622lhs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1622lhs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lhs", 1);

  /* "giacpy/auto-methods.pxi":10154
 * 
 *         '''
 *         return GiacMethods['lhs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_chapeau_carre(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10142
 *         return GiacMethods['lgcd'](self,*args)
 * 
 *      def lhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lhs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lhs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10156
 *         return GiacMethods['lhs'](self,*args)
 * 
 *      def ligne_chapeau_carre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_carre:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1625ligne_chapeau_carre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1624ligne_chapeau_carre, "From Giac's documentation:\n        Help for ligne_chapeau_carre:\n        ligne_chapeau_carre(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1625ligne_chapeau_carre = {"ligne_chapeau_carre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1625ligne_chapeau_carre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1624ligne_chapeau_carre};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1625ligne_chapeau_carre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_chapeau_carre (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_chapeau_carre", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1624ligne_chapeau_carre(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1624ligne_chapeau_carre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_chapeau_carre", 1);

  /* "giacpy/auto-methods.pxi":10166
 * 
 *         '''
 *         return GiacMethods['ligne_chapeau_carre'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_chapeau_plat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_chapeau_carre); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10166, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10156
 *         return GiacMethods['lhs'](self,*args)
 * 
 *      def ligne_chapeau_carre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_carre:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_chapeau_carre", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10168
 *         return GiacMethods['ligne_chapeau_carre'](self,*args)
 * 
 *      def ligne_chapeau_plat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_plat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1627ligne_chapeau_plat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1626ligne_chapeau_plat, "From Giac's documentation:\n        Help for ligne_chapeau_plat:\n        ligne_chapeau_plat(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1627ligne_chapeau_plat = {"ligne_chapeau_plat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1627ligne_chapeau_plat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1626ligne_chapeau_plat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1627ligne_chapeau_plat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_chapeau_plat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_chapeau_plat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1626ligne_chapeau_plat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1626ligne_chapeau_plat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_chapeau_plat", 1);

  /* "giacpy/auto-methods.pxi":10178
 * 
 *         '''
 *         return GiacMethods['ligne_chapeau_plat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_chapeau_rond(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_chapeau_plat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10178, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10168
 *         return GiacMethods['ligne_chapeau_carre'](self,*args)
 * 
 *      def ligne_chapeau_plat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_plat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_chapeau_plat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10180
 *         return GiacMethods['ligne_chapeau_plat'](self,*args)
 * 
 *      def ligne_chapeau_rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_rond:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1629ligne_chapeau_rond(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1628ligne_chapeau_rond, "From Giac's documentation:\n        Help for ligne_chapeau_rond:\n        ligne_chapeau_rond(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1629ligne_chapeau_rond = {"ligne_chapeau_rond", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1629ligne_chapeau_rond, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1628ligne_chapeau_rond};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1629ligne_chapeau_rond(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_chapeau_rond (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_chapeau_rond", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1628ligne_chapeau_rond(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1628ligne_chapeau_rond(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_chapeau_rond", 1);

  /* "giacpy/auto-methods.pxi":10190
 * 
 *         '''
 *         return GiacMethods['ligne_chapeau_rond'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_polygonale(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_chapeau_rond); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10190, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10180
 *         return GiacMethods['ligne_chapeau_plat'](self,*args)
 * 
 *      def ligne_chapeau_rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_rond:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_chapeau_rond", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10192
 *         return GiacMethods['ligne_chapeau_rond'](self,*args)
 * 
 *      def ligne_polygonale(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1631ligne_polygonale(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1630ligne_polygonale, "From Giac's documentation:\n        Help for ligne_polygonale:\n        ligne_polygonale(Mtrx)\n        Draws the polygons joining for j fixed and for k=0..nrows, the points (xk,yk) where xk=element row k column 0 and yk=element row k column j, after the xk are sorted (we obtain ncols-1 polygons).\n        See also: 1/ scatterplot 2/ listplot 3/ polygonscatterplot \n        Ex1:ligne_polygonale([[1,2,3],[2,0,1],[-1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1631ligne_polygonale = {"ligne_polygonale", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1631ligne_polygonale, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1630ligne_polygonale};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1631ligne_polygonale(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_polygonale (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_polygonale", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1630ligne_polygonale(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1630ligne_polygonale(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_polygonale", 1);

  /* "giacpy/auto-methods.pxi":10201
 * 
 *         '''
 *         return GiacMethods['ligne_polygonale'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_polygonale_pointee(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_polygonale); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10201, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10192
 *         return GiacMethods['ligne_chapeau_rond'](self,*args)
 * 
 *      def ligne_polygonale(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_polygonale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10203
 *         return GiacMethods['ligne_polygonale'](self,*args)
 * 
 *      def ligne_polygonale_pointee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale_pointee:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1633ligne_polygonale_pointee(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1632ligne_polygonale_pointee, "From Giac's documentation:\n        Help for ligne_polygonale_pointee:\n        ligne_polygonale_pointee(Mtrx)\n        Draws the points (xk,yk) and the polygons joining for j fixed and for k=0..nrows, the points (xk,yk) where xk=element row k column 0 et yk=element row k column j, after the xk are sorted (we obtain ncols-1 polygons).\n        See also: 1/ scatterplot 2/ polygonplot 3/ listplot \n        Ex1:ligne_polygonale_pointee([[1,2,3],[2,0,1],[-1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1633ligne_polygonale_pointee = {"ligne_polygonale_pointee", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1633ligne_polygonale_pointee, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1632ligne_polygonale_pointee};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1633ligne_polygonale_pointee(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_polygonale_pointee (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_polygonale_pointee", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1632ligne_polygonale_pointee(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1632ligne_polygonale_pointee(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_polygonale_pointee", 1);

  /* "giacpy/auto-methods.pxi":10212
 * 
 *         '''
 *         return GiacMethods['ligne_polygonale_pointee'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_tiret(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_polygonale_pointee); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10212, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10203
 *         return GiacMethods['ligne_polygonale'](self,*args)
 * 
 *      def ligne_polygonale_pointee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale_pointee:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_polygonale_pointee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10214
 *         return GiacMethods['ligne_polygonale_pointee'](self,*args)
 * 
 *      def ligne_tiret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1635ligne_tiret(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1634ligne_tiret, "From Giac's documentation:\n        Help for ligne_tiret:\n        ligne_tiret(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1635ligne_tiret = {"ligne_tiret", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1635ligne_tiret, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1634ligne_tiret};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1635ligne_tiret(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_tiret (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_tiret", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1634ligne_tiret(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1634ligne_tiret(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_tiret", 1);

  /* "giacpy/auto-methods.pxi":10224
 * 
 *         '''
 *         return GiacMethods['ligne_tiret'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_tiret_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_tiret); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10224, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10214
 *         return GiacMethods['ligne_polygonale_pointee'](self,*args)
 * 
 *      def ligne_tiret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_tiret", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10226
 *         return GiacMethods['ligne_tiret'](self,*args)
 * 
 *      def ligne_tiret_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1637ligne_tiret_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1636ligne_tiret_point, "From Giac's documentation:\n        Help for ligne_tiret_point:\n        ligne_tiret_point(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1637ligne_tiret_point = {"ligne_tiret_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1637ligne_tiret_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1636ligne_tiret_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1637ligne_tiret_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_tiret_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_tiret_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1636ligne_tiret_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1636ligne_tiret_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_tiret_point", 1);

  /* "giacpy/auto-methods.pxi":10236
 * 
 *         '''
 *         return GiacMethods['ligne_tiret_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_tiret_pointpoint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_tiret_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10236, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10226
 *         return GiacMethods['ligne_tiret'](self,*args)
 * 
 *      def ligne_tiret_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_tiret_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10238
 *         return GiacMethods['ligne_tiret_point'](self,*args)
 * 
 *      def ligne_tiret_pointpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_pointpoint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1639ligne_tiret_pointpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1638ligne_tiret_pointpoint, "From Giac's documentation:\n        Help for ligne_tiret_pointpoint:\n        ligne_tiret_pointpoint(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1639ligne_tiret_pointpoint = {"ligne_tiret_pointpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1639ligne_tiret_pointpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1638ligne_tiret_pointpoint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1639ligne_tiret_pointpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_tiret_pointpoint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_tiret_pointpoint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1638ligne_tiret_pointpoint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1638ligne_tiret_pointpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_tiret_pointpoint", 1);

  /* "giacpy/auto-methods.pxi":10248
 * 
 *         '''
 *         return GiacMethods['ligne_tiret_pointpoint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ligne_trait_plein(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_tiret_pointpoint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10248, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10238
 *         return GiacMethods['ligne_tiret_point'](self,*args)
 * 
 *      def ligne_tiret_pointpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_pointpoint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_tiret_pointpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10250
 *         return GiacMethods['ligne_tiret_pointpoint'](self,*args)
 * 
 *      def ligne_trait_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_trait_plein:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1641ligne_trait_plein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1640ligne_trait_plein, "From Giac's documentation:\n        Help for ligne_trait_plein:\n        ligne_trait_plein(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1641ligne_trait_plein = {"ligne_trait_plein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1641ligne_trait_plein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1640ligne_trait_plein};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1641ligne_trait_plein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ligne_trait_plein (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ligne_trait_plein", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1640ligne_trait_plein(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1640ligne_trait_plein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ligne_trait_plein", 1);

  /* "giacpy/auto-methods.pxi":10260
 * 
 *         '''
 *         return GiacMethods['ligne_trait_plein'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def limit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ligne_trait_plein); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10260, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10250
 *         return GiacMethods['ligne_tiret_pointpoint'](self,*args)
 * 
 *      def ligne_trait_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_trait_plein:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ligne_trait_plein", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10262
 *         return GiacMethods['ligne_trait_plein'](self,*args)
 * 
 *      def limit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1643limit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1642limit, "From Giac's documentation:\n        Help for limit:\n        limit(Expr,Var,Val,[Dir(d)])\n        Limit of an expression at a limit point (a or +/-infinity) (d=-1 for limit from below and +1 for limit from above).\n        See also: 1/ series 2/ taylor 3/ taux_accroissement \n        Ex1:limit((n*tan(x)-tan(n*x))/(sin(n*x)-n*sin(x)),x,0)\n        Ex2:limit(sin(x)/(x^2-3*x),x,0)\n        Ex3:limit((2*x-1)/exp(1/(x-1)),x,+infinity)\n        Ex4:limit(exp(1/x),x,0,1)\n        Ex5:limit(exp(1/x),x,0,-1)\n        Ex6:limit(taux_accroissement(x^n,1,1+h),h,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1643limit = {"limit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1643limit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1642limit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1643limit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("limit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "limit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1642limit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1642limit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("limit", 1);

  /* "giacpy/auto-methods.pxi":10276
 * 
 *         '''
 *         return GiacMethods['limit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def limite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_limit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10276, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10262
 *         return GiacMethods['ligne_trait_plein'](self,*args)
 * 
 *      def limit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.limit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10278
 *         return GiacMethods['limit'](self,*args)
 * 
 *      def limite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1645limite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1644limite, "From Giac's documentation:\n        Help for limite:\n        limite(Expr,Var,Val,[Dir(d)])\n        Limit of an expression at a limit point (a or +/-infinity) (d=-1 for limit from below and +1 for limit from above).\n        See also: 1/ series 2/ taylor 3/ taux_accroissement \n        Ex1:limite((n*tan(x)-tan(n*x))/(sin(n*x)-n*sin(x)),x,0)\n        Ex2:limite(sin(x)/(x^2-3*x),x,0)\n        Ex3:limite((2*x-1)/exp(1/(x-1)),x,+infinity)\n        Ex4:limite(exp(1/x),x,0,1)\n        Ex5:limite(exp(1/x),x,0,-1)\n        Ex6:limite(taux_accroissement(x^n,1,1+h),h,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1645limite = {"limite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1645limite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1644limite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1645limite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("limite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "limite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1644limite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1644limite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("limite", 1);

  /* "giacpy/auto-methods.pxi":10292
 * 
 *         '''
 *         return GiacMethods['limite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_limite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10292, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10278
 *         return GiacMethods['limit'](self,*args)
 * 
 *      def limite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.limite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10294
 *         return GiacMethods['limite'](self,*args)
 * 
 *      def lin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1647lin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1646lin, "From Giac's documentation:\n        Help for lin:\n        lin(Expr)\n        Linearization of exponentials.\n        See also: 1/ tlin 2/ texpand \n        Ex1:lin(exp(x)^n)\n        Ex2:lin((exp(x)^3+exp(x))^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1647lin = {"lin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1647lin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1646lin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1647lin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1646lin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1646lin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lin", 1);

  /* "giacpy/auto-methods.pxi":10304
 * 
 *         '''
 *         return GiacMethods['lin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linabs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10304, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10294
 *         return GiacMethods['limite'](self,*args)
 * 
 *      def lin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10306
 *         return GiacMethods['lin'](self,*args)
 * 
 *      def linabs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linabs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1649linabs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1648linabs, "From Giac's documentation:\n        Help for linabs:\n        linabs(Expr,[Var])\n        Rewrites signum/Heaviside/piecewise subexpressions by using absolute values.\n        See also: 1/ Heaviside 2/ sign 3/ piecewise \n        Ex1:linabs(x*sign(x))\n        Ex2:linabs(sin(x)*Heaviside(x)-sin(x)*Heaviside(-x))\n        Ex3:linabs(abs(abs(x-2)+x*abs(x+1)+1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1649linabs = {"linabs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1649linabs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1648linabs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1649linabs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linabs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linabs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1648linabs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1648linabs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linabs", 1);

  /* "giacpy/auto-methods.pxi":10317
 * 
 *         '''
 *         return GiacMethods['linabs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linabs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10317, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10306
 *         return GiacMethods['lin'](self,*args)
 * 
 *      def linabs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linabs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linabs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10319
 *         return GiacMethods['linabs'](self,*args)
 * 
 *      def line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1651line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1650line, "From Giac's documentation:\n        Help for line:\n        line(Pnt||Cplx||Eq,[Pnt||slope||Var])\n        line(A,B) (resp line(A,slope=m) or line(A,[1,m]) or line(a*x+b*y+c=0) or line(a*x+b*y+c*z+d=0,aa*x+bb*y+cc*z+dd=0) or line(A,u)) draws the line AB (resp the line going through A with slope m or with direction vector u or of equation the argument) in the plane or in the 3D space.\n        See also: 1/ point 2/ plane 3/ slope \n        Ex1:line(i,1+i)\n        Ex2:line(point(-i),point(1+i))\n        Ex3:line(1+i,slope=2)\n        Ex4:line([0,0,0],[1,1,1])\n        Ex5:line(x+y=1)\n        Ex6:line(x+y+z=0,x+y=0)\n        Ex7:line([1+t,-1+t],t)\n        Ex8:line([1+t,2-t,-1+3*t],t)\n        Ex9:line(1-i,slope=slope(line(1,2i)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1651line = {"line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1651line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1650line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1651line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1650line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1650line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("line", 1);

  /* "giacpy/auto-methods.pxi":10336
 * 
 *         '''
 *         return GiacMethods['line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def line_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10336, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10319
 *         return GiacMethods['linabs'](self,*args)
 * 
 *      def line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10338
 *         return GiacMethods['line'](self,*args)
 * 
 *      def line_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1653line_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1652line_graph, "From Giac's documentation:\n        Help for line_graph:\n        line_graph(Graph(G))\n        Returns the line graph of an undirected graph G.\n        See also: 1/ plane_dual \n        Ex1:line_graph(hypercube_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1653line_graph = {"line_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1653line_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1652line_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1653line_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "line_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1652line_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1652line_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("line_graph", 1);

  /* "giacpy/auto-methods.pxi":10347
 * 
 *         '''
 *         return GiacMethods['line_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def line_inter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_line_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10347, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10338
 *         return GiacMethods['line'](self,*args)
 * 
 *      def line_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.line_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10349
 *         return GiacMethods['line_graph'](self,*args)
 * 
 *      def line_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_inter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1655line_inter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1654line_inter, "From Giac's documentation:\n        Help for line_inter:\n        line_inter(Curve,Curve,[Pnt(A)||LstPnt(L)])\n        Gives one of the points of intersection of 2 curves or surfaces (or the intersection near A or not in L).\n        See also: 1/ intersect 2/ head \n        Ex1:line_inter(line(i,1-i),line(0,1))\n        Ex2:line_inter(line(i,1-i),circle(0,1))\n        Ex3:line_inter(line(i,1+2*i),circle(0,1),[point(i)])\n        Ex4:line_inter(line(-1-i,1+2*i),circle(0,1),point(-1))\n        Ex5:line_inter(circle(1,sqrt(2)),circle(0,1))\n        Ex6:line_inter(plane(x=y),plane(y=z))\n        Ex7:line_inter(line(x=y+1,y=2*z),plane(y=z))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1655line_inter = {"line_inter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1655line_inter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1654line_inter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1655line_inter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line_inter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "line_inter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1654line_inter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1654line_inter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("line_inter", 1);

  /* "giacpy/auto-methods.pxi":10364
 * 
 *         '''
 *         return GiacMethods['line_inter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def line_paper(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_line_inter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10364, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10349
 *         return GiacMethods['line_graph'](self,*args)
 * 
 *      def line_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_inter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.line_inter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10366
 *         return GiacMethods['line_inter'](self,*args)
 * 
 *      def line_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_paper:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1657line_paper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1656line_paper, "From Giac's documentation:\n        Help for line_paper:\n        line_paper(Real(ux),Real(t),[x=xmin..xmax,y=ymin..ymax])\n        Draws in the rectangle [xmin..xmax]*[ymin..ymax], the lines x=n*ux at an angle of t!=0 from the horizontal.\n        Ex1:line_paper(0.4,pi/3)\n        Ex2:line_paper(0.4,pi/3,x=-1..4,y=-2..2)\n        Ex3:line_paper(0.5,3*pi/4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1657line_paper = {"line_paper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1657line_paper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1656line_paper};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1657line_paper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line_paper (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "line_paper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1656line_paper(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1656line_paper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("line_paper", 1);

  /* "giacpy/auto-methods.pxi":10376
 * 
 *         '''
 *         return GiacMethods['line_paper'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def line_segments(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_line_paper); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10376, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10366
 *         return GiacMethods['line_inter'](self,*args)
 * 
 *      def line_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_paper:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.line_paper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10378
 *         return GiacMethods['line_paper'](self,*args)
 * 
 *      def line_segments(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_segments:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1659line_segments(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1658line_segments, "From Giac's documentation:\n        Help for line_segments:\n        line_segments(Polygon or Polyedr(P))\n        Returns the list of the line_segments (1 line=segment) of the polyhedron P.\n        See also: 1/ polyhedron \n        Ex1:line_segments(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))\n        Ex2:line_segments(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))[2]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1659line_segments = {"line_segments", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1659line_segments, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1658line_segments};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1659line_segments(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("line_segments (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "line_segments", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1658line_segments(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1658line_segments(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("line_segments", 1);

  /* "giacpy/auto-methods.pxi":10388
 * 
 *         '''
 *         return GiacMethods['line_segments'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linear_interpolate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_line_segments); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10388, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10378
 *         return GiacMethods['line_paper'](self,*args)
 * 
 *      def line_segments(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_segments:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.line_segments", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10390
 *         return GiacMethods['line_segments'](self,*args)
 * 
 *      def linear_interpolate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_interpolate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1661linear_interpolate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1660linear_interpolate, "From Giac's documentation:\n        Help for linear_interpolate:\n        linear_interpolate(Mtrx,xmin,xmax,xstep)\n        Makes a regular sample from a polygonal line defined by a 2 row matrix.\n        See also: 1/ polygonplot \n        Ex1:linear_interpolate([[1,2,6,9],[3,4,6,7]],1,9,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1661linear_interpolate = {"linear_interpolate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1661linear_interpolate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1660linear_interpolate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1661linear_interpolate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linear_interpolate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linear_interpolate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1660linear_interpolate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1660linear_interpolate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linear_interpolate", 1);

  /* "giacpy/auto-methods.pxi":10399
 * 
 *         '''
 *         return GiacMethods['linear_interpolate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linear_regression(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linear_interpolate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10399, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10390
 *         return GiacMethods['line_segments'](self,*args)
 * 
 *      def linear_interpolate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_interpolate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linear_interpolate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10401
 *         return GiacMethods['linear_interpolate'](self,*args)
 * 
 *      def linear_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1663linear_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1662linear_regression, "From Giac's documentation:\n        Help for linear_regression:\n        linear_regression(Lst||Mtrx(A),[Lst])\n        Returns the coefficients a and b of y=a*x+b ; it is the best line approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ polynomial_regression 2/ power_regression 3/ logistic_regression \n        Ex1:linear_regression([[0.0,0.0],[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex2:linear_regression([0.0,1.0,2.0,3.0,4.0],[0.0,1.0,4.0,9.0,16.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1663linear_regression = {"linear_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1663linear_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1662linear_regression};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1663linear_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linear_regression (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linear_regression", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1662linear_regression(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1662linear_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linear_regression", 1);

  /* "giacpy/auto-methods.pxi":10411
 * 
 *         '''
 *         return GiacMethods['linear_regression'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linear_regression_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linear_regression); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10411, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10401
 *         return GiacMethods['linear_interpolate'](self,*args)
 * 
 *      def linear_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linear_regression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10413
 *         return GiacMethods['linear_regression'](self,*args)
 * 
 *      def linear_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1665linear_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1664linear_regression_plot, "From Giac's documentation:\n        Help for linear_regression_plot:\n        linear_regression_plot(Lst||Mtrx(A),[Lst])\n        Returns the plot of y=a*x+b ;it is the best line approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ polynomial_regression_plot 2/ power_regression_plot \n        Ex1:linear_regression_plot([[0.0,0.0],[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex2:linear_regression_plot([0.0,1.0,2.0,3.0,4.0],[0.0,1.0,4.0,9.0,16.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1665linear_regression_plot = {"linear_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1665linear_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1664linear_regression_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1665linear_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linear_regression_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linear_regression_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1664linear_regression_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1664linear_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linear_regression_plot", 1);

  /* "giacpy/auto-methods.pxi":10423
 * 
 *         '''
 *         return GiacMethods['linear_regression_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lineariser(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linear_regression_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10423, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10413
 *         return GiacMethods['linear_regression'](self,*args)
 * 
 *      def linear_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linear_regression_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10425
 *         return GiacMethods['linear_regression_plot'](self,*args)
 * 
 *      def lineariser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1667lineariser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1666lineariser, "From Giac's documentation:\n        Help for lineariser:\n        lineariser(Expr)\n        Linearization of exponentials.\n        See also: 1/ tlin 2/ texpand \n        Ex1:lineariser(exp(x)^n)\n        Ex2:lineariser((exp(x)^3+exp(x))^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1667lineariser = {"lineariser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1667lineariser, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1666lineariser};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1667lineariser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lineariser (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lineariser", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1666lineariser(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1666lineariser(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lineariser", 1);

  /* "giacpy/auto-methods.pxi":10435
 * 
 *         '''
 *         return GiacMethods['lineariser'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lineariser_trigo(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lineariser); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10435, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10425
 *         return GiacMethods['linear_regression_plot'](self,*args)
 * 
 *      def lineariser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lineariser", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10437
 *         return GiacMethods['lineariser'](self,*args)
 * 
 *      def lineariser_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser_trigo:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1669lineariser_trigo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1668lineariser_trigo, "From Giac's documentation:\n        Help for lineariser_trigo:\n        lineariser_trigo(ExprTrig)\n        Trigonometric linearization.\n        See also: 1/ texpand 2/ lin \n        Ex1:lineariser_trigo(sin(x)^3)\n        Ex2:lineariser_trigo(cos(x)*cos(y))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1669lineariser_trigo = {"lineariser_trigo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1669lineariser_trigo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1668lineariser_trigo};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1669lineariser_trigo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lineariser_trigo (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lineariser_trigo", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1668lineariser_trigo(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1668lineariser_trigo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lineariser_trigo", 1);

  /* "giacpy/auto-methods.pxi":10447
 * 
 *         '''
 *         return GiacMethods['lineariser_trigo'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linfnorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lineariser_trigo); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10447, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10437
 *         return GiacMethods['lineariser'](self,*args)
 * 
 *      def lineariser_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser_trigo:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lineariser_trigo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10449
 *         return GiacMethods['lineariser_trigo'](self,*args)
 * 
 *      def linfnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linfnorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1671linfnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1670linfnorm, "From Giac's documentation:\n        Help for linfnorm:\n        linfnorm(Mtrx)\n        Matrix norm induced by linfinity norm.\n        See also: 1/ l1norm 2/ l2norm 3/ matrix_norm 4/ frobenius_norm \n        Ex1:linfnorm([[1,2,3],[3,-9,6],[4,5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1671linfnorm = {"linfnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1671linfnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1670linfnorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1671linfnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linfnorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linfnorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1670linfnorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1670linfnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linfnorm", 1);

  /* "giacpy/auto-methods.pxi":10458
 * 
 *         '''
 *         return GiacMethods['linfnorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linfnorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10458, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10449
 *         return GiacMethods['lineariser_trigo'](self,*args)
 * 
 *      def linfnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linfnorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linfnorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10460
 *         return GiacMethods['linfnorm'](self,*args)
 * 
 *      def linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1673linsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1672linsolve, "From Giac's documentation:\n        Help for linsolve:\n        linsolve(LstLinEq,LstVar)\n        Linear equations system solver.\n        See also: 1/ solve 2/ proot 3/ simult 4/ gaussjord 5/ pivot 6/ ref 7/ conjugate_gradient \n        Ex1:linsolve([x+y+z=1,x-y=2,2*x-z=3],[x,y,z])\n        Ex2:linsolve([m*x+y=a,x+m*y=b],[x,y])\n        Ex3:linsolve([x+y-z-1,x-y+1,x-y-z-1]%2,[x,y,z])\n        Ex4:linsolve([[3,4],[1,2]],[0,1])\n        Ex5: p,l,u:=lu([[3,4],[1,2]]); linsolve(p,l,u,[0,1]) \n        Ex6:linsolve([2*x+y+z=1,x+y+2*z=1,x+2*y+z=4],[x,y,z])\n        Ex7:linsolve([[2,1,1],[1,1,2],[1,2,1]],[1,1,4])\n        Ex8: p,l,u:=lu([[2,1,1],[1,1,2],[1,2,1]]);linsolve(p,l,u,[1,1,4])\n        Ex9: a:=[[100,2],[2,100]];linsolve(evalf(a),[0,1]);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1673linsolve = {"linsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1673linsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1672linsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1673linsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1672linsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1672linsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linsolve", 1);

  /* "giacpy/auto-methods.pxi":10477
 * 
 *         '''
 *         return GiacMethods['linsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linspace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10477, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10460
 *         return GiacMethods['linfnorm'](self,*args)
 * 
 *      def linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10479
 *         return GiacMethods['linsolve'](self,*args)
 * 
 *      def linspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linspace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1675linspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1674linspace, "From Giac's documentation:\n        Help for linspace:\n        linspace(Real(a),Real(b),[Int(n)])\n        linspace(a,b,n) creates a list of n elements at regular intervals between a and b, by default n=100 (compatibility with scilab).\n        Ex1:linspace(0,1,11)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1675linspace = {"linspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1675linspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1674linspace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1675linspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linspace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linspace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1674linspace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1674linspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linspace", 1);

  /* "giacpy/auto-methods.pxi":10487
 * 
 *         '''
 *         return GiacMethods['linspace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def linstep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linspace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10487, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10479
 *         return GiacMethods['linsolve'](self,*args)
 * 
 *      def linspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linspace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linspace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10489
 *         return GiacMethods['linspace'](self,*args)
 * 
 *      def linstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linstep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1677linstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1676linstep, "From Giac's documentation:\n        Help for linstep:\n        linstep(Expr,[Var])\n        Rewrites expressions as linear combinations of Heaviside functions.\n        See also: 1/ Heaviside \n        Ex1:linstep(Heaviside(x-2)*Heaviside(3-x),x)\n        Ex2:linstep(piecewise(x<-1,0,x<1,x+1,2-(x-1)^2),x)\n        Ex3:linstep(abs(abs(x)-abs(x-1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1677linstep = {"linstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1677linstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1676linstep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1677linstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("linstep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "linstep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1676linstep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1676linstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("linstep", 1);

  /* "giacpy/auto-methods.pxi":10500
 * 
 *         '''
 *         return GiacMethods['linstep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lis_phrase(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_linstep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10500, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10489
 *         return GiacMethods['linspace'](self,*args)
 * 
 *      def linstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linstep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.linstep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10502
 *         return GiacMethods['linstep'](self,*args)
 * 
 *      def lis_phrase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lis_phrase:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1679lis_phrase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1678lis_phrase, "From Giac's documentation:\n        Help for lis_phrase:\n        lis_phrase([Str],Var(Var))\n        Instruction in a program so that a string expression can be input and stored in var.\n        See also: 1/ input \n        Ex1:lis_phrase(\"nom?\",N)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1679lis_phrase = {"lis_phrase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1679lis_phrase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1678lis_phrase};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1679lis_phrase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lis_phrase (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lis_phrase", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1678lis_phrase(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1678lis_phrase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lis_phrase", 1);

  /* "giacpy/auto-methods.pxi":10511
 * 
 *         '''
 *         return GiacMethods['lis_phrase'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def list2exp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lis_phrase); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10511, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10502
 *         return GiacMethods['linstep'](self,*args)
 * 
 *      def lis_phrase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lis_phrase:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lis_phrase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10513
 *         return GiacMethods['lis_phrase'](self,*args)
 * 
 *      def list2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2exp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1681list2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1680list2exp, "From Giac's documentation:\n        Help for list2exp:\n        list2exp(List)\n        Inverse of exp2list.\n        See also: 1/ exp2list \n        Ex1:list2exp([[3,9],[- 1,1]],[x, y])\n        Ex2:list2exp(solve(x^2-1=0),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1681list2exp = {"list2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1681list2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1680list2exp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1681list2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list2exp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "list2exp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1680list2exp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1680list2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list2exp", 1);

  /* "giacpy/auto-methods.pxi":10523
 * 
 *         '''
 *         return GiacMethods['list2exp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def list2mat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_list2exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10523, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10513
 *         return GiacMethods['lis_phrase'](self,*args)
 * 
 *      def list2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2exp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.list2exp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10525
 *         return GiacMethods['list2exp'](self,*args)
 * 
 *      def list2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2mat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1683list2mat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1682list2mat, "From Giac's documentation:\n        Help for list2mat:\n        list2mat(Lst(l),Intg(n))\n        Returns the matrix with n columns and where terms are the list l completed eventually by 0.\n        See also: 1/ mat2list \n        Ex1:list2mat([1,8,4,9],1)\n        Ex2:list2mat([1,8,4,9],2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1683list2mat = {"list2mat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1683list2mat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1682list2mat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1683list2mat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list2mat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "list2mat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1682list2mat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1682list2mat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list2mat", 1);

  /* "giacpy/auto-methods.pxi":10535
 * 
 *         '''
 *         return GiacMethods['list2mat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def list_edge_attributes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_list2mat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10535, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10525
 *         return GiacMethods['list2exp'](self,*args)
 * 
 *      def list2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2mat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.list2mat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10537
 *         return GiacMethods['list2mat'](self,*args)
 * 
 *      def list_edge_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_edge_attributes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1685list_edge_attributes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1684list_edge_attributes, "From Giac's documentation:\n        Help for list_edge_attributes:\n        list_edge_attributes(Graph(G),Edge(e))\n        Returns the list of attributes assigned to the edge e in G. Each attribute has the form tag=value.\n        See also: 1/ set_edge_attribute 2/ get_edge_attribute 3/ discard_edge_attribute \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1685list_edge_attributes = {"list_edge_attributes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1685list_edge_attributes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1684list_edge_attributes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1685list_edge_attributes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list_edge_attributes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "list_edge_attributes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1684list_edge_attributes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1684list_edge_attributes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_edge_attributes", 1);

  /* "giacpy/auto-methods.pxi":10545
 * 
 *         '''
 *         return GiacMethods['list_edge_attributes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def list_graph_attributes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_list_edge_attributes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10545, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10537
 *         return GiacMethods['list2mat'](self,*args)
 * 
 *      def list_edge_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_edge_attributes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.list_edge_attributes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10547
 *         return GiacMethods['list_edge_attributes'](self,*args)
 * 
 *      def list_graph_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_graph_attributes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1687list_graph_attributes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1686list_graph_attributes, "From Giac's documentation:\n        Help for list_graph_attributes:\n        list_graph_attributes(Graph(G))\n        Returns the list of graph attributes of G. Each attribute has the form tag=value.\n        See also: 1/ set_graph_attribute 2/ get_graph_attribute 3/ discard_graph_attribute \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1687list_graph_attributes = {"list_graph_attributes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1687list_graph_attributes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1686list_graph_attributes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1687list_graph_attributes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list_graph_attributes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "list_graph_attributes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1686list_graph_attributes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1686list_graph_attributes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_graph_attributes", 1);

  /* "giacpy/auto-methods.pxi":10555
 * 
 *         '''
 *         return GiacMethods['list_graph_attributes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def list_vertex_attributes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_list_graph_attributes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10555, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10547
 *         return GiacMethods['list_edge_attributes'](self,*args)
 * 
 *      def list_graph_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_graph_attributes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.list_graph_attributes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10557
 *         return GiacMethods['list_graph_attributes'](self,*args)
 * 
 *      def list_vertex_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_vertex_attributes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1689list_vertex_attributes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1688list_vertex_attributes, "From Giac's documentation:\n        Help for list_vertex_attributes:\n        list_vertex_attributes(Graph(G),Vrtx(v))\n        Returns the list of attributes assigned to the vertex v in G. Each attribute has the form tag=value.\n        See also: 1/ set_vertex_attribute 2/ get_vertex_attribute 3/ discard_vertex_attribute \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1689list_vertex_attributes = {"list_vertex_attributes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1689list_vertex_attributes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1688list_vertex_attributes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1689list_vertex_attributes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list_vertex_attributes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "list_vertex_attributes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1688list_vertex_attributes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1688list_vertex_attributes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_vertex_attributes", 1);

  /* "giacpy/auto-methods.pxi":10565
 * 
 *         '''
 *         return GiacMethods['list_vertex_attributes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def listplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_list_vertex_attributes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10565, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10557
 *         return GiacMethods['list_graph_attributes'](self,*args)
 * 
 *      def list_vertex_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_vertex_attributes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.list_vertex_attributes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10567
 *         return GiacMethods['list_vertex_attributes'](self,*args)
 * 
 *      def listplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for listplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1691listplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1690listplot, "From Giac's documentation:\n        Help for listplot:\n        listplot(Lst(l)||Mtrx(M))\n        Draws the polygonal line through the points with abscissas 0,...,n and ordinates l=[y0,...,yn] or the line through the points with abscissas the first column of M and ordinates the second column.\n        See also: 1/ polygonplot 2/ scatterplot 3/ polygonscatterplot \n        Ex1:listplot([13,10,15,16])\n        Ex2:listplot([1,13],[2,10],[3,15],[4,16])\n        Ex3:listplot([[0,13],[2,10],[4,15]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1691listplot = {"listplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1691listplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1690listplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1691listplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("listplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "listplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1690listplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1690listplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("listplot", 1);

  /* "giacpy/auto-methods.pxi":10578
 * 
 *         '''
 *         return GiacMethods['listplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lll(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_listplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10578, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10567
 *         return GiacMethods['list_vertex_attributes'](self,*args)
 * 
 *      def listplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for listplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.listplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10580
 *         return GiacMethods['listplot'](self,*args)
 * 
 *      def lll(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lll:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1693lll(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1692lll, "From Giac's documentation:\n        Help for lll:\n        lll(Mtrx)\n        (S,A,L,O):=lll(M), short basis of a lattice (L*O=A*M=S).\n        Ex1:lll([[1234,3452,4521],[3425,2241,1543],[5643,3425,8721]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1693lll = {"lll", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1693lll, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1692lll};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1693lll(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lll (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lll", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1692lll(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1692lll(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lll", 1);

  /* "giacpy/auto-methods.pxi":10588
 * 
 *         '''
 *         return GiacMethods['lll'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ln(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lll); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10588, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10580
 *         return GiacMethods['listplot'](self,*args)
 * 
 *      def lll(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lll:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lll", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10590
 *         return GiacMethods['lll'](self,*args)
 * 
 *      def ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ln:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1695ln(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1694ln, "From Giac's documentation:\n        Help for ln:\n        ln(Expr or Opt)\n        Natural logarithm or option of the convert or convertir command (id trig2exp).\n        See also: 1/ exp 2/ convert 3/ trig2exp 4/ log10 \n        Ex1:ln(1)\n        Ex2:ln(e)\n        Ex3: convert(cos(x),ln)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1695ln = {"ln", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1695ln, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1694ln};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1695ln(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ln (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ln", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1694ln(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1694ln(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ln", 1);

  /* "giacpy/auto-methods.pxi":10601
 * 
 *         '''
 *         return GiacMethods['ln'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lname(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ln); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10601, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10590
 *         return GiacMethods['lll'](self,*args)
 * 
 *      def ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ln:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ln", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10603
 *         return GiacMethods['ln'](self,*args)
 * 
 *      def lname(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lname:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1697lname(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1696lname, "From Giac's documentation:\n        Help for lname:\n        lname(Expr)\n        List of variables in the expression.\n        See also: 1/ has 2/ lvar \n        Ex1:lname(exp(x)*2*sin(y))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1697lname = {"lname", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1697lname, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1696lname};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1697lname(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lname (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lname", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1696lname(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1696lname(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lname", 1);

  /* "giacpy/auto-methods.pxi":10612
 * 
 *         '''
 *         return GiacMethods['lname'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lncollect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lname); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10612, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10603
 *         return GiacMethods['ln'](self,*args)
 * 
 *      def lname(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lname:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10614
 *         return GiacMethods['lname'](self,*args)
 * 
 *      def lncollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lncollect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1699lncollect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1698lncollect, "From Giac's documentation:\n        Help for lncollect:\n        lncollect(Expr)\n        Collects logarithms. Applies ln(a)+n*ln(b)->ln(a*b^n) for integers n.\n        See also: 1/ texpand \n        Ex1:lncollect(ln(x)+2*ln(y))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1699lncollect = {"lncollect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1699lncollect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1698lncollect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1699lncollect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lncollect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lncollect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1698lncollect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1698lncollect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lncollect", 1);

  /* "giacpy/auto-methods.pxi":10623
 * 
 *         '''
 *         return GiacMethods['lncollect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lnexpand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lncollect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10623, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10614
 *         return GiacMethods['lname'](self,*args)
 * 
 *      def lncollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lncollect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lncollect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10625
 *         return GiacMethods['lncollect'](self,*args)
 * 
 *      def lnexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lnexpand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1701lnexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1700lnexpand, "From Giac's documentation:\n        Help for lnexpand:\n        lnexpand(Expr)\n        Expands logarithms.\n        See also: 1/ texpand 2/ expexpand 3/ trigexpand \n        Ex1:lnexpand(ln(3*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1701lnexpand = {"lnexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1701lnexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1700lnexpand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1701lnexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lnexpand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lnexpand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1700lnexpand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1700lnexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lnexpand", 1);

  /* "giacpy/auto-methods.pxi":10634
 * 
 *         '''
 *         return GiacMethods['lnexpand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def locus(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lnexpand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10634, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10625
 *         return GiacMethods['lncollect'](self,*args)
 * 
 *      def lnexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lnexpand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lnexpand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10636
 *         return GiacMethods['lnexpand'](self,*args)
 * 
 *      def locus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for locus:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1703locus(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1702locus, "From Giac's documentation:\n        Help for locus:\n        locus(Pnt,Elem)\n        locus(M,A) draws the locus of M (or locus(d,A) draws the envelope of d) when A:=element(C) (C is a curve). The example instructions below must be written in a geometric level on different lines.\n        See also: 1/ envelope 2/ trace \n        Ex1: A:=element(circle(i,1+i));M:=homothety(0,2,A);locus(M,A)\n        Ex2: A:=element(line(x=0));d:=perpen_bisector(1,A);locus(d,A)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1703locus = {"locus", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1703locus, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1702locus};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1703locus(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("locus (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "locus", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1702locus(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1702locus(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("locus", 1);

  /* "giacpy/auto-methods.pxi":10646
 * 
 *         '''
 *         return GiacMethods['locus'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def log(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_locus); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10646, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10636
 *         return GiacMethods['lnexpand'](self,*args)
 * 
 *      def locus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for locus:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.locus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10648
 *         return GiacMethods['locus'](self,*args)
 * 
 *      def log(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1705log(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1704log, "From Giac's documentation:\n        Help for log:\n        log(Expr or Opt)\n        Natural logarithm or option of the convert or convertir command (id trig2exp).\n        See also: 1/ exp 2/ convert 3/ trig2exp 4/ log10 \n        Ex1:log(1)\n        Ex2:log(e)\n        Ex3: convert(cos(x),ln)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1705log = {"log", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1705log, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1704log};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1705log(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("log (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "log", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1704log(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1704log(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("log", 1);

  /* "giacpy/auto-methods.pxi":10659
 * 
 *         '''
 *         return GiacMethods['log'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def log10(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_log); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10659, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10648
 *         return GiacMethods['locus'](self,*args)
 * 
 *      def log(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.log", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10661
 *         return GiacMethods['log'](self,*args)
 * 
 *      def log10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log10:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1707log10(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1706log10, "From Giac's documentation:\n        Help for log10:\n        log10(Expr)\n        Common logarithm (base 10).\n        See also: 1/ alog10 2/ ln \n        Ex1:log10(10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1707log10 = {"log10", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1707log10, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1706log10};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1707log10(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("log10 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "log10", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1706log10(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1706log10(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("log10", 1);

  /* "giacpy/auto-methods.pxi":10670
 * 
 *         '''
 *         return GiacMethods['log10'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def log2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_log10); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10670, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10661
 *         return GiacMethods['log'](self,*args)
 * 
 *      def log10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log10:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.log10", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10672
 *         return GiacMethods['log10'](self,*args)
 * 
 *      def log2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1709log2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1708log2, "From Giac's documentation:\n        Help for log2:\n        log2(Expr)\n        Binary logarithm (base 2).\n        See also: 1/ log 2/ logb 3/ log10 \n        Ex1:log2(8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1709log2 = {"log2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1709log2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1708log2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1709log2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("log2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "log2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1708log2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1708log2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("log2", 1);

  /* "giacpy/auto-methods.pxi":10681
 * 
 *         '''
 *         return GiacMethods['log2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def log_loss(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_log2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10681, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10672
 *         return GiacMethods['log10'](self,*args)
 * 
 *      def log2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.log2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10683
 *         return GiacMethods['log2'](self,*args)
 * 
 *      def log_loss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log_loss:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1711log_loss(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1710log_loss, "From Giac's documentation:\n        Help for log_loss:\n        log_loss(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1711log_loss = {"log_loss", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1711log_loss, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1710log_loss};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1711log_loss(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("log_loss (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "log_loss", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1710log_loss(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1710log_loss(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("log_loss", 1);

  /* "giacpy/auto-methods.pxi":10691
 * 
 *         '''
 *         return GiacMethods['log_loss'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def logarithmic_regression(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_log_loss); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10691, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10683
 *         return GiacMethods['log2'](self,*args)
 * 
 *      def log_loss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log_loss:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.log_loss", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10693
 *         return GiacMethods['log_loss'](self,*args)
 * 
 *      def logarithmic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1713logarithmic_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1712logarithmic_regression, "From Giac's documentation:\n        Help for logarithmic_regression:\n        logarithmic_regression(Lst||Mtrx(A),[Lst])\n        Returns the coefficients a and b of y=a*ln(x)+b : it is the best logarithm which approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ exponential_regression \n        Ex1:logarithmic_regression([[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex2:logarithmic_regression([1.0,2.0,3.0,4.0],[1.0,4.0,9.0,16.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1713logarithmic_regression = {"logarithmic_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1713logarithmic_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1712logarithmic_regression};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1713logarithmic_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("logarithmic_regression (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "logarithmic_regression", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1712logarithmic_regression(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1712logarithmic_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("logarithmic_regression", 1);

  /* "giacpy/auto-methods.pxi":10703
 * 
 *         '''
 *         return GiacMethods['logarithmic_regression'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def logarithmic_regression_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_logarithmic_regression); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10703, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10693
 *         return GiacMethods['log_loss'](self,*args)
 * 
 *      def logarithmic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.logarithmic_regression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10705
 *         return GiacMethods['logarithmic_regression'](self,*args)
 * 
 *      def logarithmic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1715logarithmic_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1714logarithmic_regression_plot, "From Giac's documentation:\n        Help for logarithmic_regression_plot:\n        logarithmic_regression_plot(Lst||Mtrx(A),[Lst])\n        Returns the plot of y=a*ln(x)+b : it is the best logarithm which approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ exponential_regression_plot \n        Ex1:logarithmic_regression_plot([[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex2:logarithmic_regression_plot([1.0,2.0,3.0,4.0],[1.0,4.0,9.0,16.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1715logarithmic_regression_plot = {"logarithmic_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1715logarithmic_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1714logarithmic_regression_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1715logarithmic_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("logarithmic_regression_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "logarithmic_regression_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1714logarithmic_regression_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1714logarithmic_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("logarithmic_regression_plot", 1);

  /* "giacpy/auto-methods.pxi":10715
 * 
 *         '''
 *         return GiacMethods['logarithmic_regression_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def logb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_logarithmic_regression_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10715, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10705
 *         return GiacMethods['logarithmic_regression'](self,*args)
 * 
 *      def logarithmic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.logarithmic_regression_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10717
 *         return GiacMethods['logarithmic_regression_plot'](self,*args)
 * 
 *      def logb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1717logb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1716logb, "From Giac's documentation:\n        Help for logb:\n        logb(Real)\n        Logarithm with base b.\n        See also: 1/ log 2/ log10 \n        Ex1:logb(5,2)\n        Ex2:logb(7,10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1717logb = {"logb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1717logb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1716logb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1717logb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("logb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "logb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1716logb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1716logb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("logb", 1);

  /* "giacpy/auto-methods.pxi":10727
 * 
 *         '''
 *         return GiacMethods['logb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def logistic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_logb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10727, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10717
 *         return GiacMethods['logarithmic_regression_plot'](self,*args)
 * 
 *      def logb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.logb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10729
 *         return GiacMethods['logb'](self,*args)
 * 
 *      def logistic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1719logistic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1718logistic, "From Giac's documentation:\n        Help for logistic:\n        logistic(Real(x),[Real(x0),[Real(L),[Real(k)]]])\n        Returns the logistic function value L/(1+exp(-k*(x-x0))) at point x, where L=k=1 and x0=0 by default.\n        See also: 1/ atan 2/ tanh \n        Ex1:logistic(1.8)\n        Ex2:logistic(0.0,0.5,10,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1719logistic = {"logistic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1719logistic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1718logistic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1719logistic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("logistic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "logistic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1718logistic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1718logistic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("logistic", 1);

  /* "giacpy/auto-methods.pxi":10739
 * 
 *         '''
 *         return GiacMethods['logistic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def logistic_regression(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_logistic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10739, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10729
 *         return GiacMethods['logb'](self,*args)
 * 
 *      def logistic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.logistic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10741
 *         return GiacMethods['logistic'](self,*args)
 * 
 *      def logistic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1721logistic_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1720logistic_regression, "From Giac's documentation:\n        Help for logistic_regression:\n        logistic_regression(Lst(L),Real(x0),Real(y0))\n        Returns y,y',C,y'max,xmax,R : y is a logistic function (sol of y'/y=a*y+b), such that y(x0)=y0 and where [y'(x0),y'(x0+1)...] is the best approximation of L.\n        See also: 1/ polynomial_regression 2/ power_regression 3/ linear_regression \n        Ex1:logistic_regression(evalf([1,2,4,6,8,7,5]),1,2)\n        Ex2:logistic_regression([0.0,1.0,2.0,3.0,4.0],0.0,1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1721logistic_regression = {"logistic_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1721logistic_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1720logistic_regression};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1721logistic_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("logistic_regression (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "logistic_regression", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1720logistic_regression(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1720logistic_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("logistic_regression", 1);

  /* "giacpy/auto-methods.pxi":10751
 * 
 *         '''
 *         return GiacMethods['logistic_regression'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def logistic_regression_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_logistic_regression); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10751, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10741
 *         return GiacMethods['logistic'](self,*args)
 * 
 *      def logistic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.logistic_regression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10753
 *         return GiacMethods['logistic_regression'](self,*args)
 * 
 *      def logistic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1723logistic_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1722logistic_regression_plot, "From Giac's documentation:\n        Help for logistic_regression_plot:\n        logistic_regression_plot(Lst(L),Real(x0),Real(y0))\n        Returns the plot of a logistic function y such that y(x0)=y0 and where [y'(x0),y'(x0+1)...] is the best approximation of L.\n        See also: 1/ polynomial_regression_plot 2/ power_regression_plot 3/ linear_regression_plot \n        Ex1:logistic_regression_plot(evalf([1,2,4,6,8,7,5]),1,2)\n        Ex2:logistic_regression_plot([0.0,1.0,2.0,3.0,4.0],0.0,1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1723logistic_regression_plot = {"logistic_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1723logistic_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1722logistic_regression_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1723logistic_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("logistic_regression_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "logistic_regression_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1722logistic_regression_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1722logistic_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("logistic_regression_plot", 1);

  /* "giacpy/auto-methods.pxi":10763
 * 
 *         '''
 *         return GiacMethods['logistic_regression_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lower(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_logistic_regression_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10763, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10753
 *         return GiacMethods['logistic_regression'](self,*args)
 * 
 *      def logistic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.logistic_regression_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10765
 *         return GiacMethods['logistic_regression_plot'](self,*args)
 * 
 *      def lower(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lower:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1725lower(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1724lower, "From Giac's documentation:\n        Help for lower:\n        lower(Mtrx||Strng)\n        Returns the lower triangular matrix (under the diagonal, included) or writes a string in lowercase.\n        See also: 1/ diag 2/ upper \n        Ex1:lower([[1,2,3],[4,5,6],[7,8,9]])\n        Ex2:lower(\"HELLO\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1725lower = {"lower", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1725lower, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1724lower};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1725lower(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lower (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lower", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1724lower(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1724lower(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lower", 1);

  /* "giacpy/auto-methods.pxi":10775
 * 
 *         '''
 *         return GiacMethods['lower'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lowest_common_ancestor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lower); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10775, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10765
 *         return GiacMethods['logistic_regression_plot'](self,*args)
 * 
 *      def lower(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lower:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lower", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10777
 *         return GiacMethods['lower'](self,*args)
 * 
 *      def lowest_common_ancestor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowest_common_ancestor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1727lowest_common_ancestor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1726lowest_common_ancestor, "From Giac's documentation:\n        Help for lowest_common_ancestor:\n        lowest_common_ancestor(Graph(T),Vrtx(r),Seq(u,v)||Lst([u1,v1],[u2,v2],...))\n        Returns the lowest common ancestor of nodes u and v in a tree graph T with root r, or the list of lowest common ancestors of all pairs [uk,vk].\n        See also: 1/ is_tree 2/ tree_height \n        Ex1: T:=random_tree(30); lowest_common_ancestor(T,15,10,20)\n        Ex2: T:=random_tree(30); lowest_common_ancestor(T,15,[[10,20],[11,19]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1727lowest_common_ancestor = {"lowest_common_ancestor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1727lowest_common_ancestor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1726lowest_common_ancestor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1727lowest_common_ancestor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lowest_common_ancestor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lowest_common_ancestor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1726lowest_common_ancestor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1726lowest_common_ancestor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lowest_common_ancestor", 1);

  /* "giacpy/auto-methods.pxi":10787
 * 
 *         '''
 *         return GiacMethods['lowest_common_ancestor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lowpass(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lowest_common_ancestor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10787, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10777
 *         return GiacMethods['lower'](self,*args)
 * 
 *      def lowest_common_ancestor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowest_common_ancestor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lowest_common_ancestor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10789
 *         return GiacMethods['lowest_common_ancestor'](self,*args)
 * 
 *      def lowpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowpass:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1729lowpass(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1728lowpass, "From Giac's documentation:\n        Help for lowpass:\n        lowpass(Lst(s),Real(c),[Intg(samplerate)])\n        Returns the result of applying a simple first-order lowpass RC filter with cutoff frequency c (the default samplerate is 44100) to the given signal s.\n        See also: 1/ highpass 2/ moving_average \n        Ex1: f:=unapply(periodic(sign(x),x,-1/880,1/880),x):;s:=createwav(apply(f,soundsec(1))):;playsnd(lowpass(s,1000))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1729lowpass = {"lowpass", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1729lowpass, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1728lowpass};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1729lowpass(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lowpass (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lowpass", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1728lowpass(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1728lowpass(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lowpass", 1);

  /* "giacpy/auto-methods.pxi":10798
 * 
 *         '''
 *         return GiacMethods['lowpass'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_assume(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lowpass); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10798, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10789
 *         return GiacMethods['lowest_common_ancestor'](self,*args)
 * 
 *      def lowpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowpass:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lowpass", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10800
 *         return GiacMethods['lowpass'](self,*args)
 * 
 *      def lp_assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_assume:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1731lp_assume(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1730lp_assume, "From Giac's documentation:\n        Help for lp_assume:\n        lp_assume(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1731lp_assume = {"lp_assume", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1731lp_assume, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1730lp_assume};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1731lp_assume(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_assume (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_assume", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1730lp_assume(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1730lp_assume(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_assume", 1);

  /* "giacpy/auto-methods.pxi":10808
 * 
 *         '''
 *         return GiacMethods['lp_assume'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_bestlocalbound(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_assume); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10808, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10800
 *         return GiacMethods['lowpass'](self,*args)
 * 
 *      def lp_assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_assume:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_assume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10810
 *         return GiacMethods['lp_assume'](self,*args)
 * 
 *      def lp_bestlocalbound(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestlocalbound:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1733lp_bestlocalbound(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1732lp_bestlocalbound, "From Giac's documentation:\n        Help for lp_bestlocalbound:\n        lp_bestlocalbound(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1733lp_bestlocalbound = {"lp_bestlocalbound", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1733lp_bestlocalbound, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1732lp_bestlocalbound};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1733lp_bestlocalbound(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_bestlocalbound (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_bestlocalbound", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1732lp_bestlocalbound(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1732lp_bestlocalbound(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_bestlocalbound", 1);

  /* "giacpy/auto-methods.pxi":10818
 * 
 *         '''
 *         return GiacMethods['lp_bestlocalbound'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_bestprojection(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_bestlocalbound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10818, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10810
 *         return GiacMethods['lp_assume'](self,*args)
 * 
 *      def lp_bestlocalbound(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestlocalbound:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_bestlocalbound", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10820
 *         return GiacMethods['lp_bestlocalbound'](self,*args)
 * 
 *      def lp_bestprojection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestprojection:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1735lp_bestprojection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1734lp_bestprojection, "From Giac's documentation:\n        Help for lp_bestprojection:\n        lp_bestprojection(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1735lp_bestprojection = {"lp_bestprojection", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1735lp_bestprojection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1734lp_bestprojection};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1735lp_bestprojection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_bestprojection (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_bestprojection", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1734lp_bestprojection(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1734lp_bestprojection(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_bestprojection", 1);

  /* "giacpy/auto-methods.pxi":10828
 * 
 *         '''
 *         return GiacMethods['lp_bestprojection'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_binary(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_bestprojection); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10828, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10820
 *         return GiacMethods['lp_bestlocalbound'](self,*args)
 * 
 *      def lp_bestprojection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestprojection:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_bestprojection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10830
 *         return GiacMethods['lp_bestprojection'](self,*args)
 * 
 *      def lp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binary:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1737lp_binary(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1736lp_binary, "From Giac's documentation:\n        Help for lp_binary:\n        lp_binary(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1737lp_binary = {"lp_binary", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1737lp_binary, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1736lp_binary};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1737lp_binary(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_binary (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_binary", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1736lp_binary(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1736lp_binary(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_binary", 1);

  /* "giacpy/auto-methods.pxi":10838
 * 
 *         '''
 *         return GiacMethods['lp_binary'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_binaryvariables(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_binary); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10838, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10830
 *         return GiacMethods['lp_bestprojection'](self,*args)
 * 
 *      def lp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binary:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10840
 *         return GiacMethods['lp_binary'](self,*args)
 * 
 *      def lp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binaryvariables:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1739lp_binaryvariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1738lp_binaryvariables, "From Giac's documentation:\n        Help for lp_binaryvariables:\n        lp_binaryvariables(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1739lp_binaryvariables = {"lp_binaryvariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1739lp_binaryvariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1738lp_binaryvariables};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1739lp_binaryvariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_binaryvariables (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_binaryvariables", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1738lp_binaryvariables(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1738lp_binaryvariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_binaryvariables", 1);

  /* "giacpy/auto-methods.pxi":10848
 * 
 *         '''
 *         return GiacMethods['lp_binaryvariables'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_breadthfirst(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_binaryvariables); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10848, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10840
 *         return GiacMethods['lp_binary'](self,*args)
 * 
 *      def lp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binaryvariables:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_binaryvariables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10850
 *         return GiacMethods['lp_binaryvariables'](self,*args)
 * 
 *      def lp_breadthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_breadthfirst:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1741lp_breadthfirst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1740lp_breadthfirst, "From Giac's documentation:\n        Help for lp_breadthfirst:\n        lp_breadthfirst(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1741lp_breadthfirst = {"lp_breadthfirst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1741lp_breadthfirst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1740lp_breadthfirst};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1741lp_breadthfirst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_breadthfirst (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_breadthfirst", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1740lp_breadthfirst(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1740lp_breadthfirst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_breadthfirst", 1);

  /* "giacpy/auto-methods.pxi":10858
 * 
 *         '''
 *         return GiacMethods['lp_breadthfirst'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_depthfirst(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_breadthfirst); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10858, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10850
 *         return GiacMethods['lp_binaryvariables'](self,*args)
 * 
 *      def lp_breadthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_breadthfirst:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_breadthfirst", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10860
 *         return GiacMethods['lp_breadthfirst'](self,*args)
 * 
 *      def lp_depthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthfirst:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1743lp_depthfirst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1742lp_depthfirst, "From Giac's documentation:\n        Help for lp_depthfirst:\n        lp_depthfirst(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1743lp_depthfirst = {"lp_depthfirst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1743lp_depthfirst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1742lp_depthfirst};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1743lp_depthfirst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_depthfirst (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_depthfirst", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1742lp_depthfirst(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1742lp_depthfirst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_depthfirst", 1);

  /* "giacpy/auto-methods.pxi":10868
 * 
 *         '''
 *         return GiacMethods['lp_depthfirst'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_depthlimit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_depthfirst); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10868, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10860
 *         return GiacMethods['lp_breadthfirst'](self,*args)
 * 
 *      def lp_depthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthfirst:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_depthfirst", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10870
 *         return GiacMethods['lp_depthfirst'](self,*args)
 * 
 *      def lp_depthlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthlimit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1745lp_depthlimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1744lp_depthlimit, "From Giac's documentation:\n        Help for lp_depthlimit:\n        lp_depthlimit(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1745lp_depthlimit = {"lp_depthlimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1745lp_depthlimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1744lp_depthlimit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1745lp_depthlimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_depthlimit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_depthlimit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1744lp_depthlimit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1744lp_depthlimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_depthlimit", 1);

  /* "giacpy/auto-methods.pxi":10878
 * 
 *         '''
 *         return GiacMethods['lp_depthlimit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_firstfractional(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_depthlimit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10878, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10870
 *         return GiacMethods['lp_depthfirst'](self,*args)
 * 
 *      def lp_depthlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthlimit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_depthlimit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10880
 *         return GiacMethods['lp_depthlimit'](self,*args)
 * 
 *      def lp_firstfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_firstfractional:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1747lp_firstfractional(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1746lp_firstfractional, "From Giac's documentation:\n        Help for lp_firstfractional:\n        lp_firstfractional(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1747lp_firstfractional = {"lp_firstfractional", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1747lp_firstfractional, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1746lp_firstfractional};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1747lp_firstfractional(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_firstfractional (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_firstfractional", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1746lp_firstfractional(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1746lp_firstfractional(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_firstfractional", 1);

  /* "giacpy/auto-methods.pxi":10888
 * 
 *         '''
 *         return GiacMethods['lp_firstfractional'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_gaptolerance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_firstfractional); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10888, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10880
 *         return GiacMethods['lp_depthlimit'](self,*args)
 * 
 *      def lp_firstfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_firstfractional:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_firstfractional", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10890
 *         return GiacMethods['lp_firstfractional'](self,*args)
 * 
 *      def lp_gaptolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_gaptolerance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1749lp_gaptolerance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1748lp_gaptolerance, "From Giac's documentation:\n        Help for lp_gaptolerance:\n        lp_gaptolerance(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1749lp_gaptolerance = {"lp_gaptolerance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1749lp_gaptolerance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1748lp_gaptolerance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1749lp_gaptolerance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_gaptolerance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_gaptolerance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1748lp_gaptolerance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1748lp_gaptolerance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_gaptolerance", 1);

  /* "giacpy/auto-methods.pxi":10898
 * 
 *         '''
 *         return GiacMethods['lp_gaptolerance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_heuristic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_gaptolerance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10898, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10890
 *         return GiacMethods['lp_firstfractional'](self,*args)
 * 
 *      def lp_gaptolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_gaptolerance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_gaptolerance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10900
 *         return GiacMethods['lp_gaptolerance'](self,*args)
 * 
 *      def lp_heuristic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_heuristic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1751lp_heuristic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1750lp_heuristic, "From Giac's documentation:\n        Help for lp_heuristic:\n        lp_heuristic(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1751lp_heuristic = {"lp_heuristic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1751lp_heuristic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1750lp_heuristic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1751lp_heuristic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_heuristic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_heuristic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1750lp_heuristic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1750lp_heuristic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_heuristic", 1);

  /* "giacpy/auto-methods.pxi":10908
 * 
 *         '''
 *         return GiacMethods['lp_heuristic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_hybrid(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_heuristic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10908, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10900
 *         return GiacMethods['lp_gaptolerance'](self,*args)
 * 
 *      def lp_heuristic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_heuristic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_heuristic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10910
 *         return GiacMethods['lp_heuristic'](self,*args)
 * 
 *      def lp_hybrid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_hybrid:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1753lp_hybrid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1752lp_hybrid, "From Giac's documentation:\n        Help for lp_hybrid:\n        lp_hybrid(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1753lp_hybrid = {"lp_hybrid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1753lp_hybrid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1752lp_hybrid};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1753lp_hybrid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_hybrid (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_hybrid", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1752lp_hybrid(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1752lp_hybrid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_hybrid", 1);

  /* "giacpy/auto-methods.pxi":10918
 * 
 *         '''
 *         return GiacMethods['lp_hybrid'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_integer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_hybrid); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10918, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10910
 *         return GiacMethods['lp_heuristic'](self,*args)
 * 
 *      def lp_hybrid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_hybrid:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_hybrid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10920
 *         return GiacMethods['lp_hybrid'](self,*args)
 * 
 *      def lp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1755lp_integer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1754lp_integer, "From Giac's documentation:\n        Help for lp_integer:\n        lp_integer(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1755lp_integer = {"lp_integer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1755lp_integer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1754lp_integer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1755lp_integer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_integer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_integer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1754lp_integer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1754lp_integer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_integer", 1);

  /* "giacpy/auto-methods.pxi":10928
 * 
 *         '''
 *         return GiacMethods['lp_integer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_integervariables(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_integer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10928, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10920
 *         return GiacMethods['lp_hybrid'](self,*args)
 * 
 *      def lp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_integer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10930
 *         return GiacMethods['lp_integer'](self,*args)
 * 
 *      def lp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integervariables:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1757lp_integervariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1756lp_integervariables, "From Giac's documentation:\n        Help for lp_integervariables:\n        lp_integervariables(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1757lp_integervariables = {"lp_integervariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1757lp_integervariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1756lp_integervariables};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1757lp_integervariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_integervariables (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_integervariables", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1756lp_integervariables(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1756lp_integervariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_integervariables", 1);

  /* "giacpy/auto-methods.pxi":10938
 * 
 *         '''
 *         return GiacMethods['lp_integervariables'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_interiorpoint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_integervariables); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10938, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10930
 *         return GiacMethods['lp_integer'](self,*args)
 * 
 *      def lp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integervariables:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_integervariables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10940
 *         return GiacMethods['lp_integervariables'](self,*args)
 * 
 *      def lp_interiorpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_interiorpoint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1759lp_interiorpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1758lp_interiorpoint, "From Giac's documentation:\n        Help for lp_interiorpoint:\n        lp_interiorpoint(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1759lp_interiorpoint = {"lp_interiorpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1759lp_interiorpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1758lp_interiorpoint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1759lp_interiorpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_interiorpoint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_interiorpoint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1758lp_interiorpoint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1758lp_interiorpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_interiorpoint", 1);

  /* "giacpy/auto-methods.pxi":10948
 * 
 *         '''
 *         return GiacMethods['lp_interiorpoint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_iterationlimit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_interiorpoint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10948, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10940
 *         return GiacMethods['lp_integervariables'](self,*args)
 * 
 *      def lp_interiorpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_interiorpoint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_interiorpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10950
 *         return GiacMethods['lp_interiorpoint'](self,*args)
 * 
 *      def lp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_iterationlimit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1761lp_iterationlimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1760lp_iterationlimit, "From Giac's documentation:\n        Help for lp_iterationlimit:\n        lp_iterationlimit(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1761lp_iterationlimit = {"lp_iterationlimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1761lp_iterationlimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1760lp_iterationlimit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1761lp_iterationlimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_iterationlimit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_iterationlimit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1760lp_iterationlimit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1760lp_iterationlimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_iterationlimit", 1);

  /* "giacpy/auto-methods.pxi":10958
 * 
 *         '''
 *         return GiacMethods['lp_iterationlimit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_lastfractional(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_iterationlimit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10958, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10950
 *         return GiacMethods['lp_interiorpoint'](self,*args)
 * 
 *      def lp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_iterationlimit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_iterationlimit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10960
 *         return GiacMethods['lp_iterationlimit'](self,*args)
 * 
 *      def lp_lastfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_lastfractional:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1763lp_lastfractional(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1762lp_lastfractional, "From Giac's documentation:\n        Help for lp_lastfractional:\n        lp_lastfractional(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1763lp_lastfractional = {"lp_lastfractional", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1763lp_lastfractional, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1762lp_lastfractional};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1763lp_lastfractional(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_lastfractional (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_lastfractional", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1762lp_lastfractional(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1762lp_lastfractional(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_lastfractional", 1);

  /* "giacpy/auto-methods.pxi":10968
 * 
 *         '''
 *         return GiacMethods['lp_lastfractional'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_maxcuts(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_lastfractional); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10968, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10960
 *         return GiacMethods['lp_iterationlimit'](self,*args)
 * 
 *      def lp_lastfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_lastfractional:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_lastfractional", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10970
 *         return GiacMethods['lp_lastfractional'](self,*args)
 * 
 *      def lp_maxcuts(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maxcuts:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1765lp_maxcuts(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1764lp_maxcuts, "From Giac's documentation:\n        Help for lp_maxcuts:\n        lp_maxcuts(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1765lp_maxcuts = {"lp_maxcuts", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1765lp_maxcuts, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1764lp_maxcuts};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1765lp_maxcuts(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_maxcuts (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_maxcuts", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1764lp_maxcuts(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1764lp_maxcuts(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_maxcuts", 1);

  /* "giacpy/auto-methods.pxi":10978
 * 
 *         '''
 *         return GiacMethods['lp_maxcuts'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_maximize(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_maxcuts); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10978, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10970
 *         return GiacMethods['lp_lastfractional'](self,*args)
 * 
 *      def lp_maxcuts(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maxcuts:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_maxcuts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10980
 *         return GiacMethods['lp_maxcuts'](self,*args)
 * 
 *      def lp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maximize:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1767lp_maximize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1766lp_maximize, "From Giac's documentation:\n        Help for lp_maximize:\n        lp_maximize(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1767lp_maximize = {"lp_maximize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1767lp_maximize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1766lp_maximize};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1767lp_maximize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_maximize (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_maximize", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1766lp_maximize(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1766lp_maximize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_maximize", 1);

  /* "giacpy/auto-methods.pxi":10988
 * 
 *         '''
 *         return GiacMethods['lp_maximize'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_method(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_maximize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10988, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10980
 *         return GiacMethods['lp_maxcuts'](self,*args)
 * 
 *      def lp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maximize:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_maximize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":10990
 *         return GiacMethods['lp_maximize'](self,*args)
 * 
 *      def lp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_method:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1769lp_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1768lp_method, "From Giac's documentation:\n        Help for lp_method:\n        lp_method(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1769lp_method = {"lp_method", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1769lp_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1768lp_method};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1769lp_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_method (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_method", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1768lp_method(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1768lp_method(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_method", 1);

  /* "giacpy/auto-methods.pxi":10998
 * 
 *         '''
 *         return GiacMethods['lp_method'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_mostfractional(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_method); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 10998, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 10998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 10998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":10990
 *         return GiacMethods['lp_maximize'](self,*args)
 * 
 *      def lp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_method:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11000
 *         return GiacMethods['lp_method'](self,*args)
 * 
 *      def lp_mostfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_mostfractional:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1771lp_mostfractional(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1770lp_mostfractional, "From Giac's documentation:\n        Help for lp_mostfractional:\n        lp_mostfractional(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1771lp_mostfractional = {"lp_mostfractional", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1771lp_mostfractional, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1770lp_mostfractional};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1771lp_mostfractional(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_mostfractional (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_mostfractional", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1770lp_mostfractional(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1770lp_mostfractional(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_mostfractional", 1);

  /* "giacpy/auto-methods.pxi":11008
 * 
 *         '''
 *         return GiacMethods['lp_mostfractional'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_nodelimit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_mostfractional); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11008, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11000
 *         return GiacMethods['lp_method'](self,*args)
 * 
 *      def lp_mostfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_mostfractional:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_mostfractional", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11010
 *         return GiacMethods['lp_mostfractional'](self,*args)
 * 
 *      def lp_nodelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodelimit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1773lp_nodelimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1772lp_nodelimit, "From Giac's documentation:\n        Help for lp_nodelimit:\n        lp_nodelimit(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1773lp_nodelimit = {"lp_nodelimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1773lp_nodelimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1772lp_nodelimit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1773lp_nodelimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_nodelimit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_nodelimit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1772lp_nodelimit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1772lp_nodelimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_nodelimit", 1);

  /* "giacpy/auto-methods.pxi":11018
 * 
 *         '''
 *         return GiacMethods['lp_nodelimit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_nodeselect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_nodelimit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11018, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11010
 *         return GiacMethods['lp_mostfractional'](self,*args)
 * 
 *      def lp_nodelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodelimit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_nodelimit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11020
 *         return GiacMethods['lp_nodelimit'](self,*args)
 * 
 *      def lp_nodeselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodeselect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1775lp_nodeselect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1774lp_nodeselect, "From Giac's documentation:\n        Help for lp_nodeselect:\n        lp_nodeselect(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1775lp_nodeselect = {"lp_nodeselect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1775lp_nodeselect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1774lp_nodeselect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1775lp_nodeselect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_nodeselect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_nodeselect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1774lp_nodeselect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1774lp_nodeselect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_nodeselect", 1);

  /* "giacpy/auto-methods.pxi":11028
 * 
 *         '''
 *         return GiacMethods['lp_nodeselect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_nonnegative(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_nodeselect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11028, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11020
 *         return GiacMethods['lp_nodelimit'](self,*args)
 * 
 *      def lp_nodeselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodeselect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_nodeselect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11030
 *         return GiacMethods['lp_nodeselect'](self,*args)
 * 
 *      def lp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegative:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1777lp_nonnegative(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1776lp_nonnegative, "From Giac's documentation:\n        Help for lp_nonnegative:\n        lp_nonnegative(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1777lp_nonnegative = {"lp_nonnegative", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1777lp_nonnegative, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1776lp_nonnegative};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1777lp_nonnegative(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_nonnegative (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_nonnegative", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1776lp_nonnegative(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1776lp_nonnegative(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_nonnegative", 1);

  /* "giacpy/auto-methods.pxi":11038
 * 
 *         '''
 *         return GiacMethods['lp_nonnegative'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_nonnegint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_nonnegative); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11038, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11030
 *         return GiacMethods['lp_nodeselect'](self,*args)
 * 
 *      def lp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegative:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_nonnegative", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11040
 *         return GiacMethods['lp_nonnegative'](self,*args)
 * 
 *      def lp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1779lp_nonnegint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1778lp_nonnegint, "From Giac's documentation:\n        Help for lp_nonnegint:\n        lp_nonnegint(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1779lp_nonnegint = {"lp_nonnegint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1779lp_nonnegint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1778lp_nonnegint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1779lp_nonnegint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_nonnegint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_nonnegint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1778lp_nonnegint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1778lp_nonnegint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_nonnegint", 1);

  /* "giacpy/auto-methods.pxi":11048
 * 
 *         '''
 *         return GiacMethods['lp_nonnegint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_presolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_nonnegint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11048, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11040
 *         return GiacMethods['lp_nonnegative'](self,*args)
 * 
 *      def lp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_nonnegint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11050
 *         return GiacMethods['lp_nonnegint'](self,*args)
 * 
 *      def lp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_presolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1781lp_presolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1780lp_presolve, "From Giac's documentation:\n        Help for lp_presolve:\n        lp_presolve(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1781lp_presolve = {"lp_presolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1781lp_presolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1780lp_presolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1781lp_presolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_presolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_presolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1780lp_presolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1780lp_presolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_presolve", 1);

  /* "giacpy/auto-methods.pxi":11058
 * 
 *         '''
 *         return GiacMethods['lp_presolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_pseudocost(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_presolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11058, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11050
 *         return GiacMethods['lp_nonnegint'](self,*args)
 * 
 *      def lp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_presolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_presolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11060
 *         return GiacMethods['lp_presolve'](self,*args)
 * 
 *      def lp_pseudocost(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_pseudocost:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1783lp_pseudocost(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1782lp_pseudocost, "From Giac's documentation:\n        Help for lp_pseudocost:\n        lp_pseudocost(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1783lp_pseudocost = {"lp_pseudocost", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1783lp_pseudocost, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1782lp_pseudocost};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1783lp_pseudocost(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_pseudocost (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_pseudocost", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1782lp_pseudocost(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1782lp_pseudocost(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_pseudocost", 1);

  /* "giacpy/auto-methods.pxi":11068
 * 
 *         '''
 *         return GiacMethods['lp_pseudocost'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_simplex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_pseudocost); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11068, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11060
 *         return GiacMethods['lp_presolve'](self,*args)
 * 
 *      def lp_pseudocost(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_pseudocost:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_pseudocost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11070
 *         return GiacMethods['lp_pseudocost'](self,*args)
 * 
 *      def lp_simplex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_simplex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1785lp_simplex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1784lp_simplex, "From Giac's documentation:\n        Help for lp_simplex:\n        lp_simplex(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1785lp_simplex = {"lp_simplex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1785lp_simplex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1784lp_simplex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1785lp_simplex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_simplex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_simplex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1784lp_simplex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1784lp_simplex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_simplex", 1);

  /* "giacpy/auto-methods.pxi":11078
 * 
 *         '''
 *         return GiacMethods['lp_simplex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_timelimit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_simplex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11078, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11070
 *         return GiacMethods['lp_pseudocost'](self,*args)
 * 
 *      def lp_simplex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_simplex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_simplex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11080
 *         return GiacMethods['lp_simplex'](self,*args)
 * 
 *      def lp_timelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_timelimit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1787lp_timelimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1786lp_timelimit, "From Giac's documentation:\n        Help for lp_timelimit:\n        lp_timelimit(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1787lp_timelimit = {"lp_timelimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1787lp_timelimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1786lp_timelimit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1787lp_timelimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_timelimit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_timelimit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1786lp_timelimit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1786lp_timelimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_timelimit", 1);

  /* "giacpy/auto-methods.pxi":11088
 * 
 *         '''
 *         return GiacMethods['lp_timelimit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_varselect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_timelimit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11088, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11080
 *         return GiacMethods['lp_simplex'](self,*args)
 * 
 *      def lp_timelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_timelimit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_timelimit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11090
 *         return GiacMethods['lp_timelimit'](self,*args)
 * 
 *      def lp_varselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_varselect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1789lp_varselect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1788lp_varselect, "From Giac's documentation:\n        Help for lp_varselect:\n        lp_varselect(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1789lp_varselect = {"lp_varselect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1789lp_varselect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1788lp_varselect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1789lp_varselect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_varselect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_varselect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1788lp_varselect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1788lp_varselect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_varselect", 1);

  /* "giacpy/auto-methods.pxi":11098
 * 
 *         '''
 *         return GiacMethods['lp_varselect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lp_verbose(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_varselect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11098, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11090
 *         return GiacMethods['lp_timelimit'](self,*args)
 * 
 *      def lp_varselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_varselect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_varselect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11100
 *         return GiacMethods['lp_varselect'](self,*args)
 * 
 *      def lp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_verbose:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1791lp_verbose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1790lp_verbose, "From Giac's documentation:\n        Help for lp_verbose:\n        lp_verbose(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1791lp_verbose = {"lp_verbose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1791lp_verbose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1790lp_verbose};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1791lp_verbose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lp_verbose (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lp_verbose", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1790lp_verbose(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1790lp_verbose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lp_verbose", 1);

  /* "giacpy/auto-methods.pxi":11108
 * 
 *         '''
 *         return GiacMethods['lp_verbose'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lpsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lp_verbose); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11108, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11100
 *         return GiacMethods['lp_varselect'](self,*args)
 * 
 *      def lp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_verbose:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lp_verbose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11110
 *         return GiacMethods['lp_verbose'](self,*args)
 * 
 *      def lpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lpsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1793lpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1792lpsolve, "From Giac's documentation:\n        Help for lpsolve:\n        lpsolve(Expr(o),[List(c)],[bounds],[options])\n        Solves a (mixed integer/binary) LP problem in general form.\n        See also: 1/ nlpsolve 2/ fsolve 3/ minimize 4/ maximize 5/ box_constraints \n        Ex1:lpsolve(2x+y-z+4,[x<=1,y>=2,x+3y-z=2,2x-y+z<=8,-x+y<=5])\n        Ex2:lpsolve(-7x+2y,[4x-12y<=20,-x+3y<=3],x=-5..5,y=0..inf,maximize)\n        Ex3:lpsolve(-x-y,[y<=3x+1/2,y<=-5x+2],assume=lp_nonnegative)\n        Ex4:lpsolve(-6x+4y+z,[5x-10y<=20,2z-3y=6,-x+3y<=3],x=1..20,y=0..inf)\n        Ex5:lpsolve(-5x-7y,[7x+y<=35,-x+3y<=6],assume=integer)\n        Ex6:lpsolve(8x1+11x2+6x3+4x4,[5x1+7x2+4x3+3x4<=14],assume=lp_binary,maximize)\n        Ex7:lpsolve(x1+x2,[1867x1+1913x2=3618894],assume=nonnegint,lp_verbose=true)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1793lpsolve = {"lpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1793lpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1792lpsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1793lpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lpsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lpsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1792lpsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1792lpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lpsolve", 1);

  /* "giacpy/auto-methods.pxi":11125
 * 
 *         '''
 *         return GiacMethods['lpsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lsmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lpsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11125, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11110
 *         return GiacMethods['lp_verbose'](self,*args)
 * 
 *      def lpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lpsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lpsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11127
 *         return GiacMethods['lpsolve'](self,*args)
 * 
 *      def lsmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1795lsmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1794lsmod, "From Giac's documentation:\n        Help for lsmod:\n        lsmod(NULL)\n        Displays the installed dynamic libraries.\n        See also: 1/ insmod 2/ rmmod \n        Ex1:lsmod()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1795lsmod = {"lsmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1795lsmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1794lsmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1795lsmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lsmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lsmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1794lsmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1794lsmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lsmod", 1);

  /* "giacpy/auto-methods.pxi":11136
 * 
 *         '''
 *         return GiacMethods['lsmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lsq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lsmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11136, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11127
 *         return GiacMethods['lpsolve'](self,*args)
 * 
 *      def lsmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lsmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11138
 *         return GiacMethods['lsmod'](self,*args)
 * 
 *      def lsq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1797lsq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1796lsq, "From Giac's documentation:\n        Help for lsq:\n        lsq(Mtrx(A),(Mtrx || Vect)(B))\n        Returns the vector (resp matrix) X which is the minimum of the euclidean (resp Frobenius) norm of A*X-B corresponding to the linear system A*X=B when B is a vector (resp matrix).\n        See also: 1/ lu 2/ QR \n        Ex1:lsq([[1,2],[3,4]],[5,11])\n        Ex2:lsq([[1,2],[3,4]],[[5,-1],[11,-1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1797lsq = {"lsq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1797lsq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1796lsq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1797lsq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lsq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lsq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1796lsq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1796lsq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lsq", 1);

  /* "giacpy/auto-methods.pxi":11148
 * 
 *         '''
 *         return GiacMethods['lsq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lu(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lsq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11148, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11138
 *         return GiacMethods['lsmod'](self,*args)
 * 
 *      def lsq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lsq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11150
 *         return GiacMethods['lsq'](self,*args)
 * 
 *      def lu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1799lu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1798lu, "From Giac's documentation:\n        Help for lu:\n        lu(Mtrx)\n        For a numerical matrix A, returns p permutation, L and U such that PA=LU (P=permu2mat(p)).\n        See also: 1/ qr 2/ cholesky 3/ LU \n        Ex1:lu([[1,2],[3,4]])\n        Ex2:lu([[6,12,18],[5,14,31],[3,8,18]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1799lu = {"lu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1799lu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1798lu};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1799lu(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lu (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lu", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1798lu(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1798lu(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lu", 1);

  /* "giacpy/auto-methods.pxi":11160
 * 
 *         '''
 *         return GiacMethods['lu'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def lvar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lu); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11160, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11150
 *         return GiacMethods['lsq'](self,*args)
 * 
 *      def lu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lu:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11162
 *         return GiacMethods['lu'](self,*args)
 * 
 *      def lvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lvar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1801lvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1800lvar, "From Giac's documentation:\n        Help for lvar:\n        lvar(Expr)\n        List of variables of an object (with rational dependence).\n        See also: 1/ lname 2/ has \n        Ex1:lvar(exp(x)*2*sin(y))\n        Ex2:lvar(exp(x)*2*sin(y)+ln(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1801lvar = {"lvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1801lvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1800lvar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1801lvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lvar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "lvar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1800lvar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1800lvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lvar", 1);

  /* "giacpy/auto-methods.pxi":11172
 * 
 *         '''
 *         return GiacMethods['lvar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mRow(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_lvar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11172, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11162
 *         return GiacMethods['lu'](self,*args)
 * 
 *      def lvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lvar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.lvar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11174
 *         return GiacMethods['lvar'](self,*args)
 * 
 *      def mRow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRow:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1803mRow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1802mRow, "From Giac's documentation:\n        Help for mRow:\n        mRow(Expr(Xpr),Mtrx(A),Intg(n1))\n        Multiplies row n1 of the matrix A by Xpr.\n        See also: 1/ rowAdd 2/ mRowAdd \n        Ex1:mRow(12,[[1,2],[3,4],[5,6]],0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1803mRow = {"mRow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1803mRow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1802mRow};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1803mRow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mRow (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mRow", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1802mRow(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1802mRow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mRow", 1);

  /* "giacpy/auto-methods.pxi":11183
 * 
 *         '''
 *         return GiacMethods['mRow'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mRowAdd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mRow); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11183, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11174
 *         return GiacMethods['lvar'](self,*args)
 * 
 *      def mRow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRow:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mRow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11185
 *         return GiacMethods['mRow'](self,*args)
 * 
 *      def mRowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRowAdd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1805mRowAdd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1804mRowAdd, "From Giac's documentation:\n        Help for mRowAdd:\n        mRowAdd(Expr(Xpr),Mtrx(A),Intg(n1),Intg(n2))\n        Multiplies row n1 of the matrix A by Xpr, then adds it to the row n2.\n        See also: 1/ rowAdd 2/ mRow \n        Ex1:mRowAdd(12,[[1,2],[3,4],[5,6]],0,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1805mRowAdd = {"mRowAdd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1805mRowAdd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1804mRowAdd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1805mRowAdd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mRowAdd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mRowAdd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1804mRowAdd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1804mRowAdd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mRowAdd", 1);

  /* "giacpy/auto-methods.pxi":11194
 * 
 *         '''
 *         return GiacMethods['mRowAdd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def magenta(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mRowAdd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11194, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11185
 *         return GiacMethods['mRow'](self,*args)
 * 
 *      def mRowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRowAdd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mRowAdd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11196
 *         return GiacMethods['mRowAdd'](self,*args)
 * 
 *      def magenta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for magenta:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1807magenta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1806magenta, "From Giac's documentation:\n        Help for magenta:\n        magenta(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1807magenta = {"magenta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1807magenta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1806magenta};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1807magenta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("magenta (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "magenta", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1806magenta(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1806magenta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("magenta", 1);

  /* "giacpy/auto-methods.pxi":11206
 * 
 *         '''
 *         return GiacMethods['magenta'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def make_directed(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_magenta); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11206, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11196
 *         return GiacMethods['mRowAdd'](self,*args)
 * 
 *      def magenta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for magenta:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.magenta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11208
 *         return GiacMethods['magenta'](self,*args)
 * 
 *      def make_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_directed:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1809make_directed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1808make_directed, "From Giac's documentation:\n        Help for make_directed:\n        make_directed(Graph(G),[Mrtx(A)])\n        Returns a copy of an undirected graph G in which every edge is converted to a pair of arcs [with weights specified by matrix A].\n        See also: 1/ is_directed 2/ make_weighted 3/ underlying_graph \n        Ex1:make_directed(cycle_graph(4),[[0,0,0,1],[2,0,1,3],[0,1,0,4],[5,0,4,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1809make_directed = {"make_directed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1809make_directed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1808make_directed};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1809make_directed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_directed (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "make_directed", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1808make_directed(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1808make_directed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_directed", 1);

  /* "giacpy/auto-methods.pxi":11217
 * 
 *         '''
 *         return GiacMethods['make_directed'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def make_symbol(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_make_directed); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11217, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11208
 *         return GiacMethods['magenta'](self,*args)
 * 
 *      def make_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_directed:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.make_directed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11219
 *         return GiacMethods['make_directed'](self,*args)
 * 
 *      def make_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_symbol:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1811make_symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1810make_symbol, "From Giac's documentation:\n        Help for make_symbol:\n        make_symbol(Strng(str))\n        Returns a symbol with name str.\n        See also: 1/ symbol_array \n        Ex1:make_symbol(\"abc\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1811make_symbol = {"make_symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1811make_symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1810make_symbol};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1811make_symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_symbol (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "make_symbol", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1810make_symbol(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1810make_symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_symbol", 1);

  /* "giacpy/auto-methods.pxi":11228
 * 
 *         '''
 *         return GiacMethods['make_symbol'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def make_weighted(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_make_symbol); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11228, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11219
 *         return GiacMethods['make_directed'](self,*args)
 * 
 *      def make_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_symbol:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.make_symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11230
 *         return GiacMethods['make_symbol'](self,*args)
 * 
 *      def make_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_weighted:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1813make_weighted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1812make_weighted, "From Giac's documentation:\n        Help for make_weighted:\n        make_weighted(Graph(G),[Mrtx(M)])\n        Returns a copy of G with edge/arc weights set as specified by matrix M. If M is omitted, then a square matrix of ones is used. If G is undirected, then M is assumed to be symmetric.\n        See also: 1/ get_edge_weight 2/ is_weighted 3/ make_directed 4/ set_edge_weight 5/ underlying_graph 6/ weight_matrix \n        Ex1:make_weighted(cycle_graph(3),[[0,2,3],[2,0,1],[3,1,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1813make_weighted = {"make_weighted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1813make_weighted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1812make_weighted};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1813make_weighted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_weighted (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "make_weighted", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1812make_weighted(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1812make_weighted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_weighted", 1);

  /* "giacpy/auto-methods.pxi":11239
 * 
 *         '''
 *         return GiacMethods['make_weighted'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def makelist(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_make_weighted); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11239, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11230
 *         return GiacMethods['make_symbol'](self,*args)
 * 
 *      def make_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_weighted:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.make_weighted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11241
 *         return GiacMethods['make_weighted'](self,*args)
 * 
 *      def makelist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makelist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1815makelist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1814makelist, "From Giac's documentation:\n        Help for makelist:\n        makelist(Fnc,InitVal,FinalVal,StepVal)\n        Returns a list made with a function or with a constant.\n        See also: 1/ seq 2/ range 3/ makemat 4/ $ \n        Ex1:makelist(x->x^2,1,10,2)\n        Ex2:makelist(4,1,10)\n        Ex3:makelist(4,5,10)\n        Ex4:makelist(x->ifte(x<5,\"A\",\"B\"),1,10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1815makelist = {"makelist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1815makelist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1814makelist};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1815makelist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makelist (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "makelist", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1814makelist(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1814makelist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makelist", 1);

  /* "giacpy/auto-methods.pxi":11253
 * 
 *         '''
 *         return GiacMethods['makelist'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def makemat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_makelist); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11253, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11241
 *         return GiacMethods['make_weighted'](self,*args)
 * 
 *      def makelist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makelist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.makelist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11255
 *         return GiacMethods['makelist'](self,*args)
 * 
 *      def makemat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makemat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1817makemat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1816makemat, "From Giac's documentation:\n        Help for makemat:\n        makemat(Fnct(f),RowsNumb,ColsNumb)\n        Creates a matrix.\n        See also: 1/ matrix \n        Ex1:makemat((j,k)->j+k,3,2)\n        Ex2:makemat((j,k)->1/(j+k+1),2,3)\n        Ex3:makemat(sqrt(2),2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1817makemat = {"makemat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1817makemat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1816makemat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1817makemat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makemat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "makemat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1816makemat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1816makemat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makemat", 1);

  /* "giacpy/auto-methods.pxi":11266
 * 
 *         '''
 *         return GiacMethods['makemat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def makesuite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_makemat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11266, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11255
 *         return GiacMethods['makelist'](self,*args)
 * 
 *      def makemat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makemat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.makemat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11268
 *         return GiacMethods['makemat'](self,*args)
 * 
 *      def makesuite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makesuite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1819makesuite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1818makesuite, "From Giac's documentation:\n        Help for makesuite:\n        makesuite(Vect||Lst)\n        Returns a sequence made with a vector.\n        See also: 1/ makevector 2/ op \n        Ex1:makesuite([1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1819makesuite = {"makesuite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1819makesuite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1818makesuite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1819makesuite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makesuite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "makesuite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1818makesuite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1818makesuite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makesuite", 1);

  /* "giacpy/auto-methods.pxi":11277
 * 
 *         '''
 *         return GiacMethods['makesuite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def makevector(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_makesuite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11277, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11268
 *         return GiacMethods['makemat'](self,*args)
 * 
 *      def makesuite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makesuite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.makesuite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11279
 *         return GiacMethods['makesuite'](self,*args)
 * 
 *      def makevector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makevector:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1821makevector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1820makevector, "From Giac's documentation:\n        Help for makevector:\n        makevector(Seq)\n        Returns a vector made with a sequence.\n        See also: 1/ makesuite \n        Ex1:makevector(1,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1821makevector = {"makevector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1821makevector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1820makevector};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1821makevector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makevector (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "makevector", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1820makevector(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1820makevector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("makevector", 1);

  /* "giacpy/auto-methods.pxi":11288
 * 
 *         '''
 *         return GiacMethods['makevector'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def map(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_makevector); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11288, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11279
 *         return GiacMethods['makesuite'](self,*args)
 * 
 *      def makevector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makevector:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.makevector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11290
 *         return GiacMethods['makevector'](self,*args)
 * 
 *      def map(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for map:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1823map(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1822map, "From Giac's documentation:\n        Help for map:\n        map(Lst(l),Fnc(f))\n        Applies the function f at the elements of the list l or at a polynomial of internal format.\n        See also: 1/ apply 2/ set 3/ unapply \n        Ex1:map([1,2,3],x->x^3)\n        Ex2:map([1,2,3],unapply(x^3,x))\n        Ex3:map(%%%{1,[2,0]%%%}+%%%{2,[1,1]%%%},(a,b,c)->a*(b+2*c))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1823map = {"map", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1823map, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1822map};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1823map(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "map", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1822map(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1822map(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map", 1);

  /* "giacpy/auto-methods.pxi":11301
 * 
 *         '''
 *         return GiacMethods['map'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maple2mupad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_map); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11301, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11290
 *         return GiacMethods['makevector'](self,*args)
 * 
 *      def map(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for map:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.map", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11303
 *         return GiacMethods['map'](self,*args)
 * 
 *      def maple2mupad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2mupad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1825maple2mupad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1824maple2mupad, "From Giac's documentation:\n        Help for maple2mupad:\n        maple2mupad(Str(\"Name_Maplefile\"),Str(\"Name_Mupadfile\"))\n        maple2mupad(\"file1\",\"file2\") translates file1(Maple) to file2(MuPAD).\n        See also: 1/ maple2xcas \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1825maple2mupad = {"maple2mupad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1825maple2mupad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1824maple2mupad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1825maple2mupad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maple2mupad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maple2mupad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1824maple2mupad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1824maple2mupad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maple2mupad", 1);

  /* "giacpy/auto-methods.pxi":11311
 * 
 *         '''
 *         return GiacMethods['maple2mupad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maple2xcas(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maple2mupad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11311, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11303
 *         return GiacMethods['map'](self,*args)
 * 
 *      def maple2mupad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2mupad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maple2mupad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11313
 *         return GiacMethods['maple2mupad'](self,*args)
 * 
 *      def maple2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2xcas:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1827maple2xcas(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1826maple2xcas, "From Giac's documentation:\n        Help for maple2xcas:\n        maple2xcas(Str(\"NameMapleFile\"),Str(\"NameXcasFile\"))\n        maple2xcas(\"file1\",\"file2\") translates file1(Maple) to file2(Xcas).\n        See also: 1/ maple2mupad \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1827maple2xcas = {"maple2xcas", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1827maple2xcas, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1826maple2xcas};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1827maple2xcas(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maple2xcas (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maple2xcas", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1826maple2xcas(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1826maple2xcas(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maple2xcas", 1);

  /* "giacpy/auto-methods.pxi":11321
 * 
 *         '''
 *         return GiacMethods['maple2xcas'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maple_ifactors(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maple2xcas); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11321, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11313
 *         return GiacMethods['maple2mupad'](self,*args)
 * 
 *      def maple2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2xcas:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maple2xcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11323
 *         return GiacMethods['maple2xcas'](self,*args)
 * 
 *      def maple_ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_ifactors:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1829maple_ifactors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1828maple_ifactors, "From Giac's documentation:\n        Help for maple_ifactors:\n        maple_ifactors(Intg(n))\n        Returns 1 or -1 for the sign and the prime factors with their multiplicity of n in a matrix, such as ifactors in Maple.\n        See also: 1/ ifactors \n        Ex1:maple_ifactors(120)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1829maple_ifactors = {"maple_ifactors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1829maple_ifactors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1828maple_ifactors};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1829maple_ifactors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maple_ifactors (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maple_ifactors", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1828maple_ifactors(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1828maple_ifactors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maple_ifactors", 1);

  /* "giacpy/auto-methods.pxi":11332
 * 
 *         '''
 *         return GiacMethods['maple_ifactors'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maple_mode(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maple_ifactors); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11332, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11323
 *         return GiacMethods['maple2xcas'](self,*args)
 * 
 *      def maple_ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_ifactors:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maple_ifactors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11334
 *         return GiacMethods['maple_ifactors'](self,*args)
 * 
 *      def maple_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_mode:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1831maple_mode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1830maple_mode, "From Giac's documentation:\n        Help for maple_mode:\n        maple_mode(Intg(0) or 1 or 2 or 3)\n        Switches to mode Xcas (0), Maple (1), Mupad (2), TI89 (3).\n        See also: 1/ python_compat \n        Ex1:maple_mode(1)\n        Ex2:maple_mode(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1831maple_mode = {"maple_mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1831maple_mode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1830maple_mode};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1831maple_mode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maple_mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maple_mode", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1830maple_mode(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1830maple_mode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maple_mode", 1);

  /* "giacpy/auto-methods.pxi":11344
 * 
 *         '''
 *         return GiacMethods['maple_mode'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def markov(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maple_mode); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11344, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11334
 *         return GiacMethods['maple_ifactors'](self,*args)
 * 
 *      def maple_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_mode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maple_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11346
 *         return GiacMethods['maple_mode'](self,*args)
 * 
 *      def markov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for markov:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1833markov(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1832markov, "From Giac's documentation:\n        Help for markov:\n        markov(Mtrx(M),[Real(eps)])\n        Computation of the proper elements of a Markov chain transition matrix M, returns the list of sequence of positive recurrent states, the list of corresponding invariant probabilities, the list of other strongly connected components, the list of probabilities to end up in the sequence of recurrent states.\n        See also: 1/ randmarkov 2/ plotproba \n        Ex1:markov([[0,0,1/2,0,1/2],[0,0,1,0,0],[1/4,1/4,0,1/4,1/4],[0,0,1/2,0,1/2],[0,0,0,0,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1833markov = {"markov", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1833markov, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1832markov};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1833markov(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("markov (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "markov", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1832markov(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1832markov(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("markov", 1);

  /* "giacpy/auto-methods.pxi":11355
 * 
 *         '''
 *         return GiacMethods['markov'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mat2list(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_markov); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11355, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11346
 *         return GiacMethods['maple_mode'](self,*args)
 * 
 *      def markov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for markov:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.markov", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11357
 *         return GiacMethods['markov'](self,*args)
 * 
 *      def mat2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mat2list:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1835mat2list(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1834mat2list, "From Giac's documentation:\n        Help for mat2list:\n        mat2list(Mtrx)\n        Returns the list of the terms of the matrix.\n        See also: 1/ list2mat 2/ flatten \n        Ex1:mat2list([[1,8],[4,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1835mat2list = {"mat2list", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1835mat2list, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1834mat2list};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1835mat2list(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mat2list (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mat2list", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1834mat2list(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1834mat2list(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mat2list", 1);

  /* "giacpy/auto-methods.pxi":11366
 * 
 *         '''
 *         return GiacMethods['mat2list'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mathml(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mat2list); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11366, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11357
 *         return GiacMethods['markov'](self,*args)
 * 
 *      def mat2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mat2list:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mat2list", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11368
 *         return GiacMethods['mat2list'](self,*args)
 * 
 *      def mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mathml:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1837mathml(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1836mathml, "From Giac's documentation:\n        Help for mathml:\n        mathml(Expr)\n        Converts the expression into a string to display maths for the web.\n        See also: 1/ export_mathml 2/ latex \n        Ex1:mathml(1/2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1837mathml = {"mathml", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1837mathml, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1836mathml};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1837mathml(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mathml (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mathml", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1836mathml(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1836mathml(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mathml", 1);

  /* "giacpy/auto-methods.pxi":11377
 * 
 *         '''
 *         return GiacMethods['mathml'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def matpow(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mathml); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11377, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11368
 *         return GiacMethods['mat2list'](self,*args)
 * 
 *      def mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mathml:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mathml", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11379
 *         return GiacMethods['mathml'](self,*args)
 * 
 *      def matpow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matpow:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1839matpow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1838matpow, "From Giac's documentation:\n        Help for matpow:\n        matpow(Mtrx,Intg(n))\n        Calculates the nth power of a matrix by jordanization.\n        See also: 1/ &^ 2/ ^ \n        Ex1:matpow([[1,2],[3,4]],n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1839matpow = {"matpow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1839matpow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1838matpow};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1839matpow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matpow (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "matpow", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1838matpow(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1838matpow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matpow", 1);

  /* "giacpy/auto-methods.pxi":11388
 * 
 *         '''
 *         return GiacMethods['matpow'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def matrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_matpow); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11388, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11379
 *         return GiacMethods['mathml'](self,*args)
 * 
 *      def matpow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matpow:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.matpow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11390
 *         return GiacMethods['matpow'](self,*args)
 * 
 *      def matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1841matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1840matrix, "From Giac's documentation:\n        Help for matrix:\n        matrix(Intg(p),Intg(q),(Fnc(f) or Val(a)))\n        Makes a matrix m(j,k) with p rows and q cols, m(j,k)=f(j,k) or m(j,k)=a : the index start at 0 or 1 according to the mode (Xcas or Maple) (or option of apply) or make a matrix with a table.\n        See also: 1/ makemat 2/ makelist 3/ apply \n        Ex1:matrix(2,3,(j,k)->1/(j+k+1))\n        Ex2:matrix(3,2,(j,k)->j+k)\n        Ex3:matrix(2,3,4)\n        Ex4:  A[0..2,0..2]:=1;A[0..1,1..2]:=2;a:=matrix(A) \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1841matrix = {"matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1841matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1840matrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1841matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "matrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1840matrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1840matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matrix", 1);

  /* "giacpy/auto-methods.pxi":11402
 * 
 *         '''
 *         return GiacMethods['matrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def matrix_norm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_matrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11402, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11390
 *         return GiacMethods['matpow'](self,*args)
 * 
 *      def matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11404
 *         return GiacMethods['matrix'](self,*args)
 * 
 *      def matrix_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix_norm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1843matrix_norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1842matrix_norm, "From Giac's documentation:\n        Help for matrix_norm:\n        matrix_norm(Mtrx,[2]||[inf])\n        Matrix norm induced by l1norm or by l2norm or by linfinty norm.\n        See also: 1/ l1norm 2/ l2 norm 3/ linfnorm 4/ frobenius_norm \n        Ex1:matrix_norm([[1,2,3],[3,-9,6],[4,5,6]])\n        Ex2:matrix_norm([[1,2,3],[3,-9,6],[4,5,6]],1)\n        Ex3:matrix_norm([[1,2,3],[3,-9,6],[4,5,6]],2)\n        Ex4:matrix_norm([[1,2,3],[3,-9,6],[4,5,6]],inf)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1843matrix_norm = {"matrix_norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1843matrix_norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1842matrix_norm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1843matrix_norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("matrix_norm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "matrix_norm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1842matrix_norm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1842matrix_norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("matrix_norm", 1);

  /* "giacpy/auto-methods.pxi":11416
 * 
 *         '''
 *         return GiacMethods['matrix_norm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def max(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_matrix_norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11416, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11404
 *         return GiacMethods['matrix'](self,*args)
 * 
 *      def matrix_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix_norm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.matrix_norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11418
 *         return GiacMethods['matrix_norm'](self,*args)
 * 
 *      def max(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for max:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1845max(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1844max, "From Giac's documentation:\n        Help for max:\n        max(Seq||Lst)\n        Maximum of elements of a sequence or a list of reals.\n        See also: 1/ min \n        Ex1:max(25,35)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1845max = {"max", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1845max, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1844max};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1845max(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("max (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "max", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1844max(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1844max(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("max", 1);

  /* "giacpy/auto-methods.pxi":11427
 * 
 *         '''
 *         return GiacMethods['max'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maxflow(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_max); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11427, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11418
 *         return GiacMethods['matrix_norm'](self,*args)
 * 
 *      def max(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for max:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.max", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11429
 *         return GiacMethods['max'](self,*args)
 * 
 *      def maxflow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxflow:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1847maxflow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1846maxflow, "From Giac's documentation:\n        Help for maxflow:\n        maxflow(Graph(G),Vrtx(s),Vrtx(t))\n        Returns the optimal value for a max flow problem in a network G with source s and sink t along with an optimal flow (as a matrix).\n        See also: 1/ minimum_cut \n        Ex1:maxflow(digraph(%{[[1,2],2],[[2,3],4],[[3,4],3],[[1,5],3],[[5,2],1],[[5,4],2]%}),1,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1847maxflow = {"maxflow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1847maxflow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1846maxflow};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1847maxflow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maxflow (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maxflow", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1846maxflow(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1846maxflow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maxflow", 1);

  /* "giacpy/auto-methods.pxi":11438
 * 
 *         '''
 *         return GiacMethods['maxflow'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maximal_independent_set(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maxflow); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11438, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11429
 *         return GiacMethods['max'](self,*args)
 * 
 *      def maxflow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxflow:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maxflow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11440
 *         return GiacMethods['maxflow'](self,*args)
 * 
 *      def maximal_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximal_independent_set:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1849maximal_independent_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1848maximal_independent_set, "From Giac's documentation:\n        Help for maximal_independent_set:\n        maximal_independent_set(Graph(G))\n        Returns a maximal set of mutually independent (non-adjacent) vertices in G.\n        See also: 1/ maximum_independent_set \n        Ex1:maximal_independent_set(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1849maximal_independent_set = {"maximal_independent_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1849maximal_independent_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1848maximal_independent_set};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1849maximal_independent_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maximal_independent_set (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maximal_independent_set", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1848maximal_independent_set(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1848maximal_independent_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maximal_independent_set", 1);

  /* "giacpy/auto-methods.pxi":11449
 * 
 *         '''
 *         return GiacMethods['maximal_independent_set'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maximize(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maximal_independent_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11449, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11440
 *         return GiacMethods['maxflow'](self,*args)
 * 
 *      def maximal_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximal_independent_set:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maximal_independent_set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11451
 *         return GiacMethods['maximal_independent_set'](self,*args)
 * 
 *      def maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximize:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1851maximize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1850maximize, "From Giac's documentation:\n        Help for maximize:\n        maximize(Expr,[Constr],Vars,[Options])\n        Finds the global maximum of a function.\n        See also: 1/ minimize \n        Ex1:maximize(sin(x),[x=0..4])\n        Ex2:maximize(x^4-x^2,x=-3..3,coordinates)\n        Ex3:maximize(piecewise(x<=-2,x+6,x<=1,x^2,3/2-x/2),x=-3..2)\n        Ex4:maximize(x^2-3x+y^2+3y+3,[x=2..4,y=-4..-2],point)\n        Ex5:maximize(2x^2-y^2+6y,x^2+y^2<=16,[x,y])\n        Ex6:maximize(sqrt(x^2+y^2)-z,[x^2+y^2<=16,x+y+z=10],[x,y,z])\n        Ex7:maximize((1+x^2+3y+5x-4*x*y)/(1+x^2+y^2),x^2/4+y^2/3=9,[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1851maximize = {"maximize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1851maximize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1850maximize};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1851maximize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maximize (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maximize", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1850maximize(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1850maximize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maximize", 1);

  /* "giacpy/auto-methods.pxi":11466
 * 
 *         '''
 *         return GiacMethods['maximize'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maximum_clique(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maximize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11466, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11451
 *         return GiacMethods['maximal_independent_set'](self,*args)
 * 
 *      def maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximize:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maximize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11468
 *         return GiacMethods['maximize'](self,*args)
 * 
 *      def maximum_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_clique:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1853maximum_clique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1852maximum_clique, "From Giac's documentation:\n        Help for maximum_clique:\n        maximum_clique(Graph(G))\n        Returns the maximum clique in an undirected graph G as a list of vertices.\n        See also: 1/ clique_number 2/ is_clique 3/ maximum_independent_set \n        Ex1:maximum_clique(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1853maximum_clique = {"maximum_clique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1853maximum_clique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1852maximum_clique};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1853maximum_clique(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maximum_clique (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maximum_clique", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1852maximum_clique(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1852maximum_clique(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maximum_clique", 1);

  /* "giacpy/auto-methods.pxi":11477
 * 
 *         '''
 *         return GiacMethods['maximum_clique'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maximum_degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maximum_clique); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11477, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11468
 *         return GiacMethods['maximize'](self,*args)
 * 
 *      def maximum_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_clique:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maximum_clique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11479
 *         return GiacMethods['maximum_clique'](self,*args)
 * 
 *      def maximum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1855maximum_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1854maximum_degree, "From Giac's documentation:\n        Help for maximum_degree:\n        maximum_degree(Graph(G))\n        Returns the largest degree of a vertex in G.\n        See also: 1/ minimum_degree 2/ vertex_degree \n        Ex1:maximum_degree(digraph(trail(1,2,3,4,5,6,4,7,8,2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1855maximum_degree = {"maximum_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1855maximum_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1854maximum_degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1855maximum_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maximum_degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maximum_degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1854maximum_degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1854maximum_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maximum_degree", 1);

  /* "giacpy/auto-methods.pxi":11488
 * 
 *         '''
 *         return GiacMethods['maximum_degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maximum_independent_set(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maximum_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11488, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11479
 *         return GiacMethods['maximum_clique'](self,*args)
 * 
 *      def maximum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maximum_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11490
 *         return GiacMethods['maximum_degree'](self,*args)
 * 
 *      def maximum_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_independent_set:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1857maximum_independent_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1856maximum_independent_set, "From Giac's documentation:\n        Help for maximum_independent_set:\n        maximum_independent_set(Graph(G))\n        Returns a maximum independent vertex set in G.\n        See also: 1/ clique_number 2/ graph_complement 3/ independence_number 4/ maximum_clique \n        Ex1:maximum_independent_set(complete_graph(3,4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1857maximum_independent_set = {"maximum_independent_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1857maximum_independent_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1856maximum_independent_set};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1857maximum_independent_set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maximum_independent_set (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maximum_independent_set", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1856maximum_independent_set(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1856maximum_independent_set(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maximum_independent_set", 1);

  /* "giacpy/auto-methods.pxi":11499
 * 
 *         '''
 *         return GiacMethods['maximum_independent_set'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maximum_matching(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maximum_independent_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11499, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11490
 *         return GiacMethods['maximum_degree'](self,*args)
 * 
 *      def maximum_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_independent_set:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maximum_independent_set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11501
 *         return GiacMethods['maximum_independent_set'](self,*args)
 * 
 *      def maximum_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_matching:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1859maximum_matching(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1858maximum_matching, "From Giac's documentation:\n        Help for maximum_matching:\n        maximum_matching(Graph(G))\n        Returns the list of edges representing a maximum matching in G.\n        See also: 1/ maximum_independent_set \n        Ex1: G:=graph(\"soccerball\"); draw_graph(highlight_edges(G,maximum_matching(G)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1859maximum_matching = {"maximum_matching", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1859maximum_matching, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1858maximum_matching};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1859maximum_matching(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maximum_matching (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maximum_matching", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1858maximum_matching(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1858maximum_matching(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maximum_matching", 1);

  /* "giacpy/auto-methods.pxi":11510
 * 
 *         '''
 *         return GiacMethods['maximum_matching'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def maxnorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maximum_matching); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11510, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11501
 *         return GiacMethods['maximum_independent_set'](self,*args)
 * 
 *      def maximum_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_matching:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maximum_matching", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11512
 *         return GiacMethods['maximum_matching'](self,*args)
 * 
 *      def maxnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxnorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1861maxnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1860maxnorm, "From Giac's documentation:\n        Help for maxnorm:\n        maxnorm(Vect or Mtrx)\n        Norm with the max of a vector (or of a matrix): maxnorm([x1,x2,..,xn])=max(|x1|,..,|xn|).\n        See also: 1/ l2norm 2/ l1norm \n        Ex1:maxnorm([1,2])\n        Ex2:maxnorm([1,2,3,-4])\n        Ex3:maxnorm([[1,2],[3,-4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1861maxnorm = {"maxnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1861maxnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1860maxnorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1861maxnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maxnorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "maxnorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1860maxnorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1860maxnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maxnorm", 1);

  /* "giacpy/auto-methods.pxi":11523
 * 
 *         '''
 *         return GiacMethods['maxnorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mean(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_maxnorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11523, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11512
 *         return GiacMethods['maximum_matching'](self,*args)
 * 
 *      def maxnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxnorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.maxnorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11525
 *         return GiacMethods['maxnorm'](self,*args)
 * 
 *      def mean(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mean:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1863mean(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1862mean, "From Giac's documentation:\n        Help for mean:\n        mean(Lst||Mtrx,[Lst])\n        Mean of a list with the second argument as weight or of the columns of a matrix.\n        See also: 1/ stddev \n        Ex1:mean([1,2,3])\n        Ex2:mean([1,2,3],[1,2,3])\n        Ex3:mean([[1,2,3],[1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1863mean = {"mean", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1863mean, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1862mean};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1863mean(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mean (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mean", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1862mean(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1862mean(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mean", 1);

  /* "giacpy/auto-methods.pxi":11536
 * 
 *         '''
 *         return GiacMethods['mean'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def median(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mean); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11536, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11525
 *         return GiacMethods['maxnorm'](self,*args)
 * 
 *      def mean(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mean:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mean", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11538
 *         return GiacMethods['mean'](self,*args)
 * 
 *      def median(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1865median(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1864median, "From Giac's documentation:\n        Help for median:\n        median(Lst||Mtrx,[Lst])\n        Returns the median of a list with the second argument as weight or of the columns of a matrix.\n        See also: 1/ quartiles \n        Ex1:median([1,2,3,5,10,4])\n        Ex2:median([1,2,3,5,10,4],[1,2,3,1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1865median = {"median", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1865median, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1864median};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1865median(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("median (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "median", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1864median(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1864median(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("median", 1);

  /* "giacpy/auto-methods.pxi":11548
 * 
 *         '''
 *         return GiacMethods['median'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def median_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_median); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11548, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11538
 *         return GiacMethods['mean'](self,*args)
 * 
 *      def median(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.median", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11550
 *         return GiacMethods['median'](self,*args)
 * 
 *      def median_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1867median_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1866median_line, "From Giac's documentation:\n        Help for median_line:\n        median_line((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        median_line(A,B,C) draws the median-line through A of the triangle ABC.\n        See also: 1/ midpoint 2/ perpen_bisector \n        Ex1:median_line(-1,1-i,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1867median_line = {"median_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1867median_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1866median_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1867median_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("median_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "median_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1866median_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1866median_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("median_line", 1);

  /* "giacpy/auto-methods.pxi":11559
 * 
 *         '''
 *         return GiacMethods['median_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def member(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_median_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11559, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11550
 *         return GiacMethods['median'](self,*args)
 * 
 *      def median_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.median_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11561
 *         return GiacMethods['median_line'](self,*args)
 * 
 *      def member(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for member:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1869member(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1868member, "From Giac's documentation:\n        Help for member:\n        member(Elem(e),(Lst(l) or Set(l)))\n        Tests if e is in the list or set l (=0, or k+1 with l[k]=e).\n        See also: 1/ contains 2/ est_element 3/ find 4/ index \n        Ex1:member(1,[4,3,1,2])\n        Ex2:member(1,%{4,3,1,2%})\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1869member = {"member", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1869member, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1868member};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1869member(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("member (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "member", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1868member(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1868member(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("member", 1);

  /* "giacpy/auto-methods.pxi":11571
 * 
 *         '''
 *         return GiacMethods['member'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mgf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_member); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11571, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11561
 *         return GiacMethods['median_line'](self,*args)
 * 
 *      def member(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for member:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.member", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11573
 *         return GiacMethods['member'](self,*args)
 * 
 *      def mgf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mgf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1871mgf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1870mgf, "From Giac's documentation:\n        Help for mgf:\n        mgf(Func,[Real(Param_1),Real(Param_2)])\n        Returns the moment generating function of a probability distribution from normal, binomial, Poisson, beta, gamma distribution\n        Ex1:mgf(normald,1,0)\n        Ex2:mgf(poisson,5)\n        Ex3:mgf(binomial,n,p)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1871mgf = {"mgf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1871mgf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1870mgf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1871mgf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mgf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mgf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1870mgf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1870mgf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mgf", 1);

  /* "giacpy/auto-methods.pxi":11583
 * 
 *         '''
 *         return GiacMethods['mgf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mid(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mgf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11583, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11573
 *         return GiacMethods['member'](self,*args)
 * 
 *      def mgf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mgf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mgf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11585
 *         return GiacMethods['mgf'](self,*args)
 * 
 *      def mid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mid:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1873mid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1872mid, "From Giac's documentation:\n        Help for mid:\n        mid(Lst(l) or Str(l),Intg(d),Intg(n))\n        Returns the extracted list of l with n elements (by default n=size(l)-d) and beginning at index d.\n        See also: 1/ head 2/ tail 3/ left 4/ right 5/ subMat \n        Ex1:mid([0,1,2,3,4,5,6],2,3)\n        Ex2:mid([0,1,2,3,4,5,6],2)\n        Ex3:mid(\"azertyuiop\",2,4)\n        Ex4:mid(\"azertyuiop\",2)\n        Ex5:mid([[1,2],[3,4],[5,6]],1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1873mid = {"mid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1873mid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1872mid};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1873mid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mid (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mid", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1872mid(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1872mid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mid", 1);

  /* "giacpy/auto-methods.pxi":11598
 * 
 *         '''
 *         return GiacMethods['mid'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def middle_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mid); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11598, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11585
 *         return GiacMethods['mgf'](self,*args)
 * 
 *      def mid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mid:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11600
 *         return GiacMethods['mid'](self,*args)
 * 
 *      def middle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for middle_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1875middle_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1874middle_point, "From Giac's documentation:\n        Help for middle_point:\n        middle_point(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1875middle_point = {"middle_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1875middle_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1874middle_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1875middle_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("middle_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "middle_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1874middle_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1874middle_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("middle_point", 1);

  /* "giacpy/auto-methods.pxi":11614
 * 
 *         '''
 *         return GiacMethods['middle_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def midpoint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_middle_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11614, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11600
 *         return GiacMethods['mid'](self,*args)
 * 
 *      def middle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for middle_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.middle_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11616
 *         return GiacMethods['middle_point'](self,*args)
 * 
 *      def midpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for midpoint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1877midpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1876midpoint, "From Giac's documentation:\n        Help for midpoint:\n        midpoint((Pnt or Cplx),(Pnt or Cplx))\n        midpoint(A,B) draws the midpoint of the segment AB.\n        See also: 1/ median_line 2/ perpen_bisector \n        Ex1:midpoint(-2,2i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1877midpoint = {"midpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1877midpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1876midpoint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1877midpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("midpoint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "midpoint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1876midpoint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1876midpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("midpoint", 1);

  /* "giacpy/auto-methods.pxi":11625
 * 
 *         '''
 *         return GiacMethods['midpoint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def min(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_midpoint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11625, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11616
 *         return GiacMethods['middle_point'](self,*args)
 * 
 *      def midpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for midpoint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.midpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11627
 *         return GiacMethods['midpoint'](self,*args)
 * 
 *      def min(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for min:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1879min(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1878min, "From Giac's documentation:\n        Help for min:\n        min(Seq||Lst)\n        Minimum of elements of a sequence or a list of reals.\n        See also: 1/ max \n        Ex1:min(25,35)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1879min = {"min", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1879min, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1878min};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1879min(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("min (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "min", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1878min(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1878min(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("min", 1);

  /* "giacpy/auto-methods.pxi":11636
 * 
 *         '''
 *         return GiacMethods['min'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimal_edge_coloring(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_min); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11636, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11627
 *         return GiacMethods['midpoint'](self,*args)
 * 
 *      def min(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for min:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.min", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11638
 *         return GiacMethods['min'](self,*args)
 * 
 *      def minimal_edge_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_edge_coloring:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1881minimal_edge_coloring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1880minimal_edge_coloring, "From Giac's documentation:\n        Help for minimal_edge_coloring:\n        minimal_edge_coloring(Graph(G),[sto])\n        Finds a minimal edge coloring of G and returns the sequence n,L where n is the class of G (1 for D colors and 2 for D+1 colors) and L is the list of colors of edges of G as returned by the edges command, or a copy of G with colored edges if the option 'sto' is specified.\n        See also: 1/ chromatic_index 2/ minimal_vertex_coloring 3/ edges \n        Ex1:minimal_edge_coloring(graph(\"petersen\"))\n        Ex2: G:=minimal_edge_coloring(graph(\"dodecahedron\"),sto); draw_graph(G)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1881minimal_edge_coloring = {"minimal_edge_coloring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1881minimal_edge_coloring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1880minimal_edge_coloring};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1881minimal_edge_coloring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimal_edge_coloring (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimal_edge_coloring", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1880minimal_edge_coloring(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1880minimal_edge_coloring(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimal_edge_coloring", 1);

  /* "giacpy/auto-methods.pxi":11648
 * 
 *         '''
 *         return GiacMethods['minimal_edge_coloring'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimal_spanning_tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimal_edge_coloring); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11648, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11638
 *         return GiacMethods['min'](self,*args)
 * 
 *      def minimal_edge_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_edge_coloring:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimal_edge_coloring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11650
 *         return GiacMethods['minimal_edge_coloring'](self,*args)
 * 
 *      def minimal_spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_spanning_tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1883minimal_spanning_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1882minimal_spanning_tree, "From Giac's documentation:\n        Help for minimal_spanning_tree:\n        minimal_spanning_tree(Graph(G))\n        Returns a minimal spanning tree in an undirected graph G.\n        See also: 1/ spanning_tree \n        Ex1:minimal_spanning_tree(graph([[0,1,0,4,0,0],[1,0,1,0,4,0],[0,1,0,3,0,1],[4,0,3,0,1,0],[0,4,0,1,0,4],[0,0,1,0,4,0]]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1883minimal_spanning_tree = {"minimal_spanning_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1883minimal_spanning_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1882minimal_spanning_tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1883minimal_spanning_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimal_spanning_tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimal_spanning_tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1882minimal_spanning_tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1882minimal_spanning_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimal_spanning_tree", 1);

  /* "giacpy/auto-methods.pxi":11659
 * 
 *         '''
 *         return GiacMethods['minimal_spanning_tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimal_vertex_coloring(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimal_spanning_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11659, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11650
 *         return GiacMethods['minimal_edge_coloring'](self,*args)
 * 
 *      def minimal_spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_spanning_tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimal_spanning_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11661
 *         return GiacMethods['minimal_spanning_tree'](self,*args)
 * 
 *      def minimal_vertex_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_vertex_coloring:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1885minimal_vertex_coloring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1884minimal_vertex_coloring, "From Giac's documentation:\n        Help for minimal_vertex_coloring:\n        minimal_vertex_coloring(Graph(G),[sto])\n        Computes the minimal vertex coloring for G and returns the colors in the order of vertices. If optional parameter \"sto\" is given, the colors are assigned to vertices and a modified copy of G is returned.\n        See also: 1/ chromatic_number 2/ is_vertex_colorable \n        Ex1:minimal_vertex_coloring(graph(\"petersen\"))\n        Ex2: draw_graph(minimal_vertex_coloring(graph(\"petersen\"),sto))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1885minimal_vertex_coloring = {"minimal_vertex_coloring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1885minimal_vertex_coloring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1884minimal_vertex_coloring};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1885minimal_vertex_coloring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimal_vertex_coloring (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimal_vertex_coloring", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1884minimal_vertex_coloring(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1884minimal_vertex_coloring(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimal_vertex_coloring", 1);

  /* "giacpy/auto-methods.pxi":11671
 * 
 *         '''
 *         return GiacMethods['minimal_vertex_coloring'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimax(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimal_vertex_coloring); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11671, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11661
 *         return GiacMethods['minimal_spanning_tree'](self,*args)
 * 
 *      def minimal_vertex_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_vertex_coloring:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimal_vertex_coloring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11673
 *         return GiacMethods['minimal_vertex_coloring'](self,*args)
 * 
 *      def minimax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimax:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1887minimax(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1886minimax, "From Giac's documentation:\n        Help for minimax:\n        minimax(Expr,Var=Real(a)..Real(b),Intg(n)||Lst(Intg(n),Intg(m)),[opts])\n        Returns rational approximation of degree n[,m] of a continuous bounded function on a..b using Remez algorithm.\n        See also: 1/ fitpoly \n        Ex1:minimax(abs(x)*sqrt(abs(x)),x=-2..2,15)\n        Ex2:minimax(min(1/cosh(3*sin(x)),sin(9x/10)),x=-3..4,30)\n        Ex3:minimax(x*exp(-x),x=0..10,[5,3],rand=30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1887minimax = {"minimax", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1887minimax, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1886minimax};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1887minimax(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimax (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimax", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1886minimax(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1886minimax(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimax", 1);

  /* "giacpy/auto-methods.pxi":11684
 * 
 *         '''
 *         return GiacMethods['minimax'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimize(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimax); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11684, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11673
 *         return GiacMethods['minimal_vertex_coloring'](self,*args)
 * 
 *      def minimax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimax:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimax", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11686
 *         return GiacMethods['minimax'](self,*args)
 * 
 *      def minimize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimize:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1889minimize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1888minimize, "From Giac's documentation:\n        Help for minimize:\n        minimize(Expr,[Constr],Vars,[Options])\n        Finds the global minimum of a function.\n        See also: 1/ maximize \n        Ex1:minimize(sin(x),[x=0..4])\n        Ex2:minimize(x^4-x^2,x=-3..3,coordinates)\n        Ex3:minimize(piecewise(x<=-2,x+6,x<=1,x^2,3/2-x/2),x=-3..2)\n        Ex4:minimize(x^2-3x+y^2+3y+3,[x=2..4,y=-4..-2],point)\n        Ex5:minimize(2x^2-y^2+6y,x^2+y^2<=16,[x,y])\n        Ex6:minimize(sqrt(x^2+y^2)-z,[x^2+y^2<=16,x+y+z=10],[x,y,z])\n        Ex7:minimize((1+x^2+3y+5x-4*x*y)/(1+x^2+y^2),x^2/4+y^2/3=9,[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1889minimize = {"minimize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1889minimize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1888minimize};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1889minimize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimize (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimize", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1888minimize(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1888minimize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimize", 1);

  /* "giacpy/auto-methods.pxi":11701
 * 
 *         '''
 *         return GiacMethods['minimize'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimum_cut(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11701, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11686
 *         return GiacMethods['minimax'](self,*args)
 * 
 *      def minimize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimize:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11703
 *         return GiacMethods['minimize'](self,*args)
 * 
 *      def minimum_cut(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_cut:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1891minimum_cut(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1890minimum_cut, "From Giac's documentation:\n        Help for minimum_cut:\n        minimum_cut(Graph(G),Vrtx(s),Vrtx(t))\n        Returns the list of edges forming a minimum cut in a directed graph G with source s and sink t.\n        See also: 1/ maxflow \n        Ex1:minimum_cut(digraph(%{[[1,2],2],[[2,3],4],[[3,4],3],[[1,5],3],[[5,2],1],[[5,4],2]%}),1,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1891minimum_cut = {"minimum_cut", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1891minimum_cut, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1890minimum_cut};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1891minimum_cut(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimum_cut (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimum_cut", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1890minimum_cut(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1890minimum_cut(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimum_cut", 1);

  /* "giacpy/auto-methods.pxi":11712
 * 
 *         '''
 *         return GiacMethods['minimum_cut'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimum_degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimum_cut); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11712, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11703
 *         return GiacMethods['minimize'](self,*args)
 * 
 *      def minimum_cut(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_cut:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimum_cut", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11714
 *         return GiacMethods['minimum_cut'](self,*args)
 * 
 *      def minimum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1893minimum_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1892minimum_degree, "From Giac's documentation:\n        Help for minimum_degree:\n        minimum_degree(Graph(G))\n        Returns the smallest degree of a vertex in G.\n        See also: 1/ maximum_degree 2/ vertex_degree \n        Ex1:minimum_degree(digraph(trail(1,2,3,4,5,6,4,7,8,2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1893minimum_degree = {"minimum_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1893minimum_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1892minimum_degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1893minimum_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimum_degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimum_degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1892minimum_degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1892minimum_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimum_degree", 1);

  /* "giacpy/auto-methods.pxi":11723
 * 
 *         '''
 *         return GiacMethods['minimum_degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def minimum_vertex_cover(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimum_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11723, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11714
 *         return GiacMethods['minimum_cut'](self,*args)
 * 
 *      def minimum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimum_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11725
 *         return GiacMethods['minimum_degree'](self,*args)
 * 
 *      def minimum_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_vertex_cover:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1895minimum_vertex_cover(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1894minimum_vertex_cover, "From Giac's documentation:\n        Help for minimum_vertex_cover:\n        minimum_vertex_cover(Graph(G),[approx])\n        Returns a list of vertices which comprise a minimum vertex cover in an undirected graph G.\n        See also: 1/ vertex_cover_number 2/ find_vertex_cover \n        Ex1:minimum_vertex_cover(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1895minimum_vertex_cover = {"minimum_vertex_cover", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1895minimum_vertex_cover, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1894minimum_vertex_cover};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1895minimum_vertex_cover(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("minimum_vertex_cover (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "minimum_vertex_cover", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1894minimum_vertex_cover(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1894minimum_vertex_cover(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("minimum_vertex_cover", 1);

  /* "giacpy/auto-methods.pxi":11734
 * 
 *         '''
 *         return GiacMethods['minimum_vertex_cover'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mixdown(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_minimum_vertex_cover); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11734, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11725
 *         return GiacMethods['minimum_degree'](self,*args)
 * 
 *      def minimum_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_vertex_cover:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.minimum_vertex_cover", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11736
 *         return GiacMethods['minimum_vertex_cover'](self,*args)
 * 
 *      def mixdown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mixdown:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1897mixdown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1896mixdown, "From Giac's documentation:\n        Help for mixdown:\n        mixdown(Audio(clip1),(Real||Lst)(parm1),Audio(clip2),(Real||Lst)(parm2),...)\n        Returns audio clips clip1,clip2,... mixed down to a single clip according to the given parameters.\n        See also: 2/ + 1/ splice \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1897mixdown = {"mixdown", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1897mixdown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1896mixdown};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1897mixdown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mixdown (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mixdown", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1896mixdown(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1896mixdown(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mixdown", 1);

  /* "giacpy/auto-methods.pxi":11744
 * 
 *         '''
 *         return GiacMethods['mixdown'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mkisom(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mixdown); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11744, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11736
 *         return GiacMethods['minimum_vertex_cover'](self,*args)
 * 
 *      def mixdown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mixdown:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mixdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11746
 *         return GiacMethods['mixdown'](self,*args)
 * 
 *      def mkisom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mkisom:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1899mkisom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1898mkisom, "From Giac's documentation:\n        Help for mkisom:\n        mkisom(Vect,(Sign(1) or -1))\n        Matrix of an isometry given by its proper elements.\n        See also: 1/ isom \n        Ex1:mkisom([1,2],1)\n        Ex2:mkisom([[1,0,0],pi/3],-1)\n        Ex3:mkisom(pi,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1899mkisom = {"mkisom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1899mkisom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1898mkisom};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1899mkisom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mkisom (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mkisom", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1898mkisom(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1898mkisom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mkisom", 1);

  /* "giacpy/auto-methods.pxi":11757
 * 
 *         '''
 *         return GiacMethods['mkisom'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mksa(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mkisom); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11757, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11746
 *         return GiacMethods['mixdown'](self,*args)
 * 
 *      def mkisom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mkisom:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mkisom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11759
 *         return GiacMethods['mkisom'](self,*args)
 * 
 *      def mksa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mksa:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1901mksa(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1900mksa, "From Giac's documentation:\n        Help for mksa:\n        mksa(Unit)\n        Converts units to the MKSA international unit system.\n        See also: 1/ convert 2/ ufactor \n        Ex1:mksa(1_N)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1901mksa = {"mksa", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1901mksa, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1900mksa};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1901mksa(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mksa (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mksa", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1900mksa(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1900mksa(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mksa", 1);

  /* "giacpy/auto-methods.pxi":11768
 * 
 *         '''
 *         return GiacMethods['mksa'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def modf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mksa); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11768, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11759
 *         return GiacMethods['mkisom'](self,*args)
 * 
 *      def mksa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mksa:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mksa", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11770
 *         return GiacMethods['mksa'](self,*args)
 * 
 *      def modf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1903modf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1902modf, "From Giac's documentation:\n        Help for modf:\n        modf(Real(a))\n        Returns (a-trunc(a),trunc(a)).\n        See also: 1/ frac 2/ floor \n        Ex1:modf(2.3)\n        Ex2:modf(-2.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1903modf = {"modf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1903modf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1902modf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1903modf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("modf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "modf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1902modf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1902modf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("modf", 1);

  /* "giacpy/auto-methods.pxi":11780
 * 
 *         '''
 *         return GiacMethods['modf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def modgcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_modf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11780, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11770
 *         return GiacMethods['mksa'](self,*args)
 * 
 *      def modf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.modf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11782
 *         return GiacMethods['modf'](self,*args)
 * 
 *      def modgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modgcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1905modgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1904modgcd, "From Giac's documentation:\n        Help for modgcd:\n        modgcd(Poly,Poly)\n        GCD of 2 polynomials, with the modular algorithm.\n        See also: 1/ gcd 2/ heugcd 3/ ezgcd 4/ psrgcd \n        Ex1:modgcd(x^4-1,(x-1)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1905modgcd = {"modgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1905modgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1904modgcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1905modgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("modgcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "modgcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1904modgcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1904modgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("modgcd", 1);

  /* "giacpy/auto-methods.pxi":11791
 * 
 *         '''
 *         return GiacMethods['modgcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mods(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_modgcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11791, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11782
 *         return GiacMethods['modf'](self,*args)
 * 
 *      def modgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modgcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.modgcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11793
 *         return GiacMethods['modgcd'](self,*args)
 * 
 *      def mods(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mods:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1907mods(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1906mods, "From Giac's documentation:\n        Help for mods:\n        mods(Intg,Intg)\n        Returns the Euclidean symmetric remainder of two integers.\n        See also: 1/ irem 2/ iquo 3/ mod 4/ fracmod \n        Ex1:mods(8,3)\n        Ex2:mods(10,4)\n        Ex3:mods(11,7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1907mods = {"mods", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1907mods, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1906mods};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1907mods(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mods (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mods", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1906mods(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1906mods(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mods", 1);

  /* "giacpy/auto-methods.pxi":11804
 * 
 *         '''
 *         return GiacMethods['mods'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def momentum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mods); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11804, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11793
 *         return GiacMethods['modgcd'](self,*args)
 * 
 *      def mods(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mods:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mods", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11806
 *         return GiacMethods['mods'](self,*args)
 * 
 *      def momentum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for momentum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1909momentum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1908momentum, "From Giac's documentation:\n        Help for momentum:\n        momentum(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1909momentum = {"momentum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1909momentum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1908momentum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1909momentum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("momentum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "momentum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1908momentum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1908momentum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("momentum", 1);

  /* "giacpy/auto-methods.pxi":11814
 * 
 *         '''
 *         return GiacMethods['momentum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def monotonic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_momentum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11814, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11806
 *         return GiacMethods['mods'](self,*args)
 * 
 *      def momentum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for momentum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.momentum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11816
 *         return GiacMethods['momentum'](self,*args)
 * 
 *      def monotonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for monotonic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1911monotonic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1910monotonic, "From Giac's documentation:\n        Help for monotonic:\n        monotonic()\n        Returns a real that increases as time passes\n        Ex1:monotonic()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1911monotonic = {"monotonic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1911monotonic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1910monotonic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1911monotonic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("monotonic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "monotonic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1910monotonic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1910monotonic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("monotonic", 1);

  /* "giacpy/auto-methods.pxi":11824
 * 
 *         '''
 *         return GiacMethods['monotonic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def montre_tortue(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_monotonic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11824, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11816
 *         return GiacMethods['momentum'](self,*args)
 * 
 *      def monotonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for monotonic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.monotonic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11826
 *         return GiacMethods['monotonic'](self,*args)
 * 
 *      def montre_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for montre_tortue:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1913montre_tortue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1912montre_tortue, "From Giac's documentation:\n        Help for montre_tortue:\n        montre_tortue(NULL)\n        Shows the turtle.\n        See also: 1/ cache_tortue \n        Ex1:montre_tortue()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1913montre_tortue = {"montre_tortue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1913montre_tortue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1912montre_tortue};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1913montre_tortue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("montre_tortue (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "montre_tortue", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1912montre_tortue(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1912montre_tortue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("montre_tortue", 1);

  /* "giacpy/auto-methods.pxi":11835
 * 
 *         '''
 *         return GiacMethods['montre_tortue'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def moustache(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_montre_tortue); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11835, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11826
 *         return GiacMethods['monotonic'](self,*args)
 * 
 *      def montre_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for montre_tortue:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.montre_tortue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11837
 *         return GiacMethods['montre_tortue'](self,*args)
 * 
 *      def moustache(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moustache:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1915moustache(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1914moustache, "From Giac's documentation:\n        Help for moustache:\n        moustache(Lst,[Lst],[x=a..b||y=a..b])\n        Box and Whisker plot for a statistical series.\n        See also: 1/ quartiles \n        Ex1:moustache([-1,1,2,2.2,3,4,-2,5])\n        Ex2:moustache([1,2,3,5,10,4],x=1..2)\n        Ex3:moustache([1,2,3,5,10,4],[1,2,3,1,2,3])\n        Ex4:moustache([[6,0,1,3,4,2,5],[0,1,3,4,2,5,6],[1,3,4,2,5,6,0],[3,4,2,5,6,0,1],[4,2,5,6,0,1,3],[2,5,6,0,1,3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1915moustache = {"moustache", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1915moustache, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1914moustache};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1915moustache(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("moustache (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "moustache", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1914moustache(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1914moustache(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("moustache", 1);

  /* "giacpy/auto-methods.pxi":11849
 * 
 *         '''
 *         return GiacMethods['moustache'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def moving_average(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_moustache); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11849, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11837
 *         return GiacMethods['montre_tortue'](self,*args)
 * 
 *      def moustache(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moustache:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.moustache", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11851
 *         return GiacMethods['moustache'](self,*args)
 * 
 *      def moving_average(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moving_average:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1917moving_average(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1916moving_average, "From Giac's documentation:\n        Help for moving_average:\n        moving_average(Lst(A),Intg(n))\n        Applies a moving average filter of length n to a signal sample A, and returns its result as an array of length nops(A)-n+1.\n        See also: 1/ lowpass \n        Ex1: snd:=soundsec(2):;data:=0.5*threshold(3*sin(2*pi*220*snd),[-1.0,1.0])+randvector(length(snd),normald,0,0.05):;moving_average(data,25)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1917moving_average = {"moving_average", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1917moving_average, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1916moving_average};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1917moving_average(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("moving_average (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "moving_average", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1916moving_average(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1916moving_average(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("moving_average", 1);

  /* "giacpy/auto-methods.pxi":11860
 * 
 *         '''
 *         return GiacMethods['moving_average'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def moyal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_moving_average); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11860, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11851
 *         return GiacMethods['moustache'](self,*args)
 * 
 *      def moving_average(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moving_average:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.moving_average", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11862
 *         return GiacMethods['moving_average'](self,*args)
 * 
 *      def moyal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1919moyal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1918moyal, "From Giac's documentation:\n        Help for moyal:\n        moyal(Expr,Expr,VectVar)\n        Moyal product of 2 symbols.\n        See also: 1/  \n        Ex1:moyal(x^2+y^4,x^4-y^2,[x,y],5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1919moyal = {"moyal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1919moyal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1918moyal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1919moyal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("moyal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "moyal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1918moyal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1918moyal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("moyal", 1);

  /* "giacpy/auto-methods.pxi":11871
 * 
 *         '''
 *         return GiacMethods['moyal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def moyenne(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_moyal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11871, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11862
 *         return GiacMethods['moving_average'](self,*args)
 * 
 *      def moyal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.moyal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11873
 *         return GiacMethods['moyal'](self,*args)
 * 
 *      def moyenne(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyenne:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1921moyenne(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1920moyenne, "From Giac's documentation:\n        Help for moyenne:\n        moyenne(Lst||Mtrx,[Lst])\n        Mean of a list with the second argument as weight or of the columns of a matrix.\n        See also: 1/ stddev \n        Ex1:moyenne([1,2,3])\n        Ex2:moyenne([1,2,3],[1,2,3])\n        Ex3:moyenne([[1,2,3],[1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1921moyenne = {"moyenne", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1921moyenne, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1920moyenne};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1921moyenne(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("moyenne (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "moyenne", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1920moyenne(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1920moyenne(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("moyenne", 1);

  /* "giacpy/auto-methods.pxi":11884
 * 
 *         '''
 *         return GiacMethods['moyenne'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mul(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_moyenne); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11884, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11873
 *         return GiacMethods['moyal'](self,*args)
 * 
 *      def moyenne(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyenne:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.moyenne", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11886
 *         return GiacMethods['moyenne'](self,*args)
 * 
 *      def mul(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mul:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1923mul(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1922mul, "From Giac's documentation:\n        Help for mul:\n        mul(Expr||Lst,[Var||Lst],[Intg(a)],[Intg(b)],[Intg(p)])\n        Multiplies the values of the expression when the variable go from a to b with a step p (product(expression,var,begin,end,step) by default p=1) or product of the elements of a list or product element by element of 2 lists or matrices.\n        See also: 1/ sum \n        Ex1:mul(n,n,1,10,2)\n        Ex2:mul(1/n,n,1,10)\n        Ex3:mul(1/n,n,11,1)\n        Ex4:mul(1/n,n,10,1,1)\n        Ex5:mul([2,3,4,5])\n        Ex6:mul([2,3,4],[5,6,7])\n        Ex7:mul([[2,3,4],[5,6,7]],[[2,3,4],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1923mul = {"mul", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1923mul, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1922mul};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1923mul(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mul (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mul", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1922mul(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1922mul(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mul", 1);

  /* "giacpy/auto-methods.pxi":11901
 * 
 *         '''
 *         return GiacMethods['mul'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mult_c_conjugate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mul); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11901, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11886
 *         return GiacMethods['moyenne'](self,*args)
 * 
 *      def mul(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mul:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mul", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11903
 *         return GiacMethods['mul'](self,*args)
 * 
 *      def mult_c_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_c_conjugate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1925mult_c_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1924mult_c_conjugate, "From Giac's documentation:\n        Help for mult_c_conjugate:\n        mult_c_conjugate(Expr)\n        Returns the expression after multiplication by the complex conjugate of the denominator (or of the numerator if no denominator).\n        See also: 1/ mult_conjugate \n        Ex1:mult_c_conjugate(1/(3+i*2))\n        Ex2:mult_c_conjugate(3+i*2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1925mult_c_conjugate = {"mult_c_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1925mult_c_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1924mult_c_conjugate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1925mult_c_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mult_c_conjugate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mult_c_conjugate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1924mult_c_conjugate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1924mult_c_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mult_c_conjugate", 1);

  /* "giacpy/auto-methods.pxi":11913
 * 
 *         '''
 *         return GiacMethods['mult_c_conjugate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mult_conjugate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mult_c_conjugate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11913, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11903
 *         return GiacMethods['mul'](self,*args)
 * 
 *      def mult_c_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_c_conjugate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mult_c_conjugate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11915
 *         return GiacMethods['mult_c_conjugate'](self,*args)
 * 
 *      def mult_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_conjugate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1927mult_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1926mult_conjugate, "From Giac's documentation:\n        Help for mult_conjugate:\n        mult_conjugate(Expr)\n        Returns the expression after multiplication by the conjugate of the denominator (or of the numerator if no denominator).\n        See also: 1/ mult_c_conjugate \n        Ex1:mult_conjugate(sqrt(3)-sqrt(2))\n        Ex2:mult_conjugate(1/(sqrt(3)-sqrt(2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1927mult_conjugate = {"mult_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1927mult_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1926mult_conjugate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1927mult_conjugate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mult_conjugate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mult_conjugate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1926mult_conjugate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1926mult_conjugate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mult_conjugate", 1);

  /* "giacpy/auto-methods.pxi":11925
 * 
 *         '''
 *         return GiacMethods['mult_conjugate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def multinomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mult_conjugate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11925, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11915
 *         return GiacMethods['mult_c_conjugate'](self,*args)
 * 
 *      def mult_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_conjugate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mult_conjugate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11927
 *         return GiacMethods['mult_conjugate'](self,*args)
 * 
 *      def multinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multinomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1929multinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1928multinomial, "From Giac's documentation:\n        Help for multinomial:\n        multinomial(Intg(n),Vect(p),Vect(k))\n        Returns n!/(k0!*k1!*..;kj!)*(p0^k0*p1^k1..*pj^kj) (sum(p)=1 and sum(k)=n).\n        See also: 1/ binomial 2/ randvector 3/ ranm \n        Ex1:multinomial(10,[0.5,0.5],[3,7])\n        Ex2:multinomial(10,[0.2,0.3,0.5],[1,3,6])\n        Ex3: randvector(3,multinomial,[1/2,1/3,1/6])\n        Ex4: ranm(4,3,multinomial,[1/2,1/3,1/6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1929multinomial = {"multinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1929multinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1928multinomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1929multinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("multinomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "multinomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1928multinomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1928multinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("multinomial", 1);

  /* "giacpy/auto-methods.pxi":11939
 * 
 *         '''
 *         return GiacMethods['multinomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def multiplier_conjugue(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_multinomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11939, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11927
 *         return GiacMethods['mult_conjugate'](self,*args)
 * 
 *      def multinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multinomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.multinomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11941
 *         return GiacMethods['multinomial'](self,*args)
 * 
 *      def multiplier_conjugue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1931multiplier_conjugue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1930multiplier_conjugue, "From Giac's documentation:\n        Help for multiplier_conjugue:\n        multiplier_conjugue(Expr)\n        Returns the expression after multiplication by the conjugate of the denominator (or of the numerator if no denominator).\n        See also: 1/ mult_c_conjugate \n        Ex1:multiplier_conjugue(sqrt(3)-sqrt(2))\n        Ex2:multiplier_conjugue(1/(sqrt(3)-sqrt(2)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1931multiplier_conjugue = {"multiplier_conjugue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1931multiplier_conjugue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1930multiplier_conjugue};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1931multiplier_conjugue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("multiplier_conjugue (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "multiplier_conjugue", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1930multiplier_conjugue(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1930multiplier_conjugue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("multiplier_conjugue", 1);

  /* "giacpy/auto-methods.pxi":11951
 * 
 *         '''
 *         return GiacMethods['multiplier_conjugue'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def multiplier_conjugue_complexe(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_multiplier_conjugue); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11951, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11941
 *         return GiacMethods['multinomial'](self,*args)
 * 
 *      def multiplier_conjugue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.multiplier_conjugue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11953
 *         return GiacMethods['multiplier_conjugue'](self,*args)
 * 
 *      def multiplier_conjugue_complexe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue_complexe:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1933multiplier_conjugue_complexe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1932multiplier_conjugue_complexe, "From Giac's documentation:\n        Help for multiplier_conjugue_complexe:\n        multiplier_conjugue_complexe(Expr)\n        Returns the expression after multiplication by the complex conjugate of the denominator (or of the numerator if no denominator).\n        See also: 1/ mult_conjugate \n        Ex1:multiplier_conjugue_complexe(1/(3+i*2))\n        Ex2:multiplier_conjugue_complexe(3+i*2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1933multiplier_conjugue_complexe = {"multiplier_conjugue_complexe", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1933multiplier_conjugue_complexe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1932multiplier_conjugue_complexe};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1933multiplier_conjugue_complexe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("multiplier_conjugue_complexe (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "multiplier_conjugue_complexe", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1932multiplier_conjugue_complexe(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1932multiplier_conjugue_complexe(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("multiplier_conjugue_complexe", 1);

  /* "giacpy/auto-methods.pxi":11963
 * 
 *         '''
 *         return GiacMethods['multiplier_conjugue_complexe'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def multiply(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_multiplier_conjugue_complexe); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11963, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11953
 *         return GiacMethods['multiplier_conjugue'](self,*args)
 * 
 *      def multiplier_conjugue_complexe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue_complexe:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.multiplier_conjugue_complexe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11965
 *         return GiacMethods['multiplier_conjugue_complexe'](self,*args)
 * 
 *      def multiply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiply:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1935multiply(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1934multiply, "From Giac's documentation:\n        Help for multiply:\n        multiply(Intg or Lst, Intg or Lst)\n        Returns the product of the 2 arguments.\n        See also: 1/ * \n        Ex1:multiply(41,-4)\n        Ex2:multiply([4,1],[-4,2])\n        Ex3:multiply([[4,1],[-4,1]],[[4,1],[-4,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1935multiply = {"multiply", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1935multiply, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1934multiply};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1935multiply(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("multiply (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "multiply", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1934multiply(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1934multiply(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("multiply", 1);

  /* "giacpy/auto-methods.pxi":11976
 * 
 *         '''
 *         return GiacMethods['multiply'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mupad2maple(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_multiply); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11976, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11965
 *         return GiacMethods['multiplier_conjugue_complexe'](self,*args)
 * 
 *      def multiply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiply:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.multiply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11978
 *         return GiacMethods['multiply'](self,*args)
 * 
 *      def mupad2maple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2maple:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1937mupad2maple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1936mupad2maple, "From Giac's documentation:\n        Help for mupad2maple:\n        mupad2maple(Str(\"NameMupadFile\"),Str(\"NameMapleFile\"))\n        mupad2maple(\"file1\",\"file2\") translates file1(MuPAD) to file2(Maple).\n        See also: 1/ mupad2xcas \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1937mupad2maple = {"mupad2maple", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1937mupad2maple, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1936mupad2maple};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1937mupad2maple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mupad2maple (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mupad2maple", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1936mupad2maple(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1936mupad2maple(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mupad2maple", 1);

  /* "giacpy/auto-methods.pxi":11986
 * 
 *         '''
 *         return GiacMethods['mupad2maple'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mupad2xcas(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mupad2maple); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11986, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11978
 *         return GiacMethods['multiply'](self,*args)
 * 
 *      def mupad2maple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2maple:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mupad2maple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11988
 *         return GiacMethods['mupad2maple'](self,*args)
 * 
 *      def mupad2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2xcas:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1939mupad2xcas(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1938mupad2xcas, "From Giac's documentation:\n        Help for mupad2xcas:\n        mupad2xcas(Str(\"NameMupadFile\"),Str(\"NameXcasFile\"))\n        mupad2xcas(\"file1\",\"file2\") translates file1(MuPAD) to file2(Xcas).\n        See also: 1/ mupad2maple \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1939mupad2xcas = {"mupad2xcas", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1939mupad2xcas, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1938mupad2xcas};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1939mupad2xcas(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mupad2xcas (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mupad2xcas", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1938mupad2xcas(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1938mupad2xcas(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mupad2xcas", 1);

  /* "giacpy/auto-methods.pxi":11996
 * 
 *         '''
 *         return GiacMethods['mupad2xcas'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def mycielski(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mupad2xcas); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 11996, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 11996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 11996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11988
 *         return GiacMethods['mupad2maple'](self,*args)
 * 
 *      def mupad2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2xcas:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mupad2xcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":11998
 *         return GiacMethods['mupad2xcas'](self,*args)
 * 
 *      def mycielski(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mycielski:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1941mycielski(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1940mycielski, "From Giac's documentation:\n        Help for mycielski:\n        mycielski(Graph(G))\n        Returns the Mycielskian of an undirected graph G.\n        See also: 1/ chromatic_number 2/ number_of_triangles \n        Ex1:mycielski(graph(\"petersen\"))\n        Ex2: is_isomorphic(mycielski(mycielski(path_graph(2))),graph(\"grotzsch\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1941mycielski = {"mycielski", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1941mycielski, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1940mycielski};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1941mycielski(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mycielski (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "mycielski", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1940mycielski(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1940mycielski(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mycielski", 1);

  /* "giacpy/auto-methods.pxi":12008
 * 
 *         '''
 *         return GiacMethods['mycielski'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nCr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_mycielski); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12008, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":11998
 *         return GiacMethods['mupad2xcas'](self,*args)
 * 
 *      def mycielski(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mycielski:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.mycielski", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12010
 *         return GiacMethods['mycielski'](self,*args)
 * 
 *      def nCr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nCr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1943nCr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1942nCr, "From Giac's documentation:\n        Help for nCr:\n        nCr(Intg(n),Intg(r))\n        comb(n,r)=number of combinations of r objects taken among n : n!/(r!(n-r)!) (If n<0 comb(n,r)=n(n-1)..(n-r+1)/r!).\n        See also: 1/ factorial 2/ perm \n        Ex1:nCr(4,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1943nCr = {"nCr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1943nCr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1942nCr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1943nCr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nCr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nCr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1942nCr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1942nCr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nCr", 1);

  /* "giacpy/auto-methods.pxi":12019
 * 
 *         '''
 *         return GiacMethods['nCr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nDeriv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nCr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12019, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12010
 *         return GiacMethods['mycielski'](self,*args)
 * 
 *      def nCr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nCr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nCr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12021
 *         return GiacMethods['nCr'](self,*args)
 * 
 *      def nDeriv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nDeriv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1945nDeriv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1944nDeriv, "From Giac's documentation:\n        Help for nDeriv:\n        nDeriv(Expr(Xpr),Var(Var),[Real(h)])\n        Returns an approximation of the derivative number at a point: (Xpr(var+h)-Xpr(var-h))/(2*h) (by default h=0.001).\n        See also: 1/ avgRC \n        Ex1:nDeriv(f(x),x,h)\n        Ex2:nDeriv(x^2,x,0.1)\n        Ex3:nDeriv(x^2,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1945nDeriv = {"nDeriv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1945nDeriv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1944nDeriv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1945nDeriv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nDeriv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nDeriv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1944nDeriv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1944nDeriv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nDeriv", 1);

  /* "giacpy/auto-methods.pxi":12032
 * 
 *         '''
 *         return GiacMethods['nDeriv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nInt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nDeriv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12032, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12021
 *         return GiacMethods['nCr'](self,*args)
 * 
 *      def nDeriv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nDeriv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nDeriv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12034
 *         return GiacMethods['nDeriv'](self,*args)
 * 
 *      def nInt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nInt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1947nInt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1946nInt, "From Giac's documentation:\n        Help for nInt:\n        nInt(Expr(f(x)),Var(x),Real(a),Real(b))\n        Returns the approximate value of integrate(f(x),x,a,b) by Romberg's method.\n        See also: 1/ integrate 2/ gaussquad \n        Ex1:nInt(exp(x^2),x,0,1)\n        Ex2:nInt(x^2,x,0,1)\n        Ex3:nInt(exp(-x^2),x,-1,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1947nInt = {"nInt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1947nInt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1946nInt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1947nInt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nInt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nInt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1946nInt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1946nInt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nInt", 1);

  /* "giacpy/auto-methods.pxi":12045
 * 
 *         '''
 *         return GiacMethods['nInt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nPr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nInt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12045, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12034
 *         return GiacMethods['nDeriv'](self,*args)
 * 
 *      def nInt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nInt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nInt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12047
 *         return GiacMethods['nInt'](self,*args)
 * 
 *      def nPr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nPr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1949nPr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1948nPr, "From Giac's documentation:\n        Help for nPr:\n        nPr(Intg(n),Intg(p))\n        perm(n,p)=number of arrangements of p objects taken among n : n!/(n-p)!\n        See also: 1/ comb 2/ factorial \n        Ex1:nPr(4,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1949nPr = {"nPr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1949nPr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1948nPr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1949nPr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nPr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nPr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1948nPr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1948nPr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nPr", 1);

  /* "giacpy/auto-methods.pxi":12056
 * 
 *         '''
 *         return GiacMethods['nPr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nSolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nPr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12056, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12047
 *         return GiacMethods['nInt'](self,*args)
 * 
 *      def nPr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nPr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nPr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12058
 *         return GiacMethods['nPr'](self,*args)
 * 
 *      def nSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nSolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1951nSolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1950nSolve, "From Giac's documentation:\n        Help for nSolve:\n        nSolve(Expr,Var,[Guess or Interval],[Method])\n        Numerical solution of an equation or a system of equations.\n        See also: 1/ solve 2/ fsolve 3/ csolve \n        Ex1:nSolve(cos(x)=x,x)\n        Ex2:nSolve(cos(x)=x,x=1.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1951nSolve = {"nSolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1951nSolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1950nSolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1951nSolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nSolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nSolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1950nSolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1950nSolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nSolve", 1);

  /* "giacpy/auto-methods.pxi":12068
 * 
 *         '''
 *         return GiacMethods['nSolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def navy(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nSolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12068, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12058
 *         return GiacMethods['nPr'](self,*args)
 * 
 *      def nSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nSolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nSolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12070
 *         return GiacMethods['nSolve'](self,*args)
 * 
 *      def navy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for navy:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1953navy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1952navy, "From Giac's documentation:\n        Help for navy:\n        navy(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1953navy = {"navy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1953navy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1952navy};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1953navy(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("navy (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "navy", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1952navy(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1952navy(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("navy", 1);

  /* "giacpy/auto-methods.pxi":12080
 * 
 *         '''
 *         return GiacMethods['navy'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ncols(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_navy); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12080, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12070
 *         return GiacMethods['nSolve'](self,*args)
 * 
 *      def navy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for navy:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.navy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12082
 *         return GiacMethods['navy'](self,*args)
 * 
 *      def ncols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ncols:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1955ncols(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1954ncols, "From Giac's documentation:\n        Help for ncols:\n        ncols(Mtrx)\n        Number of columns of a matrix.\n        See also: 1/ rowdim \n        Ex1:ncols([[1,2,3],[4,5,6]])\n        Ex2:ncols([[1,2],[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1955ncols = {"ncols", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1955ncols, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1954ncols};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1955ncols(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ncols (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ncols", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1954ncols(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1954ncols(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ncols", 1);

  /* "giacpy/auto-methods.pxi":12092
 * 
 *         '''
 *         return GiacMethods['ncols'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def negbinomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ncols); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12092, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12082
 *         return GiacMethods['navy'](self,*args)
 * 
 *      def ncols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ncols:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ncols", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12094
 *         return GiacMethods['ncols'](self,*args)
 * 
 *      def negbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1957negbinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1956negbinomial, "From Giac's documentation:\n        Help for negbinomial:\n        negbinomial(Intg(n),Intg(k),Real(p in 0..1))\n        Returns comb(n+k-1,k)*p^k*(1-p)^n.\n        See also: 1/ negbinomial_cdf 2/ negbinomial_icdf 3/ binomial \n        Ex1:negbinomial(4,0,0.5)\n        Ex2:negbinomial(4,2,0.6)\n        Ex3:negbinomial(4,6,0.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1957negbinomial = {"negbinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1957negbinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1956negbinomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1957negbinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("negbinomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "negbinomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1956negbinomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1956negbinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("negbinomial", 1);

  /* "giacpy/auto-methods.pxi":12105
 * 
 *         '''
 *         return GiacMethods['negbinomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def negbinomial_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_negbinomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12105, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12094
 *         return GiacMethods['ncols'](self,*args)
 * 
 *      def negbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.negbinomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12107
 *         return GiacMethods['negbinomial'](self,*args)
 * 
 *      def negbinomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1959negbinomial_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1958negbinomial_cdf, "From Giac's documentation:\n        Help for negbinomial_cdf:\n        negbinomial_cdf(Intg(n),Real(p),Real(x),[Real(y)])\n        Returns Proba(X<=x) or Proba(x<=X<=y) when X follows the negbinomial(n,p) law.\n        See also: 1/ negbinomial 2/ negbinomial_icdf \n        Ex1:negbinomial_cdf(4,0.5,2)\n        Ex2:negbinomial_cdf(4,0.1,2)\n        Ex3:negbinomial_cdf(4,0.5,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1959negbinomial_cdf = {"negbinomial_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1959negbinomial_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1958negbinomial_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1959negbinomial_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("negbinomial_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "negbinomial_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1958negbinomial_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1958negbinomial_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("negbinomial_cdf", 1);

  /* "giacpy/auto-methods.pxi":12118
 * 
 *         '''
 *         return GiacMethods['negbinomial_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def negbinomial_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_negbinomial_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12118, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12107
 *         return GiacMethods['negbinomial'](self,*args)
 * 
 *      def negbinomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.negbinomial_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12120
 *         return GiacMethods['negbinomial_cdf'](self,*args)
 * 
 *      def negbinomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1961negbinomial_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1960negbinomial_icdf, "From Giac's documentation:\n        Help for negbinomial_icdf:\n        negbinomial_icdf(Intg(n),Real(p),Real(t))\n        Returns h such as Proba(X<=h)=t when X follows the negbinomial(n,p) law.\n        See also: 1/ negbinomial 2/ negbinomial_cdf \n        Ex1:negbinomial_icdf(4,0.5,0.68)\n        Ex2:negbinomial_icdf(4,0.1,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1961negbinomial_icdf = {"negbinomial_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1961negbinomial_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1960negbinomial_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1961negbinomial_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("negbinomial_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "negbinomial_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1960negbinomial_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1960negbinomial_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("negbinomial_icdf", 1);

  /* "giacpy/auto-methods.pxi":12130
 * 
 *         '''
 *         return GiacMethods['negbinomial_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def neighbors(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_negbinomial_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12130, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12120
 *         return GiacMethods['negbinomial_cdf'](self,*args)
 * 
 *      def negbinomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.negbinomial_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12132
 *         return GiacMethods['negbinomial_icdf'](self,*args)
 * 
 *      def neighbors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neighbors:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1963neighbors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1962neighbors, "From Giac's documentation:\n        Help for neighbors:\n        neighbors(Graph(G),[Vrtx(v)])\n        Returns the list of vertices adjacent to vertex v of G. If v is omitted, a list of adjacency lists of all vertices in G is returned.\n        See also: 1/ adjacency_matrix 2/ vertex_degree 3/ in_degree 3/ out_degree \n        Ex1:neighbors(digraph(trail(1,2,3,4,5,6,4,7,8,2)),4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1963neighbors = {"neighbors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1963neighbors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1962neighbors};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1963neighbors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("neighbors (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "neighbors", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1962neighbors(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1962neighbors(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("neighbors", 1);

  /* "giacpy/auto-methods.pxi":12141
 * 
 *         '''
 *         return GiacMethods['neighbors'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def network_transitivity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_neighbors); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12141, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12132
 *         return GiacMethods['negbinomial_icdf'](self,*args)
 * 
 *      def neighbors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neighbors:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.neighbors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12143
 *         return GiacMethods['neighbors'](self,*args)
 * 
 *      def network_transitivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for network_transitivity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1965network_transitivity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1964network_transitivity, "From Giac's documentation:\n        Help for network_transitivity:\n        network_transitivity(Graph(G))\n        Returns the transitivity (also called triangle density or global clustering coefficient) of a network G.\n        See also: 1/ clustering_coefficient 2/ number_of_triangles \n        Ex1:network_transitivity(graph(%{[1,2],[2,3],[2,4],[3,4],[4,1]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1965network_transitivity = {"network_transitivity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1965network_transitivity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1964network_transitivity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1965network_transitivity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("network_transitivity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "network_transitivity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1964network_transitivity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1964network_transitivity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("network_transitivity", 1);

  /* "giacpy/auto-methods.pxi":12152
 * 
 *         '''
 *         return GiacMethods['network_transitivity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def neural_network(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_network_transitivity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12152, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12143
 *         return GiacMethods['neighbors'](self,*args)
 * 
 *      def network_transitivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for network_transitivity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.network_transitivity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12154
 *         return GiacMethods['network_transitivity'](self,*args)
 * 
 *      def neural_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neural_network:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1967neural_network(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1966neural_network, "From Giac's documentation:\n        Help for neural_network:\n        neural_network(Vect(topology)||NeuralNet(net),[opts])\n        Creates a feed-forward neural network with given parameters or creates a copy of the given network with parameter modifications.\n        See also: 1/ train \n        Ex1:neural_network([2,3,1])\n        Ex2:neural_network([2,3,1],func=logistic)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1967neural_network = {"neural_network", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1967neural_network, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1966neural_network};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1967neural_network(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("neural_network (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "neural_network", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1966neural_network(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1966neural_network(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("neural_network", 1);

  /* "giacpy/auto-methods.pxi":12164
 * 
 *         '''
 *         return GiacMethods['neural_network'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def newList(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_neural_network); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12164, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12154
 *         return GiacMethods['network_transitivity'](self,*args)
 * 
 *      def neural_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neural_network:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.neural_network", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12166
 *         return GiacMethods['neural_network'](self,*args)
 * 
 *      def newList(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newList:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1969newList(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1968newList, "From Giac's documentation:\n        Help for newList:\n        newList(Intg(n))\n        Returns the list made with n zeros.\n        See also: 1/ newMat 2/ makelist \n        Ex1:newList(4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1969newList = {"newList", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1969newList, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1968newList};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1969newList(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newList (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "newList", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1968newList(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1968newList(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newList", 1);

  /* "giacpy/auto-methods.pxi":12175
 * 
 *         '''
 *         return GiacMethods['newList'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def newMat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_newList); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12175, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12166
 *         return GiacMethods['neural_network'](self,*args)
 * 
 *      def newList(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newList:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.newList", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12177
 *         return GiacMethods['newList'](self,*args)
 * 
 *      def newMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newMat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1971newMat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1970newMat, "From Giac's documentation:\n        Help for newMat:\n        newMat(Intg(n),Intg(p))\n        Returns the list with n rows and p columns, made with zeros.\n        See also: 1/ newList 2/ makemat \n        Ex1:newMat(2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1971newMat = {"newMat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1971newMat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1970newMat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1971newMat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newMat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "newMat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1970newMat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1970newMat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newMat", 1);

  /* "giacpy/auto-methods.pxi":12186
 * 
 *         '''
 *         return GiacMethods['newMat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def newton(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_newMat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12186, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12177
 *         return GiacMethods['newList'](self,*args)
 * 
 *      def newMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newMat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.newMat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12188
 *         return GiacMethods['newMat'](self,*args)
 * 
 *      def newton(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1973newton(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1972newton, "From Giac's documentation:\n        Help for newton:\n        newton(Expr(f(x)),Var(x),[ApproxVal(a),NumIter(p)])\n        newton(f(x),x,a,p)=one root of f(x) by Newton method beginning with a and p iterations (by default p=20).\n        See also: 1/ rootof \n        Ex1:newton(x^2-2,x)\n        Ex2:newton(x^2-2,x,2)\n        Ex3:newton(x^2-2,x,-2)\n        Ex4:newton(x^2-2,x,2,5,1e-7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1973newton = {"newton", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1973newton, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1972newton};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1973newton(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newton (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "newton", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1972newton(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1972newton(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newton", 1);

  /* "giacpy/auto-methods.pxi":12200
 * 
 *         '''
 *         return GiacMethods['newton'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def newton_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_newton); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12200, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12188
 *         return GiacMethods['newMat'](self,*args)
 * 
 *      def newton(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.newton", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12202
 *         return GiacMethods['newton'](self,*args)
 * 
 *      def newton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1975newton_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1974newton_solver, "From Giac's documentation:\n        Help for newton_solver:\n        newton_solver(Opt)\n        Argument for fsolve giving the method for solving a numerical equation.\n        See also: 1/ fsolve \n        Ex1: fsolve(cos(x)=x,x,0..1,bisection_solver)\n        Ex2: fsolve(cos(x)=x,x,0..1,brent_solver)\n        Ex3: fsolve(cos(x)=x,x,0..1,falsepos_solver)\n        Ex4: fsolve(cos(x)=x,x,0,newton_solver)\n        Ex5: fsolve(cos(x)=x,x,0,secant_solver)\n        Ex6: fsolve(cos(x)=x,x,0,steffenson_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1975newton_solver = {"newton_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1975newton_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1974newton_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1975newton_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newton_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "newton_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1974newton_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1974newton_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newton_solver", 1);

  /* "giacpy/auto-methods.pxi":12216
 * 
 *         '''
 *         return GiacMethods['newton_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def newtonj_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_newton_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12216, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12202
 *         return GiacMethods['newton'](self,*args)
 * 
 *      def newton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.newton_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12218
 *         return GiacMethods['newton_solver'](self,*args)
 * 
 *      def newtonj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newtonj_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1977newtonj_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1976newtonj_solver, "From Giac's documentation:\n        Help for newtonj_solver:\n        newtonj_solver(Opt)\n        Argument for fsolve giving the method for solving a system of numerical equations.\n        See also: 1/ fsolve \n        Ex1: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],dnewton_solver)\n        Ex2: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrid_solver)\n        Ex3: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybrids_solver)\n        Ex4: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridj_solver)\n        Ex5: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],hybridsj_solver)\n        Ex6: fsolve([x^2+y-2,x+y^2-2],[x,y],[2,2],newtonj_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1977newtonj_solver = {"newtonj_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1977newtonj_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1976newtonj_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1977newtonj_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("newtonj_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "newtonj_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1976newtonj_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1976newtonj_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("newtonj_solver", 1);

  /* "giacpy/auto-methods.pxi":12232
 * 
 *         '''
 *         return GiacMethods['newtonj_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nextperm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_newtonj_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12232, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12218
 *         return GiacMethods['newton_solver'](self,*args)
 * 
 *      def newtonj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newtonj_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.newtonj_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12234
 *         return GiacMethods['newtonj_solver'](self,*args)
 * 
 *      def nextperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextperm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1979nextperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1978nextperm, "From Giac's documentation:\n        Help for nextperm:\n        nextperm(Intg(n))\n        Returns the next permutation with the lexicographic order.\n        See also: 1/ prevperm 2/ is_permu \n        Ex1:nextperm([0,2,1,3])\n        Ex2:nextperm([0,3,2,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1979nextperm = {"nextperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1979nextperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1978nextperm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1979nextperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nextperm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nextperm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1978nextperm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1978nextperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nextperm", 1);

  /* "giacpy/auto-methods.pxi":12244
 * 
 *         '''
 *         return GiacMethods['nextperm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nextprime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nextperm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12244, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12234
 *         return GiacMethods['newtonj_solver'](self,*args)
 * 
 *      def nextperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextperm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nextperm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12246
 *         return GiacMethods['nextperm'](self,*args)
 * 
 *      def nextprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextprime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1981nextprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1980nextprime, "From Giac's documentation:\n        Help for nextprime:\n        nextprime(Intg(a))\n        Next prime or pseudo-prime after a given integer.\n        See also: 1/ prevprime 2/ is_prime 3/ ithprime \n        Ex1:nextprime(9856989898990)\n        Ex2:nextprime(97160249868928888261606009)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1981nextprime = {"nextprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1981nextprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1980nextprime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1981nextprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nextprime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nextprime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1980nextprime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1980nextprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nextprime", 1);

  /* "giacpy/auto-methods.pxi":12256
 * 
 *         '''
 *         return GiacMethods['nextprime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_binary(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nextprime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12256, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12246
 *         return GiacMethods['nextperm'](self,*args)
 * 
 *      def nextprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextprime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nextprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12258
 *         return GiacMethods['nextprime'](self,*args)
 * 
 *      def nlp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binary:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1983nlp_binary(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1982nlp_binary, "From Giac's documentation:\n        Help for nlp_binary:\n        nlp_binary(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1983nlp_binary = {"nlp_binary", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1983nlp_binary, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1982nlp_binary};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1983nlp_binary(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_binary (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_binary", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1982nlp_binary(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1982nlp_binary(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_binary", 1);

  /* "giacpy/auto-methods.pxi":12266
 * 
 *         '''
 *         return GiacMethods['nlp_binary'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_binaryvariables(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_binary); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12266, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12258
 *         return GiacMethods['nextprime'](self,*args)
 * 
 *      def nlp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binary:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12268
 *         return GiacMethods['nlp_binary'](self,*args)
 * 
 *      def nlp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binaryvariables:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1985nlp_binaryvariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1984nlp_binaryvariables, "From Giac's documentation:\n        Help for nlp_binaryvariables:\n        nlp_binaryvariables(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1985nlp_binaryvariables = {"nlp_binaryvariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1985nlp_binaryvariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1984nlp_binaryvariables};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1985nlp_binaryvariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_binaryvariables (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_binaryvariables", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1984nlp_binaryvariables(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1984nlp_binaryvariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_binaryvariables", 1);

  /* "giacpy/auto-methods.pxi":12276
 * 
 *         '''
 *         return GiacMethods['nlp_binaryvariables'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_initialpoint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_binaryvariables); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12276, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12268
 *         return GiacMethods['nlp_binary'](self,*args)
 * 
 *      def nlp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binaryvariables:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_binaryvariables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12278
 *         return GiacMethods['nlp_binaryvariables'](self,*args)
 * 
 *      def nlp_initialpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_initialpoint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1987nlp_initialpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1986nlp_initialpoint, "From Giac's documentation:\n        Help for nlp_initialpoint:\n        nlp_initialpoint(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1987nlp_initialpoint = {"nlp_initialpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1987nlp_initialpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1986nlp_initialpoint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1987nlp_initialpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_initialpoint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_initialpoint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1986nlp_initialpoint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1986nlp_initialpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_initialpoint", 1);

  /* "giacpy/auto-methods.pxi":12286
 * 
 *         '''
 *         return GiacMethods['nlp_initialpoint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_integer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_initialpoint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12286, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12278
 *         return GiacMethods['nlp_binaryvariables'](self,*args)
 * 
 *      def nlp_initialpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_initialpoint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_initialpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12288
 *         return GiacMethods['nlp_initialpoint'](self,*args)
 * 
 *      def nlp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1989nlp_integer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1988nlp_integer, "From Giac's documentation:\n        Help for nlp_integer:\n        nlp_integer(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1989nlp_integer = {"nlp_integer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1989nlp_integer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1988nlp_integer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1989nlp_integer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_integer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_integer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1988nlp_integer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1988nlp_integer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_integer", 1);

  /* "giacpy/auto-methods.pxi":12296
 * 
 *         '''
 *         return GiacMethods['nlp_integer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_integervariables(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_integer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12296, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12288
 *         return GiacMethods['nlp_initialpoint'](self,*args)
 * 
 *      def nlp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_integer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12298
 *         return GiacMethods['nlp_integer'](self,*args)
 * 
 *      def nlp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integervariables:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1991nlp_integervariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1990nlp_integervariables, "From Giac's documentation:\n        Help for nlp_integervariables:\n        nlp_integervariables(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1991nlp_integervariables = {"nlp_integervariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1991nlp_integervariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1990nlp_integervariables};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1991nlp_integervariables(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_integervariables (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_integervariables", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1990nlp_integervariables(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1990nlp_integervariables(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_integervariables", 1);

  /* "giacpy/auto-methods.pxi":12306
 * 
 *         '''
 *         return GiacMethods['nlp_integervariables'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_iterationlimit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_integervariables); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12306, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12298
 *         return GiacMethods['nlp_integer'](self,*args)
 * 
 *      def nlp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integervariables:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_integervariables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12308
 *         return GiacMethods['nlp_integervariables'](self,*args)
 * 
 *      def nlp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_iterationlimit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1993nlp_iterationlimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1992nlp_iterationlimit, "From Giac's documentation:\n        Help for nlp_iterationlimit:\n        nlp_iterationlimit(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1993nlp_iterationlimit = {"nlp_iterationlimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1993nlp_iterationlimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1992nlp_iterationlimit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1993nlp_iterationlimit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_iterationlimit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_iterationlimit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1992nlp_iterationlimit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1992nlp_iterationlimit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_iterationlimit", 1);

  /* "giacpy/auto-methods.pxi":12316
 * 
 *         '''
 *         return GiacMethods['nlp_iterationlimit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_maximize(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_iterationlimit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12316, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12308
 *         return GiacMethods['nlp_integervariables'](self,*args)
 * 
 *      def nlp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_iterationlimit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_iterationlimit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12318
 *         return GiacMethods['nlp_iterationlimit'](self,*args)
 * 
 *      def nlp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_maximize:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1995nlp_maximize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1994nlp_maximize, "From Giac's documentation:\n        Help for nlp_maximize:\n        nlp_maximize(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1995nlp_maximize = {"nlp_maximize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1995nlp_maximize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1994nlp_maximize};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1995nlp_maximize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_maximize (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_maximize", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1994nlp_maximize(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1994nlp_maximize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_maximize", 1);

  /* "giacpy/auto-methods.pxi":12326
 * 
 *         '''
 *         return GiacMethods['nlp_maximize'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_method(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_maximize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12326, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12318
 *         return GiacMethods['nlp_iterationlimit'](self,*args)
 * 
 *      def nlp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_maximize:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_maximize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12328
 *         return GiacMethods['nlp_maximize'](self,*args)
 * 
 *      def nlp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_method:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1997nlp_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1996nlp_method, "From Giac's documentation:\n        Help for nlp_method:\n        nlp_method(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1997nlp_method = {"nlp_method", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1997nlp_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1996nlp_method};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1997nlp_method(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_method (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_method", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1996nlp_method(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1996nlp_method(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_method", 1);

  /* "giacpy/auto-methods.pxi":12336
 * 
 *         '''
 *         return GiacMethods['nlp_method'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_nonnegative(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_method); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12336, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12328
 *         return GiacMethods['nlp_maximize'](self,*args)
 * 
 *      def nlp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_method:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_method", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12338
 *         return GiacMethods['nlp_method'](self,*args)
 * 
 *      def nlp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegative:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1999nlp_nonnegative(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1998nlp_nonnegative, "From Giac's documentation:\n        Help for nlp_nonnegative:\n        nlp_nonnegative(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1999nlp_nonnegative = {"nlp_nonnegative", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1999nlp_nonnegative, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1998nlp_nonnegative};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1999nlp_nonnegative(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_nonnegative (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_nonnegative", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1998nlp_nonnegative(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_1998nlp_nonnegative(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_nonnegative", 1);

  /* "giacpy/auto-methods.pxi":12346
 * 
 *         '''
 *         return GiacMethods['nlp_nonnegative'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_nonnegint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_nonnegative); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12346, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12338
 *         return GiacMethods['nlp_method'](self,*args)
 * 
 *      def nlp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegative:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_nonnegative", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12348
 *         return GiacMethods['nlp_nonnegative'](self,*args)
 * 
 *      def nlp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2001nlp_nonnegint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2000nlp_nonnegint, "From Giac's documentation:\n        Help for nlp_nonnegint:\n        nlp_nonnegint(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2001nlp_nonnegint = {"nlp_nonnegint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2001nlp_nonnegint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2000nlp_nonnegint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2001nlp_nonnegint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_nonnegint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_nonnegint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2000nlp_nonnegint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2000nlp_nonnegint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_nonnegint", 1);

  /* "giacpy/auto-methods.pxi":12356
 * 
 *         '''
 *         return GiacMethods['nlp_nonnegint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_precision(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_nonnegint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12356, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12348
 *         return GiacMethods['nlp_nonnegative'](self,*args)
 * 
 *      def nlp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_nonnegint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12358
 *         return GiacMethods['nlp_nonnegint'](self,*args)
 * 
 *      def nlp_precision(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_precision:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2003nlp_precision(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2002nlp_precision, "From Giac's documentation:\n        Help for nlp_precision:\n        nlp_precision(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2003nlp_precision = {"nlp_precision", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2003nlp_precision, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2002nlp_precision};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2003nlp_precision(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_precision (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_precision", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2002nlp_precision(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2002nlp_precision(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_precision", 1);

  /* "giacpy/auto-methods.pxi":12366
 * 
 *         '''
 *         return GiacMethods['nlp_precision'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_presolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_precision); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12366, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12358
 *         return GiacMethods['nlp_nonnegint'](self,*args)
 * 
 *      def nlp_precision(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_precision:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_precision", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12368
 *         return GiacMethods['nlp_precision'](self,*args)
 * 
 *      def nlp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_presolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2005nlp_presolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2004nlp_presolve, "From Giac's documentation:\n        Help for nlp_presolve:\n        nlp_presolve(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2005nlp_presolve = {"nlp_presolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2005nlp_presolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2004nlp_presolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2005nlp_presolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_presolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_presolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2004nlp_presolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2004nlp_presolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_presolve", 1);

  /* "giacpy/auto-methods.pxi":12376
 * 
 *         '''
 *         return GiacMethods['nlp_presolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_tolerance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_presolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12376, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12368
 *         return GiacMethods['nlp_precision'](self,*args)
 * 
 *      def nlp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_presolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_presolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12378
 *         return GiacMethods['nlp_presolve'](self,*args)
 * 
 *      def nlp_tolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_tolerance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2007nlp_tolerance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2006nlp_tolerance, "From Giac's documentation:\n        Help for nlp_tolerance:\n        nlp_tolerance(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2007nlp_tolerance = {"nlp_tolerance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2007nlp_tolerance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2006nlp_tolerance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2007nlp_tolerance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_tolerance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_tolerance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2006nlp_tolerance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2006nlp_tolerance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_tolerance", 1);

  /* "giacpy/auto-methods.pxi":12386
 * 
 *         '''
 *         return GiacMethods['nlp_tolerance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlp_verbose(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_tolerance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12386, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12378
 *         return GiacMethods['nlp_presolve'](self,*args)
 * 
 *      def nlp_tolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_tolerance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_tolerance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12388
 *         return GiacMethods['nlp_tolerance'](self,*args)
 * 
 *      def nlp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_verbose:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2009nlp_verbose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2008nlp_verbose, "From Giac's documentation:\n        Help for nlp_verbose:\n        nlp_verbose(Opt)\n        Options for nlpsolve command.\n        See also: 1/ nlpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2009nlp_verbose = {"nlp_verbose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2009nlp_verbose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2008nlp_verbose};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2009nlp_verbose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlp_verbose (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlp_verbose", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2008nlp_verbose(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2008nlp_verbose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlp_verbose", 1);

  /* "giacpy/auto-methods.pxi":12396
 * 
 *         '''
 *         return GiacMethods['nlp_verbose'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nlpsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlp_verbose); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12396, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12388
 *         return GiacMethods['nlp_tolerance'](self,*args)
 * 
 *      def nlp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_verbose:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlp_verbose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12398
 *         return GiacMethods['nlp_verbose'](self,*args)
 * 
 *      def nlpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlpsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2011nlpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2010nlpsolve, "From Giac's documentation:\n        Help for nlpsolve:\n        nlpsolve(Expr(objective),[Lst(constr)],[Seq(bd)],[Seq(opts)])\n        Solves a nonlinear programming problem of optimizing the objective under constraints constr (list of equations and/or inequations) and within bounds bd (sequence of x=a..b) with optional options (for example setting an initial point or integrality constraints).\n        See also: 1/ minimize 2/ maximize 3/ fMin 4/ fMax 5/ box_constraints 6/ lpsolve 7/ fsolve \n        Ex1:nlpsolve((x1-10)^3+(x2-20)^3,[(x1-5)^2+(x2-5)^2>=100,(x2-5)^2+(x1-6)^2<=82.81],nlp_initialpoint=[x1=20.1,x2=5.84])\n        Ex2:nlpsolve(sin(x1+x2)+(x1-x2)^2-1.5x1+2.5x2+1,x1=-1.5..4,x2=-3..3)\n        Ex3:nlpsolve(2-1/120*x1*x2*x3*x4*x5,[x1<=1,x2<=2,x3<=3,x4<=4,x5<=5],assume=nlp_nonnegative)\n        Ex4:nlpsolve(x1^2/2+5x1+6x2,[6x1+x2^2<=23],[x1,x2]=1..5,assume=integer,maximize)\n        Ex5:nlpsolve(4x1*x2*x3-x1*x2-x1*x3-x2*x3,assume=nlp_binary)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2011nlpsolve = {"nlpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2011nlpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2010nlpsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2011nlpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nlpsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nlpsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2010nlpsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2010nlpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nlpsolve", 1);

  /* "giacpy/auto-methods.pxi":12411
 * 
 *         '''
 *         return GiacMethods['nlpsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nodisp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nlpsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12411, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12398
 *         return GiacMethods['nlp_verbose'](self,*args)
 * 
 *      def nlpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlpsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nlpsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12413
 *         return GiacMethods['nlpsolve'](self,*args)
 * 
 *      def nodisp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nodisp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2013nodisp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2012nodisp, "From Giac's documentation:\n        Help for nodisp:\n        nodisp(Expr)\n        Displays Done in place of a value.\n        Ex1:nodisp(A:=ranm(50,50))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2013nodisp = {"nodisp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2013nodisp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2012nodisp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2013nodisp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nodisp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nodisp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2012nodisp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2012nodisp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nodisp", 1);

  /* "giacpy/auto-methods.pxi":12421
 * 
 *         '''
 *         return GiacMethods['nodisp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def non_recursive_normal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nodisp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12421, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12413
 *         return GiacMethods['nlpsolve'](self,*args)
 * 
 *      def nodisp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nodisp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nodisp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12423
 *         return GiacMethods['nodisp'](self,*args)
 * 
 *      def non_recursive_normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for non_recursive_normal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2015non_recursive_normal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2014non_recursive_normal, "From Giac's documentation:\n        Help for non_recursive_normal:\n        non_recursive_normal(Expr)\n        Simplifies the expressions, but without simplification inside of non-rational expressions.\n        See also: 1/ normal \n        Ex1:non_recursive_normal(sin(x+x)+sin(2*x)+x+x)\n        Ex2:non_recursive_normal(sin(2*x)+sin(2*x)+x+x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2015non_recursive_normal = {"non_recursive_normal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2015non_recursive_normal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2014non_recursive_normal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2015non_recursive_normal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("non_recursive_normal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "non_recursive_normal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2014non_recursive_normal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2014non_recursive_normal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("non_recursive_normal", 1);

  /* "giacpy/auto-methods.pxi":12433
 * 
 *         '''
 *         return GiacMethods['non_recursive_normal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nonnegint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_non_recursive_normal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12433, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12423
 *         return GiacMethods['nodisp'](self,*args)
 * 
 *      def non_recursive_normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for non_recursive_normal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.non_recursive_normal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12435
 *         return GiacMethods['non_recursive_normal'](self,*args)
 * 
 *      def nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nonnegint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2017nonnegint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2016nonnegint, "From Giac's documentation:\n        Help for nonnegint:\n        nonnegint(Opt)\n        Options for lpsolve command.\n        See also: 1/ lpsolve \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2017nonnegint = {"nonnegint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2017nonnegint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2016nonnegint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2017nonnegint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonnegint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nonnegint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2016nonnegint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2016nonnegint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonnegint", 1);

  /* "giacpy/auto-methods.pxi":12443
 * 
 *         '''
 *         return GiacMethods['nonnegint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nop(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nonnegint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12443, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12435
 *         return GiacMethods['non_recursive_normal'](self,*args)
 * 
 *      def nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nonnegint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nonnegint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12445
 *         return GiacMethods['nonnegint'](self,*args)
 * 
 *      def nop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nop:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2019nop(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2018nop, "From Giac's documentation:\n        Help for nop:\n        nop(NULL)\n        No OPeration instruction.\n        See also: 1/  \n        Ex1:nop()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2019nop = {"nop", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2019nop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2018nop};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2019nop(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nop (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nop", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2018nop(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2018nop(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nop", 1);

  /* "giacpy/auto-methods.pxi":12454
 * 
 *         '''
 *         return GiacMethods['nop'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nops(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12454, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12445
 *         return GiacMethods['nonnegint'](self,*args)
 * 
 *      def nop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nop:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12456
 *         return GiacMethods['nop'](self,*args)
 * 
 *      def nops(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nops:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2021nops(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2020nops, "From Giac's documentation:\n        Help for nops:\n        nops(Lst||Str||Seq||Image||Audio)\n        Returns the size of a list, a string, a sequence, an image object or an audio clip.\n        See also: 1/ sizes 2/ dim 3/ degree \n        Ex1:nops([1,2,3])\n        Ex2:nops(\"bonjour\")\n        Ex3:nops(1,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2021nops = {"nops", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2021nops, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2020nops};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2021nops(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nops (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nops", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2020nops(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2020nops(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nops", 1);

  /* "giacpy/auto-methods.pxi":12467
 * 
 *         '''
 *         return GiacMethods['nops'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def norm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nops); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12467, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12456
 *         return GiacMethods['nop'](self,*args)
 * 
 *      def nops(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nops:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nops", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12469
 *         return GiacMethods['nops'](self,*args)
 * 
 *      def norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for norm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2023norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2022norm, "From Giac's documentation:\n        Help for norm:\n        norm(Vect or Mtrx)\n        Returns the l2 norm of a vector = sqrt(x1^2+x2^2+...xn^2) or matrix norm induced by l2 norm.\n        See also: 1/ maxnorm 2/ l1norm \n        Ex1:norm([1,2])\n        Ex2:norm([1,2,3,-4])\n        Ex3:norm([[1,2],[3,-4]])\n        Ex4:norm([[1,2,3],[3,-9,6],[4,5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2023norm = {"norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2023norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2022norm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2023norm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("norm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "norm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2022norm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2022norm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("norm", 1);

  /* "giacpy/auto-methods.pxi":12481
 * 
 *         '''
 *         return GiacMethods['norm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12481, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12469
 *         return GiacMethods['nops'](self,*args)
 * 
 *      def norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for norm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.norm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12483
 *         return GiacMethods['norm'](self,*args)
 * 
 *      def normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2025normal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2024normal, "From Giac's documentation:\n        Help for normal:\n        normal(Expr)\n        Simplifies the expression.\n        See also: 1/ simplify \n        Ex1:normal(2*x+y=1)\n        Ex2:normal(2*x*2)\n        Ex3:normal((2*x+1)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2025normal = {"normal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2025normal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2024normal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2025normal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2024normal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2024normal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normal", 1);

  /* "giacpy/auto-methods.pxi":12494
 * 
 *         '''
 *         return GiacMethods['normal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normal_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12494, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12483
 *         return GiacMethods['norm'](self,*args)
 * 
 *      def normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12496
 *         return GiacMethods['normal'](self,*args)
 * 
 *      def normal_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2027normal_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2026normal_cdf, "From Giac's documentation:\n        Help for normal_cdf:\n        normal_cdf(Real(mu),Real(sigma),Real(x0),[Real(y0)])\n        Returns the probability that a Normal random variable is less than x0 or between x0 and y0 (mu is the mean and sigma the standard deviation).\n        See also: 1/ UTPN 2/ normal_icdf 3/ normald \n        Ex1:normal_cdf(1.96)\n        Ex2:normal_cdf(1,2,2.96*sqrt(2))\n        Ex3:normal_cdf(1,2,1.4*sqrt(2),2.96*sqrt(2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2027normal_cdf = {"normal_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2027normal_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2026normal_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2027normal_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normal_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normal_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2026normal_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2026normal_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normal_cdf", 1);

  /* "giacpy/auto-methods.pxi":12507
 * 
 *         '''
 *         return GiacMethods['normal_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normal_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normal_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12507, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12496
 *         return GiacMethods['normal'](self,*args)
 * 
 *      def normal_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normal_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12509
 *         return GiacMethods['normal_cdf'](self,*args)
 * 
 *      def normal_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2029normal_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2028normal_icdf, "From Giac's documentation:\n        Help for normal_icdf:\n        normal_icdf(Real(mu),Real(sigma),Real(p))\n        Returns h such as the probability that a Normal random variable is less than h is p (mu is the mean and sigma the standard deviation and 0<=p<=1).\n        See also: 1/ normal_cdf 2/ normald \n        Ex1:normal_icdf(0.95)\n        Ex2:normal_icdf(1,2,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2029normal_icdf = {"normal_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2029normal_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2028normal_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2029normal_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normal_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normal_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2028normal_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2028normal_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normal_icdf", 1);

  /* "giacpy/auto-methods.pxi":12519
 * 
 *         '''
 *         return GiacMethods['normal_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normald(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normal_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12519, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12509
 *         return GiacMethods['normal_cdf'](self,*args)
 * 
 *      def normal_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normal_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12521
 *         return GiacMethods['normal_icdf'](self,*args)
 * 
 *      def normald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2031normald(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2030normald, "From Giac's documentation:\n        Help for normald:\n        normald(Real(mu),Real(sigma),Real(x0))\n        Returns the probability density of the Normal law (mu is the mean and sigma the standard deviation).\n        See also: 1/ normal_cdf 2/ normal_icdf 3/ randvector 4/ ranm \n        Ex1:normald(1)\n        Ex2:normald(1,2,3.5)\n        Ex3: randvector(3,normald,1,0.5)\n        Ex4: ranm(4,3,normald,1,0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2031normald = {"normald", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2031normald, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2030normald};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2031normald(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normald (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normald", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2030normald(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2030normald(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normald", 1);

  /* "giacpy/auto-methods.pxi":12533
 * 
 *         '''
 *         return GiacMethods['normald'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normald_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normald); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12533, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12521
 *         return GiacMethods['normal_icdf'](self,*args)
 * 
 *      def normald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normald", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12535
 *         return GiacMethods['normald'](self,*args)
 * 
 *      def normald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2033normald_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2032normald_cdf, "From Giac's documentation:\n        Help for normald_cdf:\n        normald_cdf(Real(mu),Real(sigma),Real(x0),[Real(y0)])\n        Returns the probability that a Normal random variable is less than x0 or between x0 and y0 (mu is the mean and sigma the standard deviation).\n        See also: 1/ UTPN 2/ normal_icdf 3/ normald \n        Ex1:normald_cdf(1.96)\n        Ex2:normald_cdf(1,2,2.96*sqrt(2))\n        Ex3:normald_cdf(1,2,1.4*sqrt(2),2.96*sqrt(2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2033normald_cdf = {"normald_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2033normald_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2032normald_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2033normald_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normald_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normald_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2032normald_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2032normald_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normald_cdf", 1);

  /* "giacpy/auto-methods.pxi":12546
 * 
 *         '''
 *         return GiacMethods['normald_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normald_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normald_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12546, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12535
 *         return GiacMethods['normald'](self,*args)
 * 
 *      def normald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normald_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12548
 *         return GiacMethods['normald_cdf'](self,*args)
 * 
 *      def normald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2035normald_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2034normald_icdf, "From Giac's documentation:\n        Help for normald_icdf:\n        normald_icdf(Real(mu),Real(sigma),Real(p))\n        Returns h such as the probability that a Normal random variable is less than h is p (mu is the mean and sigma the standard deviation and 0<=p<=1).\n        See also: 1/ normal_cdf 2/ normald \n        Ex1:normald_icdf(0.95)\n        Ex2:normald_icdf(1,2,0.95)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2035normald_icdf = {"normald_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2035normald_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2034normald_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2035normald_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normald_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normald_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2034normald_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2034normald_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normald_icdf", 1);

  /* "giacpy/auto-methods.pxi":12558
 * 
 *         '''
 *         return GiacMethods['normald_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normalize(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normald_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12558, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12548
 *         return GiacMethods['normald_cdf'](self,*args)
 * 
 *      def normald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normald_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12560
 *         return GiacMethods['normald_icdf'](self,*args)
 * 
 *      def normalize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalize:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2037normalize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2036normalize, "From Giac's documentation:\n        Help for normalize:\n        normalize(Lst||Cplx||Audio)\n        Returns the vector divided by its l2norm or normalizes an audio clip. It is also an option for plotfield.\n        See also: 1/ l2norm \n        Ex1:normalize(3+4*i)\n        Ex2:normalize([3,4])\n        Ex3: fieldplot(-t*y,[t,y],normalize)\n        Ex4: fieldplot(-t*y,[t,y],normalize,xstep=0.5,ystep=0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2037normalize = {"normalize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2037normalize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2036normalize};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2037normalize(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normalize (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normalize", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2036normalize(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2036normalize(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normalize", 1);

  /* "giacpy/auto-methods.pxi":12572
 * 
 *         '''
 *         return GiacMethods['normalize'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normalt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normalize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12572, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12560
 *         return GiacMethods['normald_icdf'](self,*args)
 * 
 *      def normalize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalize:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12574
 *         return GiacMethods['normalize'](self,*args)
 * 
 *      def normalt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2039normalt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2038normalt, "From Giac's documentation:\n        Help for normalt:\n        normalt(Lst,Real,[Real],Fnc,[Real])\n        Z-Test/normal law: arg1=[success,trial] or [mean,sample size] or data, arg2=proportion or data, arg3 optional if data=sigma, arg4 alternative '!=' or '>' or '<', arg5 optional alpha confidence level.\n        See also: 1/ studentt 2/ chisquaret 3/ kolmogorovt \n        Ex1:normalt([10,30],.5,.02,'!=',0.1)\n        Ex2:normalt([0.48,50],0.5,0.1,'<')\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2039normalt = {"normalt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2039normalt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2038normalt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2039normalt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normalt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normalt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2038normalt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2038normalt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normalt", 1);

  /* "giacpy/auto-methods.pxi":12584
 * 
 *         '''
 *         return GiacMethods['normalt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def normalvariate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normalt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12584, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12574
 *         return GiacMethods['normalize'](self,*args)
 * 
 *      def normalt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normalt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12586
 *         return GiacMethods['normalt'](self,*args)
 * 
 *      def normalvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalvariate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2041normalvariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2040normalvariate, "From Giac's documentation:\n        Help for normalvariate:\n        normalvariate(Real(mu),Real(sigma))\n        Returns a random real with normal distribution N(mu,sigma).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randpoisson 8/ randgeometric 9/ randmultinomial \n        Ex1:normalvariate(0,1)\n        Ex2:normalvariate(2,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2041normalvariate = {"normalvariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2041normalvariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2040normalvariate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2041normalvariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("normalvariate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "normalvariate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2040normalvariate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2040normalvariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("normalvariate", 1);

  /* "giacpy/auto-methods.pxi":12596
 * 
 *         '''
 *         return GiacMethods['normalvariate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nprimes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_normalvariate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12596, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12586
 *         return GiacMethods['normalt'](self,*args)
 * 
 *      def normalvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalvariate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.normalvariate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12598
 *         return GiacMethods['normalvariate'](self,*args)
 * 
 *      def nprimes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nprimes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2043nprimes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2042nprimes, "From Giac's documentation:\n        Help for nprimes:\n        nprimes(Intg(n))\n        Counts the number of primes less than n.\n        See also: 1/ ithprime 2/ prevprime 3/ nextprime 4/ isprime \n        Ex1:nprimes(20)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2043nprimes = {"nprimes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2043nprimes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2042nprimes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2043nprimes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nprimes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nprimes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2042nprimes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2042nprimes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nprimes", 1);

  /* "giacpy/auto-methods.pxi":12607
 * 
 *         '''
 *         return GiacMethods['nprimes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nrows(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nprimes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12607, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12598
 *         return GiacMethods['normalvariate'](self,*args)
 * 
 *      def nprimes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nprimes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nprimes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12609
 *         return GiacMethods['nprimes'](self,*args)
 * 
 *      def nrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nrows:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2045nrows(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2044nrows, "From Giac's documentation:\n        Help for nrows:\n        nrows(Mtrx)\n        Number of rows of a matrix.\n        See also: 1/ ncols \n        Ex1:nrows([[1,2,3],[4,5,6]])\n        Ex2:nrows([[1,2],[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2045nrows = {"nrows", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2045nrows, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2044nrows};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2045nrows(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nrows (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nrows", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2044nrows(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2044nrows(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nrows", 1);

  /* "giacpy/auto-methods.pxi":12619
 * 
 *         '''
 *         return GiacMethods['nrows'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nstep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nrows); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12619, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12609
 *         return GiacMethods['nprimes'](self,*args)
 * 
 *      def nrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nrows:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nrows", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12621
 *         return GiacMethods['nrows'](self,*args)
 * 
 *      def nstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nstep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2047nstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2046nstep, "From Giac's documentation:\n        Help for nstep:\n        nstep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2047nstep = {"nstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2047nstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2046nstep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2047nstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nstep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nstep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2046nstep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2046nstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nstep", 1);

  /* "giacpy/auto-methods.pxi":12628
 * 
 *         '''
 *         return GiacMethods['nstep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nuage_points(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nstep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12628, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12621
 *         return GiacMethods['nrows'](self,*args)
 * 
 *      def nstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nstep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nstep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12630
 *         return GiacMethods['nstep'](self,*args)
 * 
 *      def nuage_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nuage_points:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2049nuage_points(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2048nuage_points, "From Giac's documentation:\n        Help for nuage_points:\n        nuage_points(Mtrx)\n        Draws for k=0..nrows, the points (xk,yk) where xk=element row k column 0 and yk=element row k column j (j=1..ncols).\n        See also: 1/ polygonplot 2/ polygonscatterplot 3/ listplot \n        Ex1:nuage_points([[1,2,3],[2,0,1],[-1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2049nuage_points = {"nuage_points", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2049nuage_points, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2048nuage_points};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2049nuage_points(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nuage_points (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nuage_points", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2048nuage_points(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2048nuage_points(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nuage_points", 1);

  /* "giacpy/auto-methods.pxi":12639
 * 
 *         '''
 *         return GiacMethods['nuage_points'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def nullspace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nuage_points); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12639, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12630
 *         return GiacMethods['nstep'](self,*args)
 * 
 *      def nuage_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nuage_points:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nuage_points", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12641
 *         return GiacMethods['nuage_points'](self,*args)
 * 
 *      def nullspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nullspace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2051nullspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2050nullspace, "From Giac's documentation:\n        Help for nullspace:\n        nullspace(Mtrx)\n        Kernel of a linear map with matrix M.\n        See also: 1/ image 2/ rref 3/ Nullspace \n        Ex1:nullspace([[1,2],[3,6]])\n        Ex2:nullspace([[1,2,3],[1,3,6],[2,5,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2051nullspace = {"nullspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2051nullspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2050nullspace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2051nullspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nullspace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "nullspace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2050nullspace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2050nullspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nullspace", 1);

  /* "giacpy/auto-methods.pxi":12651
 * 
 *         '''
 *         return GiacMethods['nullspace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def number_of_edges(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_nullspace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12651, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12641
 *         return GiacMethods['nuage_points'](self,*args)
 * 
 *      def nullspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nullspace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.nullspace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12653
 *         return GiacMethods['nullspace'](self,*args)
 * 
 *      def number_of_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_edges:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2053number_of_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2052number_of_edges, "From Giac's documentation:\n        Help for number_of_edges:\n        number_of_edges(Graph(G))\n        Returns the number of edges/arcs in G.\n        See also: 1/ edges 2/ number_of_vertices \n        Ex1:number_of_edges(complete_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2053number_of_edges = {"number_of_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2053number_of_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2052number_of_edges};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2053number_of_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("number_of_edges (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "number_of_edges", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2052number_of_edges(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2052number_of_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("number_of_edges", 1);

  /* "giacpy/auto-methods.pxi":12662
 * 
 *         '''
 *         return GiacMethods['number_of_edges'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def number_of_spanning_trees(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_number_of_edges); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12662, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12653
 *         return GiacMethods['nullspace'](self,*args)
 * 
 *      def number_of_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_edges:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.number_of_edges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12664
 *         return GiacMethods['number_of_edges'](self,*args)
 * 
 *      def number_of_spanning_trees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_spanning_trees:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2055number_of_spanning_trees(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2054number_of_spanning_trees, "From Giac's documentation:\n        Help for number_of_spanning_trees:\n        number_of_spanning_trees(Graph(G))\n        Returns the number of spanning trees in an undirected graph G.\n        See also: 1/ spanning_tree \n        Ex1:number_of_spanning_trees(complete_graph(4))\n        Ex2:number_of_spanning_trees(graph(trail(1,2,3,4,1,3)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2055number_of_spanning_trees = {"number_of_spanning_trees", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2055number_of_spanning_trees, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2054number_of_spanning_trees};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2055number_of_spanning_trees(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("number_of_spanning_trees (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "number_of_spanning_trees", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2054number_of_spanning_trees(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2054number_of_spanning_trees(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("number_of_spanning_trees", 1);

  /* "giacpy/auto-methods.pxi":12674
 * 
 *         '''
 *         return GiacMethods['number_of_spanning_trees'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def number_of_triangles(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_number_of_spanning_trees); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12674, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12664
 *         return GiacMethods['number_of_edges'](self,*args)
 * 
 *      def number_of_spanning_trees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_spanning_trees:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.number_of_spanning_trees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12676
 *         return GiacMethods['number_of_spanning_trees'](self,*args)
 * 
 *      def number_of_triangles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_triangles:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2057number_of_triangles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2056number_of_triangles, "From Giac's documentation:\n        Help for number_of_triangles:\n        number_of_triangles(Graph(G))\n        Returns the number of 3-cliques if G is undirected resp. the number of directed cycles on 3 vertices if G is directed.\n        See also: 1/ is_clique 2/ maximal_clique \n        Ex1:number_of_triangles(graph(\"tetrahedron\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2057number_of_triangles = {"number_of_triangles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2057number_of_triangles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2056number_of_triangles};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2057number_of_triangles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("number_of_triangles (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "number_of_triangles", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2056number_of_triangles(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2056number_of_triangles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("number_of_triangles", 1);

  /* "giacpy/auto-methods.pxi":12685
 * 
 *         '''
 *         return GiacMethods['number_of_triangles'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def number_of_vertices(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_number_of_triangles); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12685, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12676
 *         return GiacMethods['number_of_spanning_trees'](self,*args)
 * 
 *      def number_of_triangles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_triangles:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.number_of_triangles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12687
 *         return GiacMethods['number_of_triangles'](self,*args)
 * 
 *      def number_of_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_vertices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2059number_of_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2058number_of_vertices, "From Giac's documentation:\n        Help for number_of_vertices:\n        number_of_vertices(Graph(G))\n        Returns the number of vertices in G.\n        See also: 1/ graph_vertices 2/ number_of_edges \n        Ex1:number_of_vertices(graph(\"petersen\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2059number_of_vertices = {"number_of_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2059number_of_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2058number_of_vertices};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2059number_of_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("number_of_vertices (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "number_of_vertices", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2058number_of_vertices(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2058number_of_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("number_of_vertices", 1);

  /* "giacpy/auto-methods.pxi":12696
 * 
 *         '''
 *         return GiacMethods['number_of_vertices'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def numdiff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_number_of_vertices); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12696, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12687
 *         return GiacMethods['number_of_triangles'](self,*args)
 * 
 *      def number_of_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_vertices:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.number_of_vertices", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12698
 *         return GiacMethods['number_of_vertices'](self,*args)
 * 
 *      def numdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numdiff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2061numdiff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2060numdiff, "From Giac's documentation:\n        Help for numdiff:\n        numdiff(Lst(X),Lst(Y),Real(x0),[Intg(n)])\n        Returns an approximation of the n-th derivative (n>=0, by default n=1) of the function f given by f(X_i)=Y_i at point x0.\n        See also: 1/ nDeriv 2/ diff \n        Ex1:numdiff([1,3,4],[3,0,1],2)\n        Ex2: f:=unapply(sin(x)*exp(-x),x):;X:=[0,0.1,0.2,0.4,0.5,0.7,0.8,1]:;Y:=apply(f,X):;abs(numdiff(X,Y,1/pi,2)-f''(1/pi))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2061numdiff = {"numdiff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2061numdiff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2060numdiff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2061numdiff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("numdiff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "numdiff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2060numdiff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2060numdiff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("numdiff", 1);

  /* "giacpy/auto-methods.pxi":12708
 * 
 *         '''
 *         return GiacMethods['numdiff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def numer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_numdiff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12708, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12698
 *         return GiacMethods['number_of_vertices'](self,*args)
 * 
 *      def numdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numdiff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.numdiff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12710
 *         return GiacMethods['numdiff'](self,*args)
 * 
 *      def numer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2063numer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2062numer, "From Giac's documentation:\n        Help for numer:\n        numer(Frac(a/b) or RatFrac)\n        Returns the numerator of the simplified fraction.\n        See also: 1/ getNum 2/ getDenom 3/ denom 4/ f2nd \n        Ex1:numer(25/15)\n        Ex2:numer((x^3-1)/(x^2-1))\n        Ex3:numer(1+(x^3-1)/x^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2063numer = {"numer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2063numer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2062numer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2063numer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("numer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "numer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2062numer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2062numer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("numer", 1);

  /* "giacpy/auto-methods.pxi":12721
 * 
 *         '''
 *         return GiacMethods['numer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def octahedron(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_numer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12721, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12710
 *         return GiacMethods['numdiff'](self,*args)
 * 
 *      def numer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.numer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12723
 *         return GiacMethods['numer'](self,*args)
 * 
 *      def octahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for octahedron:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2065octahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2064octahedron, "From Giac's documentation:\n        Help for octahedron:\n        octahedron(Pnt(A),Pnt(B),Pnt(C))\n        Draws an octahedron with center A, vertex B and such that the plane ABC contains 4 vertices.\n        See also: 1/ icosahedron 2/ dodecahedron 3/ cube 4/ tetrahedron \n        Ex1:octahedron([0,0,0],[0,0,5],[0,5,0])\n        Ex2:octahedron(evalf([0,0,0],[3,2,4],[1,1,0]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2065octahedron = {"octahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2065octahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2064octahedron};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2065octahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("octahedron (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "octahedron", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2064octahedron(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2064octahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("octahedron", 1);

  /* "giacpy/auto-methods.pxi":12733
 * 
 *         '''
 *         return GiacMethods['octahedron'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def odd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_octahedron); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12733, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12723
 *         return GiacMethods['numer'](self,*args)
 * 
 *      def octahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for octahedron:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.octahedron", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12735
 *         return GiacMethods['octahedron'](self,*args)
 * 
 *      def odd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2067odd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2066odd, "From Giac's documentation:\n        Help for odd:\n        odd(Intg(n))\n        Returns 1 if the integer is odd, else returns 0.\n        See also: 1/ even \n        Ex1:odd(6)\n        Ex2:odd(1251)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2067odd = {"odd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2067odd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2066odd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2067odd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("odd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "odd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2066odd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2066odd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("odd", 1);

  /* "giacpy/auto-methods.pxi":12745
 * 
 *         '''
 *         return GiacMethods['odd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def odd_girth(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_odd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12745, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12735
 *         return GiacMethods['octahedron'](self,*args)
 * 
 *      def odd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.odd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12747
 *         return GiacMethods['odd'](self,*args)
 * 
 *      def odd_girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_girth:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2069odd_girth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2068odd_girth, "From Giac's documentation:\n        Help for odd_girth:\n        odd_girth(Graph(G))\n        Returns the length of a shortest odd cycle in an undirected unweighted graph G.\n        See also: 1/ girth \n        Ex1:odd_girth(graph(\"petersen\"))\n        Ex2:odd_girth(hypercube_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2069odd_girth = {"odd_girth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2069odd_girth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2068odd_girth};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2069odd_girth(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("odd_girth (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "odd_girth", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2068odd_girth(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2068odd_girth(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("odd_girth", 1);

  /* "giacpy/auto-methods.pxi":12757
 * 
 *         '''
 *         return GiacMethods['odd_girth'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def odd_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_odd_girth); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12757, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12747
 *         return GiacMethods['odd'](self,*args)
 * 
 *      def odd_girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_girth:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.odd_girth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12759
 *         return GiacMethods['odd_girth'](self,*args)
 * 
 *      def odd_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2071odd_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2070odd_graph, "From Giac's documentation:\n        Help for odd_graph:\n        odd_graph(Intg(n))\n        Returns the odd graph of order n as Kneser graph K(2n-1,n-1), where n<=8.\n        See also: 1/ kneser_graph \n        Ex1:odd_graph(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2071odd_graph = {"odd_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2071odd_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2070odd_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2071odd_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("odd_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "odd_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2070odd_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2070odd_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("odd_graph", 1);

  /* "giacpy/auto-methods.pxi":12768
 * 
 *         '''
 *         return GiacMethods['odd_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def odeplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_odd_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12768, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12759
 *         return GiacMethods['odd_girth'](self,*args)
 * 
 *      def odd_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.odd_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12770
 *         return GiacMethods['odd_graph'](self,*args)
 * 
 *      def odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odeplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2073odeplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2072odeplot, "From Giac's documentation:\n        Help for odeplot:\n        odeplot(Expr,VectVar,VectInitCond)\n        plotode(f(t,y),[t,y],[t0,y0]) draws the solution of y'=f(t,y) and y(t0)=y0 or of the system [x'=g(t,x,y),y'=h(t,x,y)] with x(t0)=x0 and y(t0)=y0.\n        See also: 1/ interactive_plotode 2/ fieldplot 3/ odesolve 4/ desolve \n        Ex1:odeplot(sin(t*y),[t,y],[0,1])\n        Ex2:odeplot(sin(t*y),[t=-10..10,y],[0,1])\n        Ex3:odeplot(sin(t*y),[t=-3..3,y],[0,1],tstep=0.1,color=vert)\n        Ex4:odeplot([x-0.3*x*y, 0.3*x*y-y], [t,x,y],[0,0.3,0.7])\n        Ex5:odeplot([x-0.3*x*y, 0.3*x*y-y], [t,x,y],[0,0.3,0.7],plan)\n        Ex6:odeplot([-y+b,-1+(x-a)^2+(y-b)^2],[t=-3..3,x,y],[0,a+1,b+0.5],plan)\n        Ex7:odeplot(5*[-y,x],[t=0..1,x,y],[0,0.3,0.7],tstep=0.05,plan)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2073odeplot = {"odeplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2073odeplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2072odeplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2073odeplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("odeplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "odeplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2072odeplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2072odeplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("odeplot", 1);

  /* "giacpy/auto-methods.pxi":12785
 * 
 *         '''
 *         return GiacMethods['odeplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def odesolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_odeplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12785, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12770
 *         return GiacMethods['odd_graph'](self,*args)
 * 
 *      def odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odeplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.odeplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12787
 *         return GiacMethods['odeplot'](self,*args)
 * 
 *      def odesolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odesolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2075odesolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2074odesolve, "From Giac's documentation:\n        Help for odesolve:\n        odesolve(Expr,VectVar,VectInitCond,FinalVal,[tstep=Val,curve])\n        odesolve(f(t,y),[t,y],[t0,y0],t1)=odesolve(t0..t1,f,y0)=y(t1) for y approx sol of y'=f(t,y) and y(t0)=y0 with y=vector for systems.\n        See also: 1/ plotode 2/ plotfield 3/ interactive_plotode 4/ desolve \n        Ex1:odesolve(sin(t*y),[t,y],[0,1],2)\n        Ex2:odesolve(0..2,(t,y)->sin(t*y),1)\n        Ex3:odesolve(0..pi,(t,v)->{[-v[1],v[0]]},[0,1])\n        Ex4:odesolve(sin(t*y),t=0..2,y,1,tstep=0.5)\n        Ex5:odesolve(sin(t*y),t=0..2,y,1,tstep=0.5,curve)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2075odesolve = {"odesolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2075odesolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2074odesolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2075odesolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("odesolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "odesolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2074odesolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2074odesolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("odesolve", 1);

  /* "giacpy/auto-methods.pxi":12800
 * 
 *         '''
 *         return GiacMethods['odesolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def olive(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_odesolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12800, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12787
 *         return GiacMethods['odeplot'](self,*args)
 * 
 *      def odesolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odesolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.odesolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12802
 *         return GiacMethods['odesolve'](self,*args)
 * 
 *      def olive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for olive:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2077olive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2076olive, "From Giac's documentation:\n        Help for olive:\n        olive(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2077olive = {"olive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2077olive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2076olive};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2077olive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("olive (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "olive", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2076olive(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2076olive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("olive", 1);

  /* "giacpy/auto-methods.pxi":12812
 * 
 *         '''
 *         return GiacMethods['olive'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def op(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_olive); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12812, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12802
 *         return GiacMethods['odesolve'](self,*args)
 * 
 *      def olive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for olive:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.olive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12814
 *         return GiacMethods['olive'](self,*args)
 * 
 *      def op(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for op:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2079op(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2078op, "From Giac's documentation:\n        Help for op:\n        op(Op or Fnc)\n        Returns the arguments of an operator as a sequence.\n        See also: 1/ sommet 2/ quote 3/ makesuite \n        Ex1:op(quote(gcd(45,126)))\n        Ex2:op('gcd(45,126)')\n        Ex3:op('1+2')[1]\n        Ex4:op([1,2,3])\n        Ex5:op(set[1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2079op = {"op", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2079op, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2078op};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2079op(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("op (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "op", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2078op(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2078op(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("op", 1);

  /* "giacpy/auto-methods.pxi":12827
 * 
 *         '''
 *         return GiacMethods['op'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def open_polygon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_op); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12827, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12814
 *         return GiacMethods['olive'](self,*args)
 * 
 *      def op(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for op:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.op", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12829
 *         return GiacMethods['op'](self,*args)
 * 
 *      def open_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for open_polygon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2081open_polygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2080open_polygon, "From Giac's documentation:\n        Help for open_polygon:\n        open_polygon(LstPnt||LstCplx)\n        Returns and draws the polygonal line where its vertices are the element of l.\n        See also: 1/ isopolygon 2/ quadrilateral \n        Ex1:open_polygon(i,1+i,2-i,-1,-1+i/2)\n        Ex2:open_polygon(point(0,0,0),point(3,3,3),point(0,0,3),point(3,0,0))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2081open_polygon = {"open_polygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2081open_polygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2080open_polygon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2081open_polygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open_polygon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "open_polygon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2080open_polygon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2080open_polygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("open_polygon", 1);

  /* "giacpy/auto-methods.pxi":12839
 * 
 *         '''
 *         return GiacMethods['open_polygon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def orange(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_open_polygon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12839, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12829
 *         return GiacMethods['op'](self,*args)
 * 
 *      def open_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for open_polygon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.open_polygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12841
 *         return GiacMethods['open_polygon'](self,*args)
 * 
 *      def orange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orange:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2083orange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2082orange, "From Giac's documentation:\n        Help for orange:\n        orange(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2083orange = {"orange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2083orange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2082orange};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2083orange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("orange (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "orange", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2082orange(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2082orange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("orange", 1);

  /* "giacpy/auto-methods.pxi":12851
 * 
 *         '''
 *         return GiacMethods['orange'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ord(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_orange); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12851, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12841
 *         return GiacMethods['open_polygon'](self,*args)
 * 
 *      def orange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orange:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.orange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12853
 *         return GiacMethods['orange'](self,*args)
 * 
 *      def ord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ord:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2085ord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2084ord, "From Giac's documentation:\n        Help for ord:\n        ord(Char||LstChar)\n        Returns the ASCII code of a character or of the first character of a string.\n        See also: 1/ asc 2/ char \n        Ex1:ord(\"A\")\n        Ex2:ord(\"ABC\")\n        Ex3:ord([\"a\",\"b\",\"c\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2085ord = {"ord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2085ord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2084ord};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2085ord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ord (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ord", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2084ord(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2084ord(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ord", 1);

  /* "giacpy/auto-methods.pxi":12864
 * 
 *         '''
 *         return GiacMethods['ord'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def order(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ord); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12864, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12853
 *         return GiacMethods['orange'](self,*args)
 * 
 *      def ord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ord:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12866
 *         return GiacMethods['ord'](self,*args)
 * 
 *      def order(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2087order(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2086order, "From Giac's documentation:\n        Help for order:\n        order(g)\n        Returns element order of g in (Z/nZ)^* or in a finite field.\n        Ex1:order(3 % 7)\n        Ex2: GF(3,5,g); order(g^2+g+1);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2087order = {"order", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2087order, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2086order};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2087order(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "order", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2086order(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2086order(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order", 1);

  /* "giacpy/auto-methods.pxi":12875
 * 
 *         '''
 *         return GiacMethods['order'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def order_size(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12875, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12866
 *         return GiacMethods['ord'](self,*args)
 * 
 *      def order(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.order", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12877
 *         return GiacMethods['order'](self,*args)
 * 
 *      def order_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order_size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2089order_size(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2088order_size, "From Giac's documentation:\n        Help for order_size:\n        order_size(Expr)\n        Remainder (O term) of a series expansion: limit(x^a*order_size(x),x=0)=0 if a>0.\n        See also: 1/ series \n        Ex1:order_size(x)\n        Ex2: limit(sqrt(x)*order_size(x),x=0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2089order_size = {"order_size", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2089order_size, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2088order_size};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2089order_size(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("order_size (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "order_size", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2088order_size(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2088order_size(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("order_size", 1);

  /* "giacpy/auto-methods.pxi":12887
 * 
 *         '''
 *         return GiacMethods['order_size'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ordinate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_order_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12887, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12877
 *         return GiacMethods['order'](self,*args)
 * 
 *      def order_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order_size:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.order_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12889
 *         return GiacMethods['order_size'](self,*args)
 * 
 *      def ordinate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ordinate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2091ordinate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2090ordinate, "From Giac's documentation:\n        Help for ordinate:\n        ordinate(Pnt or Vect)\n        Returns the ordinate of a point or a vector.\n        See also: 1/ abscissa 2/ affix 3/ cote 4/ coordinates \n        Ex1:ordinate(point(1+2*i))\n        Ex2:ordinate(point(i)-point(1+2*i))\n        Ex3:ordinate(-1-i)\n        Ex4:ordinate(point(1,2,3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2091ordinate = {"ordinate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2091ordinate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2090ordinate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2091ordinate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ordinate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ordinate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2090ordinate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2090ordinate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ordinate", 1);

  /* "giacpy/auto-methods.pxi":12901
 * 
 *         '''
 *         return GiacMethods['ordinate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def orthocenter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ordinate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12901, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12889
 *         return GiacMethods['order_size'](self,*args)
 * 
 *      def ordinate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ordinate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ordinate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12903
 *         return GiacMethods['ordinate'](self,*args)
 * 
 *      def orthocenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthocenter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2093orthocenter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2092orthocenter, "From Giac's documentation:\n        Help for orthocenter:\n        orthocenter((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        Shows the orthocenter of a triangle or of the triangle made with 3 points.\n        See also: 1/ altitude 2/ triangle \n        Ex1:orthocenter(1+i,2,i)\n        Ex2:orthocenter(point(1+i),point(2),point(i))\n        Ex3:orthocenter(triangle(0,1,1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2093orthocenter = {"orthocenter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2093orthocenter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2092orthocenter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2093orthocenter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("orthocenter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "orthocenter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2092orthocenter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2092orthocenter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("orthocenter", 1);

  /* "giacpy/auto-methods.pxi":12914
 * 
 *         '''
 *         return GiacMethods['orthocenter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def orthogonal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_orthocenter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12914, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12903
 *         return GiacMethods['ordinate'](self,*args)
 * 
 *      def orthocenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthocenter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.orthocenter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12916
 *         return GiacMethods['orthocenter'](self,*args)
 * 
 *      def orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthogonal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2095orthogonal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2094orthogonal, "From Giac's documentation:\n        Help for orthogonal:\n        orthogonal((Pnt),(Line or Plan))\n        orthogonal(A,line(B,C)) draws the orthogonal plane of line BC through A and orthogonal(A,plane(B,C,D)) draws the orthogonal line of plane(B,C,D) through A.\n        See also: 1/ altitude 2/ perpendicular \n        Ex1:orthogonal(point(0,0,0),line(point(1,0,0),point(0,1,0)))\n        Ex2:orthogonal(point(0,0,0),plane(point(1,0,0),point(0,1,0),point(0,0,1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2095orthogonal = {"orthogonal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2095orthogonal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2094orthogonal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2095orthogonal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("orthogonal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "orthogonal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2094orthogonal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2094orthogonal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("orthogonal", 1);

  /* "giacpy/auto-methods.pxi":12926
 * 
 *         '''
 *         return GiacMethods['orthogonal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def osculating_circle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_orthogonal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12926, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12916
 *         return GiacMethods['orthocenter'](self,*args)
 * 
 *      def orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthogonal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.orthogonal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12928
 *         return GiacMethods['orthogonal'](self,*args)
 * 
 *      def osculating_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for osculating_circle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2097osculating_circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2096osculating_circle, "From Giac's documentation:\n        Help for osculating_circle:\n        osculating_circle(Curve,Point)\n        Osculating circle at point M to the curve C.\n        See also: 1/ curvature 2/ evolute \n        Ex1:osculating_circle(plot(x^2),point(1,1))\n        Ex2:osculating_circle([5*cos(t),5*sin(t)],t,0)\n        Ex3:osculating_circle([t,t^2],t)\n        Ex4:osculating_circle([t,t^2],t,1)\n        Ex5:osculating_circle([3*exp(t/2)*cos(t),3*exp(t/2)*sin(t)],t)\n        Ex6:osculating_circle([3*exp(t/2)*cos(t),3*exp(t/2)*sin(t)],t,7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2097osculating_circle = {"osculating_circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2097osculating_circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2096osculating_circle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2097osculating_circle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("osculating_circle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "osculating_circle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2096osculating_circle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2096osculating_circle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("osculating_circle", 1);

  /* "giacpy/auto-methods.pxi":12942
 * 
 *         '''
 *         return GiacMethods['osculating_circle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def p1oc2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_osculating_circle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12942, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12928
 *         return GiacMethods['orthogonal'](self,*args)
 * 
 *      def osculating_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for osculating_circle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.osculating_circle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12944
 *         return GiacMethods['osculating_circle'](self,*args)
 * 
 *      def p1oc2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1oc2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2099p1oc2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2098p1oc2, "From Giac's documentation:\n        Help for p1oc2:\n        p1oc2(Permut,Cycle)\n        Returns the permutation product of p1 and c2.\n        See also: 1/ c1op2 2/ p1op2 \n        Ex1:p1oc2([0,2,1],[2,1,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2099p1oc2 = {"p1oc2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2099p1oc2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2098p1oc2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2099p1oc2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p1oc2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "p1oc2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2098p1oc2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2098p1oc2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p1oc2", 1);

  /* "giacpy/auto-methods.pxi":12953
 * 
 *         '''
 *         return GiacMethods['p1oc2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def p1op2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_p1oc2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12953, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12944
 *         return GiacMethods['osculating_circle'](self,*args)
 * 
 *      def p1oc2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1oc2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.p1oc2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12955
 *         return GiacMethods['p1oc2'](self,*args)
 * 
 *      def p1op2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1op2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2101p1op2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2100p1op2, "From Giac's documentation:\n        Help for p1op2:\n        p1op2(Permut,Permut)\n        Returns the permutation product of p1 and p2.\n        See also: 1/ c1op2 2/ p1oc2 \n        Ex1:p1op2([0,2,1],[1,0,3,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2101p1op2 = {"p1op2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2101p1op2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2100p1op2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2101p1op2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("p1op2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "p1op2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2100p1op2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2100p1op2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("p1op2", 1);

  /* "giacpy/auto-methods.pxi":12964
 * 
 *         '''
 *         return GiacMethods['p1op2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pa2b2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_p1op2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12964, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12955
 *         return GiacMethods['p1oc2'](self,*args)
 * 
 *      def p1op2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1op2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.p1op2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12966
 *         return GiacMethods['p1op2'](self,*args)
 * 
 *      def pa2b2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pa2b2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2103pa2b2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2102pa2b2, "From Giac's documentation:\n        Help for pa2b2:\n        pa2b2(Intg(n))\n        Returns [a,b] such that a^2+b^2=n (for n prime and n=1 (mod 4)).\n        Ex1:pa2b2(17)\n        Ex2:pa2b2(209)\n        Ex3:pa2b2(229)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2103pa2b2 = {"pa2b2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2103pa2b2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2102pa2b2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2103pa2b2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pa2b2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pa2b2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2102pa2b2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2102pa2b2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pa2b2", 1);

  /* "giacpy/auto-methods.pxi":12976
 * 
 *         '''
 *         return GiacMethods['pa2b2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pade(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pa2b2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12976, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12966
 *         return GiacMethods['p1op2'](self,*args)
 * 
 *      def pa2b2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pa2b2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pa2b2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12978
 *         return GiacMethods['pa2b2'](self,*args)
 * 
 *      def pade(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pade:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2105pade(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2104pade, "From Giac's documentation:\n        Help for pade:\n        pade(Expr(Xpr), Var(x), (Intg(n) || Poly(N)), Intg(p))\n        Pade approximation P/Q=Xpr mod x^(n+1) or mod N with degree(P)<p.\n        See also: 1/ taylor 2/ series \n        Ex1:pade(exp(x),x,10,6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2105pade = {"pade", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2105pade, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2104pade};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2105pade(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pade (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pade", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2104pade(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2104pade(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pade", 1);

  /* "giacpy/auto-methods.pxi":12987
 * 
 *         '''
 *         return GiacMethods['pade'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def paley_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pade); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12987, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12978
 *         return GiacMethods['pa2b2'](self,*args)
 * 
 *      def pade(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pade:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pade", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":12989
 *         return GiacMethods['pade'](self,*args)
 * 
 *      def paley_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paley_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2107paley_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2106paley_graph, "From Giac's documentation:\n        Help for paley_graph:\n        paley_graph(Intg(p),[Intg(k)])\n        Returns the Paley (di)graph on p^k vertices, where p>2 is prime and k>0.\n        See also: 1/ graph \n        Ex1:paley_graph(3,2)\n        Ex2:paley_graph(3,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2107paley_graph = {"paley_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2107paley_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2106paley_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2107paley_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("paley_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "paley_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2106paley_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2106paley_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("paley_graph", 1);

  /* "giacpy/auto-methods.pxi":12999
 * 
 *         '''
 *         return GiacMethods['paley_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parabola(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_paley_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 12999, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 12999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":12989
 *         return GiacMethods['pade'](self,*args)
 * 
 *      def paley_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paley_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.paley_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13001
 *         return GiacMethods['paley_graph'](self,*args)
 * 
 *      def parabola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parabola:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2109parabola(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2108parabola, "From Giac's documentation:\n        Help for parabola:\n        parabola(Pnt(F)||Pnt(xA+i*yA),Pnt(A)||Real(c),[Pnt(P)])\n        parabola(F,A)=focus F, top A (in the plane ABP) or (parabola(A,c) of equa. y=yA+c*(x-xA)^2 c=1/(2*p) and FA=p/2 geo2d) and parabola(P(x,y)) draws the conic if deg(P)=2.\n        See also: 1/ ellipse 2/ hyperbola \n        Ex1:parabola(point(0),point(2))\n        Ex2:parabola(0,2)\n        Ex3:parabola(point(0,0,0),point(1,0,0),point(1,1,1))\n        Ex4:parabola(x-y^2+y-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2109parabola = {"parabola", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2109parabola, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2108parabola};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2109parabola(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parabola (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parabola", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2108parabola(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2108parabola(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parabola", 1);

  /* "giacpy/auto-methods.pxi":13013
 * 
 *         '''
 *         return GiacMethods['parabola'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parallel(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parabola); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13013, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13001
 *         return GiacMethods['paley_graph'](self,*args)
 * 
 *      def parabola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parabola:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parabola", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13015
 *         return GiacMethods['parabola'](self,*args)
 * 
 *      def parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallel:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2111parallel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2110parallel, "From Giac's documentation:\n        Help for parallel:\n        parallel(Pnt or Line,Line or Plan,[Line])\n        parallel(A,D) (resp parallel(A,P) or parallel(A,D,DD)) draws the line (resp plane) through A parallel to the line D (resp parallel to the plane P or to the lines D,DD) and parallel(d,D) draws the plane through d parallel to the line D.\n        See also: 1/  \n        Ex1:parallel(1+i,line(1-i,i))\n        Ex2:parallel(1+i,segment(1-i,i))\n        Ex3:parallel(point([1,1,1]),line(x=0,y=0))\n        Ex4:parallel([1,1,1],line(x=0,y=0))\n        Ex5:parallel([1,1,1],plane(x=0))\n        Ex6:parallel([1,0,0],line(x=0,y=0),line(x=y,y=z))\n        Ex7:parallel(line(x=y,y=z),line(x=0,y=0))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2111parallel = {"parallel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2111parallel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2110parallel};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2111parallel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parallel (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parallel", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2110parallel(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2110parallel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parallel", 1);

  /* "giacpy/auto-methods.pxi":13030
 * 
 *         '''
 *         return GiacMethods['parallel'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parallelepiped(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parallel); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13030, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13015
 *         return GiacMethods['parabola'](self,*args)
 * 
 *      def parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallel:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parallel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13032
 *         return GiacMethods['parallel'](self,*args)
 * 
 *      def parallelepiped(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelepiped:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2113parallelepiped(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2112parallelepiped, "From Giac's documentation:\n        Help for parallelepiped:\n        parallelepiped(Pnt(A),Pnt(B),Pnt(C),Pnt(D))\n        Draws a parallelepiped with sides AB,AC,AD (the faces are parallelograms).\n        See also: 1/ cube 2/ polyhedron \n        Ex1:parallelepiped([0,0,0],[2,0,0],[0,1,0],[0,0,3])\n        Ex2: p:=parallelepiped([0,0,0],[5,0,0],[0,3,0],[0,0,2]);c1,c2,c3,c4,c5,c6,c7,c8:=sommets(p);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2113parallelepiped = {"parallelepiped", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2113parallelepiped, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2112parallelepiped};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2113parallelepiped(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parallelepiped (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parallelepiped", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2112parallelepiped(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2112parallelepiped(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parallelepiped", 1);

  /* "giacpy/auto-methods.pxi":13042
 * 
 *         '''
 *         return GiacMethods['parallelepiped'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parallelogram(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parallelepiped); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13042, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13032
 *         return GiacMethods['parallel'](self,*args)
 * 
 *      def parallelepiped(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelepiped:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parallelepiped", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13044
 *         return GiacMethods['parallelepiped'](self,*args)
 * 
 *      def parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelogram:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2115parallelogram(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2114parallelogram, "From Giac's documentation:\n        Help for parallelogram:\n        parallelogram(Pnt(A)||Cplx,Pnt(B)||Cplx,Pnt(C)||Cplx,[Var(D)])\n        Returns and draws the parallelogram ABCD such that vector(AB)+vector(AD)=vector(AC).\n        See also: 1/ quadrilateral 2/ rhombus \n        Ex1:parallelogram(0,1,2+i)\n        Ex2:parallelogram(1,0,2+i,D)\n        Ex3:parallelogram(point(0,0,0),point(3,3,3),point(0,0,3))\n        Ex4:parallelogram(point(0,0,0),point(3,3,3),point(0,0,3),D)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2115parallelogram = {"parallelogram", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2115parallelogram, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2114parallelogram};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2115parallelogram(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parallelogram (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parallelogram", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2114parallelogram(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2114parallelogram(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parallelogram", 1);

  /* "giacpy/auto-methods.pxi":13056
 * 
 *         '''
 *         return GiacMethods['parallelogram'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parameq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parallelogram); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13056, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13044
 *         return GiacMethods['parallelepiped'](self,*args)
 * 
 *      def parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelogram:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parallelogram", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13058
 *         return GiacMethods['parallelogram'](self,*args)
 * 
 *      def parameq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2117parameq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2116parameq, "From Giac's documentation:\n        Help for parameq:\n        parameq(GeoObj)\n        parameq(C) returns the complex number=parametric equation of the curve C.\n        See also: 1/ equation \n        Ex1:parameq(circle(0,1))\n        Ex2:parameq(line(i,1-i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2117parameq = {"parameq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2117parameq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2116parameq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2117parameq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parameq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parameq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2116parameq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2116parameq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parameq", 1);

  /* "giacpy/auto-methods.pxi":13068
 * 
 *         '''
 *         return GiacMethods['parameq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parameter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parameq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13068, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13058
 *         return GiacMethods['parallelogram'](self,*args)
 * 
 *      def parameq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parameq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13070
 *         return GiacMethods['parameq'](self,*args)
 * 
 *      def parameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2119parameter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2118parameter, "From Giac's documentation:\n        Help for parameter:\n        parameter()\n        Reserved word.\n        See also: 1/  \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2119parameter = {"parameter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2119parameter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2118parameter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2119parameter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parameter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parameter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2118parameter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2118parameter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parameter", 1);

  /* "giacpy/auto-methods.pxi":13078
 * 
 *         '''
 *         return GiacMethods['parameter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def paramplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parameter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13078, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13070
 *         return GiacMethods['parameq'](self,*args)
 * 
 *      def parameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parameter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13080
 *         return GiacMethods['parameter'](self,*args)
 * 
 *      def paramplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paramplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2121paramplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2120paramplot, "From Giac's documentation:\n        Help for paramplot:\n        paramplot(Cplx||Lst,Var||Lst(Var))\n        plotparam(a(x)+i*b(x),x=x0..x1) draws the curve X=a(x),Y=b(x) x=x0..x1 or plotparam([a(u,v),b(u,v),c(u,v)],[u=u0..u1,v=v0..v1]) draws the surface X=a(u,v),Y=b(u,v),Z=c(u,v) u=u0..u1 and v=v0..v1.\n        See also: 1/ plotfunc 2/ plotpolar 3/ arc \n        Ex1:paramplot(sin(t)+i*cos(t),t)\n        Ex2:paramplot(exp(i*t),t=0..pi/2,affichage=1)\n        Ex3:paramplot(exp(i*t),t=0..pi/2,affichage=1+rempli)\n        Ex4:paramplot([sin(x),cos(x)],x=0..1)\n        Ex5:paramplot([sin(x),cos(x)],x=0..1,affichage=rouge)\n        Ex6:paramplot(sin(x)+i*cos(x),x=0..1,tstep=0.01)\n        Ex7:paramplot([v*cos(u),v*sin(u),v],[u,v])\n        Ex8:paramplot([v*cos(u),v*sin(u),v],[u=0..pi,v=0..3],ustep=0.1,vstep=0.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2121paramplot = {"paramplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2121paramplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2120paramplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2121paramplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("paramplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "paramplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2120paramplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2120paramplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("paramplot", 1);

  /* "giacpy/auto-methods.pxi":13096
 * 
 *         '''
 *         return GiacMethods['paramplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parfrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_paramplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13096, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13080
 *         return GiacMethods['parameter'](self,*args)
 * 
 *      def paramplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paramplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.paramplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13098
 *         return GiacMethods['paramplot'](self,*args)
 * 
 *      def parfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parfrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2123parfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2122parfrac, "From Giac's documentation:\n        Help for parfrac:\n        parfrac(Opt)\n        Option of the convert or convertir command (id at the option partfrac).\n        See also: 1/ convert \n        Ex1: convert(1/(x^2-1),parfrac)\n        Ex2: convert(1/(x^2-1),fullparfrac)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2123parfrac = {"parfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2123parfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2122parfrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2123parfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parfrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parfrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2122parfrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2122parfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parfrac", 1);

  /* "giacpy/auto-methods.pxi":13108
 * 
 *         '''
 *         return GiacMethods['parfrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pari(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parfrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13108, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13098
 *         return GiacMethods['paramplot'](self,*args)
 * 
 *      def parfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parfrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parfrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13110
 *         return GiacMethods['parfrac'](self,*args)
 * 
 *      def pari(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pari:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2125pari(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2124pari, "From Giac's documentation:\n        Help for pari:\n        pari(Str,arguments)\n        Executes a PARI/GP command or exports all PARI/GP commands.\n        See also: 1/ gcd 2/ lgcd 3/ is_prime \n        Ex1:pari()\n        Ex2:pari(\"gcd\",15,50)\n        Ex3:pari(\"gcd\",5/7,50/9)\n        Ex4:pari(\"gcd\", 3,[25,15,50,75])\n        Ex5:pari(\"gcd\", [2,3],[25,15,50,75])\n        Ex6:pari(\"content\",[25,15,50,75])\n        Ex7:pari(\"isprime\",9856989898997789789,1)\n        Ex8:pari(\"isprime\",9856989898997789789,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2125pari = {"pari", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2125pari, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2124pari};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2125pari(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pari (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pari", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2124pari(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2124pari(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pari", 1);

  /* "giacpy/auto-methods.pxi":13126
 * 
 *         '''
 *         return GiacMethods['pari'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def part(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pari); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13126, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13110
 *         return GiacMethods['parfrac'](self,*args)
 * 
 *      def pari(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pari:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pari", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13128
 *         return GiacMethods['pari'](self,*args)
 * 
 *      def part(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for part:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2127part(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2126part, "From Giac's documentation:\n        Help for part:\n        part(Expr, Intg(n))\n        Returns the n-th subexpression of the expression.\n        See also: 1/  \n        Ex1:part(sin(x)+cos(x),1)\n        Ex2:part(sin(x)+cos(x),2)\n        Ex3:part(exp(x)*sin(x),1)\n        Ex4:part(part(exp(x)*sin(x)+cos(x),1),1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2127part = {"part", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2127part, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2126part};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2127part(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("part (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "part", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2126part(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2126part(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("part", 1);

  /* "giacpy/auto-methods.pxi":13140
 * 
 *         '''
 *         return GiacMethods['part'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def partfrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_part); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13140, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13128
 *         return GiacMethods['pari'](self,*args)
 * 
 *      def part(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for part:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.part", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13142
 *         return GiacMethods['part'](self,*args)
 * 
 *      def partfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for partfrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2129partfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2128partfrac, "From Giac's documentation:\n        Help for partfrac:\n        partfrac(RatFrac or Opt)\n        Performs partial fraction decomposition on a fraction or option of the convert or convertir command (id at the option parfrac).\n        See also: 1/ factor 2/ normal 3/ convert 4/ propfrac \n        Ex1:partfrac(x/(4-x^2))\n        Ex2:partfrac((x^2-2*x+3)/(x^2-3*x+2))\n        Ex3:partfrac(a/(z*(z-b)),z)\n        Ex4: convert(x/(4-x^2),partfrac)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2129partfrac = {"partfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2129partfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2128partfrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2129partfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("partfrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "partfrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2128partfrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2128partfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("partfrac", 1);

  /* "giacpy/auto-methods.pxi":13154
 * 
 *         '''
 *         return GiacMethods['partfrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def parzen_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_partfrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13142
 *         return GiacMethods['part'](self,*args)
 * 
 *      def partfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for partfrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.partfrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13156
 *         return GiacMethods['partfrac'](self,*args)
 * 
 *      def parzen_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parzen_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2131parzen_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2130parzen_window, "From Giac's documentation:\n        Help for parzen_window:\n        parzen_window(Lst,[Interval(n1..n2)])\n        Applies the Parzen windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ bartlett_hann_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(parzen_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2131parzen_window = {"parzen_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2131parzen_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2130parzen_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2131parzen_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parzen_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "parzen_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2130parzen_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2130parzen_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parzen_window", 1);

  /* "giacpy/auto-methods.pxi":13165
 * 
 *         '''
 *         return GiacMethods['parzen_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pas_de_cote(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_parzen_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13165, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13156
 *         return GiacMethods['partfrac'](self,*args)
 * 
 *      def parzen_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parzen_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.parzen_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13167
 *         return GiacMethods['parzen_window'](self,*args)
 * 
 *      def pas_de_cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pas_de_cote:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2133pas_de_cote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2132pas_de_cote, "From Giac's documentation:\n        Help for pas_de_cote:\n        pas_de_cote(NULL or Real(n))\n        The turtle does n side-steps to the left (-n steps to the right if n negative) without trace (by default n=10).\n        See also: 1/ saute 2/ tourne_droite 3/ tourne_gauche \n        Ex1: pas_de_cote 30\n        Ex2:pas_de_cote(30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2133pas_de_cote = {"pas_de_cote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2133pas_de_cote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2132pas_de_cote};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2133pas_de_cote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pas_de_cote (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pas_de_cote", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2132pas_de_cote(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2132pas_de_cote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pas_de_cote", 1);

  /* "giacpy/auto-methods.pxi":13177
 * 
 *         '''
 *         return GiacMethods['pas_de_cote'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def path_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pas_de_cote); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13177, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13167
 *         return GiacMethods['parzen_window'](self,*args)
 * 
 *      def pas_de_cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pas_de_cote:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pas_de_cote", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13179
 *         return GiacMethods['pas_de_cote'](self,*args)
 * 
 *      def path_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for path_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2135path_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2134path_graph, "From Giac's documentation:\n        Help for path_graph:\n        path_graph(Intg(n)||Lst(V))\n        Returns a path graph on n vertices [with labels from V].\n        See also: 1/ cycle_graph 2/ graph 3/ trail \n        Ex1:path_graph(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2135path_graph = {"path_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2135path_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2134path_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2135path_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("path_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "path_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2134path_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2134path_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("path_graph", 1);

  /* "giacpy/auto-methods.pxi":13188
 * 
 *         '''
 *         return GiacMethods['path_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pcar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_path_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13188, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13179
 *         return GiacMethods['pas_de_cote'](self,*args)
 * 
 *      def path_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for path_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.path_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13190
 *         return GiacMethods['path_graph'](self,*args)
 * 
 *      def pcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2137pcar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2136pcar, "From Giac's documentation:\n        Help for pcar:\n        pcar(Mtrx,[Var])\n        List of the coefficients of the characteristic polynomial of a matrix or characteristic polynomial of a matrix with the second argument as variable.\n        See also: 1/ jordan 2/ egv 3/ egvl 4/ companion 5/ rat_jordan 6/ pmin 7/ adjoint_matrix  \n        Ex1:pcar([[1,2],[3,4]])\n        Ex2:pcar([[1,2],[3,4]],x)\n        Ex3:pcar([[1,2,3],[1,3,6],[2,5,7]])\n        Ex4:pcar([[1,2,3],[1,3,6],[2,5,7]],z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2137pcar = {"pcar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2137pcar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2136pcar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2137pcar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pcar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pcar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2136pcar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2136pcar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pcar", 1);

  /* "giacpy/auto-methods.pxi":13202
 * 
 *         '''
 *         return GiacMethods['pcar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pcar_hessenberg(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pcar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13202, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13190
 *         return GiacMethods['path_graph'](self,*args)
 * 
 *      def pcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pcar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13204
 *         return GiacMethods['pcar'](self,*args)
 * 
 *      def pcar_hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar_hessenberg:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2139pcar_hessenberg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2138pcar_hessenberg, "From Giac's documentation:\n        Help for pcar_hessenberg:\n        pcar_hessenberg(Mtrx,[Var])\n        Characteristic polynomial of a matrix by the Hessenberg method (if the coefficients are in a finite field).\n        See also: 1/ jordan 2/ pcar 3/ egvl \n        Ex1:pcar_hessenberg([[1,2],[3,4]])\n        Ex2:pcar_hessenberg([[1,2],[3,4]],x)\n        Ex3:pcar_hessenberg([[1,2,3],[1,3,6],[2,5,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2139pcar_hessenberg = {"pcar_hessenberg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2139pcar_hessenberg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2138pcar_hessenberg};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2139pcar_hessenberg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pcar_hessenberg (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pcar_hessenberg", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2138pcar_hessenberg(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2138pcar_hessenberg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pcar_hessenberg", 1);

  /* "giacpy/auto-methods.pxi":13215
 * 
 *         '''
 *         return GiacMethods['pcar_hessenberg'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pcoef(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pcar_hessenberg); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13215, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13204
 *         return GiacMethods['pcar'](self,*args)
 * 
 *      def pcar_hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar_hessenberg:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pcar_hessenberg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13217
 *         return GiacMethods['pcar_hessenberg'](self,*args)
 * 
 *      def pcoef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2141pcoef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2140pcoef, "From Giac's documentation:\n        Help for pcoef:\n        pcoef(Vect)\n        Returns the polynomial coefficients having the roots specified as argument.\n        See also: 1/ proot 2/ peval \n        Ex1:pcoef([1,0,0,0,1])\n        Ex2:pcoef([1,0,-2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2141pcoef = {"pcoef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2141pcoef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2140pcoef};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2141pcoef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pcoef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pcoef", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2140pcoef(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2140pcoef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pcoef", 1);

  /* "giacpy/auto-methods.pxi":13227
 * 
 *         '''
 *         return GiacMethods['pcoef'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pcoeff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pcoef); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13227, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13217
 *         return GiacMethods['pcar_hessenberg'](self,*args)
 * 
 *      def pcoef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pcoef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13229
 *         return GiacMethods['pcoef'](self,*args)
 * 
 *      def pcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoeff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2143pcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2142pcoeff, "From Giac's documentation:\n        Help for pcoeff:\n        pcoeff(Vect)\n        Returns the polynomial coefficients having the roots specified as argument.\n        See also: 1/ proot 2/ peval \n        Ex1:pcoeff([1,0,0,0,1])\n        Ex2:pcoeff([1,0,-2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2143pcoeff = {"pcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2143pcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2142pcoeff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2143pcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pcoeff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pcoeff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2142pcoeff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2142pcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pcoeff", 1);

  /* "giacpy/auto-methods.pxi":13239
 * 
 *         '''
 *         return GiacMethods['pcoeff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pencolor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pcoeff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13239, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13229
 *         return GiacMethods['pcoef'](self,*args)
 * 
 *      def pcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoeff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pcoeff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13241
 *         return GiacMethods['pcoeff'](self,*args)
 * 
 *      def pencolor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pencolor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2145pencolor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2144pencolor, "From Giac's documentation:\n        Help for pencolor:\n        pencolor(Color)\n        Changes the color of the pencil (without parameter, returns the current color).\n        See also: 1/ leve_crayon 2/ baisse_crayon \n        Ex1: crayon vert\n        Ex2:pencolor(rouge)\n        Ex3:pencolor(5)\n        Ex4:pencolor(gomme)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2145pencolor = {"pencolor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2145pencolor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2144pencolor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2145pencolor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pencolor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pencolor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2144pencolor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2144pencolor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pencolor", 1);

  /* "giacpy/auto-methods.pxi":13253
 * 
 *         '''
 *         return GiacMethods['pencolor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pendown(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pencolor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13253, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13241
 *         return GiacMethods['pcoeff'](self,*args)
 * 
 *      def pencolor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pencolor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pencolor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13255
 *         return GiacMethods['pencolor'](self,*args)
 * 
 *      def pendown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pendown:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2147pendown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2146pendown, "From Giac's documentation:\n        Help for pendown:\n        pendown(NULL)\n        Presses the pencil down so that the turtle move with traces.\n        See also: 1/ leve_crayon 2/ crayon \n        Ex1:pendown()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2147pendown = {"pendown", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2147pendown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2146pendown};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2147pendown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pendown (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pendown", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2146pendown(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2146pendown(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pendown", 1);

  /* "giacpy/auto-methods.pxi":13264
 * 
 *         '''
 *         return GiacMethods['pendown'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def penup(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pendown); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13264, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13255
 *         return GiacMethods['pencolor'](self,*args)
 * 
 *      def pendown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pendown:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pendown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13266
 *         return GiacMethods['pendown'](self,*args)
 * 
 *      def penup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for penup:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2149penup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2148penup, "From Giac's documentation:\n        Help for penup:\n        penup(NULL)\n        Lifts the pencil up so that the turtle moves without traces.\n        See also: 1/ baisse_crayon 2/ crayon \n        Ex1:penup()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2149penup = {"penup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2149penup, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2148penup};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2149penup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("penup (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "penup", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2148penup(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2148penup(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("penup", 1);

  /* "giacpy/auto-methods.pxi":13275
 * 
 *         '''
 *         return GiacMethods['penup'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perimeter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_penup); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13275, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13266
 *         return GiacMethods['pendown'](self,*args)
 * 
 *      def penup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for penup:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.penup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13277
 *         return GiacMethods['penup'](self,*args)
 * 
 *      def perimeter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2151perimeter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2150perimeter, "From Giac's documentation:\n        Help for perimeter:\n        perimeter(Polygone)\n        Perimeter of a polygon (e.g. triangle, square, ...)\n        See also: 1/ polygon 2/ area 3/ perimeteratraw 4/ perimeterat \n        Ex1:perimeter(triangle(0,1,i))\n        Ex2:perimeter(square(0,2))\n        Ex3:perimeter(circle(0,2))\n        Ex4:perimeter(0,1,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2151perimeter = {"perimeter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2151perimeter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2150perimeter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2151perimeter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perimeter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perimeter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2150perimeter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2150perimeter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perimeter", 1);

  /* "giacpy/auto-methods.pxi":13289
 * 
 *         '''
 *         return GiacMethods['perimeter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perimeterat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perimeter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13289, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13277
 *         return GiacMethods['penup'](self,*args)
 * 
 *      def perimeter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perimeter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13291
 *         return GiacMethods['perimeter'](self,*args)
 * 
 *      def perimeterat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeterat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2153perimeterat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2152perimeterat, "From Giac's documentation:\n        Help for perimeterat:\n        perimeterat(Polygone, Pnt||Cplx(z0))\n        Displays at point(z0), with a legend, the perimeter of a circle or of a polygon (e.g. triangle, square, ...)\n        See also: 1/ perimeter 2/ perimeteratraw 2/ polygon 3/ areaatraw \n        Ex1: t:=triangle(0,1,i);perimeterat(t,1+i)\n        Ex2: c:=square(0,2);perimeterat(c,1+i)\n        Ex3: c2:=circle(0,2);perimeterat(c2,1+i)\n        Ex4: p:=polygon(0,1,i);perimeterat(p,1+i)\n        Ex5: A:=point(0);B:=point(1+i);c:=carre(A,B);perimeterat(c,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2153perimeterat = {"perimeterat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2153perimeterat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2152perimeterat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2153perimeterat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perimeterat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perimeterat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2152perimeterat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2152perimeterat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perimeterat", 1);

  /* "giacpy/auto-methods.pxi":13304
 * 
 *         '''
 *         return GiacMethods['perimeterat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perimeteratraw(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perimeterat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13304, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13291
 *         return GiacMethods['perimeter'](self,*args)
 * 
 *      def perimeterat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeterat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perimeterat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13306
 *         return GiacMethods['perimeterat'](self,*args)
 * 
 *      def perimeteratraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeteratraw:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2155perimeteratraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2154perimeteratraw, "From Giac's documentation:\n        Help for perimeteratraw:\n        perimeteratraw(Polygone, Pnt||Cplx(z0))\n        Displays at point(z0), the perimeter of a circle or of a polygon (e.g. triangle, square, ...)\n        See also: 1/ perimeter 2/ perimeterat 3/ polygon 4/ areaatraw \n        Ex1:perimeteratraw(triangle(0,1,i),1+i)\n        Ex2:perimeteratraw(square(0,2),1+i)\n        Ex3:perimeteratraw(circle(0,2),1+i)\n        Ex4:perimeteratraw(polygon(0,1,i),1+i)\n        Ex5: A:=point(0);B:=point(1+i);c:=carre(A,B);perimeteratraw(c,i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2155perimeteratraw = {"perimeteratraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2155perimeteratraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2154perimeteratraw};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2155perimeteratraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perimeteratraw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perimeteratraw", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2154perimeteratraw(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2154perimeteratraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perimeteratraw", 1);

  /* "giacpy/auto-methods.pxi":13319
 * 
 *         '''
 *         return GiacMethods['perimeteratraw'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def period(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perimeteratraw); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13319, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13306
 *         return GiacMethods['perimeterat'](self,*args)
 * 
 *      def perimeteratraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeteratraw:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perimeteratraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13321
 *         return GiacMethods['perimeteratraw'](self,*args)
 * 
 *      def period(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for period:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2157period(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2156period, "From Giac's documentation:\n        Help for period:\n        period(Expr,[Var])\n        Returns a period of a given periodic expression with respect to a single real variable (by default x).\n        See also: 1/ periodic \n        Ex1:period(sin(x*pi/2)/(2+cos(x*pi/3+pi/4)))\n        Ex2:period(sin(x)+sin(sqrt(2)*x),x)\n        Ex3: f:=periodic(x^2,x,0,3):;g:=periodic(x^3,x,-1,1):;period(f*g/(1+f^2+g^2),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2157period = {"period", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2157period, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2156period};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2157period(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("period (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "period", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2156period(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2156period(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("period", 1);

  /* "giacpy/auto-methods.pxi":13332
 * 
 *         '''
 *         return GiacMethods['period'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def periodic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_period); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13332, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13321
 *         return GiacMethods['perimeteratraw'](self,*args)
 * 
 *      def period(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for period:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.period", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13334
 *         return GiacMethods['period'](self,*args)
 * 
 *      def periodic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for periodic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2159periodic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2158periodic, "From Giac's documentation:\n        Help for periodic:\n        periodic(Expr,Var,Real(a),Real(b)||Expr,Var=a..b)\n        Returns the periodic expression equal to Expr on a..b, period b-a.\n        See also: 1/ period \n        Ex1:periodic(x^2,x=-1..1)\n        Ex2: plot(periodic(x^2,x,-1,1),x=-5..5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2159periodic = {"periodic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2159periodic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2158periodic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2159periodic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("periodic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "periodic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2158periodic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2158periodic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("periodic", 1);

  /* "giacpy/auto-methods.pxi":13344
 * 
 *         '''
 *         return GiacMethods['periodic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_periodic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13344, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13334
 *         return GiacMethods['period'](self,*args)
 * 
 *      def periodic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for periodic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.periodic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13346
 *         return GiacMethods['periodic'](self,*args)
 * 
 *      def perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2161perm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2160perm, "From Giac's documentation:\n        Help for perm:\n        perm(Intg(n),Intg(p))\n        perm(n,p)=number of arrangements of p objects taken among n : n!/(n-p)!\n        See also: 1/ comb 2/ factorial \n        Ex1:perm(4,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2161perm = {"perm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2161perm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2160perm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2161perm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2160perm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2160perm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perm", 1);

  /* "giacpy/auto-methods.pxi":13355
 * 
 *         '''
 *         return GiacMethods['perm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perminv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13355, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13346
 *         return GiacMethods['periodic'](self,*args)
 * 
 *      def perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13357
 *         return GiacMethods['perm'](self,*args)
 * 
 *      def perminv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perminv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2163perminv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2162perminv, "From Giac's documentation:\n        Help for perminv:\n        perminv(Permut(a))\n        Returns the inverse permutation of the permutation a.\n        See also: 1/ cycleinv \n        Ex1:perminv([1,3,2,4,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2163perminv = {"perminv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2163perminv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2162perminv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2163perminv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perminv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perminv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2162perminv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2162perminv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perminv", 1);

  /* "giacpy/auto-methods.pxi":13366
 * 
 *         '''
 *         return GiacMethods['perminv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def permu2cycles(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perminv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13366, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13357
 *         return GiacMethods['perm'](self,*args)
 * 
 *      def perminv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perminv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perminv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13368
 *         return GiacMethods['perminv'](self,*args)
 * 
 *      def permu2cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2cycles:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2165permu2cycles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2164permu2cycles, "From Giac's documentation:\n        Help for permu2cycles:\n        permu2cycles(Permut)\n        Converts a permutation to a product of disjoint cycles.\n        See also: 1/  cycles2permu 2/ cycle2perm \n        Ex1:permu2cycles([0,2,1,3,5,4])\n        Ex2:permu2cycles([0,2,1,4,3,5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2165permu2cycles = {"permu2cycles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2165permu2cycles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2164permu2cycles};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2165permu2cycles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("permu2cycles (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "permu2cycles", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2164permu2cycles(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2164permu2cycles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("permu2cycles", 1);

  /* "giacpy/auto-methods.pxi":13378
 * 
 *         '''
 *         return GiacMethods['permu2cycles'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def permu2mat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_permu2cycles); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13378, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13368
 *         return GiacMethods['perminv'](self,*args)
 * 
 *      def permu2cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2cycles:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.permu2cycles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13380
 *         return GiacMethods['permu2cycles'](self,*args)
 * 
 *      def permu2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2mat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2167permu2mat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2166permu2mat, "From Giac's documentation:\n        Help for permu2mat:\n        permu2mat(Permut(p))\n        Returns the matrix where the lines of the identity matrix are permuted with the permutation p.\n        See also: 1/  \n        Ex1:permu2mat([1,3,2,4,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2167permu2mat = {"permu2mat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2167permu2mat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2166permu2mat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2167permu2mat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("permu2mat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "permu2mat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2166permu2mat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2166permu2mat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("permu2mat", 1);

  /* "giacpy/auto-methods.pxi":13389
 * 
 *         '''
 *         return GiacMethods['permu2mat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def permuorder(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_permu2mat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13389, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13380
 *         return GiacMethods['permu2cycles'](self,*args)
 * 
 *      def permu2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2mat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.permu2mat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13391
 *         return GiacMethods['permu2mat'](self,*args)
 * 
 *      def permuorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permuorder:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2169permuorder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2168permuorder, "From Giac's documentation:\n        Help for permuorder:\n        permuorder(Permut(a))\n        Returns the order of the permutation a.\n        See also: 1/ cycles2permu \n        Ex1:permuorder([1,3,2,4,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2169permuorder = {"permuorder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2169permuorder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2168permuorder};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2169permuorder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("permuorder (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "permuorder", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2168permuorder(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2168permuorder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("permuorder", 1);

  /* "giacpy/auto-methods.pxi":13400
 * 
 *         '''
 *         return GiacMethods['permuorder'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def permute_vertices(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_permuorder); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13400, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13391
 *         return GiacMethods['permu2mat'](self,*args)
 * 
 *      def permuorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permuorder:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.permuorder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13402
 *         return GiacMethods['permuorder'](self,*args)
 * 
 *      def permute_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permute_vertices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2171permute_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2170permute_vertices, "From Giac's documentation:\n        Help for permute_vertices:\n        permute_vertices(Graph(G),Lst(V))\n        Returns a copy of G with vertices reordered according to the order in V.\n        See also: 1/ graph_vertices 2/ isomorphic_copy 3/ relabel_vertices \n        Ex1:permute_vertices(graph([a,b,c]),[a,c,b])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2171permute_vertices = {"permute_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2171permute_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2170permute_vertices};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2171permute_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("permute_vertices (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "permute_vertices", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2170permute_vertices(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2170permute_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("permute_vertices", 1);

  /* "giacpy/auto-methods.pxi":13411
 * 
 *         '''
 *         return GiacMethods['permute_vertices'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perpen_bisector(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_permute_vertices); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13411, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13402
 *         return GiacMethods['permuorder'](self,*args)
 * 
 *      def permute_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permute_vertices:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.permute_vertices", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13413
 *         return GiacMethods['permute_vertices'](self,*args)
 * 
 *      def perpen_bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpen_bisector:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2173perpen_bisector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2172perpen_bisector, "From Giac's documentation:\n        Help for perpen_bisector:\n        perpen_bisector((Pnt or Cplx),(Pnt or Cplx))\n        perpen_bisector(A,B) draws the bisector (line or plane) of the segment AB.\n        See also: 1/ midpoint 2/ median_line \n        Ex1:perpen_bisector(1-i,i)\n        Ex2:perpen_bisector([0,0,0],[5,5,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2173perpen_bisector = {"perpen_bisector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2173perpen_bisector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2172perpen_bisector};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2173perpen_bisector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perpen_bisector (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perpen_bisector", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2172perpen_bisector(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2172perpen_bisector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perpen_bisector", 1);

  /* "giacpy/auto-methods.pxi":13423
 * 
 *         '''
 *         return GiacMethods['perpen_bisector'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def perpendicular(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perpen_bisector); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13423, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13413
 *         return GiacMethods['permute_vertices'](self,*args)
 * 
 *      def perpen_bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpen_bisector:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perpen_bisector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13425
 *         return GiacMethods['perpen_bisector'](self,*args)
 * 
 *      def perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpendicular:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2175perpendicular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2174perpendicular, "From Giac's documentation:\n        Help for perpendicular:\n        perpendicular((Pnt or Line),(Line or Plan))\n        perpendicular(A,line(B,C)) or perpendicular(A,B,C) draws the orthogonal line of line BC through A and perpendicular(d,plane(B,C,D)) draws the orthogonal plane of plane(B,C,D) through the line d.\n        See also: 1/ altitude 2/ orthogonal \n        Ex1:perpendicular(1,line(1,i))\n        Ex2:perpendicular(1,0,1+i)\n        Ex3:perpendicular([0,0,0],line(x=y,y=z))\n        Ex4:perpendicular(line([0,0,0],[1,1,0]),plane(x+y+z=1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2175perpendicular = {"perpendicular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2175perpendicular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2174perpendicular};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2175perpendicular(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("perpendicular (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "perpendicular", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2174perpendicular(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2174perpendicular(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("perpendicular", 1);

  /* "giacpy/auto-methods.pxi":13437
 * 
 *         '''
 *         return GiacMethods['perpendicular'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def petersen_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_perpendicular); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13437, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13425
 *         return GiacMethods['perpen_bisector'](self,*args)
 * 
 *      def perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpendicular:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.perpendicular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13439
 *         return GiacMethods['perpendicular'](self,*args)
 * 
 *      def petersen_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for petersen_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2177petersen_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2176petersen_graph, "From Giac's documentation:\n        Help for petersen_graph:\n        petersen_graph(Intg(n),[Intg(k)])\n        Returns the generalized Petersen graph G(n,k), where n and k are positive integers (k defaults to 2).\n        See also: 1/ graph \n        Ex1:petersen_graph(5,2)\n        Ex2:petersen_graph(6,3)\n        Ex3:petersen_graph(10,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2177petersen_graph = {"petersen_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2177petersen_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2176petersen_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2177petersen_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("petersen_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "petersen_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2176petersen_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2176petersen_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("petersen_graph", 1);

  /* "giacpy/auto-methods.pxi":13450
 * 
 *         '''
 *         return GiacMethods['petersen_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def peval(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_petersen_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13450, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13439
 *         return GiacMethods['perpendicular'](self,*args)
 * 
 *      def petersen_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for petersen_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.petersen_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13452
 *         return GiacMethods['petersen_graph'](self,*args)
 * 
 *      def peval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for peval:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2179peval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2178peval, "From Giac's documentation:\n        Help for peval:\n        peval(Vect,Real(x0))\n        Evaluates at a point x0, a polynomial given by its coefficients.\n        See also: 1/ proot 2/ pcoeff \n        Ex1:peval([1,0,-2],1)\n        Ex2:peval([1,2,-25,-26,120],8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2179peval = {"peval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2179peval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2178peval};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2179peval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peval (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "peval", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2178peval(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2178peval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peval", 1);

  /* "giacpy/auto-methods.pxi":13462
 * 
 *         '''
 *         return GiacMethods['peval'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pi(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_peval); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13462, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13452
 *         return GiacMethods['petersen_graph'](self,*args)
 * 
 *      def peval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for peval:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.peval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13464
 *         return GiacMethods['peval'](self,*args)
 * 
 *      def pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pi:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2181pi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2180pi, "From Giac's documentation:\n        Help for pi:\n        pi()\n        pi.\n        See also: 1/ e 2/ i \n        Ex1: pi/4\n        Ex2: Pi/4\n        Ex3: evalf(pi)\n        Ex4: evalf(Pi)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2181pi = {"pi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2181pi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2180pi};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2181pi(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pi (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pi", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2180pi(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2180pi(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pi", 1);

  /* "giacpy/auto-methods.pxi":13476
 * 
 *         '''
 *         return GiacMethods['pi'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pie(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pi); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13476, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13464
 *         return GiacMethods['peval'](self,*args)
 * 
 *      def pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pi:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13478
 *         return GiacMethods['pi'](self,*args)
 * 
 *      def pie(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pie:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2183pie(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2182pie, "From Giac's documentation:\n        Help for pie:\n        pie(Mtrx)\n        Draws pie chart of a one variable statistical series.\n        See also: 1/ bar_plot \n        Ex1:pie([[\"France\",6],[\"Allemagne\",12],[\"Suisse\",5]])\n        Ex2:pie([3/2,2/3,5/4,4/5,7/6,6/7,9/8,8/9,11/10])\n        Ex3:pie([[2,\"xyz\",\"abc\"],[\"A\",2,5],[\"B\",5,6],[\"C\",7,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2183pie = {"pie", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2183pie, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2182pie};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2183pie(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pie (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pie", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2182pie(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2182pie(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pie", 1);

  /* "giacpy/auto-methods.pxi":13489
 * 
 *         '''
 *         return GiacMethods['pie'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def piecewise(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pie); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13489, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13478
 *         return GiacMethods['pi'](self,*args)
 * 
 *      def pie(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pie:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pie", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13491
 *         return GiacMethods['pie'](self,*args)
 * 
 *      def piecewise(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for piecewise:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2185piecewise(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2184piecewise, "From Giac's documentation:\n        Help for piecewise:\n        piecewise(Cond1,Expr1,..,Cond2p,Expr2p,[Expr2p+1])\n        If condition1 returns expr1 else...if condition2p returns expr2p else returns expr2p+1.\n        See also: 1/ if 2/ then 3/ else 4/ ifte 5/ switch \n        Ex1:piecewise(x<=-pi,x+2*pi,x<=pi,x,x+2*pi)\n        Ex2:piecewise(x<-2,-2,x<-1,3x+4,x<0,1,x+1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2185piecewise = {"piecewise", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2185piecewise, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2184piecewise};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2185piecewise(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("piecewise (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "piecewise", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2184piecewise(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2184piecewise(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("piecewise", 1);

  /* "giacpy/auto-methods.pxi":13501
 * 
 *         '''
 *         return GiacMethods['piecewise'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pink(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_piecewise); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13501, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13491
 *         return GiacMethods['pie'](self,*args)
 * 
 *      def piecewise(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for piecewise:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.piecewise", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13503
 *         return GiacMethods['piecewise'](self,*args)
 * 
 *      def pink(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pink:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2187pink(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2186pink, "From Giac's documentation:\n        Help for pink:\n        pink(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2187pink = {"pink", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2187pink, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2186pink};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2187pink(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pink (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pink", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2186pink(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2186pink(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pink", 1);

  /* "giacpy/auto-methods.pxi":13513
 * 
 *         '''
 *         return GiacMethods['pink'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pivot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pink); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13513, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13503
 *         return GiacMethods['piecewise'](self,*args)
 * 
 *      def pink(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pink:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pink", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13515
 *         return GiacMethods['pink'](self,*args)
 * 
 *      def pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pivot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2189pivot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2188pivot, "From Giac's documentation:\n        Help for pivot:\n        pivot(Mtrx(A),Intg(nl),Intg(nc))\n        Returns the matrix obtained from A by creating zeros in the column nc, by the method of Gauss-Jordan with the element A[nl,nc] as pivot.\n        See also: 1/ gaussjord 2/ linsolve \n        Ex1:pivot([[1,2],[3,4],[5,6]],0,1)\n        Ex2:pivot([[1,2],[3,4],[5,6]],1,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2189pivot = {"pivot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2189pivot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2188pivot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2189pivot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pivot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pivot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2188pivot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2188pivot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pivot", 1);

  /* "giacpy/auto-methods.pxi":13525
 * 
 *         '''
 *         return GiacMethods['pivot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pixoff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pivot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13525, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13515
 *         return GiacMethods['pink'](self,*args)
 * 
 *      def pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pivot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pivot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13527
 *         return GiacMethods['pivot'](self,*args)
 * 
 *      def pixoff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixoff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2191pixoff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2190pixoff, "From Giac's documentation:\n        Help for pixoff:\n        pixoff(Real(x),Real(y))\n        Pixel off.\n        See also: 1/ set_pixel 2/ pixon \n        Ex1:pixoff(1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2191pixoff = {"pixoff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2191pixoff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2190pixoff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2191pixoff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pixoff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pixoff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2190pixoff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2190pixoff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pixoff", 1);

  /* "giacpy/auto-methods.pxi":13536
 * 
 *         '''
 *         return GiacMethods['pixoff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pixon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pixoff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13536, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13527
 *         return GiacMethods['pivot'](self,*args)
 * 
 *      def pixoff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixoff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pixoff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13538
 *         return GiacMethods['pixoff'](self,*args)
 * 
 *      def pixon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2193pixon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2192pixon, "From Giac's documentation:\n        Help for pixon:\n        pixon(Real(x),Real(y))\n        Pixel on.\n        See also: 1/ set_pixel 2/ pixoff \n        Ex1:pixon(1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2193pixon = {"pixon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2193pixon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2192pixon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2193pixon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pixon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pixon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2192pixon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2192pixon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pixon", 1);

  /* "giacpy/auto-methods.pxi":13547
 * 
 *         '''
 *         return GiacMethods['pixon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def planar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pixon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13547, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13538
 *         return GiacMethods['pixoff'](self,*args)
 * 
 *      def pixon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pixon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13549
 *         return GiacMethods['pixon'](self,*args)
 * 
 *      def planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for planar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2195planar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2194planar, "From Giac's documentation:\n        Help for planar:\n        planar(Opt)\n        Option for the draw_graph command.\n        See also: 1/ spring 2/ tree 3/ draw_graph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2195planar = {"planar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2195planar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2194planar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2195planar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("planar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "planar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2194planar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2194planar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("planar", 1);

  /* "giacpy/auto-methods.pxi":13557
 * 
 *         '''
 *         return GiacMethods['planar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plane(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_planar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13557, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13549
 *         return GiacMethods['pixon'](self,*args)
 * 
 *      def planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for planar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.planar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13559
 *         return GiacMethods['planar'](self,*args)
 * 
 *      def plane(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2197plane(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2196plane, "From Giac's documentation:\n        Help for plane:\n        plane(Pnt or Eq, [Pnt or Line],[Pnt])\n        plane(A,B,C) or plane(A,line(B,C)) (resp plane(a*x+b*y+c*z+d=0)) draws the plane ABC (resp of equation a*x+b*y+c*z+d=0) in 3D space.\n        See also: 1/ line \n        Ex1:plane([0,0,0],[1,1,1],[1,0,0])\n        Ex2:plane([0,0,0],line([1,0,0],[1,1,1]))\n        Ex3:plane(x+y+z=0)\n        Ex4:plane(2*x+y-2*z-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2197plane = {"plane", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2197plane, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2196plane};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2197plane(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plane (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plane", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2196plane(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2196plane(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plane", 1);

  /* "giacpy/auto-methods.pxi":13571
 * 
 *         '''
 *         return GiacMethods['plane'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plane_dual(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plane); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13571, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13559
 *         return GiacMethods['planar'](self,*args)
 * 
 *      def plane(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plane", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13573
 *         return GiacMethods['plane'](self,*args)
 * 
 *      def plane_dual(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane_dual:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2199plane_dual(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2198plane_dual, "From Giac's documentation:\n        Help for plane_dual:\n        plane_dual(Graph(G)||Lst(F))\n        Returns the plane dual of a biconnected planar graph G or constructs it from the list F of its faces.\n        See also: 1/ is_planar \n        Ex1:plane_dual(hypercube_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2199plane_dual = {"plane_dual", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2199plane_dual, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2198plane_dual};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2199plane_dual(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plane_dual (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plane_dual", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2198plane_dual(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2198plane_dual(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plane_dual", 1);

  /* "giacpy/auto-methods.pxi":13582
 * 
 *         '''
 *         return GiacMethods['plane_dual'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def playsnd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plane_dual); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13582, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13573
 *         return GiacMethods['plane'](self,*args)
 * 
 *      def plane_dual(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane_dual:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plane_dual", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13584
 *         return GiacMethods['plane_dual'](self,*args)
 * 
 *      def playsnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for playsnd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2201playsnd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2200playsnd, "From Giac's documentation:\n        Help for playsnd:\n        playsnd(Vect)\n        Plays a sound data.\n        See also: 1/ readwav 2/ writewav 3/ soundsec \n        Ex1:playsnd(2^14*(sin(2*pi*440*soundsec(1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2201playsnd = {"playsnd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2201playsnd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2200playsnd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2201playsnd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("playsnd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "playsnd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2200playsnd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2200playsnd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("playsnd", 1);

  /* "giacpy/auto-methods.pxi":13593
 * 
 *         '''
 *         return GiacMethods['playsnd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_playsnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13593, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13584
 *         return GiacMethods['plane_dual'](self,*args)
 * 
 *      def playsnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for playsnd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.playsnd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13595
 *         return GiacMethods['playsnd'](self,*args)
 * 
 *      def plex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2203plex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2202plex, "From Giac's documentation:\n        Help for plex:\n        plex(Opt)\n        Option of the gbasis or greduce command to specify an order for monomials (=default order=pure lexicographic).\n        See also: 1/ gbasis 2/ greduce \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2203plex = {"plex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2203plex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2202plex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2203plex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2202plex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2202plex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plex", 1);

  /* "giacpy/auto-methods.pxi":13603
 * 
 *         '''
 *         return GiacMethods['plex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13603, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13595
 *         return GiacMethods['playsnd'](self,*args)
 * 
 *      def plex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13605
 *         return GiacMethods['plex'](self,*args)
 * 
 *      def plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2205plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2204plot, "From Giac's documentation:\n        Help for plot:\n        plot((Expr or LstExpr),Var[=VarMin..VarMax],[color=LstColor])\n        Plots a one-variable expression (or list of expressions).\n        See also: 1/ plotfunc 2/ plotparam 3/ animate 4/ animate3d 5/ plotarea \n        Ex1:plot(x-1/6*x^3,x)\n        Ex2:plot([2*x-1,sin(x)],x=1..2)\n        Ex3:plot(sin(x),x=-2..2,color=green,xstep=0.1)\n        Ex4:plot([2*x-2,2*sin(x)],x=1..2,color=[green,red],legende=[\"2x-2\",\"sin\"])\n        Ex5:plot(exponentiald(2))\n        Ex6:plot(normald)\n        Ex7:plot(normald(-1,2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2205plot = {"plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2205plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2204plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2205plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2204plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2204plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plot", 1);

  /* "giacpy/auto-methods.pxi":13620
 * 
 *         '''
 *         return GiacMethods['plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plot3d(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13620, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13605
 *         return GiacMethods['plex'](self,*args)
 * 
 *      def plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13622
 *         return GiacMethods['plot'](self,*args)
 * 
 *      def plot3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot3d:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2207plot3d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2206plot3d, "From Giac's documentation:\n        Help for plot3d:\n        plot3d(Expr||Lst(3*Expr),Var,Var)\n        Erases and plots a 2 variable expression or of a surface defined with a list of the 3 functions or of 3 expression of 2 variables.\n        See also: 1/ plotfunc 2/ animate3d \n        Ex1:plot3d(x^2+y^2+1,x,y)\n        Ex2:plot3d(x^2+y^2,x=-1..1,y=-2..2)\n        Ex3:plot3d([u+1,2*v,u^2+v^2],u=-1..1,v=-2..2)\n        Ex4:plot3d(f,-1..1,-2..2)\n        Ex5:plot3d([f,g,h],-1..1,-2..2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2207plot3d = {"plot3d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2207plot3d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2206plot3d};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2207plot3d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plot3d (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plot3d", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2206plot3d(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2206plot3d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plot3d", 1);

  /* "giacpy/auto-methods.pxi":13635
 * 
 *         '''
 *         return GiacMethods['plot3d'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotarea(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plot3d); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13635, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13622
 *         return GiacMethods['plot'](self,*args)
 * 
 *      def plot3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot3d:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plot3d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13637
 *         return GiacMethods['plot3d'](self,*args)
 * 
 *      def plotarea(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotarea:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2209plotarea(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2208plotarea, "From Giac's documentation:\n        Help for plotarea:\n        plotarea(Expr,x=a..b,[n],[Method])\n        Displays the area below a curve, optionally with a quadrature method (trapezoid,left_rectangle,right_rectangle,middle_point).\n        See also: 1/ integrate 2/ plot 3/ area 4/ areaat 5/ areaatraw \n        Ex1:plotarea(sin(x),x=0..pi)\n        Ex2:plotarea(x^2,x=0..1,5,trapezoid)\n        Ex3:plotarea(x^2,x=0..1,5,middle_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2209plotarea = {"plotarea", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2209plotarea, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2208plotarea};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2209plotarea(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotarea (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotarea", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2208plotarea(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2208plotarea(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotarea", 1);

  /* "giacpy/auto-methods.pxi":13648
 * 
 *         '''
 *         return GiacMethods['plotarea'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotcdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotarea); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13648, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13637
 *         return GiacMethods['plot3d'](self,*args)
 * 
 *      def plotarea(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotarea:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotarea", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13650
 *         return GiacMethods['plotarea'](self,*args)
 * 
 *      def plotcdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2211plotcdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2210plotcdf, "From Giac's documentation:\n        Help for plotcdf:\n        plotcdf(Func,FuncParams)\n        Graphic representation of a cumulative distribution function.\n        See also: 1/ icdf 2/ binomial_cdf 3/ normald_cdf 4/ cdf \n        Ex1:plotcdf(binomial,10,0.5)\n        Ex2:plotcdf(normald,0.0,1.0)\n        Ex3:plotcdf([1,3,4,3,5,6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2211plotcdf = {"plotcdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2211plotcdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2210plotcdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2211plotcdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotcdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotcdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2210plotcdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2210plotcdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotcdf", 1);

  /* "giacpy/auto-methods.pxi":13661
 * 
 *         '''
 *         return GiacMethods['plotcdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotcontour(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotcdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13661, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13650
 *         return GiacMethods['plotarea'](self,*args)
 * 
 *      def plotcdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotcdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13663
 *         return GiacMethods['plotcdf'](self,*args)
 * 
 *      def plotcontour(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcontour:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2213plotcontour(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2212plotcontour, "From Giac's documentation:\n        Help for plotcontour:\n        plotcontour(Expr(Xpr),[LstVar],[LstVal])\n        Draws 11 equirepartited contour-lines z=z_min,,...z=z_max of the surface z=Xpr, or the contour-lines defined by the 3-rd argument.\n        See also: 1/ plotdensity 2/ plotimplicit \n        Ex1:plotcontour(x^2+y^2)\n        Ex2:plotcontour(x^2+y^2,[x,y])\n        Ex3:plotcontour(x^2+2*y^2-2,[x,y],[1.0,2.0,3.0])\n        Ex4:plotcontour(x^2-y^2,[x=-4..4,y=-4..4],seq(k,k,-11,11,3),xstep=0.1,ystep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2213plotcontour = {"plotcontour", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2213plotcontour, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2212plotcontour};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2213plotcontour(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotcontour (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotcontour", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2212plotcontour(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2212plotcontour(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotcontour", 1);

  /* "giacpy/auto-methods.pxi":13675
 * 
 *         '''
 *         return GiacMethods['plotcontour'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotdensity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotcontour); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13675, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13663
 *         return GiacMethods['plotcdf'](self,*args)
 * 
 *      def plotcontour(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcontour:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotcontour", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13677
 *         return GiacMethods['plotcontour'](self,*args)
 * 
 *      def plotdensity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotdensity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2215plotdensity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2214plotdensity, "From Giac's documentation:\n        Help for plotdensity:\n        plotdensity(Expr,[x=xrange,y=yrange],[z],[xstep],[ystep])\n        Shows in the plane with colors the graph of an expression of 2 variables.\n        See also: 1/ plotfunc 2/ plotcontour \n        Ex1:plotdensity(x^2-y^2,[x=-2..2,y=-2..2],xstep=0.1,ystep=0.1)\n        Ex2:plotdensity(x^2-y^2,[x=-2..2,y=-2..2],z=-2..2,xstep=0.1,ystep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2215plotdensity = {"plotdensity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2215plotdensity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2214plotdensity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2215plotdensity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotdensity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotdensity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2214plotdensity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2214plotdensity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotdensity", 1);

  /* "giacpy/auto-methods.pxi":13687
 * 
 *         '''
 *         return GiacMethods['plotdensity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotfield(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotdensity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13687, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13677
 *         return GiacMethods['plotcontour'](self,*args)
 * 
 *      def plotdensity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotdensity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotdensity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13689
 *         return GiacMethods['plotdensity'](self,*args)
 * 
 *      def plotfield(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfield:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2217plotfield(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2216plotfield, "From Giac's documentation:\n        Help for plotfield:\n        plotfield(Expr,VectVar,[Opt])\n        plotfield(f(t,y),[t,y]) draws the plotfield of the diff equation y'=f(t,y).\n        See also: 1/ interactive_plotode 2/ odeplot 3/ odesolve 4/ desolve \n        Ex1:plotfield(sin(t*y),[t=-5..5,y=-3..3],xstep=0.5,ystep=0.5)\n        Ex2:plotfield(-t*y,[t,y])\n        Ex3:plotfield(-t*y,[t,y],normalize)\n        Ex4:plotfield(-t*y,[t,y],normalize,xstep=0.5,ystep=0.5)\n        Ex5:plotfield(-t*y,[t=-6.868..6.868,y=-6.868..6.868],normalize)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2217plotfield = {"plotfield", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2217plotfield, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2216plotfield};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2217plotfield(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotfield (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotfield", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2216plotfield(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2216plotfield(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotfield", 1);

  /* "giacpy/auto-methods.pxi":13702
 * 
 *         '''
 *         return GiacMethods['plotfield'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotfunc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotfield); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13702, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13689
 *         return GiacMethods['plotdensity'](self,*args)
 * 
 *      def plotfield(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfield:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotfield", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13704
 *         return GiacMethods['plotfield'](self,*args)
 * 
 *      def plotfunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfunc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2219plotfunc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2218plotfunc, "From Giac's documentation:\n        Help for plotfunc:\n        plotfunc(Expr,[Var(x) or VectVar] ,[Intg(color)])\n        Plots a 1 variable or 2 variables expression with superposition.\n        See also: 1/ plot 2/ plot3d 3/ plotparam 4/ animate 5/ animate3d 6/ plotdensity \n        Ex1:plotfunc(-2*x+1,x=1..2,color=red)\n        Ex2:plotfunc([-2*x+1,x^2-2],x=-2..2,color=[red,yellow],xstep=0.2)\n        Ex3:plotfunc(x^2-y^2,[x,y],xstep=0.5,ystep=0.3)\n        Ex4:plotfunc(x^2+y^2,[x=-1..1,y=-2..2],nstep=900)\n        Ex5:plotfunc((x+i*y)^2,[x=-1..1,y=-2..2],nstep=900,affichage=rempli)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2219plotfunc = {"plotfunc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2219plotfunc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2218plotfunc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2219plotfunc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotfunc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotfunc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2218plotfunc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2218plotfunc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotfunc", 1);

  /* "giacpy/auto-methods.pxi":13717
 * 
 *         '''
 *         return GiacMethods['plotfunc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotimf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotfunc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13717, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13704
 *         return GiacMethods['plotfield'](self,*args)
 * 
 *      def plotfunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfunc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotfunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13719
 *         return GiacMethods['plotfunc'](self,*args)
 * 
 *      def plotimf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2221plotimf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2220plotimf, "From Giac's documentation:\n        Help for plotimf:\n        plotimf(Lst(imf),[opts])\n        Displays selected intrinsic mode functions in a stacked layout.\n        See also: 1/ emd \n        Ex1:plotimf(emd(apply(x->cos(10*x^2*pi),linspace(-pi,pi)),residue=false))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2221plotimf = {"plotimf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2221plotimf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2220plotimf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2221plotimf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotimf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotimf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2220plotimf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2220plotimf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotimf", 1);

  /* "giacpy/auto-methods.pxi":13728
 * 
 *         '''
 *         return GiacMethods['plotimf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotimplicit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotimf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13728, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13719
 *         return GiacMethods['plotfunc'](self,*args)
 * 
 *      def plotimf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotimf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13730
 *         return GiacMethods['plotimf'](self,*args)
 * 
 *      def plotimplicit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimplicit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2223plotimplicit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2222plotimplicit, "From Giac's documentation:\n        Help for plotimplicit:\n        plotimplicit(Expr,Var1,Var2)\n        plotimplicit(f(x,y),x,y) or plotimplicit(f(x,y),[x,y]) draws graph of f(x,y)=0.\n        See also: 1/ plotcontour 2/ unfactored 3/ plotinequation \n        Ex1:plotimplicit(x^2+y^2-1,x,y)\n        Ex2:plotimplicit(x^4+y^4=x^2-y^2)\n        Ex3:plotimplicit(x^2+y^2-1,x,y,unfactored)\n        Ex4:plotimplicit(x^2+4*y^3-1)\n        Ex5:plotimplicit(x^2+4*y^3-k)$(k=-5..5)\n        Ex6:plotimplicit(y^3=x^3-x^2,x,y,xstep=0.1,ystep=0.1)\n        Ex7:plotimplicit(y^3=x^3-x^2,[x,y],xstep=0.1,ystep=0.1)\n        Ex8:plotimplicit((x+5)^2+(y+4)^2-1,x=-6..-4,y=-5..-3)\n        Ex9:plotimplicit((x+5)^2+(y+4)^2-1,[x=-6..-4,y=-5..-3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2223plotimplicit = {"plotimplicit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2223plotimplicit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2222plotimplicit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2223plotimplicit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotimplicit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotimplicit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2222plotimplicit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2222plotimplicit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotimplicit", 1);

  /* "giacpy/auto-methods.pxi":13747
 * 
 *         '''
 *         return GiacMethods['plotimplicit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotinequation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotimplicit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13747, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13730
 *         return GiacMethods['plotimf'](self,*args)
 * 
 *      def plotimplicit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimplicit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotimplicit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13749
 *         return GiacMethods['plotimplicit'](self,*args)
 * 
 *      def plotinequation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotinequation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2225plotinequation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2224plotinequation, "From Giac's documentation:\n        Help for plotinequation:\n        plotinequation(Expr,[x=xrange,y=yrange],[xstep],[ystep])\n        Shows the graph of the solutions of inequalities with 2 variables.\n        See also: 1/ plotfunc 2/ plotcontour 3/ plotdensity 4/ plotimplicit \n        Ex1:plotinequation(x^2-y^2<3)\n        Ex2:plotinequation(x^2-y^2<3,[x=-2..2,y=-2..2],xstep=0.1,ystep=0.1)\n        Ex3:plotinequation(3-(x^2-y^2),[x=-2..2,y=-2..2],xstep=0.1,ystep=0.1)\n        Ex4:plotinequation([x+y>3,x^2<y],[x,y],xstep=0.2,ystep=0.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2225plotinequation = {"plotinequation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2225plotinequation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2224plotinequation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2225plotinequation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotinequation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotinequation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2224plotinequation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2224plotinequation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotinequation", 1);

  /* "giacpy/auto-methods.pxi":13761
 * 
 *         '''
 *         return GiacMethods['plotinequation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotlist(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotinequation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13761, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13749
 *         return GiacMethods['plotimplicit'](self,*args)
 * 
 *      def plotinequation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotinequation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotinequation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13763
 *         return GiacMethods['plotinequation'](self,*args)
 * 
 *      def plotlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotlist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2227plotlist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2226plotlist, "From Giac's documentation:\n        Help for plotlist:\n        plotlist(Lst(l)||Mtrx(M))\n        Draws the polygonal line through the points with abscissas 0,...,n and ordinates l=[y0,...,yn] or the line through the points with abscissas the first column of M and ordinates the second column.\n        See also: 1/ polygonplot 2/ scatterplot 3/ polygonscatterplot \n        Ex1:plotlist([13,10,15,16])\n        Ex2:plotlist([1,13],[2,10],[3,15],[4,16])\n        Ex3:plotlist([[0,13],[2,10],[4,15]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2227plotlist = {"plotlist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2227plotlist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2226plotlist};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2227plotlist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotlist (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotlist", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2226plotlist(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2226plotlist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotlist", 1);

  /* "giacpy/auto-methods.pxi":13774
 * 
 *         '''
 *         return GiacMethods['plotlist'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotode(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotlist); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13774, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13763
 *         return GiacMethods['plotinequation'](self,*args)
 * 
 *      def plotlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotlist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotlist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13776
 *         return GiacMethods['plotlist'](self,*args)
 * 
 *      def plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotode:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2229plotode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2228plotode, "From Giac's documentation:\n        Help for plotode:\n        plotode(Expr,VectVar,VectInitCond)\n        plotode(f(t,y),[t,y],[t0,y0]) draws the solution of y'=f(t,y) and y(t0)=y0 or of the system [x'=g(t,x,y),y'=h(t,x,y)] with x(t0)=x0 and y(t0)=y0.\n        See also: 1/ interactive_plotode 2/ fieldplot 3/ odesolve 4/ desolve \n        Ex1:plotode(sin(t*y),[t,y],[0,1])\n        Ex2:plotode(sin(t*y),[t=-10..10,y],[0,1])\n        Ex3:plotode(sin(t*y),[t=-3..3,y],[0,1],tstep=0.1,color=vert)\n        Ex4:plotode([x-0.3*x*y, 0.3*x*y-y], [t,x,y],[0,0.3,0.7])\n        Ex5:plotode([x-0.3*x*y, 0.3*x*y-y], [t,x,y],[0,0.3,0.7],plan)\n        Ex6:plotode([-y+b,-1+(x-a)^2+(y-b)^2],[t=-3..3,x,y],[0,a+1,b+0.5],plan)\n        Ex7:plotode(5*[-y,x],[t=0..1,x,y],[0,0.3,0.7],tstep=0.05,plan)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2229plotode = {"plotode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2229plotode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2228plotode};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2229plotode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotode", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2228plotode(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2228plotode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotode", 1);

  /* "giacpy/auto-methods.pxi":13791
 * 
 *         '''
 *         return GiacMethods['plotode'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotparam(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotode); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13791, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13776
 *         return GiacMethods['plotlist'](self,*args)
 * 
 *      def plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13793
 *         return GiacMethods['plotode'](self,*args)
 * 
 *      def plotparam(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotparam:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2231plotparam(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2230plotparam, "From Giac's documentation:\n        Help for plotparam:\n        plotparam(Cplx||Lst,Var||Lst(Var))\n        plotparam(a(x)+i*b(x),x=x0..x1) draws the curve X=a(x),Y=b(x) x=x0..x1 or plotparam([a(u,v),b(u,v),c(u,v)],[u=u0..u1,v=v0..v1]) draws the surface X=a(u,v),Y=b(u,v),Z=c(u,v) u=u0..u1 and v=v0..v1.\n        See also: 1/ plotfunc 2/ plotpolar 3/ arc \n        Ex1:plotparam(sin(t)+i*cos(t),t)\n        Ex2:plotparam(exp(i*t),t=0..pi/2,affichage=1)\n        Ex3:plotparam(exp(i*t),t=0..pi/2,affichage=1+rempli)\n        Ex4:plotparam([sin(x),cos(x)],x=0..1)\n        Ex5:plotparam([sin(x),cos(x)],x=0..1,affichage=rouge)\n        Ex6:plotparam(sin(x)+i*cos(x),x=0..1,tstep=0.01)\n        Ex7:plotparam([v*cos(u),v*sin(u),v],[u,v])\n        Ex8:plotparam([v*cos(u),v*sin(u),v],[u=0..pi,v=0..3],ustep=0.1,vstep=0.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2231plotparam = {"plotparam", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2231plotparam, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2230plotparam};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2231plotparam(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotparam (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotparam", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2230plotparam(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2230plotparam(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotparam", 1);

  /* "giacpy/auto-methods.pxi":13809
 * 
 *         '''
 *         return GiacMethods['plotparam'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotpolar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotparam); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13809, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13793
 *         return GiacMethods['plotode'](self,*args)
 * 
 *      def plotparam(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotparam:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotparam", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13811
 *         return GiacMethods['plotparam'](self,*args)
 * 
 *      def plotpolar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotpolar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2233plotpolar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2232plotpolar, "From Giac's documentation:\n        Help for plotpolar:\n        plotpolar(Expr,Var,VarMin,VarMax)\n        plotpolar(f(x),x,a,b) draws the polar curve r=f(x) for x in [a,b].\n        See also: 1/ plotparam 2/ plotfunc 3/ plotpolar \n        Ex1:plotpolar(sin(2*x),x,0,pi)\n        Ex2:plotpolar(sin(2*x),x,0,pi,tstep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2233plotpolar = {"plotpolar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2233plotpolar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2232plotpolar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2233plotpolar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotpolar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotpolar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2232plotpolar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2232plotpolar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotpolar", 1);

  /* "giacpy/auto-methods.pxi":13821
 * 
 *         '''
 *         return GiacMethods['plotpolar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotproba(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotpolar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13821, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13811
 *         return GiacMethods['plotparam'](self,*args)
 * 
 *      def plotpolar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotpolar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotpolar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13823
 *         return GiacMethods['plotpolar'](self,*args)
 * 
 *      def plotproba(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotproba:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2235plotproba(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2234plotproba, "From Giac's documentation:\n        Help for plotproba:\n        plotproba(Matrix,[Vector])\n        Graph of a transition matrix with at most 7x7 entries (optionally with list of vertex positions).\n        See also: 1/ markov 2/ randmarkov \n        Ex1:plotproba([[1/2,1/3,1/12,1/12],[1/3,1/2,1/6,0],[0,0,1/2,1/2],[1/4,1/4,1/4,1/4],[\"xy\",b,\"state\",d]])\n        Ex2:plotproba([[1/2,1/3,1/12,1/12],[1/3,1/2,1/6,0],[0,0,1/2,1/2],[1/4,1/4,1/4,1/4]],[0,1,i,1/3+2/3*i])\n        Ex3: L:=point(1):;C:=point(0.5+0.3*i):;G:=point(0.5+0.8*i):;plotproba([[1/2,1/3,1/12],[1/3,1/2,1/6],[0,0,1/2]],[L,C,G])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2235plotproba = {"plotproba", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2235plotproba, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2234plotproba};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2235plotproba(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotproba (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotproba", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2234plotproba(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2234plotproba(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotproba", 1);

  /* "giacpy/auto-methods.pxi":13834
 * 
 *         '''
 *         return GiacMethods['plotproba'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotseq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotproba); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13834, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13823
 *         return GiacMethods['plotpolar'](self,*args)
 * 
 *      def plotproba(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotproba:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotproba", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13836
 *         return GiacMethods['plotproba'](self,*args)
 * 
 *      def plotseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotseq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2237plotseq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2236plotseq, "From Giac's documentation:\n        Help for plotseq:\n        plotseq(Expr(f(Var)),Var=[a,xm,xM],Intg(p))\n        For seeing the pth terms of the sequence u(0)=a,u(n)=f(u(n-1)).\n        See also: 1/ seqsolve 2/ rsolve \n        Ex1:plotseq(sqrt(2+x),6,5)\n        Ex2:plotseq(sqrt(2+t),t=6,5)\n        Ex3:plotseq(sqrt(2+x),x=[6,1,7],5,affichage=epaisseur_ligne_2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2237plotseq = {"plotseq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2237plotseq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2236plotseq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2237plotseq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotseq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotseq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2236plotseq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2236plotseq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotseq", 1);

  /* "giacpy/auto-methods.pxi":13847
 * 
 *         '''
 *         return GiacMethods['plotseq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotspectrum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotseq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13847, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13836
 *         return GiacMethods['plotproba'](self,*args)
 * 
 *      def plotseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotseq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotseq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13849
 *         return GiacMethods['plotseq'](self,*args)
 * 
 *      def plotspectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotspectrum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2239plotspectrum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2238plotspectrum, "From Giac's documentation:\n        Help for plotspectrum:\n        plotspectrum(Audio(clip),[range=a..b])\n        Plots the power spectrum of an audio clip (on the specified frequency range).\n        See also: 1/ plotwav \n        Ex1:plotspectrum(readwav(\"/some/file\"))\n        Ex2:plotspectrum(readwav(\"/some/file\"),range=100..1000)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2239plotspectrum = {"plotspectrum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2239plotspectrum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2238plotspectrum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2239plotspectrum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotspectrum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotspectrum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2238plotspectrum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2238plotspectrum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotspectrum", 1);

  /* "giacpy/auto-methods.pxi":13859
 * 
 *         '''
 *         return GiacMethods['plotspectrum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plotwav(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotspectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13859, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13849
 *         return GiacMethods['plotseq'](self,*args)
 * 
 *      def plotspectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotspectrum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotspectrum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13861
 *         return GiacMethods['plotspectrum'](self,*args)
 * 
 *      def plotwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotwav:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2241plotwav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2240plotwav, "From Giac's documentation:\n        Help for plotwav:\n        plotwav(Audio(clip),[range=a..b])\n        Plots the waveform of an audio clip (optionally at the specified range).\n        See also: 1/ plotspectrum \n        Ex1:plotwav(readwav(\"/some/file\"))\n        Ex2:plotwav(readwav(\"/some/file\"),range=1.0..2.5) // range in seconds\n        Ex3:plotwav(readwav(\"/some/file\"),range=[10000,22000]) // range in samples\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2241plotwav = {"plotwav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2241plotwav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2240plotwav};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2241plotwav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plotwav (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plotwav", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2240plotwav(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2240plotwav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plotwav", 1);

  /* "giacpy/auto-methods.pxi":13872
 * 
 *         '''
 *         return GiacMethods['plotwav'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def plus_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plotwav); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13872, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13861
 *         return GiacMethods['plotspectrum'](self,*args)
 * 
 *      def plotwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotwav:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plotwav", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13874
 *         return GiacMethods['plotwav'](self,*args)
 * 
 *      def plus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plus_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2243plus_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2242plus_point, "From Giac's documentation:\n        Help for plus_point:\n        plus_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2243plus_point = {"plus_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2243plus_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2242plus_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2243plus_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plus_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "plus_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2242plus_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2242plus_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plus_point", 1);

  /* "giacpy/auto-methods.pxi":13884
 * 
 *         '''
 *         return GiacMethods['plus_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pmin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_plus_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13884, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13874
 *         return GiacMethods['plotwav'](self,*args)
 * 
 *      def plus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plus_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.plus_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13886
 *         return GiacMethods['plus_point'](self,*args)
 * 
 *      def pmin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pmin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2245pmin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2244pmin, "From Giac's documentation:\n        Help for pmin:\n        pmin(Mtrx(A)||Real(a),[Var])\n        Returns the minimal polynomial of the matrix A or the minimal polynomial of the algebraic number a.\n        See also: 1/ pcar 2/ jordan \n        Ex1:pmin((\316\261\316\273\316\263\316\265\316\262\317\201\316\271\316\272\316\256 \316\261\317\201\316\271\316\270\316\274\316\277\317\215).)\n        Ex2:pmin([[1,0],[0,1]])\n        Ex3:pmin([[1,0],[0,1]],x)\n        Ex4:pmin(sqrt(2)+sqrt(3))\n        Ex5:pmin(sqrt(2)+sqrt(3),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2245pmin = {"pmin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2245pmin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2244pmin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2245pmin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pmin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pmin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2244pmin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2244pmin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pmin", 1);

  /* "giacpy/auto-methods.pxi":13899
 * 
 *         '''
 *         return GiacMethods['pmin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pmin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13899, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13886
 *         return GiacMethods['plus_point'](self,*args)
 * 
 *      def pmin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pmin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pmin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13901
 *         return GiacMethods['pmin'](self,*args)
 * 
 *      def point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2247point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2246point, "From Giac's documentation:\n        Help for point:\n        point(Cplx(za)||Vect)\n        A:=point(za) or A:=point(a,b) (resp A:=point([a,b,c])) draws a point with affix za=a+ib (resp of coordinates (a,b,c)) with the legend A.\n        See also: 1/ pixon 2/ line 3/ point2d 4/ point3d 5/ polar_point \n        Ex1:point(1+2i)\n        Ex2:point(1,2)\n        Ex3:point(1,2,3)\n        Ex4:point([1,2,3])\n        Ex5: B:=point(1-i)\n        Ex6: B:=point(1,-1)\n        Ex7: B:=point(1,0,0)\n        Ex8: B:=point([1,0,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2247point = {"point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2247point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2246point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2247point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2246point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2246point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("point", 1);

  /* "giacpy/auto-methods.pxi":13917
 * 
 *         '''
 *         return GiacMethods['point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def point2d(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13917, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13901
 *         return GiacMethods['pmin'](self,*args)
 * 
 *      def point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13919
 *         return GiacMethods['point'](self,*args)
 * 
 *      def point2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point2d:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2249point2d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2248point2d, "From Giac's documentation:\n        Help for point2d:\n        point2d(SeqVar(A,B,C...))\n        Defines at random, the coordinates (between -5 and +5) of the 2d points given as argument.\n        See also: 1/ point3d 2/ point \n        Ex1:point2d(A,B,C,D)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2249point2d = {"point2d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2249point2d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2248point2d};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2249point2d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("point2d (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "point2d", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2248point2d(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2248point2d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("point2d", 1);

  /* "giacpy/auto-methods.pxi":13928
 * 
 *         '''
 *         return GiacMethods['point2d'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def point3d(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_point2d); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13928, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13919
 *         return GiacMethods['point'](self,*args)
 * 
 *      def point2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point2d:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.point2d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13930
 *         return GiacMethods['point2d'](self,*args)
 * 
 *      def point3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point3d:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2251point3d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2250point3d, "From Giac's documentation:\n        Help for point3d:\n        point3d(SeqVar(A,B,C...))\n        Defines at random, the coordinates (between -5 and +5) of the 3d points given as argument.\n        See also: 1/ point2d 2/ point \n        Ex1:point3d(A,B,C,D)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2251point3d = {"point3d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2251point3d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2250point3d};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2251point3d(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("point3d (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "point3d", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2250point3d(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2250point3d(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("point3d", 1);

  /* "giacpy/auto-methods.pxi":13939
 * 
 *         '''
 *         return GiacMethods['point3d'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def poisson(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_point3d); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13939, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13930
 *         return GiacMethods['point2d'](self,*args)
 * 
 *      def point3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point3d:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.point3d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13941
 *         return GiacMethods['point3d'](self,*args)
 * 
 *      def poisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2253poisson(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2252poisson, "From Giac's documentation:\n        Help for poisson:\n        poisson(Real(mu),Intg(k))\n        Returns exp(-mu)*mu^k/k!\n        See also: 1/ poisson_cdf 2/ poisson_icdf 3/ randvector 4/ ranm \n        Ex1:poisson(0.5,2)\n        Ex2:poisson(4.0,2)\n        Ex3: randvector(3,poisson,0.5)\n        Ex4: ranm(4,3,poisson,0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2253poisson = {"poisson", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2253poisson, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2252poisson};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2253poisson(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("poisson (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "poisson", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2252poisson(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2252poisson(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("poisson", 1);

  /* "giacpy/auto-methods.pxi":13953
 * 
 *         '''
 *         return GiacMethods['poisson'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def poisson_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_poisson); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13953, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13941
 *         return GiacMethods['point3d'](self,*args)
 * 
 *      def poisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.poisson", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13955
 *         return GiacMethods['poisson'](self,*args)
 * 
 *      def poisson_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2255poisson_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2254poisson_cdf, "From Giac's documentation:\n        Help for poisson_cdf:\n        poisson_cdf(Real(mu),Real(x))\n        Returns Proba(X<=x) when X follows the Poisson law with mu as mean.\n        See also: 1/ poisson 2/ poisson_icdf \n        Ex1:poisson_cdf(4.0,7)\n        Ex2:poisson_cdf(poisson_cpdf(2.5,4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2255poisson_cdf = {"poisson_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2255poisson_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2254poisson_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2255poisson_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("poisson_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "poisson_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2254poisson_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2254poisson_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("poisson_cdf", 1);

  /* "giacpy/auto-methods.pxi":13965
 * 
 *         '''
 *         return GiacMethods['poisson_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def poisson_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_poisson_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13965, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13955
 *         return GiacMethods['poisson'](self,*args)
 * 
 *      def poisson_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.poisson_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13967
 *         return GiacMethods['poisson_cdf'](self,*args)
 * 
 *      def poisson_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2257poisson_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2256poisson_icdf, "From Giac's documentation:\n        Help for poisson_icdf:\n        poisson_icdf(Real(mu),Real(p))\n        Returns h such as Proba(X<=h)=p when X follows the Poisson law with mu as parameter.\n        See also: 1/ poisson 2/ poisson_cdf \n        Ex1:poisson_icdf(4.0,0.95)\n        Ex2:poisson_icdf(2.5,0.9)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2257poisson_icdf = {"poisson_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2257poisson_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2256poisson_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2257poisson_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("poisson_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "poisson_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2256poisson_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2256poisson_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("poisson_icdf", 1);

  /* "giacpy/auto-methods.pxi":13977
 * 
 *         '''
 *         return GiacMethods['poisson_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def poisson_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_poisson_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13977, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13967
 *         return GiacMethods['poisson_cdf'](self,*args)
 * 
 *      def poisson_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.poisson_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13979
 *         return GiacMethods['poisson_icdf'](self,*args)
 * 
 *      def poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2259poisson_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2258poisson_window, "From Giac's documentation:\n        Help for poisson_window:\n        poisson_window(Lst,[Real(a)],[Interval(n1..n2)])\n        Applies the Poisson windowing function with parameter a>0 (by default a=1) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ bartlett_hann_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(poisson_window(randvector(1000,0..1),0.5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2259poisson_window = {"poisson_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2259poisson_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2258poisson_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2259poisson_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("poisson_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "poisson_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2258poisson_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2258poisson_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("poisson_window", 1);

  /* "giacpy/auto-methods.pxi":13988
 * 
 *         '''
 *         return GiacMethods['poisson_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_poisson_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 13988, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13979
 *         return GiacMethods['poisson_icdf'](self,*args)
 * 
 *      def poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.poisson_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":13990
 *         return GiacMethods['poisson_window'](self,*args)
 * 
 *      def polar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2261polar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2260polar, "From Giac's documentation:\n        Help for polar:\n        polar(Crcle,Pnt or Cplxe(A))\n        Returns the line of the conjugated points of A with respect to the circle.\n        See also: 1/ pole 2/ is_conjugate \n        Ex1:polar(circle(0,1),point(1+i)/2)\n        Ex2:polar(circle(0,1),point(1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2261polar = {"polar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2261polar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2260polar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2261polar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2260polar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2260polar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polar", 1);

  /* "giacpy/auto-methods.pxi":14000
 * 
 *         '''
 *         return GiacMethods['polar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polar_coordinates(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14000, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":13990
 *         return GiacMethods['poisson_window'](self,*args)
 * 
 *      def polar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14002
 *         return GiacMethods['polar'](self,*args)
 * 
 *      def polar_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_coordinates:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2263polar_coordinates(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2262polar_coordinates, "From Giac's documentation:\n        Help for polar_coordinates:\n        polar_coordinates(Pnt or Cplx or LstRectCoord)\n        Returns the list of the norm and of the argument of the affix of a point (for 2D) or of a complex number or of the the list of rectangular coordinates.\n        See also: 1/ abscissapoint 2/ ordinate 3/ rectangular_coordinates 4/ polar_point \n        Ex1:polar_coordinates(point(1+2*i))\n        Ex2:polar_coordinates(-1-i)\n        Ex3:polar_coordinates([-1,2])\n        Ex4:polar_coordinates(point(1+2*i)-point(-1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2263polar_coordinates = {"polar_coordinates", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2263polar_coordinates, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2262polar_coordinates};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2263polar_coordinates(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polar_coordinates (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polar_coordinates", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2262polar_coordinates(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2262polar_coordinates(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polar_coordinates", 1);

  /* "giacpy/auto-methods.pxi":14014
 * 
 *         '''
 *         return GiacMethods['polar_coordinates'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polar_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polar_coordinates); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14014, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14002
 *         return GiacMethods['polar'](self,*args)
 * 
 *      def polar_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_coordinates:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polar_coordinates", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14016
 *         return GiacMethods['polar_coordinates'](self,*args)
 * 
 *      def polar_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2265polar_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2264polar_point, "From Giac's documentation:\n        Help for polar_point:\n        polar_point(Real(r),Real(t))\n        Returns the point (for 2D) with the arguments r and t as polar coordinates (i.e. with r*exp(i*t) as affix).\n        See also: 1/ abscissa 2/ ordinate 3/ polar_coordinates 4/ rectangular_coordinates 5/ point \n        Ex1:polar_point(1,pi/4)\n        Ex2:polar_point(2,-pi/3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2265polar_point = {"polar_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2265polar_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2264polar_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2265polar_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polar_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polar_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2264polar_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2264polar_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polar_point", 1);

  /* "giacpy/auto-methods.pxi":14026
 * 
 *         '''
 *         return GiacMethods['polar_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polarplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polar_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14026, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14016
 *         return GiacMethods['polar_coordinates'](self,*args)
 * 
 *      def polar_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polar_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14028
 *         return GiacMethods['polar_point'](self,*args)
 * 
 *      def polarplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polarplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2267polarplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2266polarplot, "From Giac's documentation:\n        Help for polarplot:\n        polarplot(Expr,Var,VarMin,VarMax)\n        plotpolar(f(x),x,a,b) draws the polar curve r=f(x) for x in [a,b].\n        See also: 1/ plotparam 2/ plotfunc 3/ plotpolar \n        Ex1:polarplot(sin(2*x),x,0,pi)\n        Ex2:polarplot(sin(2*x),x,0,pi,tstep=0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2267polarplot = {"polarplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2267polarplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2266polarplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2267polarplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polarplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polarplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2266polarplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2266polarplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polarplot", 1);

  /* "giacpy/auto-methods.pxi":14038
 * 
 *         '''
 *         return GiacMethods['polarplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pole(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polarplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14038, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14028
 *         return GiacMethods['polar_point'](self,*args)
 * 
 *      def polarplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polarplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polarplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14040
 *         return GiacMethods['polarplot'](self,*args)
 * 
 *      def pole(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pole:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2269pole(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2268pole, "From Giac's documentation:\n        Help for pole:\n        pole(Crcle,Line)\n        Returns the point having the line as polar with respect to the circle .\n        See also: 1/ polar 2/ is_conjugate \n        Ex1:pole(circle(0,1),line(i,1))\n        Ex2:pole(circle(0,1),line((1+i),2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2269pole = {"pole", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2269pole, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2268pole};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2269pole(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pole (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pole", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2268pole(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2268pole(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pole", 1);

  /* "giacpy/auto-methods.pxi":14050
 * 
 *         '''
 *         return GiacMethods['pole'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def poly2symb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pole); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14050, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14040
 *         return GiacMethods['polarplot'](self,*args)
 * 
 *      def pole(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pole:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pole", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14052
 *         return GiacMethods['pole'](self,*args)
 * 
 *      def poly2symb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poly2symb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2271poly2symb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2270poly2symb, "From Giac's documentation:\n        Help for poly2symb:\n        poly2symb(Lst,Var)\n        Gives the polynomial (or its value) : the first argument is the vector of coefficients and the second argument is the variable (by default x).\n        See also: 1/ e2r 2/ symb2poly \n        Ex1:poly2symb([1,2,3])\n        Ex2:poly2symb([1,2,3],x)\n        Ex3:poly2symb([1,2,3],-1)\n        Ex4:poly2symb([1,2,-1],y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2271poly2symb = {"poly2symb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2271poly2symb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2270poly2symb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2271poly2symb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("poly2symb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "poly2symb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2270poly2symb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2270poly2symb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("poly2symb", 1);

  /* "giacpy/auto-methods.pxi":14064
 * 
 *         '''
 *         return GiacMethods['poly2symb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polyEval(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_poly2symb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14064, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14052
 *         return GiacMethods['pole'](self,*args)
 * 
 *      def poly2symb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poly2symb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.poly2symb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14066
 *         return GiacMethods['poly2symb'](self,*args)
 * 
 *      def polyEval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyEval:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2273polyEval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2272polyEval, "From Giac's documentation:\n        Help for polyEval:\n        polyEval(Vect,Real(x0))\n        Evaluates at a point x0, a polynomial given by its coefficients.\n        See also: 1/ proot 2/ pcoeff \n        Ex1:polyEval([1,0,-2],1)\n        Ex2:polyEval([1,2,-25,-26,120],8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2273polyEval = {"polyEval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2273polyEval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2272polyEval};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2273polyEval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polyEval (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polyEval", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2272polyEval(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2272polyEval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polyEval", 1);

  /* "giacpy/auto-methods.pxi":14076
 * 
 *         '''
 *         return GiacMethods['polyEval'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polygon(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polyEval); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14076, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14066
 *         return GiacMethods['poly2symb'](self,*args)
 * 
 *      def polyEval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyEval:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polyEval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14078
 *         return GiacMethods['polyEval'](self,*args)
 * 
 *      def polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygon:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2275polygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2274polygon, "From Giac's documentation:\n        Help for polygon:\n        polygon(LstPnt||LstCplx)\n        Returns and draws the polygon where its vertices are the elements of l.\n        See also: 1/ isopolygon 2/ quadrilateral 3/ convexhull 4/ hexagon \n        Ex1:polygon(i,1+i,2-i,-1,-1+i/2)\n        Ex2:polygon(point(0,0,0),point(3,3,3),point(0,0,3),point(3,0,0))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2275polygon = {"polygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2275polygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2274polygon};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2275polygon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polygon (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polygon", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2274polygon(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2274polygon(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polygon", 1);

  /* "giacpy/auto-methods.pxi":14088
 * 
 *         '''
 *         return GiacMethods['polygon'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polygone_rempli(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polygon); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14088, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14078
 *         return GiacMethods['polyEval'](self,*args)
 * 
 *      def polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygon:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14090
 *         return GiacMethods['polygon'](self,*args)
 * 
 *      def polygone_rempli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygone_rempli:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2277polygone_rempli(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2276polygone_rempli, "From Giac's documentation:\n        Help for polygone_rempli:\n        polygone_rempli(Intg(n))\n        The argument is an integer <-1 which gives the number of previous turtle positions drawing a polygon and created this full polygon.\n        See also: 1/  \n        Ex1: repete(4,avance 40,tourne_droite);polygone_rempli -8\n        Ex2: repete(3,avance 40,tourne_droite 120);polygone_rempli -6\n        Ex3: repete(3,avance 40,avance 40,tourne_droite 120);polygone_rempli -9\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2277polygone_rempli = {"polygone_rempli", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2277polygone_rempli, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2276polygone_rempli};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2277polygone_rempli(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polygone_rempli (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polygone_rempli", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2276polygone_rempli(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2276polygone_rempli(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polygone_rempli", 1);

  /* "giacpy/auto-methods.pxi":14101
 * 
 *         '''
 *         return GiacMethods['polygone_rempli'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polygonplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polygone_rempli); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14101, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14090
 *         return GiacMethods['polygon'](self,*args)
 * 
 *      def polygone_rempli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygone_rempli:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polygone_rempli", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14103
 *         return GiacMethods['polygone_rempli'](self,*args)
 * 
 *      def polygonplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2279polygonplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2278polygonplot, "From Giac's documentation:\n        Help for polygonplot:\n        polygonplot(Mtrx)\n        Draws the polygons joining for j fixed and for k=0..nrows, the points (xk,yk) where xk=element row k column 0 and yk=element row k column j, after the xk are sorted (we obtain ncols-1 polygons).\n        See also: 1/ scatterplot 2/ listplot 3/ polygonscatterplot \n        Ex1:polygonplot([[1,2,3],[2,0,1],[-1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2279polygonplot = {"polygonplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2279polygonplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2278polygonplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2279polygonplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polygonplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polygonplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2278polygonplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2278polygonplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polygonplot", 1);

  /* "giacpy/auto-methods.pxi":14112
 * 
 *         '''
 *         return GiacMethods['polygonplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polygonscatterplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polygonplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14112, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14103
 *         return GiacMethods['polygone_rempli'](self,*args)
 * 
 *      def polygonplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polygonplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14114
 *         return GiacMethods['polygonplot'](self,*args)
 * 
 *      def polygonscatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonscatterplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2281polygonscatterplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2280polygonscatterplot, "From Giac's documentation:\n        Help for polygonscatterplot:\n        polygonscatterplot(Mtrx)\n        Draws the points (xk,yk) and the polygons joining for j fixed and for k=0..nrows, the points (xk,yk) where xk=element row k column 0 et yk=element row k column j, after the xk are sorted (we obtain ncols-1 polygons).\n        See also: 1/ scatterplot 2/ polygonplot 3/ listplot \n        Ex1:polygonscatterplot([[1,2,3],[2,0,1],[-1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2281polygonscatterplot = {"polygonscatterplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2281polygonscatterplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2280polygonscatterplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2281polygonscatterplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polygonscatterplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polygonscatterplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2280polygonscatterplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2280polygonscatterplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polygonscatterplot", 1);

  /* "giacpy/auto-methods.pxi":14123
 * 
 *         '''
 *         return GiacMethods['polygonscatterplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polyhedron(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polygonscatterplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14123, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14114
 *         return GiacMethods['polygonplot'](self,*args)
 * 
 *      def polygonscatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonscatterplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polygonscatterplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14125
 *         return GiacMethods['polygonscatterplot'](self,*args)
 * 
 *      def polyhedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyhedron:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2283polyhedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2282polyhedron, "From Giac's documentation:\n        Help for polyhedron:\n        polyhedron(SeqPnt(A,B,C...))\n        Draws a convex polyhedron with vertices among the arguments.\n        See also: 1/ cube 2/ parallelepiped \n        Ex1:polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2283polyhedron = {"polyhedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2283polyhedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2282polyhedron};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2283polyhedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polyhedron (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polyhedron", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2282polyhedron(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2282polyhedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polyhedron", 1);

  /* "giacpy/auto-methods.pxi":14134
 * 
 *         '''
 *         return GiacMethods['polyhedron'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polynom(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polyhedron); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14134, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14125
 *         return GiacMethods['polygonscatterplot'](self,*args)
 * 
 *      def polyhedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyhedron:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polyhedron", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14136
 *         return GiacMethods['polyhedron'](self,*args)
 * 
 *      def polynom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynom:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2285polynom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2284polynom, "From Giac's documentation:\n        Help for polynom:\n        polynom(Opt)\n        Option of the convert or convertir command and of the taylor and series commands (list=>n-poly or series=>poly).\n        See also: 1/ poly2symb 2/ taylor 3/ series 4/ convert \n        Ex1: convert([[10,[3,1]],[12,[2,2]]],polynom)\n        Ex2: convert(taylor(sin(x)),polynom)\n        Ex3: convert(series(sin(x),x=0,6),polynom)\n        Ex4: taylor(sin(x),x=0,5,polynom)\n        Ex5: series(sin(x),x=0,6,,polynom)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2285polynom = {"polynom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2285polynom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2284polynom};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2285polynom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polynom (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polynom", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2284polynom(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2284polynom(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polynom", 1);

  /* "giacpy/auto-methods.pxi":14149
 * 
 *         '''
 *         return GiacMethods['polynom'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polynomial_regression(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polynom); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14149, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14136
 *         return GiacMethods['polyhedron'](self,*args)
 * 
 *      def polynom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynom:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polynom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14151
 *         return GiacMethods['polynom'](self,*args)
 * 
 *      def polynomial_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2287polynomial_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2286polynomial_regression, "From Giac's documentation:\n        Help for polynomial_regression:\n        polynomial_regression(Lst||Mtrx(A),[Lst],Intg(n))\n        Returns the coefficients (an,...a1,a0) of y=an*x^n+..a1x+a0 : it is the best polynomial which approx the points where the coordinates are the rows of A (or the 2 lists) (n is the 2nd argument).\n        See also: 1/ linear_regression 2/ power_regression \n        Ex1:polynomial_regression([[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]],3)\n        Ex2:polynomial_regression([[0.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]],3)\n        Ex3:polynomial_regression([0.0,2.0,3.0,4.0],[1.0,4.0,9.0,16.0],3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2287polynomial_regression = {"polynomial_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2287polynomial_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2286polynomial_regression};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2287polynomial_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polynomial_regression (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polynomial_regression", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2286polynomial_regression(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2286polynomial_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polynomial_regression", 1);

  /* "giacpy/auto-methods.pxi":14162
 * 
 *         '''
 *         return GiacMethods['polynomial_regression'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def polynomial_regression_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polynomial_regression); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14162, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14151
 *         return GiacMethods['polynom'](self,*args)
 * 
 *      def polynomial_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polynomial_regression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14164
 *         return GiacMethods['polynomial_regression'](self,*args)
 * 
 *      def polynomial_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2289polynomial_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2288polynomial_regression_plot, "From Giac's documentation:\n        Help for polynomial_regression_plot:\n        polynomial_regression_plot(Lst||Mtrx(A),[Lst],Intg(n))\n        Returns the plot of y=an*x^n+..a1x+a0 : it is the best polynomial which approx the points where the coordinates are the rows of A (or the 2 lists) (n is the 2nd argument).\n        See also: 1/ linear_regression_plot 2/ power_regression_plot \n        Ex1:polynomial_regression_plot([[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]],3)\n        Ex2:polynomial_regression_plot([[0.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]],3)\n        Ex3:polynomial_regression_plot([0.0,2.0,3.0,4.0],[1.0,4.0,9.0,16.0],3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2289polynomial_regression_plot = {"polynomial_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2289polynomial_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2288polynomial_regression_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2289polynomial_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("polynomial_regression_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "polynomial_regression_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2288polynomial_regression_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2288polynomial_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("polynomial_regression_plot", 1);

  /* "giacpy/auto-methods.pxi":14175
 * 
 *         '''
 *         return GiacMethods['polynomial_regression_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def position(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_polynomial_regression_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14175, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14164
 *         return GiacMethods['polynomial_regression'](self,*args)
 * 
 *      def polynomial_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.polynomial_regression_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14177
 *         return GiacMethods['polynomial_regression_plot'](self,*args)
 * 
 *      def position(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for position:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2291position(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2290position, "From Giac's documentation:\n        Help for position:\n        position(NULL or LstCoord)\n        Returns the turtle position in pixels or puts the turtle at the position given by the argument with the same direction.\n        See also: 1/ cap 2/ initialise \n        Ex1:position()\n        Ex2:position(50,70)\n        Ex3:position([50,70])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2291position = {"position", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2291position, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2290position};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2291position(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("position (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "position", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2290position(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2290position(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("position", 1);

  /* "giacpy/auto-methods.pxi":14188
 * 
 *         '''
 *         return GiacMethods['position'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def poslbdLMQ(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_position); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14188, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14177
 *         return GiacMethods['polynomial_regression_plot'](self,*args)
 * 
 *      def position(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for position:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.position", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14190
 *         return GiacMethods['position'](self,*args)
 * 
 *      def poslbdLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poslbdLMQ:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2293poslbdLMQ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2292poslbdLMQ, "From Giac's documentation:\n        Help for poslbdLMQ:\n        poslbdLMQ(Poly(P))\n        Returns a lower bound on the values of the positive roots of P. Akritas-Strzebonski-Vigklas' Local Max Quadratic (LMQ) method is used.\n        See also: 1/ posubLMQ 2/ VAS_positive 3/ realroot \n        Ex1:poslbdLMQ(x^3-7*x+7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2293poslbdLMQ = {"poslbdLMQ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2293poslbdLMQ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2292poslbdLMQ};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2293poslbdLMQ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("poslbdLMQ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "poslbdLMQ", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2292poslbdLMQ(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2292poslbdLMQ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("poslbdLMQ", 1);

  /* "giacpy/auto-methods.pxi":14199
 * 
 *         '''
 *         return GiacMethods['poslbdLMQ'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def posubLMQ(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_poslbdLMQ); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14199, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14190
 *         return GiacMethods['position'](self,*args)
 * 
 *      def poslbdLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poslbdLMQ:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.poslbdLMQ", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14201
 *         return GiacMethods['poslbdLMQ'](self,*args)
 * 
 *      def posubLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for posubLMQ:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2295posubLMQ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2294posubLMQ, "From Giac's documentation:\n        Help for posubLMQ:\n        posubLMQ(Poly(P))\n        Returns an upper bound on the values of the positive roots of P. Akritas-Strzebonski-Vigklas' Local Max Quadratic (LMQ) method is used.\n        See also: 1/ poslbdLMQ 2/ VAS_positive 3/ realroot \n        Ex1:posubLMQ(x^3-7*x+7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2295posubLMQ = {"posubLMQ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2295posubLMQ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2294posubLMQ};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2295posubLMQ(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("posubLMQ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "posubLMQ", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2294posubLMQ(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2294posubLMQ(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("posubLMQ", 1);

  /* "giacpy/auto-methods.pxi":14210
 * 
 *         '''
 *         return GiacMethods['posubLMQ'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def potential(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_posubLMQ); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14210, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14201
 *         return GiacMethods['poslbdLMQ'](self,*args)
 * 
 *      def posubLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for posubLMQ:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.posubLMQ", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14212
 *         return GiacMethods['posubLMQ'](self,*args)
 * 
 *      def potential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for potential:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2297potential(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2296potential, "From Giac's documentation:\n        Help for potential:\n        potential(Vect(V),VectVar)\n        Returns U such that derive(U,Vector_of_variable)=V.\n        See also: 1/ derive 2/ vpotential \n        Ex1:potential([2*x*y+3,x^2-4*z,-4*y],[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2297potential = {"potential", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2297potential, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2296potential};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2297potential(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("potential (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "potential", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2296potential(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2296potential(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("potential", 1);

  /* "giacpy/auto-methods.pxi":14221
 * 
 *         '''
 *         return GiacMethods['potential'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pow2exp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_potential); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14221, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14212
 *         return GiacMethods['posubLMQ'](self,*args)
 * 
 *      def potential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for potential:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.potential", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14223
 *         return GiacMethods['potential'](self,*args)
 * 
 *      def pow2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pow2exp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2299pow2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2298pow2exp, "From Giac's documentation:\n        Help for pow2exp:\n        pow2exp(Expr)\n        Converts powers to exponentials.\n        See also: 1/ exp2pow \n        Ex1:pow2exp(a^b)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2299pow2exp = {"pow2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2299pow2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2298pow2exp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2299pow2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pow2exp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pow2exp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2298pow2exp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2298pow2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pow2exp", 1);

  /* "giacpy/auto-methods.pxi":14232
 * 
 *         '''
 *         return GiacMethods['pow2exp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def power_regression(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pow2exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14232, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14223
 *         return GiacMethods['potential'](self,*args)
 * 
 *      def pow2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pow2exp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pow2exp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14234
 *         return GiacMethods['pow2exp'](self,*args)
 * 
 *      def power_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2301power_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2300power_regression, "From Giac's documentation:\n        Help for power_regression:\n        power_regression(Lst|Mtrx(A),[Lst])\n        Returns the coefficients (m,b) of y=b*x^m : it is the best monomial which approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ polynomial_regression 2/ linear_regressiont \n        Ex1:power_regression([[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex2:power_regression([[1.0,2.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex3:power_regression([1.0,2.0,3.0,4.0],[2.0,4.0,9.0,16.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2301power_regression = {"power_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2301power_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2300power_regression};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2301power_regression(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("power_regression (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "power_regression", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2300power_regression(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2300power_regression(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("power_regression", 1);

  /* "giacpy/auto-methods.pxi":14245
 * 
 *         '''
 *         return GiacMethods['power_regression'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def power_regression_plot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_power_regression); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14245, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14234
 *         return GiacMethods['pow2exp'](self,*args)
 * 
 *      def power_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.power_regression", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14247
 *         return GiacMethods['power_regression'](self,*args)
 * 
 *      def power_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression_plot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2303power_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2302power_regression_plot, "From Giac's documentation:\n        Help for power_regression_plot:\n        power_regression_plot(Lst||Mtrx(A),[Lst])\n        Returns the plot of y=b*x^m : it is the best monomial which approx the points where the coordinates are the rows of A (or the 2 lists).\n        See also: 1/ polynomial_regression_plot 2/ linear_regression_plot \n        Ex1:power_regression_plot([[1.0,1.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex2:power_regression_plot([[1.0,2.0],[2.0,4.0],[3.0,9.0],[4.0,16.0]])\n        Ex3:power_regression_plot([1.0,2.0,3.0,4.0],[2.0,4.0,9.0,16.0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2303power_regression_plot = {"power_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2303power_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2302power_regression_plot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2303power_regression_plot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("power_regression_plot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "power_regression_plot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2302power_regression_plot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2302power_regression_plot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("power_regression_plot", 1);

  /* "giacpy/auto-methods.pxi":14258
 * 
 *         '''
 *         return GiacMethods['power_regression_plot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def powermod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_power_regression_plot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14258, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14247
 *         return GiacMethods['power_regression'](self,*args)
 * 
 *      def power_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression_plot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.power_regression_plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14260
 *         return GiacMethods['power_regression_plot'](self,*args)
 * 
 *      def powermod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powermod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2305powermod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2304powermod, "From Giac's documentation:\n        Help for powermod:\n        powermod(Intg(a),Intg(n),Intg(p),[Expr(P(x))],[Var])\n        Computes a^n modulo p or modulo p,P(x) (fast algorithm).\n        See also: 1/ pow 2/ ^ \n        Ex1:powermod(17,452,19)\n        Ex2:powermod(x+1,452,19,x^4+x+1,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2305powermod = {"powermod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2305powermod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2304powermod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2305powermod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("powermod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "powermod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2304powermod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2304powermod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("powermod", 1);

  /* "giacpy/auto-methods.pxi":14270
 * 
 *         '''
 *         return GiacMethods['powermod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def powerpc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_powermod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14270, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14260
 *         return GiacMethods['power_regression_plot'](self,*args)
 * 
 *      def powermod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powermod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.powermod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14272
 *         return GiacMethods['powermod'](self,*args)
 * 
 *      def powerpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powerpc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2307powerpc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2306powerpc, "From Giac's documentation:\n        Help for powerpc:\n        powerpc(Cercle,Pnt or Cplx)\n        Returns the real number d^2-R^2 (d=distance between point and center, R=radius).\n        See also: 1/ radical_axis \n        Ex1:powerpc(circle(0,1+i),3+i)\n        Ex2:powerpc(circle(0,point(1+i)),3+i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2307powerpc = {"powerpc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2307powerpc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2306powerpc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2307powerpc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("powerpc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "powerpc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2306powerpc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2306powerpc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("powerpc", 1);

  /* "giacpy/auto-methods.pxi":14282
 * 
 *         '''
 *         return GiacMethods['powerpc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def powexpand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_powerpc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14282, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14272
 *         return GiacMethods['powermod'](self,*args)
 * 
 *      def powerpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powerpc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.powerpc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14284
 *         return GiacMethods['powerpc'](self,*args)
 * 
 *      def powexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powexpand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2309powexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2308powexpand, "From Giac's documentation:\n        Help for powexpand:\n        powexpand(Expr)\n        Expands the expression as a function of the exponent.\n        See also: 1/  \n        Ex1:powexpand(2^(x+y))\n        Ex2:powexpand(3^(2*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2309powexpand = {"powexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2309powexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2308powexpand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2309powexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("powexpand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "powexpand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2308powexpand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2308powexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("powexpand", 1);

  /* "giacpy/auto-methods.pxi":14294
 * 
 *         '''
 *         return GiacMethods['powexpand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def powmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_powexpand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14294, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14284
 *         return GiacMethods['powerpc'](self,*args)
 * 
 *      def powexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powexpand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.powexpand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14296
 *         return GiacMethods['powexpand'](self,*args)
 * 
 *      def powmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2311powmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2310powmod, "From Giac's documentation:\n        Help for powmod:\n        powmod(Intg(a),Intg(n),Intg(p),[Expr(P(x))],[Var])\n        Computes a^n modulo p or modulo p,P(x) (fast algorithm).\n        See also: 1/ pow 2/ ^ \n        Ex1:powmod(17,452,19)\n        Ex2:powmod(x+1,452,19,x^4+x+1,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2311powmod = {"powmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2311powmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2310powmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2311powmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("powmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "powmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2310powmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2310powmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("powmod", 1);

  /* "giacpy/auto-methods.pxi":14306
 * 
 *         '''
 *         return GiacMethods['powmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def prepend(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_powmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14306, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14296
 *         return GiacMethods['powexpand'](self,*args)
 * 
 *      def powmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.powmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14308
 *         return GiacMethods['powmod'](self,*args)
 * 
 *      def prepend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prepend:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2313prepend(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2312prepend, "From Giac's documentation:\n        Help for prepend:\n        prepend(Lst||Set||Str(L),Elem(n))\n        Adds an element to a set or at the beginning of a list or of a string (L:=prepend(L,a) or L.prepend(a)).\n        See also: 1/ append 2/ concat \n        Ex1:prepend([1,2],3)\n        Ex2:prepend(set[1,2],3)\n        Ex3: L:=[1,2];L:=prepend(L,3)\n        Ex4: L:=[1,2];L.prepend(L,3) \n        Ex5: S:=set[1,2];S:=prepend(L,3)\n        Ex6: S:=set[1,2];S.prepend(L,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2313prepend = {"prepend", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2313prepend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2312prepend};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2313prepend(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prepend (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "prepend", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2312prepend(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2312prepend(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prepend", 1);

  /* "giacpy/auto-methods.pxi":14322
 * 
 *         '''
 *         return GiacMethods['prepend'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def preval(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_prepend); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14322, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14308
 *         return GiacMethods['powmod'](self,*args)
 * 
 *      def prepend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prepend:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.prepend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14324
 *         return GiacMethods['prepend'](self,*args)
 * 
 *      def preval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for preval:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2315preval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2314preval, "From Giac's documentation:\n        Help for preval:\n        preval(Expr(F(Var)),Real(a),Real(b),[Var])\n        Returns F(b)-F(a).\n        See also: 1/ subst 2/ int \n        Ex1:preval(x^2-2,2,3)\n        Ex2:preval(y^2-2,2,3,y)\n        Ex3:preval(int(x),0,1)\n        Ex4:preval(int(y,y),0,1,y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2315preval = {"preval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2315preval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2314preval};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2315preval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("preval (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "preval", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2314preval(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2314preval(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("preval", 1);

  /* "giacpy/auto-methods.pxi":14336
 * 
 *         '''
 *         return GiacMethods['preval'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def prevperm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_preval); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14336, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14324
 *         return GiacMethods['prepend'](self,*args)
 * 
 *      def preval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for preval:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.preval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14338
 *         return GiacMethods['preval'](self,*args)
 * 
 *      def prevperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevperm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2317prevperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2316prevperm, "From Giac's documentation:\n        Help for prevperm:\n        prevperm(Intg(n))\n        Returns the previous permutation with the lexicographic order.\n        See also: 1/ nextperm 2/ is_permu \n        Ex1:prevperm([0,1,3,2])\n        Ex2:prevperm([0,1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2317prevperm = {"prevperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2317prevperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2316prevperm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2317prevperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prevperm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "prevperm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2316prevperm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2316prevperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prevperm", 1);

  /* "giacpy/auto-methods.pxi":14348
 * 
 *         '''
 *         return GiacMethods['prevperm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def prevprime(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_prevperm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14348, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14338
 *         return GiacMethods['preval'](self,*args)
 * 
 *      def prevperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevperm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.prevperm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14350
 *         return GiacMethods['prevperm'](self,*args)
 * 
 *      def prevprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevprime:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2319prevprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2318prevprime, "From Giac's documentation:\n        Help for prevprime:\n        prevprime(Intg(a))\n        Previous prime or pseudo-prime before a given integer a.\n        See also: 1/ nextprime 2/ is_prime 3/ ithprime \n        Ex1:prevprime(9856989898999)\n        Ex2:prevprime(97160249868928888261606009)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2319prevprime = {"prevprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2319prevprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2318prevprime};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2319prevprime(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prevprime (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "prevprime", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2318prevprime(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2318prevprime(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prevprime", 1);

  /* "giacpy/auto-methods.pxi":14360
 * 
 *         '''
 *         return GiacMethods['prevprime'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def primpart(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_prevprime); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14360, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14350
 *         return GiacMethods['prevperm'](self,*args)
 * 
 *      def prevprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevprime:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.prevprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14362
 *         return GiacMethods['prevprime'](self,*args)
 * 
 *      def primpart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for primpart:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2321primpart(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2320primpart, "From Giac's documentation:\n        Help for primpart:\n        primpart(Poly(P),[Var])\n        Returns the polynomial P divided by the gcd of its coefficients.\n        See also: 1/ content \n        Ex1:primpart(2x^2+10x+6)\n        Ex2:primpart(2t^2+10t+6,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2321primpart = {"primpart", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2321primpart, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2320primpart};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2321primpart(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("primpart (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "primpart", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2320primpart(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2320primpart(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("primpart", 1);

  /* "giacpy/auto-methods.pxi":14372
 * 
 *         '''
 *         return GiacMethods['primpart'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def printf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_primpart); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14372, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14362
 *         return GiacMethods['prevprime'](self,*args)
 * 
 *      def primpart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for primpart:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.primpart", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14374
 *         return GiacMethods['primpart'](self,*args)
 * 
 *      def printf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for printf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2323printf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2322printf, "From Giac's documentation:\n        Help for printf:\n        printf(Expr)\n        2d printing.\n        See also: 1/ print \n        Ex1:printf(sqrt(2))\n        Ex2:printf(\"%gen+%gen=%gen\",a,b,a+b)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2323printf = {"printf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2323printf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2322printf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2323printf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("printf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "printf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2322printf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2322printf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("printf", 1);

  /* "giacpy/auto-methods.pxi":14384
 * 
 *         '''
 *         return GiacMethods['printf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def prism(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_printf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14384, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14374
 *         return GiacMethods['primpart'](self,*args)
 * 
 *      def printf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for printf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.printf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14386
 *         return GiacMethods['printf'](self,*args)
 * 
 *      def prism(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2325prism(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2324prism, "From Giac's documentation:\n        Help for prism:\n        prism(LstPnt([A,B,C,D]),Pnt(A1))\n        Draws a prism with plane base ABCD...and with edges parallel to AA1 (the faces are parallelograms).\n        See also: 1/ cube 2/ polyhedron \n        Ex1:prism([[0,0,0],[5,0,0],[0,5,0],[-5,5,0]],[0,0,5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2325prism = {"prism", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2325prism, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2324prism};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2325prism(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prism (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "prism", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2324prism(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2324prism(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prism", 1);

  /* "giacpy/auto-methods.pxi":14395
 * 
 *         '''
 *         return GiacMethods['prism'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def prism_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_prism); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14395, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14386
 *         return GiacMethods['printf'](self,*args)
 * 
 *      def prism(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.prism", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14397
 *         return GiacMethods['prism'](self,*args)
 * 
 *      def prism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2327prism_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2326prism_graph, "From Giac's documentation:\n        Help for prism_graph:\n        prism_graph(Intg(n))\n        Returns the generalized Petersen graph GP(n,1).\n        See also: 1/ antiprism_graph 2/ web_graph \n        Ex1:prism_graph(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2327prism_graph = {"prism_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2327prism_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2326prism_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2327prism_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("prism_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "prism_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2326prism_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2326prism_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("prism_graph", 1);

  /* "giacpy/auto-methods.pxi":14406
 * 
 *         '''
 *         return GiacMethods['prism_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def product(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_prism_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14406, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14397
 *         return GiacMethods['prism'](self,*args)
 * 
 *      def prism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.prism_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14408
 *         return GiacMethods['prism_graph'](self,*args)
 * 
 *      def product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for product:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2329product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2328product, "From Giac's documentation:\n        Help for product:\n        product(Expr||Lst,[Var||Lst],[Intg(a)],[Intg(b)],[Intg(p)])\n        Multiplies the values of the expression when the variable go from a to b with a step p (product(expression,var,begin,end,step) by default p=1) or product of the elements of a list or product element by element of 2 lists or matrices.\n        See also: 1/ sum \n        Ex1:product(n,n,1,10,2)\n        Ex2:product(1/n,n,1,10)\n        Ex3:product(1/n,n,11,1)\n        Ex4:product(1/n,n,10,1,1)\n        Ex5:product([2,3,4,5])\n        Ex6:product([2,3,4],[5,6,7])\n        Ex7:product([[2,3,4],[5,6,7]],[[2,3,4],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2329product = {"product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2329product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2328product};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2329product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("product (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "product", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2328product(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2328product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("product", 1);

  /* "giacpy/auto-methods.pxi":14423
 * 
 *         '''
 *         return GiacMethods['product'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def projection(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_product); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14423, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14408
 *         return GiacMethods['prism_graph'](self,*args)
 * 
 *      def product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for product:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14425
 *         return GiacMethods['product'](self,*args)
 * 
 *      def projection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for projection:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2331projection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2330projection, "From Giac's documentation:\n        Help for projection:\n        projection(Curve,Pnt)\n        projection(C,A) is the orthogonal projection of A on the curve C.\n        See also: 1/ perpendicular \n        Ex1: H:=projection(line(i,1-i),1+i)\n        Ex2: K:=projection(circle(0,1),1+i)\n        Ex3: J:=projection(circle(0,1),point(1+2*i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2331projection = {"projection", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2331projection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2330projection};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2331projection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("projection (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "projection", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2330projection(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2330projection(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("projection", 1);

  /* "giacpy/auto-methods.pxi":14436
 * 
 *         '''
 *         return GiacMethods['projection'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def proot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_projection); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14436, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14425
 *         return GiacMethods['product'](self,*args)
 * 
 *      def projection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for projection:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.projection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14438
 *         return GiacMethods['projection'](self,*args)
 * 
 *      def proot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for proot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2333proot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2332proot, "From Giac's documentation:\n        Help for proot:\n        proot(Vect||Poly,[Intg(n)])\n        Returns all computed roots of a polynomial given by its coefficients (may not work if roots are not simple).\n        See also: 1/ pcoeff 2/ peval 3/ realroot 4/ complexroot 5/ rationalroot 6/ crationalroot \n        Ex1:proot([1,0,-2])\n        Ex2:proot(x^2-2)\n        Ex3:proot([1,2,-25,-26,120])\n        Ex4:proot(x^4+5x-3,30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2333proot = {"proot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2333proot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2332proot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2333proot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("proot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "proot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2332proot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2332proot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("proot", 1);

  /* "giacpy/auto-methods.pxi":14450
 * 
 *         '''
 *         return GiacMethods['proot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def propFrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_proot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14450, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14438
 *         return GiacMethods['projection'](self,*args)
 * 
 *      def proot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for proot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.proot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14452
 *         return GiacMethods['proot'](self,*args)
 * 
 *      def propFrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propFrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2335propFrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2334propFrac, "From Giac's documentation:\n        Help for propFrac:\n        propFrac(Frac or RatFrac)\n        Simplifies and writes the fraction (or rational fraction) A/B as Q+R/B with R<B (or deg(R)<deg(B)).\n        See also: 1/ partfrac \n        Ex1:propFrac(28/12)\n        Ex2:propFrac((x^2+2*x-1)/(x+1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2335propFrac = {"propFrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2335propFrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2334propFrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2335propFrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("propFrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "propFrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2334propFrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2334propFrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("propFrac", 1);

  /* "giacpy/auto-methods.pxi":14462
 * 
 *         '''
 *         return GiacMethods['propFrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def propfrac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_propFrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14462, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14452
 *         return GiacMethods['proot'](self,*args)
 * 
 *      def propFrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propFrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.propFrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14464
 *         return GiacMethods['propFrac'](self,*args)
 * 
 *      def propfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propfrac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2337propfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2336propfrac, "From Giac's documentation:\n        Help for propfrac:\n        propfrac(Frac or RatFrac)\n        Simplifies and writes the fraction (or rational fraction) A/B as Q+R/B with R<B (or deg(R)<deg(B)).\n        See also: 1/ partfrac \n        Ex1:propfrac(28/12)\n        Ex2:propfrac((x^2+2*x-1)/(x+1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2337propfrac = {"propfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2337propfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2336propfrac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2337propfrac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("propfrac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "propfrac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2336propfrac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2336propfrac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("propfrac", 1);

  /* "giacpy/auto-methods.pxi":14474
 * 
 *         '''
 *         return GiacMethods['propfrac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pruefer_code(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_propfrac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14474, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14464
 *         return GiacMethods['propFrac'](self,*args)
 * 
 *      def propfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propfrac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.propfrac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14476
 *         return GiacMethods['propfrac'](self,*args)
 * 
 *      def pruefer_code(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pruefer_code:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2339pruefer_code(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2338pruefer_code, "From Giac's documentation:\n        Help for pruefer_code:\n        pruefer_code(Vect(S)|Graph(T))\n        Returns the Pruefer code for a tree graph T or converts a Pruefer sequence S into the corresponding tree.\n        See also: 1/ is_tree \n        Ex1:pruefer_code([5,6,0,4,1,2,10,3,8,11]) // xcas mode\n        Ex2:pruefer_code(graph(%{[1,8],[2,3],[2,7],[4,6],[5,6],[6,7],[6,8],[7,9],[8,10]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2339pruefer_code = {"pruefer_code", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2339pruefer_code, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2338pruefer_code};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2339pruefer_code(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pruefer_code (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pruefer_code", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2338pruefer_code(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2338pruefer_code(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pruefer_code", 1);

  /* "giacpy/auto-methods.pxi":14486
 * 
 *         '''
 *         return GiacMethods['pruefer_code'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def psrgcd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pruefer_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14486, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14476
 *         return GiacMethods['propfrac'](self,*args)
 * 
 *      def pruefer_code(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pruefer_code:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pruefer_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14488
 *         return GiacMethods['pruefer_code'](self,*args)
 * 
 *      def psrgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for psrgcd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2341psrgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2340psrgcd, "From Giac's documentation:\n        Help for psrgcd:\n        psrgcd(Poly,Poly)\n        GCD of 2 polynomials, with the sub resultant algorithm.\n        See also: 1/ gcd 2/ modgcd 3/ ezgcd 4/ heugcd \n        Ex1:psrgcd(x^4-1,(x-1)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2341psrgcd = {"psrgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2341psrgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2340psrgcd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2341psrgcd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("psrgcd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "psrgcd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2340psrgcd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2340psrgcd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("psrgcd", 1);

  /* "giacpy/auto-methods.pxi":14497
 * 
 *         '''
 *         return GiacMethods['psrgcd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ptayl(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_psrgcd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14497, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14488
 *         return GiacMethods['pruefer_code'](self,*args)
 * 
 *      def psrgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for psrgcd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.psrgcd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14499
 *         return GiacMethods['psrgcd'](self,*args)
 * 
 *      def ptayl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ptayl:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2343ptayl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2342ptayl, "From Giac's documentation:\n        Help for ptayl:\n        ptayl(Expr||Poly(P(Var)),Var=Real || Real(a),[Order || Var])\n        Returns the Taylor polynomial of the expression at the given point and order or a polynomial Q such that P(x)=Q(x-a).\n        See also: 1/ series 2/ taylor \n        Ex1:ptayl(sin(x),x=0,5)\n        Ex2:ptayl(x^2+2*x+1,1)\n        Ex3:ptayl(x^2+2*x+1,-1)\n        Ex4:ptayl(y^2+2*y+1,1.1,y)\n        Ex5:ptayl(y^3+y^2+2*y+1,2,y)\n        Ex6: subst(ptayl(y^3+y^2+2*y+1,2,y),y,y-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2343ptayl = {"ptayl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2343ptayl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2342ptayl};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2343ptayl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ptayl (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ptayl", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2342ptayl(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2342ptayl(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ptayl", 1);

  /* "giacpy/auto-methods.pxi":14513
 * 
 *         '''
 *         return GiacMethods['ptayl'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def purge(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ptayl); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14513, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14499
 *         return GiacMethods['psrgcd'](self,*args)
 * 
 *      def ptayl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ptayl:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ptayl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14515
 *         return GiacMethods['ptayl'](self,*args)
 * 
 *      def purge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purge:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2345purge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2344purge, "From Giac's documentation:\n        Help for purge:\n        purge(Var)\n        purge(varname) unassigns the variable varname.\n        See also: 1/ sto 2/ restart 3/ assume 4/ about \n        Ex1:purge(t)\n        Ex2:purge(C)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2345purge = {"purge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2345purge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2344purge};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2345purge(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("purge (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "purge", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2344purge(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2344purge(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("purge", 1);

  /* "giacpy/auto-methods.pxi":14525
 * 
 *         '''
 *         return GiacMethods['purge'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def purple(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_purge); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14525, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14515
 *         return GiacMethods['ptayl'](self,*args)
 * 
 *      def purge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purge:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.purge", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14527
 *         return GiacMethods['purge'](self,*args)
 * 
 *      def purple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purple:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2347purple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2346purple, "From Giac's documentation:\n        Help for purple:\n        purple(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2347purple = {"purple", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2347purple, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2346purple};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2347purple(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("purple (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "purple", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2346purple(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2346purple(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("purple", 1);

  /* "giacpy/auto-methods.pxi":14537
 * 
 *         '''
 *         return GiacMethods['purple'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pwd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_purple); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14537, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14527
 *         return GiacMethods['purge'](self,*args)
 * 
 *      def purple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purple:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.purple", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14539
 *         return GiacMethods['purple'](self,*args)
 * 
 *      def pwd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pwd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2349pwd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2348pwd, "From Giac's documentation:\n        Help for pwd:\n        pwd(NULL)\n        Current working directory.\n        See also: 1/ cd \n        Ex1:pwd()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2349pwd = {"pwd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2349pwd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2348pwd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2349pwd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pwd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pwd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2348pwd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2348pwd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pwd", 1);

  /* "giacpy/auto-methods.pxi":14548
 * 
 *         '''
 *         return GiacMethods['pwd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def pyramid(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pwd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14548, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14539
 *         return GiacMethods['purple'](self,*args)
 * 
 *      def pwd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pwd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pwd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14550
 *         return GiacMethods['pwd'](self,*args)
 * 
 *      def pyramid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pyramid:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2351pyramid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2350pyramid, "From Giac's documentation:\n        Help for pyramid:\n        pyramid(Pnt(A),Pnt(B),Pnt(C),[Pnt(D)])\n        Draws the regular direct pyramid ABCD with vertices A,B and a face in the plane (A,B,C) when there is 3 arguments and the pyramid ABCD when there are 4 arguments.\n        See also: 1/ cube 2/ cylinder 3/ icosahedron 4/ dodecahedron 5/ octahedron \n        Ex1:pyramid([0,0,0],[3,0,0],[0,1,0])\n        Ex2:pyramid([0,0,0],[3,0,0],[0,3,0],[0,0,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2351pyramid = {"pyramid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2351pyramid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2350pyramid};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2351pyramid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pyramid (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pyramid", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2350pyramid(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2350pyramid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pyramid", 1);

  /* "giacpy/auto-methods.pxi":14560
 * 
 *         '''
 *         return GiacMethods['pyramid'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def python_compat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_pyramid); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14560, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14550
 *         return GiacMethods['pwd'](self,*args)
 * 
 *      def pyramid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pyramid:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.pyramid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14562
 *         return GiacMethods['pyramid'](self,*args)
 * 
 *      def python_compat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for python_compat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2353python_compat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2352python_compat, "From Giac's documentation:\n        Help for python_compat:\n        python_compat(Intg(0) or 1)\n        Sets Python-syntax compatibility (1) or not (0).\n        See also: 1/ xcas_mode \n        Ex1:python_compat()\n        Ex2:python_compat(1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2353python_compat = {"python_compat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2353python_compat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2352python_compat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2353python_compat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("python_compat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "python_compat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2352python_compat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2352python_compat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("python_compat", 1);

  /* "giacpy/auto-methods.pxi":14572
 * 
 *         '''
 *         return GiacMethods['python_compat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def q2a(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_python_compat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14572, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14562
 *         return GiacMethods['pyramid'](self,*args)
 * 
 *      def python_compat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for python_compat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.python_compat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14574
 *         return GiacMethods['python_compat'](self,*args)
 * 
 *      def q2a(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for q2a:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2355q2a(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2354q2a, "From Giac's documentation:\n        Help for q2a:\n        q2a(QuadraForm, VectVar)\n        q2a(q(x,y),[x,y])=the symmetric matrix associated to the quadratic form q.\n        See also: 1/ a2q \n        Ex1:q2a(x^2+2*x*y+2*y^2,[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2355q2a = {"q2a", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2355q2a, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2354q2a};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2355q2a(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("q2a (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "q2a", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2354q2a(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2354q2a(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("q2a", 1);

  /* "giacpy/auto-methods.pxi":14583
 * 
 *         '''
 *         return GiacMethods['q2a'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def qr(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_q2a); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14583, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14574
 *         return GiacMethods['python_compat'](self,*args)
 * 
 *      def q2a(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for q2a:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.q2a", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14585
 *         return GiacMethods['q2a'](self,*args)
 * 
 *      def qr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for qr:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2357qr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2356qr, "From Giac's documentation:\n        Help for qr:\n        qr(Mtrx)\n        For a numerical matrix A, returns R (right) such that A=QR and Q orthogonal.\n        See also: 1/ lu \n        Ex1:qr([[1,2],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2357qr = {"qr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2357qr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2356qr};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2357qr(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("qr (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "qr", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2356qr(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2356qr(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("qr", 1);

  /* "giacpy/auto-methods.pxi":14594
 * 
 *         '''
 *         return GiacMethods['qr'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quadric(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_qr); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14594, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14585
 *         return GiacMethods['q2a'](self,*args)
 * 
 *      def qr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for qr:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.qr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14596
 *         return GiacMethods['qr'](self,*args)
 * 
 *      def quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadric:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2359quadric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2358quadric, "From Giac's documentation:\n        Help for quadric:\n        quadric(Expr,[Lst(Var)])\n        Defines a quadric by its cartesian equation with x,y,z as default variables and draws it.\n        See also: 1/ reduced_quadric \n        Ex1:quadric(4*x^2+y^2+z^2-4*x*y+4*x*z-2*y*z+8*x-4*y+4*z+2)\n        Ex2:quadric(x^2+3*y^2-3*z^2-8*y*z+2*z*x-4*x*y-1,x,y,z,affichage=vert+rempli)\n        Ex3:quadric((u+v)*(v-w)+3*u-5*v,[u,v,w],affichage=cyan)\n        Ex4:quadric(7*x^2+4*y^2+4*z^2+4*x*y-4*x*z-2*y*z-4*x+5*y+4*z-18,[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2359quadric = {"quadric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2359quadric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2358quadric};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2359quadric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quadric (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quadric", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2358quadric(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2358quadric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quadric", 1);

  /* "giacpy/auto-methods.pxi":14608
 * 
 *         '''
 *         return GiacMethods['quadric'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quadrilateral(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quadric); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14608, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14596
 *         return GiacMethods['qr'](self,*args)
 * 
 *      def quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadric:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quadric", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14610
 *         return GiacMethods['quadric'](self,*args)
 * 
 *      def quadrilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadrilateral:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2361quadrilateral(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2360quadrilateral, "From Giac's documentation:\n        Help for quadrilateral:\n        quadrilateral(Pnt(A)||Cplx,Pnt(B)||Cplx,Pnt(C)||Cplx,Pnt(D)||Cplx)\n        Returns and draws the quadrilateral ABCD.\n        See also: 1/ polygon 2/ square \n        Ex1:quadrilateral(i,1+i,2-i,-1)\n        Ex2:quadrilateral(point(0,0,0),point(3,3,3),point(0,0,3),point(3,0,0))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2361quadrilateral = {"quadrilateral", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2361quadrilateral, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2360quadrilateral};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2361quadrilateral(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quadrilateral (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quadrilateral", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2360quadrilateral(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2360quadrilateral(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quadrilateral", 1);

  /* "giacpy/auto-methods.pxi":14620
 * 
 *         '''
 *         return GiacMethods['quadrilateral'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quantile(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quadrilateral); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14620, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14610
 *         return GiacMethods['quadric'](self,*args)
 * 
 *      def quadrilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadrilateral:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quadrilateral", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14622
 *         return GiacMethods['quadrilateral'](self,*args)
 * 
 *      def quantile(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quantile:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2363quantile(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2362quantile, "From Giac's documentation:\n        Help for quantile:\n        quantile(Lst(l),Real(p))\n        Returns the quantile of the elements of l corresponding to p (0<p<1).\n        See also: 1/ quartile1 2/ median 3/ quartile3 \n        Ex1:quantile([0,1,3,4,2,5,6],0.25)\n        Ex2:quantile([0,1,3,4,2,5,6],0.75)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2363quantile = {"quantile", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2363quantile, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2362quantile};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2363quantile(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quantile (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quantile", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2362quantile(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2362quantile(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quantile", 1);

  /* "giacpy/auto-methods.pxi":14632
 * 
 *         '''
 *         return GiacMethods['quantile'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quartile1(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quantile); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14632, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14622
 *         return GiacMethods['quadrilateral'](self,*args)
 * 
 *      def quantile(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quantile:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quantile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14634
 *         return GiacMethods['quantile'](self,*args)
 * 
 *      def quartile1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile1:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2365quartile1(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2364quartile1, "From Giac's documentation:\n        Help for quartile1:\n        quartile1(Lst||Mtrx,[Lst])\n        Returns the 1st quartile of the elements (or of the columns) of its argument.\n        See also: 1/ quantile 2/ quartiles \n        Ex1:quartile1([1,2,3,5,10,4])\n        Ex2:quartile1([1,2,3,5,10,4],[1,2,3,1,2,3])\n        Ex3:quartile1([[1,2],[5,4],[3,6],[7,8]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2365quartile1 = {"quartile1", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2365quartile1, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2364quartile1};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2365quartile1(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quartile1 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quartile1", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2364quartile1(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2364quartile1(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quartile1", 1);

  /* "giacpy/auto-methods.pxi":14645
 * 
 *         '''
 *         return GiacMethods['quartile1'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quartile3(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quartile1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14645, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14634
 *         return GiacMethods['quantile'](self,*args)
 * 
 *      def quartile1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile1:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quartile1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14647
 *         return GiacMethods['quartile1'](self,*args)
 * 
 *      def quartile3(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile3:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2367quartile3(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2366quartile3, "From Giac's documentation:\n        Help for quartile3:\n        quartile3(Lst||Mtrx,[Lst])\n        Returns the 3rd quartile of the elements (or of the columns) of its argument.\n        See also: 1/ quartiles 2/ quantile \n        Ex1:quartile3([1,2,3,5,10,4])\n        Ex2:quartile3([[1,2,3,5,10,4],[2,3,4,4,5,6],[7,6,5,8,9,1]])\n        Ex3:quartile3([[1,2],[5,4],[3,6],[7,8]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2367quartile3 = {"quartile3", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2367quartile3, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2366quartile3};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2367quartile3(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quartile3 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quartile3", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2366quartile3(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2366quartile3(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quartile3", 1);

  /* "giacpy/auto-methods.pxi":14658
 * 
 *         '''
 *         return GiacMethods['quartile3'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quartiles(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quartile3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14658, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14647
 *         return GiacMethods['quartile1'](self,*args)
 * 
 *      def quartile3(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile3:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quartile3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14660
 *         return GiacMethods['quartile3'](self,*args)
 * 
 *      def quartiles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartiles:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2369quartiles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2368quartiles, "From Giac's documentation:\n        Help for quartiles:\n        quartiles(Lst||Mtrx,[Lst])\n        Min,1st quartile,the median,3rd quartile, max of the elements (or of the columns) of its argument.\n        See also: 1/ boxwhisker 2/ quantile 3/ mean \n        Ex1:quartiles([1,2,3,5,10,4])\n        Ex2:quartiles([1,2,3,5,10,4],[1,2,3,5,10,4])\n        Ex3:quartiles([[1,2],[5,4],[3,6],[7,8]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2369quartiles = {"quartiles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2369quartiles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2368quartiles};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2369quartiles(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quartiles (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quartiles", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2368quartiles(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2368quartiles(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quartiles", 1);

  /* "giacpy/auto-methods.pxi":14671
 * 
 *         '''
 *         return GiacMethods['quartiles'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quest(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quartiles); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14671, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14660
 *         return GiacMethods['quartile3'](self,*args)
 * 
 *      def quartiles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartiles:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quartiles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14673
 *         return GiacMethods['quartiles'](self,*args)
 * 
 *      def quest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quest:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2371quest(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2370quest, "From Giac's documentation:\n        Help for quest:\n        quest(Intg(n))\n        Returns the (n+1)th question of the command history if n>=0 or, the (-n)th previous question if n<0 (by default n=-1 for the previous question).\n        See also: 1/ ans \n        Ex1:quest()\n        Ex2:quest(2)\n        Ex3:quest(-2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2371quest = {"quest", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2371quest, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2370quest};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2371quest(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quest (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quest", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2370quest(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2370quest(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quest", 1);

  /* "giacpy/auto-methods.pxi":14684
 * 
 *         '''
 *         return GiacMethods['quest'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quo(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quest); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14684, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14673
 *         return GiacMethods['quartiles'](self,*args)
 * 
 *      def quest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quest:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quest", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14686
 *         return GiacMethods['quest'](self,*args)
 * 
 *      def quo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quo:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2373quo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2372quo, "From Giac's documentation:\n        Help for quo:\n        quo((Vect or Poly),(Vect or Poly),[Var])\n        Euclidean quotient of 2 polynomials.\n        See also: 1/ rem 2/ quorem 3/ Quo 4/ iquo \n        Ex1:quo([1,2,3,4],[-1,2])\n        Ex2:quo(x^3+2x^2+3x+4,-x+2)\n        Ex3:quo(t^3+2t^2+3t+4,-t+2,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2373quo = {"quo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2373quo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2372quo};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2373quo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quo (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quo", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2372quo(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2372quo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quo", 1);

  /* "giacpy/auto-methods.pxi":14697
 * 
 *         '''
 *         return GiacMethods['quo'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quorem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quo); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14697, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14686
 *         return GiacMethods['quest'](self,*args)
 * 
 *      def quo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quo:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14699
 *         return GiacMethods['quo'](self,*args)
 * 
 *      def quorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quorem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2375quorem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2374quorem, "From Giac's documentation:\n        Help for quorem:\n        quorem((Vect or Poly),(Vect or Poly),[Var])\n        Euclidean quotient and remainder of 2 polynomials.\n        See also: 1/ rem 2/ quo 3/ iquorem \n        Ex1:quorem([1,2,3,4],[-1,2])\n        Ex2:quorem(x^3+2x^2+3x+4,-x+2)\n        Ex3:quorem(t^3+2t^2+3t+4,-t+2,t)\n        Ex4:quorem(t^4-1,(t+1)^2,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2375quorem = {"quorem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2375quorem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2374quorem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2375quorem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quorem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quorem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2374quorem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2374quorem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quorem", 1);

  /* "giacpy/auto-methods.pxi":14711
 * 
 *         '''
 *         return GiacMethods['quorem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def quote(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quorem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14711, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14699
 *         return GiacMethods['quo'](self,*args)
 * 
 *      def quorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quorem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quorem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14713
 *         return GiacMethods['quorem'](self,*args)
 * 
 *      def quote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quote:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2377quote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2376quote, "From Giac's documentation:\n        Help for quote:\n        quote(Expr)\n        Returns its argument unevaluated (and also a:=quote(a) purges a).\n        See also: 1/  \n        Ex1:quote(1+2)\n        Ex2:quote(1/x+1/(x-1))\n        Ex3:quote((x+1)*(x-1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2377quote = {"quote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2377quote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2376quote};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2377quote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quote (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "quote", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2376quote(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2376quote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quote", 1);

  /* "giacpy/auto-methods.pxi":14724
 * 
 *         '''
 *         return GiacMethods['quote'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def r2e(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_quote); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14724, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14713
 *         return GiacMethods['quorem'](self,*args)
 * 
 *      def quote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quote:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14726
 *         return GiacMethods['quote'](self,*args)
 * 
 *      def r2e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for r2e:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2379r2e(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2378r2e, "From Giac's documentation:\n        Help for r2e:\n        r2e(Lst,Var)\n        Gives the polynomial (or its value) : the first argument is the vector of coefficients and the second argument is the variable (by default x).\n        See also: 1/ e2r 2/ symb2poly \n        Ex1:r2e([1,2,3])\n        Ex2:r2e([1,2,3],x)\n        Ex3:r2e([1,2,3],-1)\n        Ex4:r2e([1,2,-1],y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2379r2e = {"r2e", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2379r2e, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2378r2e};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2379r2e(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("r2e (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "r2e", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2378r2e(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2378r2e(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("r2e", 1);

  /* "giacpy/auto-methods.pxi":14738
 * 
 *         '''
 *         return GiacMethods['r2e'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def radians(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_r2e); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14738, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14726
 *         return GiacMethods['quote'](self,*args)
 * 
 *      def r2e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for r2e:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.r2e", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14740
 *         return GiacMethods['r2e'](self,*args)
 * 
 *      def radians(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radians:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2381radians(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2380radians, "From Giac's documentation:\n        Help for radians:\n        radians(Real(deg))\n        Converts degrees to radians (inexact).\n        See also: 1/ degrees \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2381radians = {"radians", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2381radians, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2380radians};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2381radians(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("radians (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "radians", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2380radians(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2380radians(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("radians", 1);

  /* "giacpy/auto-methods.pxi":14748
 * 
 *         '''
 *         return GiacMethods['radians'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def radical_axis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_radians); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14748, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14740
 *         return GiacMethods['r2e'](self,*args)
 * 
 *      def radians(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radians:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.radians", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14750
 *         return GiacMethods['radians'](self,*args)
 * 
 *      def radical_axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radical_axis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2383radical_axis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2382radical_axis, "From Giac's documentation:\n        Help for radical_axis:\n        radical_axis(Crcle,Crcle)\n        Returns the line of points with same powerpc with respect to the 2 circles.\n        See also: 1/ powerpc \n        Ex1:radical_axis(circle(0,1+i),circle(1,1+i))\n        Ex2:radical_axis(circle(0,point(1+i)),circle(1,point(1+i)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2383radical_axis = {"radical_axis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2383radical_axis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2382radical_axis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2383radical_axis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("radical_axis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "radical_axis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2382radical_axis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2382radical_axis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("radical_axis", 1);

  /* "giacpy/auto-methods.pxi":14760
 * 
 *         '''
 *         return GiacMethods['radical_axis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def radius(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_radical_axis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14760, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14750
 *         return GiacMethods['radians'](self,*args)
 * 
 *      def radical_axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radical_axis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.radical_axis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14762
 *         return GiacMethods['radical_axis'](self,*args)
 * 
 *      def radius(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radius:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2385radius(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2384radius, "From Giac's documentation:\n        Help for radius:\n        radius(Crcle)\n        radius(C) gives the radius of the circle C.\n        See also: 1/ center 2/ circle \n        Ex1:radius(incircle(-1,1-i,i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2385radius = {"radius", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2385radius, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2384radius};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2385radius(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("radius (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "radius", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2384radius(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2384radius(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("radius", 1);

  /* "giacpy/auto-methods.pxi":14771
 * 
 *         '''
 *         return GiacMethods['radius'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ramene(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_radius); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14771, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14762
 *         return GiacMethods['radical_axis'](self,*args)
 * 
 *      def radius(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radius:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.radius", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14773
 *         return GiacMethods['radius'](self,*args)
 * 
 *      def ramene(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ramene:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2387ramene(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2386ramene, "From Giac's documentation:\n        Help for ramene:\n        ramene(Str(fich_name))\n        Reads variables and their values from the file fich_name.\n        See also: 1/ write 2/ readrgb 3/ readwav 4/ csv2gen \n        Ex1:ramene(\"toto\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2387ramene = {"ramene", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2387ramene, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2386ramene};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2387ramene(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ramene (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ramene", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2386ramene(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2386ramene(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ramene", 1);

  /* "giacpy/auto-methods.pxi":14782
 * 
 *         '''
 *         return GiacMethods['ramene'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ramene); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14782, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14773
 *         return GiacMethods['radius'](self,*args)
 * 
 *      def ramene(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ramene:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ramene", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14784
 *         return GiacMethods['ramene'](self,*args)
 * 
 *      def rand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2389rand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2388rand, "From Giac's documentation:\n        Help for rand:\n        rand(Intg(n) or Interval(p..n) or NULL,[Intg(b1) or Lst(L)],[Intg(b2)])\n        rand(n)=a random integer (resp rand(p,n)=a real or rand(p..n)=a real function) with uniform distribution in 0..n-1 (resp in [p;n])(rand()=rand(0,1)=a real in [0,1[) or rand(n,b1,b2)=n integers between b1 and b2 or rand(n,L)=list of n elements of L.\n        See also: 1/ srand 2/ randpoly 3/ ranm 4/ randvector 5/ hasard \n        Ex1:rand(4)\n        Ex2:rand()\n        Ex3:rand(0,2)\n        Ex4:rand(0..2)()\n        Ex5: f:=rand(0..2)\n        Ex6:rand(3,1,10)\n        Ex7:rand(3,[\"r\",\"r\",\"r\",\"b\",\"n\"])\n        Ex8: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];L3:=rand(L,3)\n        Ex9: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];L3:=L.rand(3)\n        Ex10: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];a:=rand(L)\n        Ex11: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];a:=L.rand()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2389rand = {"rand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2389rand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2388rand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2389rand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2388rand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2388rand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rand", 1);

  /* "giacpy/auto-methods.pxi":14803
 * 
 *         '''
 *         return GiacMethods['rand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randMat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14803, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14784
 *         return GiacMethods['ramene'](self,*args)
 * 
 *      def rand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14805
 *         return GiacMethods['rand'](self,*args)
 * 
 *      def randMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randMat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2391randMat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2390randMat, "From Giac's documentation:\n        Help for randMat:\n        randMat(Intg(n), [Intg(m)],[Interval or quote(DistribLaw)])\n        Returns a list of size n or an n*m matrix that contains random integers in the range -99 through 99 with uniform distribution or contains random numbers according to the law put between quotes.\n        See also: 1/ idn 2/ randPoly 3/ rand 4/ randvector \n        Ex1:randMat(3)\n        Ex2:randMat(3,2)\n        Ex3:randMat(3,2,6)\n        Ex4:randMat(3,2,binomial,10,0.3)\n        Ex5:randMat(3,2,multinomial,[1/2,1/3,1/6])\n        Ex6:randMat(3,2,poisson,5.2)\n        Ex7:randMat(3,2,normald,0,1)\n        Ex8:randMat(3,2,exp,7/2)\n        Ex9:randMat(3,2,poisson,1.2)\n        Ex10:randMat(3,2,'rand(3)')\n        Ex11:randMat(3,2,1..2)\n        Ex12:randMat(3,5,multinomial,[1/2,1/3,1/6],[\"R\",\"V\",\"B\"])\n        Ex13: GF(2,8,g);ranm(3,3,g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2391randMat = {"randMat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2391randMat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2390randMat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2391randMat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randMat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randMat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2390randMat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2390randMat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randMat", 1);

  /* "giacpy/auto-methods.pxi":14826
 * 
 *         '''
 *         return GiacMethods['randMat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randNorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randMat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14826, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14805
 *         return GiacMethods['rand'](self,*args)
 * 
 *      def randMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randMat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randMat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14828
 *         return GiacMethods['randMat'](self,*args)
 * 
 *      def randNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randNorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2393randNorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2392randNorm, "From Giac's documentation:\n        Help for randNorm:\n        randNorm(Real(mu),Real(sigma))\n        Returns a random real with normal distribution N(mu,sigma).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randpoisson 8/ randgeometric 9/ randmultinomial \n        Ex1:randNorm(0,1)\n        Ex2:randNorm(2,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2393randNorm = {"randNorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2393randNorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2392randNorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2393randNorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randNorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randNorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2392randNorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2392randNorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randNorm", 1);

  /* "giacpy/auto-methods.pxi":14838
 * 
 *         '''
 *         return GiacMethods['randNorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randPoly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randNorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14838, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14828
 *         return GiacMethods['randMat'](self,*args)
 * 
 *      def randNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randNorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randNorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14840
 *         return GiacMethods['randNorm'](self,*args)
 * 
 *      def randPoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randPoly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2395randPoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2394randPoly, "From Giac's documentation:\n        Help for randPoly:\n        randPoly([Var(Var)],Intg(n),[law])\n        Returns a polynomial with variable var (or x), of degree n and where the coefficients are random integers in the range -99 through 99 with uniform distribution or according to a law.\n        See also: 1/ ranm 2/ randvector \n        Ex1:randPoly(5)\n        Ex2:randPoly(t,8)\n        Ex3:randPoly(t,8,-1..1)\n        Ex4:randPoly([x,y],[10,3])\n        Ex5:randPoly([x,y],[10,3],1 mod 7)\n        Ex6: GF(2,8,g);randpoly(t,8,g);randpoly([x,y],[2,3],g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2395randPoly = {"randPoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2395randPoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2394randPoly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2395randPoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randPoly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randPoly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2394randPoly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2394randPoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randPoly", 1);

  /* "giacpy/auto-methods.pxi":14854
 * 
 *         '''
 *         return GiacMethods['randPoly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randbetad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randPoly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14854, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14840
 *         return GiacMethods['randNorm'](self,*args)
 * 
 *      def randPoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randPoly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randPoly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14856
 *         return GiacMethods['randPoly'](self,*args)
 * 
 *      def randbetad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbetad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2397randbetad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2396randbetad, "From Giac's documentation:\n        Help for randbetad:\n        randbetad(Real(a),Real(b))\n        Returns a random real according to the Beta distribution with parameters a>0 and b>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:randbetad(1,2)\n        Ex2:randbetad(1.5,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2397randbetad = {"randbetad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2397randbetad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2396randbetad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2397randbetad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randbetad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randbetad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2396randbetad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2396randbetad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randbetad", 1);

  /* "giacpy/auto-methods.pxi":14866
 * 
 *         '''
 *         return GiacMethods['randbetad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randbinomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randbetad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14866, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14856
 *         return GiacMethods['randPoly'](self,*args)
 * 
 *      def randbetad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbetad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randbetad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14868
 *         return GiacMethods['randbetad'](self,*args)
 * 
 *      def randbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbinomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2399randbinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2398randbinomial, "From Giac's documentation:\n        Help for randbinomial:\n        randbinomial(Intg(n),Real(p))\n        Returns a random integer with binomial distribution B(n,p) i.e. the number of successes in n independant tests where for each test, the success of probability is p.\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randnorm 7/ randpoisson 8/ randgeometric 9/ randmultinomial \n        Ex1:randbinomial(10,0.4)\n        Ex2:randbinomial(100,0.8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2399randbinomial = {"randbinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2399randbinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2398randbinomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2399randbinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randbinomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randbinomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2398randbinomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2398randbinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randbinomial", 1);

  /* "giacpy/auto-methods.pxi":14878
 * 
 *         '''
 *         return GiacMethods['randbinomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randchisquare(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randbinomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14878, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14868
 *         return GiacMethods['randbetad'](self,*args)
 * 
 *      def randbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbinomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randbinomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14880
 *         return GiacMethods['randbinomial'](self,*args)
 * 
 *      def randchisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randchisquare:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2401randchisquare(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2400randchisquare, "From Giac's documentation:\n        Help for randchisquare:\n        randchisquare(Intg(n))\n        Returns a random integer with chi^2 distribution, \317\207^2(n).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randnorm 8/ randgeometric 9/ randmultinomial \n        Ex1:randchisquare(5)\n        Ex2:randchisquare(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2401randchisquare = {"randchisquare", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2401randchisquare, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2400randchisquare};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2401randchisquare(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randchisquare (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randchisquare", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2400randchisquare(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2400randchisquare(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randchisquare", 1);

  /* "giacpy/auto-methods.pxi":14890
 * 
 *         '''
 *         return GiacMethods['randchisquare'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randexp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randchisquare); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14890, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14880
 *         return GiacMethods['randbinomial'](self,*args)
 * 
 *      def randchisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randchisquare:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randchisquare", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14892
 *         return GiacMethods['randchisquare'](self,*args)
 * 
 *      def randexp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randexp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2403randexp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2402randexp, "From Giac's documentation:\n        Help for randexp:\n        randexp(Real(a))\n        Returns a random real according to the exponential distribution with parameter a>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:randexp(1)\n        Ex2:randexp(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2403randexp = {"randexp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2403randexp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2402randexp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2403randexp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randexp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randexp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2402randexp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2402randexp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randexp", 1);

  /* "giacpy/auto-methods.pxi":14902
 * 
 *         '''
 *         return GiacMethods['randexp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randfisher(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randexp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14902, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14892
 *         return GiacMethods['randchisquare'](self,*args)
 * 
 *      def randexp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randexp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randexp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14904
 *         return GiacMethods['randexp'](self,*args)
 * 
 *      def randfisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randfisher:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2405randfisher(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2404randfisher, "From Giac's documentation:\n        Help for randfisher:\n        randfisher(Intg(n),Intg(m))\n        Returns a random integer with Fisher-Snedecor distribution F(n,m).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randnorm 8/ randgeometric 9/ randmultinomial \n        Ex1:randfisher(5,2)\n        Ex2:randfisher(2,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2405randfisher = {"randfisher", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2405randfisher, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2404randfisher};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2405randfisher(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randfisher (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randfisher", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2404randfisher(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2404randfisher(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randfisher", 1);

  /* "giacpy/auto-methods.pxi":14914
 * 
 *         '''
 *         return GiacMethods['randfisher'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randgammad(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randfisher); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14914, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14904
 *         return GiacMethods['randexp'](self,*args)
 * 
 *      def randfisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randfisher:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randfisher", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14916
 *         return GiacMethods['randfisher'](self,*args)
 * 
 *      def randgammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgammad:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2407randgammad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2406randgammad, "From Giac's documentation:\n        Help for randgammad:\n        randgammad(Real(a),Real(b))\n        Returns a random real according to the Gamma distribution with parameters a>0 and b>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:randgammad(1,2)\n        Ex2:randgammad(1.5,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2407randgammad = {"randgammad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2407randgammad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2406randgammad};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2407randgammad(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randgammad (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randgammad", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2406randgammad(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2406randgammad(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randgammad", 1);

  /* "giacpy/auto-methods.pxi":14926
 * 
 *         '''
 *         return GiacMethods['randgammad'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randgeometric(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randgammad); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14926, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14916
 *         return GiacMethods['randfisher'](self,*args)
 * 
 *      def randgammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgammad:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randgammad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14928
 *         return GiacMethods['randgammad'](self,*args)
 * 
 *      def randgeometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgeometric:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2409randgeometric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2408randgeometric, "From Giac's documentation:\n        Help for randgeometric:\n        randgeometric(Real(p))\n        Returns a random integer following the geometric distribution with parameter p.\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randnorm 7/ randpoisson 8/ randbinomial 9/ randmultinomial \n        Ex1:randgeometric(0.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2409randgeometric = {"randgeometric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2409randgeometric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2408randgeometric};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2409randgeometric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randgeometric (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randgeometric", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2408randgeometric(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2408randgeometric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randgeometric", 1);

  /* "giacpy/auto-methods.pxi":14937
 * 
 *         '''
 *         return GiacMethods['randgeometric'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randgeometric); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14937, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14928
 *         return GiacMethods['randgammad'](self,*args)
 * 
 *      def randgeometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgeometric:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randgeometric", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14939
 *         return GiacMethods['randgeometric'](self,*args)
 * 
 *      def randint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2411randint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2410randint, "From Giac's documentation:\n        Help for randint:\n        randint(Intg(n1),Intg(n2))\n        randint(n1,n2)=an integer in [n1, n2] or [n2,n1].\n        See also: 1/ rand  \n        Ex1:randint(1,10)\n        Ex2:randint(-1,-10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2411randint = {"randint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2411randint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2410randint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2411randint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2410randint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2410randint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randint", 1);

  /* "giacpy/auto-methods.pxi":14949
 * 
 *         '''
 *         return GiacMethods['randint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randmarkov(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14949, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14939
 *         return GiacMethods['randgeometric'](self,*args)
 * 
 *      def randint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14951
 *         return GiacMethods['randint'](self,*args)
 * 
 *      def randmarkov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmarkov:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2413randmarkov(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2412randmarkov, "From Giac's documentation:\n        Help for randmarkov:\n        randmarkov(Mtrx(M) || Vctr(v),Intg(i0),[Intg(n)])\n        Returns a random sequence of n states (Markov chain) starting from i0, with probability transition matrix M, or returns a stochastic matrix with p recurrent loops v=[n1,..,np] and i0 transient states.\n        See also: 1/ markov 2/ plotproba \n        Ex1:randmarkov([[0,0,1/2,0,1/2],[0,0,1,0,0],[1/4,1/4,0,1/4,1/4],[0,0,1/2,0,1/2],[0,0,0,0,1]],2,20)\n        Ex2:randmarkov([1,2,1,3],4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2413randmarkov = {"randmarkov", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2413randmarkov, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2412randmarkov};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2413randmarkov(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randmarkov (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randmarkov", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2412randmarkov(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2412randmarkov(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randmarkov", 1);

  /* "giacpy/auto-methods.pxi":14961
 * 
 *         '''
 *         return GiacMethods['randmarkov'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randmatrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randmarkov); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14961, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14951
 *         return GiacMethods['randint'](self,*args)
 * 
 *      def randmarkov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmarkov:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randmarkov", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14963
 *         return GiacMethods['randmarkov'](self,*args)
 * 
 *      def randmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmatrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2415randmatrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2414randmatrix, "From Giac's documentation:\n        Help for randmatrix:\n        randmatrix(Intg(n), [Intg(m)],[Interval or quote(DistribLaw)])\n        Returns a list of size n or an n*m matrix that contains random integers in the range -99 through 99 with uniform distribution or contains random numbers according to the law put between quotes.\n        See also: 1/ idn 2/ randPoly 3/ rand 4/ randvector \n        Ex1:randmatrix(3)\n        Ex2:randmatrix(3,2)\n        Ex3:randmatrix(3,2,6)\n        Ex4:randmatrix(3,2,binomial,10,0.3)\n        Ex5:randmatrix(3,2,multinomial,[1/2,1/3,1/6])\n        Ex6:randmatrix(3,2,poisson,5.2)\n        Ex7:randmatrix(3,2,normald,0,1)\n        Ex8:randmatrix(3,2,exp,7/2)\n        Ex9:randmatrix(3,2,poisson,1.2)\n        Ex10:randmatrix(3,2,'rand(3)')\n        Ex11:randmatrix(3,2,1..2)\n        Ex12:randmatrix(3,5,multinomial,[1/2,1/3,1/6],[\"R\",\"V\",\"B\"])\n        Ex13: GF(2,8,g);ranm(3,3,g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2415randmatrix = {"randmatrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2415randmatrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2414randmatrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2415randmatrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randmatrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randmatrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2414randmatrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2414randmatrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randmatrix", 1);

  /* "giacpy/auto-methods.pxi":14984
 * 
 *         '''
 *         return GiacMethods['randmatrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randmultinomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randmatrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14984, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14963
 *         return GiacMethods['randmarkov'](self,*args)
 * 
 *      def randmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmatrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randmatrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14986
 *         return GiacMethods['randmatrix'](self,*args)
 * 
 *      def randmultinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmultinomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2417randmultinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2416randmultinomial, "From Giac's documentation:\n        Help for randmultinomial:\n        randmultinomial(List(P),[List(K)])\n        Returns a random index or list element according to a multinomial distribution probability list P.\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randnorm 7/ randpoisson 8/ randgeometric 9/ randbinomial \n        Ex1:randmultinomial([1/2,1/3,1/6])\n        Ex2:randmultinomial([1/2,1/3,1/6],[\"R\",\"V\",\"B\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2417randmultinomial = {"randmultinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2417randmultinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2416randmultinomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2417randmultinomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randmultinomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randmultinomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2416randmultinomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2416randmultinomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randmultinomial", 1);

  /* "giacpy/auto-methods.pxi":14996
 * 
 *         '''
 *         return GiacMethods['randmultinomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randnorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randmultinomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 14996, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 14996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 14996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14986
 *         return GiacMethods['randmatrix'](self,*args)
 * 
 *      def randmultinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmultinomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randmultinomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":14998
 *         return GiacMethods['randmultinomial'](self,*args)
 * 
 *      def randnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randnorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2419randnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2418randnorm, "From Giac's documentation:\n        Help for randnorm:\n        randnorm(Real(mu),Real(sigma))\n        Returns a random real with normal distribution N(mu,sigma).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randpoisson 8/ randgeometric 9/ randmultinomial \n        Ex1:randnorm(0,1)\n        Ex2:randnorm(2,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2419randnorm = {"randnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2419randnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2418randnorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2419randnorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randnorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randnorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2418randnorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2418randnorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randnorm", 1);

  /* "giacpy/auto-methods.pxi":15008
 * 
 *         '''
 *         return GiacMethods['randnorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randnorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15008, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":14998
 *         return GiacMethods['randmultinomial'](self,*args)
 * 
 *      def randnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randnorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randnorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15010
 *         return GiacMethods['randnorm'](self,*args)
 * 
 *      def random(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2421random(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2420random, "From Giac's documentation:\n        Help for random:\n        random(Intg(n) or Interval(p..n) or NULL,[Intg(b1) or Lst(L)],[Intg(b2)])\n        rand(n)=a random integer (resp rand(p,n)=a real or rand(p..n)=a real function) with uniform distribution in 0..n-1 (resp in [p;n])(rand()=rand(0,1)=a real in [0,1[) or rand(n,b1,b2)=n integers between b1 and b2 or rand(n,L)=list of n elements of L.\n        See also: 1/ srand 2/ randpoly 3/ ranm 4/ randvector 5/ hasard \n        Ex1:random(4)\n        Ex2:random()\n        Ex3:random(0,2)\n        Ex4:random(0..2)()\n        Ex5: f:=rand(0..2)\n        Ex6:random(3,1,10)\n        Ex7:random(3,[\"r\",\"r\",\"r\",\"b\",\"n\"])\n        Ex8: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];L3:=rand(L,3)\n        Ex9: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];L3:=L.rand(3)\n        Ex10: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];a:=rand(L)\n        Ex11: L:=[\"r\",\"r\",\"r\",\"b\",\"n\"];a:=L.rand()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2421random = {"random", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2421random, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2420random};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2421random(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2420random(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2420random(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random", 1);

  /* "giacpy/auto-methods.pxi":15029
 * 
 *         '''
 *         return GiacMethods['random'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_bipartite_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15029, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15010
 *         return GiacMethods['randnorm'](self,*args)
 * 
 *      def random(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15031
 *         return GiacMethods['random'](self,*args)
 * 
 *      def random_bipartite_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_bipartite_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2423random_bipartite_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2422random_bipartite_graph, "From Giac's documentation:\n        Help for random_bipartite_graph:\n        random_bipartite_graph(Intg(n)||Lst(a,b),Real(p)||Intg(m))\n        Returns a random undirected unweighted bipartite graph on n vertices where each possible edge is present with probability p or where m edges are created at random. When the first argument is list [a,b] of integers, two groups of vertices with sizes a and b are created.\n        See also: 1/ random_digraph 2/ random_graph 3/ random_planar_graph 4/ random_regular_graph 5/ random_sequence_graph 6/ random_tournament 7/ random_tree \n        Ex1:random_bipartite_graph(10,0.5)\n        Ex2:random_bipartite_graph([2,3],1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2423random_bipartite_graph = {"random_bipartite_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2423random_bipartite_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2422random_bipartite_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2423random_bipartite_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_bipartite_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_bipartite_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2422random_bipartite_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2422random_bipartite_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_bipartite_graph", 1);

  /* "giacpy/auto-methods.pxi":15041
 * 
 *         '''
 *         return GiacMethods['random_bipartite_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_digraph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_bipartite_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15041, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15031
 *         return GiacMethods['random'](self,*args)
 * 
 *      def random_bipartite_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_bipartite_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_bipartite_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15043
 *         return GiacMethods['random_bipartite_graph'](self,*args)
 * 
 *      def random_digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_digraph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2425random_digraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2424random_digraph, "From Giac's documentation:\n        Help for random_digraph:\n        random_digraph(Intg(n)||Lst(V),Real(p)||Intg(m))\n        Returns a random directed unweighted graph on n vertices (list V of labels may me specified) where two vertices are connected with probability p or where m edges are created at random.\n        See also: 1/ random_bipartite_graph 2/ random_graph 3/ random_planar_graph 4/ random_regular_graph 5/ random_sequence_graph 6/ random_tournament 7/ random_tree \n        Ex1:random_digraph(8,0.5)\n        Ex2:random_digraph(8,10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2425random_digraph = {"random_digraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2425random_digraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2424random_digraph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2425random_digraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_digraph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_digraph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2424random_digraph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2424random_digraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_digraph", 1);

  /* "giacpy/auto-methods.pxi":15053
 * 
 *         '''
 *         return GiacMethods['random_digraph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_digraph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15053, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15043
 *         return GiacMethods['random_bipartite_graph'](self,*args)
 * 
 *      def random_digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_digraph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_digraph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15055
 *         return GiacMethods['random_digraph'](self,*args)
 * 
 *      def random_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2427random_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2426random_graph, "From Giac's documentation:\n        Help for random_graph:\n        random_graph(Intg(n)||Lst(V),Real(p)||Intg(m))\n        Returns a random undirected unweighted graph on n vertices (list V of labels may be specified) where two vertices are connected with probability p or where m edges are created at random.\n        See also: 1/ random_bipartite_graph 2/ random_digraph 3/ random_planar_graph 4/ random_regular_graph 5/ random_sequence_graph 6/ random_tournament 7/ random_tree \n        Ex1:random_graph(8,0.5)\n        Ex2:random_graph(8,10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2427random_graph = {"random_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2427random_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2426random_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2427random_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2426random_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2426random_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_graph", 1);

  /* "giacpy/auto-methods.pxi":15065
 * 
 *         '''
 *         return GiacMethods['random_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_network(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15065, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15055
 *         return GiacMethods['random_digraph'](self,*args)
 * 
 *      def random_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15067
 *         return GiacMethods['random_graph'](self,*args)
 * 
 *      def random_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_network:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2429random_network(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2428random_network, "From Giac's documentation:\n        Help for random_network:\n        random_network(Intg(a),Intg(b),[Real(p)],[opts])\n        Returns a random network composed of b frames of size a*a in which every edge appears with the probability p (by default 0.5).\n        See also: 1/ is_network 2/ maxflow \n        Ex1:random_network(3,3)\n        Ex2:random_network(3,3,acyclic)\n        Ex3:random_network(3,4,0.75)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2429random_network = {"random_network", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2429random_network, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2428random_network};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2429random_network(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_network (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_network", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2428random_network(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2428random_network(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_network", 1);

  /* "giacpy/auto-methods.pxi":15078
 * 
 *         '''
 *         return GiacMethods['random_network'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_planar_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_network); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15078, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15067
 *         return GiacMethods['random_graph'](self,*args)
 * 
 *      def random_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_network:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_network", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15080
 *         return GiacMethods['random_network'](self,*args)
 * 
 *      def random_planar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_planar_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2431random_planar_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2430random_planar_graph, "From Giac's documentation:\n        Help for random_planar_graph:\n        random_planar_graph(Intg(n)||Lst(V),Real(p),[Intg(c)])\n        Returns a random planar graph with n vertices, which can also be specified as a list V of their labels, obtained by trying to remove each edge of a random triangulated graph with probability 0<=p<1 [c is connectivity level : 0 - any, 1 - connected, 2 - biconnected, 3 - triconnected (by default, c=1)].\n        See also: 1/ random_bipartite_graph 2/ random_digraph 3/ random_graph 4/ random_regular_graph 5/ random_sequence_graph 6/ random_tournament 7/ random_tree \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2431random_planar_graph = {"random_planar_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2431random_planar_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2430random_planar_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2431random_planar_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_planar_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_planar_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2430random_planar_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2430random_planar_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_planar_graph", 1);

  /* "giacpy/auto-methods.pxi":15088
 * 
 *         '''
 *         return GiacMethods['random_planar_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_regular_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_planar_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15088, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15080
 *         return GiacMethods['random_network'](self,*args)
 * 
 *      def random_planar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_planar_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_planar_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15090
 *         return GiacMethods['random_planar_graph'](self,*args)
 * 
 *      def random_regular_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_regular_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2433random_regular_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2432random_regular_graph, "From Giac's documentation:\n        Help for random_regular_graph:\n        random_regular_graph(Intg(n)||Lst(V),Intg(d),[connected])\n        Returns a random d-regular graph with n vertices, which may be specified as list V of their labels.\n        See also: 1/ random_bipartite_graph 2/ random_digraph 3/ random_graph 4/ random_planar_graph 5/ random_sequence_graph 6/ random_tournament 7/ random_tree \n        Ex1:random_regular_graph(100,80,connected)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2433random_regular_graph = {"random_regular_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2433random_regular_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2432random_regular_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2433random_regular_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_regular_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_regular_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2432random_regular_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2432random_regular_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_regular_graph", 1);

  /* "giacpy/auto-methods.pxi":15099
 * 
 *         '''
 *         return GiacMethods['random_regular_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_sequence_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_regular_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15099, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15090
 *         return GiacMethods['random_planar_graph'](self,*args)
 * 
 *      def random_regular_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_regular_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_regular_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15101
 *         return GiacMethods['random_regular_graph'](self,*args)
 * 
 *      def random_sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_sequence_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2435random_sequence_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2434random_sequence_graph, "From Giac's documentation:\n        Help for random_sequence_graph:\n        random_sequence_graph(Lst(L))\n        Returns a random undirected graph with degree sequence L.\n        See also: 1/ random_bipartite_graph 2/ random_digraph 3/ random_graph 4/ random_planar_graph 5/ random_sequence_graph 6/ random_tournament 7/ random_tree \n        Ex1:random_sequence_graph([1,3,3,2,1,2,2,2,3,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2435random_sequence_graph = {"random_sequence_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2435random_sequence_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2434random_sequence_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2435random_sequence_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_sequence_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_sequence_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2434random_sequence_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2434random_sequence_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_sequence_graph", 1);

  /* "giacpy/auto-methods.pxi":15110
 * 
 *         '''
 *         return GiacMethods['random_sequence_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_tournament(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_sequence_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15110, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15101
 *         return GiacMethods['random_regular_graph'](self,*args)
 * 
 *      def random_sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_sequence_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_sequence_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15112
 *         return GiacMethods['random_sequence_graph'](self,*args)
 * 
 *      def random_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tournament:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2437random_tournament(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2436random_tournament, "From Giac's documentation:\n        Help for random_tournament:\n        random_tournament(Intg(n)||Lst(V))\n        Returns a random tournament graph on n vertices, which may be specified as list V of their labels.\n        See also: 1/ random_bipartite_graph 2/ random_digraph 3/ random_graph 4/ random_planar_graph 5/ random_regular_graph 6/ random_sequence_graph 7/ random_tree \n        Ex1:random_tournament(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2437random_tournament = {"random_tournament", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2437random_tournament, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2436random_tournament};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2437random_tournament(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_tournament (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_tournament", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2436random_tournament(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2436random_tournament(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_tournament", 1);

  /* "giacpy/auto-methods.pxi":15121
 * 
 *         '''
 *         return GiacMethods['random_tournament'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_tournament); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15121, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15112
 *         return GiacMethods['random_sequence_graph'](self,*args)
 * 
 *      def random_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tournament:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_tournament", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15123
 *         return GiacMethods['random_tournament'](self,*args)
 * 
 *      def random_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2439random_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2438random_tree, "From Giac's documentation:\n        Help for random_tree:\n        random_tree(Intg(n)||Lst(V),[Intg(d)||root[=Vrtx(v)]])\n        Returns a random tree graph on n vertices, which may be specified as list V of their labels [with the upper bound d (positive integer) for the degree of graph or 'root' for rooted trees].\n        See also: 1/ random_bipartite_graph 2/ random_digraph 3/ random_graph 4/ random_planar_graph 5/ random_regular_graph 6/ random_sequence_graph 7/ random_tournament \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2439random_tree = {"random_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2439random_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2438random_tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2439random_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2438random_tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2438random_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_tree", 1);

  /* "giacpy/auto-methods.pxi":15131
 * 
 *         '''
 *         return GiacMethods['random_tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def random_variable(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15131, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15123
 *         return GiacMethods['random_tournament'](self,*args)
 * 
 *      def random_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15133
 *         return GiacMethods['random_tree'](self,*args)
 * 
 *      def random_variable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_variable:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2441random_variable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2440random_variable, "From Giac's documentation:\n        Help for random_variable:\n        random_variable(Lst(W)||Mtrx(M)||Fnc(f),[params])\n        Returns a random variable from a probability density function f or from list of weights (discrete variable).\n        See also: 1/ randvector 2/ randmatrix 3/ rand \n        Ex1:random_variable(fisher,2,3)\n        Ex2:random_variable([[\"apple\",1/3],[\"orange\",1/4],[\"pear\",1/5],[\"plum\",13/60]])\n        Ex3:random_variable(k->1-(k/10)^2,range=-10..10)\n        Ex4:random_variable([3,1,2,5],[alpha,beta,gamma,delta])\n        Ex5:random_variable(gammad,mean=12,variance=4)\n        Ex6:random_variable(binomial,mean=18,stddev=4)\n        Ex7:random_variable(multinomial,[1/2,1/3,1/6],[a,b,c])\n        Ex8:random_variable(weibull,mean=12.5,variance=1)\n        Ex9:random_variable(uniform,mean=10,stddev=2)\n        Ex10:random_variable(uniform,e..pi)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2441random_variable = {"random_variable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2441random_variable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2440random_variable};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2441random_variable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("random_variable (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "random_variable", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2440random_variable(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2440random_variable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("random_variable", 1);

  /* "giacpy/auto-methods.pxi":15151
 * 
 *         '''
 *         return GiacMethods['random_variable'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randperm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_random_variable); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15151, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15133
 *         return GiacMethods['random_tree'](self,*args)
 * 
 *      def random_variable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_variable:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.random_variable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15153
 *         return GiacMethods['random_variable'](self,*args)
 * 
 *      def randperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randperm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2443randperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2442randperm, "From Giac's documentation:\n        Help for randperm:\n        randperm(Intg(n)||Lst(L))\n        Returns a random permutation of [0,1,2,..,n-1] or of the list L.\n        See also: 1/ permu2cycles 2/ is_permu 3/ permu2mat \n        Ex1:randperm(4)\n        Ex2:randperm(7)\n        Ex3:randperm([1,3,5,7,9])\n        Ex4: L:=[1,3,5,7,9];L:=randperm(L)\n        Ex5: L:=[1,3,5,7,9];L.randperm()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2443randperm = {"randperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2443randperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2442randperm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2443randperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randperm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randperm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2442randperm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2442randperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randperm", 1);

  /* "giacpy/auto-methods.pxi":15166
 * 
 *         '''
 *         return GiacMethods['randperm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randpoisson(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randperm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15166, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15153
 *         return GiacMethods['random_variable'](self,*args)
 * 
 *      def randperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randperm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randperm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15168
 *         return GiacMethods['randperm'](self,*args)
 * 
 *      def randpoisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoisson:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2445randpoisson(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2444randpoisson, "From Giac's documentation:\n        Help for randpoisson:\n        randpoisson(Real(\316\273))\n        Returns a random integer with poisson distribution P(\316\273).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randnorm 8/ randgeometric 9/ randmultinomial \n        Ex1:randpoisson(5.4)\n        Ex2:randpoisson(2.8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2445randpoisson = {"randpoisson", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2445randpoisson, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2444randpoisson};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2445randpoisson(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randpoisson (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randpoisson", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2444randpoisson(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2444randpoisson(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randpoisson", 1);

  /* "giacpy/auto-methods.pxi":15178
 * 
 *         '''
 *         return GiacMethods['randpoisson'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randpoly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randpoisson); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15178, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15168
 *         return GiacMethods['randperm'](self,*args)
 * 
 *      def randpoisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoisson:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randpoisson", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15180
 *         return GiacMethods['randpoisson'](self,*args)
 * 
 *      def randpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2447randpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2446randpoly, "From Giac's documentation:\n        Help for randpoly:\n        randpoly([Var(Var)],Intg(n),[law])\n        Returns a polynomial with variable var (or x), of degree n and where the coefficients are random integers in the range -99 through 99 with uniform distribution or according to a law.\n        See also: 1/ ranm 2/ randvector \n        Ex1:randpoly(5)\n        Ex2:randpoly(t,8)\n        Ex3:randpoly(t,8,-1..1)\n        Ex4:randpoly([x,y],[10,3])\n        Ex5:randpoly([x,y],[10,3],1 mod 7)\n        Ex6: GF(2,8,g);randpoly(t,8,g);randpoly([x,y],[2,3],g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2447randpoly = {"randpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2447randpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2446randpoly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2447randpoly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randpoly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randpoly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2446randpoly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2446randpoly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randpoly", 1);

  /* "giacpy/auto-methods.pxi":15194
 * 
 *         '''
 *         return GiacMethods['randpoly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randseed(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randpoly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15194, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15180
 *         return GiacMethods['randpoisson'](self,*args)
 * 
 *      def randpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randpoly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15196
 *         return GiacMethods['randpoly'](self,*args)
 * 
 *      def randseed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randseed:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2449randseed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2448randseed, "From Giac's documentation:\n        Help for randseed:\n        randseed()\n        srand returns an integer and initializes the sequence of random numbers.\n        See also: 1/ RandSeed \n        Ex1:randseed(12)\n        Ex2: srand\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2449randseed = {"randseed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2449randseed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2448randseed};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2449randseed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randseed (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randseed", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2448randseed(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2448randseed(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randseed", 1);

  /* "giacpy/auto-methods.pxi":15206
 * 
 *         '''
 *         return GiacMethods['randseed'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randstudent(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randseed); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15206, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15196
 *         return GiacMethods['randpoly'](self,*args)
 * 
 *      def randseed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randseed:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randseed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15208
 *         return GiacMethods['randseed'](self,*args)
 * 
 *      def randstudent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randstudent:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2451randstudent(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2450randstudent, "From Giac's documentation:\n        Help for randstudent:\n        randstudent(Intg(n))\n        Returns a random integer with Student distribution S(n).\n        See also: 1/ rand 2/ randpoly 3/ ranm 4/ randvector 5/ randexp 6/ randbinomial 7/ randnorm 8/ randgeometric 9/ randmultinomial \n        Ex1:randstudent(5)\n        Ex2:randstudent(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2451randstudent = {"randstudent", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2451randstudent, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2450randstudent};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2451randstudent(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randstudent (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randstudent", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2450randstudent(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2450randstudent(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randstudent", 1);

  /* "giacpy/auto-methods.pxi":15218
 * 
 *         '''
 *         return GiacMethods['randstudent'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randvar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randstudent); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15218, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15208
 *         return GiacMethods['randseed'](self,*args)
 * 
 *      def randstudent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randstudent:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randstudent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15220
 *         return GiacMethods['randstudent'](self,*args)
 * 
 *      def randvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2453randvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2452randvar, "From Giac's documentation:\n        Help for randvar:\n        randvar(Lst(W)||Mtrx(M)||Fnc(f),[params])\n        Returns a random variable from a probability density function f or from list of weights (discrete variable).\n        See also: 1/ randvector 2/ randmatrix 3/ rand \n        Ex1:randvar(fisher,2,3)\n        Ex2:randvar([[\"apple\",1/3],[\"orange\",1/4],[\"pear\",1/5],[\"plum\",13/60]])\n        Ex3:randvar(k->1-(k/10)^2,range=-10..10)\n        Ex4:randvar([3,1,2,5],[alpha,beta,gamma,delta])\n        Ex5:randvar(gammad,mean=12,variance=4)\n        Ex6:randvar(binomial,mean=18,stddev=4)\n        Ex7:randvar(multinomial,[1/2,1/3,1/6],[a,b,c])\n        Ex8:randvar(weibull,mean=12.5,variance=1)\n        Ex9:randvar(uniform,mean=10,stddev=2)\n        Ex10:randvar(uniform,e..pi)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2453randvar = {"randvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2453randvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2452randvar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2453randvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randvar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randvar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2452randvar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2452randvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randvar", 1);

  /* "giacpy/auto-methods.pxi":15238
 * 
 *         '''
 *         return GiacMethods['randvar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randvector(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randvar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15238, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15220
 *         return GiacMethods['randstudent'](self,*args)
 * 
 *      def randvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randvar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15240
 *         return GiacMethods['randvar'](self,*args)
 * 
 *      def randvector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvector:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2455randvector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2454randvector, "From Giac's documentation:\n        Help for randvector:\n        randvector(Intg(n), [Intg(m)],[Interval or quote(DistribLaw)])\n        Returns a list of size n that contains random integers in the range -99 through 99 (or in 0..m-1) with uniform distribution or contains random numbers according to the law put between quotes.\n        See also: 1/ idn 2/ randPoly 3/ rand 4/ ranm \n        Ex1:randvector(3)\n        Ex2:randvector(3,6)\n        Ex3:randvector(3,normald,0,1)\n        Ex4:randvector(3,poisson,1.2)\n        Ex5:randvector(3,exponentiald,1.2)\n        Ex6:randvector(3,multinomial,[1/2,1/3,1/6])\n        Ex7:randvector(3,multinomial,[1/2,1/3,1/6],[a,b,c])\n        Ex8:randvector(3,'rand(3)')\n        Ex9:randvector(3,1..2)\n        Ex10: GF(2,8,g);randvector(3,g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2455randvector = {"randvector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2455randvector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2454randvector};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2455randvector(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randvector (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randvector", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2454randvector(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2454randvector(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randvector", 1);

  /* "giacpy/auto-methods.pxi":15258
 * 
 *         '''
 *         return GiacMethods['randvector'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def randweibulld(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randvector); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15258, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15240
 *         return GiacMethods['randvar'](self,*args)
 * 
 *      def randvector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvector:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randvector", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15260
 *         return GiacMethods['randvector'](self,*args)
 * 
 *      def randweibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randweibulld:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2457randweibulld(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2456randweibulld, "From Giac's documentation:\n        Help for randweibulld:\n        randweibulld(Real(a),Real(b))\n        Returns a random real according to the Weibull distribution with parameters a>0 and b>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:randweibulld(1,2)\n        Ex2:randweibulld(1.5,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2457randweibulld = {"randweibulld", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2457randweibulld, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2456randweibulld};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2457randweibulld(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("randweibulld (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "randweibulld", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2456randweibulld(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2456randweibulld(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("randweibulld", 1);

  /* "giacpy/auto-methods.pxi":15270
 * 
 *         '''
 *         return GiacMethods['randweibulld'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rank(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_randweibulld); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15270, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15260
 *         return GiacMethods['randvector'](self,*args)
 * 
 *      def randweibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randweibulld:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.randweibulld", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15272
 *         return GiacMethods['randweibulld'](self,*args)
 * 
 *      def rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rank:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2459rank(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2458rank, "From Giac's documentation:\n        Help for rank:\n        rank(Mtrx)\n        Returns the rank of the matrix.\n        See also: 1/ det 2/ image \n        Ex1:rank([[1,1,2],[2,1,3],[3,1,4]])\n        Ex2:rank([[1,1,2],[2,1,3],[3,1,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2459rank = {"rank", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2459rank, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2458rank};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2459rank(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rank (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rank", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2458rank(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2458rank(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rank", 1);

  /* "giacpy/auto-methods.pxi":15282
 * 
 *         '''
 *         return GiacMethods['rank'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ranm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rank); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15282, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15272
 *         return GiacMethods['randweibulld'](self,*args)
 * 
 *      def rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rank:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rank", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15284
 *         return GiacMethods['rank'](self,*args)
 * 
 *      def ranm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2461ranm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2460ranm, "From Giac's documentation:\n        Help for ranm:\n        ranm(Intg(n), [Intg(m)],[Interval or quote(DistribLaw)])\n        Returns a list of size n or an n*m matrix that contains random integers in the range -99 through 99 with uniform distribution or contains random numbers according to the law put between quotes.\n        See also: 1/ idn 2/ randPoly 3/ rand 4/ randvector \n        Ex1:ranm(3)\n        Ex2:ranm(3,2)\n        Ex3:ranm(3,2,6)\n        Ex4:ranm(3,2,binomial,10,0.3)\n        Ex5:ranm(3,2,multinomial,[1/2,1/3,1/6])\n        Ex6:ranm(3,2,poisson,5.2)\n        Ex7:ranm(3,2,normald,0,1)\n        Ex8:ranm(3,2,exp,7/2)\n        Ex9:ranm(3,2,poisson,1.2)\n        Ex10:ranm(3,2,'rand(3)')\n        Ex11:ranm(3,2,1..2)\n        Ex12:ranm(3,5,multinomial,[1/2,1/3,1/6],[\"R\",\"V\",\"B\"])\n        Ex13: GF(2,8,g);ranm(3,3,g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2461ranm = {"ranm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2461ranm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2460ranm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2461ranm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ranm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ranm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2460ranm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2460ranm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ranm", 1);

  /* "giacpy/auto-methods.pxi":15305
 * 
 *         '''
 *         return GiacMethods['ranm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ranv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ranm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15305, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15284
 *         return GiacMethods['rank'](self,*args)
 * 
 *      def ranm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ranm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15307
 *         return GiacMethods['ranm'](self,*args)
 * 
 *      def ranv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2463ranv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2462ranv, "From Giac's documentation:\n        Help for ranv:\n        ranv(Intg(n), [Intg(m)],[Interval or quote(DistribLaw)])\n        Returns a list of size n that contains random integers in the range -99 through 99 (or in 0..m-1) with uniform distribution or contains random numbers according to the law put between quotes.\n        See also: 1/ idn 2/ randPoly 3/ rand 4/ ranm \n        Ex1:ranv(3)\n        Ex2:ranv(3,6)\n        Ex3:ranv(3,normald,0,1)\n        Ex4:ranv(3,poisson,1.2)\n        Ex5:ranv(3,exponentiald,1.2)\n        Ex6:ranv(3,multinomial,[1/2,1/3,1/6])\n        Ex7:ranv(3,multinomial,[1/2,1/3,1/6],[a,b,c])\n        Ex8:ranv(3,'rand(3)')\n        Ex9:ranv(3,1..2)\n        Ex10: GF(2,8,g);randvector(3,g)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2463ranv = {"ranv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2463ranv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2462ranv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2463ranv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ranv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ranv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2462ranv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2462ranv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ranv", 1);

  /* "giacpy/auto-methods.pxi":15325
 * 
 *         '''
 *         return GiacMethods['ranv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rassembler_trigo(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ranv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15325, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15307
 *         return GiacMethods['ranm'](self,*args)
 * 
 *      def ranv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ranv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15327
 *         return GiacMethods['ranv'](self,*args)
 * 
 *      def rassembler_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rassembler_trigo:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2465rassembler_trigo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2464rassembler_trigo, "From Giac's documentation:\n        Help for rassembler_trigo:\n        rassembler_trigo(Expr)\n        Collects trigonometric expressions.\n        See also: 1/ texpand 2/ tlin \n        Ex1:rassembler_trigo(sin(x)+cos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2465rassembler_trigo = {"rassembler_trigo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2465rassembler_trigo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2464rassembler_trigo};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2465rassembler_trigo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rassembler_trigo (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rassembler_trigo", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2464rassembler_trigo(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2464rassembler_trigo(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rassembler_trigo", 1);

  /* "giacpy/auto-methods.pxi":15336
 * 
 *         '''
 *         return GiacMethods['rassembler_trigo'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rat_jordan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rassembler_trigo); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15336, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15327
 *         return GiacMethods['ranv'](self,*args)
 * 
 *      def rassembler_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rassembler_trigo:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rassembler_trigo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15338
 *         return GiacMethods['rassembler_trigo'](self,*args)
 * 
 *      def rat_jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rat_jordan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2467rat_jordan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2466rat_jordan, "From Giac's documentation:\n        Help for rat_jordan:\n        rat_jordan(Mtrx)\n        Returns the list made by the transition matrix and the rational Jordan form of a matrix.\n        See also: 1/ egv 2/ egvl 3/ jordan 4/ companion \n        Ex1:rat_jordan([[0,2],[1,0]])\n        Ex2:rat_jordan([[-2,-2,1],[-2,1,-2],[1,-2,-2]])\n        Ex3:rat_jordan([[1,1,-1,2,-1],[2,0,1,-4,-1],[0,1,1,1,1],[0,1,2,0,1],[0,0,-3,3,-1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2467rat_jordan = {"rat_jordan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2467rat_jordan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2466rat_jordan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2467rat_jordan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rat_jordan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rat_jordan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2466rat_jordan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2466rat_jordan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rat_jordan", 1);

  /* "giacpy/auto-methods.pxi":15349
 * 
 *         '''
 *         return GiacMethods['rat_jordan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ratinterp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rat_jordan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15349, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15338
 *         return GiacMethods['rassembler_trigo'](self,*args)
 * 
 *      def rat_jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rat_jordan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rat_jordan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15351
 *         return GiacMethods['rat_jordan'](self,*args)
 * 
 *      def ratinterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratinterp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2469ratinterp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2468ratinterp, "From Giac's documentation:\n        Help for ratinterp:\n        ratinterp([Mtrx(P) || List(X)],[List(Y)],[Var(x)],[Intg(d)]))\n        Computes rational interpolations without poles of the given points.\n        See also: 1/ thiele 2/ lagrange 3/ triginterp \n        Ex1:ratinterp([1,3,5,8],[2,-1,3,4],x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2469ratinterp = {"ratinterp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2469ratinterp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2468ratinterp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2469ratinterp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ratinterp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ratinterp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2468ratinterp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2468ratinterp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ratinterp", 1);

  /* "giacpy/auto-methods.pxi":15360
 * 
 *         '''
 *         return GiacMethods['ratinterp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rational(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ratinterp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15360, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15351
 *         return GiacMethods['rat_jordan'](self,*args)
 * 
 *      def ratinterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratinterp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ratinterp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15362
 *         return GiacMethods['ratinterp'](self,*args)
 * 
 *      def rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rational:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2471rational(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2470rational, "From Giac's documentation:\n        Help for rational:\n        rational(Opt)\n        DOM_RAT or rational is the type of a rational, as returned by the type command. It is also an option of the assume command.\n        See also: 1/ type 2/ assume 3/ DOM_INT 4/ DOM_FLOAT \n        Ex1: assume(a,rational)\n        Ex2: assume(a,DOM_RAT)\n        Ex3: a:=1/2;type(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2471rational = {"rational", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2471rational, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2470rational};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2471rational(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rational (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rational", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2470rational(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2470rational(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rational", 1);

  /* "giacpy/auto-methods.pxi":15373
 * 
 *         '''
 *         return GiacMethods['rational'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rationalroot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rational); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15373, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15362
 *         return GiacMethods['ratinterp'](self,*args)
 * 
 *      def rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rational:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rational", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15375
 *         return GiacMethods['rational'](self,*args)
 * 
 *      def rationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rationalroot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2473rationalroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2472rationalroot, "From Giac's documentation:\n        Help for rationalroot:\n        rationalroot(Poly(P))\n        Returns the list of rational roots of P without indicating the multiplicity.\n        See also: 1/ proot 2/ froot 3/ complexroot 4/ realroot 5/ crationalroot \n        Ex1:rationalroot(2*x^3-9*x^2+13*x-6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2473rationalroot = {"rationalroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2473rationalroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2472rationalroot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2473rationalroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rationalroot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rationalroot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2472rationalroot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2472rationalroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rationalroot", 1);

  /* "giacpy/auto-methods.pxi":15384
 * 
 *         '''
 *         return GiacMethods['rationalroot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ratnormal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rationalroot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15384, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15375
 *         return GiacMethods['rational'](self,*args)
 * 
 *      def rationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rationalroot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rationalroot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15386
 *         return GiacMethods['rationalroot'](self,*args)
 * 
 *      def ratnormal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratnormal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2475ratnormal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2474ratnormal, "From Giac's documentation:\n        Help for ratnormal:\n        ratnormal(Expr)\n        Rewrites as an irreducible rational fraction.\n        See also: 1/ normal 2/ simplify 3/ factor 4/ expand \n        Ex1:ratnormal((x^2-1)/(x^3-1))\n        Ex2:ratnormal(c/d+b/d+a/d)\n        Ex3:ratnormal((x^2-1)/(x^3-1)+(x-1)/(x^3-1)+1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2475ratnormal = {"ratnormal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2475ratnormal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2474ratnormal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2475ratnormal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ratnormal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ratnormal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2474ratnormal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2474ratnormal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ratnormal", 1);

  /* "giacpy/auto-methods.pxi":15397
 * 
 *         '''
 *         return GiacMethods['ratnormal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rdiv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ratnormal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15397, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15386
 *         return GiacMethods['rationalroot'](self,*args)
 * 
 *      def ratnormal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratnormal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ratnormal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15399
 *         return GiacMethods['ratnormal'](self,*args)
 * 
 *      def rdiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rdiv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2477rdiv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2476rdiv, "From Giac's documentation:\n        Help for rdiv:\n        rdiv(Expr(a),Expr(b))\n        Division of a by b (prefixed version of /).\n        See also: 1/ / \n        Ex1:rdiv(3,5)\n        Ex2:rdiv(3.2,5.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2477rdiv = {"rdiv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2477rdiv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2476rdiv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2477rdiv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rdiv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rdiv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2476rdiv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2476rdiv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rdiv", 1);

  /* "giacpy/auto-methods.pxi":15409
 * 
 *         '''
 *         return GiacMethods['rdiv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def re(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rdiv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15409, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15399
 *         return GiacMethods['ratnormal'](self,*args)
 * 
 *      def rdiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rdiv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rdiv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15411
 *         return GiacMethods['rdiv'](self,*args)
 * 
 *      def re(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for re:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2479re(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2478re, "From Giac's documentation:\n        Help for re:\n        re(Cplx or LstCplx)\n        Returns the real part of a complex number.\n        See also: 1/ im 2/ conj \n        Ex1:re(1+2*i)\n        Ex2:re((1+2*i)^2)\n        Ex3:re([1+2*i,(1+2*i)^2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2479re = {"re", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2479re, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2478re};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2479re(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("re (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "re", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2478re(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2478re(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("re", 1);

  /* "giacpy/auto-methods.pxi":15422
 * 
 *         '''
 *         return GiacMethods['re'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reachable(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15422, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15411
 *         return GiacMethods['rdiv'](self,*args)
 * 
 *      def re(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for re:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.re", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15424
 *         return GiacMethods['re'](self,*args)
 * 
 *      def reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reachable:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2481reachable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2480reachable, "From Giac's documentation:\n        Help for reachable:\n        reachable(Graph(G),Vrtx(u))\n        Returns the list of vertices in G which are reachable from u.\n        See also: 1/ is_reachable 2/ shortest_path \n        Ex1: G:=graph_complement(complete_graph(3,4)):;reachable(G,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2481reachable = {"reachable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2481reachable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2480reachable};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2481reachable(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reachable (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reachable", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2480reachable(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2480reachable(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reachable", 1);

  /* "giacpy/auto-methods.pxi":15433
 * 
 *         '''
 *         return GiacMethods['reachable'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def read(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reachable); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15433, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15424
 *         return GiacMethods['re'](self,*args)
 * 
 *      def reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reachable:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reachable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15435
 *         return GiacMethods['reachable'](self,*args)
 * 
 *      def read(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for read:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2483read(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2482read, "From Giac's documentation:\n        Help for read:\n        read(Str(fich_name))\n        Reads variables and their values from the file fich_name.\n        See also: 1/ write 2/ readrgb 3/ readwav 4/ csv2gen \n        Ex1:read(\"toto\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2483read = {"read", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2483read, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2482read};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2483read(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "read", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2482read(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2482read(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read", 1);

  /* "giacpy/auto-methods.pxi":15444
 * 
 *         '''
 *         return GiacMethods['read'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def readrgb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15444, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15435
 *         return GiacMethods['reachable'](self,*args)
 * 
 *      def read(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for read:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15446
 *         return GiacMethods['read'](self,*args)
 * 
 *      def readrgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readrgb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2485readrgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2484readrgb, "From Giac's documentation:\n        Help for readrgb:\n        readrgb(Str(s),[Intg(w)],[Intg(h)])\n        Reads a picture file, using it's natural dimensions, or using specified dimensions.\n        See also: 1/ writergb 2/ readwav \n        Ex1:readrgb(\"image.png\")\n        Ex2:readrgb(\"image.png\",50,50)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2485readrgb = {"readrgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2485readrgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2484readrgb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2485readrgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("readrgb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "readrgb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2484readrgb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2484readrgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("readrgb", 1);

  /* "giacpy/auto-methods.pxi":15456
 * 
 *         '''
 *         return GiacMethods['readrgb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def readwav(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_readrgb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15456, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15446
 *         return GiacMethods['read'](self,*args)
 * 
 *      def readrgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readrgb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.readrgb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15458
 *         return GiacMethods['readrgb'](self,*args)
 * 
 *      def readwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readwav:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2487readwav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2486readwav, "From Giac's documentation:\n        Help for readwav:\n        readwav(Str(s))\n        Reads a WAV sound file.\n        See also: 1/ writewav 2/ readrgb \n        Ex1:readwav(\"pop.wav\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2487readwav = {"readwav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2487readwav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2486readwav};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2487readwav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("readwav (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "readwav", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2486readwav(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2486readwav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("readwav", 1);

  /* "giacpy/auto-methods.pxi":15467
 * 
 *         '''
 *         return GiacMethods['readwav'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def real(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_readwav); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15467, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15458
 *         return GiacMethods['readrgb'](self,*args)
 * 
 *      def readwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readwav:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.readwav", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15469
 *         return GiacMethods['readwav'](self,*args)
 * 
 *      def real(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for real:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2489real(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2488real, "From Giac's documentation:\n        Help for real:\n        real(Cplx or LstCplx)\n        Returns the real part of a complex number.\n        See also: 1/ im 2/ conj \n        Ex1:real(1+2*i)\n        Ex2:real((1+2*i)^2)\n        Ex3:real([1+2*i,(1+2*i)^2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2489real = {"real", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2489real, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2488real};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2489real(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("real (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "real", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2488real(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2488real(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("real", 1);

  /* "giacpy/auto-methods.pxi":15480
 * 
 *         '''
 *         return GiacMethods['real'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def realroot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_real); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15480, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15469
 *         return GiacMethods['readwav'](self,*args)
 * 
 *      def real(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for real:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.real", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15482
 *         return GiacMethods['real'](self,*args)
 * 
 *      def realroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for realroot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2491realroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2490realroot, "From Giac's documentation:\n        Help for realroot:\n        realroot([sturm],Poly(P),[Real(l)],[Cplx(a)],[Cplx(b)])\n        Returns the list of intervals of length <=l containing the real roots of P inside a..b with their multiplicity. By default the Vincent-Akritas-Strzebonski (VAS) method is used. realroot(sturm,P) uses Sturm's method.\n        See also: 1/ proot 2/ froot 3/ complexroot 4/ rationalroot 5/ crationalroot 6/ sturmab 7/ VAS \n        Ex1:realroot(x^3+7,0.1)\n        Ex2:realroot(x^3-7*x+7)\n        Ex3:realroot(sturm,x^3-7*x+7)\n        Ex4:realroot(x^5-2*x^4+x^3+1)\n        Ex5:realroot(x^5-2*x^4+x^3+1,0.1)\n        Ex6:realroot(x^3+x+8,1e-5,-4,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2491realroot = {"realroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2491realroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2490realroot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2491realroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("realroot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "realroot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2490realroot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2490realroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("realroot", 1);

  /* "giacpy/auto-methods.pxi":15496
 * 
 *         '''
 *         return GiacMethods['realroot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reciprocation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_realroot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15496, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15482
 *         return GiacMethods['real'](self,*args)
 * 
 *      def realroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for realroot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.realroot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15498
 *         return GiacMethods['realroot'](self,*args)
 * 
 *      def reciprocation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reciprocation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2493reciprocation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2492reciprocation, "From Giac's documentation:\n        Help for reciprocation:\n        reciprocation(Crcle,Lst(Pnt,Line))\n        Returns the list where the points (resp lines) are replaced with their polars (resp poles) with respect to the circle C.\n        See also: 1/ pole 2/ polar \n        Ex1:reciprocation(circle(0,1),[point((1+i)/2), line(1,-1+i)])\n        Ex2:reciprocation(circle(0,1),[line(1+i,2),point(1+i*2)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2493reciprocation = {"reciprocation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2493reciprocation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2492reciprocation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2493reciprocation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reciprocation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reciprocation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2492reciprocation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2492reciprocation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reciprocation", 1);

  /* "giacpy/auto-methods.pxi":15508
 * 
 *         '''
 *         return GiacMethods['reciprocation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reciprocation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15508, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15498
 *         return GiacMethods['realroot'](self,*args)
 * 
 *      def reciprocation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reciprocation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reciprocation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15510
 *         return GiacMethods['reciprocation'](self,*args)
 * 
 *      def rect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2495rect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2494rect, "From Giac's documentation:\n        Help for rect:\n        rect(Expr(x))\n        Returns the value of the rectangle function at x.\n        See also: 1/ boxcar 2/ tri 3/ Heaviside \n        Ex1:rect(x/2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2495rect = {"rect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2495rect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2494rect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2495rect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2494rect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2494rect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rect", 1);

  /* "giacpy/auto-methods.pxi":15519
 * 
 *         '''
 *         return GiacMethods['rect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rectangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15519, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15510
 *         return GiacMethods['reciprocation'](self,*args)
 * 
 *      def rect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15521
 *         return GiacMethods['rect'](self,*args)
 * 
 *      def rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2497rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2496rectangle, "From Giac's documentation:\n        Help for rectangle:\n        rectangle(Pnt(A)||Cplx,Pnt(B)||Cplx,Real(k)||Pnt(P)||Lst(P,k),[Var(D)],[Var(C)])\n        Returns and draws the rectangle ABCD, AD=k*AB; if k>0 ABCD is direct else indirect (in the plane ABP AD=AP or AD=k*AB).\n        See also: 1/ quadrilateral 2/ square \n        Ex1:rectangle(-i,1,2)\n        Ex2:rectangle(-i,1,-2,D,C)\n        Ex3:rectangle(point(0,0,0),point(3,3,3),point(0,0,3),D,C)\n        Ex4:rectangle(point(0,0,0),point(3,3,3),2,D,C)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2497rectangle = {"rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2497rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2496rectangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2497rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rectangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rectangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2496rectangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2496rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rectangle", 1);

  /* "giacpy/auto-methods.pxi":15533
 * 
 *         '''
 *         return GiacMethods['rectangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rectangle_droit(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rectangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15533, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15521
 *         return GiacMethods['rect'](self,*args)
 * 
 *      def rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rectangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15535
 *         return GiacMethods['rectangle'](self,*args)
 * 
 *      def rectangle_droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_droit:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2499rectangle_droit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2498rectangle_droit, "From Giac's documentation:\n        Help for rectangle_droit:\n        rectangle_droit(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2499rectangle_droit = {"rectangle_droit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2499rectangle_droit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2498rectangle_droit};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2499rectangle_droit(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rectangle_droit (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rectangle_droit", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2498rectangle_droit(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2498rectangle_droit(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rectangle_droit", 1);

  /* "giacpy/auto-methods.pxi":15549
 * 
 *         '''
 *         return GiacMethods['rectangle_droit'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rectangle_gauche(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rectangle_droit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15549, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15535
 *         return GiacMethods['rectangle'](self,*args)
 * 
 *      def rectangle_droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_droit:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rectangle_droit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15551
 *         return GiacMethods['rectangle_droit'](self,*args)
 * 
 *      def rectangle_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_gauche:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2501rectangle_gauche(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2500rectangle_gauche, "From Giac's documentation:\n        Help for rectangle_gauche:\n        rectangle_gauche(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2501rectangle_gauche = {"rectangle_gauche", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2501rectangle_gauche, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2500rectangle_gauche};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2501rectangle_gauche(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rectangle_gauche (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rectangle_gauche", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2500rectangle_gauche(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2500rectangle_gauche(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rectangle_gauche", 1);

  /* "giacpy/auto-methods.pxi":15565
 * 
 *         '''
 *         return GiacMethods['rectangle_gauche'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rectangle_plein(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rectangle_gauche); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15565, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15551
 *         return GiacMethods['rectangle_droit'](self,*args)
 * 
 *      def rectangle_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_gauche:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rectangle_gauche", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15567
 *         return GiacMethods['rectangle_gauche'](self,*args)
 * 
 *      def rectangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_plein:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2503rectangle_plein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2502rectangle_plein, "From Giac's documentation:\n        Help for rectangle_plein:\n        rectangle_plein(Real(a),[Real(b)])\n        Draws a full direct rectangle (resp square) with sides a,b (resp a) from the turtle position and on the left (by default b=a).\n        See also: 1/ triangle_plein \n        Ex1: rectangle_plein 20\n        Ex2:rectangle_plein(20)\n        Ex3:rectangle_plein(20,40)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2503rectangle_plein = {"rectangle_plein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2503rectangle_plein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2502rectangle_plein};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2503rectangle_plein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rectangle_plein (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rectangle_plein", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2502rectangle_plein(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2502rectangle_plein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rectangle_plein", 1);

  /* "giacpy/auto-methods.pxi":15578
 * 
 *         '''
 *         return GiacMethods['rectangle_plein'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rectangular_coordinates(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rectangle_plein); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15578, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15567
 *         return GiacMethods['rectangle_gauche'](self,*args)
 * 
 *      def rectangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_plein:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rectangle_plein", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15580
 *         return GiacMethods['rectangle_plein'](self,*args)
 * 
 *      def rectangular_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangular_coordinates:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2505rectangular_coordinates(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2504rectangular_coordinates, "From Giac's documentation:\n        Help for rectangular_coordinates:\n        rectangular_coordinates(LstPolCoord)\n        Returns the list of the abscissa and of the ordinate of a point given by the list of its polar coordinates.\n        See also: 1/ abscissa 2/ ordinate 3/ rectangular_coordinates 4/ polar_point \n        Ex1:rectangular_coordinates([1,pi/4])\n        Ex2:rectangular_coordinates(polar_point(1,pi/4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2505rectangular_coordinates = {"rectangular_coordinates", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2505rectangular_coordinates, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2504rectangular_coordinates};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2505rectangular_coordinates(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rectangular_coordinates (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rectangular_coordinates", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2504rectangular_coordinates(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2504rectangular_coordinates(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rectangular_coordinates", 1);

  /* "giacpy/auto-methods.pxi":15590
 * 
 *         '''
 *         return GiacMethods['rectangular_coordinates'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def recule(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rectangular_coordinates); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15590, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15580
 *         return GiacMethods['rectangle_plein'](self,*args)
 * 
 *      def rectangular_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangular_coordinates:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rectangular_coordinates", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15592
 *         return GiacMethods['rectangular_coordinates'](self,*args)
 * 
 *      def recule(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for recule:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2507recule(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2506recule, "From Giac's documentation:\n        Help for recule:\n        recule(NULL or Real(n))\n        The turtle takes n steps back (by default n=10).\n        See also: 1/ avance 2/ saute \n        Ex1: recule 30\n        Ex2:recule(30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2507recule = {"recule", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2507recule, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2506recule};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2507recule(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recule (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recule", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2506recule(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2506recule(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("recule", 1);

  /* "giacpy/auto-methods.pxi":15602
 * 
 *         '''
 *         return GiacMethods['recule'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def red(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_recule); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15602, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15592
 *         return GiacMethods['rectangular_coordinates'](self,*args)
 * 
 *      def recule(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for recule:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.recule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15604
 *         return GiacMethods['recule'](self,*args)
 * 
 *      def red(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for red:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2509red(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2508red, "From Giac's documentation:\n        Help for red:\n        red(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2509red = {"red", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2509red, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2508red};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2509red(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("red (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "red", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2508red(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2508red(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("red", 1);

  /* "giacpy/auto-methods.pxi":15614
 * 
 *         '''
 *         return GiacMethods['red'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reduced_conic(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_red); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15614, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15604
 *         return GiacMethods['recule'](self,*args)
 * 
 *      def red(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for red:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.red", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15616
 *         return GiacMethods['red'](self,*args)
 * 
 *      def reduced_conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_conic:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2511reduced_conic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2510reduced_conic, "From Giac's documentation:\n        Help for reduced_conic:\n        reduced_conic(Expr,[LstVar])\n        Returns the origin and the matrix of a base in which the conic given by its equation is reduced, 0 or 1 (0 if the conic is degenerate) and the equation of the conic in this base and also its parametric equation.\n        See also: 1/ gauss 2/ conic \n        Ex1:reduced_conic(x^2+2*x-2*y+1)\n        Ex2:reduced_conic(a*x^2-2*x*y+a*y^2-2*x+2*y+3,[x,y])\n        Ex3:reduced_conic(2*u^2+2*u*v+2*v^2+5*u+3,[u,v])\n        Ex4:reduced_conic((x+y)^2-2*x+1,x,y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2511reduced_conic = {"reduced_conic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2511reduced_conic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2510reduced_conic};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2511reduced_conic(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reduced_conic (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reduced_conic", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2510reduced_conic(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2510reduced_conic(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reduced_conic", 1);

  /* "giacpy/auto-methods.pxi":15628
 * 
 *         '''
 *         return GiacMethods['reduced_conic'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reduced_quadric(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reduced_conic); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15628, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15616
 *         return GiacMethods['red'](self,*args)
 * 
 *      def reduced_conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_conic:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reduced_conic", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15630
 *         return GiacMethods['reduced_conic'](self,*args)
 * 
 *      def reduced_quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_quadric:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2513reduced_quadric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2512reduced_quadric, "From Giac's documentation:\n        Help for reduced_quadric:\n        reduced_quadric(Expr, [LstVar])\n        Returns the origin and the matrix of a basis in which the quadric (given by its equation) is reduced, the list of its eigenvalues, the equation of the quadric in this basis and its parametric equation.\n        See also: 1/ gauss 2/ quadric \n        Ex1:reduced_quadric(4*x^2+y^2+z^2-4*x*y+4*x*z-2*y*z+8*x-4*y+4*z+2)\n        Ex2:reduced_quadric(x^2+3*y^2-3*z^2-8*y*z+2*z*x-4*x*y-1,x,y,z)\n        Ex3:reduced_quadric((u+v)*(v-w)+3*u-5*v,[u,v,w])\n        Ex4:reduced_quadric(7*x^2+4*y^2+4*z^2+4*x*y-4*x*z-2*y*z-4*x+5*y+4*z-18,[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2513reduced_quadric = {"reduced_quadric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2513reduced_quadric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2512reduced_quadric};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2513reduced_quadric(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reduced_quadric (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reduced_quadric", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2512reduced_quadric(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2512reduced_quadric(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reduced_quadric", 1);

  /* "giacpy/auto-methods.pxi":15642
 * 
 *         '''
 *         return GiacMethods['reduced_quadric'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ref(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reduced_quadric); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15642, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15630
 *         return GiacMethods['reduced_conic'](self,*args)
 * 
 *      def reduced_quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_quadric:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reduced_quadric", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15644
 *         return GiacMethods['reduced_quadric'](self,*args)
 * 
 *      def ref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ref:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2515ref(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2514ref, "From Giac's documentation:\n        Help for ref:\n        ref(Mtrx(M))\n        Gaussian reduction of AX=b (M=A|(-b)).\n        See also: 1/ rref 2/ det \n        Ex1:ref([[3,1,-2],[3,2,2]])\n        Ex2:ref([[2,1,1,-1],[1,1,2,-1],[1,2,1,-4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2515ref = {"ref", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2515ref, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2514ref};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2515ref(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ref (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ref", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2514ref(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2514ref(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ref", 1);

  /* "giacpy/auto-methods.pxi":15654
 * 
 *         '''
 *         return GiacMethods['ref'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reflection(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ref); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15654, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15644
 *         return GiacMethods['reduced_quadric'](self,*args)
 * 
 *      def ref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ref:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15656
 *         return GiacMethods['ref'](self,*args)
 * 
 *      def reflection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reflection:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2517reflection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2516reflection, "From Giac's documentation:\n        Help for reflection:\n        reflection((Pnt(A) or Line(D)),(Pnt(C) or Curve(C)))\n        reflection(D,C) (or reflection(A,C))=symmetry of C with the symmetry-line D (or sym-point A).\n        See also: 1/ rotation 2/ translation \n        Ex1:reflection(line(0,1+i),A)\n        Ex2:reflection(B,A)\n        Ex3:reflection(line(0,1+i),circle(i,1+i))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2517reflection = {"reflection", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2517reflection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2516reflection};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2517reflection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reflection (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reflection", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2516reflection(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2516reflection(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reflection", 1);

  /* "giacpy/auto-methods.pxi":15667
 * 
 *         '''
 *         return GiacMethods['reflection'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def regroup(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reflection); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15667, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15656
 *         return GiacMethods['ref'](self,*args)
 * 
 *      def reflection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reflection:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reflection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15669
 *         return GiacMethods['reflection'](self,*args)
 * 
 *      def regroup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for regroup:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2519regroup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2518regroup, "From Giac's documentation:\n        Help for regroup:\n        regroup(Expr)\n        Collects terms in an expression.\n        See also: 1/ simplify 2/ normal \n        Ex1:regroup(x+3*x+5*4/x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2519regroup = {"regroup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2519regroup, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2518regroup};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2519regroup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("regroup (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "regroup", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2518regroup(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2518regroup(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("regroup", 1);

  /* "giacpy/auto-methods.pxi":15678
 * 
 *         '''
 *         return GiacMethods['regroup'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def relabel_vertices(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_regroup); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15678, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15669
 *         return GiacMethods['reflection'](self,*args)
 * 
 *      def regroup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for regroup:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.regroup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15680
 *         return GiacMethods['regroup'](self,*args)
 * 
 *      def relabel_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for relabel_vertices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2521relabel_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2520relabel_vertices, "From Giac's documentation:\n        Help for relabel_vertices:\n        relabel_vertices(Graph(G),Lst(L))\n        Returns a copy of G with vertex labels changed to those in L.\n        See also: 1/ graph_vertices 2/ isomorphic_copy 3/ permute_vertices \n        Ex1:relabel_vertices(graph([a,b,c]),[\"first\",\"second\",\"third\"])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2521relabel_vertices = {"relabel_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2521relabel_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2520relabel_vertices};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2521relabel_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("relabel_vertices (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "relabel_vertices", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2520relabel_vertices(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2520relabel_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("relabel_vertices", 1);

  /* "giacpy/auto-methods.pxi":15689
 * 
 *         '''
 *         return GiacMethods['relabel_vertices'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reliability_polynomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_relabel_vertices); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15689, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15680
 *         return GiacMethods['regroup'](self,*args)
 * 
 *      def relabel_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for relabel_vertices:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.relabel_vertices", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15691
 *         return GiacMethods['relabel_vertices'](self,*args)
 * 
 *      def reliability_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reliability_polynomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2523reliability_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2522reliability_polynomial, "From Giac's documentation:\n        Help for reliability_polynomial:\n        reliability_polynomial(Graph(G),[Var(p)])\n        Returns the reliability polynomial [or its value at point p] of an undirected graph G. If G is weighted, then all weights must be positive integers which are interpreted as edge multiplicities.\n        See also: 1/ chromatic_polynomial 2/ flow_polynomial 3/ tutte_polynomial \n        Ex1:reliability_polynomial(graph(\"petersen\"))\n        Ex2:reliability_polynomial(graph(\"petersen\"),0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2523reliability_polynomial = {"reliability_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2523reliability_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2522reliability_polynomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2523reliability_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reliability_polynomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reliability_polynomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2522reliability_polynomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2522reliability_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reliability_polynomial", 1);

  /* "giacpy/auto-methods.pxi":15701
 * 
 *         '''
 *         return GiacMethods['reliability_polynomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rem(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reliability_polynomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15701, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15691
 *         return GiacMethods['relabel_vertices'](self,*args)
 * 
 *      def reliability_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reliability_polynomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reliability_polynomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15703
 *         return GiacMethods['reliability_polynomial'](self,*args)
 * 
 *      def rem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rem:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2525rem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2524rem, "From Giac's documentation:\n        Help for rem:\n        rem((Vect or Poly),(Vect or Poly),[Var])\n        Euclidean remainder of 2 polynomials.\n        See also: 1/ quo 2/ quorem 3/ Rem 4/ irem \n        Ex1:rem([1,2,3,4],[-1,2])\n        Ex2:rem(x^3+2x^2+3x+4,-x+2)\n        Ex3:rem(t^3+2t^2+3t+4,-t+2,t)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2525rem = {"rem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2525rem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2524rem};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2525rem(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rem (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rem", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2524rem(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2524rem(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rem", 1);

  /* "giacpy/auto-methods.pxi":15714
 * 
 *         '''
 *         return GiacMethods['rem'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def remain(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rem); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15714, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15703
 *         return GiacMethods['reliability_polynomial'](self,*args)
 * 
 *      def rem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rem:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15716
 *         return GiacMethods['rem'](self,*args)
 * 
 *      def remain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remain:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2527remain(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2526remain, "From Giac's documentation:\n        Help for remain:\n        remain(Intg(a),Intg(b))\n        Euclidean remainder of 2 integers.\n        See also: 1/ iquo 2/ smod 3/ rem 4/ mod \n        Ex1:remain(125,15)\n        Ex2:remain(125,41)\n        Ex3:remain(-7,3)\n        Ex4:remain(25+12*i,5+7*i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2527remain = {"remain", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2527remain, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2526remain};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2527remain(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remain (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "remain", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2526remain(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2526remain(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remain", 1);

  /* "giacpy/auto-methods.pxi":15728
 * 
 *         '''
 *         return GiacMethods['remain'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def remove(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_remain); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15728, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15716
 *         return GiacMethods['rem'](self,*args)
 * 
 *      def remain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remain:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.remain", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15730
 *         return GiacMethods['remain'](self,*args)
 * 
 *      def remove(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remove:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2529remove(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2528remove, "From Giac's documentation:\n        Help for remove:\n        remove(FncBool(f)||a,Lst(l))\n        Remove the occurrences a of l or the elements a such that f(a)=true.\n        See also: 1/ select 2/ suppress \n        Ex1:remove(x->x>=5,[1,2,6,7])\n        Ex2:remove(5,[1,2,5,6,7,5])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2529remove = {"remove", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2529remove, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2528remove};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2529remove(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "remove", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2528remove(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2528remove(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove", 1);

  /* "giacpy/auto-methods.pxi":15740
 * 
 *         '''
 *         return GiacMethods['remove'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reorder(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_remove); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15740, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15730
 *         return GiacMethods['remain'](self,*args)
 * 
 *      def remove(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remove:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.remove", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15742
 *         return GiacMethods['remove'](self,*args)
 * 
 *      def reorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reorder:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2531reorder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2530reorder, "From Giac's documentation:\n        Help for reorder:\n        reorder(Expr, LstVar)\n        Reorders the variables in E according to the order of the 2nd argument.\n        See also: 1/  \n        Ex1:reorder(-2)\n        Ex2:reorder(x^2+2*x+y^2,[y,x])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2531reorder = {"reorder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2531reorder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2530reorder};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2531reorder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reorder (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reorder", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2530reorder(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2530reorder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reorder", 1);

  /* "giacpy/auto-methods.pxi":15752
 * 
 *         '''
 *         return GiacMethods['reorder'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def resample(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reorder); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15752, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15742
 *         return GiacMethods['remove'](self,*args)
 * 
 *      def reorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reorder:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reorder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15754
 *         return GiacMethods['reorder'](self,*args)
 * 
 *      def resample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resample:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2533resample(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2532resample, "From Giac's documentation:\n        Help for resample:\n        resample(Audio(clip),[Intg(s),[Intg(q)]])\n        Returns a copy of an audio clip resampled to the rate s (by default 44100), optionally with quality level q (from 0 to 4, by default 2).\n        See also: 1/ samplerate 2/ playsnd 3/ readwav 4/ writewav \n        Ex1:resample(readwav(\"/some/file\"),48000)\n        Ex2:resample(readwav(\"/some/file\"),48000,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2533resample = {"resample", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2533resample, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2532resample};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2533resample(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resample (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "resample", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2532resample(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2532resample(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resample", 1);

  /* "giacpy/auto-methods.pxi":15764
 * 
 *         '''
 *         return GiacMethods['resample'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def residue(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_resample); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15764, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15754
 *         return GiacMethods['reorder'](self,*args)
 * 
 *      def resample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resample:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.resample", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15766
 *         return GiacMethods['resample'](self,*args)
 * 
 *      def residue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for residue:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2535residue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2534residue, "From Giac's documentation:\n        Help for residue:\n        residue(Expr,Var(v),Cplx(a))\n        Returns the residue in a of the expression with v as variable.\n        See also: 1/ series \n        Ex1:residue(1/z,z,0)\n        Ex2:residue(5/z,z=0)\n        Ex3:residue(cos(z)/(z*(z-b)),z,0)\n        Ex4:residue(c/(z*(z-b)),z=b)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2535residue = {"residue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2535residue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2534residue};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2535residue(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("residue (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "residue", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2534residue(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2534residue(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("residue", 1);

  /* "giacpy/auto-methods.pxi":15778
 * 
 *         '''
 *         return GiacMethods['residue'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def resoudre(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_residue); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15778, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15766
 *         return GiacMethods['resample'](self,*args)
 * 
 *      def residue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for residue:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.residue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15780
 *         return GiacMethods['residue'](self,*args)
 * 
 *      def resoudre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2537resoudre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2536resoudre, "From Giac's documentation:\n        Help for resoudre:\n        resoudre(Expr,[Var])\n        Solves a (or a set of) polynomial equation.\n        See also: 1/ linsolve 2/ proot 3/ fsolve 4/ csolve 5/ nSolve \n        Ex1:resoudre(x^2-3=1)\n        Ex2:resoudre(x^3-3*y,y)\n        Ex3:resoudre([y-z=0,z-x=0,x-y=0,x-1+y+z=0],[x,y,z])\n        Ex4:resoudre([x^2-y^2=0,x^2-z^2=0],[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2537resoudre = {"resoudre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2537resoudre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2536resoudre};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2537resoudre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resoudre (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "resoudre", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2536resoudre(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2536resoudre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resoudre", 1);

  /* "giacpy/auto-methods.pxi":15792
 * 
 *         '''
 *         return GiacMethods['resoudre'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def resoudre_dans_C(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_resoudre); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15792, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15780
 *         return GiacMethods['residue'](self,*args)
 * 
 *      def resoudre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.resoudre", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15794
 *         return GiacMethods['resoudre'](self,*args)
 * 
 *      def resoudre_dans_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_dans_C:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2539resoudre_dans_C(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2538resoudre_dans_C, "From Giac's documentation:\n        Help for resoudre_dans_C:\n        resoudre_dans_C(LstEq,LstVar)\n        Returns the list of complex solutions of an equation or a matrix where the rows are \342\204\202-solutions of a system of polynomial equations.\n        See also: 1/ cZeros 2/ solve 3/ fslove \n        Ex1:resoudre_dans_C(x^4-1,x)\n        Ex2:resoudre_dans_C(x^4-y^4 and x+y=2,[x,y])\n        Ex3:resoudre_dans_C(x^4-y^4 and x+y=0 and x^2=2*x,[x,y])\n        Ex4:resoudre_dans_C(u*v-u=v and v^2=u,[u,v])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2539resoudre_dans_C = {"resoudre_dans_C", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2539resoudre_dans_C, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2538resoudre_dans_C};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2539resoudre_dans_C(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resoudre_dans_C (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "resoudre_dans_C", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2538resoudre_dans_C(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2538resoudre_dans_C(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resoudre_dans_C", 1);

  /* "giacpy/auto-methods.pxi":15806
 * 
 *         '''
 *         return GiacMethods['resoudre_dans_C'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def resoudre_systeme_lineaire(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_resoudre_dans_C); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15806, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15794
 *         return GiacMethods['resoudre'](self,*args)
 * 
 *      def resoudre_dans_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_dans_C:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.resoudre_dans_C", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15808
 *         return GiacMethods['resoudre_dans_C'](self,*args)
 * 
 *      def resoudre_systeme_lineaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_systeme_lineaire:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2541resoudre_systeme_lineaire(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2540resoudre_systeme_lineaire, "From Giac's documentation:\n        Help for resoudre_systeme_lineaire:\n        resoudre_systeme_lineaire(LstLinEq,LstVar)\n        Linear equations system solver.\n        See also: 1/ solve 2/ proot 3/ simult 4/ gaussjord 5/ pivot 6/ ref 7/ conjugate_gradient \n        Ex1:resoudre_systeme_lineaire([x+y+z=1,x-y=2,2*x-z=3],[x,y,z])\n        Ex2:resoudre_systeme_lineaire([m*x+y=a,x+m*y=b],[x,y])\n        Ex3:resoudre_systeme_lineaire([x+y-z-1,x-y+1,x-y-z-1]%2,[x,y,z])\n        Ex4:resoudre_systeme_lineaire([[3,4],[1,2]],[0,1])\n        Ex5: p,l,u:=lu([[3,4],[1,2]]); linsolve(p,l,u,[0,1]) \n        Ex6:resoudre_systeme_lineaire([2*x+y+z=1,x+y+2*z=1,x+2*y+z=4],[x,y,z])\n        Ex7:resoudre_systeme_lineaire([[2,1,1],[1,1,2],[1,2,1]],[1,1,4])\n        Ex8: p,l,u:=lu([[2,1,1],[1,1,2],[1,2,1]]);linsolve(p,l,u,[1,1,4])\n        Ex9: a:=[[100,2],[2,100]];linsolve(evalf(a),[0,1]);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2541resoudre_systeme_lineaire = {"resoudre_systeme_lineaire", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2541resoudre_systeme_lineaire, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2540resoudre_systeme_lineaire};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2541resoudre_systeme_lineaire(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resoudre_systeme_lineaire (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "resoudre_systeme_lineaire", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2540resoudre_systeme_lineaire(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2540resoudre_systeme_lineaire(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resoudre_systeme_lineaire", 1);

  /* "giacpy/auto-methods.pxi":15825
 * 
 *         '''
 *         return GiacMethods['resoudre_systeme_lineaire'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def resultant(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_resoudre_systeme_lineaire); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15825, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15808
 *         return GiacMethods['resoudre_dans_C'](self,*args)
 * 
 *      def resoudre_systeme_lineaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_systeme_lineaire:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.resoudre_systeme_lineaire", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15827
 *         return GiacMethods['resoudre_systeme_lineaire'](self,*args)
 * 
 *      def resultant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resultant:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2543resultant(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2542resultant, "From Giac's documentation:\n        Help for resultant:\n        resultant(Poly,Poly,Var)\n        Resultant of two polynomials.\n        See also: 1/ sylvester 2/ gcd \n        Ex1:resultant(x^2-1,x^3-1,x)\n        Ex2:resultant(x^3-p*x+q,3*x^2-p,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2543resultant = {"resultant", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2543resultant, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2542resultant};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2543resultant(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resultant (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "resultant", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2542resultant(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2542resultant(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resultant", 1);

  /* "giacpy/auto-methods.pxi":15837
 * 
 *         '''
 *         return GiacMethods['resultant'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reverse(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_resultant); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15837, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15827
 *         return GiacMethods['resoudre_systeme_lineaire'](self,*args)
 * 
 *      def resultant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resultant:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.resultant", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15839
 *         return GiacMethods['resultant'](self,*args)
 * 
 *      def reverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2545reverse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2544reverse, "From Giac's documentation:\n        Help for reverse:\n        reverse(Lst(L)||Audio)\n        Returns the list L in reverse order; L:=revlist(L) or L.revlist(). Also reverses audio clips.\n        Ex1:reverse([1,2,3,4])\n        Ex2: L:=[1,2,3,4];L:=revlist(L)\n        Ex3: L:=[1,2,3,4];L.revlist()\n        Ex4: L:=[1,2,3,4];L.reverse()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2545reverse = {"reverse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2545reverse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2544reverse};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2545reverse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reverse (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reverse", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2544reverse(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2544reverse(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reverse", 1);

  /* "giacpy/auto-methods.pxi":15850
 * 
 *         '''
 *         return GiacMethods['reverse'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reverse_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reverse); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15850, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15839
 *         return GiacMethods['resultant'](self,*args)
 * 
 *      def reverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reverse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15852
 *         return GiacMethods['reverse'](self,*args)
 * 
 *      def reverse_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2547reverse_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2546reverse_graph, "From Giac's documentation:\n        Help for reverse_graph:\n        reverse_graph(Graph(G))\n        Returns a copy of G in which the directions of all edges are reversed.\n        See also: 1/ digraph \n        Ex1:reverse_graph(digraph(%{[1,2],[1,3],[2,3]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2547reverse_graph = {"reverse_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2547reverse_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2546reverse_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2547reverse_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reverse_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reverse_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2546reverse_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2546reverse_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reverse_graph", 1);

  /* "giacpy/auto-methods.pxi":15861
 * 
 *         '''
 *         return GiacMethods['reverse_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def reverse_rsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reverse_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15861, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15852
 *         return GiacMethods['reverse'](self,*args)
 * 
 *      def reverse_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reverse_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15863
 *         return GiacMethods['reverse_graph'](self,*args)
 * 
 *      def reverse_rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_rsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2549reverse_rsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2548reverse_rsolve, "From Giac's documentation:\n        Help for reverse_rsolve:\n        reverse_rsolve(Vect(v))\n        If v=[v_0 ... v_(2n-1)], returns [b_n,...,b_0] such that b_n*v_{n+k}+...+b_0*v_k=0 for k=0..n-1.\n        See also: 1/ rsolve \n        Ex1:reverse_rsolve([1,-1,3,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2549reverse_rsolve = {"reverse_rsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2549reverse_rsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2548reverse_rsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2549reverse_rsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reverse_rsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "reverse_rsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2548reverse_rsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2548reverse_rsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reverse_rsolve", 1);

  /* "giacpy/auto-methods.pxi":15872
 * 
 *         '''
 *         return GiacMethods['reverse_rsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def revert(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_reverse_rsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15872, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15863
 *         return GiacMethods['reverse_graph'](self,*args)
 * 
 *      def reverse_rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_rsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.reverse_rsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15874
 *         return GiacMethods['reverse_rsolve'](self,*args)
 * 
 *      def revert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revert:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2551revert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2550revert, "From Giac's documentation:\n        Help for revert:\n        revert(Expr)\n        Returns the inverse expansion of a series expansion at 0.\n        See also: 1/ series \n        Ex1:revert(x+x^2+x^4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2551revert = {"revert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2551revert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2550revert};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2551revert(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("revert (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "revert", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2550revert(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2550revert(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("revert", 1);

  /* "giacpy/auto-methods.pxi":15883
 * 
 *         '''
 *         return GiacMethods['revert'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def revlex(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_revert); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15883, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15874
 *         return GiacMethods['reverse_rsolve'](self,*args)
 * 
 *      def revert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revert:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.revert", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15885
 *         return GiacMethods['revert'](self,*args)
 * 
 *      def revlex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlex:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2553revlex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2552revlex, "From Giac's documentation:\n        Help for revlex:\n        revlex(Opt)\n        Option of the gbasis or greduce command to specify an order for monomials (complete degree then inverse lexicographic order).\n        See also: 1/ gbasis 2/ greduce \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2553revlex = {"revlex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2553revlex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2552revlex};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2553revlex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("revlex (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "revlex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2552revlex(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2552revlex(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("revlex", 1);

  /* "giacpy/auto-methods.pxi":15893
 * 
 *         '''
 *         return GiacMethods['revlex'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def revlist(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_revlex); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15893, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15885
 *         return GiacMethods['revert'](self,*args)
 * 
 *      def revlex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlex:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.revlex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15895
 *         return GiacMethods['revlex'](self,*args)
 * 
 *      def revlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlist:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2555revlist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2554revlist, "From Giac's documentation:\n        Help for revlist:\n        revlist(Lst(L)||Audio)\n        Returns the list L in reverse order; L:=revlist(L) or L.revlist(). Also reverses audio clips.\n        Ex1:revlist([1,2,3,4])\n        Ex2: L:=[1,2,3,4];L:=revlist(L)\n        Ex3: L:=[1,2,3,4];L.revlist()\n        Ex4: L:=[1,2,3,4];L.reverse()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2555revlist = {"revlist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2555revlist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2554revlist};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2555revlist(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("revlist (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "revlist", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2554revlist(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2554revlist(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("revlist", 1);

  /* "giacpy/auto-methods.pxi":15906
 * 
 *         '''
 *         return GiacMethods['revlist'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rgb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_revlist); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15906, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15895
 *         return GiacMethods['revlex'](self,*args)
 * 
 *      def revlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlist:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.revlist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15908
 *         return GiacMethods['revlist'](self,*args)
 * 
 *      def rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2557rgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2556rgb, "From Giac's documentation:\n        Help for rgb:\n        rgb(Lst(r,g,b)||Intg(rrggbb)||Str(rrggbb)||Color(c))\n        Convert a RGB triple [r,g,b] or a hexadecimal integer or string rrggbb into xcas color or return RGB specification of xcas color c.\n        See also: 1/ hsv 2/ rgb2hsv 3/ hsv2rgb \n        Ex1:rgb(0x00ff00)\n        Ex2:rgb(red)\n        Ex3:rgb(255,0,255)\n        Ex4: redcolor:=rgb(0.99,0,0);display(square(0,2+i),filled+redcolor)\n        Ex5: greencolor:=rgb(0,0.99,0);display(square(0,2+i),filled+greencolor)\n        Ex6: bluecolor:=rgb(0,0,0.99);display(square(0,2+i),filled+bluecolor)\n        Ex7: greycolor:=rgb(0.5,0.5,0.5);display(square(0,2+i),filled+greycolor)\n        Ex8: F:=display(square(0,2+i),filled+rgb(rand(),rand(),rand()))\n        Ex9: L:=rand(),rand(),rand();affichage(square(0,2+i),rgb(L)+rempli);legend(0.2,[L])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2557rgb = {"rgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2557rgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2556rgb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2557rgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rgb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rgb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2556rgb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2556rgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rgb", 1);

  /* "giacpy/auto-methods.pxi":15925
 * 
 *         '''
 *         return GiacMethods['rgb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rgb2hsv(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rgb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15925, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15908
 *         return GiacMethods['revlist'](self,*args)
 * 
 *      def rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rgb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15927
 *         return GiacMethods['rgb'](self,*args)
 * 
 *      def rgb2hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2hsv:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2559rgb2hsv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2558rgb2hsv, "From Giac's documentation:\n        Help for rgb2hsv:\n        rgb2hsv(Lst(r,g,b))\n        Convert RGB to HSV.\n        See also: 1/ hsv2rgb 2/ rgb 3/ hsv \n        Ex1:rgb2hsv(32,64,126)\n        Ex2:rgb2hsv([0.3,0.2,0.1])\n        Ex3:rgb2hsv(0.3,0.2,0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2559rgb2hsv = {"rgb2hsv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2559rgb2hsv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2558rgb2hsv};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2559rgb2hsv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rgb2hsv (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rgb2hsv", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2558rgb2hsv(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2558rgb2hsv(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rgb2hsv", 1);

  /* "giacpy/auto-methods.pxi":15938
 * 
 *         '''
 *         return GiacMethods['rgb2hsv'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rgb2xyz(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rgb2hsv); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15938, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15927
 *         return GiacMethods['rgb'](self,*args)
 * 
 *      def rgb2hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2hsv:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rgb2hsv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15940
 *         return GiacMethods['rgb2hsv'](self,*args)
 * 
 *      def rgb2xyz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2xyz:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2561rgb2xyz(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2560rgb2xyz, "From Giac's documentation:\n        Help for rgb2xyz:\n        rgb2xyz(Lst(r,g,b)||Color(c))\n        Convert RGB to XYZ.\n        See also: 1/ xyz2rgb 2/ rgb 3/ interp \n        Ex1:rgb2xyz(teal)\n        Ex2:rgb2xyz([0,255,255])\n        Ex3:rgb2xyz(0.7,0.8,0.9)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2561rgb2xyz = {"rgb2xyz", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2561rgb2xyz, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2560rgb2xyz};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2561rgb2xyz(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rgb2xyz (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rgb2xyz", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2560rgb2xyz(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2560rgb2xyz(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rgb2xyz", 1);

  /* "giacpy/auto-methods.pxi":15951
 * 
 *         '''
 *         return GiacMethods['rgb2xyz'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rhombus(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rgb2xyz); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15951, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15940
 *         return GiacMethods['rgb2hsv'](self,*args)
 * 
 *      def rgb2xyz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2xyz:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rgb2xyz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15953
 *         return GiacMethods['rgb2xyz'](self,*args)
 * 
 *      def rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2563rhombus(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2562rhombus, "From Giac's documentation:\n        Help for rhombus:\n        rhombus(Pnt(A)||Cplx,Pnt(B)||Cplx,Angle(a)||Pnt(P)||Lst(P,a)),[Var(C)],[Var(D)])\n        Returns and draws the rhombus ABCD such that the angle (AB,AD)=a (or in the plane ABP angle(AB,AD)=angle(AB,AP) or such that angle(AB,AD)=a).\n        See also: 1/ square 2/ quadrilateral \n        Ex1:rhombus(i,1+i,pi/4)\n        Ex2:rhombus(i,1+i,pi/4,C,D)\n        Ex3:rhombus(point(0,0,0),point(3,3,3),[point(0,0,3),pi/4])\n        Ex4:rhombus(point(0,0,0),point(3,3,3),point(0,0,3),C,D)\n        Ex5:rhombus(point(0,0,0),point(3,3,3),[point(0,0,3),pi/4],C,D)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2563rhombus = {"rhombus", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2563rhombus, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2562rhombus};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2563rhombus(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rhombus (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rhombus", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2562rhombus(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2562rhombus(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rhombus", 1);

  /* "giacpy/auto-methods.pxi":15966
 * 
 *         '''
 *         return GiacMethods['rhombus'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rhombus_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rhombus); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15966, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15953
 *         return GiacMethods['rgb2xyz'](self,*args)
 * 
 *      def rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rhombus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15968
 *         return GiacMethods['rhombus'](self,*args)
 * 
 *      def rhombus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2565rhombus_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2564rhombus_point, "From Giac's documentation:\n        Help for rhombus_point:\n        rhombus_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2565rhombus_point = {"rhombus_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2565rhombus_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2564rhombus_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2565rhombus_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rhombus_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rhombus_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2564rhombus_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2564rhombus_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rhombus_point", 1);

  /* "giacpy/auto-methods.pxi":15978
 * 
 *         '''
 *         return GiacMethods['rhombus_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rhs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rhombus_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15978, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15968
 *         return GiacMethods['rhombus'](self,*args)
 * 
 *      def rhombus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rhombus_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15980
 *         return GiacMethods['rhombus_point'](self,*args)
 * 
 *      def rhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2567rhs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2566rhs, "From Giac's documentation:\n        Help for rhs:\n        rhs(Equal(a=b) or Interval(a..b) or Str,Intg)\n        Returns the right part of an equality, of an interval, of a list or of a string.\n        See also: 1/ left 2/ mid 3/ tail 4/ head \n        Ex1:rhs(a=b)\n        Ex2:rhs(x^2+1=5)\n        Ex3:rhs(1..5)\n        Ex4:rhs(\"abcdefg\",3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2567rhs = {"rhs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2567rhs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2566rhs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2567rhs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rhs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rhs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2566rhs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2566rhs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rhs", 1);

  /* "giacpy/auto-methods.pxi":15992
 * 
 *         '''
 *         return GiacMethods['rhs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def riemann_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rhs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 15992, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15980
 *         return GiacMethods['rhombus_point'](self,*args)
 * 
 *      def rhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rhs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":15994
 *         return GiacMethods['rhs'](self,*args)
 * 
 *      def riemann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for riemann_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2569riemann_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2568riemann_window, "From Giac's documentation:\n        Help for riemann_window:\n        riemann_window(Lst,[Interval(n1..n2)])\n        Applies the Riemann windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ bartlett_hann_window 12/ triangle_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(riemann_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2569riemann_window = {"riemann_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2569riemann_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2568riemann_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2569riemann_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("riemann_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "riemann_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2568riemann_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2568riemann_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("riemann_window", 1);

  /* "giacpy/auto-methods.pxi":16003
 * 
 *         '''
 *         return GiacMethods['riemann_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def right(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_riemann_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16003, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":15994
 *         return GiacMethods['rhs'](self,*args)
 * 
 *      def riemann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for riemann_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.riemann_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16005
 *         return GiacMethods['riemann_window'](self,*args)
 * 
 *      def right(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2571right(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2570right, "From Giac's documentation:\n        Help for right:\n        right(Equal(a=b) or Interval(a..b) or Str,Intg)\n        Returns the right part of an equality, of an interval, of a list or of a string.\n        See also: 1/ left 2/ mid 3/ tail 4/ head \n        Ex1:right(a=b)\n        Ex2:right(x^2+1=5)\n        Ex3:right(1..5)\n        Ex4:right(\"abcdefg\",3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2571right = {"right", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2571right, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2570right};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2571right(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("right (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "right", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2570right(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2570right(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("right", 1);

  /* "giacpy/auto-methods.pxi":16017
 * 
 *         '''
 *         return GiacMethods['right'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def right_rectangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_right); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16017, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16005
 *         return GiacMethods['riemann_window'](self,*args)
 * 
 *      def right(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.right", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16019
 *         return GiacMethods['right'](self,*args)
 * 
 *      def right_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_rectangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2573right_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2572right_rectangle, "From Giac's documentation:\n        Help for right_rectangle:\n        right_rectangle(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2573right_rectangle = {"right_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2573right_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2572right_rectangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2573right_rectangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("right_rectangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "right_rectangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2572right_rectangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2572right_rectangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("right_rectangle", 1);

  /* "giacpy/auto-methods.pxi":16033
 * 
 *         '''
 *         return GiacMethods['right_rectangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def right_triangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_right_rectangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16033, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16019
 *         return GiacMethods['right'](self,*args)
 * 
 *      def right_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_rectangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.right_rectangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16035
 *         return GiacMethods['right_rectangle'](self,*args)
 * 
 *      def right_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_triangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2575right_triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2574right_triangle, "From Giac's documentation:\n        Help for right_triangle:\n        right_triangle((Pnt(A) or Cplx),(Pnt(B) or Cplx),(Real(k) or Pnt(P) or Lst(P,k)),[Var(C)])\n        Draws the A_rectangular triangle ABC with AC=k*AB (or in the plane ABP AC=AP or AC=k*AB).\n        See also: 1/ triangle \n        Ex1:right_triangle(1,i,tan(pi/3))\n        Ex2:right_triangle(1,i,1/2,C)\n        Ex3:right_triangle(point(0,0,0),point(3,3,3),point(0,0,3))\n        Ex4:right_triangle(point(0,0,0),point(3,3,3),[point(0,0,3),1/2],C)\n        Ex5:right_triangle(point(0,0,0),point(3,3,3),[point(0,0,3),1/2],C)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2575right_triangle = {"right_triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2575right_triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2574right_triangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2575right_triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("right_triangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "right_triangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2574right_triangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2574right_triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("right_triangle", 1);

  /* "giacpy/auto-methods.pxi":16048
 * 
 *         '''
 *         return GiacMethods['right_triangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def risch(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_right_triangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16048, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16035
 *         return GiacMethods['right_rectangle'](self,*args)
 * 
 *      def right_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_triangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.right_triangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16050
 *         return GiacMethods['right_triangle'](self,*args)
 * 
 *      def risch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for risch:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2577risch(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2576risch, "From Giac's documentation:\n        Help for risch:\n        risch(Expr,[Var])\n        Returns a primitive of the expression calculated with the Risch algorithm.\n        See also: 1/ int \n        Ex1:risch(ln(x),x)\n        Ex2:risch(ln(x))\n        Ex3:risch(exp(x^2),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2577risch = {"risch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2577risch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2576risch};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2577risch(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("risch (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "risch", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2576risch(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2576risch(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("risch", 1);

  /* "giacpy/auto-methods.pxi":16061
 * 
 *         '''
 *         return GiacMethods['risch'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rm_a_z(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_risch); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16061, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16050
 *         return GiacMethods['right_triangle'](self,*args)
 * 
 *      def risch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for risch:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.risch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16063
 *         return GiacMethods['risch'](self,*args)
 * 
 *      def rm_a_z(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_a_z:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2579rm_a_z(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2578rm_a_z, "From Giac's documentation:\n        Help for rm_a_z:\n        rm_a_z(NULL)\n        Erases all the variable name made up of only one lowercase a..z character.\n        See also: 1/ rm_all_vars \n        Ex1:rm_a_z()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2579rm_a_z = {"rm_a_z", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2579rm_a_z, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2578rm_a_z};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2579rm_a_z(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rm_a_z (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rm_a_z", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2578rm_a_z(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2578rm_a_z(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rm_a_z", 1);

  /* "giacpy/auto-methods.pxi":16072
 * 
 *         '''
 *         return GiacMethods['rm_a_z'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rm_all_vars(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rm_a_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16072, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16063
 *         return GiacMethods['risch'](self,*args)
 * 
 *      def rm_a_z(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_a_z:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rm_a_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16074
 *         return GiacMethods['rm_a_z'](self,*args)
 * 
 *      def rm_all_vars(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_all_vars:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2581rm_all_vars(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2580rm_all_vars, "From Giac's documentation:\n        Help for rm_all_vars:\n        rm_all_vars(NULL)\n        Erases all the variable names.\n        See also: 1/ rm_a_z \n        Ex1:rm_all_vars()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2581rm_all_vars = {"rm_all_vars", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2581rm_all_vars, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2580rm_all_vars};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2581rm_all_vars(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rm_all_vars (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rm_all_vars", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2580rm_all_vars(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2580rm_all_vars(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rm_all_vars", 1);

  /* "giacpy/auto-methods.pxi":16083
 * 
 *         '''
 *         return GiacMethods['rm_all_vars'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rmbreakpoint(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rm_all_vars); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16083, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16074
 *         return GiacMethods['rm_a_z'](self,*args)
 * 
 *      def rm_all_vars(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_all_vars:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rm_all_vars", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16085
 *         return GiacMethods['rm_all_vars'](self,*args)
 * 
 *      def rmbreakpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmbreakpoint:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2583rmbreakpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2582rmbreakpoint, "From Giac's documentation:\n        Help for rmbreakpoint:\n        rmbreakpoint(Intg)\n        Removes a breakpoint.\n        See also: 1/ breakpoint \n        Ex1:rmbreakpoint(1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2583rmbreakpoint = {"rmbreakpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2583rmbreakpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2582rmbreakpoint};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2583rmbreakpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rmbreakpoint (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rmbreakpoint", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2582rmbreakpoint(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2582rmbreakpoint(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rmbreakpoint", 1);

  /* "giacpy/auto-methods.pxi":16094
 * 
 *         '''
 *         return GiacMethods['rmbreakpoint'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rmmod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rmbreakpoint); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16094, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16085
 *         return GiacMethods['rm_all_vars'](self,*args)
 * 
 *      def rmbreakpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmbreakpoint:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rmbreakpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16096
 *         return GiacMethods['rmbreakpoint'](self,*args)
 * 
 *      def rmmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmmod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2585rmmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2584rmmod, "From Giac's documentation:\n        Help for rmmod:\n        rmmod(Str(pwd))\n        Removes the installed dynamic libraries.\n        See also: 1/ lsmod 2/ insmod \n        Ex1:rmmod(\"/home/parisse/giac/src/libprogfr.so\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2585rmmod = {"rmmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2585rmmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2584rmmod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2585rmmod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rmmod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rmmod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2584rmmod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2584rmmod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rmmod", 1);

  /* "giacpy/auto-methods.pxi":16105
 * 
 *         '''
 *         return GiacMethods['rmmod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rms(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rmmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16105, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16096
 *         return GiacMethods['rmbreakpoint'](self,*args)
 * 
 *      def rmmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmmod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rmmod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16107
 *         return GiacMethods['rmmod'](self,*args)
 * 
 *      def rms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rms:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2587rms(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2586rms, "From Giac's documentation:\n        Help for rms:\n        rms(Lst(X))\n        Returns the root mean square of X.\n        See also: 1/ mean \n        Ex1:rms([1,2,5,8,3,6,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2587rms = {"rms", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2587rms, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2586rms};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2587rms(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rms (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rms", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2586rms(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2586rms(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rms", 1);

  /* "giacpy/auto-methods.pxi":16116
 * 
 *         '''
 *         return GiacMethods['rms'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rmwatch(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rms); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16116, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16107
 *         return GiacMethods['rmmod'](self,*args)
 * 
 *      def rms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rms:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rms", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16118
 *         return GiacMethods['rms'](self,*args)
 * 
 *      def rmwatch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmwatch:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2589rmwatch(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2588rmwatch, "From Giac's documentation:\n        Help for rmwatch:\n        rmwatch(Var)\n        Clears a variables from the table of displayed variables in step/step.\n        See also: 1/ watch \n        Ex1:rmwatch(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2589rmwatch = {"rmwatch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2589rmwatch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2588rmwatch};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2589rmwatch(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rmwatch (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rmwatch", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2588rmwatch(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2588rmwatch(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rmwatch", 1);

  /* "giacpy/auto-methods.pxi":16127
 * 
 *         '''
 *         return GiacMethods['rmwatch'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def romberg(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rmwatch); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16127, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16118
 *         return GiacMethods['rms'](self,*args)
 * 
 *      def rmwatch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmwatch:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rmwatch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16129
 *         return GiacMethods['rmwatch'](self,*args)
 * 
 *      def romberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for romberg:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2591romberg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2590romberg, "From Giac's documentation:\n        Help for romberg:\n        romberg(Expr(f(x)),Var(x),Real(a),Real(b))\n        Returns the approximate value of integrate(f(x),x,a,b) by Romberg's method.\n        See also: 1/ integrate 2/ gaussquad \n        Ex1:romberg(exp(x^2),x,0,1)\n        Ex2:romberg(x^2,x,0,1)\n        Ex3:romberg(exp(-x^2),x,-1,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2591romberg = {"romberg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2591romberg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2590romberg};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2591romberg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("romberg (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "romberg", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2590romberg(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2590romberg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("romberg", 1);

  /* "giacpy/auto-methods.pxi":16140
 * 
 *         '''
 *         return GiacMethods['romberg'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rombergm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_romberg); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16140, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16129
 *         return GiacMethods['rmwatch'](self,*args)
 * 
 *      def romberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for romberg:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.romberg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16142
 *         return GiacMethods['romberg'](self,*args)
 * 
 *      def rombergm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2593rombergm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2592rombergm, "From Giac's documentation:\n        Help for rombergm:\n        rombergm(Opt)\n        Option of the area command.\n        See also: 1/ area \n        Ex1: area(x^2,x=0..1,5,simpson)\n        Ex2: area(x^2,x=0..1,5,rombergt)\n        Ex3: area(x^2,x=0..1,5,rombergm)\n        Ex4:rombergm(area(x^2,x=0..1,5,gauss15))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2593rombergm = {"rombergm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2593rombergm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2592rombergm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2593rombergm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rombergm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rombergm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2592rombergm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2592rombergm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rombergm", 1);

  /* "giacpy/auto-methods.pxi":16154
 * 
 *         '''
 *         return GiacMethods['rombergm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rombergt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rombergm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16154, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16142
 *         return GiacMethods['romberg'](self,*args)
 * 
 *      def rombergm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rombergm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16156
 *         return GiacMethods['rombergm'](self,*args)
 * 
 *      def rombergt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2595rombergt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2594rombergt, "From Giac's documentation:\n        Help for rombergt:\n        rombergt(Opt)\n        Option of the area command.\n        See also: 1/ area \n        Ex1: area(x^2,x=0..1,5,simpson)\n        Ex2: area(x^2,x=0..1,5,rombergt)\n        Ex3: area(x^2,x=0..1,5,rombergm)\n        Ex4:rombergt(area(x^2,x=0..1,5,gauss15))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2595rombergt = {"rombergt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2595rombergt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2594rombergt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2595rombergt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rombergt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rombergt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2594rombergt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2594rombergt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rombergt", 1);

  /* "giacpy/auto-methods.pxi":16168
 * 
 *         '''
 *         return GiacMethods['rombergt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rond(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rombergt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16168, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16156
 *         return GiacMethods['rombergm'](self,*args)
 * 
 *      def rombergt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rombergt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16170
 *         return GiacMethods['rombergt'](self,*args)
 * 
 *      def rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rond:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2597rond(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2596rond, "From Giac's documentation:\n        Help for rond:\n        rond(Real(r),[Real(a)],[Real(b)])\n        Draws a circle (resp a arc) with radius r (resp and with angle (0,a) or (a,b)), tangent at the turtle position.\n        See also: 1/ disque \n        Ex1: rond 30\n        Ex2:rond(40)\n        Ex3:rond(40,90)\n        Ex4:rond(40,10,100)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2597rond = {"rond", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2597rond, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2596rond};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2597rond(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rond (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rond", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2596rond(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2596rond(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rond", 1);

  /* "giacpy/auto-methods.pxi":16182
 * 
 *         '''
 *         return GiacMethods['rond'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def root(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rond); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16182, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16170
 *         return GiacMethods['rombergt'](self,*args)
 * 
 *      def rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rond:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rond", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16184
 *         return GiacMethods['rond'](self,*args)
 * 
 *      def root(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for root:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2599root(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2598root, "From Giac's documentation:\n        Help for root:\n        root(Expr(a),Expr(b))\n        Returns b^(1/a) (root(2,3)=sqrt(3)).\n        See also: 1/  \n        Ex1:root(3,2)\n        Ex2:root(1/3,2)\n        Ex3:root(3,1.2)\n        Ex4:root(3.2,1.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2599root = {"root", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2599root, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2598root};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2599root(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("root (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "root", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2598root(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2598root(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("root", 1);

  /* "giacpy/auto-methods.pxi":16196
 * 
 *         '''
 *         return GiacMethods['root'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rootof(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16196, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16184
 *         return GiacMethods['rond'](self,*args)
 * 
 *      def root(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for root:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.root", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16198
 *         return GiacMethods['root'](self,*args)
 * 
 *      def rootof(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rootof:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2601rootof(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2600rootof, "From Giac's documentation:\n        Help for rootof:\n        rootof(LstPoly(P),LstPoly(Q))\n        Polynomial in terms of a root of an irreducible polynomial on Q. Returns P(a) with a the greatest root of Q.\n        See also: 1/  \n        Ex1: normal(1/rootof([1,0],[1,0,10,0,1]))\n        Ex2: normal(1/rootof([1,0,0],[1,1,0,-1]))\n        Ex3: rootof(x^4+x+1):='j'; normal(j^5); \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2601rootof = {"rootof", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2601rootof, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2600rootof};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2601rootof(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rootof (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rootof", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2600rootof(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2600rootof(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootof", 1);

  /* "giacpy/auto-methods.pxi":16209
 * 
 *         '''
 *         return GiacMethods['rootof'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def roots(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rootof); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16209, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16198
 *         return GiacMethods['root'](self,*args)
 * 
 *      def rootof(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rootof:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rootof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16211
 *         return GiacMethods['rootof'](self,*args)
 * 
 *      def roots(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for roots:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2603roots(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2602roots, "From Giac's documentation:\n        Help for roots:\n        roots(Poly,[Var])\n        Returns a matrix having 2 columns and where the rows are the roots of the polynomial with their multiplicity (for 1 variable).\n        See also: 1/ proot 2/ cZeros \n        Ex1:roots(t^3-1,t)\n        Ex2:roots(x^5-2*x^4+x^3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2603roots = {"roots", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2603roots, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2602roots};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2603roots(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("roots (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "roots", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2602roots(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2602roots(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("roots", 1);

  /* "giacpy/auto-methods.pxi":16221
 * 
 *         '''
 *         return GiacMethods['roots'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rotate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_roots); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16221, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16211
 *         return GiacMethods['rootof'](self,*args)
 * 
 *      def roots(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for roots:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.roots", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16223
 *         return GiacMethods['roots'](self,*args)
 * 
 *      def rotate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2605rotate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2604rotate, "From Giac's documentation:\n        Help for rotate:\n        rotate(Lst||Str(L),[Intg(n)])\n        Returns the list where the last element [or the tail beginning with the n-th element] is moved to the first element (by default n=-1);L:=rotate(L,n) or L.rotate(n).\n        See also: 1/ tail 2/ mid 3/ shift \n        Ex1:rotate([0,1,2,3],2)\n        Ex2:rotate([[1,2,3],[4,5,6],[7,8,9]])\n        Ex3:rotate([0,1,2,3,4])\n        Ex4:rotate([0,1,2,3,4],-1)\n        Ex5: L:=[0,1,2,3,4];L:=rotate([0,1,2,3,4])\n        Ex6: L:=[0,1,2,3,4];L.rotate()\n        Ex7: L:=[0,1,2,3];L:=rotate([0,1,2,3],2)\n        Ex8: L:=[0,1,2,3];L.rotate(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2605rotate = {"rotate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2605rotate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2604rotate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2605rotate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rotate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rotate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2604rotate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2604rotate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rotate", 1);

  /* "giacpy/auto-methods.pxi":16239
 * 
 *         '''
 *         return GiacMethods['rotate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rotation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rotate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16239, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16223
 *         return GiacMethods['roots'](self,*args)
 * 
 *      def rotate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rotate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16241
 *         return GiacMethods['rotate'](self,*args)
 * 
 *      def rotation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2607rotation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2606rotation, "From Giac's documentation:\n        Help for rotation:\n        rotation((Pnt(B) or Cplx or Dr3),Angle(a1),(Pnt(A) or Curve))\n        rotation(B,a1,A) (resp rotation(d,a1,A)) is the transformation of A by rotation with center B (resp of axis d) and angle a1.\n        See also: 1/ translation 2/ reflection \n        Ex1:rotation(point(1+i),pi/2,point(i))\n        Ex2:rotation(1+i,pi/3,line(i,1))\n        Ex3:rotation(line(x=y,y=z),pi/2,point(1,-1,2))\n        Ex4: r:=rotation(1+i,pi/2);r(i)\n        Ex5: r:=rotation(line(x=y,y=z),pi/2);r(point(1,-1,2))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2607rotation = {"rotation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2607rotation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2606rotation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2607rotation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rotation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rotation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2606rotation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2606rotation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rotation", 1);

  /* "giacpy/auto-methods.pxi":16254
 * 
 *         '''
 *         return GiacMethods['rotation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def round(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rotation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16254, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16241
 *         return GiacMethods['rotate'](self,*args)
 * 
 *      def rotation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rotation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16256
 *         return GiacMethods['rotation'](self,*args)
 * 
 *      def round(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for round:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2609round(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2608round, "From Giac's documentation:\n        Help for round:\n        round(Real or Cplx,[Intg(n)])\n        Rounds the real or complex to the nearest integer (resp the nearest decimal number) or to the nearest element of \342\204\244[i], (resp with n decimals).\n        See also: 1/ floor 2/ ceil \n        Ex1:round(2.5)\n        Ex2:round(-2.4)\n        Ex3:round(-2.5+i*2.4)\n        Ex4:round(1.237,2)\n        Ex5:round(sqrt(2)+i*sqrt(5),4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2609round = {"round", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2609round, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2608round};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2609round(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("round (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "round", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2608round(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2608round(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("round", 1);

  /* "giacpy/auto-methods.pxi":16269
 * 
 *         '''
 *         return GiacMethods['round'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def row(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_round); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16269, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16256
 *         return GiacMethods['rotation'](self,*args)
 * 
 *      def round(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for round:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.round", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16271
 *         return GiacMethods['round'](self,*args)
 * 
 *      def row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for row:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2611row(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2610row, "From Giac's documentation:\n        Help for row:\n        row(Mtrx(A),Intg(n)||Interval(n1..n2))\n        Returns row n or the sequence of the rows n1..n2 of the matrix A, or optional argument of count,count_eq,count_inf,count_sup.\n        See also: 1/ col 2/ count 3/ count_eq 4/ count_inf 5/ count_sup \n        Ex1:row([[1,2,3],[4,5,6],[7,8,9]],1)\n        Ex2:row([[1,2,3],[4,5,6],[7,8,9]],0..1)\n        Ex3: count_eq(3,[[1,2,3],[4,3,2],[3,2,1]],row)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2611row = {"row", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2611row, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2610row};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2611row(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("row (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "row", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2610row(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2610row(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("row", 1);

  /* "giacpy/auto-methods.pxi":16282
 * 
 *         '''
 *         return GiacMethods['row'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowAdd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_row); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16282, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16271
 *         return GiacMethods['round'](self,*args)
 * 
 *      def row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for row:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.row", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16284
 *         return GiacMethods['row'](self,*args)
 * 
 *      def rowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowAdd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2613rowAdd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2612rowAdd, "From Giac's documentation:\n        Help for rowAdd:\n        rowAdd(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by replacing the n2-th row by the sum of the n1-th and n2-th rows.\n        See also: 1/ rowSwap \n        Ex1:rowAdd([[1,2],[3,4],[5,6]],1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2613rowAdd = {"rowAdd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2613rowAdd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2612rowAdd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2613rowAdd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowAdd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowAdd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2612rowAdd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2612rowAdd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowAdd", 1);

  /* "giacpy/auto-methods.pxi":16293
 * 
 *         '''
 *         return GiacMethods['rowAdd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowDim(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowAdd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16293, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16284
 *         return GiacMethods['row'](self,*args)
 * 
 *      def rowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowAdd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowAdd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16295
 *         return GiacMethods['rowAdd'](self,*args)
 * 
 *      def rowDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowDim:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2615rowDim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2614rowDim, "From Giac's documentation:\n        Help for rowDim:\n        rowDim(Mtrx)\n        Number of rows of a matrix.\n        See also: 1/ ncols \n        Ex1:rowDim([[1,2,3],[4,5,6]])\n        Ex2:rowDim([[1,2],[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2615rowDim = {"rowDim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2615rowDim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2614rowDim};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2615rowDim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowDim (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowDim", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2614rowDim(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2614rowDim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowDim", 1);

  /* "giacpy/auto-methods.pxi":16305
 * 
 *         '''
 *         return GiacMethods['rowDim'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowNorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowDim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16305, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16295
 *         return GiacMethods['rowAdd'](self,*args)
 * 
 *      def rowDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowDim:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowDim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16307
 *         return GiacMethods['rowDim'](self,*args)
 * 
 *      def rowNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowNorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2617rowNorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2616rowNorm, "From Giac's documentation:\n        Help for rowNorm:\n        rowNorm(Vect or Mtrx)\n        Returns the max of the l1_norm of the rows of a matrix: rowNorm(a_{j,k})=max_j(sum_k(|a_{j,k}|)).\n        See also: 1/ norm \n        Ex1:rowNorm([[1,2],[3,-4]])\n        Ex2:rowNorm([[1,2,3,-4],[-5,3,2,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2617rowNorm = {"rowNorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2617rowNorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2616rowNorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2617rowNorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowNorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowNorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2616rowNorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2616rowNorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowNorm", 1);

  /* "giacpy/auto-methods.pxi":16317
 * 
 *         '''
 *         return GiacMethods['rowNorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowSwap(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowNorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16317, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16307
 *         return GiacMethods['rowDim'](self,*args)
 * 
 *      def rowNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowNorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowNorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16319
 *         return GiacMethods['rowNorm'](self,*args)
 * 
 *      def rowSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowSwap:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2619rowSwap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2618rowSwap, "From Giac's documentation:\n        Help for rowSwap:\n        rowSwap(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by swapping the n1-th row and the n2-th row.\n        See also: 1/ rowAdd 2/ colSwap \n        Ex1:rowSwap([[1,2],[3,4],[5,6]],1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2619rowSwap = {"rowSwap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2619rowSwap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2618rowSwap};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2619rowSwap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowSwap (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowSwap", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2618rowSwap(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2618rowSwap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowSwap", 1);

  /* "giacpy/auto-methods.pxi":16328
 * 
 *         '''
 *         return GiacMethods['rowSwap'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowdim(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowSwap); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16328, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16319
 *         return GiacMethods['rowNorm'](self,*args)
 * 
 *      def rowSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowSwap:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowSwap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16330
 *         return GiacMethods['rowSwap'](self,*args)
 * 
 *      def rowdim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowdim:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2621rowdim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2620rowdim, "From Giac's documentation:\n        Help for rowdim:\n        rowdim(Mtrx)\n        Number of rows of a matrix.\n        See also: 1/ ncols \n        Ex1:rowdim([[1,2,3],[4,5,6]])\n        Ex2:rowdim([[1,2],[3,4],[5,6]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2621rowdim = {"rowdim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2621rowdim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2620rowdim};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2621rowdim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowdim (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowdim", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2620rowdim(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2620rowdim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowdim", 1);

  /* "giacpy/auto-methods.pxi":16340
 * 
 *         '''
 *         return GiacMethods['rowdim'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rownorm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowdim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16340, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16330
 *         return GiacMethods['rowSwap'](self,*args)
 * 
 *      def rowdim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowdim:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowdim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16342
 *         return GiacMethods['rowdim'](self,*args)
 * 
 *      def rownorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rownorm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2623rownorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2622rownorm, "From Giac's documentation:\n        Help for rownorm:\n        rownorm(Vect or Mtrx)\n        Returns the max of the l1_norm of the rows of a matrix: rowNorm(a_{j,k})=max_j(sum_k(|a_{j,k}|)).\n        See also: 1/ norm \n        Ex1:rownorm([[1,2],[3,-4]])\n        Ex2:rownorm([[1,2,3,-4],[-5,3,2,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2623rownorm = {"rownorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2623rownorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2622rownorm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2623rownorm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rownorm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rownorm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2622rownorm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2622rownorm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rownorm", 1);

  /* "giacpy/auto-methods.pxi":16352
 * 
 *         '''
 *         return GiacMethods['rownorm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowspace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rownorm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16352, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16342
 *         return GiacMethods['rowdim'](self,*args)
 * 
 *      def rownorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rownorm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rownorm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16354
 *         return GiacMethods['rownorm'](self,*args)
 * 
 *      def rowspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowspace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2625rowspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2624rowspace, "From Giac's documentation:\n        Help for rowspace:\n        rowspace(Mtrx(A), [Var(d)])\n        Returns a matrix where the rows are a basis of the vector space generated by the rows of the matrix A [d is the dimension of this space].\n        See also: 1/ colspace \n        Ex1:rowspace([[1,2,3],[1,2,3],[1,2,4],[1,2,5]])\n        Ex2:rowspace([[1,2,3],[1,3,6],[2,5,9]],d)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2625rowspace = {"rowspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2625rowspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2624rowspace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2625rowspace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowspace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowspace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2624rowspace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2624rowspace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowspace", 1);

  /* "giacpy/auto-methods.pxi":16364
 * 
 *         '''
 *         return GiacMethods['rowspace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rowswap(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowspace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16364, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16354
 *         return GiacMethods['rownorm'](self,*args)
 * 
 *      def rowspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowspace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowspace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16366
 *         return GiacMethods['rowspace'](self,*args)
 * 
 *      def rowswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowswap:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2627rowswap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2626rowswap, "From Giac's documentation:\n        Help for rowswap:\n        rowswap(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by swapping the n1-th row and the n2-th row.\n        See also: 1/ rowAdd 2/ colSwap \n        Ex1:rowswap([[1,2],[3,4],[5,6]],1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2627rowswap = {"rowswap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2627rowswap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2626rowswap};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2627rowswap(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rowswap (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rowswap", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2626rowswap(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2626rowswap(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rowswap", 1);

  /* "giacpy/auto-methods.pxi":16375
 * 
 *         '''
 *         return GiacMethods['rowswap'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rref(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rowswap); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16375, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16366
 *         return GiacMethods['rowspace'](self,*args)
 * 
 *      def rowswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowswap:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rowswap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16377
 *         return GiacMethods['rowswap'](self,*args)
 * 
 *      def rref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rref:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2629rref(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2628rref, "From Giac's documentation:\n        Help for rref:\n        rref(Mtrx(M),[Intg(k)]||Opt)\n        Row reduction to echelon form of AX=b (M=A|(-b)) [Reduction on columns 0..k-1].\n        See also: 1/ ker 2/ image 3/ det 4/ Rref 5/ pivot 6/ ref 7/ keep_pivot \n        Ex1:rref([[3,1,-2],[3,2,2]])\n        Ex2:rref([[2,1,1,-1],[1,1,2,-1],[1,2,1,-4]])\n        Ex3:rref([[2,1,1,-1],[1,1,2,-1],[1,2,1,-4]],2)\n        Ex4:rref([[1,1,0,0,-a1],[0,1,1,0,-a2],[0,0,1,1,-a3],[1,0,0,1,-a4]],keep_pivot)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2629rref = {"rref", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2629rref, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2628rref};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2629rref(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rref (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rref", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2628rref(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2628rref(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rref", 1);

  /* "giacpy/auto-methods.pxi":16389
 * 
 *         '''
 *         return GiacMethods['rref'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rref); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16389, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16377
 *         return GiacMethods['rowswap'](self,*args)
 * 
 *      def rref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rref:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16391
 *         return GiacMethods['rref'](self,*args)
 * 
 *      def rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2631rsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2630rsolve, "From Giac's documentation:\n        Help for rsolve:\n        rsolve((Expr or LstExpr),(Var or LstVar),(InitVal or LstInitVal))\n        Gives the value of a recurrent sequence or of a system of recurrent sequences.\n        See also: 1/ seqsolve 2/ plotseq 3/ tableseq 4/ reverse_rsolve \n        Ex1:rsolve(u(n+1)=2*u(n)+n,u(n),u(0)=1)\n        Ex2:rsolve(u(n+1)=2*u(n)+n,u(n),u(1)^2=1)\n        Ex3:rsolve(u(n+1)=(u(n)-1)/(u(n)-2),u(n),u(0)=4)\n        Ex4:rsolve(u(n+2)=u(n)+2*u(n+1)+n+1,u(n),[u(0)=0,u(1)=1])\n        Ex5:rsolve([u(n+1)=3*v(n)+u(n),v(n+1)=v(n)+u(n)],[u(n),v(n)],[u(0)=1,v(0)=2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2631rsolve = {"rsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2631rsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2630rsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2631rsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2630rsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2630rsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rsolve", 1);

  /* "giacpy/auto-methods.pxi":16404
 * 
 *         '''
 *         return GiacMethods['rsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rur(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16404, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16391
 *         return GiacMethods['rref'](self,*args)
 * 
 *      def rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16406
 *         return GiacMethods['rsolve'](self,*args)
 * 
 *      def rur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2633rur(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2632rur, "From Giac's documentation:\n        Help for rur:\n        rur(rur)\n        Optional parameter of gbasis, will return a rational univariate representation instead of a Groebner basis for a 0 dimensional ideal\n        See also: 1/ gbasis \n        Ex1: gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3],rur)\n        Ex2:  \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2633rur = {"rur", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2633rur, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2632rur};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2633rur(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rur (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rur", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2632rur(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2632rur(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rur", 1);

  /* "giacpy/auto-methods.pxi":16416
 * 
 *         '''
 *         return GiacMethods['rur'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rur_certify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rur); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16416, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16406
 *         return GiacMethods['rsolve'](self,*args)
 * 
 *      def rur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rur", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16418
 *         return GiacMethods['rur'](self,*args)
 * 
 *      def rur_certify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_certify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2635rur_certify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2634rur_certify, "From Giac's documentation:\n        Help for rur_certify:\n        rur_certify(Intg(n))\n        Rur certification if argument n is 1, of equations of degree <= n if n>1 or no certification if n=0. If n<0, set maximal number of threads for certification to -n.\n        See also: 1/ gbasis 2/ rur_gbasis \n        Ex1: rur_certify(2); gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3],rur)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2635rur_certify = {"rur_certify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2635rur_certify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2634rur_certify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2635rur_certify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rur_certify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rur_certify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2634rur_certify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2634rur_certify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rur_certify", 1);

  /* "giacpy/auto-methods.pxi":16427
 * 
 *         '''
 *         return GiacMethods['rur_certify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def rur_gbasis(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rur_certify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16427, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16418
 *         return GiacMethods['rur'](self,*args)
 * 
 *      def rur_certify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_certify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rur_certify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16429
 *         return GiacMethods['rur_certify'](self,*args)
 * 
 *      def rur_gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_gbasis:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2637rur_gbasis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2636rur_gbasis, "From Giac's documentation:\n        Help for rur_gbasis:\n        rur_gbasis(Intg(n))\n        Gbasis fine-tuning; in the modular algorithm of a rur over Q, reconstruct a gbasis over Q if n=1, or if the number of monomials of the gbasis is <n if n>1. If n=0 no gbasis reconstruction over Q. If n==-1 and if one computes a rational univariate representation for a non 0 dimensional ideal, returns fast [rur]. If n==-2 returns a Groebner basis instead.\n        See also: 1/ gbasis 2/ rur_certify \n        Ex1: rur_gbasis(0); gbasis([x1+x2+x3,x1*x2+x1*x3+x2*x3,x1*x2*x3-1],[x1,x2,x3],rur)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2637rur_gbasis = {"rur_gbasis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2637rur_gbasis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2636rur_gbasis};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2637rur_gbasis(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rur_gbasis (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rur_gbasis", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2636rur_gbasis(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2636rur_gbasis(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rur_gbasis", 1);

  /* "giacpy/auto-methods.pxi":16438
 * 
 *         '''
 *         return GiacMethods['rur_gbasis'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def same(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_rur_gbasis); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16438, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16429
 *         return GiacMethods['rur_certify'](self,*args)
 * 
 *      def rur_gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_gbasis:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.rur_gbasis", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16440
 *         return GiacMethods['rur_gbasis'](self,*args)
 * 
 *      def same(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for same:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2639same(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2638same, "From Giac's documentation:\n        Help for same:\n        same(Expr,Expr)\n        Equality test.\n        See also: 1/  \n        Ex1:same(a,b)\n        Ex2:same((2-1)^2,2^2-2*2+1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2639same = {"same", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2639same, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2638same};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2639same(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("same (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "same", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2638same(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2638same(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("same", 1);

  /* "giacpy/auto-methods.pxi":16450
 * 
 *         '''
 *         return GiacMethods['same'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sample(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_same); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16450, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16440
 *         return GiacMethods['rur_gbasis'](self,*args)
 * 
 *      def same(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for same:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.same", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16452
 *         return GiacMethods['same'](self,*args)
 * 
 *      def sample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sample:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2641sample(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2640sample, "From Giac's documentation:\n        Help for sample:\n        sample(Lst(L),Intg(n))\n        sample(L,n)= rand(n,L)=list of the n extracted elements of L without replacement.\n        See also: 1/ rand  \n        Ex1:sample([1,2,3,4,5,6],6)\n        Ex2:sample([1,2,3,4,5,6],3)\n        Ex3:sample([\"r\",\"r\",\"r\",\"b\",\"n\"],3)\n        Ex4: L:=[1,2,3,4,5,6];L:=sample(L,3)\n        Ex5: L:=[1,2,3,4,5,6];L.sample(3)\n        Ex6: \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2641sample = {"sample", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2641sample, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2640sample};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2641sample(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sample (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sample", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2640sample(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2640sample(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sample", 1);

  /* "giacpy/auto-methods.pxi":16466
 * 
 *         '''
 *         return GiacMethods['sample'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def samplerate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sample); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16466, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16452
 *         return GiacMethods['same'](self,*args)
 * 
 *      def sample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sample:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sample", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16468
 *         return GiacMethods['sample'](self,*args)
 * 
 *      def samplerate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for samplerate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2643samplerate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2642samplerate, "From Giac's documentation:\n        Help for samplerate:\n        samplerate(Audio(clip))\n        Returns the sampling rate of an audio clip, in Hertz.\n        See also: 1/ bit_depth 2/ channels 3/ channel_data 4/ duration \n        Ex1:samplerate(readwav(\"/some/file\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2643samplerate = {"samplerate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2643samplerate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2642samplerate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2643samplerate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("samplerate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "samplerate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2642samplerate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2642samplerate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("samplerate", 1);

  /* "giacpy/auto-methods.pxi":16477
 * 
 *         '''
 *         return GiacMethods['samplerate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sans_factoriser(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_samplerate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16477, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16468
 *         return GiacMethods['sample'](self,*args)
 * 
 *      def samplerate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for samplerate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.samplerate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16479
 *         return GiacMethods['samplerate'](self,*args)
 * 
 *      def sans_factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sans_factoriser:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2645sans_factoriser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2644sans_factoriser, "From Giac's documentation:\n        Help for sans_factoriser:\n        sans_factoriser(Opt.)\n        Option of the plotimplicit command.\n        See also: 1/ plotimplicit \n        Ex1: plotimplicit(x^2+y^2-1,x,y,unfactored)\n        Ex2: plotimplicit(x^2+y^2-1,[x,y],unfactored)\n        Ex3: plotimplicit(x^2+y^2+z^2-1,x,y,z,xstep=0.2,ystep=0.2,zstep=0.2,unfactored)\n        Ex4: plotimplicit(x^2+y^2+z^2-1,[x,y,z],xstep=0.2,ystep=0.2,zstep=0.2,unfactored)\n        Ex5: plotimplicit(x^2+y^2+z^2-1,x=0..1,y=0..1,z=0..1,xstep=0.2,ystep=0.2,zstep=0.2,unfactored)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2645sans_factoriser = {"sans_factoriser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2645sans_factoriser, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2644sans_factoriser};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2645sans_factoriser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sans_factoriser (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sans_factoriser", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2644sans_factoriser(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2644sans_factoriser(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sans_factoriser", 1);

  /* "giacpy/auto-methods.pxi":16492
 * 
 *         '''
 *         return GiacMethods['sans_factoriser'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def saute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sans_factoriser); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16492, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16479
 *         return GiacMethods['samplerate'](self,*args)
 * 
 *      def sans_factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sans_factoriser:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sans_factoriser", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16494
 *         return GiacMethods['sans_factoriser'](self,*args)
 * 
 *      def saute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for saute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2647saute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2646saute, "From Giac's documentation:\n        Help for saute:\n        saute(NULL or Real(n))\n        The turtle takes n steps forward without traces (by default n=10).\n        See also: 1/ avance 2/ recule \n        Ex1: saute 30\n        Ex2:saute(30)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2647saute = {"saute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2647saute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2646saute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2647saute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("saute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "saute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2646saute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2646saute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("saute", 1);

  /* "giacpy/auto-methods.pxi":16504
 * 
 *         '''
 *         return GiacMethods['saute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def scalarProduct(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_saute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16504, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16494
 *         return GiacMethods['sans_factoriser'](self,*args)
 * 
 *      def saute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for saute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.saute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16506
 *         return GiacMethods['saute'](self,*args)
 * 
 *      def scalarProduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalarProduct:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2649scalarProduct(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2648scalarProduct, "From Giac's documentation:\n        Help for scalarProduct:\n        scalarProduct(Vect(v1),Vect(v2))\n        Scalar product.\n        See also: 1/ * 2/ cross 3/ .* 4/ hadamard \n        Ex1:scalarProduct([1,2],[3,4])\n        Ex2:scalarProduct([3,2,4],[3,2,4])\n        Ex3:scalarProduct([[1,2],[3,4]],[[3,2],[4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2649scalarProduct = {"scalarProduct", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2649scalarProduct, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2648scalarProduct};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2649scalarProduct(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scalarProduct (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "scalarProduct", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2648scalarProduct(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2648scalarProduct(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scalarProduct", 1);

  /* "giacpy/auto-methods.pxi":16517
 * 
 *         '''
 *         return GiacMethods['scalarProduct'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def scalar_product(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_scalarProduct); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16517, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16506
 *         return GiacMethods['saute'](self,*args)
 * 
 *      def scalarProduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalarProduct:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.scalarProduct", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16519
 *         return GiacMethods['scalarProduct'](self,*args)
 * 
 *      def scalar_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalar_product:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2651scalar_product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2650scalar_product, "From Giac's documentation:\n        Help for scalar_product:\n        scalar_product(Vect(v1),Vect(v2))\n        Scalar product.\n        See also: 1/ * 2/ cross 3/ .* 4/ hadamard \n        Ex1:scalar_product([1,2],[3,4])\n        Ex2:scalar_product([3,2,4],[3,2,4])\n        Ex3:scalar_product([[1,2],[3,4]],[[3,2],[4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2651scalar_product = {"scalar_product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2651scalar_product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2650scalar_product};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2651scalar_product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scalar_product (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "scalar_product", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2650scalar_product(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2650scalar_product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scalar_product", 1);

  /* "giacpy/auto-methods.pxi":16530
 * 
 *         '''
 *         return GiacMethods['scalar_product'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def scatterplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_scalar_product); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16530, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16519
 *         return GiacMethods['scalarProduct'](self,*args)
 * 
 *      def scalar_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalar_product:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.scalar_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16532
 *         return GiacMethods['scalar_product'](self,*args)
 * 
 *      def scatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scatterplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2653scatterplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2652scatterplot, "From Giac's documentation:\n        Help for scatterplot:\n        scatterplot(Mtrx)\n        Draws for k=0..nrows, the points (xk,yk) where xk=element row k column 0 and yk=element row k column j (j=1..ncols).\n        See also: 1/ polygonplot 2/ polygonscatterplot 3/ listplot \n        Ex1:scatterplot([[1,2,3],[2,0,1],[-1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2653scatterplot = {"scatterplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2653scatterplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2652scatterplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2653scatterplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scatterplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "scatterplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2652scatterplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2652scatterplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scatterplot", 1);

  /* "giacpy/auto-methods.pxi":16541
 * 
 *         '''
 *         return GiacMethods['scatterplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def schur(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_scatterplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16541, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16532
 *         return GiacMethods['scalar_product'](self,*args)
 * 
 *      def scatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scatterplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.scatterplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16543
 *         return GiacMethods['scatterplot'](self,*args)
 * 
 *      def schur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for schur:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2655schur(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2654schur, "From Giac's documentation:\n        Help for schur:\n        schur(Mtrx(A))\n        Matrix reduction to Hessenberg form. Returns [P,B] such that B=inv(P)*A*P:SCHUR(A)=hessenberg(A,-1).\n        See also: 1/ hessenberg \n        Ex1:schur([[1,2,3],[4,5,6],[7,8,1]])\n        Ex2:schur([[1,2,3,4],[4,5,6,7],[7,8,9,0],[0,1,2,3]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2655schur = {"schur", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2655schur, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2654schur};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2655schur(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("schur (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "schur", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2654schur(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2654schur(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("schur", 1);

  /* "giacpy/auto-methods.pxi":16553
 * 
 *         '''
 *         return GiacMethods['schur'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sec(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_schur); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16553, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16543
 *         return GiacMethods['scatterplot'](self,*args)
 * 
 *      def schur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for schur:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.schur", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16555
 *         return GiacMethods['schur'](self,*args)
 * 
 *      def sec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sec:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2657sec(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2656sec, "From Giac's documentation:\n        Help for sec:\n        sec(Expr)\n        Secant: sec(x)=1/cos(x).\n        See also: 1/ cos 2/ asec \n        Ex1:sec(pi/3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2657sec = {"sec", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2657sec, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2656sec};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2657sec(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sec (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sec", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2656sec(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2656sec(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sec", 1);

  /* "giacpy/auto-methods.pxi":16564
 * 
 *         '''
 *         return GiacMethods['sec'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def secant_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sec); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16564, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16555
 *         return GiacMethods['schur'](self,*args)
 * 
 *      def sec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sec:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16566
 *         return GiacMethods['sec'](self,*args)
 * 
 *      def secant_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for secant_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2659secant_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2658secant_solver, "From Giac's documentation:\n        Help for secant_solver:\n        secant_solver(Opt)\n        Argument for fsolve giving the method for solving a numerical equation.\n        See also: 1/ fsolve \n        Ex1: fsolve(cos(x)=x,x,0..1,bisection_solver)\n        Ex2: fsolve(cos(x)=x,x,0..1,brent_solver)\n        Ex3: fsolve(cos(x)=x,x,0..1,falsepos_solver)\n        Ex4: fsolve(cos(x)=x,x,0,newton_solver)\n        Ex5: fsolve(cos(x)=x,x,0,secant_solver)\n        Ex6: fsolve(cos(x)=x,x,0,steffenson_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2659secant_solver = {"secant_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2659secant_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2658secant_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2659secant_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("secant_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "secant_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2658secant_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2658secant_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("secant_solver", 1);

  /* "giacpy/auto-methods.pxi":16580
 * 
 *         '''
 *         return GiacMethods['secant_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def segment(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_secant_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16580, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16566
 *         return GiacMethods['sec'](self,*args)
 * 
 *      def secant_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for secant_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.secant_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16582
 *         return GiacMethods['secant_solver'](self,*args)
 * 
 *      def segment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for segment:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2661segment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2660segment, "From Giac's documentation:\n        Help for segment:\n        segment((Pnt or Cplx or Lst([xM,yM])),(Pnt or Cplx or Lst([xN,yN]),[Var],[Var] or Opt)\n        segment(A,B) draws the segment AB and segment([xM,yM],[xN,yN]) draws the vector as origin [xM,yM], of coordinates [xN,yN] (i.e draws segment(M,point(M+N)) or Option of the arc command.\n        See also: 1/ line 2/ arc \n        Ex1:segment(i,1+i)\n        Ex2:segment(point(i),point(1+i))\n        Ex3:segment(point(i),point(1+i),A,B)\n        Ex4:segment([-1,0],[2,1])\n        Ex5:segment([-1,0],point([-1,0]+[2,1]))\n        Ex6: arc(i,1,pi/4,segment)\n        Ex7: affichage( arc(i,1,pi/4,segment),1+rempli)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2661segment = {"segment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2661segment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2660segment};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2661segment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("segment (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "segment", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2660segment(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2660segment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("segment", 1);

  /* "giacpy/auto-methods.pxi":16597
 * 
 *         '''
 *         return GiacMethods['segment'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def seidel_spectrum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_segment); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16597, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16582
 *         return GiacMethods['secant_solver'](self,*args)
 * 
 *      def segment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for segment:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.segment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16599
 *         return GiacMethods['segment'](self,*args)
 * 
 *      def seidel_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_spectrum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2663seidel_spectrum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2662seidel_spectrum, "From Giac's documentation:\n        Help for seidel_spectrum:\n        seidel_spectrum(Graph(G))\n        Returns the Seidel spectrum of G as a list of lists with two elements, each containing an eigenvalue and its multiplicity.\n        See also: 1/ graph_spectrum \n        Ex1:seidel_spectrum(graph(\"clebsch\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2663seidel_spectrum = {"seidel_spectrum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2663seidel_spectrum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2662seidel_spectrum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2663seidel_spectrum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seidel_spectrum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "seidel_spectrum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2662seidel_spectrum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2662seidel_spectrum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seidel_spectrum", 1);

  /* "giacpy/auto-methods.pxi":16608
 * 
 *         '''
 *         return GiacMethods['seidel_spectrum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def seidel_switch(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_seidel_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16608, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16599
 *         return GiacMethods['segment'](self,*args)
 * 
 *      def seidel_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_spectrum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.seidel_spectrum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16610
 *         return GiacMethods['seidel_spectrum'](self,*args)
 * 
 *      def seidel_switch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_switch:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2665seidel_switch(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2664seidel_switch, "From Giac's documentation:\n        Help for seidel_switch:\n        seidel_switch(Graph(G),Lst(V))\n        Returns a copy of G in which the edges between vertices in list V and vertices not in V are inverted (replaced with a set of edges from V to other vertices which are not present in G).\n        See also: 1/ neighbors 2/ graph_complement \n        Ex1:seidel_switch(cycle_graph(5),[1,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2665seidel_switch = {"seidel_switch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2665seidel_switch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2664seidel_switch};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2665seidel_switch(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seidel_switch (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "seidel_switch", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2664seidel_switch(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2664seidel_switch(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seidel_switch", 1);

  /* "giacpy/auto-methods.pxi":16619
 * 
 *         '''
 *         return GiacMethods['seidel_switch'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def select(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_seidel_switch); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16619, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16610
 *         return GiacMethods['seidel_spectrum'](self,*args)
 * 
 *      def seidel_switch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_switch:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.seidel_switch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16621
 *         return GiacMethods['seidel_switch'](self,*args)
 * 
 *      def select(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for select:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2667select(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2666select, "From Giac's documentation:\n        Help for select:\n        select(FncBool(f),Lst(l))\n        Selects the elements e of l such that f(e)=true.\n        See also: 1/ remove 2/ range \n        Ex1:select(x->x>=5,[1,2,6,7])\n        Ex2:select(x->isprime(x),range(20)).^2\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2667select = {"select", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2667select, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2666select};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2667select(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("select (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "select", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2666select(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2666select(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("select", 1);

  /* "giacpy/auto-methods.pxi":16631
 * 
 *         '''
 *         return GiacMethods['select'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def semi_augment(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_select); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16631, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16621
 *         return GiacMethods['seidel_switch'](self,*args)
 * 
 *      def select(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for select:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.select", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16633
 *         return GiacMethods['select'](self,*args)
 * 
 *      def semi_augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for semi_augment:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2669semi_augment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2668semi_augment, "From Giac's documentation:\n        Help for semi_augment:\n        semi_augment(Mtrx(A),Mtrx(B))\n        Returns a matrix made with A and B, with n1+n2 rows and p columns if dim(A)=[n1,p] and dim(B)=[n2,p].\n        See also: 1/ augment \n        Ex1:semi_augment([[68,-21],[56,59],[1,2]],[[68,-21],[56,59]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2669semi_augment = {"semi_augment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2669semi_augment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2668semi_augment};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2669semi_augment(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("semi_augment (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "semi_augment", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2668semi_augment(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2668semi_augment(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("semi_augment", 1);

  /* "giacpy/auto-methods.pxi":16642
 * 
 *         '''
 *         return GiacMethods['semi_augment'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def seq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_semi_augment); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16642, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16633
 *         return GiacMethods['select'](self,*args)
 * 
 *      def semi_augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for semi_augment:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.semi_augment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16644
 *         return GiacMethods['semi_augment'](self,*args)
 * 
 *      def seq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2671seq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2670seq, "From Giac's documentation:\n        Help for seq:\n        seq(Expr(Xpr),Var(Var)=Int(a..b),[Real(p)]||Expr(Xpr),Var(Var),Real(a),Real(b),[Real(p)])\n        Returns the sequence (2 or 3 arg) or the list (4 or 5 arg) obtained when var goes from a to b (step p) in Xpr (or the Xpr is repeated n times or returns the sequence of reals from a to b (step p)).  And also seq(expression,variable,list) is equivalent to map(list,unapply(expression,variable)) \n        See also: 1/ $ 2/ makelist 3/ range 4/ map 5/ unapply \n        Ex1:seq(0.3,4)\n        Ex2:seq(t,4)\n        Ex3:seq(0,0)\n        Ex4:seq(2^k,k=0..8)\n        Ex5:seq(2^k,k=0..8,2)\n        Ex6:seq(0.3..2,0.2)\n        Ex7:seq(2^k,k,0,8)\n        Ex8:seq(2^k,k,0,8,2)\n        Ex9:seq(x^3,x,[1,2,3])\n        Ex10: [seq(0.3..2,0.2)] \n        Ex11: a:=(1,2,3);eval(seq(a,4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2671seq = {"seq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2671seq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2670seq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2671seq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "seq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2670seq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2670seq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seq", 1);

  /* "giacpy/auto-methods.pxi":16663
 * 
 *         '''
 *         return GiacMethods['seq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def seqplot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_seq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16663, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16644
 *         return GiacMethods['semi_augment'](self,*args)
 * 
 *      def seq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.seq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16665
 *         return GiacMethods['seq'](self,*args)
 * 
 *      def seqplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqplot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2673seqplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2672seqplot, "From Giac's documentation:\n        Help for seqplot:\n        seqplot(Expr(f(Var)),Var=[a,xm,xM],Intg(p))\n        For seeing the pth terms of the sequence u(0)=a,u(n)=f(u(n-1)).\n        See also: 1/ seqsolve 2/ rsolve \n        Ex1:seqplot(sqrt(2+x),6,5)\n        Ex2:seqplot(sqrt(2+t),t=6,5)\n        Ex3:seqplot(sqrt(2+x),x=[6,1,7],5,affichage=epaisseur_ligne_2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2673seqplot = {"seqplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2673seqplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2672seqplot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2673seqplot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seqplot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "seqplot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2672seqplot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2672seqplot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seqplot", 1);

  /* "giacpy/auto-methods.pxi":16676
 * 
 *         '''
 *         return GiacMethods['seqplot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def seqsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_seqplot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16676, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16665
 *         return GiacMethods['seq'](self,*args)
 * 
 *      def seqplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqplot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.seqplot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16678
 *         return GiacMethods['seqplot'](self,*args)
 * 
 *      def seqsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2675seqsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2674seqsolve, "From Giac's documentation:\n        Help for seqsolve:\n        seqsolve((Expr or LstExpr),(Var or LstVar),(InitVal or LstInitVal))\n        Gives the value of a recurrent sequence (u_{n+1}=f(u_n) or u_{n+k}=f(u_n,u_{n+1}...u_{n+k-1})) or of a system of recurrent sequences.\n        See also: 1/ rsolve 2/ plotseq 3/ tableseq \n        Ex1:seqsolve(2x+n,[x,n],1)\n        Ex2:seqsolve(2x+n*3^n,[x,n],1)\n        Ex3:seqsolve(x+y,[x,y,n],[1,1])\n        Ex4:seqsolve(x+2*y+n+1,[x,y,n],[0,1])\n        Ex5:seqsolve([x+2*y,n+1+x],[x,y,n],[0,1])\n        Ex6:seqsolve([x+2*y+n+1,x],[x,y,n],[0,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2675seqsolve = {"seqsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2675seqsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2674seqsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2675seqsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("seqsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "seqsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2674seqsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2674seqsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("seqsolve", 1);

  /* "giacpy/auto-methods.pxi":16692
 * 
 *         '''
 *         return GiacMethods['seqsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sequence_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_seqsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16692, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16678
 *         return GiacMethods['seqplot'](self,*args)
 * 
 *      def seqsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.seqsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16694
 *         return GiacMethods['seqsolve'](self,*args)
 * 
 *      def sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sequence_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2677sequence_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2676sequence_graph, "From Giac's documentation:\n        Help for sequence_graph:\n        sequence_graph(Lst(L))\n        Returns an undirected graph with degree sequence equal to L.\n        See also: 1/ degree_sequence 2/ is_graphic_sequence \n        Ex1:sequence_graph(degree_sequence(sequence_graph([3,2,4,2,3,4,5,7])))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2677sequence_graph = {"sequence_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2677sequence_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2676sequence_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2677sequence_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sequence_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sequence_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2676sequence_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2676sequence_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sequence_graph", 1);

  /* "giacpy/auto-methods.pxi":16703
 * 
 *         '''
 *         return GiacMethods['sequence_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def series(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sequence_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16703, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16694
 *         return GiacMethods['seqsolve'](self,*args)
 * 
 *      def sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sequence_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sequence_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16705
 *         return GiacMethods['sequence_graph'](self,*args)
 * 
 *      def series(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for series:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2679series(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2678series, "From Giac's documentation:\n        Help for series:\n        series(Expr,Equal(var=limit_point),[Order],[Dir(1,0,-1)])\n        Series expansion at finite or infinite points.\n        See also: 1/ limit 2/ taylor 3/ pad 4/ polynom 5/ truncate \n        Ex1:series(sin(x)/x,x=0)\n        Ex2:series(sin(x),x=0,6,polynom)\n        Ex3:series(ln(x+x^2)-ln(x),x=0,1)\n        Ex4:series((x^4+x+2)/(x^2+1),x=0,5)\n        Ex5: series(\"h\",8); ln(1+h);\n        Ex6:series(1/(1+x+y),[x,y],[0,0],5) \n        Ex7:series(sin(x*y),[x,y],[1,pi/2],3)\n        Ex8:series(sin((1+h*t)*(pi/2+k*t)),t=0,3,polynom)(t=1)\n        Ex9:series(y^2/x^3,[x,y],[1,-1],3)\n        Ex10:series((-1+k*t)^2/(1+h*t)^3,t=0,3,polynom)(t=1)\n        Ex11:series(subst(sin(x+y)+cos(y*x),[x,y],h*[x,y]),h=0,6,polynom)\n        Ex12:series(subst(sin(x+y)+cos(y*x),[x,y],h*[x,y]),h=0,6,polynom)(h=1)\n        Ex13: truncate(series(sin(x),x=0,6),6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2679series = {"series", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2679series, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2678series};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2679series(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("series (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "series", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2678series(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2678series(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("series", 1);

  /* "giacpy/auto-methods.pxi":16726
 * 
 *         '''
 *         return GiacMethods['series'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_channel_data(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_series); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16726, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16705
 *         return GiacMethods['sequence_graph'](self,*args)
 * 
 *      def series(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for series:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.series", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16728
 *         return GiacMethods['series'](self,*args)
 * 
 *      def set_channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_channel_data:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2681set_channel_data(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2680set_channel_data, "From Giac's documentation:\n        Help for set_channel_data:\n        set_channel_data(Audio(clip),Lst||Mtrx(data),[Intg(offset),Intg(chn)]||Image(img),Intg(chn),Intg(x),Intg(y),Mtrx(data))\n        Returns a copy of an audio clip/image object with the sample/pixel data (in channel chn starting at offset/(x,y)) set to the values in data.\n        See also: 1/ channel_data 2/ channels \n        Ex1: clip:=readwav(\"sample.wav\");set_channel_data(clip,0$20000,40000,left)\n        Ex2: logo:=image(\"xcas-logo.png\");set_channel_data(logo,blue,0,0,(-logo)[red])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2681set_channel_data = {"set_channel_data", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2681set_channel_data, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2680set_channel_data};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2681set_channel_data(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_channel_data (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_channel_data", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2680set_channel_data(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2680set_channel_data(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_channel_data", 1);

  /* "giacpy/auto-methods.pxi":16738
 * 
 *         '''
 *         return GiacMethods['set_channel_data'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_edge_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_channel_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16738, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16728
 *         return GiacMethods['series'](self,*args)
 * 
 *      def set_channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_channel_data:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_channel_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16740
 *         return GiacMethods['set_channel_data'](self,*args)
 * 
 *      def set_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2683set_edge_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2682set_edge_attribute, "From Giac's documentation:\n        Help for set_edge_attribute:\n        set_edge_attribute(Graph(G),Edge(e),Seq(tag1=value1,tag2=value2,..))\n        Stores the attributes to the edge e and returns a modified copy of G.\n        See also: 1/ discard_edge_attribute 2/ get_edge_attribute 3/ list_edge_attributes \n        Ex1:set_edge_attribute(cycle_graph(3),[1,2],\"cost\"=12.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2683set_edge_attribute = {"set_edge_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2683set_edge_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2682set_edge_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2683set_edge_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_edge_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_edge_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2682set_edge_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2682set_edge_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_edge_attribute", 1);

  /* "giacpy/auto-methods.pxi":16749
 * 
 *         '''
 *         return GiacMethods['set_edge_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_edge_weight(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_edge_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16749, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16740
 *         return GiacMethods['set_channel_data'](self,*args)
 * 
 *      def set_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_edge_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16751
 *         return GiacMethods['set_edge_attribute'](self,*args)
 * 
 *      def set_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_weight:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2685set_edge_weight(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2684set_edge_weight, "From Giac's documentation:\n        Help for set_edge_weight:\n        set_edge_weight(Graph(G),Edge(e),Real(w))\n        Sets the weight of the edge e in the weighted graph G to w and returns a modified copy of G.\n        See also: 1/ is_weighted 2/ get_edge_weight 3/ make_weighted 4/ weight_matrix \n        Ex1:set_edge_weight(graph(%{[1,2],[2,3]%}),[1,2],5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2685set_edge_weight = {"set_edge_weight", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2685set_edge_weight, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2684set_edge_weight};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2685set_edge_weight(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_edge_weight (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_edge_weight", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2684set_edge_weight(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2684set_edge_weight(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_edge_weight", 1);

  /* "giacpy/auto-methods.pxi":16760
 * 
 *         '''
 *         return GiacMethods['set_edge_weight'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_graph_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_edge_weight); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16760, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16751
 *         return GiacMethods['set_edge_attribute'](self,*args)
 * 
 *      def set_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_weight:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_edge_weight", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16762
 *         return GiacMethods['set_edge_weight'](self,*args)
 * 
 *      def set_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_graph_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2687set_graph_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2686set_graph_attribute, "From Giac's documentation:\n        Help for set_graph_attribute:\n        set_graph_attribute(Graph(G),Seq(tag1=value1,tag2=value2,..))\n        Stores the attributes where each tag is a string, and returns a modified copy of G.\n        See also: 1/ discard_graph_attribute 2/ get_graph_attribute 3/ list_graph_attributes \n        Ex1:set_graph_attribute(cycle_graph(3),\"name\"=\"cycle graph\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2687set_graph_attribute = {"set_graph_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2687set_graph_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2686set_graph_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2687set_graph_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_graph_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_graph_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2686set_graph_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2686set_graph_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_graph_attribute", 1);

  /* "giacpy/auto-methods.pxi":16771
 * 
 *         '''
 *         return GiacMethods['set_graph_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_pixel(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_graph_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16771, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16762
 *         return GiacMethods['set_edge_weight'](self,*args)
 * 
 *      def set_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_graph_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_graph_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16773
 *         return GiacMethods['set_graph_attribute'](self,*args)
 * 
 *      def set_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_pixel:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2689set_pixel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2688set_pixel, "From Giac's documentation:\n        Help for set_pixel:\n        set_pixel(Intg(x),Intg(y),Intg(col))\n        Pixel on and adds to the list of pixels. Run set_pixel() or show_pixels() to display, set_pixel(n) to zoom.\n        See also: 1/ clear 2/ show_pixels 3/ draw_line 4/ draw_rectangle 5/ draw_polygon \n        Ex1: clear(); set_pixel(4); draw_pixel(1,2,red); show_pixels();\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2689set_pixel = {"set_pixel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2689set_pixel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2688set_pixel};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2689set_pixel(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_pixel (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_pixel", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2688set_pixel(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2688set_pixel(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_pixel", 1);

  /* "giacpy/auto-methods.pxi":16782
 * 
 *         '''
 *         return GiacMethods['set_pixel'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_screen(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_pixel); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16782, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16773
 *         return GiacMethods['set_graph_attribute'](self,*args)
 * 
 *      def set_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_pixel:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_pixel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16784
 *         return GiacMethods['set_pixel'](self,*args)
 * 
 *      def set_screen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_screen:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2691set_screen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2690set_screen, "From Giac's documentation:\n        Help for set_screen:\n        set_screen(Intg(x),Intg(y))\n        Defines the virtual screen sizes for get_key()\n        See also: 1/ set_pixel \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2691set_screen = {"set_screen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2691set_screen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2690set_screen};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2691set_screen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_screen (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_screen", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2690set_screen(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2690set_screen(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_screen", 1);

  /* "giacpy/auto-methods.pxi":16792
 * 
 *         '''
 *         return GiacMethods['set_screen'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_vertex_attribute(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_screen); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16792, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16784
 *         return GiacMethods['set_pixel'](self,*args)
 * 
 *      def set_screen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_screen:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_screen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16794
 *         return GiacMethods['set_screen'](self,*args)
 * 
 *      def set_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_attribute:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2693set_vertex_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2692set_vertex_attribute, "From Giac's documentation:\n        Help for set_vertex_attribute:\n        set_vertex_attribute(Graph(G),Vrtx(v),Seq(tag1=value1,tag2=value2,..))\n        Stores the attributes to the vertex v and returns a modified copy of G.\n        See also: 1/ discard_vertex_attribute 2/ get_vertex_attribute 3/ list_vertex_attributes \n        Ex1:set_vertex_attribute(cycle_graph(3),1,\"supply\"=27)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2693set_vertex_attribute = {"set_vertex_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2693set_vertex_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2692set_vertex_attribute};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2693set_vertex_attribute(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_vertex_attribute (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_vertex_attribute", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2692set_vertex_attribute(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2692set_vertex_attribute(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_vertex_attribute", 1);

  /* "giacpy/auto-methods.pxi":16803
 * 
 *         '''
 *         return GiacMethods['set_vertex_attribute'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def set_vertex_positions(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_vertex_attribute); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16803, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16794
 *         return GiacMethods['set_screen'](self,*args)
 * 
 *      def set_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_attribute:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_vertex_attribute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16805
 *         return GiacMethods['set_vertex_attribute'](self,*args)
 * 
 *      def set_vertex_positions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_positions:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2695set_vertex_positions(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2694set_vertex_positions, "From Giac's documentation:\n        Help for set_vertex_positions:\n        set_vertex_positions(Graph(G),Lst(vp))\n        Sets the coordinates, given in the list vp, to the vertices of G and returns a modified copy of G.\n        See also: 1/ draw_graph \n        Ex1: G:=graph([1,2,3,4,5,6],%{[1,2],[1,4],[4,5],[2,5],[2,3],[3,6],[5,6]%}); G:=set_vertex_positions(G,[[0,0],[0.5,0],[1,0],[0,0.5],[0.5,0.5],[1,0.5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2695set_vertex_positions = {"set_vertex_positions", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2695set_vertex_positions, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2694set_vertex_positions};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2695set_vertex_positions(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_vertex_positions (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_vertex_positions", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2694set_vertex_positions(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2694set_vertex_positions(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_vertex_positions", 1);

  /* "giacpy/auto-methods.pxi":16814
 * 
 *         '''
 *         return GiacMethods['set_vertex_positions'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def shift(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_set_vertex_positions); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16814, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16805
 *         return GiacMethods['set_vertex_attribute'](self,*args)
 * 
 *      def set_vertex_positions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_positions:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.set_vertex_positions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16816
 *         return GiacMethods['set_vertex_positions'](self,*args)
 * 
 *      def shift(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2697shift(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2696shift, "From Giac's documentation:\n        Help for shift:\n        shift(Lst,[Intg(n)])\n        Returns the list where the last element [or the tail beginning with the n-th element] is moved to the first element and then completed with 0s (by default n=-1);L:=shift(L,2) o L.shift(2).\n        See also: 1/ rotate 2/ tail \n        Ex1:shift([0,1,2,3],2)\n        Ex2:shift([0,1,2,3])\n        Ex3:shift([0,1,2,3,4])\n        Ex4: L:=[0,1,2,3];L:=shift(L,2)\n        Ex5: L:=[0,1,2,3];L.shift(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2697shift = {"shift", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2697shift, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2696shift};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2697shift(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shift (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "shift", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2696shift(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2696shift(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shift", 1);

  /* "giacpy/auto-methods.pxi":16829
 * 
 *         '''
 *         return GiacMethods['shift'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def shift_phase(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_shift); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16829, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16816
 *         return GiacMethods['set_vertex_positions'](self,*args)
 * 
 *      def shift(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.shift", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16831
 *         return GiacMethods['shift'](self,*args)
 * 
 *      def shift_phase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift_phase:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2699shift_phase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2698shift_phase, "From Giac's documentation:\n        Help for shift_phase:\n        shift_phase(Expr)\n        shift_phase returns the expressions where the phase of the evaluated trigonometric expressions is increased by pi/2.\n        See also: 1/ series \n        Ex1:shift_phase(sin(x))\n        Ex2:shift_phase('sin(x+pi/2)')\n        Ex3:shift_phase(x+sin(x))\n        Ex4:shift_phase(x+sin(x))\n        Ex5:shift_phase(cos(t))\n        Ex6:shift_phase(tan(u))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2699shift_phase = {"shift_phase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2699shift_phase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2698shift_phase};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2699shift_phase(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shift_phase (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "shift_phase", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2698shift_phase(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2698shift_phase(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shift_phase", 1);

  /* "giacpy/auto-methods.pxi":16845
 * 
 *         '''
 *         return GiacMethods['shift_phase'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def shortest_path(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_shift_phase); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16845, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16831
 *         return GiacMethods['shift'](self,*args)
 * 
 *      def shift_phase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift_phase:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.shift_phase", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16847
 *         return GiacMethods['shift_phase'](self,*args)
 * 
 *      def shortest_path(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shortest_path:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2701shortest_path(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2700shortest_path, "From Giac's documentation:\n        Help for shortest_path:\n        shortest_path(Graph(G),Vrtx(s),Vrtx(t)||Lst(T))\n        Returns the shortest path from vertex s to vertex t in G, or an empty list if there is no such path. If vector T of vertices from G is given, then the list of shortest paths from s to each t int T is returned.\n        See also: 1/ dijkstra 2/ vertex_distance \n        Ex1:shortest_path(cycle_graph(6),1,5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2701shortest_path = {"shortest_path", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2701shortest_path, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2700shortest_path};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2701shortest_path(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shortest_path (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "shortest_path", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2700shortest_path(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2700shortest_path(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shortest_path", 1);

  /* "giacpy/auto-methods.pxi":16856
 * 
 *         '''
 *         return GiacMethods['shortest_path'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def show_pixels(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_shortest_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16856, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16847
 *         return GiacMethods['shift_phase'](self,*args)
 * 
 *      def shortest_path(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shortest_path:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.shortest_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16858
 *         return GiacMethods['shortest_path'](self,*args)
 * 
 *      def show_pixels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for show_pixels:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2703show_pixels(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2702show_pixels, "From Giac's documentation:\n        Help for show_pixels:\n        show_pixels(NULL)\n        Displays the list of pixels.\n        See also: 1/ set_pixel 2/ clear \n        Ex1:show_pixels()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2703show_pixels = {"show_pixels", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2703show_pixels, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2702show_pixels};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2703show_pixels(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("show_pixels (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "show_pixels", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2702show_pixels(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2702show_pixels(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("show_pixels", 1);

  /* "giacpy/auto-methods.pxi":16867
 * 
 *         '''
 *         return GiacMethods['show_pixels'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def shuffle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_show_pixels); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16867, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16858
 *         return GiacMethods['shortest_path'](self,*args)
 * 
 *      def show_pixels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for show_pixels:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.show_pixels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16869
 *         return GiacMethods['show_pixels'](self,*args)
 * 
 *      def shuffle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shuffle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2705shuffle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2704shuffle, "From Giac's documentation:\n        Help for shuffle:\n        shuffle(Intg(n)||Lst(L))\n        Returns a random permutation of [0,1,2,..,n-1] or of the list L.\n        See also: 1/ permu2cycles 2/ is_permu 3/ permu2mat \n        Ex1:shuffle(4)\n        Ex2:shuffle(7)\n        Ex3:shuffle([1,3,5,7,9])\n        Ex4: L:=[1,3,5,7,9];L:=randperm(L)\n        Ex5: L:=[1,3,5,7,9];L.randperm()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2705shuffle = {"shuffle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2705shuffle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2704shuffle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2705shuffle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shuffle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "shuffle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2704shuffle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2704shuffle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shuffle", 1);

  /* "giacpy/auto-methods.pxi":16882
 * 
 *         '''
 *         return GiacMethods['shuffle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sierpinski_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_shuffle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16882, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16869
 *         return GiacMethods['show_pixels'](self,*args)
 * 
 *      def shuffle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shuffle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.shuffle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16884
 *         return GiacMethods['shuffle'](self,*args)
 * 
 *      def sierpinski_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sierpinski_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2707sierpinski_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2706sierpinski_graph, "From Giac's documentation:\n        Help for sierpinski_graph:\n        sierpinski_graph(Intg(n),Intg(k),[triangle])\n        Returns the Sierpi\305\204ski (triangle) graph S(n,k) (resp. ST(n,k)).\n        See also: 1/ graph \n        Ex1:sierpinski_graph(2,4)\n        Ex2:sierpinski_graph(4,3)\n        Ex3:sierpinski_graph(3,4)\n        Ex4:sierpinski_graph(3,2)\n        Ex5:sierpinski_graph(3,3,at_triangle)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2707sierpinski_graph = {"sierpinski_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2707sierpinski_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2706sierpinski_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2707sierpinski_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sierpinski_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sierpinski_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2706sierpinski_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2706sierpinski_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sierpinski_graph", 1);

  /* "giacpy/auto-methods.pxi":16897
 * 
 *         '''
 *         return GiacMethods['sierpinski_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sign(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sierpinski_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16897, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16884
 *         return GiacMethods['shuffle'](self,*args)
 * 
 *      def sierpinski_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sierpinski_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sierpinski_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16899
 *         return GiacMethods['sierpinski_graph'](self,*args)
 * 
 *      def sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2709sign(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2708sign, "From Giac's documentation:\n        Help for sign:\n        sign(Expr)\n        Returns the sign (-1,0,+1) of its argument.\n        See also: 1/ abs \n        Ex1:sign(-4)\n        Ex2:sign(4-5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2709sign = {"sign", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2709sign, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2708sign};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2709sign(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sign (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sign", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2708sign(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2708sign(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sign", 1);

  /* "giacpy/auto-methods.pxi":16909
 * 
 *         '''
 *         return GiacMethods['sign'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sign2Heaviside(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sign); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16909, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16899
 *         return GiacMethods['sierpinski_graph'](self,*args)
 * 
 *      def sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16911
 *         return GiacMethods['sign'](self,*args)
 * 
 *      def sign2Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign2Heaviside:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2711sign2Heaviside(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2710sign2Heaviside, "From Giac's documentation:\n        Help for sign2Heaviside:\n        sign2Heaviside(Expr)\n        Replaces sign function by Heaviside function in an expression.\n        See also: 1/ Heaviside 2/ sign 3/ Heaviside2sign 4/ simpd \n        Ex1:sign2Heaviside(sign(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2711sign2Heaviside = {"sign2Heaviside", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2711sign2Heaviside, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2710sign2Heaviside};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2711sign2Heaviside(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sign2Heaviside (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sign2Heaviside", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2710sign2Heaviside(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2710sign2Heaviside(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sign2Heaviside", 1);

  /* "giacpy/auto-methods.pxi":16920
 * 
 *         '''
 *         return GiacMethods['sign2Heaviside'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def signature(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sign2Heaviside); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16920, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16911
 *         return GiacMethods['sign'](self,*args)
 * 
 *      def sign2Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign2Heaviside:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sign2Heaviside", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16922
 *         return GiacMethods['sign2Heaviside'](self,*args)
 * 
 *      def signature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signature:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2713signature(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2712signature, "From Giac's documentation:\n        Help for signature:\n        signature(Permut)\n        Returns the signature of a permutation.\n        See also: 1/ permu2cycles 2/ is_permu \n        Ex1:signature([1,0,3,4,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2713signature = {"signature", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2713signature, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2712signature};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2713signature(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("signature (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "signature", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2712signature(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2712signature(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("signature", 1);

  /* "giacpy/auto-methods.pxi":16931
 * 
 *         '''
 *         return GiacMethods['signature'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def signe(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_signature); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16931, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16922
 *         return GiacMethods['sign2Heaviside'](self,*args)
 * 
 *      def signature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signature:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16933
 *         return GiacMethods['signature'](self,*args)
 * 
 *      def signe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signe:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2715signe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2714signe, "From Giac's documentation:\n        Help for signe:\n        signe(Str(s))\n        Writes the string s with the font 20 at the point [10,10].\n        See also: 1/ ecris \n        Ex1:signe(\"Thomas\")\n        Ex2:signe(Thomas)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2715signe = {"signe", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2715signe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2714signe};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2715signe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("signe (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "signe", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2714signe(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2714signe(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("signe", 1);

  /* "giacpy/auto-methods.pxi":16943
 * 
 *         '''
 *         return GiacMethods['signe'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def similarity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_signe); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16943, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16933
 *         return GiacMethods['signature'](self,*args)
 * 
 *      def signe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signe:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.signe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16945
 *         return GiacMethods['signe'](self,*args)
 * 
 *      def similarity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for similarity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2717similarity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2716similarity, "From Giac's documentation:\n        Help for similarity:\n        similarity(Pnt or Dr3,Real,Angle,Pnt)\n        similarity(B,k,a1,A)=transformation of A in the similarity (center B or axis d, coeff k,angle a1) (or also homothety(B,k*exp(i*a1),A)).\n        See also: 1/ homothety \n        Ex1:similarity(1+i,2,pi/3,i)\n        Ex2:similarity(line(x=y,y=z),2,pi/3,point(-1,2,1))\n        Ex3: s:=similarity(1+i,2,pi/3);s(i)\n        Ex4: s:=similarity(line(x=y,y=z),2,pi/3),s(point(-1,2,1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2717similarity = {"similarity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2717similarity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2716similarity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2717similarity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("similarity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "similarity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2716similarity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2716similarity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("similarity", 1);

  /* "giacpy/auto-methods.pxi":16957
 * 
 *         '''
 *         return GiacMethods['similarity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simp2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_similarity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16957, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16945
 *         return GiacMethods['signe'](self,*args)
 * 
 *      def similarity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for similarity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.similarity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16959
 *         return GiacMethods['similarity'](self,*args)
 * 
 *      def simp2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simp2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2719simp2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2718simp2, "From Giac's documentation:\n        Help for simp2:\n        simp2(Intg(A) or Poly(A),Intg(B) or Poly(B))\n        Returns the list [A/gcd(A,B),B/gcd(A,B)].\n        See also: 1/ gcd \n        Ex1:simp2(12,18)\n        Ex2:simp2(x^3-1,x^2-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2719simp2 = {"simp2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2719simp2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2718simp2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2719simp2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simp2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simp2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2718simp2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2718simp2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simp2", 1);

  /* "giacpy/auto-methods.pxi":16969
 * 
 *         '''
 *         return GiacMethods['simp2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simplex_reduce(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simp2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16969, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16959
 *         return GiacMethods['similarity'](self,*args)
 * 
 *      def simp2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simp2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simp2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16971
 *         return GiacMethods['simp2'](self,*args)
 * 
 *      def simplex_reduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplex_reduce:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2721simplex_reduce(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2720simplex_reduce, "From Giac's documentation:\n        Help for simplex_reduce:\n        simplex_reduce(Mtrx(A), Vect(b), Vect(c))\n        Reduction by simplex algorithm to find max(c.x) under A.x<=b and x>=0, b>=0. Returns the maximum, the augmented solution x and the reduced matrix. Accepts also [[A|I|b],[-c|*|0]] as argument.\n        Ex1:simplex_reduce([[3,2,2],[1,1,1]],[3,4],[1,2,3])\n        Ex2:simplex_reduce([[3,2,2,1,0,3],[1,1,1,0,1,4],[-1,-2,-3,0,0,0]])\n        Ex3:simplex_reduce([[-3,2],[1,1]],[3,4],[1,2])\n        Ex4:simplex_reduce([[-3,2,1,0,3],[1,1,0,1,4],[-1,-2,0,0,0]])\n        Ex5:simplex_reduce([[2,1,1,1,0,0,2],[1,2,3,0,1,0,5],[2,2,1,0,0,1,6],[-3,-1,-3,1,-1,2,0]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2721simplex_reduce = {"simplex_reduce", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2721simplex_reduce, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2720simplex_reduce};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2721simplex_reduce(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simplex_reduce (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simplex_reduce", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2720simplex_reduce(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2720simplex_reduce(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simplex_reduce", 1);

  /* "giacpy/auto-methods.pxi":16983
 * 
 *         '''
 *         return GiacMethods['simplex_reduce'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simplicial_vertices(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simplex_reduce); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16983, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16971
 *         return GiacMethods['simp2'](self,*args)
 * 
 *      def simplex_reduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplex_reduce:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simplex_reduce", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16985
 *         return GiacMethods['simplex_reduce'](self,*args)
 * 
 *      def simplicial_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplicial_vertices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2723simplicial_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2722simplicial_vertices, "From Giac's documentation:\n        Help for simplicial_vertices:\n        simplicial_vertices(Graph(G))\n        Returns the list of simplicial vertices in an undirected graph G.\n        See also: 1/ is_clique 2/ neighbors \n        Ex1:simplicial_vertices(graph(\"goldner-harary\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2723simplicial_vertices = {"simplicial_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2723simplicial_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2722simplicial_vertices};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2723simplicial_vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simplicial_vertices (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simplicial_vertices", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2722simplicial_vertices(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2722simplicial_vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simplicial_vertices", 1);

  /* "giacpy/auto-methods.pxi":16994
 * 
 *         '''
 *         return GiacMethods['simplicial_vertices'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simplifier(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simplicial_vertices); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 16994, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 16994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 16994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16985
 *         return GiacMethods['simplex_reduce'](self,*args)
 * 
 *      def simplicial_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplicial_vertices:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simplicial_vertices", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":16996
 *         return GiacMethods['simplicial_vertices'](self,*args)
 * 
 *      def simplifier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifier:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2725simplifier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2724simplifier, "From Giac's documentation:\n        Help for simplifier:\n        simplifier(Expr)\n        Simplifies an expression.\n        See also: 1/ normal \n        Ex1:simplifier(4*atan(1/5)-atan(1/239))\n        Ex2:simplifier(texpand((sin(3*x)+sin(7*x))/sin(5*x)))\n        Ex3:simplifier(texpand((cos(3*x)+cos(7*x))/cos(5*x)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2725simplifier = {"simplifier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2725simplifier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2724simplifier};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2725simplifier(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simplifier (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simplifier", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2724simplifier(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2724simplifier(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simplifier", 1);

  /* "giacpy/auto-methods.pxi":17007
 * 
 *         '''
 *         return GiacMethods['simplifier'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simplify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simplifier); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17007, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":16996
 *         return GiacMethods['simplicial_vertices'](self,*args)
 * 
 *      def simplifier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifier:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simplifier", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17009
 *         return GiacMethods['simplifier'](self,*args)
 * 
 *      def simplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2727simplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2726simplify, "From Giac's documentation:\n        Help for simplify:\n        simplify(Expr)\n        Simplifies an expression.\n        See also: 1/ normal \n        Ex1:simplify(4*atan(1/5)-atan(1/239))\n        Ex2:simplify(texpand((sin(3*x)+sin(7*x))/sin(5*x)))\n        Ex3:simplify(texpand((cos(3*x)+cos(7*x))/cos(5*x)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2727simplify = {"simplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2727simplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2726simplify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2727simplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simplify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simplify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2726simplify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2726simplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simplify", 1);

  /* "giacpy/auto-methods.pxi":17020
 * 
 *         '''
 *         return GiacMethods['simplify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simplifyDirac(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simplify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17020, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17009
 *         return GiacMethods['simplifier'](self,*args)
 * 
 *      def simplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simplify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17022
 *         return GiacMethods['simplify'](self,*args)
 * 
 *      def simplifyDirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifyDirac:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2729simplifyDirac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2728simplifyDirac, "From Giac's documentation:\n        Help for simplifyDirac:\n        simplifyDirac(Expr,[Seq(vars)])\n        Simplifies expressions involving Dirac delta distribution.\n        See also: 1/ simplify 2/ Dirac \n        Ex1:simplifyDirac(Dirac(a*x),x)\n        Ex2:simplifyDirac(Dirac(x,1)*x)\n        Ex3:simplifyDirac(Dirac(x^2-x-6))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2729simplifyDirac = {"simplifyDirac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2729simplifyDirac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2728simplifyDirac};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2729simplifyDirac(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simplifyDirac (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simplifyDirac", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2728simplifyDirac(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2728simplifyDirac(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simplifyDirac", 1);

  /* "giacpy/auto-methods.pxi":17033
 * 
 *         '''
 *         return GiacMethods['simplifyDirac'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simpson(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simplifyDirac); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17033, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17022
 *         return GiacMethods['simplify'](self,*args)
 * 
 *      def simplifyDirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifyDirac:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simplifyDirac", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17035
 *         return GiacMethods['simplifyDirac'](self,*args)
 * 
 *      def simpson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simpson:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2731simpson(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2730simpson, "From Giac's documentation:\n        Help for simpson:\n        simpson(Opt)\n        Option of the area command.\n        See also: 1/ area \n        Ex1: area(x^2,x=0..1,5,simpson)\n        Ex2: area(x^2,x=0..1,5,rombergt)\n        Ex3: area(x^2,x=0..1,5,rombergm)\n        Ex4:simpson(area(x^2,x=0..1,5,gauss15))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2731simpson = {"simpson", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2731simpson, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2730simpson};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2731simpson(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simpson (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simpson", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2730simpson(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2730simpson(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simpson", 1);

  /* "giacpy/auto-methods.pxi":17047
 * 
 *         '''
 *         return GiacMethods['simpson'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simulated_annealing(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simpson); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17047, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17035
 *         return GiacMethods['simplifyDirac'](self,*args)
 * 
 *      def simpson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simpson:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simpson", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17049
 *         return GiacMethods['simpson'](self,*args)
 * 
 *      def simulated_annealing(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simulated_annealing:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2733simulated_annealing(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2732simulated_annealing, "From Giac's documentation:\n        Help for simulated_annealing:\n        simulated_annealing(x0,Func(cost),Func(dist),Func(step),Lst(csparam),[Lst(iterparam),[Real(maxstep)]])\n        Returns the point in a search space which minimizes the cost function using the method of simulated annealing, starting from an initial configuration x0.\n        See also: 1/ nlpsolve 2/ fMin 3/ find_minimum \n        Ex1:simulated_annealing(2,x->x^2+sin(20x)/5,(x,y)->abs(x-y),(x,m)->rand(x-m,x+m),[1,0.1,1.002,1e-6],[5,20],1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2733simulated_annealing = {"simulated_annealing", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2733simulated_annealing, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2732simulated_annealing};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2733simulated_annealing(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simulated_annealing (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simulated_annealing", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2732simulated_annealing(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2732simulated_annealing(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simulated_annealing", 1);

  /* "giacpy/auto-methods.pxi":17058
 * 
 *         '''
 *         return GiacMethods['simulated_annealing'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def simult(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simulated_annealing); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17058, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17049
 *         return GiacMethods['simpson'](self,*args)
 * 
 *      def simulated_annealing(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simulated_annealing:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simulated_annealing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17060
 *         return GiacMethods['simulated_annealing'](self,*args)
 * 
 *      def simult(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simult:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2735simult(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2734simult, "From Giac's documentation:\n        Help for simult:\n        simult(Mtrx(A),Mtrx(B))\n        Returns the matrix where the column of index k is solution of A*X=column of index k of B (=B[0..nr-1,k..k] with nr=number of rows of B).\n        See also: 1/ rref 2/ linsolve \n        Ex1:simult([[3,1],[3,2]],[[-2],[2]])\n        Ex2:simult([[3,1],[3,2]],[[-2,1],[2,-1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2735simult = {"simult", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2735simult, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2734simult};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2735simult(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("simult (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "simult", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2734simult(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2734simult(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("simult", 1);

  /* "giacpy/auto-methods.pxi":17070
 * 
 *         '''
 *         return GiacMethods['simult'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_simult); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17070, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17060
 *         return GiacMethods['simulated_annealing'](self,*args)
 * 
 *      def simult(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simult:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.simult", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17072
 *         return GiacMethods['simult'](self,*args)
 * 
 *      def sin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2737sin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2736sin, "From Giac's documentation:\n        Help for sin:\n        sin(Expr or Opt)\n        Sine or option of the convert or convertir command (id trigsin).\n        See also: 1/ asin 2/ convert 3/ trigsin \n        Ex1:sin(0)\n        Ex2: convert(cos(x)^4+sin(x)^2,sin)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2737sin = {"sin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2737sin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2736sin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2737sin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2736sin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2736sin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sin", 1);

  /* "giacpy/auto-methods.pxi":17082
 * 
 *         '''
 *         return GiacMethods['sin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sin2costan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17082, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17072
 *         return GiacMethods['simult'](self,*args)
 * 
 *      def sin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17084
 *         return GiacMethods['sin'](self,*args)
 * 
 *      def sin2costan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin2costan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2739sin2costan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2738sin2costan, "From Giac's documentation:\n        Help for sin2costan:\n        sin2costan(Expr)\n        Replaces sin(x) by cos(x)*tan(x) in the argument.\n        See also: 1/ tan2sincos 2/ cos2sintan 3/ tan2sincos2 4/ tan2cossin2 \n        Ex1:sin2costan(sin(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2739sin2costan = {"sin2costan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2739sin2costan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2738sin2costan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2739sin2costan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sin2costan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sin2costan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2738sin2costan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2738sin2costan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sin2costan", 1);

  /* "giacpy/auto-methods.pxi":17093
 * 
 *         '''
 *         return GiacMethods['sin2costan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sinc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sin2costan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17093, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17084
 *         return GiacMethods['sin'](self,*args)
 * 
 *      def sin2costan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin2costan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sin2costan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17095
 *         return GiacMethods['sin2costan'](self,*args)
 * 
 *      def sinc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2741sinc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2740sinc, "From Giac's documentation:\n        Help for sinc:\n        sinc(Expr(x))\n        Returns the value of the cardinal sine function at x.\n        See also: 1/ sin \n        Ex1:sinc(pi*x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2741sinc = {"sinc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2741sinc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2740sinc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2741sinc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sinc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sinc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2740sinc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2740sinc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sinc", 1);

  /* "giacpy/auto-methods.pxi":17104
 * 
 *         '''
 *         return GiacMethods['sinc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sincos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sinc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17104, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17095
 *         return GiacMethods['sin2costan'](self,*args)
 * 
 *      def sinc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sinc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17106
 *         return GiacMethods['sinc'](self,*args)
 * 
 *      def sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sincos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2743sincos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2742sincos, "From Giac's documentation:\n        Help for sincos:\n        sincos(Expr or Opt)\n        Transforms the complex exponential into sine and cosine (id exp2trig) or option of the convert or convertir command (id sincos).\n        See also: 1/ trig2trig 2/ trig2exp 3/ atrig2ln 4/ convert \n        Ex1:sincos(exp(i*x))\n        Ex2:sincos(exp(-i*x))\n        Ex3: convert(exp(i*x),sincos)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2743sincos = {"sincos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2743sincos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2742sincos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2743sincos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sincos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sincos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2742sincos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2742sincos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sincos", 1);

  /* "giacpy/auto-methods.pxi":17117
 * 
 *         '''
 *         return GiacMethods['sincos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def single_inter(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sincos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17117, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17106
 *         return GiacMethods['sinc'](self,*args)
 * 
 *      def sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sincos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sincos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17119
 *         return GiacMethods['sincos'](self,*args)
 * 
 *      def single_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for single_inter:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2745single_inter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2744single_inter, "From Giac's documentation:\n        Help for single_inter:\n        single_inter(Curve,Curve,[Pnt(A)||LstPnt(L)])\n        Gives one of the points of intersection of 2 curves or surfaces (or the intersection near A or not in L).\n        See also: 1/ intersect 2/ head \n        Ex1:single_inter(line(i,1-i),line(0,1))\n        Ex2:single_inter(line(i,1-i),circle(0,1))\n        Ex3:single_inter(line(i,1+2*i),circle(0,1),[point(i)])\n        Ex4:single_inter(line(-1-i,1+2*i),circle(0,1),point(-1))\n        Ex5:single_inter(circle(1,sqrt(2)),circle(0,1))\n        Ex6:single_inter(plane(x=y),plane(y=z))\n        Ex7:single_inter(line(x=y+1,y=2*z),plane(y=z))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2745single_inter = {"single_inter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2745single_inter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2744single_inter};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2745single_inter(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("single_inter (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "single_inter", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2744single_inter(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2744single_inter(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("single_inter", 1);

  /* "giacpy/auto-methods.pxi":17134
 * 
 *         '''
 *         return GiacMethods['single_inter'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sinh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_single_inter); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17134, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17119
 *         return GiacMethods['sincos'](self,*args)
 * 
 *      def single_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for single_inter:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.single_inter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17136
 *         return GiacMethods['single_inter'](self,*args)
 * 
 *      def sinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2747sinh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2746sinh, "From Giac's documentation:\n        Help for sinh:\n        sinh(Expr)\n        Hyperbolic sine.\n        See also: 1/ asinh \n        Ex1:sinh(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2747sinh = {"sinh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2747sinh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2746sinh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2747sinh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sinh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sinh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2746sinh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2746sinh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sinh", 1);

  /* "giacpy/auto-methods.pxi":17145
 * 
 *         '''
 *         return GiacMethods['sinh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sizes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sinh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17145, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17136
 *         return GiacMethods['single_inter'](self,*args)
 * 
 *      def sinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sinh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17147
 *         return GiacMethods['sinh'](self,*args)
 * 
 *      def sizes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sizes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2749sizes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2748sizes, "From Giac's documentation:\n        Help for sizes:\n        sizes(Lst or Str or Seq)\n        Returns the list of sizes of a list of lists.\n        See also: 1/ size 2/ dim \n        Ex1:sizes([[1,2,3],[1,2],[1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2749sizes = {"sizes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2749sizes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2748sizes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2749sizes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sizes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2748sizes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2748sizes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizes", 1);

  /* "giacpy/auto-methods.pxi":17156
 * 
 *         '''
 *         return GiacMethods['sizes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def slope(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sizes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17156, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17147
 *         return GiacMethods['sinh'](self,*args)
 * 
 *      def sizes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sizes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sizes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17158
 *         return GiacMethods['sizes'](self,*args)
 * 
 *      def slope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slope:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2751slope(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2750slope, "From Giac's documentation:\n        Help for slope:\n        slope(Line||Pnt||Cplx,[Pnt||Cplx])\n        Returns the slope of the line defined in the argument or is an attribute of line.\n        See also: 1/ line 2/ tangent 3/ LinTan 4/ slopeatraw 5/ slopeat \n        Ex1:slope(line(1,2i))\n        Ex2:slope(segment(1,2i))\n        Ex3:slope(1,2i)\n        Ex4:slope(line(y+2x=2))\n        Ex5:slope(point(1),point(2i))\n        Ex6:slope(tangent(plotfunc(sin(x)),pi/4))\n        Ex7:slope(LineTan(sin(x),pi/4))\n        Ex8: line(point(1,2),slope=-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2751slope = {"slope", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2751slope, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2750slope};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2751slope(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("slope (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "slope", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2750slope(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2750slope(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("slope", 1);

  /* "giacpy/auto-methods.pxi":17174
 * 
 *         '''
 *         return GiacMethods['slope'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def slopeat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_slope); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17174, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17158
 *         return GiacMethods['sizes'](self,*args)
 * 
 *      def slope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slope:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.slope", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17176
 *         return GiacMethods['slope'](self,*args)
 * 
 *      def slopeat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2753slopeat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2752slopeat, "From Giac's documentation:\n        Help for slopeat:\n        slopeat(Line, Pnt||Cplx(z0))\n        slopeat(d,z0) displays at the point(z0), with a legend, the value of the slope of the line or segment d.\n        See also: 1/ slope 2/ slopeatraw \n        Ex1: A:=point(0);B:=point(1+i);slopeat(droite(A,B),(1+i)/2)\n        Ex2: s:=segment(1-i,i);slopeat(s,point(0.4))\n        Ex3: t:=tangent(plotfunc(sin(x)),pi/4);slopeat(t,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2753slopeat = {"slopeat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2753slopeat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2752slopeat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2753slopeat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("slopeat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "slopeat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2752slopeat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2752slopeat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("slopeat", 1);

  /* "giacpy/auto-methods.pxi":17187
 * 
 *         '''
 *         return GiacMethods['slopeat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def slopeatraw(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_slopeat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17187, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17176
 *         return GiacMethods['slope'](self,*args)
 * 
 *      def slopeat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.slopeat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17189
 *         return GiacMethods['slopeat'](self,*args)
 * 
 *      def slopeatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeatraw:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2755slopeatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2754slopeatraw, "From Giac's documentation:\n        Help for slopeatraw:\n        slopeatraw(Line, Pnt||Cplx(z0))\n        slopeatraw(d,z0) displays at point(z0), the value of the slope of the line or segment d.\n        See also: 1/ slope 2/ slopeat \n        Ex1: A:=point(0);B:=point(1+i);slopeatraw(droite(A,B),(1+i)/2)\n        Ex2: s:=segment(1-i,i);slopeatraw(s,point(0.4))\n        Ex3:slopeatraw(tangent(plotfunc(sin(x)),pi/4),0)\n        Ex4:slopeatraw((LineTan sin(x),pi/4),i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2755slopeatraw = {"slopeatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2755slopeatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2754slopeatraw};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2755slopeatraw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("slopeatraw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "slopeatraw", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2754slopeatraw(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2754slopeatraw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("slopeatraw", 1);

  /* "giacpy/auto-methods.pxi":17201
 * 
 *         '''
 *         return GiacMethods['slopeatraw'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def smith(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_slopeatraw); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17201, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17189
 *         return GiacMethods['slopeat'](self,*args)
 * 
 *      def slopeatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeatraw:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.slopeatraw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17203
 *         return GiacMethods['slopeatraw'](self,*args)
 * 
 *      def smith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smith:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2757smith(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2756smith, "From Giac's documentation:\n        Help for smith:\n        smith(Matr(A))\n        Returns the Smith normal form of a matrix with polynomial coefficients (U,D,V tels que U*A*V=D)\n        See also: 1/ hermite 2/ ismith 3/ ihermite \n        Ex1: n:=10; a:=ranm(n,n) % 17; u,b,v:=smith(x-a);normal(u*(x-a)*v-b); diag(b);\n        Ex2: GF(3,5,g); n:=3; a:=ranm(n,n,g); u,b,v:=smith(x-a);normal(u*(x-a)*v-b); diag(b);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2757smith = {"smith", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2757smith, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2756smith};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2757smith(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("smith (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "smith", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2756smith(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2756smith(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("smith", 1);

  /* "giacpy/auto-methods.pxi":17213
 * 
 *         '''
 *         return GiacMethods['smith'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def smod(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_smith); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17213, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17203
 *         return GiacMethods['slopeatraw'](self,*args)
 * 
 *      def smith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smith:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.smith", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17215
 *         return GiacMethods['smith'](self,*args)
 * 
 *      def smod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smod:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2759smod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2758smod, "From Giac's documentation:\n        Help for smod:\n        smod(Intg,Intg)\n        Returns the Euclidean symmetric remainder of two integers.\n        See also: 1/ irem 2/ iquo 3/ mod 4/ fracmod \n        Ex1:smod(8,3)\n        Ex2:smod(10,4)\n        Ex3:smod(11,7)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2759smod = {"smod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2759smod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2758smod};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2759smod(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("smod (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "smod", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2758smod(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2758smod(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("smod", 1);

  /* "giacpy/auto-methods.pxi":17226
 * 
 *         '''
 *         return GiacMethods['smod'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def snedecor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_smod); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17226, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17215
 *         return GiacMethods['smith'](self,*args)
 * 
 *      def smod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smod:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.smod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17228
 *         return GiacMethods['smod'](self,*args)
 * 
 *      def snedecor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2761snedecor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2760snedecor, "From Giac's documentation:\n        Help for snedecor:\n        snedecor(Intg(n),Intg(m),Real(x0))\n        Returns the probability density of the Fisher-Snedecor law (n and m are the numbers of degrees of freedom).\n        See also: 1/ fisher_cdf 2/ fisher_icdf 3/ randvector 4/ ranm \n        Ex1:snedecor(4,10,2.1)\n        Ex2:snedecor(4,4,2.1)\n        Ex3: randvector(5,fisher,4,6)\n        Ex4: ranm(2,3,fisher,4,6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2761snedecor = {"snedecor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2761snedecor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2760snedecor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2761snedecor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("snedecor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "snedecor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2760snedecor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2760snedecor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("snedecor", 1);

  /* "giacpy/auto-methods.pxi":17240
 * 
 *         '''
 *         return GiacMethods['snedecor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def snedecor_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_snedecor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17240, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17228
 *         return GiacMethods['smod'](self,*args)
 * 
 *      def snedecor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.snedecor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17242
 *         return GiacMethods['snedecor'](self,*args)
 * 
 *      def snedecor_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2763snedecor_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2762snedecor_cdf, "From Giac's documentation:\n        Help for snedecor_cdf:\n        snedecor_cdf(Intg(n),Intg(m),Real(x0))\n        Returns the probability that a Fisher-Snedecor random variable is less than x0 (n and m are the numbers of degrees of freedom).\n        See also: 1/ UTPF 2/ fisher_icdf 3/ fisherd \n        Ex1:snedecor_cdf(4,4,2.1)\n        Ex2:snedecor_cdf(4,10,3.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2763snedecor_cdf = {"snedecor_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2763snedecor_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2762snedecor_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2763snedecor_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("snedecor_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "snedecor_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2762snedecor_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2762snedecor_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("snedecor_cdf", 1);

  /* "giacpy/auto-methods.pxi":17252
 * 
 *         '''
 *         return GiacMethods['snedecor_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def snedecor_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_snedecor_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17252, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17242
 *         return GiacMethods['snedecor'](self,*args)
 * 
 *      def snedecor_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.snedecor_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17254
 *         return GiacMethods['snedecor_cdf'](self,*args)
 * 
 *      def snedecor_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2765snedecor_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2764snedecor_icdf, "From Giac's documentation:\n        Help for snedecor_icdf:\n        snedecor_icdf(Intg(n),Intg(m),Real(p))\n        Returns h such as the probability that a Fisher-Snedecor random variable is less than h is p (n and m are the numbers of degrees of freedom and 0<=p<=1).\n        See also: 1/ fisher_cdf 2/ fisherd \n        Ex1:snedecor_icdf(4,10,0.95)\n        Ex2:snedecor_icdf(4,10,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2765snedecor_icdf = {"snedecor_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2765snedecor_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2764snedecor_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2765snedecor_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("snedecor_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "snedecor_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2764snedecor_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2764snedecor_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("snedecor_icdf", 1);

  /* "giacpy/auto-methods.pxi":17264
 * 
 *         '''
 *         return GiacMethods['snedecor_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def snedecord(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_snedecor_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17264, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17254
 *         return GiacMethods['snedecor_cdf'](self,*args)
 * 
 *      def snedecor_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.snedecor_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17266
 *         return GiacMethods['snedecor_icdf'](self,*args)
 * 
 *      def snedecord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2767snedecord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2766snedecord, "From Giac's documentation:\n        Help for snedecord:\n        snedecord(Intg(n),Intg(m),Real(x0))\n        Returns the probability density of the Fisher-Snedecor law (n and m are the numbers of degrees of freedom).\n        See also: 1/ fisher_cdf 2/ fisher_icdf 3/ randvector 4/ ranm \n        Ex1:snedecord(4,10,2.1)\n        Ex2:snedecord(4,4,2.1)\n        Ex3: randvector(5,fisher,4,6)\n        Ex4: ranm(2,3,fisher,4,6)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2767snedecord = {"snedecord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2767snedecord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2766snedecord};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2767snedecord(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("snedecord (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "snedecord", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2766snedecord(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2766snedecord(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("snedecord", 1);

  /* "giacpy/auto-methods.pxi":17278
 * 
 *         '''
 *         return GiacMethods['snedecord'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def snedecord_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_snedecord); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17278, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17266
 *         return GiacMethods['snedecor_icdf'](self,*args)
 * 
 *      def snedecord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.snedecord", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17280
 *         return GiacMethods['snedecord'](self,*args)
 * 
 *      def snedecord_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2769snedecord_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2768snedecord_cdf, "From Giac's documentation:\n        Help for snedecord_cdf:\n        snedecord_cdf(Intg(n),Intg(m),Real(x0))\n        Returns the probability that a Fisher-Snedecor random variable is less than x0 (n and m are the numbers of degrees of freedom).\n        See also: 1/ UTPF 2/ fisher_icdf 3/ fisherd \n        Ex1:snedecord_cdf(4,4,2.1)\n        Ex2:snedecord_cdf(4,10,3.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2769snedecord_cdf = {"snedecord_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2769snedecord_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2768snedecord_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2769snedecord_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("snedecord_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "snedecord_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2768snedecord_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2768snedecord_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("snedecord_cdf", 1);

  /* "giacpy/auto-methods.pxi":17290
 * 
 *         '''
 *         return GiacMethods['snedecord_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def snedecord_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_snedecord_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17290, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17280
 *         return GiacMethods['snedecord'](self,*args)
 * 
 *      def snedecord_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.snedecord_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17292
 *         return GiacMethods['snedecord_cdf'](self,*args)
 * 
 *      def snedecord_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2771snedecord_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2770snedecord_icdf, "From Giac's documentation:\n        Help for snedecord_icdf:\n        snedecord_icdf(Intg(n),Intg(m),Real(p))\n        Returns h such as the probability that a Fisher-Snedecor random variable is less than h is p (n and m are the numbers of degrees of freedom and 0<=p<=1).\n        See also: 1/ fisher_cdf 2/ fisherd \n        Ex1:snedecord_icdf(4,10,0.95)\n        Ex2:snedecord_icdf(4,10,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2771snedecord_icdf = {"snedecord_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2771snedecord_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2770snedecord_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2771snedecord_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("snedecord_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "snedecord_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2770snedecord_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2770snedecord_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("snedecord_icdf", 1);

  /* "giacpy/auto-methods.pxi":17302
 * 
 *         '''
 *         return GiacMethods['snedecord_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def solid_line(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_snedecord_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17302, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17292
 *         return GiacMethods['snedecord_cdf'](self,*args)
 * 
 *      def snedecord_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.snedecord_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17304
 *         return GiacMethods['snedecord_icdf'](self,*args)
 * 
 *      def solid_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solid_line:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2773solid_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2772solid_line, "From Giac's documentation:\n        Help for solid_line:\n        solid_line(Opt)\n        Option of the display command for a line.\n        See also: 1/ display \n        Ex1: display(line(y=x),green+dash_line+line_width_2)\n        Ex2: d:=display(line(2+i,1),cap_round_line)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2773solid_line = {"solid_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2773solid_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2772solid_line};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2773solid_line(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("solid_line (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "solid_line", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2772solid_line(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2772solid_line(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("solid_line", 1);

  /* "giacpy/auto-methods.pxi":17314
 * 
 *         '''
 *         return GiacMethods['solid_line'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def solve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_solid_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17314, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17304
 *         return GiacMethods['snedecord_icdf'](self,*args)
 * 
 *      def solid_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solid_line:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.solid_line", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17316
 *         return GiacMethods['solid_line'](self,*args)
 * 
 *      def solve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2775solve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2774solve, "From Giac's documentation:\n        Help for solve:\n        solve(Expr,[Var])\n        Solves a (or a set of) polynomial equation.\n        See also: 1/ linsolve 2/ proot 3/ fsolve 4/ csolve 5/ nSolve \n        Ex1:solve(x^2-3=1)\n        Ex2:solve(x^3-3*y,y)\n        Ex3:solve([y-z=0,z-x=0,x-y=0,x-1+y+z=0],[x,y,z])\n        Ex4:solve([x^2-y^2=0,x^2-z^2=0],[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2775solve = {"solve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2775solve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2774solve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2775solve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("solve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "solve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2774solve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2774solve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("solve", 1);

  /* "giacpy/auto-methods.pxi":17328
 * 
 *         '''
 *         return GiacMethods['solve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def somme(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_solve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17328, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17316
 *         return GiacMethods['solid_line'](self,*args)
 * 
 *      def solve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.solve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17330
 *         return GiacMethods['solve'](self,*args)
 * 
 *      def somme(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for somme:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2777somme(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2776somme, "From Giac's documentation:\n        Help for somme:\n        somme(Expr,Var,VarMin(a),VarMax(b),[VarStep(p)])\n        Discrete sum (with 2 or 4 arguments return then sum from a to b if a<=b or of the opposite of the sum from b+1 to a-1 if a>b+1 or 0 if a=b+1) or the discrete primitive or sum of the elements of a list or a sequence.\n        See also: 1/ + \n        Ex1:somme(1/n^2,n,1,17)\n        Ex2:somme(1/n^2,n=1..17)\n        Ex3:somme(1/n^2,n,17,1)\n        Ex4:somme(1/n^2,n=17..1)\n        Ex5:somme(1/n^2,n,17,1,1)\n        Ex6:somme(1/n^2,n,1,17,2)\n        Ex7:somme([1,2,3,4])\n        Ex8:somme([[1,2,3,4,5,6,7,8,9],[1,2,3,4,5,6,7,8,9]])\n        Ex9:somme(1/(x*(x+1)),x)\n        Ex10:somme(cos(n*x),n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2777somme = {"somme", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2777somme, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2776somme};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2777somme(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("somme (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "somme", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2776somme(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2776somme(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("somme", 1);

  /* "giacpy/auto-methods.pxi":17348
 * 
 *         '''
 *         return GiacMethods['somme'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sommet(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_somme); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17348, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17330
 *         return GiacMethods['solve'](self,*args)
 * 
 *      def somme(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for somme:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.somme", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17350
 *         return GiacMethods['somme'](self,*args)
 * 
 *      def sommet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sommet:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2779sommet(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2778sommet, "From Giac's documentation:\n        Help for sommet:\n        sommet(Op or Fnct)\n        Returns the top of an operator.\n        See also: 1/ feuille 2/ quote \n        Ex1:sommet(quote(gcd(45,123)))\n        Ex2:sommet('gcd(45,123)')\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2779sommet = {"sommet", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2779sommet, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2778sommet};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2779sommet(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sommet (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sommet", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2778sommet(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2778sommet(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sommet", 1);

  /* "giacpy/auto-methods.pxi":17360
 * 
 *         '''
 *         return GiacMethods['sommet'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sort(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sommet); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17360, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17350
 *         return GiacMethods['somme'](self,*args)
 * 
 *      def sommet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sommet:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sommet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17362
 *         return GiacMethods['sommet'](self,*args)
 * 
 *      def sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sort:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2781sort(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2780sort, "From Giac's documentation:\n        Help for sort:\n        sort(LstReal or Seq [Fnc])\n        Returns the sorted list (or sequence) with increasing order according to the second argument which defines a weak strict ordering or sorts and collects equal terms in sums and products.\n        See also: 1/ SortA 2/ SortD \n        Ex1:sort([3,2,2,4,1,0])\n        Ex2:sort(3,2.1,2,4,1,0)\n        Ex3:sort([3,4,2],(x,y)->x>y)\n        Ex4:sort([[1,2],[2,3],[4,3]],(x,y)->when(x[1]==y[1],x[0]>y[0],x[1]>y[1]))\n        Ex5:sort(y*x*2+x*y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2781sort = {"sort", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2781sort, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2780sort};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2781sort(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sort (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sort", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2780sort(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2780sort(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sort", 1);

  /* "giacpy/auto-methods.pxi":17375
 * 
 *         '''
 *         return GiacMethods['sort'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sorta(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sort); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17375, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17362
 *         return GiacMethods['sommet'](self,*args)
 * 
 *      def sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sort:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17377
 *         return GiacMethods['sort'](self,*args)
 * 
 *      def sorta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorta:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2783sorta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2782sorta, "From Giac's documentation:\n        Help for sorta:\n        sorta(LstReal||Seq\303\227||Mtrx)\n        Sorts the list in increasing order or sorts the columns of the matrix so the first row is in increasing order.\n        See also: 1/ SortA 2/ sortd 3/ sort \n        Ex1:sorta(3,4,2)\n        Ex2:sorta([3,4,2])\n        Ex3:sorta([[3,4,2],[6,4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2783sorta = {"sorta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2783sorta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2782sorta};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2783sorta(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sorta (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sorta", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2782sorta(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2782sorta(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sorta", 1);

  /* "giacpy/auto-methods.pxi":17388
 * 
 *         '''
 *         return GiacMethods['sorta'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sortd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sorta); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17388, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17377
 *         return GiacMethods['sort'](self,*args)
 * 
 *      def sorta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorta:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sorta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17390
 *         return GiacMethods['sorta'](self,*args)
 * 
 *      def sortd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2785sortd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2784sortd, "From Giac's documentation:\n        Help for sortd:\n        sortd(LstReal||Seq||Mtrx)\n        Sorts the list in decreasing order or sorts the columns of the matrix so the first row is in decreasing order.\n        See also: 1/ SortD 2/ sorta 3/ sort \n        Ex1:sortd(3,4,2)\n        Ex2:sortd([3,4,2])\n        Ex3:sortd([[3,4,2],[6,4,5]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2785sortd = {"sortd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2785sortd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2784sortd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2785sortd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sortd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sortd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2784sortd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2784sortd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sortd", 1);

  /* "giacpy/auto-methods.pxi":17401
 * 
 *         '''
 *         return GiacMethods['sortd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sorted(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sortd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17401, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17390
 *         return GiacMethods['sorta'](self,*args)
 * 
 *      def sortd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sortd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17403
 *         return GiacMethods['sortd'](self,*args)
 * 
 *      def sorted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorted:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2787sorted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2786sorted, "From Giac's documentation:\n        Help for sorted:\n        sorted(LstReal or Seq [Fnc])\n        Returns the sorted list (or sequence) with increasing order according to the second argument which defines a weak strict ordering or sorts and collects equal terms in sums and products.\n        See also: 1/ SortA 2/ SortD \n        Ex1:sorted([3,2,2,4,1,0])\n        Ex2:sorted(3,2.1,2,4,1,0)\n        Ex3:sorted([3,4,2],(x,y)->x>y)\n        Ex4:sorted([[1,2],[2,3],[4,3]],(x,y)->when(x[1]==y[1],x[0]>y[0],x[1]>y[1]))\n        Ex5:sorted(y*x*2+x*y)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2787sorted = {"sorted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2787sorted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2786sorted};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2787sorted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sorted (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sorted", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2786sorted(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2786sorted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sorted", 1);

  /* "giacpy/auto-methods.pxi":17416
 * 
 *         '''
 *         return GiacMethods['sorted'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sortperm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sorted); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17416, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17403
 *         return GiacMethods['sortd'](self,*args)
 * 
 *      def sorted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorted:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sorted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17418
 *         return GiacMethods['sorted'](self,*args)
 * 
 *      def sortperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortperm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2789sortperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2788sortperm, "From Giac's documentation:\n        Help for sortperm:\n        sortperm(Lst(V),[Permu(P)])\n        Sorts the list V according to the permutation P or outputs the permutation which sorts V in ascending order.\n        See also: 1/ sort 2/ sortA \n        Ex1:sortperm([30,25,40,10,20])\n        Ex2:sortperm([\"ab\",\"cd\",\"ad\",\"bc\",\"de\"],[3,4,1,0,2])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2789sortperm = {"sortperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2789sortperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2788sortperm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2789sortperm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sortperm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sortperm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2788sortperm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2788sortperm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sortperm", 1);

  /* "giacpy/auto-methods.pxi":17428
 * 
 *         '''
 *         return GiacMethods['sortperm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def soundsec(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sortperm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17428, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17418
 *         return GiacMethods['sorted'](self,*args)
 * 
 *      def sortperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortperm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sortperm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17430
 *         return GiacMethods['sortperm'](self,*args)
 * 
 *      def soundsec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for soundsec:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2791soundsec(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2790soundsec, "From Giac's documentation:\n        Help for soundsec:\n        soundsec(Intg(n),[Intg(N)])\n        Generates a vector coding n seconds of time/N (default N=44100).\n        See also: 1/ readwav 2/ writewav 3/ playsnd \n        Ex1:soundsec(1)\n        Ex2:soundsec(1,22100)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2791soundsec = {"soundsec", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2791soundsec, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2790soundsec};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2791soundsec(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("soundsec (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "soundsec", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2790soundsec(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2790soundsec(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("soundsec", 1);

  /* "giacpy/auto-methods.pxi":17440
 * 
 *         '''
 *         return GiacMethods['soundsec'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def spanning_tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_soundsec); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17440, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17430
 *         return GiacMethods['sortperm'](self,*args)
 * 
 *      def soundsec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for soundsec:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.soundsec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17442
 *         return GiacMethods['soundsec'](self,*args)
 * 
 *      def spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spanning_tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2793spanning_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2792spanning_tree, "From Giac's documentation:\n        Help for spanning_tree:\n        spanning_tree(Graph(G),[Vrtx(r)])\n        Returns a spanning tree of an undirected graph G [with r as the root node].\n        See also: 1/ number_of_spanning_trees 2/ minimal_spanning_tree \n        Ex1:spanning_tree(graph(\"petersen\"))\n        Ex2:spanning_tree(graph(\"petersen\"),5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2793spanning_tree = {"spanning_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2793spanning_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2792spanning_tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2793spanning_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("spanning_tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "spanning_tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2792spanning_tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2792spanning_tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("spanning_tree", 1);

  /* "giacpy/auto-methods.pxi":17452
 * 
 *         '''
 *         return GiacMethods['spanning_tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sphere(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_spanning_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17452, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17442
 *         return GiacMethods['soundsec'](self,*args)
 * 
 *      def spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spanning_tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.spanning_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17454
 *         return GiacMethods['spanning_tree'](self,*args)
 * 
 *      def sphere(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sphere:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2795sphere(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2794sphere, "From Giac's documentation:\n        Help for sphere:\n        sphere((Pnt or Vect),(Pnt or Real))\n        sphere(A,B) (resp sphere(A,r)) draws the sphere with diameter AB (resp center A and radius r) in 3D space.\n        See also: 1/ circle \n        Ex1:sphere([0,0,0],[2,2,2])\n        Ex2:sphere([1,1,1],1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2795sphere = {"sphere", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2795sphere, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2794sphere};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2795sphere(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sphere (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sphere", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2794sphere(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2794sphere(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sphere", 1);

  /* "giacpy/auto-methods.pxi":17464
 * 
 *         '''
 *         return GiacMethods['sphere'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def splice(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sphere); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17464, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17454
 *         return GiacMethods['spanning_tree'](self,*args)
 * 
 *      def sphere(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sphere:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sphere", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17466
 *         return GiacMethods['sphere'](self,*args)
 * 
 *      def splice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for splice:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2797splice(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2796splice, "From Giac's documentation:\n        Help for splice:\n        splice(Audio(clip1),Audio(clip2),[Intg(len),Real(p)])\n        Joins clip1 and clip2 with overlap of length len and crossfade determined by p>0.\n        See also: 1/ + 2/ mixdown \n        Ex1: t:=soundsec(2):;clip:=splice(createwav(sin(2*pi*440*t)),createwav(sin(2*pi*220*t)),1000,0.75):;playsnd(clip)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2797splice = {"splice", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2797splice, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2796splice};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2797splice(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("splice (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "splice", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2796splice(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2796splice(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("splice", 1);

  /* "giacpy/auto-methods.pxi":17475
 * 
 *         '''
 *         return GiacMethods['splice'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def spline(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_splice); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17475, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17466
 *         return GiacMethods['sphere'](self,*args)
 * 
 *      def splice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for splice:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.splice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17477
 *         return GiacMethods['splice'](self,*args)
 * 
 *      def spline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spline:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2799spline(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2798spline, "From Giac's documentation:\n        Help for spline:\n        spline(Lst(lx),Lst(ly),Var(x),Intg(d))\n        Natural spline through the points given by the lx and ly lists, variable x, degree d.\n        See also: 1/ lagrange \n        Ex1:spline([0,1,2],[1,3,0],x,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2799spline = {"spline", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2799spline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2798spline};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2799spline(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("spline (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "spline", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2798spline(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2798spline(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("spline", 1);

  /* "giacpy/auto-methods.pxi":17486
 * 
 *         '''
 *         return GiacMethods['spline'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def split(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_spline); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17486, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17477
 *         return GiacMethods['splice'](self,*args)
 * 
 *      def spline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spline:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.spline", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17488
 *         return GiacMethods['spline'](self,*args)
 * 
 *      def split(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for split:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2801split(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2800split, "From Giac's documentation:\n        Help for split:\n        split((Expr(Xpr),Lst(var1,var2))||(Str(s),Str(sep)))\n        Splits the two variables var1,var2 of the expression Xpr (without denominator) or returns [0], or splits a string into a list of substrings with respect to a given separator.\n        See also: 1/ factor 2/ join \n        Ex1:split(x^3*y^2-y^2+x^3-1,[x,y])\n        Ex2:split(x^3*y^2-y^2+x^3+1,[x,y])\n        Ex3:split(\"This is a phrase\",\" \")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2801split = {"split", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2801split, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2800split};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2801split(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "split", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2800split(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2800split(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("split", 1);

  /* "giacpy/auto-methods.pxi":17499
 * 
 *         '''
 *         return GiacMethods['split'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def spring(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_split); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17499, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17488
 *         return GiacMethods['spline'](self,*args)
 * 
 *      def split(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for split:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17501
 *         return GiacMethods['split'](self,*args)
 * 
 *      def spring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spring:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2803spring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2802spring, "From Giac's documentation:\n        Help for spring:\n        spring(Opt)\n        Option for the draw_graph command.\n        See also: 1/ planar 2/ tree 3/ draw_graph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2803spring = {"spring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2803spring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2802spring};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2803spring(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("spring (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "spring", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2802spring(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2802spring(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("spring", 1);

  /* "giacpy/auto-methods.pxi":17509
 * 
 *         '''
 *         return GiacMethods['spring'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_spring); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17509, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17501
 *         return GiacMethods['split'](self,*args)
 * 
 *      def spring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spring:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.spring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17511
 *         return GiacMethods['spring'](self,*args)
 * 
 *      def sq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2805sq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2804sq, "From Giac's documentation:\n        Help for sq:\n        sq(Seq)\n        Is the name of the function (\342\204\235^n -> \342\204\235)=sum of the squares of the arguments.\n        See also: 1/ sqrt \n        Ex1:sq(5)\n        Ex2:sq(1,2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2805sq = {"sq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2805sq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2804sq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2805sq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2804sq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2804sq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sq", 1);

  /* "giacpy/auto-methods.pxi":17521
 * 
 *         '''
 *         return GiacMethods['sq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sqrfree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17521, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17511
 *         return GiacMethods['spring'](self,*args)
 * 
 *      def sq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17523
 *         return GiacMethods['sq'](self,*args)
 * 
 *      def sqrfree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrfree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2807sqrfree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2806sqrfree, "From Giac's documentation:\n        Help for sqrfree:\n        sqrfree(Expr)\n        Factorization of the its argument gathering the terms with the same exponent.\n        See also: 1/ factor \n        Ex1:sqrfree(x^4-2*x^2+1)\n        Ex2:sqrfree((x-2)^7*(x+2)^7*(x^4-2*x^2+1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2807sqrfree = {"sqrfree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2807sqrfree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2806sqrfree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2807sqrfree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sqrfree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sqrfree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2806sqrfree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2806sqrfree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sqrfree", 1);

  /* "giacpy/auto-methods.pxi":17533
 * 
 *         '''
 *         return GiacMethods['sqrfree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sqrt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sqrfree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17533, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17523
 *         return GiacMethods['sq'](self,*args)
 * 
 *      def sqrfree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrfree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sqrfree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17535
 *         return GiacMethods['sqrfree'](self,*args)
 * 
 *      def sqrt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2809sqrt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2808sqrt, "From Giac's documentation:\n        Help for sqrt:\n        sqrt(Expr)\n        Square root.\n        See also: 1/ surd 2/ ^ \n        Ex1:sqrt(50)\n        Ex2:sqrt(x^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2809sqrt = {"sqrt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2809sqrt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2808sqrt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2809sqrt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sqrt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sqrt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2808sqrt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2808sqrt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sqrt", 1);

  /* "giacpy/auto-methods.pxi":17545
 * 
 *         '''
 *         return GiacMethods['sqrt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def square(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sqrt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17545, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17535
 *         return GiacMethods['sqrfree'](self,*args)
 * 
 *      def sqrt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sqrt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17547
 *         return GiacMethods['sqrt'](self,*args)
 * 
 *      def square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2811square(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2810square, "From Giac's documentation:\n        Help for square:\n        square((Pnt(A) or Cplx),(Pnt(B) or Cplx),[Pnt(P),Var(C),Var(D)])\n        Returns and draws the square of side AB (ABCD is direct) (in the plane ABP).\n        See also: 1/ rhombus 2/ quadrilateral \n        Ex1:square(i,1+i)\n        Ex2:square(i,1+i,C,D)\n        Ex3:square(point(0,0,0),point(3,3,3),point(0,0,3))\n        Ex4:square(point(0,0,0),point(3,3,3),point(0,0,3),C,D)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2811square = {"square", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2811square, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2810square};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2811square(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("square (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "square", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2810square(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2810square(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("square", 1);

  /* "giacpy/auto-methods.pxi":17559
 * 
 *         '''
 *         return GiacMethods['square'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def square_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_square); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17559, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17547
 *         return GiacMethods['sqrt'](self,*args)
 * 
 *      def square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.square", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17561
 *         return GiacMethods['square'](self,*args)
 * 
 *      def square_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2813square_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2812square_point, "From Giac's documentation:\n        Help for square_point:\n        square_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2813square_point = {"square_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2813square_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2812square_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2813square_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("square_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "square_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2812square_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2812square_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("square_point", 1);

  /* "giacpy/auto-methods.pxi":17571
 * 
 *         '''
 *         return GiacMethods['square_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def srand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_square_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17571, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17561
 *         return GiacMethods['square'](self,*args)
 * 
 *      def square_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.square_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17573
 *         return GiacMethods['square_point'](self,*args)
 * 
 *      def srand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for srand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2815srand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2814srand, "From Giac's documentation:\n        Help for srand:\n        srand()\n        srand returns an integer and initializes the sequence of random numbers.\n        See also: 1/ RandSeed \n        Ex1:srand(12)\n        Ex2: srand\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2815srand = {"srand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2815srand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2814srand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2815srand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("srand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "srand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2814srand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2814srand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("srand", 1);

  /* "giacpy/auto-methods.pxi":17583
 * 
 *         '''
 *         return GiacMethods['srand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sst(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_srand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17583, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17573
 *         return GiacMethods['square_point'](self,*args)
 * 
 *      def srand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for srand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.srand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17585
 *         return GiacMethods['srand'](self,*args)
 * 
 *      def sst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2817sst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2816sst, "From Giac's documentation:\n        Help for sst:\n        sst(NULL)\n        Steps 1 instruction.\n        See also: 1/  \n        Ex1:sst()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2817sst = {"sst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2817sst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2816sst};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2817sst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sst (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sst", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2816sst(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2816sst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sst", 1);

  /* "giacpy/auto-methods.pxi":17594
 * 
 *         '''
 *         return GiacMethods['sst'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sst_in(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sst); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17594, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17585
 *         return GiacMethods['srand'](self,*args)
 * 
 *      def sst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sst", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17596
 *         return GiacMethods['sst'](self,*args)
 * 
 *      def sst_in(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst_in:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2819sst_in(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2818sst_in, "From Giac's documentation:\n        Help for sst_in:\n        sst_in(NULL)\n        Enters into a function in step-by-step mode.\n        See also: 1/  \n        Ex1:sst_in()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2819sst_in = {"sst_in", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2819sst_in, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2818sst_in};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2819sst_in(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sst_in (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sst_in", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2818sst_in(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2818sst_in(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sst_in", 1);

  /* "giacpy/auto-methods.pxi":17605
 * 
 *         '''
 *         return GiacMethods['sst_in'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def st_ordering(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sst_in); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17605, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17596
 *         return GiacMethods['sst'](self,*args)
 * 
 *      def sst_in(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst_in:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sst_in", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17607
 *         return GiacMethods['sst_in'](self,*args)
 * 
 *      def st_ordering(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for st_ordering:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2821st_ordering(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2820st_ordering, "From Giac's documentation:\n        Help for st_ordering:\n        st_ordering(Graph(G),Vrtx(s),Vrtx(t))\n        Returns ST numbering for a biconnected graph G with source s and sink (target) t.\n        See also: 1/ is_biconnected \n        Ex1:st_ordering(graph(\"petersen\"),1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2821st_ordering = {"st_ordering", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2821st_ordering, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2820st_ordering};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2821st_ordering(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("st_ordering (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "st_ordering", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2820st_ordering(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2820st_ordering(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("st_ordering", 1);

  /* "giacpy/auto-methods.pxi":17616
 * 
 *         '''
 *         return GiacMethods['st_ordering'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def star_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_st_ordering); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17616, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17607
 *         return GiacMethods['sst_in'](self,*args)
 * 
 *      def st_ordering(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for st_ordering:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.st_ordering", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17618
 *         return GiacMethods['st_ordering'](self,*args)
 * 
 *      def star_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2823star_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2822star_graph, "From Giac's documentation:\n        Help for star_graph:\n        star_graph(Intg(n))\n        Returns a complete bipartite graph complete_graph(1,n).\n        See also: 1/ complete_graph 2/ wheel_graph \n        Ex1:star_graph(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2823star_graph = {"star_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2823star_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2822star_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2823star_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("star_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "star_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2822star_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2822star_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("star_graph", 1);

  /* "giacpy/auto-methods.pxi":17627
 * 
 *         '''
 *         return GiacMethods['star_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def star_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_star_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17627, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17618
 *         return GiacMethods['st_ordering'](self,*args)
 * 
 *      def star_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.star_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17629
 *         return GiacMethods['star_graph'](self,*args)
 * 
 *      def star_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2825star_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2824star_point, "From Giac's documentation:\n        Help for star_point:\n        star_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2825star_point = {"star_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2825star_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2824star_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2825star_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("star_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "star_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2824star_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2824star_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("star_point", 1);

  /* "giacpy/auto-methods.pxi":17639
 * 
 *         '''
 *         return GiacMethods['star_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def stdDev(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_star_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17639, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17629
 *         return GiacMethods['star_graph'](self,*args)
 * 
 *      def star_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.star_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17641
 *         return GiacMethods['star_point'](self,*args)
 * 
 *      def stdDev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stdDev:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2827stdDev(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2826stdDev, "From Giac's documentation:\n        Help for stdDev:\n        stdDev(Lst||Mtrx,[Lst])\n        Returns an unbiased estimate of the population standard deviation of the sample (first argument) with an optional list of weight as second argument.\n        See also: 1/ mean 2/ stddev \n        Ex1:stdDev([1,2,3])\n        Ex2:stdDev([1,2,3],[1,2,1])\n        Ex3:stdDev([[1,2,3],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2827stdDev = {"stdDev", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2827stdDev, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2826stdDev};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2827stdDev(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stdDev (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "stdDev", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2826stdDev(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2826stdDev(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stdDev", 1);

  /* "giacpy/auto-methods.pxi":17652
 * 
 *         '''
 *         return GiacMethods['stdDev'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def stddev(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_stdDev); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17652, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17641
 *         return GiacMethods['star_point'](self,*args)
 * 
 *      def stdDev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stdDev:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.stdDev", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17654
 *         return GiacMethods['stdDev'](self,*args)
 * 
 *      def stddev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddev:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2829stddev(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2828stddev, "From Giac's documentation:\n        Help for stddev:\n        stddev(Lst||Mtrx,[Lst])\n        Returns the standard deviation of the elements of its argument with an optional second argument as weight or the list of standard deviations of the columns of a matrix.\n        See also: 1/ mean 2/ variance 3/ stddevp \n        Ex1:stddev([1,2,3])\n        Ex2:stddev([1,2,3],[1,2,1])\n        Ex3:stddev([[1,2,3],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2829stddev = {"stddev", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2829stddev, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2828stddev};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2829stddev(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stddev (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "stddev", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2828stddev(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2828stddev(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stddev", 1);

  /* "giacpy/auto-methods.pxi":17665
 * 
 *         '''
 *         return GiacMethods['stddev'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def stddevp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_stddev); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17665, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17654
 *         return GiacMethods['stdDev'](self,*args)
 * 
 *      def stddev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddev:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.stddev", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17667
 *         return GiacMethods['stddev'](self,*args)
 * 
 *      def stddevp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddevp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2831stddevp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2830stddevp, "From Giac's documentation:\n        Help for stddevp:\n        stddevp(Lst||Mtrx,[Lst])\n        Returns an unbiased estimate of the population standard deviation of the sample (first argument) with an optional list of weight as second argument.\n        See also: 1/ mean 2/ stddev \n        Ex1:stddevp([1,2,3])\n        Ex2:stddevp([1,2,3],[1,2,1])\n        Ex3:stddevp([[1,2,3],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2831stddevp = {"stddevp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2831stddevp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2830stddevp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2831stddevp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stddevp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "stddevp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2830stddevp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2830stddevp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stddevp", 1);

  /* "giacpy/auto-methods.pxi":17678
 * 
 *         '''
 *         return GiacMethods['stddevp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def steffenson_solver(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_stddevp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17678, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17667
 *         return GiacMethods['stddev'](self,*args)
 * 
 *      def stddevp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddevp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.stddevp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17680
 *         return GiacMethods['stddevp'](self,*args)
 * 
 *      def steffenson_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for steffenson_solver:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2833steffenson_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2832steffenson_solver, "From Giac's documentation:\n        Help for steffenson_solver:\n        steffenson_solver(Opt)\n        Argument for fsolve giving the method for solving a numerical equation.\n        See also: 1/ fsolve \n        Ex1: fsolve(cos(x)=x,x,0..1,bisection_solver)\n        Ex2: fsolve(cos(x)=x,x,0..1,brent_solver)\n        Ex3: fsolve(cos(x)=x,x,0..1,falsepos_solver)\n        Ex4: fsolve(cos(x)=x,x,0,newton_solver)\n        Ex5: fsolve(cos(x)=x,x,0,secant_solver)\n        Ex6: fsolve(cos(x)=x,x,0,steffenson_solver)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2833steffenson_solver = {"steffenson_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2833steffenson_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2832steffenson_solver};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2833steffenson_solver(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("steffenson_solver (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "steffenson_solver", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2832steffenson_solver(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2832steffenson_solver(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("steffenson_solver", 1);

  /* "giacpy/auto-methods.pxi":17694
 * 
 *         '''
 *         return GiacMethods['steffenson_solver'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def stereo2mono(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_steffenson_solver); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17694, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17680
 *         return GiacMethods['stddevp'](self,*args)
 * 
 *      def steffenson_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for steffenson_solver:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.steffenson_solver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17696
 *         return GiacMethods['steffenson_solver'](self,*args)
 * 
 *      def stereo2mono(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stereo2mono:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2835stereo2mono(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2834stereo2mono, "From Giac's documentation:\n        Help for stereo2mono:\n        stereo2mono(Audio(clip))\n        Returns an audio clip with all channels in the input clip averaged to a single one.\n        See also: 1/ channel_data 2/ mean 3/ createwav \n        Ex1:stereo2mono(readwav(\"/some/file\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2835stereo2mono = {"stereo2mono", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2835stereo2mono, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2834stereo2mono};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2835stereo2mono(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stereo2mono (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "stereo2mono", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2834stereo2mono(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2834stereo2mono(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stereo2mono", 1);

  /* "giacpy/auto-methods.pxi":17705
 * 
 *         '''
 *         return GiacMethods['stereo2mono'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def stft(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_stereo2mono); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17705, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17696
 *         return GiacMethods['steffenson_solver'](self,*args)
 * 
 *      def stereo2mono(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stereo2mono:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.stereo2mono", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17707
 *         return GiacMethods['stereo2mono'](self,*args)
 * 
 *      def stft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stft:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2837stft(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2836stft, "From Giac's documentation:\n        Help for stft:\n        stft(Lst(data))\n        Short-time Fourier transform.\n        See also: 1/ istft 2/ fft \n        Ex1:stft([0.2,-0.8,0.4,0.6,0.1,-0.2,0.5,-0.3],2)\n        Ex2:stft(randvector(1024,randvar(normal,0,0.1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2837stft = {"stft", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2837stft, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2836stft};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2837stft(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stft (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "stft", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2836stft(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2836stft(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("stft", 1);

  /* "giacpy/auto-methods.pxi":17717
 * 
 *         '''
 *         return GiacMethods['stft'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def str(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_stft); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17717, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17707
 *         return GiacMethods['stereo2mono'](self,*args)
 * 
 *      def stft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stft:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.stft", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17719
 *         return GiacMethods['stft'](self,*args)
 * 
 *      def str(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for str:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2839str(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2838str, "From Giac's documentation:\n        Help for str:\n        str(Expr or Opt)\n        Returns the evaluated expression as a string or is an option of the convert or convertir command (id string).\n        See also: 1/ expr 2/ format 3/ convert \n        Ex1:str(1.23)\n        Ex2:str(a:=12)\n        Ex3:str(quote(a:=12))\n        Ex4: convert(quote(a:=12),string)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2839str = {"str", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2839str, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2838str};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2839str(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("str (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "str", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2838str(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2838str(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("str", 1);

  /* "giacpy/auto-methods.pxi":17731
 * 
 *         '''
 *         return GiacMethods['str'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def strip(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_str); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17731, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17719
 *         return GiacMethods['stft'](self,*args)
 * 
 *      def str(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for str:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17733
 *         return GiacMethods['str'](self,*args)
 * 
 *      def strip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strip:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2841strip(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2840strip, "From Giac's documentation:\n        Help for strip:\n        strip(Str(s))\n        Removes space characters from the beginning and end of a string.\n        See also: 1/ trim \n        Ex1:strip(\"  an apple     \")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2841strip = {"strip", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2841strip, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2840strip};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2841strip(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("strip (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "strip", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2840strip(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2840strip(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("strip", 1);

  /* "giacpy/auto-methods.pxi":17742
 * 
 *         '''
 *         return GiacMethods['strip'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def strongly_connected_components(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_strip); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17742, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17733
 *         return GiacMethods['str'](self,*args)
 * 
 *      def strip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strip:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.strip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17744
 *         return GiacMethods['strip'](self,*args)
 * 
 *      def strongly_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strongly_connected_components:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2843strongly_connected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2842strongly_connected_components, "From Giac's documentation:\n        Help for strongly_connected_components:\n        strongly_connected_components(Graph(G))\n        Returns the list of strongly connected components in a digraph G.\n        See also: 1/ connected_components 2/ is_connected 3/ is_strongly_connected \n        Ex1:strongly_connected_components(digraph([1,2,3],%{[1,2],[1,3],[2,3],[3,2]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2843strongly_connected_components = {"strongly_connected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2843strongly_connected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2842strongly_connected_components};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2843strongly_connected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("strongly_connected_components (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "strongly_connected_components", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2842strongly_connected_components(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2842strongly_connected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("strongly_connected_components", 1);

  /* "giacpy/auto-methods.pxi":17753
 * 
 *         '''
 *         return GiacMethods['strongly_connected_components'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def student(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_strongly_connected_components); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17753, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17744
 *         return GiacMethods['strip'](self,*args)
 * 
 *      def strongly_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strongly_connected_components:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.strongly_connected_components", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17755
 *         return GiacMethods['strongly_connected_components'](self,*args)
 * 
 *      def student(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2845student(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2844student, "From Giac's documentation:\n        Help for student:\n        student(Intg(n),Real(x0))\n        Returns the probability density of the Student law (n is the number of degrees of freedom).\n        See also: 1/ student_cdf 2/ student_icdf \n        Ex1:student(3,5.2)\n        Ex2:student(1,5.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2845student = {"student", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2845student, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2844student};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2845student(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("student (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "student", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2844student(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2844student(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("student", 1);

  /* "giacpy/auto-methods.pxi":17765
 * 
 *         '''
 *         return GiacMethods['student'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def student_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_student); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17765, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17755
 *         return GiacMethods['strongly_connected_components'](self,*args)
 * 
 *      def student(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.student", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17767
 *         return GiacMethods['student'](self,*args)
 * 
 *      def student_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2847student_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2846student_cdf, "From Giac's documentation:\n        Help for student_cdf:\n        student_cdf(Intg(n),Real(x0))\n        Returns the probability that a Student random variable is less than x0 (n is the number of degrees of freedom).\n        See also: 1/ UTPT 2/ student_icdf 3/ studentd \n        Ex1:student_cdf(3,2.35)\n        Ex2:student_cdf(3,-3.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2847student_cdf = {"student_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2847student_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2846student_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2847student_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("student_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "student_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2846student_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2846student_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("student_cdf", 1);

  /* "giacpy/auto-methods.pxi":17777
 * 
 *         '''
 *         return GiacMethods['student_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def student_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_student_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17777, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17767
 *         return GiacMethods['student'](self,*args)
 * 
 *      def student_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.student_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17779
 *         return GiacMethods['student_cdf'](self,*args)
 * 
 *      def student_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2849student_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2848student_icdf, "From Giac's documentation:\n        Help for student_icdf:\n        student_icdf(Intg(n),Real(p))\n        Returns h such as the probability that a Student random variable is less than h is p (n is the number of degrees of freedom and 0<=p<=1).\n        See also: 1/ student_cdf 2/ studentd \n        Ex1:student_icdf(3,0.95)\n        Ex2:student_icdf(3,0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2849student_icdf = {"student_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2849student_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2848student_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2849student_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("student_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "student_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2848student_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2848student_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("student_icdf", 1);

  /* "giacpy/auto-methods.pxi":17789
 * 
 *         '''
 *         return GiacMethods['student_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def studentd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_student_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17789, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17779
 *         return GiacMethods['student_cdf'](self,*args)
 * 
 *      def student_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.student_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17791
 *         return GiacMethods['student_icdf'](self,*args)
 * 
 *      def studentd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2851studentd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2850studentd, "From Giac's documentation:\n        Help for studentd:\n        studentd(Intg(n),Real(x0))\n        Returns the probability density of the Student law (n is the number of degrees of freedom).\n        See also: 1/ student_cdf 2/ student_icdf \n        Ex1:studentd(3,5.2)\n        Ex2:studentd(1,5.2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2851studentd = {"studentd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2851studentd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2850studentd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2851studentd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("studentd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "studentd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2850studentd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2850studentd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("studentd", 1);

  /* "giacpy/auto-methods.pxi":17801
 * 
 *         '''
 *         return GiacMethods['studentd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def studentt(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_studentd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17801, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17791
 *         return GiacMethods['student_icdf'](self,*args)
 * 
 *      def studentd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.studentd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17803
 *         return GiacMethods['studentd'](self,*args)
 * 
 *      def studentt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentt:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2853studentt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2852studentt, "From Giac's documentation:\n        Help for studentt:\n        studentt(Lst,Real,[Real],Fnc,[Real])\n        T-Test/Student law: arg1=[success,trial] or [mean,sample size] or data, arg2=proportion or data, arg3 optional if data=sigma, arg4 alternative '!=' or '>' or '<', arg5 optional alpha confidence level.\n        See also: 1/ normalt 2/ chisquaret 3/ kolmogorovt \n        Ex1:studentt([10,20],.5,.02,'!=',0.1)\n        Ex2:studentt([0.48,20],0.5,0.1,'<')\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2853studentt = {"studentt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2853studentt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2852studentt};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2853studentt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("studentt (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "studentt", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2852studentt(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2852studentt(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("studentt", 1);

  /* "giacpy/auto-methods.pxi":17813
 * 
 *         '''
 *         return GiacMethods['studentt'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sturm(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_studentt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17813, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17803
 *         return GiacMethods['studentd'](self,*args)
 * 
 *      def studentt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentt:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.studentt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17815
 *         return GiacMethods['studentt'](self,*args)
 * 
 *      def sturm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturm:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2855sturm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2854sturm, "From Giac's documentation:\n        Help for sturm:\n        sturm(Poly,[Var],[Cplx(a)],[Cplx(b)])\n        Sturm sequence corresponding to a polynomial or number of sign changes of this polynomial in ]a;b].\n        See also: 1/ sturmseq 2/ sturmab \n        Ex1:sturm(x^3-1,x)\n        Ex2:sturm(x^5-x^3,x)\n        Ex3:sturm((x^5-x^3)/(x+2),x)\n        Ex4:sturm(x^5-x^3,x,-2,5)\n        Ex5:sturm(x^3-1,x,-2-i,5+3i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2855sturm = {"sturm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2855sturm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2854sturm};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2855sturm(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sturm (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sturm", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2854sturm(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2854sturm(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sturm", 1);

  /* "giacpy/auto-methods.pxi":17828
 * 
 *         '''
 *         return GiacMethods['sturm'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sturmab(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sturm); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17828, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17815
 *         return GiacMethods['studentt'](self,*args)
 * 
 *      def sturm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturm:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sturm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17830
 *         return GiacMethods['sturm'](self,*args)
 * 
 *      def sturmab(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmab:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2857sturmab(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2856sturmab, "From Giac's documentation:\n        Help for sturmab:\n        sturmab(Poly,Var,Cplx(a),Cplx(b))\n        Number of sign changes of a polynomial in ]a;b] or of complex roots in a..b if a or b is non-real.\n        See also: 1/ sturm 2/ sturmseq 3/ realroot \n        Ex1:sturmab(x^3-1,x,-2,5)\n        Ex2:sturmab(x^3-1,x,-2-i,5+3i)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2857sturmab = {"sturmab", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2857sturmab, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2856sturmab};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2857sturmab(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sturmab (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sturmab", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2856sturmab(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2856sturmab(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sturmab", 1);

  /* "giacpy/auto-methods.pxi":17840
 * 
 *         '''
 *         return GiacMethods['sturmab'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sturmseq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sturmab); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17840, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17830
 *         return GiacMethods['sturm'](self,*args)
 * 
 *      def sturmab(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmab:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sturmab", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17842
 *         return GiacMethods['sturmab'](self,*args)
 * 
 *      def sturmseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmseq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2859sturmseq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2858sturmseq, "From Giac's documentation:\n        Help for sturmseq:\n        sturmseq(Poly,[Var])\n        Sturm sequence corresponding to a polynomial or to a rational fraction.\n        See also: 1/ sturm 2/ sturmab \n        Ex1:sturmseq(x^3-1,x)\n        Ex2:sturmseq(x^5-x^3,x)\n        Ex3:sturmseq((x^5-x^3)/(x+2),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2859sturmseq = {"sturmseq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2859sturmseq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2858sturmseq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2859sturmseq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sturmseq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sturmseq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2858sturmseq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2858sturmseq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sturmseq", 1);

  /* "giacpy/auto-methods.pxi":17853
 * 
 *         '''
 *         return GiacMethods['sturmseq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def style(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sturmseq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17853, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17842
 *         return GiacMethods['sturmab'](self,*args)
 * 
 *      def sturmseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmseq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sturmseq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17855
 *         return GiacMethods['sturmseq'](self,*args)
 * 
 *      def style(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for style:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2861style(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2860style, "From Giac's documentation:\n        Help for style:\n        style(Opt)\n        Local option (Maple compatibility) of a graphic command to plot a line with dots with style=point.\n        See also: 1/ line_width \n        Ex1: segment(0,point(1,1),style=point)\n        Ex2: line(y=x,style=point,display=green+line_width_2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2861style = {"style", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2861style, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2860style};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2861style(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("style (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "style", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2860style(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2860style(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("style", 1);

  /* "giacpy/auto-methods.pxi":17865
 * 
 *         '''
 *         return GiacMethods['style'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subMat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_style); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17865, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17855
 *         return GiacMethods['sturmseq'](self,*args)
 * 
 *      def style(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for style:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.style", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17867
 *         return GiacMethods['style'](self,*args)
 * 
 *      def subMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subMat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2863subMat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2862subMat, "From Giac's documentation:\n        Help for subMat:\n        subMat(Mtrx(A),Intg(n1),Intg(n2),Intg(n3),Intg(n4).)\n        Extracts a sub matrix with first element=A[n1,n2] and last element=A[n3,n4].\n        See also: 1/ mid \n        Ex1:subMat([[1,2],[3,4],[5,6]],1,0,2,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2863subMat = {"subMat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2863subMat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2862subMat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2863subMat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subMat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subMat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2862subMat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2862subMat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subMat", 1);

  /* "giacpy/auto-methods.pxi":17876
 * 
 *         '''
 *         return GiacMethods['subMat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subdivide_edges(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subMat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17876, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17867
 *         return GiacMethods['style'](self,*args)
 * 
 *      def subMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subMat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subMat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17878
 *         return GiacMethods['subMat'](self,*args)
 * 
 *      def subdivide_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subdivide_edges:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2865subdivide_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2864subdivide_edges, "From Giac's documentation:\n        Help for subdivide_edges:\n        subdivide_edges(Graph(G),Lst(E),[Intg(r)])\n        Inserts r (by default 1) new vertices to each edge/arc in G contained in the list E (which may be a single edge/arc) and returns a modified copy of G. New vertices are labeled by the smallest available integers.\n        See also: 1/ edges \n        Ex1:subdivide_edges(complete_graph(2,3),[[1,3],[1,4]],2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2865subdivide_edges = {"subdivide_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2865subdivide_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2864subdivide_edges};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2865subdivide_edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subdivide_edges (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subdivide_edges", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2864subdivide_edges(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2864subdivide_edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subdivide_edges", 1);

  /* "giacpy/auto-methods.pxi":17887
 * 
 *         '''
 *         return GiacMethods['subdivide_edges'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subgraph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subdivide_edges); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17887, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17878
 *         return GiacMethods['subMat'](self,*args)
 * 
 *      def subdivide_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subdivide_edges:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subdivide_edges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17889
 *         return GiacMethods['subdivide_edges'](self,*args)
 * 
 *      def subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subgraph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2867subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2866subgraph, "From Giac's documentation:\n        Help for subgraph:\n        subgraph(Graph(G),Lst(E))\n        Returns the subgraph of G defined by the edges in list E.\n        See also: 1/ induced_subgraph 2/ highlight_subgraph \n        Ex1:subgraph(complete_graph(5),[[1,2],[2,3],[3,4],[4,1]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2867subgraph = {"subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2867subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2866subgraph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2867subgraph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subgraph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subgraph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2866subgraph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2866subgraph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subgraph", 1);

  /* "giacpy/auto-methods.pxi":17898
 * 
 *         '''
 *         return GiacMethods['subgraph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subs(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subgraph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17898, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17898, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17889
 *         return GiacMethods['subdivide_edges'](self,*args)
 * 
 *      def subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subgraph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subgraph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17900
 *         return GiacMethods['subgraph'](self,*args)
 * 
 *      def subs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subs:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2869subs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2868subs, "From Giac's documentation:\n        Help for subs:\n        subs(Expr or Var=value,Var=value or Expr)\n        Equivalent of subst except in maple_mode where the arguments are switched over, in maple_mode choose the second example.\n        See also: 1/ subst 2/ maple_mode 3/ algsubs 4/ () \n        Ex1:subs(1/(4+x^2),x=2)\n        Ex2:subs(x=2,1/(4+x^2))\n        Ex3: f:=1/(4+x^2);f(x=2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2869subs = {"subs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2869subs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2868subs};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2869subs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subs (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subs", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2868subs(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2868subs(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subs", 1);

  /* "giacpy/auto-methods.pxi":17911
 * 
 *         '''
 *         return GiacMethods['subs'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subsop(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subs); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17911, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17900
 *         return GiacMethods['subgraph'](self,*args)
 * 
 *      def subs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17913
 *         return GiacMethods['subs'](self,*args)
 * 
 *      def subsop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subsop:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2871subsop(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2870subsop, "From Giac's documentation:\n        Help for subsop:\n        subsop(Lst||Mtrx,Intg(n)=Expr)\n        Replaces in the list (or the matrix) the element of index n with the expression (with Maple the arguments are switched over)(NULL remove this element).\n        Ex1:subsop([0,1,2,3,4],2=sqrt(2)+1)\n        Ex2:subsop([[1,2],[3,4]],[1,1]=5)\n        Ex3:subsop([[1,2],[3,4]],1=[10,8])\n        Ex4:subsop([0,1,2,3],'1=NULL')\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2871subsop = {"subsop", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2871subsop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2870subsop};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2871subsop(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subsop (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subsop", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2870subsop(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2870subsop(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subsop", 1);

  /* "giacpy/auto-methods.pxi":17924
 * 
 *         '''
 *         return GiacMethods['subsop'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subst(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subsop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17924, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17913
 *         return GiacMethods['subs'](self,*args)
 * 
 *      def subsop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subsop:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subsop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17926
 *         return GiacMethods['subsop'](self,*args)
 * 
 *      def subst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subst:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2873subst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2872subst, "From Giac's documentation:\n        Help for subst:\n        subst(Expr,Var(v)=value(a))\n        Substitutes a value for a variable in an expression.\n        See also: 1/ eval 2/ algsubs 3/ subs 4/ () \n        Ex1:subst(1/(4+x^2),x=2)\n        Ex2:subst(1/(x^2+y^2),x=2,y=3)\n        Ex3:subst(1/(x^2+y^2+z^2),[x=2,y=3,z=1])\n        Ex4:subst(x-2/(4+x^2),x=1)\n        Ex5:subst('integrate(sin(x^2)*x,x)',x=sqrt(t))\n        Ex6:subst('sum(x^(n+1)/((n+p+1)*(n+1)),n,0,inf)',n=k-1)\n        Ex7: f:=1/(x^2+y^2;f(x=2,y=3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2873subst = {"subst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2873subst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2872subst};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2873subst(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subst (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subst", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2872subst(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2872subst(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subst", 1);

  /* "giacpy/auto-methods.pxi":17941
 * 
 *         '''
 *         return GiacMethods['subst'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def substituer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subst); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17941, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17926
 *         return GiacMethods['subsop'](self,*args)
 * 
 *      def subst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subst:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subst", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17943
 *         return GiacMethods['subst'](self,*args)
 * 
 *      def substituer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for substituer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2875substituer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2874substituer, "From Giac's documentation:\n        Help for substituer:\n        substituer(Expr,Var(v)=value(a))\n        Substitutes a value for a variable in an expression.\n        See also: 1/ eval 2/ algsubs 3/ subs 4/ () \n        Ex1:substituer(1/(4+x^2),x=2)\n        Ex2:substituer(1/(x^2+y^2),x=2,y=3)\n        Ex3:substituer(1/(x^2+y^2+z^2),[x=2,y=3,z=1])\n        Ex4:substituer(x-2/(4+x^2),x=1)\n        Ex5:substituer('integrate(sin(x^2)*x,x)',x=sqrt(t))\n        Ex6:substituer('sum(x^(n+1)/((n+p+1)*(n+1)),n,0,inf)',n=k-1)\n        Ex7: f:=1/(x^2+y^2;f(x=2,y=3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2875substituer = {"substituer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2875substituer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2874substituer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2875substituer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("substituer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "substituer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2874substituer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2874substituer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("substituer", 1);

  /* "giacpy/auto-methods.pxi":17958
 * 
 *         '''
 *         return GiacMethods['substituer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def subtype(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_substituer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17958, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17943
 *         return GiacMethods['subst'](self,*args)
 * 
 *      def substituer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for substituer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.substituer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17960
 *         return GiacMethods['substituer'](self,*args)
 * 
 *      def subtype(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subtype:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2877subtype(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2876subtype, "From Giac's documentation:\n        Help for subtype:\n        subtype(Expr)\n        Returns 1 for a sequence,2 for a set, 10 for a polynomial and 0 otherwise.\n        See also: 1/ DOM_LIST 2/ type \n        Ex1:subtype(1,2,3)\n        Ex2:subtype(set[1,2,3])\n        Ex3:subtype(poly1[1,2,3])\n        Ex4:subtype([1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2877subtype = {"subtype", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2877subtype, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2876subtype};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2877subtype(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subtype (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "subtype", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2876subtype(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2876subtype(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("subtype", 1);

  /* "giacpy/auto-methods.pxi":17972
 * 
 *         '''
 *         return GiacMethods['subtype'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sum(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_subtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17972, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17960
 *         return GiacMethods['substituer'](self,*args)
 * 
 *      def subtype(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subtype:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.subtype", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17974
 *         return GiacMethods['subtype'](self,*args)
 * 
 *      def sum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2879sum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2878sum, "From Giac's documentation:\n        Help for sum:\n        sum(Expr,Var,VarMin(a),VarMax(b),[VarStep(p)])\n        Discrete sum (with 2 or 4 arguments return then sum from a to b if a<=b or of the opposite of the sum from b+1 to a-1 if a>b+1 or 0 if a=b+1) or the discrete primitive or sum of the elements of a list or a sequence.\n        See also: 1/ + \n        Ex1:sum(1/n^2,n,1,17)\n        Ex2:sum(1/n^2,n=1..17)\n        Ex3:sum(1/n^2,n,17,1)\n        Ex4:sum(1/n^2,n=17..1)\n        Ex5:sum(1/n^2,n,17,1,1)\n        Ex6:sum(1/n^2,n,1,17,2)\n        Ex7:sum([1,2,3,4])\n        Ex8:sum([[1,2,3,4,5,6,7,8,9],[1,2,3,4,5,6,7,8,9]])\n        Ex9:sum(1/(x*(x+1)),x)\n        Ex10:sum(cos(n*x),n)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2879sum = {"sum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2879sum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2878sum};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2879sum(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sum (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sum", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2878sum(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2878sum(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sum", 1);

  /* "giacpy/auto-methods.pxi":17992
 * 
 *         '''
 *         return GiacMethods['sum'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sum_riemann(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 17992, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 17992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 17992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17974
 *         return GiacMethods['subtype'](self,*args)
 * 
 *      def sum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":17994
 *         return GiacMethods['sum'](self,*args)
 * 
 *      def sum_riemann(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum_riemann:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2881sum_riemann(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2880sum_riemann, "From Giac's documentation:\n        Help for sum_riemann:\n        sum_riemann(Expr(Xpr),Lst(var1,var2))\n        Returns an equivalent when var1=+infinity of the sum of Xpr(var1,var2) for var2 from 1 to var1 when the sum is a Riemann sum.\n        See also: 1/  \n        Ex1:sum_riemann(1/(n+k),[n,k])\n        Ex2:sum_riemann(n/(n^2+k),[n,k])\n        Ex3:sum_riemann(n/(n^2+k^2),[n,k])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2881sum_riemann = {"sum_riemann", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2881sum_riemann, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2880sum_riemann};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2881sum_riemann(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sum_riemann (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sum_riemann", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2880sum_riemann(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2880sum_riemann(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sum_riemann", 1);

  /* "giacpy/auto-methods.pxi":18005
 * 
 *         '''
 *         return GiacMethods['sum_riemann'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def suppress(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sum_riemann); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18005, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":17994
 *         return GiacMethods['sum'](self,*args)
 * 
 *      def sum_riemann(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum_riemann:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sum_riemann", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18007
 *         return GiacMethods['sum_riemann'](self,*args)
 * 
 *      def suppress(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for suppress:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2883suppress(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2882suppress, "From Giac's documentation:\n        Help for suppress:\n        suppress(Vect(L)||Str(l),Intg(n))\n        Returns L without the element of index n; L:=suppress(L,n) or L.suppress(n).\n        See also: 1/ tail 2/ mid 3/ remove 4/ insert \n        Ex1:suppress([0,1,2,3],2)\n        Ex2:suppress(\"0123\",2)\n        Ex3: L:=[0,1,2,3];L:=suppress(L,2)\n        Ex4: L:=[0,1,2,3];L.suppress(2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2883suppress = {"suppress", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2883suppress, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2882suppress};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2883suppress(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "suppress", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2882suppress(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2882suppress(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("suppress", 1);

  /* "giacpy/auto-methods.pxi":18019
 * 
 *         '''
 *         return GiacMethods['suppress'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def surd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_suppress); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18019, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18007
 *         return GiacMethods['sum_riemann'](self,*args)
 * 
 *      def suppress(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for suppress:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.suppress", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18021
 *         return GiacMethods['suppress'](self,*args)
 * 
 *      def surd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for surd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2885surd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2884surd, "From Giac's documentation:\n        Help for surd:\n        surd(Expr,Intg(n))\n        Power 1/n.\n        See also: 1/ sqrt 2/ ^ \n        Ex1:surd(8,3)\n        Ex2:surd(-8,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2885surd = {"surd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2885surd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2884surd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2885surd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("surd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "surd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2884surd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2884surd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("surd", 1);

  /* "giacpy/auto-methods.pxi":18031
 * 
 *         '''
 *         return GiacMethods['surd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def svd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_surd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18031, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18021
 *         return GiacMethods['suppress'](self,*args)
 * 
 *      def surd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for surd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.surd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18033
 *         return GiacMethods['surd'](self,*args)
 * 
 *      def svd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for svd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2887svd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2886svd, "From Giac's documentation:\n        Help for svd:\n        svd(Mtrx(A))\n        For a square numerical real matrix A, returns U orthogonal, S vector of singular values, Q orthogonal such that A=U*diag(S)*tran(Q).\n        Ex1:svd([[1,2],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2887svd = {"svd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2887svd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2886svd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2887svd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("svd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "svd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2886svd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2886svd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("svd", 1);

  /* "giacpy/auto-methods.pxi":18041
 * 
 *         '''
 *         return GiacMethods['svd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def swapcol(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_svd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18041, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18033
 *         return GiacMethods['surd'](self,*args)
 * 
 *      def svd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for svd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.svd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18043
 *         return GiacMethods['svd'](self,*args)
 * 
 *      def swapcol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swapcol:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2889swapcol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2888swapcol, "From Giac's documentation:\n        Help for swapcol:\n        swapcol(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by swapping the n1-th column and the n2-th column.\n        See also: 1/ rowSwap \n        Ex1:swapcol([[1,2],[3,4],[5,6]],0,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2889swapcol = {"swapcol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2889swapcol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2888swapcol};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2889swapcol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("swapcol (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "swapcol", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2888swapcol(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2888swapcol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("swapcol", 1);

  /* "giacpy/auto-methods.pxi":18052
 * 
 *         '''
 *         return GiacMethods['swapcol'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def swaprow(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_swapcol); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18052, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18043
 *         return GiacMethods['svd'](self,*args)
 * 
 *      def swapcol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swapcol:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.swapcol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18054
 *         return GiacMethods['swapcol'](self,*args)
 * 
 *      def swaprow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swaprow:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2891swaprow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2890swaprow, "From Giac's documentation:\n        Help for swaprow:\n        swaprow(Mtrx(A),Intg(n1),Intg(n2))\n        Returns the matrix obtained from A by swapping the n1-th row and the n2-th row.\n        See also: 1/ rowAdd 2/ colSwap \n        Ex1:swaprow([[1,2],[3,4],[5,6]],1,2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2891swaprow = {"swaprow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2891swaprow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2890swaprow};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2891swaprow(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("swaprow (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "swaprow", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2890swaprow(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2890swaprow(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("swaprow", 1);

  /* "giacpy/auto-methods.pxi":18063
 * 
 *         '''
 *         return GiacMethods['swaprow'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def switch_axes(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_swaprow); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18063, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18054
 *         return GiacMethods['swapcol'](self,*args)
 * 
 *      def swaprow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swaprow:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.swaprow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18065
 *         return GiacMethods['swaprow'](self,*args)
 * 
 *      def switch_axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for switch_axes:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2893switch_axes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2892switch_axes, "From Giac's documentation:\n        Help for switch_axes:\n        switch_axes([Intg(0 or 1)])\n        switch_axes() puts or erases the axes of the graphic-screen.\n        See also: 1/ gl_showaxes 2/ axes \n        Ex1:switch_axes()\n        Ex2:switch_axes(0)\n        Ex3:switch_axes(1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2893switch_axes = {"switch_axes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2893switch_axes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2892switch_axes};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2893switch_axes(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("switch_axes (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "switch_axes", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2892switch_axes(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2892switch_axes(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("switch_axes", 1);

  /* "giacpy/auto-methods.pxi":18076
 * 
 *         '''
 *         return GiacMethods['switch_axes'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def sylvester(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_switch_axes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18076, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18065
 *         return GiacMethods['swaprow'](self,*args)
 * 
 *      def switch_axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for switch_axes:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.switch_axes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18078
 *         return GiacMethods['switch_axes'](self,*args)
 * 
 *      def sylvester(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sylvester:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2895sylvester(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2894sylvester, "From Giac's documentation:\n        Help for sylvester:\n        sylvester(Poly,Poly,Var)\n        Sylvester matrix of two polynomials.\n        See also: 1/ resultant \n        Ex1:sylvester(x^2-1,x^3-1,x)\n        Ex2:sylvester(x^3-p*x+q,3*x^2-p,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2895sylvester = {"sylvester", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2895sylvester, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2894sylvester};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2895sylvester(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sylvester (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sylvester", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2894sylvester(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2894sylvester(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sylvester", 1);

  /* "giacpy/auto-methods.pxi":18088
 * 
 *         '''
 *         return GiacMethods['sylvester'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def symb2poly(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_sylvester); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18088, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18078
 *         return GiacMethods['switch_axes'](self,*args)
 * 
 *      def sylvester(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sylvester:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.sylvester", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18090
 *         return GiacMethods['sylvester'](self,*args)
 * 
 *      def symb2poly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symb2poly:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2897symb2poly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2896symb2poly, "From Giac's documentation:\n        Help for symb2poly:\n        symb2poly(Expr, LstVar or [Var])\n        Returns the coefficients of a polynomial with respect to the 2nd argument or if the second argument is a list the internal format of the polynomial.\n        See also: 1/ poly2symb 2/ r2e \n        Ex1:symb2poly(x*3+2.1)\n        Ex2:symb2poly(3*x*y+2*y+1,y)\n        Ex3:symb2poly(3*x*y+2*y+1,x,y)\n        Ex4:symb2poly(3*x*y+2*y+1,[x,y])\n        Ex5:symb2poly(-x^4+x*3*y+2+y^2*z,[x,y,z])\n        Ex6:symb2poly(-x^4+x*3*y+2+y^2*z,[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2897symb2poly = {"symb2poly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2897symb2poly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2896symb2poly};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2897symb2poly(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("symb2poly (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "symb2poly", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2896symb2poly(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2896symb2poly(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("symb2poly", 1);

  /* "giacpy/auto-methods.pxi":18104
 * 
 *         '''
 *         return GiacMethods['symb2poly'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def symbol(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_symb2poly); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18104, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18090
 *         return GiacMethods['sylvester'](self,*args)
 * 
 *      def symb2poly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symb2poly:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.symb2poly", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18106
 *         return GiacMethods['symb2poly'](self,*args)
 * 
 *      def symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2899symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2898symbol, "From Giac's documentation:\n        Help for symbol:\n        symbol(Opt)\n        DOM_SYMBOLIC or symbol is the type of a symbolic variable, as returned by the type command. It is also an option of the assume command.\n        See also: 1/ type 2/ assume 3/ DOM_INT 4/ DOM_FLOAT \n        Ex1: assume(a,symbol)\n        Ex2: assume(a,DOM_SYMBOLIC)\n        Ex3: a:=sqrt(2);type(a)\n        Ex4: type(2x+1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2899symbol = {"symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2899symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2898symbol};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2899symbol(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("symbol (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "symbol", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2898symbol(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2898symbol(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("symbol", 1);

  /* "giacpy/auto-methods.pxi":18118
 * 
 *         '''
 *         return GiacMethods['symbol'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def symbol_array(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_symbol); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18118, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18106
 *         return GiacMethods['symb2poly'](self,*args)
 * 
 *      def symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.symbol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18120
 *         return GiacMethods['symbol'](self,*args)
 * 
 *      def symbol_array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol_array:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2901symbol_array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2900symbol_array, "From Giac's documentation:\n        Help for symbol_array:\n        symbol_array(Strng(str),Seq(dim))\n        Returns an array of symbols with base name str (which may contain index placeholders %) and specified dimensions dim=(d1,d2,...,dn).\n        See also: 1/ make_symbol \n        Ex1:symbol_array(\"x\",5)\n        Ex2:symbol_array(\"a\",2,3)\n        Ex3:symbol_array(\"a%%\",2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2901symbol_array = {"symbol_array", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2901symbol_array, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2900symbol_array};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2901symbol_array(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("symbol_array (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "symbol_array", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2900symbol_array(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2900symbol_array(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("symbol_array", 1);

  /* "giacpy/auto-methods.pxi":18131
 * 
 *         '''
 *         return GiacMethods['symbol_array'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def syst2mat(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_symbol_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18131, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18120
 *         return GiacMethods['symbol'](self,*args)
 * 
 *      def symbol_array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol_array:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.symbol_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18133
 *         return GiacMethods['symbol_array'](self,*args)
 * 
 *      def syst2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for syst2mat:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2903syst2mat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2902syst2mat, "From Giac's documentation:\n        Help for syst2mat:\n        syst2mat(LstLinEq,LstVar)\n        Returns the matrix M=A|(-b) associate to the system Y=AX+b.\n        See also: 1/ linsolve 2/ rref \n        Ex1:syst2mat([x-y=1,x+2*y],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2903syst2mat = {"syst2mat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2903syst2mat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2902syst2mat};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2903syst2mat(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("syst2mat (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "syst2mat", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2902syst2mat(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2902syst2mat(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("syst2mat", 1);

  /* "giacpy/auto-methods.pxi":18142
 * 
 *         '''
 *         return GiacMethods['syst2mat'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tCollect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_syst2mat); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18142, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18133
 *         return GiacMethods['symbol_array'](self,*args)
 * 
 *      def syst2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for syst2mat:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.syst2mat", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18144
 *         return GiacMethods['syst2mat'](self,*args)
 * 
 *      def tCollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tCollect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2905tCollect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2904tCollect, "From Giac's documentation:\n        Help for tCollect:\n        tCollect(Expr)\n        Collects trigonometric expressions.\n        See also: 1/ texpand 2/ tlin \n        Ex1:tCollect(sin(x)+cos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2905tCollect = {"tCollect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2905tCollect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2904tCollect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2905tCollect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tCollect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tCollect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2904tCollect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2904tCollect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tCollect", 1);

  /* "giacpy/auto-methods.pxi":18153
 * 
 *         '''
 *         return GiacMethods['tCollect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tExpand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tCollect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18153, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18144
 *         return GiacMethods['syst2mat'](self,*args)
 * 
 *      def tCollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tCollect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tCollect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18155
 *         return GiacMethods['tCollect'](self,*args)
 * 
 *      def tExpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tExpand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2907tExpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2906tExpand, "From Giac's documentation:\n        Help for tExpand:\n        tExpand(Expr)\n        Expands transcendental expressions.\n        See also: 1/ tcollect 2/ tlin 3/ lin 4/ trigexpand \n        Ex1:tExpand(sin(2*x)+exp(x+y))\n        Ex2:tExpand(cos(x+y))\n        Ex3:tExpand(cos(3*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2907tExpand = {"tExpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2907tExpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2906tExpand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2907tExpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tExpand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tExpand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2906tExpand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2906tExpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tExpand", 1);

  /* "giacpy/auto-methods.pxi":18166
 * 
 *         '''
 *         return GiacMethods['tExpand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def table(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tExpand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18166, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18155
 *         return GiacMethods['tCollect'](self,*args)
 * 
 *      def tExpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tExpand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tExpand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18168
 *         return GiacMethods['tExpand'](self,*args)
 * 
 *      def table(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for table:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2909table(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2908table, "From Giac's documentation:\n        Help for table:\n        table(SeqEqual(index=value))\n        Defines an array where the indices are strings or real numbers or defines a table with a matrix.\n        See also: 1/ matrix 2/ convert 3/ array \n        Ex1:table(3=-10,\"a\"=10,\"b\"=20,\"c\"=30,\"d\"=40)\n        Ex2: A:=[[0,1],[2,3]];table(A)  \n        Ex3: B:=table([1,2]=12,[2,5]=25);matrix(B)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2909table = {"table", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2909table, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2908table};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2909table(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("table (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "table", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2908table(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2908table(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("table", 1);

  /* "giacpy/auto-methods.pxi":18179
 * 
 *         '''
 *         return GiacMethods['table'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tablefunc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_table); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18179, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18168
 *         return GiacMethods['tExpand'](self,*args)
 * 
 *      def table(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for table:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.table", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18181
 *         return GiacMethods['table'](self,*args)
 * 
 *      def tablefunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tablefunc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2911tablefunc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2910tablefunc, "From Giac's documentation:\n        Help for tablefunc:\n        tablefunc(Expr,Var)\n        Table of values of a function : you must be in a spreadsheet.\n        See also: 1/ tabvar 2/ tableseq \n        Ex1:tablefunc(sin(x),x)\n        Ex2:tablefunc(x^2-x-2,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2911tablefunc = {"tablefunc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2911tablefunc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2910tablefunc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2911tablefunc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tablefunc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tablefunc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2910tablefunc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2910tablefunc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tablefunc", 1);

  /* "giacpy/auto-methods.pxi":18191
 * 
 *         '''
 *         return GiacMethods['tablefunc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tableseq(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tablefunc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18191, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18181
 *         return GiacMethods['table'](self,*args)
 * 
 *      def tablefunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tablefunc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tablefunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18193
 *         return GiacMethods['tablefunc'](self,*args)
 * 
 *      def tableseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tableseq:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2913tableseq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2912tableseq, "From Giac's documentation:\n        Help for tableseq:\n        tableseq(Expr,(Var or LstVar),(InitVal or LstInitVal))\n        Table of values of a sequence (in a spreadsheet.)\n        See also: 1/ tablefunc \n        Ex1:tableseq(cos(x),x,0.0)\n        Ex2:tableseq(x+y,[x,y],[1,1])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2913tableseq = {"tableseq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2913tableseq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2912tableseq};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2913tableseq(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tableseq (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tableseq", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2912tableseq(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2912tableseq(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tableseq", 1);

  /* "giacpy/auto-methods.pxi":18203
 * 
 *         '''
 *         return GiacMethods['tableseq'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tabsign(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tableseq); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18203, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18193
 *         return GiacMethods['tablefunc'](self,*args)
 * 
 *      def tableseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tableseq:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tableseq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18205
 *         return GiacMethods['tableseq'](self,*args)
 * 
 *      def tabsign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabsign:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2915tabsign(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2914tabsign, "From Giac's documentation:\n        Help for tabsign:\n        tabsign(Expr,Var)\n        Table of signs of a function.\n        See also: 1/ tablefunc 2/ tabvar \n        Ex1:tabsign(x^2-x,x)\n        Ex2:tabsign(x^2,x,-3,5)\n        Ex3:tabsign(sin(x),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2915tabsign = {"tabsign", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2915tabsign, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2914tabsign};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2915tabsign(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tabsign (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tabsign", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2914tabsign(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2914tabsign(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tabsign", 1);

  /* "giacpy/auto-methods.pxi":18216
 * 
 *         '''
 *         return GiacMethods['tabsign'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tabvar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tabsign); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18216, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18205
 *         return GiacMethods['tableseq'](self,*args)
 * 
 *      def tabsign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabsign:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tabsign", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18218
 *         return GiacMethods['tabsign'](self,*args)
 * 
 *      def tabvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabvar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2917tabvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2916tabvar, "From Giac's documentation:\n        Help for tabvar:\n        tabvar(Expr,Var)\n        Table of variations of a function with its graph on DispG.\n        See also: 1/ tablefunc 2/ tabsign \n        Ex1:tabvar(sin(x),x)\n        Ex2:tabvar(1/ln(x^2-1),x,diff=1)\n        Ex3:tabvar(x^2+x+1,x)\n        Ex4:tabvar(x^2,x,-3,5)\n        Ex5:tabvar([sin(2t),cos(3t)])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2917tabvar = {"tabvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2917tabvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2916tabvar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2917tabvar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tabvar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tabvar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2916tabvar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2916tabvar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tabvar", 1);

  /* "giacpy/auto-methods.pxi":18231
 * 
 *         '''
 *         return GiacMethods['tabvar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tail(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tabvar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18231, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18218
 *         return GiacMethods['tabsign'](self,*args)
 * 
 *      def tabvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabvar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tabvar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18233
 *         return GiacMethods['tabvar'](self,*args)
 * 
 *      def tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tail:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2919tail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2918tail, "From Giac's documentation:\n        Help for tail:\n        tail(Lst or Seq or Str)\n        Returns the list (or sequence or string) without its first element.\n        See also: 1/ head 2/ mid 3/ left 4/ right 5/ back \n        Ex1:tail([3,2,4,1,0])\n        Ex2:tail(3,2,4,1,0)\n        Ex3:tail(\"bonjour\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2919tail = {"tail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2919tail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2918tail};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2919tail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tail (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tail", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2918tail(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2918tail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tail", 1);

  /* "giacpy/auto-methods.pxi":18244
 * 
 *         '''
 *         return GiacMethods['tail'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tail); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18244, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18233
 *         return GiacMethods['tabvar'](self,*args)
 * 
 *      def tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tail:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18246
 *         return GiacMethods['tail'](self,*args)
 * 
 *      def tan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2921tan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2920tan, "From Giac's documentation:\n        Help for tan:\n        tan(Expr)\n        Tangent or option of the convert or convertir command (id halftan).\n        See also: 1/ atan or Opt 2/ convert 3/ halftan \n        Ex1:tan(0)\n        Ex2:tan(pi/4)\n        Ex3: convert(tan(x),tan)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2921tan = {"tan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2921tan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2920tan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2921tan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2920tan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2920tan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tan", 1);

  /* "giacpy/auto-methods.pxi":18257
 * 
 *         '''
 *         return GiacMethods['tan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tan2cossin2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18257, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18246
 *         return GiacMethods['tail'](self,*args)
 * 
 *      def tan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18259
 *         return GiacMethods['tan'](self,*args)
 * 
 *      def tan2cossin2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2cossin2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2923tan2cossin2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2922tan2cossin2, "From Giac's documentation:\n        Help for tan2cossin2:\n        tan2cossin2(Expr)\n        Replaces tan(x) by (1-cos(2*x))/sin(2*x) in the argument.\n        See also: 1/ tan2sincos2 2/ tan2sincos 3/ sin2costan 4/ cos2sintan \n        Ex1:tan2cossin2(tan(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2923tan2cossin2 = {"tan2cossin2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2923tan2cossin2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2922tan2cossin2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2923tan2cossin2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tan2cossin2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tan2cossin2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2922tan2cossin2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2922tan2cossin2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tan2cossin2", 1);

  /* "giacpy/auto-methods.pxi":18268
 * 
 *         '''
 *         return GiacMethods['tan2cossin2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tan2sincos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tan2cossin2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18268, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18259
 *         return GiacMethods['tan'](self,*args)
 * 
 *      def tan2cossin2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2cossin2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tan2cossin2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18270
 *         return GiacMethods['tan2cossin2'](self,*args)
 * 
 *      def tan2sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2925tan2sincos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2924tan2sincos, "From Giac's documentation:\n        Help for tan2sincos:\n        tan2sincos(Expr)\n        Replaces tan(x) by sin(x)/cos(x) in the argument.\n        See also: 1/ sin2costan 2/ cos2sintan 3/ tan2sincos2 4/ tan2cossin2 \n        Ex1:tan2sincos(tan(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2925tan2sincos = {"tan2sincos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2925tan2sincos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2924tan2sincos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2925tan2sincos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tan2sincos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tan2sincos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2924tan2sincos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2924tan2sincos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tan2sincos", 1);

  /* "giacpy/auto-methods.pxi":18279
 * 
 *         '''
 *         return GiacMethods['tan2sincos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tan2sincos2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tan2sincos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18279, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18270
 *         return GiacMethods['tan2cossin2'](self,*args)
 * 
 *      def tan2sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tan2sincos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18281
 *         return GiacMethods['tan2sincos'](self,*args)
 * 
 *      def tan2sincos2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2927tan2sincos2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2926tan2sincos2, "From Giac's documentation:\n        Help for tan2sincos2:\n        tan2sincos2(Expr)\n        Replaces tan(x) by sin(2*x)/(1+cos(2*x)) in the argument.\n        See also: 1/ tan2cossin2 2/ tan2sincos 3/ sin2costan 4/ cos2sintan \n        Ex1:tan2sincos2(tan(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2927tan2sincos2 = {"tan2sincos2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2927tan2sincos2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2926tan2sincos2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2927tan2sincos2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tan2sincos2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tan2sincos2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2926tan2sincos2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2926tan2sincos2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tan2sincos2", 1);

  /* "giacpy/auto-methods.pxi":18290
 * 
 *         '''
 *         return GiacMethods['tan2sincos2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tangent(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tan2sincos2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18290, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18281
 *         return GiacMethods['tan2sincos'](self,*args)
 * 
 *      def tan2sincos2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tan2sincos2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18292
 *         return GiacMethods['tan2sincos2'](self,*args)
 * 
 *      def tangent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangent:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2929tangent(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2928tangent, "From Giac's documentation:\n        Help for tangent:\n        tangent(Curve(C),Pnt(A))\n        tangent(C,A) draws the tangents (line or plane) to C through A.\n        See also: 1/ LineTan 2/ droite_tangente \n        Ex1:tangent(circle(i,1+i),A)\n        Ex2:tangent(plotfunc(sin(x)),3*pi/4)\n        Ex3:tangent(plotfunc(sin(x)),point(3*pi/4+i*sqrt(2)/2))\n        Ex4:tangent(plotfunc(x^2+y^2,[x,y]),[2,2])\n        Ex5:tangent(plotfunc(x^2+y^2,[x,y]),point([2,2,8]))\n        Ex6:tangent(plotparam(3*exp(t/2)*exp(i*t),t),7)\n        Ex7:tangent(plotpolar(3*exp(t/2),t),7)\n        Ex8: equation(tangente([2*cos(t),2*sin(t),3*t],t))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2929tangent = {"tangent", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2929tangent, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2928tangent};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2929tangent(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tangent (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tangent", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2928tangent(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2928tangent(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tangent", 1);

  /* "giacpy/auto-methods.pxi":18308
 * 
 *         '''
 *         return GiacMethods['tangent'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tangente(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tangent); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18308, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18292
 *         return GiacMethods['tan2sincos2'](self,*args)
 * 
 *      def tangent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangent:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tangent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18310
 *         return GiacMethods['tangent'](self,*args)
 * 
 *      def tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangente:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2931tangente(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2930tangente, "From Giac's documentation:\n        Help for tangente:\n        tangente(Curve(C),Pnt(A))\n        tangent(C,A) draws the tangents (line or plane) to C through A.\n        See also: 1/ LineTan 2/ droite_tangente \n        Ex1:tangente(circle(i,1+i),A)\n        Ex2:tangente(plotfunc(sin(x)),3*pi/4)\n        Ex3:tangente(plotfunc(sin(x)),point(3*pi/4+i*sqrt(2)/2))\n        Ex4:tangente(plotfunc(x^2+y^2,[x,y]),[2,2])\n        Ex5:tangente(plotfunc(x^2+y^2,[x,y]),point([2,2,8]))\n        Ex6:tangente(plotparam(3*exp(t/2)*exp(i*t),t),7)\n        Ex7:tangente(plotpolar(3*exp(t/2),t),7)\n        Ex8: equation(tangente([2*cos(t),2*sin(t),3*t],t))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2931tangente = {"tangente", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2931tangente, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2930tangente};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2931tangente(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tangente (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tangente", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2930tangente(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2930tangente(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tangente", 1);

  /* "giacpy/auto-methods.pxi":18326
 * 
 *         '''
 *         return GiacMethods['tangente'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tanh(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tangente); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18326, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18310
 *         return GiacMethods['tangent'](self,*args)
 * 
 *      def tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangente:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tangente", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18328
 *         return GiacMethods['tangente'](self,*args)
 * 
 *      def tanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tanh:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2933tanh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2932tanh, "From Giac's documentation:\n        Help for tanh:\n        tanh(Expr)\n        Hyperbolic tangent.\n        See also: 1/ atanh 2/ hyp2exp \n        Ex1:tanh(0)\n        Ex2:tanh(hyp2exp(tanh(1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2933tanh = {"tanh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2933tanh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2932tanh};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2933tanh(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tanh (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tanh", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2932tanh(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2932tanh(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tanh", 1);

  /* "giacpy/auto-methods.pxi":18338
 * 
 *         '''
 *         return GiacMethods['tanh'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tar(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tanh); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18338, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18328
 *         return GiacMethods['tangente'](self,*args)
 * 
 *      def tanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tanh:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tanh", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18340
 *         return GiacMethods['tanh'](self,*args)
 * 
 *      def tar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tar:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2935tar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2934tar, "From Giac's documentation:\n        Help for tar:\n        tar(String || Buffer || Buffer,String || Buffer,Int,String)\n        Tar archive handling. buf:=tar(\"src.tar\") create a buffer, tar(buf) display list of files, tar(buf,\"target.tar\") save buffer, tar(buf,0,\"filename\") remove file from buffer, tar(buf,1,\"filename\") add file, tar(buf,2,\"filename\") save file, purge(buf) free buffer\n        Ex1: buf:=tar(\"test.tar\");\n        Ex2:tar(buf);\n        Ex3:tar(buf,1,\"123456\");\n        Ex4:tar(buf,2,\"456\");\n        Ex5:tar(buf,0,\"456\");\n        Ex6:tar(buf,\"file.tar\");\n        Ex7: purge(buf);\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2935tar = {"tar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2935tar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2934tar};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2935tar(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tar (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tar", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2934tar(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2934tar(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tar", 1);

  /* "giacpy/auto-methods.pxi":18354
 * 
 *         '''
 *         return GiacMethods['tar'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def taux_accroissement(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tar); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18354, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18340
 *         return GiacMethods['tanh'](self,*args)
 * 
 *      def tar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tar:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18356
 *         return GiacMethods['tar'](self,*args)
 * 
 *      def taux_accroissement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taux_accroissement:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2937taux_accroissement(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2936taux_accroissement, "From Giac's documentation:\n        Help for taux_accroissement:\n        taux_accroissement(Expr,Var,Val1,(Val1+Var or Val2))\n        Returns the rate of change of an expression when the variable goes from Val1 to Val2 (by default Var=x).\n        See also: 1/ diff 2/ limit \n        Ex1:taux_accroissement(x^2,1,1+h)\n        Ex2:taux_accroissement(x^2,1,2)\n        Ex3:taux_accroissement(a^2,a,1,1+h)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2937taux_accroissement = {"taux_accroissement", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2937taux_accroissement, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2936taux_accroissement};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2937taux_accroissement(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("taux_accroissement (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "taux_accroissement", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2936taux_accroissement(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2936taux_accroissement(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("taux_accroissement", 1);

  /* "giacpy/auto-methods.pxi":18367
 * 
 *         '''
 *         return GiacMethods['taux_accroissement'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def taylor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_taux_accroissement); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18367, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18356
 *         return GiacMethods['tar'](self,*args)
 * 
 *      def taux_accroissement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taux_accroissement:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.taux_accroissement", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18369
 *         return GiacMethods['taux_accroissement'](self,*args)
 * 
 *      def taylor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taylor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2939taylor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2938taylor, "From Giac's documentation:\n        Help for taylor:\n        taylor(Expr,[Var=limit_point],[Order])\n        Series expansion at finite or infinite points (by default x=0, and relative order=5).\n        See also: 1/ series 2/ limit 3/ pade 4/ polynom \n        Ex1:taylor(sin(x)/x,x,0)\n        Ex2:taylor(sin(x),x=0,5,polynom)\n        Ex3:taylor(ln(y+y^2)-ln(y),y)\n        Ex4:taylor(ln(x+x^2)-ln(x),x,2)\n        Ex5:taylor(ln(x+x^2)-ln(x),x=0,2)\n        Ex6:taylor(ln(x+x^2)-ln(x),x=1,2)\n        Ex7:taylor((x^4+x+2)/(x^2+1),x,5)\n        Ex8:taylor(sin(t*x+t*y)+cos(t*x*t*y),t=0,6,polynom)(h=1) \n        Ex9:taylor(sin((1+h*t)*(pi/2+k*t)),t=0,3,polynom)(t=1)\n        Ex10:taylor((-1+k*t)^2/(1+h*t)^3,t=0,3,polynom)(t=1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2939taylor = {"taylor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2939taylor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2938taylor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2939taylor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("taylor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "taylor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2938taylor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2938taylor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("taylor", 1);

  /* "giacpy/auto-methods.pxi":18387
 * 
 *         '''
 *         return GiacMethods['taylor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tchebyshev1(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_taylor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18387, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18369
 *         return GiacMethods['taux_accroissement'](self,*args)
 * 
 *      def taylor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taylor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.taylor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18389
 *         return GiacMethods['taylor'](self,*args)
 * 
 *      def tchebyshev1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev1:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2941tchebyshev1(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2940tchebyshev1, "From Giac's documentation:\n        Help for tchebyshev1:\n        tchebyshev1(Intg(n))\n        Returns the n-th Tchebyshev polynomial of first kind.\n        See also: 1/ tchebyshev2 2/ hermite \n        Ex1:tchebyshev1(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2941tchebyshev1 = {"tchebyshev1", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2941tchebyshev1, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2940tchebyshev1};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2941tchebyshev1(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tchebyshev1 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tchebyshev1", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2940tchebyshev1(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2940tchebyshev1(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tchebyshev1", 1);

  /* "giacpy/auto-methods.pxi":18398
 * 
 *         '''
 *         return GiacMethods['tchebyshev1'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tchebyshev2(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tchebyshev1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18398, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18389
 *         return GiacMethods['taylor'](self,*args)
 * 
 *      def tchebyshev1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev1:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tchebyshev1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18400
 *         return GiacMethods['tchebyshev1'](self,*args)
 * 
 *      def tchebyshev2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2943tchebyshev2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2942tchebyshev2, "From Giac's documentation:\n        Help for tchebyshev2:\n        tchebyshev2(Intg(n))\n        Returns the nt-h Tchebyshev polynomial of second kind.\n        See also: 1/ tchebyshev1 2/ hermite \n        Ex1:tchebyshev2(3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2943tchebyshev2 = {"tchebyshev2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2943tchebyshev2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2942tchebyshev2};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2943tchebyshev2(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tchebyshev2 (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tchebyshev2", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2942tchebyshev2(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2942tchebyshev2(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tchebyshev2", 1);

  /* "giacpy/auto-methods.pxi":18409
 * 
 *         '''
 *         return GiacMethods['tchebyshev2'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tcoeff(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tchebyshev2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18409, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18400
 *         return GiacMethods['tchebyshev1'](self,*args)
 * 
 *      def tchebyshev2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tchebyshev2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18411
 *         return GiacMethods['tchebyshev2'](self,*args)
 * 
 *      def tcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcoeff:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2945tcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2944tcoeff, "From Giac's documentation:\n        Help for tcoeff:\n        tcoeff(Poly||Lst)\n        Returns the coefficient of the term of lowest degree of a polynomial (t=trailing).\n        See also: 1/ lcoeff \n        Ex1:tcoeff(-2*x^3+x^2+7*x)\n        Ex2:tcoeff([-2,1,7,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2945tcoeff = {"tcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2945tcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2944tcoeff};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2945tcoeff(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tcoeff (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tcoeff", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2944tcoeff(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2944tcoeff(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tcoeff", 1);

  /* "giacpy/auto-methods.pxi":18421
 * 
 *         '''
 *         return GiacMethods['tcoeff'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tcollect(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tcoeff); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18421, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18411
 *         return GiacMethods['tchebyshev2'](self,*args)
 * 
 *      def tcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcoeff:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tcoeff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18423
 *         return GiacMethods['tcoeff'](self,*args)
 * 
 *      def tcollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcollect:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2947tcollect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2946tcollect, "From Giac's documentation:\n        Help for tcollect:\n        tcollect(Expr)\n        Collects trigonometric expressions.\n        See also: 1/ texpand 2/ tlin \n        Ex1:tcollect(sin(x)+cos(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2947tcollect = {"tcollect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2947tcollect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2946tcollect};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2947tcollect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tcollect (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tcollect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2946tcollect(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2946tcollect(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tcollect", 1);

  /* "giacpy/auto-methods.pxi":18432
 * 
 *         '''
 *         return GiacMethods['tcollect'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tdeg(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tcollect); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18432, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18423
 *         return GiacMethods['tcoeff'](self,*args)
 * 
 *      def tcollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcollect:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tcollect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18434
 *         return GiacMethods['tcollect'](self,*args)
 * 
 *      def tdeg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tdeg:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2949tdeg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2948tdeg, "From Giac's documentation:\n        Help for tdeg:\n        tdeg(Opt)\n        Option of the gbasis or greduce command to specify an order for monomials (complete degree then lexicographic order).\n        See also: 1/ gbasis 2/ greduce \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2949tdeg = {"tdeg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2949tdeg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2948tdeg};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2949tdeg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tdeg (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tdeg", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2948tdeg(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2948tdeg(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tdeg", 1);

  /* "giacpy/auto-methods.pxi":18442
 * 
 *         '''
 *         return GiacMethods['tdeg'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def teal(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tdeg); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18442, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18434
 *         return GiacMethods['tcollect'](self,*args)
 * 
 *      def tdeg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tdeg:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tdeg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18444
 *         return GiacMethods['tdeg'](self,*args)
 * 
 *      def teal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for teal:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2951teal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2950teal, "From Giac's documentation:\n        Help for teal:\n        teal(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2951teal = {"teal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2951teal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2950teal};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2951teal(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("teal (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "teal", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2950teal(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2950teal(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("teal", 1);

  /* "giacpy/auto-methods.pxi":18454
 * 
 *         '''
 *         return GiacMethods['teal'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tensor_product(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_teal); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18454, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18444
 *         return GiacMethods['tdeg'](self,*args)
 * 
 *      def teal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for teal:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.teal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18456
 *         return GiacMethods['teal'](self,*args)
 * 
 *      def tensor_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tensor_product:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2953tensor_product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2952tensor_product, "From Giac's documentation:\n        Help for tensor_product:\n        tensor_product(Seq(G1,G2,..))\n        Returns the tensor product of the input graphs G1, G2, ... with vertices labeled as \"u:v:...\" where u, v, ... are vertices from G1, G2, ..., respectively.\n        See also: 1/ cartesian_product \n        Ex1:tensor_product(graph(trail(1,2,3,4,5,2)),star_graph(3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2953tensor_product = {"tensor_product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2953tensor_product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2952tensor_product};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2953tensor_product(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tensor_product (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tensor_product", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2952tensor_product(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2952tensor_product(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tensor_product", 1);

  /* "giacpy/auto-methods.pxi":18465
 * 
 *         '''
 *         return GiacMethods['tensor_product'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tetrahedron(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tensor_product); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18465, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18456
 *         return GiacMethods['teal'](self,*args)
 * 
 *      def tensor_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tensor_product:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tensor_product", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18467
 *         return GiacMethods['tensor_product'](self,*args)
 * 
 *      def tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tetrahedron:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2955tetrahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2954tetrahedron, "From Giac's documentation:\n        Help for tetrahedron:\n        tetrahedron(Pnt(A),Pnt(B),Pnt(C),[Pnt(D)])\n        Draws the regular direct pyramid ABCD with vertices A,B and a face in the plane (A,B,C) when there is 3 arguments and the pyramid ABCD when there are 4 arguments.\n        See also: 1/ cube 2/ cylinder 3/ icosahedron 4/ dodecahedron 5/ octahedron \n        Ex1:tetrahedron([0,0,0],[3,0,0],[0,1,0])\n        Ex2:tetrahedron([0,0,0],[3,0,0],[0,3,0],[0,0,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2955tetrahedron = {"tetrahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2955tetrahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2954tetrahedron};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2955tetrahedron(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tetrahedron (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tetrahedron", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2954tetrahedron(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2954tetrahedron(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tetrahedron", 1);

  /* "giacpy/auto-methods.pxi":18477
 * 
 *         '''
 *         return GiacMethods['tetrahedron'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def texpand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tetrahedron); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18477, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18467
 *         return GiacMethods['tensor_product'](self,*args)
 * 
 *      def tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tetrahedron:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tetrahedron", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18479
 *         return GiacMethods['tetrahedron'](self,*args)
 * 
 *      def texpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for texpand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2957texpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2956texpand, "From Giac's documentation:\n        Help for texpand:\n        texpand(Expr)\n        Expands transcendental expressions.\n        See also: 1/ tcollect 2/ tlin 3/ lin 4/ trigexpand \n        Ex1:texpand(sin(2*x)+exp(x+y))\n        Ex2:texpand(cos(x+y))\n        Ex3:texpand(cos(3*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2957texpand = {"texpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2957texpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2956texpand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2957texpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("texpand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "texpand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2956texpand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2956texpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("texpand", 1);

  /* "giacpy/auto-methods.pxi":18490
 * 
 *         '''
 *         return GiacMethods['texpand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def thickness(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_texpand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18490, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18479
 *         return GiacMethods['tetrahedron'](self,*args)
 * 
 *      def texpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for texpand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.texpand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18492
 *         return GiacMethods['texpand'](self,*args)
 * 
 *      def thickness(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for thickness:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2959thickness(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2958thickness, "From Giac's documentation:\n        Help for thickness:\n        thickness(Opt)\n        Option (Maple compatibility) of a graphic command to define the thickness of lines.\n        See also: 1/ line_width \n        Ex1: segment(0,point(1,1),thickness=5)\n        Ex2: segment(0,point(1,1),epaisseur=5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2959thickness = {"thickness", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2959thickness, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2958thickness};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2959thickness(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("thickness (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "thickness", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2958thickness(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2958thickness(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("thickness", 1);

  /* "giacpy/auto-methods.pxi":18502
 * 
 *         '''
 *         return GiacMethods['thickness'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def threshold(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_thickness); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18502, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18492
 *         return GiacMethods['texpand'](self,*args)
 * 
 *      def thickness(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for thickness:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.thickness", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18504
 *         return GiacMethods['thickness'](self,*args)
 * 
 *      def threshold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for threshold:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2961threshold(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2960threshold, "From Giac's documentation:\n        Help for threshold:\n        threshold(Lst,Real(bound)[=Expr(repl)] or Lst[Real(lower)[=Expr(rl)],Real(upper)[=Expr(ru)]],[Fnc(compare)],[abs[=true or false]])\n        Performs thresholding operations on a list of real or complex numbers.\n        See also: 1/ max 2/ min \n        Ex1:threshold([1,3,2,4,5,4,3,2,3,1],3,'>=')\n        Ex2:threshold([-10,-5,0,5,10],7=a,abs=true)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2961threshold = {"threshold", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2961threshold, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2960threshold};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2961threshold(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("threshold (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "threshold", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2960threshold(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2960threshold(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("threshold", 1);

  /* "giacpy/auto-methods.pxi":18514
 * 
 *         '''
 *         return GiacMethods['threshold'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def throw(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_threshold); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18514, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18504
 *         return GiacMethods['thickness'](self,*args)
 * 
 *      def threshold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for threshold:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.threshold", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18516
 *         return GiacMethods['threshold'](self,*args)
 * 
 *      def throw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for throw:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2963throw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2962throw, "From Giac's documentation:\n        Help for throw:\n        throw(Str)\n        Generates the display of an error in a program.\n        See also: 1/ try 2/ catch \n        Ex1:throw(\"Argument should be integer\")\n        Ex2:throw(\"je provoque une erreur\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2963throw = {"throw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2963throw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2962throw};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2963throw(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("throw (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "throw", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2962throw(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2962throw(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("throw", 1);

  /* "giacpy/auto-methods.pxi":18526
 * 
 *         '''
 *         return GiacMethods['throw'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def title(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_throw); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18526, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18516
 *         return GiacMethods['threshold'](self,*args)
 * 
 *      def throw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for throw:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.throw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18528
 *         return GiacMethods['throw'](self,*args)
 * 
 *      def title(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for title:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2965title(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2964title, "From Giac's documentation:\n        Help for title:\n        title(Opt)\n        Global option of a graphic command to put a title in a graphic.\n        See also: 1/ line_width \n        Ex1: title=\"segment\";segment(0,point(1,1),epaisseur=5)\n        Ex2: titre=\"segment\";segment(0,point(1,1),epaisseur=5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2965title = {"title", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2965title, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2964title};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2965title(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("title (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "title", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2964title(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2964title(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("title", 1);

  /* "giacpy/auto-methods.pxi":18538
 * 
 *         '''
 *         return GiacMethods['title'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def titre(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_title); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18538, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18528
 *         return GiacMethods['throw'](self,*args)
 * 
 *      def title(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for title:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.title", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18540
 *         return GiacMethods['title'](self,*args)
 * 
 *      def titre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for titre:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2967titre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2966titre, "From Giac's documentation:\n        Help for titre:\n        titre(Opt)\n        Global option of a graphic command to put a title in a graphic.\n        See also: 1/ line_width \n        Ex1: title=\"segment\";segment(0,point(1,1),epaisseur=5)\n        Ex2: titre=\"segment\";segment(0,point(1,1),epaisseur=5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2967titre = {"titre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2967titre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2966titre};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2967titre(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("titre (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "titre", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2966titre(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2966titre(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("titre", 1);

  /* "giacpy/auto-methods.pxi":18550
 * 
 *         '''
 *         return GiacMethods['titre'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tlin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_titre); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18550, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18540
 *         return GiacMethods['title'](self,*args)
 * 
 *      def titre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for titre:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.titre", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18552
 *         return GiacMethods['titre'](self,*args)
 * 
 *      def tlin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tlin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2969tlin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2968tlin, "From Giac's documentation:\n        Help for tlin:\n        tlin(ExprTrig)\n        Trigonometric linearization.\n        See also: 1/ texpand 2/ lin \n        Ex1:tlin(sin(x)^3)\n        Ex2:tlin(cos(x)*cos(y))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2969tlin = {"tlin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2969tlin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2968tlin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2969tlin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tlin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tlin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2968tlin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2968tlin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tlin", 1);

  /* "giacpy/auto-methods.pxi":18562
 * 
 *         '''
 *         return GiacMethods['tlin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tonnetz(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tlin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18562, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18552
 *         return GiacMethods['titre'](self,*args)
 * 
 *      def tlin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tlin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tlin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18564
 *         return GiacMethods['tlin'](self,*args)
 * 
 *      def tonnetz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tonnetz:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2971tonnetz(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2970tonnetz, "From Giac's documentation:\n        Help for tonnetz:\n        tonnetz(Intg(a),Intg(b),Intg(c),[Intg(d)])\n        Returns the graph corresponding to the [a,b,c] resp. [a,b,c,d] tone network (tonnetz) used in neo-Riemannian music theory.\n        See also: 1/ is_regular 2/ find_cliques \n        Ex1:tonnetz(3,4,5)\n        Ex2:tonnetz(2,3,3,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2971tonnetz = {"tonnetz", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2971tonnetz, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2970tonnetz};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2971tonnetz(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tonnetz (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tonnetz", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2970tonnetz(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2970tonnetz(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tonnetz", 1);

  /* "giacpy/auto-methods.pxi":18574
 * 
 *         '''
 *         return GiacMethods['tonnetz'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def topologic_sort(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tonnetz); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18574, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18564
 *         return GiacMethods['tlin'](self,*args)
 * 
 *      def tonnetz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tonnetz:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tonnetz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18576
 *         return GiacMethods['tonnetz'](self,*args)
 * 
 *      def topologic_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topologic_sort:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2973topologic_sort(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2972topologic_sort, "From Giac's documentation:\n        Help for topologic_sort:\n        topologic_sort(Graph(G))\n        Returns the list of vertices sorted according to the topological ordering in a directed acyclic graph G.\n        See also: 1/ digraph 2/ is_acyclic \n        Ex1:topologic_sort(digraph(%{[c,a],[c,b],[c,d],[a,d],[b,d],[a,b]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2973topologic_sort = {"topologic_sort", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2973topologic_sort, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2972topologic_sort};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2973topologic_sort(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("topologic_sort (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "topologic_sort", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2972topologic_sort(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2972topologic_sort(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("topologic_sort", 1);

  /* "giacpy/auto-methods.pxi":18585
 * 
 *         '''
 *         return GiacMethods['topologic_sort'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def topological_sort(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_topologic_sort); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18585, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18576
 *         return GiacMethods['tonnetz'](self,*args)
 * 
 *      def topologic_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topologic_sort:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.topologic_sort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18587
 *         return GiacMethods['topologic_sort'](self,*args)
 * 
 *      def topological_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topological_sort:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2975topological_sort(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2974topological_sort, "From Giac's documentation:\n        Help for topological_sort:\n        topological_sort(Graph(G))\n        Returns the list of vertices sorted according to the topological ordering in a directed acyclic graph G.\n        See also: 1/ digraph 2/ is_acyclic \n        Ex1:topological_sort(digraph(%{[c,a],[c,b],[c,d],[a,d],[b,d],[a,b]%}))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2975topological_sort = {"topological_sort", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2975topological_sort, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2974topological_sort};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2975topological_sort(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("topological_sort (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "topological_sort", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2974topological_sort(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2974topological_sort(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("topological_sort", 1);

  /* "giacpy/auto-methods.pxi":18596
 * 
 *         '''
 *         return GiacMethods['topological_sort'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def topology(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_topological_sort); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18596, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18587
 *         return GiacMethods['topologic_sort'](self,*args)
 * 
 *      def topological_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topological_sort:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.topological_sort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18598
 *         return GiacMethods['topological_sort'](self,*args)
 * 
 *      def topology(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topology:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2977topology(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2976topology, "From Giac's documentation:\n        Help for topology:\n        topology(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2977topology = {"topology", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2977topology, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2976topology};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2977topology(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("topology (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "topology", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2976topology(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2976topology(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("topology", 1);

  /* "giacpy/auto-methods.pxi":18606
 * 
 *         '''
 *         return GiacMethods['topology'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def torus_grid_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_topology); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18606, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18598
 *         return GiacMethods['topological_sort'](self,*args)
 * 
 *      def topology(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topology:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.topology", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18608
 *         return GiacMethods['topology'](self,*args)
 * 
 *      def torus_grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for torus_grid_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2979torus_grid_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2978torus_grid_graph, "From Giac's documentation:\n        Help for torus_grid_graph:\n        torus_grid_graph(Intg(m),Intg(n))\n        Returns a torus grid graph on m*n vertices, where m,n>=3.\n        See also: 1/ grid_graph \n        Ex1:torus_grid_graph(6,12)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2979torus_grid_graph = {"torus_grid_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2979torus_grid_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2978torus_grid_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2979torus_grid_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("torus_grid_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "torus_grid_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2978torus_grid_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2978torus_grid_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("torus_grid_graph", 1);

  /* "giacpy/auto-methods.pxi":18617
 * 
 *         '''
 *         return GiacMethods['torus_grid_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def total_degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_torus_grid_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18617, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18608
 *         return GiacMethods['topology'](self,*args)
 * 
 *      def torus_grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for torus_grid_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.torus_grid_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18619
 *         return GiacMethods['torus_grid_graph'](self,*args)
 * 
 *      def total_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for total_degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2981total_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2980total_degree, "From Giac's documentation:\n        Help for total_degree:\n        total_degree(Poly(P),Lst(Vars))\n        Total degree of the polynomial P with respect to the second argument.\n        See also: 1/ valuation 2/ size 3/ degree \n        Ex1:total_degree(x^3*y+x*y,[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2981total_degree = {"total_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2981total_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2980total_degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2981total_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("total_degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "total_degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2980total_degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2980total_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("total_degree", 1);

  /* "giacpy/auto-methods.pxi":18628
 * 
 *         '''
 *         return GiacMethods['total_degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tourne_droite(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_total_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18628, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18619
 *         return GiacMethods['torus_grid_graph'](self,*args)
 * 
 *      def total_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for total_degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.total_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18630
 *         return GiacMethods['total_degree'](self,*args)
 * 
 *      def tourne_droite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_droite:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2983tourne_droite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2982tourne_droite, "From Giac's documentation:\n        Help for tourne_droite:\n        tourne_droite(NULL or Real(n))\n        The turtle turns right by n degrees (by default n=90).\n        See also: 1/ tourne_gauche 2/ pas_de_cote \n        Ex1: tourne_droite 60\n        Ex2:tourne_droite(60)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2983tourne_droite = {"tourne_droite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2983tourne_droite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2982tourne_droite};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2983tourne_droite(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tourne_droite (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tourne_droite", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2982tourne_droite(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2982tourne_droite(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tourne_droite", 1);

  /* "giacpy/auto-methods.pxi":18640
 * 
 *         '''
 *         return GiacMethods['tourne_droite'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tourne_gauche(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tourne_droite); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18640, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18630
 *         return GiacMethods['total_degree'](self,*args)
 * 
 *      def tourne_droite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_droite:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tourne_droite", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18642
 *         return GiacMethods['tourne_droite'](self,*args)
 * 
 *      def tourne_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_gauche:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2985tourne_gauche(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2984tourne_gauche, "From Giac's documentation:\n        Help for tourne_gauche:\n        tourne_gauche(NULL or Real(n))\n        The turtle turns left by n degrees (by defaults n=90).\n        See also: 1/ tourne_droite \n        Ex1: tourne_gauche 60\n        Ex2:tourne_gauche(60)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2985tourne_gauche = {"tourne_gauche", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2985tourne_gauche, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2984tourne_gauche};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2985tourne_gauche(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tourne_gauche (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tourne_gauche", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2984tourne_gauche(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2984tourne_gauche(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tourne_gauche", 1);

  /* "giacpy/auto-methods.pxi":18652
 * 
 *         '''
 *         return GiacMethods['tourne_gauche'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tpsolve(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tourne_gauche); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18652, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18642
 *         return GiacMethods['tourne_droite'](self,*args)
 * 
 *      def tourne_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_gauche:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tourne_gauche", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18654
 *         return GiacMethods['tourne_gauche'](self,*args)
 * 
 *      def tpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tpsolve:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2987tpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2986tpsolve, "From Giac's documentation:\n        Help for tpsolve:\n        tpsolve(List(supply),List(demand),Mtrx(cost_matrix))\n        Solves a transportation problem using MODI method.\n        Ex1:tpsolve([12,17,11],[10,10,10,10],[[500,750,300,450],[650,800,400,600],[400,700,500,550]])\n        Ex2:tpsolve([95,70,165,165],[195,150,30,45,75],[[15,M,45,M,0],[12,40,M,M,0],[0,15,25,25,0],[M,0,M,12,0]])\n        Ex3:tpsolve([1,1,1,1],[1,1,1,1],[[10,12,9,11],[5,10,7,8],[12,14,13,11],[8,15,11,9]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2987tpsolve = {"tpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2987tpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2986tpsolve};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2987tpsolve(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tpsolve (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tpsolve", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2986tpsolve(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2986tpsolve(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tpsolve", 1);

  /* "giacpy/auto-methods.pxi":18664
 * 
 *         '''
 *         return GiacMethods['tpsolve'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trace(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tpsolve); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18664, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18654
 *         return GiacMethods['tourne_gauche'](self,*args)
 * 
 *      def tpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tpsolve:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tpsolve", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18666
 *         return GiacMethods['tpsolve'](self,*args)
 * 
 *      def trace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trace:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2989trace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2988trace, "From Giac's documentation:\n        Help for trace:\n        trace(Mtrx or GeoObj)\n        Returns the trace of a square matrix or draws the trace of a geometric object when the parameter changes (see Trace in Menu button of a geometric level and write only one instruction on each line).\n        See also: 1/ det 2/ lieu \n        Ex1:trace([[1,2,3],[1,3,6],[2,5,7]])\n        Ex2:trace([[1+i,2,3],[1,3,6],[2,5,9-i]])\n        Ex3: assume(a=[0.7,-5,5,0.1]);trace(point(a-i*a))\n        Ex4: assume(a=[0.7,-5,5,0.1]);trace(inter_unique(droite(y=a*x+a),droite(y=2*a*x+1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2989trace = {"trace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2989trace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2988trace};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2989trace(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trace (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trace", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2988trace(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2988trace(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trace", 1);

  /* "giacpy/auto-methods.pxi":18678
 * 
 *         '''
 *         return GiacMethods['trace'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trail(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trace); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18678, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18666
 *         return GiacMethods['tpsolve'](self,*args)
 * 
 *      def trace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trace:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18680
 *         return GiacMethods['trace'](self,*args)
 * 
 *      def trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2991trail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2990trail, "From Giac's documentation:\n        Help for trail:\n        trail(Seq(V))\n        Returns a trail of vertices from V (inert command).\n        See also: 1/ graph 2/ digraph \n        Ex1:trail(1,2,3,4,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2991trail = {"trail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2991trail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2990trail};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2991trail(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trail (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trail", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2990trail(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2990trail(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trail", 1);

  /* "giacpy/auto-methods.pxi":18689
 * 
 *         '''
 *         return GiacMethods['trail'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trail2edges(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trail); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18689, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18680
 *         return GiacMethods['trace'](self,*args)
 * 
 *      def trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trail", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18691
 *         return GiacMethods['trail'](self,*args)
 * 
 *      def trail2edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail2edges:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2993trail2edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2992trail2edges, "From Giac's documentation:\n        Help for trail2edges:\n        trail2edges(Trail(T))\n        Converts a trail T to the list of its edges.\n        See also: 1/ subgraph 2/ trail \n        Ex1:trail2edges(trail(1,2,3,4,1,3))\n        Ex2:trail2edges([1,2,3,4,1,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2993trail2edges = {"trail2edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2993trail2edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2992trail2edges};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2993trail2edges(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trail2edges (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trail2edges", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2992trail2edges(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2992trail2edges(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trail2edges", 1);

  /* "giacpy/auto-methods.pxi":18701
 * 
 *         '''
 *         return GiacMethods['trail2edges'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def train(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trail2edges); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18701, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18691
 *         return GiacMethods['trail'](self,*args)
 * 
 *      def trail2edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail2edges:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trail2edges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18703
 *         return GiacMethods['trail2edges'](self,*args)
 * 
 *      def train(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for train:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2995train(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2994train, "From Giac's documentation:\n        Help for train:\n        train(NeuralNet(net),Mtrx(input),Mtrx||Vect(expected_output),[Intg(batchsize)]))\n        Performs neural network training and returns the trained network.\n        See also: 1/ neural_network \n        Ex1: X:=ranm(10000,2,uniformd(-1,1)):;f(x):=2*x[0]-x[1]+10:;net:=train(neural_network([2,3,1]),X,apply(f,X),1):;x0:=ranv(2,uniformd(-1,1)):;net(x0);f(x0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2995train = {"train", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2995train, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2994train};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2995train(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("train (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "train", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2994train(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2994train(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("train", 1);

  /* "giacpy/auto-methods.pxi":18712
 * 
 *         '''
 *         return GiacMethods['train'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trames(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_train); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18712, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18703
 *         return GiacMethods['trail2edges'](self,*args)
 * 
 *      def train(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for train:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.train", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18714
 *         return GiacMethods['train'](self,*args)
 * 
 *      def trames(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trames:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2997trames(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2996trames, "From Giac's documentation:\n        Help for trames:\n        trames(Opt)\n        Option of animate and animate3d commands to give the number of pictures.\n        See also: 1/ animate 2/ animate3d \n        Ex1: animate(sin(x*t),x=-pi..pi,t=-3..3,frames=30)\n        Ex2: animate3d(x^2+t*y^2,[x=-2..2,y=-2..2],t=-3..3,frames=10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2997trames = {"trames", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2997trames, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2996trames};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2997trames(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trames (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trames", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2996trames(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2996trames(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trames", 1);

  /* "giacpy/auto-methods.pxi":18724
 * 
 *         '''
 *         return GiacMethods['trames'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tran(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trames); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18724, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18714
 *         return GiacMethods['train'](self,*args)
 * 
 *      def trames(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trames:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trames", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18726
 *         return GiacMethods['trames'](self,*args)
 * 
 *      def tran(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tran:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2999tran(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2998tran, "From Giac's documentation:\n        Help for tran:\n        tran(Mtrx)\n        Transposes a matrix (without conjugation).\n        See also: 1/ conj 2/ trn \n        Ex1:tran([[1,2,3],[1,3,6],[2,5,7]])\n        Ex2:tran([[1+i,2,3],[1,3,6],[2,5,9-i]])\n        Ex3:tran(conj([[1+i,2,3],[1,3,6],[2,5,9-i]]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2999tran = {"tran", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2999tran, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2998tran};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2999tran(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tran (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tran", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2998tran(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_2998tran(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tran", 1);

  /* "giacpy/auto-methods.pxi":18737
 * 
 *         '''
 *         return GiacMethods['tran'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def transitive_closure(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tran); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18737, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18726
 *         return GiacMethods['trames'](self,*args)
 * 
 *      def tran(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tran:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tran", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18739
 *         return GiacMethods['tran'](self,*args)
 * 
 *      def transitive_closure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transitive_closure:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3001transitive_closure(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3000transitive_closure, "From Giac's documentation:\n        Help for transitive_closure:\n        transitive_closure(Graph(G),[weighted[=true||false]])\n        Returns the [weighted (by default false)] transitive closure of G.\n        See also: 1/ allpairs_distance 2/ is_connected 3/ shortest_path 4/ vertex_distance \n        Ex1:transitive_closure(digraph([1,2,3,4,5,6],%{[1,2],[2,3],[2,4],[4,5],[3,5]%}),weighted)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3001transitive_closure = {"transitive_closure", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3001transitive_closure, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3000transitive_closure};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3001transitive_closure(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transitive_closure (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "transitive_closure", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3000transitive_closure(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3000transitive_closure(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transitive_closure", 1);

  /* "giacpy/auto-methods.pxi":18748
 * 
 *         '''
 *         return GiacMethods['transitive_closure'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def translation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_transitive_closure); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18748, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18739
 *         return GiacMethods['tran'](self,*args)
 * 
 *      def transitive_closure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transitive_closure:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.transitive_closure", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18750
 *         return GiacMethods['transitive_closure'](self,*args)
 * 
 *      def translation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for translation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3003translation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3002translation, "From Giac's documentation:\n        Help for translation:\n        translation(Vect, Pnt(C))\n        translation(B-A,C) (resp translation([a,b,c],C)) is the translation of C in the translation of vector AB (resp [a,b,c]).\n        See also: 1/ rotation 2/ reflection \n        Ex1:translation(1+i,i)\n        Ex2:translation([1,1,1],point([1,2,3]))\n        Ex3: t:=translation(1+i);t(i)\n        Ex4: t:=translation([1,1,1]);t(point([1,2,3]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3003translation = {"translation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3003translation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3002translation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3003translation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("translation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "translation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3002translation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3002translation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("translation", 1);

  /* "giacpy/auto-methods.pxi":18762
 * 
 *         '''
 *         return GiacMethods['translation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def transpose(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_translation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18762, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18750
 *         return GiacMethods['transitive_closure'](self,*args)
 * 
 *      def translation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for translation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.translation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18764
 *         return GiacMethods['translation'](self,*args)
 * 
 *      def transpose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transpose:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3005transpose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3004transpose, "From Giac's documentation:\n        Help for transpose:\n        transpose(Mtrx)\n        Transposes a matrix (without conjugation).\n        See also: 1/ conj 2/ trn \n        Ex1:transpose([[1,2,3],[1,3,6],[2,5,7]])\n        Ex2:transpose([[1+i,2,3],[1,3,6],[2,5,9-i]])\n        Ex3:transpose(conj([[1+i,2,3],[1,3,6],[2,5,9-i]]))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3005transpose = {"transpose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3005transpose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3004transpose};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3005transpose(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("transpose (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "transpose", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3004transpose(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3004transpose(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("transpose", 1);

  /* "giacpy/auto-methods.pxi":18775
 * 
 *         '''
 *         return GiacMethods['transpose'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trapeze(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_transpose); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18775, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18764
 *         return GiacMethods['translation'](self,*args)
 * 
 *      def transpose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transpose:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.transpose", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18777
 *         return GiacMethods['transpose'](self,*args)
 * 
 *      def trapeze(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapeze:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3007trapeze(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3006trapeze, "From Giac's documentation:\n        Help for trapeze:\n        trapeze(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3007trapeze = {"trapeze", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3007trapeze, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3006trapeze};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3007trapeze(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trapeze (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trapeze", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3006trapeze(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3006trapeze(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trapeze", 1);

  /* "giacpy/auto-methods.pxi":18791
 * 
 *         '''
 *         return GiacMethods['trapeze'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trapezoid(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trapeze); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18791, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18777
 *         return GiacMethods['transpose'](self,*args)
 * 
 *      def trapeze(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapeze:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trapeze", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18793
 *         return GiacMethods['trapeze'](self,*args)
 * 
 *      def trapezoid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapezoid:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3009trapezoid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3008trapezoid, "From Giac's documentation:\n        Help for trapezoid:\n        trapezoid(Opt)\n        Option of the plotarea command and of the area command.\n        See also: 1/ plotarea 2/ area \n        Ex1: plotarea(x^2,x=0..1,5,trapezoid)\n        Ex2: plotarea(x^2,x=0..1,5,middle_point)\n        Ex3: plotarea(x^2,x=0..1,5,right_rectangle)\n        Ex4: plotarea(x^2,x=0..1,5,left_rectangle)\n        Ex5: area(x^2,x=0..1,5,middle_point)\n        Ex6: area(x^2,x=0..1,5,trapezoid)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3009trapezoid = {"trapezoid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3009trapezoid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3008trapezoid};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3009trapezoid(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trapezoid (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trapezoid", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3008trapezoid(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3008trapezoid(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trapezoid", 1);

  /* "giacpy/auto-methods.pxi":18807
 * 
 *         '''
 *         return GiacMethods['trapezoid'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def traveling_salesman(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trapezoid); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18807, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18793
 *         return GiacMethods['trapeze'](self,*args)
 * 
 *      def trapezoid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapezoid:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trapezoid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18809
 *         return GiacMethods['trapezoid'](self,*args)
 * 
 *      def traveling_salesman(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for traveling_salesman:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3011traveling_salesman(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3010traveling_salesman, "From Giac's documentation:\n        Help for traveling_salesman:\n        traveling_salesman(Graph(G),[Mtrx(M)],[opts])\n        Returns a Hamiltonian cycle in an unweighted graph G or solves a traveling salesman problem if G is weighted (matrix M can be used for edge weights), returning a sequence containing the minimal cost and the corresponding Hamiltonian cycle.\n        See also: 1/ is_hamiltonian \n        Ex1:traveling_salesman(hypercube_graph(5))\n        Ex2:traveling_salesman(digraph(%{[[1,2],1],[[1,3],2],[[2,3],2],[[2,4],3],[[3,2],3],[[3,4],2],[[4,1],1]%}))\n        Ex3: M:=randmatrix(4,4,99); traveling_salesman(graph(\"tetrahedron\"),M)\n        Ex4: G:=set_vertex_positions(complete_graph(42),[randvector(2,1000)$(k=1..42)]); traveling_salesman(G,vertex_distance)\n        Ex5: G:=set_vertex_positions(complete_graph(120),[randvector(2,1000)$(k=1..120)]); c,T:=traveling_salesman(G,vertex_distance,approx)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3011traveling_salesman = {"traveling_salesman", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3011traveling_salesman, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3010traveling_salesman};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3011traveling_salesman(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("traveling_salesman (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "traveling_salesman", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3010traveling_salesman(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3010traveling_salesman(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("traveling_salesman", 1);

  /* "giacpy/auto-methods.pxi":18822
 * 
 *         '''
 *         return GiacMethods['traveling_salesman'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_traveling_salesman); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18822, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18809
 *         return GiacMethods['trapezoid'](self,*args)
 * 
 *      def traveling_salesman(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for traveling_salesman:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.traveling_salesman", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18824
 *         return GiacMethods['traveling_salesman'](self,*args)
 * 
 *      def tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3013tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3012tree, "From Giac's documentation:\n        Help for tree:\n        tree(Opt)\n        Option for the draw_graph command.\n        See also: 1/ planar 2/ spring 3/ draw_graph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3013tree = {"tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3013tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3012tree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3013tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3012tree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3012tree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tree", 1);

  /* "giacpy/auto-methods.pxi":18832
 * 
 *         '''
 *         return GiacMethods['tree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tree_height(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18832, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18824
 *         return GiacMethods['traveling_salesman'](self,*args)
 * 
 *      def tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18834
 *         return GiacMethods['tree'](self,*args)
 * 
 *      def tree_height(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree_height:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3015tree_height(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3014tree_height, "From Giac's documentation:\n        Help for tree_height:\n        tree_height(Graph(T),[Vrtx(r)])\n        Returns the height of a tree graph T with r as the root node, or the minimal height and the corresponding root node if r is omitted.\n        See also: 1/ is_tree 2/ random_tree \n        Ex1:tree_height(graph(%{[1,2],[2,3],[2,4],[4,5]%}),1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3015tree_height = {"tree_height", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3015tree_height, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3014tree_height};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3015tree_height(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tree_height (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tree_height", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3014tree_height(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3014tree_height(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tree_height", 1);

  /* "giacpy/auto-methods.pxi":18843
 * 
 *         '''
 *         return GiacMethods['tree_height'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tri(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tree_height); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18843, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18834
 *         return GiacMethods['tree'](self,*args)
 * 
 *      def tree_height(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree_height:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tree_height", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18845
 *         return GiacMethods['tree_height'](self,*args)
 * 
 *      def tri(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tri:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3017tri(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3016tri, "From Giac's documentation:\n        Help for tri:\n        tri(Expr(x))\n        Returns the value of the triangle function at x.\n        See also: 1/ rect 2/ Heaviside \n        Ex1:tri(x-1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3017tri = {"tri", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3017tri, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3016tri};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3017tri(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tri (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tri", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3016tri(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3016tri(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tri", 1);

  /* "giacpy/auto-methods.pxi":18854
 * 
 *         '''
 *         return GiacMethods['tri'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def triangle(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tri); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18854, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18845
 *         return GiacMethods['tree_height'](self,*args)
 * 
 *      def tri(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tri:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tri", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18856
 *         return GiacMethods['tri'](self,*args)
 * 
 *      def triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3019triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3018triangle, "From Giac's documentation:\n        Help for triangle:\n        triangle((Pnt or Cplx),(Pnt or Cplx),(Pnt or Cplx))\n        triangle(A,B,C) draws the triangle ABC.\n        See also: 1/ equilateral_triangle 2/ isosceles_triangle 3/ right_triangle \n        Ex1:triangle(point(1+i),1,0)\n        Ex2:triangle(0,1,1+i)\n        Ex3:triangle(point(0,0,0),point(3,3,3),point(0,3,3))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3019triangle = {"triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3019triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3018triangle};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3019triangle(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("triangle (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "triangle", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3018triangle(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3018triangle(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("triangle", 1);

  /* "giacpy/auto-methods.pxi":18867
 * 
 *         '''
 *         return GiacMethods['triangle'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def triangle_paper(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_triangle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18867, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18856
 *         return GiacMethods['tri'](self,*args)
 * 
 *      def triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.triangle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18869
 *         return GiacMethods['triangle'](self,*args)
 * 
 *      def triangle_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_paper:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3021triangle_paper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3020triangle_paper, "From Giac's documentation:\n        Help for triangle_paper:\n        triangle_paper(Real(ux),Real(t),Real(uy),[x=xmin..xmax,y=ymin..ymax])\n        Draws in the rectangle [xmin..xmax]*[ymin..ymax], the lines of the grid formed by the lines y=n*uy, the lines, the lines x=n*ux at an angle of t!=0, and the lines ux*y+uy*x=n*ux*uy.\n        Ex1:triangle_paper(1,pi/3,sqrt(3)/2)\n        Ex2:triangle_paper(1,pi/3,sqrt(3)/2,x=-1..4,y=-2..2)\n        Ex3:triangle_paper(papier_triangule(1,pi/3,sqrt(3)/2,x=-2..6,y=-4*sqrt(3)..4*sqrt(3)))\n        Ex4:triangle_paper(0.5,3*pi/4,0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3021triangle_paper = {"triangle_paper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3021triangle_paper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3020triangle_paper};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3021triangle_paper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("triangle_paper (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "triangle_paper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3020triangle_paper(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3020triangle_paper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("triangle_paper", 1);

  /* "giacpy/auto-methods.pxi":18880
 * 
 *         '''
 *         return GiacMethods['triangle_paper'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def triangle_plein(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_triangle_paper); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18880, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18869
 *         return GiacMethods['triangle'](self,*args)
 * 
 *      def triangle_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_paper:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.triangle_paper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18882
 *         return GiacMethods['triangle_paper'](self,*args)
 * 
 *      def triangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_plein:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3023triangle_plein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3022triangle_plein, "From Giac's documentation:\n        Help for triangle_plein:\n        triangle_plein(Real(a),[Real(b)],[Real(t)])\n        Draws a full direct triangle with sides a,b and with angle t, from the turtle position (by default t=90 or (b=a and t=60)).\n        See also: 1/ rectangle_plein \n        Ex1: triangle_plein 30\n        Ex2:triangle_plein(30)\n        Ex3:triangle_plein(30,40)\n        Ex4:triangle_plein(30,40,60)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3023triangle_plein = {"triangle_plein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3023triangle_plein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3022triangle_plein};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3023triangle_plein(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("triangle_plein (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "triangle_plein", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3022triangle_plein(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3022triangle_plein(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("triangle_plein", 1);

  /* "giacpy/auto-methods.pxi":18894
 * 
 *         '''
 *         return GiacMethods['triangle_plein'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def triangle_point(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_triangle_plein); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18894, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18882
 *         return GiacMethods['triangle_paper'](self,*args)
 * 
 *      def triangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_plein:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.triangle_plein", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18896
 *         return GiacMethods['triangle_plein'](self,*args)
 * 
 *      def triangle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_point:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3025triangle_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3024triangle_point, "From Giac's documentation:\n        Help for triangle_point:\n        triangle_point(Opt)\n        Option of the display command for a point.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),point_point)\n        Ex2: F:=display(point(2+1.5*i),rhombus_point)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3025triangle_point = {"triangle_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3025triangle_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3024triangle_point};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3025triangle_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("triangle_point (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "triangle_point", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3024triangle_point(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3024triangle_point(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("triangle_point", 1);

  /* "giacpy/auto-methods.pxi":18906
 * 
 *         '''
 *         return GiacMethods['triangle_point'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def triangle_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_triangle_point); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18906, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18896
 *         return GiacMethods['triangle_plein'](self,*args)
 * 
 *      def triangle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_point:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.triangle_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18908
 *         return GiacMethods['triangle_point'](self,*args)
 * 
 *      def triangle_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3027triangle_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3026triangle_window, "From Giac's documentation:\n        Help for triangle_window:\n        triangle_window(Lst,[Intg(d)],[Interval(n1..n2)])\n        Applies the triangular windowing function with parameter d in {-1,0,1} (by default L=0) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ bartlett_hann_window 13/ tukey_window 14/ welch_window \n        Ex1: scatterplot(triangle_window(randvector(1000,0..1),1))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3027triangle_window = {"triangle_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3027triangle_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3026triangle_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3027triangle_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("triangle_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "triangle_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3026triangle_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3026triangle_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("triangle_window", 1);

  /* "giacpy/auto-methods.pxi":18917
 * 
 *         '''
 *         return GiacMethods['triangle_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trig2exp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_triangle_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18917, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18908
 *         return GiacMethods['triangle_point'](self,*args)
 * 
 *      def triangle_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.triangle_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18919
 *         return GiacMethods['triangle_window'](self,*args)
 * 
 *      def trig2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trig2exp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3029trig2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3028trig2exp, "From Giac's documentation:\n        Help for trig2exp:\n        trig2exp(Expr)\n        Replaces in the argument the trigonometric functions by complex exponentials without linearisation.\n        See also: 1/ exp2trig 2/ atrig2ln \n        Ex1:trig2exp(sin(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3029trig2exp = {"trig2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3029trig2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3028trig2exp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3029trig2exp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trig2exp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trig2exp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3028trig2exp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3028trig2exp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trig2exp", 1);

  /* "giacpy/auto-methods.pxi":18928
 * 
 *         '''
 *         return GiacMethods['trig2exp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trigcos(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trig2exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18928, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18919
 *         return GiacMethods['triangle_window'](self,*args)
 * 
 *      def trig2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trig2exp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trig2exp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18930
 *         return GiacMethods['trig2exp'](self,*args)
 * 
 *      def trigcos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigcos:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3031trigcos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3030trigcos, "From Giac's documentation:\n        Help for trigcos:\n        trigcos(Expr)\n        Simplifies the argument with the formulas sin(x)^2+cos(x)^2=1 and tan(x)=sin(x)/cos(x) privileging cosine.\n        See also: 1/ trigsin 2/ trigtan \n        Ex1:trigcos(sin(x)^4+sin(x)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3031trigcos = {"trigcos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3031trigcos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3030trigcos};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3031trigcos(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trigcos (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trigcos", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3030trigcos(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3030trigcos(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trigcos", 1);

  /* "giacpy/auto-methods.pxi":18939
 * 
 *         '''
 *         return GiacMethods['trigcos'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trigexpand(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trigcos); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18939, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18930
 *         return GiacMethods['trig2exp'](self,*args)
 * 
 *      def trigcos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigcos:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trigcos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18941
 *         return GiacMethods['trigcos'](self,*args)
 * 
 *      def trigexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigexpand:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3033trigexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3032trigexpand, "From Giac's documentation:\n        Help for trigexpand:\n        trigexpand(Expr)\n        Expands trigonometric functions.\n        See also: 1/ texpand 2/ lnexpand 3/ expexpand \n        Ex1:trigexpand(sin(3*x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3033trigexpand = {"trigexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3033trigexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3032trigexpand};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3033trigexpand(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trigexpand (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trigexpand", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3032trigexpand(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3032trigexpand(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trigexpand", 1);

  /* "giacpy/auto-methods.pxi":18950
 * 
 *         '''
 *         return GiacMethods['trigexpand'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def triginterp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trigexpand); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18950, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18941
 *         return GiacMethods['trigcos'](self,*args)
 * 
 *      def trigexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigexpand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trigexpand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18952
 *         return GiacMethods['trigexpand'](self,*args)
 * 
 *      def triginterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triginterp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3035triginterp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3034triginterp, "From Giac's documentation:\n        Help for triginterp:\n        triginterp(List,Var=xmin..xmax)\n        Returns a trigonometric polynomial interpolation (with respect to variable x) of the points with ordinate given in list y and the abscissa equally spaced between a and b.\n        See also: 1/ lagrange 2/ thiele \n        Ex1:triginterp([11,10,17,24,32,26,23,19],x=0..21)\n        Ex2:triginterp([11,10,17,24,32,26,23,19],0,21,x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3035triginterp = {"triginterp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3035triginterp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3034triginterp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3035triginterp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("triginterp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "triginterp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3034triginterp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3034triginterp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("triginterp", 1);

  /* "giacpy/auto-methods.pxi":18962
 * 
 *         '''
 *         return GiacMethods['triginterp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trigsimplify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_triginterp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18962, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18952
 *         return GiacMethods['trigexpand'](self,*args)
 * 
 *      def triginterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triginterp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.triginterp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18964
 *         return GiacMethods['triginterp'](self,*args)
 * 
 *      def trigsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsimplify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3037trigsimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3036trigsimplify, "From Giac's documentation:\n        Help for trigsimplify:\n        trigsimplify(Expr)\n        Simplifies a trigonometric expression.\n        See also: 1/ simplify \n        Ex1:trigsimplify(3*sin(x)-4*sin(x)^3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3037trigsimplify = {"trigsimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3037trigsimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3036trigsimplify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3037trigsimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trigsimplify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trigsimplify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3036trigsimplify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3036trigsimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trigsimplify", 1);

  /* "giacpy/auto-methods.pxi":18973
 * 
 *         '''
 *         return GiacMethods['trigsimplify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trigsin(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trigsimplify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18973, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18964
 *         return GiacMethods['triginterp'](self,*args)
 * 
 *      def trigsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsimplify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trigsimplify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18975
 *         return GiacMethods['trigsimplify'](self,*args)
 * 
 *      def trigsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsin:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3039trigsin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3038trigsin, "From Giac's documentation:\n        Help for trigsin:\n        trigsin(Expr)\n        Simplifies the argument with the formulas sin(x)^2+cos(x)^2=1 and tan(x)=sin(x)/cos(x) privileging sine.\n        See also: 1/ trigcos 2/ trigtan \n        Ex1:trigsin(cos(x)^4+sin(x)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3039trigsin = {"trigsin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3039trigsin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3038trigsin};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3039trigsin(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trigsin (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trigsin", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3038trigsin(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3038trigsin(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trigsin", 1);

  /* "giacpy/auto-methods.pxi":18984
 * 
 *         '''
 *         return GiacMethods['trigsin'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trigtan(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trigsin); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18984, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18975
 *         return GiacMethods['trigsimplify'](self,*args)
 * 
 *      def trigsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsin:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trigsin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18986
 *         return GiacMethods['trigsin'](self,*args)
 * 
 *      def trigtan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigtan:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3041trigtan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3040trigtan, "From Giac's documentation:\n        Help for trigtan:\n        trigtan(Expr)\n        Simplifies the argument with the formulas sin(x)^2+cos(x)^2=1 and tan(x)=sin(x)/cos(x) privileging tangent.\n        See also: 1/ trigsin 2/ trigcos \n        Ex1:trigtan(cos(x)^4+sin(x)^2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3041trigtan = {"trigtan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3041trigtan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3040trigtan};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3041trigtan(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trigtan (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trigtan", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3040trigtan(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3040trigtan(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trigtan", 1);

  /* "giacpy/auto-methods.pxi":18995
 * 
 *         '''
 *         return GiacMethods['trigtan'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trim(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trigtan); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 18995, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 18995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 18995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18986
 *         return GiacMethods['trigsin'](self,*args)
 * 
 *      def trigtan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigtan:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trigtan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":18997
 *         return GiacMethods['trigtan'](self,*args)
 * 
 *      def trim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trim:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3043trim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3042trim, "From Giac's documentation:\n        Help for trim:\n        trim((Str||Vect||Audio||Image)(s),[opts],[left|right],[index])\n        Removes leading/trailing whitespace from strings, zeros from vectors, zero-pixel margins from images, and silence from audio clips, or returns positions specifying that portions.\n        See also: 1/ strip \n        Ex1:trim(\"   an apple     \")\n        Ex2:trim([0,0,1,2,3,0,1e-16,0],right)\n        Ex3:trim([0.01,0.023,0.005,0.12,0.27,0.82,0.53,0.21,0.05,0.001],0.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3043trim = {"trim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3043trim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3042trim};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3043trim(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trim (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trim", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3042trim(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3042trim(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trim", 1);

  /* "giacpy/auto-methods.pxi":19008
 * 
 *         '''
 *         return GiacMethods['trim'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trn(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trim); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19008, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":18997
 *         return GiacMethods['trigtan'](self,*args)
 * 
 *      def trim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trim:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19010
 *         return GiacMethods['trim'](self,*args)
 * 
 *      def trn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trn:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3045trn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3044trn, "From Giac's documentation:\n        Help for trn:\n        trn(Mtrx)\n        Returns the adjoint matrix of A =tran(conj(A)).\n        See also: 1/ tran 2/ conj \n        Ex1:trn([[1,2+i],[3,4]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3045trn = {"trn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3045trn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3044trn};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3045trn(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trn (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trn", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3044trn(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3044trn(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trn", 1);

  /* "giacpy/auto-methods.pxi":19019
 * 
 *         '''
 *         return GiacMethods['trn'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def true(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trn); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19019, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19010
 *         return GiacMethods['trim'](self,*args)
 * 
 *      def trn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trn:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19021
 *         return GiacMethods['trn'](self,*args)
 * 
 *      def true(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for true:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3047true(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3046true, "From Giac's documentation:\n        Help for true:\n        true()\n        Boolean equal to true or 1.\n        See also: 1/ false \n        Ex1: a:=true\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3047true = {"true", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3047true, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3046true};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3047true(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("true (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "true", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3046true(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3046true(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("true", 1);

  /* "giacpy/auto-methods.pxi":19030
 * 
 *         '''
 *         return GiacMethods['true'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def trunc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_true); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19030, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19021
 *         return GiacMethods['trn'](self,*args)
 * 
 *      def true(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for true:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.true", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19032
 *         return GiacMethods['true'](self,*args)
 * 
 *      def trunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trunc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3049trunc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3048trunc, "From Giac's documentation:\n        Help for trunc:\n        trunc(Real||LstReal,Int(n))\n        Truncates value to n decimal places (by default n=0). Accepts complex numbers.(type=DOM_COMPLEX or DOM_FLOAT).\n        See also: 1/ fPart 2/ floor 3/ iPart \n        Ex1:trunc(4.3)\n        Ex2:trunc(sqrt(2),3)\n        Ex3:trunc([4.3333,sqrt(2)])\n        Ex4:trunc([4.3333,sqrt(2)],2)\n        Ex5:trunc(sqrt(2)+i*sqrt(5),4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3049trunc = {"trunc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3049trunc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3048trunc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3049trunc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("trunc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "trunc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3048trunc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3048trunc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("trunc", 1);

  /* "giacpy/auto-methods.pxi":19045
 * 
 *         '''
 *         return GiacMethods['trunc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def truncate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_trunc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19045, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19032
 *         return GiacMethods['true'](self,*args)
 * 
 *      def trunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trunc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.trunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19047
 *         return GiacMethods['trunc'](self,*args)
 * 
 *      def truncate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3051truncate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3050truncate, "From Giac's documentation:\n        Help for truncate:\n        truncate(Poly(P),Intg(n))\n        Truncates the polynomial P at order n.\n        See also: 1/ series \n        Ex1:truncate((x^2+x)^2,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3051truncate = {"truncate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3051truncate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3050truncate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3051truncate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("truncate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "truncate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3050truncate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3050truncate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("truncate", 1);

  /* "giacpy/auto-methods.pxi":19056
 * 
 *         '''
 *         return GiacMethods['truncate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def truncate_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_truncate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19056, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19047
 *         return GiacMethods['trunc'](self,*args)
 * 
 *      def truncate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.truncate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19058
 *         return GiacMethods['truncate'](self,*args)
 * 
 *      def truncate_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3053truncate_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3052truncate_graph, "From Giac's documentation:\n        Help for truncate_graph:\n        truncate_graph(Graph(G))\n        Returns the graph obtained by truncating the biconnected planar graph G.\n        See also: 1/ is_biconnected 2/ is_planar 3/ plane_dual \n        Ex1:truncate_graph(graph(\"tetrahedron\"))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3053truncate_graph = {"truncate_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3053truncate_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3052truncate_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3053truncate_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("truncate_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "truncate_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3052truncate_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3052truncate_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("truncate_graph", 1);

  /* "giacpy/auto-methods.pxi":19067
 * 
 *         '''
 *         return GiacMethods['truncate_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tsimplify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_truncate_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19067, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19058
 *         return GiacMethods['truncate'](self,*args)
 * 
 *      def truncate_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.truncate_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19069
 *         return GiacMethods['truncate_graph'](self,*args)
 * 
 *      def tsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tsimplify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3055tsimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3054tsimplify, "From Giac's documentation:\n        Help for tsimplify:\n        tsimplify(Expr)\n        Lowers the number of non rational variables.\n        See also: 1/ simplify \n        Ex1:tsimplify(exp(2*x)+exp(x))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3055tsimplify = {"tsimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3055tsimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3054tsimplify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3055tsimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tsimplify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tsimplify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3054tsimplify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3054tsimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tsimplify", 1);

  /* "giacpy/auto-methods.pxi":19078
 * 
 *         '''
 *         return GiacMethods['tsimplify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tstep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tsimplify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19078, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19069
 *         return GiacMethods['truncate_graph'](self,*args)
 * 
 *      def tsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tsimplify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tsimplify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19080
 *         return GiacMethods['tsimplify'](self,*args)
 * 
 *      def tstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tstep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3057tstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3056tstep, "From Giac's documentation:\n        Help for tstep:\n        tstep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3057tstep = {"tstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3057tstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3056tstep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3057tstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tstep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tstep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3056tstep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3056tstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tstep", 1);

  /* "giacpy/auto-methods.pxi":19087
 * 
 *         '''
 *         return GiacMethods['tstep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tuer(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tstep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19087, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19080
 *         return GiacMethods['tsimplify'](self,*args)
 * 
 *      def tstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tstep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tstep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19089
 *         return GiacMethods['tstep'](self,*args)
 * 
 *      def tuer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tuer:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3059tuer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3058tuer, "From Giac's documentation:\n        Help for tuer:\n        tuer(NULL)\n        Stop step-by-step execution of a program (with debug).\n        See also: 1/  \n        Ex1:tuer()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3059tuer = {"tuer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3059tuer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3058tuer};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3059tuer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tuer (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tuer", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3058tuer(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3058tuer(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tuer", 1);

  /* "giacpy/auto-methods.pxi":19098
 * 
 *         '''
 *         return GiacMethods['tuer'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tukey_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tuer); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19098, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19089
 *         return GiacMethods['tstep'](self,*args)
 * 
 *      def tuer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tuer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tuer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19100
 *         return GiacMethods['tuer'](self,*args)
 * 
 *      def tukey_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tukey_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3061tukey_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3060tukey_window, "From Giac's documentation:\n        Help for tukey_window:\n        tukey_window(Lst,[Real(a)],[Interval(n1..n2)])\n        Applies the Tukey windowing function with parameter a in [0,1] (by default a=0.5) to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ bartlett_hann_window 14/ welch_window \n        Ex1: scatterplot(tukey_window(randvector(1000,0..1),0.4))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3061tukey_window = {"tukey_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3061tukey_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3060tukey_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3061tukey_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tukey_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tukey_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3060tukey_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3060tukey_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tukey_window", 1);

  /* "giacpy/auto-methods.pxi":19109
 * 
 *         '''
 *         return GiacMethods['tukey_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def tutte_polynomial(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tukey_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19109, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19100
 *         return GiacMethods['tuer'](self,*args)
 * 
 *      def tukey_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tukey_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tukey_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19111
 *         return GiacMethods['tukey_window'](self,*args)
 * 
 *      def tutte_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tutte_polynomial:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3063tutte_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3062tutte_polynomial, "From Giac's documentation:\n        Help for tutte_polynomial:\n        tutte_polynomial(Graph(G),[Var(x),Var(y)])\n        Returns the Tutte polynomial [or its value at point (x,y)] of an undirected graph G. If G is weighted, then all weights must be positive integers which are interpreted as edge multiplicities.\n        See also: 1/ chromatic_polynomial 2/ flow_polynomial 3/ reliability_polynomial 4/ delete_edge 5/ contract_edge \n        Ex1:tutte_polynomial(graph(\"tetrahedron\"))\n        Ex2:tutte_polynomial(graph(\"tetrahedron\"),1,1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3063tutte_polynomial = {"tutte_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3063tutte_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3062tutte_polynomial};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3063tutte_polynomial(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tutte_polynomial (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tutte_polynomial", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3062tutte_polynomial(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3062tutte_polynomial(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tutte_polynomial", 1);

  /* "giacpy/auto-methods.pxi":19121
 * 
 *         '''
 *         return GiacMethods['tutte_polynomial'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def two_edge_connected_components(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_tutte_polynomial); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19121, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19111
 *         return GiacMethods['tukey_window'](self,*args)
 * 
 *      def tutte_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tutte_polynomial:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.tutte_polynomial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19123
 *         return GiacMethods['tutte_polynomial'](self,*args)
 * 
 *      def two_edge_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for two_edge_connected_components:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3065two_edge_connected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3064two_edge_connected_components, "From Giac's documentation:\n        Help for two_edge_connected_components:\n        two_edge_connected_components(Graph(G))\n        Returns the list of two-edge-connected components of an undirected graph G, each of them represented by the list of its vertices.\n        See also: 1/ is_two_edge_connected 2/ connected_components \n        Ex1:two_edge_connected_components(graph(trail(1,2,3,4,5,3,1),trail(5,6,7,8,6)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3065two_edge_connected_components = {"two_edge_connected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3065two_edge_connected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3064two_edge_connected_components};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3065two_edge_connected_components(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("two_edge_connected_components (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "two_edge_connected_components", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3064two_edge_connected_components(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3064two_edge_connected_components(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("two_edge_connected_components", 1);

  /* "giacpy/auto-methods.pxi":19132
 * 
 *         '''
 *         return GiacMethods['two_edge_connected_components'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ufactor(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_two_edge_connected_components); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19132, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19123
 *         return GiacMethods['tutte_polynomial'](self,*args)
 * 
 *      def two_edge_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for two_edge_connected_components:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.two_edge_connected_components", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19134
 *         return GiacMethods['two_edge_connected_components'](self,*args)
 * 
 *      def ufactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ufactor:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3067ufactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3066ufactor, "From Giac's documentation:\n        Help for ufactor:\n        ufactor(Unit,Unit)\n        Factors a unit in a unit object.\n        See also: 1/ convert 2/ mksa 3/ usimplify \n        Ex1:ufactor(100_C,1_A)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3067ufactor = {"ufactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3067ufactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3066ufactor};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3067ufactor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ufactor (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ufactor", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3066ufactor(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3066ufactor(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ufactor", 1);

  /* "giacpy/auto-methods.pxi":19143
 * 
 *         '''
 *         return GiacMethods['ufactor'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ugamma(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ufactor); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19143, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19134
 *         return GiacMethods['two_edge_connected_components'](self,*args)
 * 
 *      def ufactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ufactor:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ufactor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19145
 *         return GiacMethods['ufactor'](self,*args)
 * 
 *      def ugamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ugamma:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3069ugamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3068ugamma, "From Giac's documentation:\n        Help for ugamma:\n        ugamma(Real(a),Real(x),[1])\n        Calculates ugamma function at a point (a,x):if a and x>=0 ugamma(a,x)=int(e^{-t}*t^{a-1},t=x..inf),(ugamma(a,x)+igamma(a,x)=Gamma(a)).\n        See also: 1/ Psi 2/ Beta 3/ Gamma 4/ igamma \n        Ex1:ugamma(5.0,2.0)\n        Ex2:ugamma(-5.1,2.1)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3069ugamma = {"ugamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3069ugamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3068ugamma};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3069ugamma(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ugamma (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ugamma", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3068ugamma(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3068ugamma(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ugamma", 1);

  /* "giacpy/auto-methods.pxi":19155
 * 
 *         '''
 *         return GiacMethods['ugamma'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def unapply(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ugamma); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19155, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19145
 *         return GiacMethods['ufactor'](self,*args)
 * 
 *      def ugamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ugamma:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ugamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19157
 *         return GiacMethods['ugamma'](self,*args)
 * 
 *      def unapply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unapply:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3071unapply(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3070unapply, "From Giac's documentation:\n        Help for unapply:\n        unapply(Expr,Var)\n        Returns a function defined by an expression.\n        See also: 1/ apply \n        Ex1:unapply(2*x^2,x)\n        Ex2: f(x):=x*exp(x);g:=unapply(diff(f(x),x),x)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3071unapply = {"unapply", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3071unapply, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3070unapply};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3071unapply(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unapply (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "unapply", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3070unapply(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3070unapply(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unapply", 1);

  /* "giacpy/auto-methods.pxi":19167
 * 
 *         '''
 *         return GiacMethods['unapply'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def unarchive(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_unapply); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19167, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19157
 *         return GiacMethods['ugamma'](self,*args)
 * 
 *      def unapply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unapply:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.unapply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19169
 *         return GiacMethods['unapply'](self,*args)
 * 
 *      def unarchive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unarchive:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3073unarchive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3072unarchive, "From Giac's documentation:\n        Help for unarchive:\n        unarchive(Str(namefich),Seq(Var))\n        Reads the value of a variable or of a list of variables which are in the file given as argument (file created with archive).\n        See also: 1/ archive 2/ Archive 3/ Unarchiv \n        Ex1:unarchive(\"toto\")\n        Ex2:unarchive(\"aa.txt\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3073unarchive = {"unarchive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3073unarchive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3072unarchive};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3073unarchive(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unarchive (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "unarchive", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3072unarchive(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3072unarchive(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unarchive", 1);

  /* "giacpy/auto-methods.pxi":19179
 * 
 *         '''
 *         return GiacMethods['unarchive'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def undef(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_unarchive); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19179, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19169
 *         return GiacMethods['unapply'](self,*args)
 * 
 *      def unarchive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unarchive:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.unarchive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19181
 *         return GiacMethods['unarchive'](self,*args)
 * 
 *      def undef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for undef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3075undef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3074undef, "From Giac's documentation:\n        Help for undef:\n        undef(Expr)\n        Udefined value (NaN).\n        See also: 1/ isnan 2/ infinity \n        Ex1:undef(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3075undef = {"undef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3075undef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3074undef};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3075undef(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("undef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "undef", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3074undef(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3074undef(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("undef", 1);

  /* "giacpy/auto-methods.pxi":19190
 * 
 *         '''
 *         return GiacMethods['undef'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def underlying_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_undef); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19190, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19181
 *         return GiacMethods['unarchive'](self,*args)
 * 
 *      def undef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for undef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.undef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19192
 *         return GiacMethods['undef'](self,*args)
 * 
 *      def underlying_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for underlying_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3077underlying_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3076underlying_graph, "From Giac's documentation:\n        Help for underlying_graph:\n        underlying_graph(Graph(G))\n        Returns the graph obtained by stripping directions and weights from arcs in G (pairs of arcs connecting the same vertices are merged to a single edge).\n        See also: 1/ is_directed 2/ is_weighted 3/ make_directed 4/ make_weighted \n        Ex1:underlying_graph(digraph(trail(1,2,3,4,1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3077underlying_graph = {"underlying_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3077underlying_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3076underlying_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3077underlying_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("underlying_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "underlying_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3076underlying_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3076underlying_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("underlying_graph", 1);

  /* "giacpy/auto-methods.pxi":19201
 * 
 *         '''
 *         return GiacMethods['underlying_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def unfactored(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_underlying_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19201, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19192
 *         return GiacMethods['undef'](self,*args)
 * 
 *      def underlying_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for underlying_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.underlying_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19203
 *         return GiacMethods['underlying_graph'](self,*args)
 * 
 *      def unfactored(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unfactored:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3079unfactored(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3078unfactored, "From Giac's documentation:\n        Help for unfactored:\n        unfactored(Opt.)\n        Option of the plotimplicit command.\n        See also: 1/ plotimplicit \n        Ex1: plotimplicit(x^2+y^2-1,x,y,unfactored)\n        Ex2: plotimplicit(x^2+y^2-1,[x,y],unfactored)\n        Ex3: plotimplicit(x^2+y^2+z^2-1,x,y,z,xstep=0.2,ystep=0.2,zstep=0.2,unfactored)\n        Ex4: plotimplicit(x^2+y^2+z^2-1,[x,y,z],xstep=0.2,ystep=0.2,zstep=0.2,unfactored)\n        Ex5: plotimplicit(x^2+y^2+z^2-1,x=0..1,y=0..1,z=0..1,xstep=0.2,ystep=0.2,zstep=0.2,unfactored)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3079unfactored = {"unfactored", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3079unfactored, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3078unfactored};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3079unfactored(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unfactored (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "unfactored", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3078unfactored(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3078unfactored(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unfactored", 1);

  /* "giacpy/auto-methods.pxi":19216
 * 
 *         '''
 *         return GiacMethods['unfactored'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def uniform(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_unfactored); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19216, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19203
 *         return GiacMethods['underlying_graph'](self,*args)
 * 
 *      def unfactored(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unfactored:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.unfactored", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19218
 *         return GiacMethods['unfactored'](self,*args)
 * 
 *      def uniform(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3081uniform(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3080uniform, "From Giac's documentation:\n        Help for uniform:\n        uniform(Real(a),Real(b),Real(x))\n        Returns the probability density at x of the uniform law on [a,b].\n        See also: 1/ uniform_cdf 2/ uniform_icdf 3/ randvector 4/ ranm \n        Ex1:uniform(2,5,4)\n        Ex2:uniform(1.2,3.5,3)\n        Ex3: randvector(3,uniform,1.2,3.5)\n        Ex4: ranm(4,3,uniform,1.2,3.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3081uniform = {"uniform", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3081uniform, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3080uniform};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3081uniform(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uniform (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "uniform", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3080uniform(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3080uniform(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("uniform", 1);

  /* "giacpy/auto-methods.pxi":19230
 * 
 *         '''
 *         return GiacMethods['uniform'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def uniform_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_uniform); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19230, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19218
 *         return GiacMethods['unfactored'](self,*args)
 * 
 *      def uniform(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.uniform", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19232
 *         return GiacMethods['uniform'](self,*args)
 * 
 *      def uniform_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3083uniform_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3082uniform_cdf, "From Giac's documentation:\n        Help for uniform_cdf:\n        uniform_cdf(Real(a),Real(b),Real(x0),[Real(y0)])\n        Returns the probability that a uniform random variable on [a,b] is less than x0 (or between x0 and y0).\n        See also: 1/ uniformd 2/ uniform_icdf \n        Ex1:uniform_cdf(3.2,5.7,4.4)\n        Ex2:uniform_cdf(3.2,5.7,4.4,5.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3083uniform_cdf = {"uniform_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3083uniform_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3082uniform_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3083uniform_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uniform_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "uniform_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3082uniform_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3082uniform_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("uniform_cdf", 1);

  /* "giacpy/auto-methods.pxi":19242
 * 
 *         '''
 *         return GiacMethods['uniform_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def uniform_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_uniform_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19242, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19232
 *         return GiacMethods['uniform'](self,*args)
 * 
 *      def uniform_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.uniform_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19244
 *         return GiacMethods['uniform_cdf'](self,*args)
 * 
 *      def uniform_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3085uniform_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3084uniform_icdf, "From Giac's documentation:\n        Help for uniform_icdf:\n        uniform_icdf(Real(a),Real(b),Real(p))\n        Returns h such that the probability that a uniform random variable on [a,b] is less than h is p (0<=p<=1).\n        See also: 1/ uniform_cdf 2/ uniformd \n        Ex1:uniform_icdf(4.2,10.3,0.95)\n        Ex2:uniform_icdf(3.2,5.7,0.48)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3085uniform_icdf = {"uniform_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3085uniform_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3084uniform_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3085uniform_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uniform_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "uniform_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3084uniform_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3084uniform_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("uniform_icdf", 1);

  /* "giacpy/auto-methods.pxi":19254
 * 
 *         '''
 *         return GiacMethods['uniform_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def uniformd(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_uniform_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19254, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19244
 *         return GiacMethods['uniform_cdf'](self,*args)
 * 
 *      def uniform_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.uniform_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19256
 *         return GiacMethods['uniform_icdf'](self,*args)
 * 
 *      def uniformd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3087uniformd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3086uniformd, "From Giac's documentation:\n        Help for uniformd:\n        uniformd(Real(a),Real(b),Real(x))\n        Returns the probability density at x of the uniform law on [a,b].\n        See also: 1/ uniform_cdf 2/ uniform_icdf 3/ randvector 4/ ranm \n        Ex1:uniformd(2,5,4)\n        Ex2:uniformd(1.2,3.5,3)\n        Ex3: randvector(3,uniform,1.2,3.5)\n        Ex4: ranm(4,3,uniform,1.2,3.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3087uniformd = {"uniformd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3087uniformd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3086uniformd};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3087uniformd(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uniformd (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "uniformd", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3086uniformd(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3086uniformd(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("uniformd", 1);

  /* "giacpy/auto-methods.pxi":19268
 * 
 *         '''
 *         return GiacMethods['uniformd'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def uniformd_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_uniformd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19268, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19256
 *         return GiacMethods['uniform_icdf'](self,*args)
 * 
 *      def uniformd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.uniformd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19270
 *         return GiacMethods['uniformd'](self,*args)
 * 
 *      def uniformd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3089uniformd_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3088uniformd_cdf, "From Giac's documentation:\n        Help for uniformd_cdf:\n        uniformd_cdf(Real(a),Real(b),Real(x0),[Real(y0)])\n        Returns the probability that a uniform random variable on [a,b] is less than x0 (or between x0 and y0).\n        See also: 1/ uniformd 2/ uniform_icdf \n        Ex1:uniformd_cdf(3.2,5.7,4.4)\n        Ex2:uniformd_cdf(3.2,5.7,4.4,5.4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3089uniformd_cdf = {"uniformd_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3089uniformd_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3088uniformd_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3089uniformd_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uniformd_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "uniformd_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3088uniformd_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3088uniformd_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("uniformd_cdf", 1);

  /* "giacpy/auto-methods.pxi":19280
 * 
 *         '''
 *         return GiacMethods['uniformd_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def uniformd_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_uniformd_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19280, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19270
 *         return GiacMethods['uniformd'](self,*args)
 * 
 *      def uniformd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.uniformd_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19282
 *         return GiacMethods['uniformd_cdf'](self,*args)
 * 
 *      def uniformd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3091uniformd_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3090uniformd_icdf, "From Giac's documentation:\n        Help for uniformd_icdf:\n        uniformd_icdf(Real(a),Real(b),Real(p))\n        Returns h such that the probability that a uniform random variable on [a,b] is less than h is p (0<=p<=1).\n        See also: 1/ uniform_cdf 2/ uniformd \n        Ex1:uniformd_icdf(4.2,10.3,0.95)\n        Ex2:uniformd_icdf(3.2,5.7,0.48)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3091uniformd_icdf = {"uniformd_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3091uniformd_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3090uniformd_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3091uniformd_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("uniformd_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "uniformd_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3090uniformd_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3090uniformd_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("uniformd_icdf", 1);

  /* "giacpy/auto-methods.pxi":19292
 * 
 *         '''
 *         return GiacMethods['uniformd_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def unitV(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_uniformd_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19292, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19282
 *         return GiacMethods['uniformd_cdf'](self,*args)
 * 
 *      def uniformd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.uniformd_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19294
 *         return GiacMethods['uniformd_icdf'](self,*args)
 * 
 *      def unitV(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unitV:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3093unitV(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3092unitV, "From Giac's documentation:\n        Help for unitV:\n        unitV(Lst||Cplx||Audio)\n        Returns the vector divided by its l2norm or normalizes an audio clip. It is also an option for plotfield.\n        See also: 1/ l2norm \n        Ex1:unitV(3+4*i)\n        Ex2:unitV([3,4])\n        Ex3: fieldplot(-t*y,[t,y],normalize)\n        Ex4: fieldplot(-t*y,[t,y],normalize,xstep=0.5,ystep=0.5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3093unitV = {"unitV", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3093unitV, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3092unitV};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3093unitV(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unitV (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "unitV", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3092unitV(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3092unitV(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unitV", 1);

  /* "giacpy/auto-methods.pxi":19306
 * 
 *         '''
 *         return GiacMethods['unitV'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def unquote(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_unitV); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19306, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19294
 *         return GiacMethods['uniformd_icdf'](self,*args)
 * 
 *      def unitV(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unitV:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.unitV", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19308
 *         return GiacMethods['unitV'](self,*args)
 * 
 *      def unquote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unquote:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3095unquote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3094unquote, "From Giac's documentation:\n        Help for unquote:\n        unquote(Expr)\n        Evaluates a quoted expression (for example purge(c);a:=c;unquote(a):=3; put 3 in the variables a and c).\n        See also: 1/ quote \n        Ex1:unquote(a)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3095unquote = {"unquote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3095unquote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3094unquote};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3095unquote(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unquote (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "unquote", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3094unquote(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3094unquote(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unquote", 1);

  /* "giacpy/auto-methods.pxi":19317
 * 
 *         '''
 *         return GiacMethods['unquote'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def upper(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_unquote); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19317, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19308
 *         return GiacMethods['unitV'](self,*args)
 * 
 *      def unquote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unquote:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.unquote", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19319
 *         return GiacMethods['unquote'](self,*args)
 * 
 *      def upper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for upper:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3097upper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3096upper, "From Giac's documentation:\n        Help for upper:\n        upper(Mtrx||Strng)\n        Returns the upper triangular matrix (over the diagonal, included) or writes a string in uppercase.\n        See also: 1/ diag 2/ lower \n        Ex1:upper([[1,2,3],[4,5,6],[7,8,9]])\n        Ex2:upper(\"hello\")\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3097upper = {"upper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3097upper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3096upper};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3097upper(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("upper (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "upper", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3096upper(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3096upper(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("upper", 1);

  /* "giacpy/auto-methods.pxi":19329
 * 
 *         '''
 *         return GiacMethods['upper'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def user_operator(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_upper); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19329, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19319
 *         return GiacMethods['unquote'](self,*args)
 * 
 *      def upper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for upper:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.upper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19331
 *         return GiacMethods['upper'](self,*args)
 * 
 *      def user_operator(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for user_operator:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3099user_operator(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3098user_operator, "From Giac's documentation:\n        Help for user_operator:\n        user_operator(Str(R),Fnc(f),Opt(Binary||Unary||Delete))\n        Defines a binary operator and returns 0 (failure) or 1(success).\n        See also: 1/  \n        Ex1:user_operator(\"R\",(x,y)->x*y+x+y,Binary)\n        Ex2:user_operator(\"R\",(x,y)->x*y+x+y,Delete)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3099user_operator = {"user_operator", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3099user_operator, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3098user_operator};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3099user_operator(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("user_operator (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "user_operator", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3098user_operator(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3098user_operator(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("user_operator", 1);

  /* "giacpy/auto-methods.pxi":19341
 * 
 *         '''
 *         return GiacMethods['user_operator'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def usimplify(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_user_operator); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19341, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19331
 *         return GiacMethods['upper'](self,*args)
 * 
 *      def user_operator(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for user_operator:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.user_operator", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19343
 *         return GiacMethods['user_operator'](self,*args)
 * 
 *      def usimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for usimplify:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3101usimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3100usimplify, "From Giac's documentation:\n        Help for usimplify:\n        usimplify(Unit)\n        Simplifies a unit in a unit object.\n        See also: 1/ convert 2/ mksa 3/ ufactor \n        Ex1:usimplify(100_(W*s))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3101usimplify = {"usimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3101usimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3100usimplify};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3101usimplify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("usimplify (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "usimplify", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3100usimplify(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3100usimplify(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("usimplify", 1);

  /* "giacpy/auto-methods.pxi":19352
 * 
 *         '''
 *         return GiacMethods['usimplify'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ustep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_usimplify); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19352, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19343
 *         return GiacMethods['user_operator'](self,*args)
 * 
 *      def usimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for usimplify:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.usimplify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19354
 *         return GiacMethods['usimplify'](self,*args)
 * 
 *      def ustep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ustep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3103ustep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3102ustep, "From Giac's documentation:\n        Help for ustep:\n        ustep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3103ustep = {"ustep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3103ustep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3102ustep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3103ustep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ustep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ustep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3102ustep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3102ustep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ustep", 1);

  /* "giacpy/auto-methods.pxi":19361
 * 
 *         '''
 *         return GiacMethods['ustep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def valuation(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ustep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19361, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19354
 *         return GiacMethods['usimplify'](self,*args)
 * 
 *      def ustep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ustep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ustep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19363
 *         return GiacMethods['ustep'](self,*args)
 * 
 *      def valuation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for valuation:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3105valuation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3104valuation, "From Giac's documentation:\n        Help for valuation:\n        valuation(Poly(P))\n        Returns the valuation (degree of the term of lowest degree) of the polynomial P.\n        See also: 1/ degree 2/ tcoeff \n        Ex1:valuation(x^4+x^3)\n        Ex2:valuation([1,1,0,0,0])\n        Ex3:valuation(130,5)\n        Ex4:valuation(x^5+3*x^2)\n        Ex5:valuation([5,0,0,3,0,0])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3105valuation = {"valuation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3105valuation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3104valuation};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3105valuation(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("valuation (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "valuation", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3104valuation(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3104valuation(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("valuation", 1);

  /* "giacpy/auto-methods.pxi":19376
 * 
 *         '''
 *         return GiacMethods['valuation'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vandermonde(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_valuation); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19376, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19363
 *         return GiacMethods['ustep'](self,*args)
 * 
 *      def valuation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for valuation:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.valuation", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19378
 *         return GiacMethods['valuation'](self,*args)
 * 
 *      def vandermonde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vandermonde:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3107vandermonde(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3106vandermonde, "From Giac's documentation:\n        Help for vandermonde:\n        vandermonde(Vect(V))\n        Returns the Vandermonde matrix=[V^0,V^1,..].\n        See also: 1/ det \n        Ex1:vandermonde([1,2,a])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3107vandermonde = {"vandermonde", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3107vandermonde, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3106vandermonde};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3107vandermonde(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vandermonde (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vandermonde", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3106vandermonde(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3106vandermonde(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vandermonde", 1);

  /* "giacpy/auto-methods.pxi":19387
 * 
 *         '''
 *         return GiacMethods['vandermonde'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def variables_are_files(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vandermonde); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19387, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19378
 *         return GiacMethods['valuation'](self,*args)
 * 
 *      def vandermonde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vandermonde:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vandermonde", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19389
 *         return GiacMethods['vandermonde'](self,*args)
 * 
 *      def variables_are_files(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variables_are_files:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3109variables_are_files(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3108variables_are_files, "From Giac's documentation:\n        Help for variables_are_files:\n        variables_are_files(:=Intg(0 or 1))\n        Pseudo-variable to specify if you want to save the variables as file \"nameofthevariable.cas\".\n        See also: 1/ cas_setup \n        Ex1: variables_are_files:=1\n        Ex2: variables_are_files:=0\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3109variables_are_files = {"variables_are_files", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3109variables_are_files, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3108variables_are_files};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3109variables_are_files(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("variables_are_files (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "variables_are_files", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3108variables_are_files(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3108variables_are_files(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("variables_are_files", 1);

  /* "giacpy/auto-methods.pxi":19399
 * 
 *         '''
 *         return GiacMethods['variables_are_files'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def variance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_variables_are_files); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19399, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19389
 *         return GiacMethods['vandermonde'](self,*args)
 * 
 *      def variables_are_files(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variables_are_files:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.variables_are_files", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19401
 *         return GiacMethods['variables_are_files'](self,*args)
 * 
 *      def variance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3111variance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3110variance, "From Giac's documentation:\n        Help for variance:\n        variance(Lst||Mtrx,[Lst])\n        Returns the variance of a list with the second argument as weights or the list of variances of the columns of a matrix.\n        See also: 1/ stddev 2/ mean \n        Ex1:variance([3,4,2])\n        Ex2:variance([1,2,3],[1,2,1])\n        Ex3:variance([[1,2,3],[5,6,7]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3111variance = {"variance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3111variance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3110variance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3111variance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("variance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "variance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3110variance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3110variance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("variance", 1);

  /* "giacpy/auto-methods.pxi":19412
 * 
 *         '''
 *         return GiacMethods['variance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def version(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_variance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19412, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19401
 *         return GiacMethods['variables_are_files'](self,*args)
 * 
 *      def variance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.variance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19414
 *         return GiacMethods['variance'](self,*args)
 * 
 *      def version(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for version:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3113version(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3112version, "From Giac's documentation:\n        Help for version:\n        version(NULL)\n        Returns the giac version number; for example, you are using : giac 0.4.0\n        See also: 1/  \n        Ex1:version()\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3113version = {"version", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3113version, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3112version};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3113version(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("version (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "version", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3112version(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3112version(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("version", 1);

  /* "giacpy/auto-methods.pxi":19423
 * 
 *         '''
 *         return GiacMethods['version'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertex_connectivity(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_version); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19423, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19414
 *         return GiacMethods['variance'](self,*args)
 * 
 *      def version(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for version:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19425
 *         return GiacMethods['version'](self,*args)
 * 
 *      def vertex_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_connectivity:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3115vertex_connectivity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3114vertex_connectivity, "From Giac's documentation:\n        Help for vertex_connectivity:\n        vertex_connectivity(Graph(G))\n        Returns the largest integer k such that an undirected connected graph G remains connected when fewer than k vertices are removed.\n        See also: 1/ edge_connectivity 2/ is_connected \n        Ex1:vertex_connectivity(graph(\"petersen\"))\n        Ex2:vertex_connectivity(graph(\"clebsch\"))\n        Ex3:vertex_connectivity(complete_graph(5))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3115vertex_connectivity = {"vertex_connectivity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3115vertex_connectivity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3114vertex_connectivity};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3115vertex_connectivity(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertex_connectivity (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertex_connectivity", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3114vertex_connectivity(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3114vertex_connectivity(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertex_connectivity", 1);

  /* "giacpy/auto-methods.pxi":19436
 * 
 *         '''
 *         return GiacMethods['vertex_connectivity'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertex_cover_number(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertex_connectivity); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19436, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19425
 *         return GiacMethods['version'](self,*args)
 * 
 *      def vertex_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_connectivity:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertex_connectivity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19438
 *         return GiacMethods['vertex_connectivity'](self,*args)
 * 
 *      def vertex_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_cover_number:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3117vertex_cover_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3116vertex_cover_number, "From Giac's documentation:\n        Help for vertex_cover_number:\n        vertex_cover_number(Graph(G))\n        Returns the size of a minimum vertex cover in an undirected graph G.\n        See also: 1/ minimum_vertex_cover \n        Ex1:vertex_cover_number(graph_complement(complete_graph(3,4)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3117vertex_cover_number = {"vertex_cover_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3117vertex_cover_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3116vertex_cover_number};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3117vertex_cover_number(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertex_cover_number (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertex_cover_number", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3116vertex_cover_number(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3116vertex_cover_number(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertex_cover_number", 1);

  /* "giacpy/auto-methods.pxi":19447
 * 
 *         '''
 *         return GiacMethods['vertex_cover_number'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertex_degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertex_cover_number); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19447, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19438
 *         return GiacMethods['vertex_connectivity'](self,*args)
 * 
 *      def vertex_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_cover_number:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertex_cover_number", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19449
 *         return GiacMethods['vertex_cover_number'](self,*args)
 * 
 *      def vertex_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3119vertex_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3118vertex_degree, "From Giac's documentation:\n        Help for vertex_degree:\n        vertex_degree(Graph(G),Vrtx(v))\n        Returns the degree of the vertex v in G (i.e. the number of edges incident to v).\n        See also: 1/ degree_sequence 2/ is_regular 3/ maximum_degree 4/ minimum_degree 5/ vertex_in_degree 6/ vertex_out_degree \n        Ex1:vertex_degree(digraph(trail(1,2,3,4,2)),2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3119vertex_degree = {"vertex_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3119vertex_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3118vertex_degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3119vertex_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertex_degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertex_degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3118vertex_degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3118vertex_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertex_degree", 1);

  /* "giacpy/auto-methods.pxi":19458
 * 
 *         '''
 *         return GiacMethods['vertex_degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertex_distance(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertex_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19458, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19449
 *         return GiacMethods['vertex_cover_number'](self,*args)
 * 
 *      def vertex_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertex_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19460
 *         return GiacMethods['vertex_degree'](self,*args)
 * 
 *      def vertex_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_distance:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3121vertex_distance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3120vertex_distance, "From Giac's documentation:\n        Help for vertex_distance:\n        vertex_distance(Graph(G),Vrtx(s),Vrtx(t)||Lst(T))\n        Returns the number of edges in the shortest path from vertex s to vertex t in G, or +infinity if there is no such path. For a vector T of vertices from G returns the list of distances from s to each vertex t in T.\n        See also: 1/ allpairs_distance 2/ graph_diameter 3/ dijkstra 4/ shortest_path \n        Ex1:vertex_distance(graph(\"petersen\"),1,4)\n        Ex2:vertex_distance(graph(\"petersen\"),1,[2,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3121vertex_distance = {"vertex_distance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3121vertex_distance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3120vertex_distance};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3121vertex_distance(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertex_distance (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertex_distance", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3120vertex_distance(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3120vertex_distance(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertex_distance", 1);

  /* "giacpy/auto-methods.pxi":19470
 * 
 *         '''
 *         return GiacMethods['vertex_distance'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertex_in_degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertex_distance); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19470, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19460
 *         return GiacMethods['vertex_degree'](self,*args)
 * 
 *      def vertex_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_distance:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertex_distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19472
 *         return GiacMethods['vertex_distance'](self,*args)
 * 
 *      def vertex_in_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_in_degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3123vertex_in_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3122vertex_in_degree, "From Giac's documentation:\n        Help for vertex_in_degree:\n        vertex_in_degree(Graph(G),Vrtx(v))\n        Returns the number of arcs in G entering the vertex v.\n        See also: 1/ degree_sequence 2/ is_regular 3/ maximum_degree 4/ minimum_degree 5/ vertex_degree 6/ vertex_out_degree \n        Ex1:vertex_in_degree(digraph(trail(1,2,3,4,2)),2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3123vertex_in_degree = {"vertex_in_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3123vertex_in_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3122vertex_in_degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3123vertex_in_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertex_in_degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertex_in_degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3122vertex_in_degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3122vertex_in_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertex_in_degree", 1);

  /* "giacpy/auto-methods.pxi":19481
 * 
 *         '''
 *         return GiacMethods['vertex_in_degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertex_out_degree(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertex_in_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19481, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19472
 *         return GiacMethods['vertex_distance'](self,*args)
 * 
 *      def vertex_in_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_in_degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertex_in_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19483
 *         return GiacMethods['vertex_in_degree'](self,*args)
 * 
 *      def vertex_out_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_out_degree:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3125vertex_out_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3124vertex_out_degree, "From Giac's documentation:\n        Help for vertex_out_degree:\n        vertex_out_degree(Graph(G),Vrtx(v))\n        Returns the number of arcs in G emanating from the vertex v.\n        See also: 1/ degree_sequence 2/ is_regular 3/ maximum_degree 4/ minimum_degree 5/ vertex_degree 6/ vertex_in_degree \n        Ex1:vertex_out_degree(digraph(trail(1,2,3,4,2)),2)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3125vertex_out_degree = {"vertex_out_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3125vertex_out_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3124vertex_out_degree};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3125vertex_out_degree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertex_out_degree (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertex_out_degree", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3124vertex_out_degree(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3124vertex_out_degree(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertex_out_degree", 1);

  /* "giacpy/auto-methods.pxi":19492
 * 
 *         '''
 *         return GiacMethods['vertex_out_degree'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertices(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertex_out_degree); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19492, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19483
 *         return GiacMethods['vertex_in_degree'](self,*args)
 * 
 *      def vertex_out_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_out_degree:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertex_out_degree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19494
 *         return GiacMethods['vertex_out_degree'](self,*args)
 * 
 *      def vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3127vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3126vertices, "From Giac's documentation:\n        Help for vertices:\n        vertices(Polygon or Polyedr(P))\n        Returns the list of the vertices of the polygon or polyhedron P.\n        See also: 1/ isosceles_triangle 2/ polyhedron \n        Ex1:vertices(isosceles_triangle(0,1,pi/4))\n        Ex2:vertices(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))\n        Ex3:vertices(isosceles_triangle(0,1,pi/4))[2]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3127vertices = {"vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3127vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3126vertices};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3127vertices(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertices (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertices", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3126vertices(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3126vertices(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertices", 1);

  /* "giacpy/auto-methods.pxi":19505
 * 
 *         '''
 *         return GiacMethods['vertices'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertices_abc(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertices); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19505, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19494
 *         return GiacMethods['vertex_out_degree'](self,*args)
 * 
 *      def vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertices", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19507
 *         return GiacMethods['vertices'](self,*args)
 * 
 *      def vertices_abc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abc:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3129vertices_abc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3128vertices_abc, "From Giac's documentation:\n        Help for vertices_abc:\n        vertices_abc(Polygon or Polyedr(P))\n        Returns the list of the vertices of the polygon or polyhedron P.\n        See also: 1/ isosceles_triangle 2/ polyhedron \n        Ex1:vertices_abc(isosceles_triangle(0,1,pi/4))\n        Ex2:vertices_abc(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))\n        Ex3:vertices_abc(isosceles_triangle(0,1,pi/4))[2]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3129vertices_abc = {"vertices_abc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3129vertices_abc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3128vertices_abc};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3129vertices_abc(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertices_abc (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertices_abc", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3128vertices_abc(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3128vertices_abc(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertices_abc", 1);

  /* "giacpy/auto-methods.pxi":19518
 * 
 *         '''
 *         return GiacMethods['vertices_abc'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vertices_abca(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertices_abc); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19518, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19507
 *         return GiacMethods['vertices'](self,*args)
 * 
 *      def vertices_abc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abc:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertices_abc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19520
 *         return GiacMethods['vertices_abc'](self,*args)
 * 
 *      def vertices_abca(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abca:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3131vertices_abca(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3130vertices_abca, "From Giac's documentation:\n        Help for vertices_abca:\n        vertices_abca(Polygon or Polyedr(P))\n        Returns the closed list [A,B,...A] of the vertices of the polygon or polyhedron P.\n        See also: 1/ isosceles_triangle 2/ polyhedron \n        Ex1:vertices_abca(isosceles_triangle(0,1,pi/4))\n        Ex2:vertices_abca(polyhedron([0,0,0],[0,5,0],[0,0,5],[1,2,6]))\n        Ex3:vertices_abca(isosceles_triangle(0,1,pi/4))[2]\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3131vertices_abca = {"vertices_abca", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3131vertices_abca, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3130vertices_abca};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3131vertices_abca(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vertices_abca (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vertices_abca", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3130vertices_abca(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3130vertices_abca(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vertices_abca", 1);

  /* "giacpy/auto-methods.pxi":19531
 * 
 *         '''
 *         return GiacMethods['vertices_abca'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def violet(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vertices_abca); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19531, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19520
 *         return GiacMethods['vertices_abc'](self,*args)
 * 
 *      def vertices_abca(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abca:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vertices_abca", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19533
 *         return GiacMethods['vertices_abca'](self,*args)
 * 
 *      def violet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for violet:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3133violet(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3132violet, "From Giac's documentation:\n        Help for violet:\n        violet(Opt)\n        Option of the display command to display with color.\n        See also: 1/ display \n        Ex1: F:=display(point(2+1.5*i),red)\n        Ex2: F:=display(point(2+1.5*i),point_point+green)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3133violet = {"violet", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3133violet, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3132violet};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3133violet(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("violet (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "violet", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3132violet(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3132violet(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("violet", 1);

  /* "giacpy/auto-methods.pxi":19543
 * 
 *         '''
 *         return GiacMethods['violet'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vpotential(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_violet); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19543, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19533
 *         return GiacMethods['vertices_abca'](self,*args)
 * 
 *      def violet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for violet:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.violet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19545
 *         return GiacMethods['violet'](self,*args)
 * 
 *      def vpotential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vpotential:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3135vpotential(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3134vpotential, "From Giac's documentation:\n        Help for vpotential:\n        vpotential(Vect(V),LstVar)\n        Returns U such that curl(U)=V.\n        See also: 1/ curl 2/ potential \n        Ex1:vpotential([2*x*y+3,x^2-4*z,-2*y*z],[x,y,z])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3135vpotential = {"vpotential", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3135vpotential, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3134vpotential};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3135vpotential(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vpotential (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vpotential", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3134vpotential(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3134vpotential(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vpotential", 1);

  /* "giacpy/auto-methods.pxi":19554
 * 
 *         '''
 *         return GiacMethods['vpotential'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def vstep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vpotential); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19554, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19545
 *         return GiacMethods['violet'](self,*args)
 * 
 *      def vpotential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vpotential:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vpotential", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19556
 *         return GiacMethods['vpotential'](self,*args)
 * 
 *      def vstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vstep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3137vstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3136vstep, "From Giac's documentation:\n        Help for vstep:\n        vstep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3137vstep = {"vstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3137vstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3136vstep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3137vstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("vstep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "vstep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3136vstep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3136vstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("vstep", 1);

  /* "giacpy/auto-methods.pxi":19563
 * 
 *         '''
 *         return GiacMethods['vstep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def web_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_vstep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19563, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19556
 *         return GiacMethods['vpotential'](self,*args)
 * 
 *      def vstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vstep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.vstep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19565
 *         return GiacMethods['vstep'](self,*args)
 * 
 *      def web_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for web_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3139web_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3138web_graph, "From Giac's documentation:\n        Help for web_graph:\n        web_graph(Intg(a),Intg(b))\n        Returns a web graph on a*b vertices, where a>=3 and b>=2.\n        See also: 1/ prism_graph 2/ wheel_graph \n        Ex1:web_graph(5,3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3139web_graph = {"web_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3139web_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3138web_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3139web_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("web_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "web_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3138web_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3138web_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("web_graph", 1);

  /* "giacpy/auto-methods.pxi":19574
 * 
 *         '''
 *         return GiacMethods['web_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibull(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_web_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19574, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19565
 *         return GiacMethods['vstep'](self,*args)
 * 
 *      def web_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for web_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.web_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19576
 *         return GiacMethods['web_graph'](self,*args)
 * 
 *      def weibull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3141weibull(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3140weibull, "From Giac's documentation:\n        Help for weibull:\n        weibull(Real(k),Real(lambda),Real(theta),Real(x))\n        Returns the density of probability at x of the Weibull law with parameters k, lambda, theta (by default theta=0).\n        See also: 1/ weibull_cdf 2/ weibull_icdf \n        Ex1:weibull(2.1,1.2,1.3)\n        Ex2:weibull(2.1,1.2,0.0,1.3)\n        Ex3:weibull(2.1,1.2,0.5,1.8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3141weibull = {"weibull", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3141weibull, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3140weibull};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3141weibull(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibull (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibull", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3140weibull(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3140weibull(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibull", 1);

  /* "giacpy/auto-methods.pxi":19587
 * 
 *         '''
 *         return GiacMethods['weibull'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibull_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibull); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19587, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19576
 *         return GiacMethods['web_graph'](self,*args)
 * 
 *      def weibull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibull", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19589
 *         return GiacMethods['weibull'](self,*args)
 * 
 *      def weibull_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3143weibull_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3142weibull_cdf, "From Giac's documentation:\n        Help for weibull_cdf:\n        weibull_cdf(Real(k),Real(lambda),Real(theta),Real(x0))\n        Returns the probability that a Weibull random variable of parameters k, lambda, theta is less than x0.\n        See also: 1/ weibulld 2/ weibull_icdf \n        Ex1:weibull_cdf(2.1,1.2,1.9)\n        Ex2:weibull_cdf(2.1,1.2,0.0,1.9)\n        Ex3:weibull_cdf(2.2,1.5,0.4,1.9)\n        Ex4:weibull_cdf(2.2,1.5,0.4,1.2)\n        Ex5:weibull_cdf(2.2,1.5,0.4,1.2,1.9)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3143weibull_cdf = {"weibull_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3143weibull_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3142weibull_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3143weibull_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibull_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibull_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3142weibull_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3142weibull_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibull_cdf", 1);

  /* "giacpy/auto-methods.pxi":19602
 * 
 *         '''
 *         return GiacMethods['weibull_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibull_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibull_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19602, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19589
 *         return GiacMethods['weibull'](self,*args)
 * 
 *      def weibull_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibull_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19604
 *         return GiacMethods['weibull_cdf'](self,*args)
 * 
 *      def weibull_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3145weibull_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3144weibull_icdf, "From Giac's documentation:\n        Help for weibull_icdf:\n        weibull_icdf(Real(k),Real(lambda),Real(theta),Real(p))\n        Returns h such that the probability that a Weibull random variable of parameters k, lambda, theta is less than h is p (0<=p<=1).\n        See also: 1/ weibull_cdf 2/ weibull \n        Ex1:weibull_icdf(4.2,1.3,0.0,0.95)\n        Ex2:weibull_icdf(2.2,1.5,0.4,0.632)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3145weibull_icdf = {"weibull_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3145weibull_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3144weibull_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3145weibull_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibull_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibull_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3144weibull_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3144weibull_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibull_icdf", 1);

  /* "giacpy/auto-methods.pxi":19614
 * 
 *         '''
 *         return GiacMethods['weibull_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibulld(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibull_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19614, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19604
 *         return GiacMethods['weibull_cdf'](self,*args)
 * 
 *      def weibull_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibull_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19616
 *         return GiacMethods['weibull_icdf'](self,*args)
 * 
 *      def weibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3147weibulld(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3146weibulld, "From Giac's documentation:\n        Help for weibulld:\n        weibulld(Real(k),Real(lambda),Real(theta),Real(x))\n        Returns the density of probability at x of the Weibull law with parameters k, lambda, theta (by default theta=0).\n        See also: 1/ weibull_cdf 2/ weibull_icdf \n        Ex1:weibulld(2.1,1.2,1.3)\n        Ex2:weibulld(2.1,1.2,0.0,1.3)\n        Ex3:weibulld(2.1,1.2,0.5,1.8)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3147weibulld = {"weibulld", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3147weibulld, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3146weibulld};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3147weibulld(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibulld (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibulld", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3146weibulld(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3146weibulld(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibulld", 1);

  /* "giacpy/auto-methods.pxi":19627
 * 
 *         '''
 *         return GiacMethods['weibulld'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibulld_cdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibulld); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19627, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19616
 *         return GiacMethods['weibull_icdf'](self,*args)
 * 
 *      def weibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibulld", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19629
 *         return GiacMethods['weibulld'](self,*args)
 * 
 *      def weibulld_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_cdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3149weibulld_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3148weibulld_cdf, "From Giac's documentation:\n        Help for weibulld_cdf:\n        weibulld_cdf(Real(k),Real(lambda),Real(theta),Real(x0))\n        Returns the probability that a Weibull random variable of parameters k, lambda, theta is less than x0.\n        See also: 1/ weibulld 2/ weibull_icdf \n        Ex1:weibulld_cdf(2.1,1.2,1.9)\n        Ex2:weibulld_cdf(2.1,1.2,0.0,1.9)\n        Ex3:weibulld_cdf(2.2,1.5,0.4,1.9)\n        Ex4:weibulld_cdf(2.2,1.5,0.4,1.2)\n        Ex5:weibulld_cdf(2.2,1.5,0.4,1.2,1.9)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3149weibulld_cdf = {"weibulld_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3149weibulld_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3148weibulld_cdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3149weibulld_cdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibulld_cdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibulld_cdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3148weibulld_cdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3148weibulld_cdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibulld_cdf", 1);

  /* "giacpy/auto-methods.pxi":19642
 * 
 *         '''
 *         return GiacMethods['weibulld_cdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibulld_icdf(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibulld_cdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19642, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19629
 *         return GiacMethods['weibulld'](self,*args)
 * 
 *      def weibulld_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_cdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibulld_cdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19644
 *         return GiacMethods['weibulld_cdf'](self,*args)
 * 
 *      def weibulld_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_icdf:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3151weibulld_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3150weibulld_icdf, "From Giac's documentation:\n        Help for weibulld_icdf:\n        weibulld_icdf(Real(k),Real(lambda),Real(theta),Real(p))\n        Returns h such that the probability that a Weibull random variable of parameters k, lambda, theta is less than h is p (0<=p<=1).\n        See also: 1/ weibull_cdf 2/ weibull \n        Ex1:weibulld_icdf(4.2,1.3,0.0,0.95)\n        Ex2:weibulld_icdf(2.2,1.5,0.4,0.632)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3151weibulld_icdf = {"weibulld_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3151weibulld_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3150weibulld_icdf};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3151weibulld_icdf(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibulld_icdf (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibulld_icdf", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3150weibulld_icdf(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3150weibulld_icdf(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibulld_icdf", 1);

  /* "giacpy/auto-methods.pxi":19654
 * 
 *         '''
 *         return GiacMethods['weibulld_icdf'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weibullvariate(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibulld_icdf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19654, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19644
 *         return GiacMethods['weibulld_cdf'](self,*args)
 * 
 *      def weibulld_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_icdf:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibulld_icdf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19656
 *         return GiacMethods['weibulld_icdf'](self,*args)
 * 
 *      def weibullvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibullvariate:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3153weibullvariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3152weibullvariate, "From Giac's documentation:\n        Help for weibullvariate:\n        weibullvariate(Real(a),Real(b))\n        Returns a random real according to the Weibull distribution with parameters a>0 and b>0.\n        See also: 1/ rand 2/ randpoly 3/ randnorm 4/ randvector \n        Ex1:weibullvariate(1,2)\n        Ex2:weibullvariate(1.5,4)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3153weibullvariate = {"weibullvariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3153weibullvariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3152weibullvariate};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3153weibullvariate(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weibullvariate (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weibullvariate", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3152weibullvariate(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3152weibullvariate(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weibullvariate", 1);

  /* "giacpy/auto-methods.pxi":19666
 * 
 *         '''
 *         return GiacMethods['weibullvariate'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weight_decay(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weibullvariate); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19666, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19656
 *         return GiacMethods['weibulld_icdf'](self,*args)
 * 
 *      def weibullvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibullvariate:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weibullvariate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19668
 *         return GiacMethods['weibullvariate'](self,*args)
 * 
 *      def weight_decay(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_decay:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3155weight_decay(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3154weight_decay, "From Giac's documentation:\n        Help for weight_decay:\n        weight_decay(Opt)\n        Option for the neural_network command.\n        See also: 1/ neural_network \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3155weight_decay = {"weight_decay", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3155weight_decay, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3154weight_decay};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3155weight_decay(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weight_decay (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weight_decay", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3154weight_decay(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3154weight_decay(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weight_decay", 1);

  /* "giacpy/auto-methods.pxi":19676
 * 
 *         '''
 *         return GiacMethods['weight_decay'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weight_matrix(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weight_decay); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19676, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19668
 *         return GiacMethods['weibullvariate'](self,*args)
 * 
 *      def weight_decay(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_decay:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weight_decay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19678
 *         return GiacMethods['weight_decay'](self,*args)
 * 
 *      def weight_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_matrix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3157weight_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3156weight_matrix, "From Giac's documentation:\n        Help for weight_matrix:\n        weight_matrix(Graph(G))\n        Returns the weight matrix of G.\n        See also: 1/ set_edge_weight 2/ get_edge_weights 3/ is_weighted 4/ make_weighted 5/ assign_edge_weights \n        Ex1:weight_matrix(graph(%{[[1,2],2],[[2,3],1]%})\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3157weight_matrix = {"weight_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3157weight_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3156weight_matrix};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3157weight_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weight_matrix (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weight_matrix", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3156weight_matrix(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3156weight_matrix(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weight_matrix", 1);

  /* "giacpy/auto-methods.pxi":19687
 * 
 *         '''
 *         return GiacMethods['weight_matrix'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weighted(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weight_matrix); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19687, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19678
 *         return GiacMethods['weight_decay'](self,*args)
 * 
 *      def weight_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_matrix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weight_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19689
 *         return GiacMethods['weight_matrix'](self,*args)
 * 
 *      def weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weighted:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3159weighted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3158weighted, "From Giac's documentation:\n        Help for weighted:\n        weighted(Opt)\n        Option for graph and digraph commands.\n        See also: 1/ directed 2/ graph 3/ digraph \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3159weighted = {"weighted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3159weighted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3158weighted};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3159weighted(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weighted (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weighted", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3158weighted(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3158weighted(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weighted", 1);

  /* "giacpy/auto-methods.pxi":19697
 * 
 *         '''
 *         return GiacMethods['weighted'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def weights(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weighted); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19697, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19689
 *         return GiacMethods['weight_matrix'](self,*args)
 * 
 *      def weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weighted:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weighted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19699
 *         return GiacMethods['weighted'](self,*args)
 * 
 *      def weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weights:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3161weights(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3160weights, "From Giac's documentation:\n        Help for weights:\n        weights(Opt)\n        Option for the edges command.\n        See also: 1/ edges \n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3161weights = {"weights", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3161weights, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3160weights};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3161weights(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("weights (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "weights", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3160weights(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3160weights(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("weights", 1);

  /* "giacpy/auto-methods.pxi":19707
 * 
 *         '''
 *         return GiacMethods['weights'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def welch_window(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_weights); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19707, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19699
 *         return GiacMethods['weighted'](self,*args)
 * 
 *      def weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weights:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.weights", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19709
 *         return GiacMethods['weights'](self,*args)
 * 
 *      def welch_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for welch_window:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3163welch_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3162welch_window, "From Giac's documentation:\n        Help for welch_window:\n        welch_window(Lst,[Interval(n1..n2)])\n        Applies the Welch windowing function to the given signal u (or to the elements with indices between n1 and n2) and returns the result in a new list.\n        See also: 1/ blackman_harris_window 2/ blackman_window 3/ bohman_window 4/ cosine_window 5/ gaussian_window 6/ hamming_window 7/ hann_poisson_window 8/ hann_window 9/ parzen_window 10/ poisson_window 11/ riemann_window 12/ triangle_window 13/ tukey_window 14/ bartlett_hann_window \n        Ex1: scatterplot(welch_window(randvector(1000,0..1)))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3163welch_window = {"welch_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3163welch_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3162welch_window};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3163welch_window(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("welch_window (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "welch_window", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3162welch_window(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3162welch_window(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("welch_window", 1);

  /* "giacpy/auto-methods.pxi":19718
 * 
 *         '''
 *         return GiacMethods['welch_window'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def wheel_graph(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_welch_window); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19718, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19709
 *         return GiacMethods['weights'](self,*args)
 * 
 *      def welch_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for welch_window:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.welch_window", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19720
 *         return GiacMethods['welch_window'](self,*args)
 * 
 *      def wheel_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wheel_graph:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3165wheel_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3164wheel_graph, "From Giac's documentation:\n        Help for wheel_graph:\n        wheel_graph(Intg(n))\n        Returns a wheel graph with n+1 vertices.\n        See also: 1/ star_graph 2/ web_graph \n        Ex1:wheel_graph(5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3165wheel_graph = {"wheel_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3165wheel_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3164wheel_graph};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3165wheel_graph(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wheel_graph (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "wheel_graph", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3164wheel_graph(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3164wheel_graph(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wheel_graph", 1);

  /* "giacpy/auto-methods.pxi":19729
 * 
 *         '''
 *         return GiacMethods['wheel_graph'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def widget_size(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_wheel_graph); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19729, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19720
 *         return GiacMethods['welch_window'](self,*args)
 * 
 *      def wheel_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wheel_graph:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.wheel_graph", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19731
 *         return GiacMethods['wheel_graph'](self,*args)
 * 
 *      def widget_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for widget_size:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3167widget_size(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3166widget_size, "From Giac's documentation:\n        Help for widget_size:\n        widget_size(Intg(n))\n        Changes the character sizes of the display on the xcas screen (size=n) and with more parameters define the general configuration.\n        See also: 1/ cas_setup \n        Ex1:widget_size(20)\n        Ex2:widget_size(8)\n        Ex3:widget_size(20,58,49,697,563,1,1,0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3167widget_size = {"widget_size", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3167widget_size, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3166widget_size};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3167widget_size(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("widget_size (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "widget_size", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3166widget_size(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3166widget_size(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("widget_size", 1);

  /* "giacpy/auto-methods.pxi":19742
 * 
 *         '''
 *         return GiacMethods['widget_size'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def wilcoxonp(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_widget_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19742, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19731
 *         return GiacMethods['wheel_graph'](self,*args)
 * 
 *      def widget_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for widget_size:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.widget_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19744
 *         return GiacMethods['widget_size'](self,*args)
 * 
 *      def wilcoxonp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxonp:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3169wilcoxonp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3168wilcoxonp, "From Giac's documentation:\n        Help for wilcoxonp:\n        wilcoxonp(Intg,[Intg])\n        Distribution of the Wilcoxon or Mann-Whitney test for one or two samples.\n        See also: 1/ wilcoxont 2/ wilcoxons \n        Ex1:wilcoxonp(4)\n        Ex2:wilcoxonp(7,5)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3169wilcoxonp = {"wilcoxonp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3169wilcoxonp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3168wilcoxonp};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3169wilcoxonp(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wilcoxonp (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "wilcoxonp", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3168wilcoxonp(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3168wilcoxonp(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wilcoxonp", 1);

  /* "giacpy/auto-methods.pxi":19754
 * 
 *         '''
 *         return GiacMethods['wilcoxonp'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def wilcoxons(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_wilcoxonp); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19754, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19744
 *         return GiacMethods['widget_size'](self,*args)
 * 
 *      def wilcoxonp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxonp:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.wilcoxonp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19756
 *         return GiacMethods['wilcoxonp'](self,*args)
 * 
 *      def wilcoxons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxons:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3171wilcoxons(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3170wilcoxons, "From Giac's documentation:\n        Help for wilcoxons:\n        wilcoxons(List,List || Real)\n        Rank statistic of Wilcoxon or Mann-Whitney for 1 sample and one median or 2 samples.\n        See also: 1/ wilcoxont 2/ wilcoxonp \n        Ex1:wilcoxons([1, 3, 4, 5, 7, 8, 8, 12, 15, 17] , [2, 6, 10, 11, 13, 14, 15, 18, 19, 20])\n        Ex2:wilcoxons([1, 3, 4, 5, 7, 8, 8, 12, 15, 17] , 10)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3171wilcoxons = {"wilcoxons", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3171wilcoxons, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3170wilcoxons};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3171wilcoxons(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wilcoxons (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "wilcoxons", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3170wilcoxons(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3170wilcoxons(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wilcoxons", 1);

  /* "giacpy/auto-methods.pxi":19766
 * 
 *         '''
 *         return GiacMethods['wilcoxons'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def wilcoxont(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_wilcoxons); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19766, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19756
 *         return GiacMethods['wilcoxonp'](self,*args)
 * 
 *      def wilcoxons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxons:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.wilcoxons", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19768
 *         return GiacMethods['wilcoxons'](self,*args)
 * 
 *      def wilcoxont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxont:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3173wilcoxont(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3172wilcoxont, "From Giac's documentation:\n        Help for wilcoxont:\n        wilcoxont(List,List || Real,[Func],[Real])\n        Wilcoxon or Mann-Whitney test for one sample and a median or 2 samples.\n        See also: 1/ wilcoxonp 2/ wilcoxons 3/ studentt 4/ normalt \n        Ex1:wilcoxont([1, 3, 4, 5, 7, 8, 8, 12, 15, 17] , [2, 6, 10, 11, 13, 14, 15, 18, 19, 20])\n        Ex2:wilcoxont([1, 3, 4, 5, 7, 8, 8, 12, 15, 17] , [2, 6, 10, 11, 13, 14, 15, 18, 19, 20],0.01)\n        Ex3:wilcoxont([1, 3, 4, 5, 7, 8, 8, 12, 15, 17] , 10,'>')\n        Ex4:wilcoxont([1, 3, 4, 5, 7, 8, 8, 12, 15, 17] , 10,'>',0.05)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3173wilcoxont = {"wilcoxont", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3173wilcoxont, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3172wilcoxont};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3173wilcoxont(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wilcoxont (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "wilcoxont", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3172wilcoxont(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3172wilcoxont(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wilcoxont", 1);

  /* "giacpy/auto-methods.pxi":19780
 * 
 *         '''
 *         return GiacMethods['wilcoxont'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def writergb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_wilcoxont); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19780, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19768
 *         return GiacMethods['wilcoxons'](self,*args)
 * 
 *      def wilcoxont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxont:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.wilcoxont", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19782
 *         return GiacMethods['wilcoxont'](self,*args)
 * 
 *      def writergb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writergb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3175writergb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3174writergb, "From Giac's documentation:\n        Help for writergb:\n        writergb(Str(s),Lst)\n        Write a PNG picture file named s either from a list [[number_channels,width,height],red,green,alpha,blue] where red,green,alpha,blue are matrices of pixels color or from a matrix of grey pixels or from 3 matrices of RGB colored pixels.\n        See also: 1/ readrgb \n        Ex1:writergb(\"image.png\",[[255,0],[0,255]])\n        Ex2:writergb(\"image.png\",[[255,0],[0,0]],[[0,255],[0,0]],[[0,0],[255,0]])\n        Ex3: a:=readrgb(\"rgb_image.png\");writergb(\"brg_image.png\",[a[0],a[4],a[1],a[3],a[2]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3175writergb = {"writergb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3175writergb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3174writergb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3175writergb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("writergb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "writergb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3174writergb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3174writergb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("writergb", 1);

  /* "giacpy/auto-methods.pxi":19793
 * 
 *         '''
 *         return GiacMethods['writergb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def writewav(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_writergb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19793, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19782
 *         return GiacMethods['wilcoxont'](self,*args)
 * 
 *      def writergb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writergb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.writergb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19795
 *         return GiacMethods['writergb'](self,*args)
 * 
 *      def writewav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writewav:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3177writewav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3176writewav, "From Giac's documentation:\n        Help for writewav:\n        writewav(Str(s),Lst(l))\n        Writes a WAV sound file.\n        See also: 1/ readwav \n        Ex1:writewav(\"la.wav\",2^14*(sin(2*pi*440*soundsec(1))))\n        Ex2:writewav(\"beep.wav\",[[1,16,44100,80000],[65000$10000,0$10000,65000$10000,0$10000]])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3177writewav = {"writewav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3177writewav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3176writewav};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3177writewav(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("writewav (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "writewav", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3176writewav(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3176writewav(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("writewav", 1);

  /* "giacpy/auto-methods.pxi":19805
 * 
 *         '''
 *         return GiacMethods['writewav'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def xcas_mode(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_writewav); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19805, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19795
 *         return GiacMethods['writergb'](self,*args)
 * 
 *      def writewav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writewav:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.writewav", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19807
 *         return GiacMethods['writewav'](self,*args)
 * 
 *      def xcas_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xcas_mode:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3179xcas_mode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3178xcas_mode, "From Giac's documentation:\n        Help for xcas_mode:\n        xcas_mode(Intg(0) or 1 or 2 or 3)\n        Switches to mode Xcas (0), Maple (1), Mupad (2), TI89 (3).\n        See also: 1/ python_compat \n        Ex1:xcas_mode(1)\n        Ex2:xcas_mode(0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3179xcas_mode = {"xcas_mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3179xcas_mode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3178xcas_mode};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3179xcas_mode(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("xcas_mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "xcas_mode", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3178xcas_mode(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3178xcas_mode(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("xcas_mode", 1);

  /* "giacpy/auto-methods.pxi":19817
 * 
 *         '''
 *         return GiacMethods['xcas_mode'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def xml_print(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_xcas_mode); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19817, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19807
 *         return GiacMethods['writewav'](self,*args)
 * 
 *      def xcas_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xcas_mode:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.xcas_mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19819
 *         return GiacMethods['xcas_mode'](self,*args)
 * 
 *      def xml_print(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xml_print:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3181xml_print(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3180xml_print, "From Giac's documentation:\n        Help for xml_print:\n        xml_print(Str)\n        Indents a XML code given in a string (pretty print).\n        See also: 1/ export_mathml \n        Ex1:xml_print(export_mathml(a+2*b))\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3181xml_print = {"xml_print", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3181xml_print, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3180xml_print};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3181xml_print(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("xml_print (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "xml_print", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3180xml_print(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3180xml_print(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("xml_print", 1);

  /* "giacpy/auto-methods.pxi":19828
 * 
 *         '''
 *         return GiacMethods['xml_print'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def xstep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_xml_print); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19828, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19819
 *         return GiacMethods['xcas_mode'](self,*args)
 * 
 *      def xml_print(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xml_print:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.xml_print", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19830
 *         return GiacMethods['xml_print'](self,*args)
 * 
 *      def xstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xstep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3183xstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3182xstep, "From Giac's documentation:\n        Help for xstep:\n        xstep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3183xstep = {"xstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3183xstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3182xstep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3183xstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("xstep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "xstep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3182xstep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3182xstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("xstep", 1);

  /* "giacpy/auto-methods.pxi":19837
 * 
 *         '''
 *         return GiacMethods['xstep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def xyz2rgb(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_xstep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19837, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19830
 *         return GiacMethods['xml_print'](self,*args)
 * 
 *      def xstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xstep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.xstep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19839
 *         return GiacMethods['xstep'](self,*args)
 * 
 *      def xyz2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyz2rgb:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3185xyz2rgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3184xyz2rgb, "From Giac's documentation:\n        Help for xyz2rgb:\n        xyz2rgb(Lst(x,y,z))\n        Convert XYZ to RGB.\n        See also: 1/ rgb2xyz 2/ interp \n        Ex1:xyz2rgb(0.1,0.2,0.3)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3185xyz2rgb = {"xyz2rgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3185xyz2rgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3184xyz2rgb};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3185xyz2rgb(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("xyz2rgb (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "xyz2rgb", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3184xyz2rgb(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3184xyz2rgb(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("xyz2rgb", 1);

  /* "giacpy/auto-methods.pxi":19848
 * 
 *         '''
 *         return GiacMethods['xyz2rgb'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def xyztrange(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_xyz2rgb); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19848, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19839
 *         return GiacMethods['xstep'](self,*args)
 * 
 *      def xyz2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyz2rgb:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.xyz2rgb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19850
 *         return GiacMethods['xyz2rgb'](self,*args)
 * 
 *      def xyztrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyztrange:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3187xyztrange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3186xyztrange, "From Giac's documentation:\n        Help for xyztrange:\n        xyztrange(SeqReal)\n        xyztrange puts or erases the axes on the graphic-screen (cf button Cfg).\n        Ex1:xyztrange(-5.0,5.0,-5.0,2.0,-10.0,10.0,-1.0,6.0,-5.0,5.0,-1.2384,2.0,1,0.0,1.0)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3187xyztrange = {"xyztrange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3187xyztrange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3186xyztrange};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3187xyztrange(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("xyztrange (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "xyztrange", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3186xyztrange(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3186xyztrange(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("xyztrange", 1);

  /* "giacpy/auto-methods.pxi":19858
 * 
 *         '''
 *         return GiacMethods['xyztrange'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ystep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_xyztrange); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19858, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19850
 *         return GiacMethods['xyz2rgb'](self,*args)
 * 
 *      def xyztrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyztrange:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.xyztrange", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19860
 *         return GiacMethods['xyztrange'](self,*args)
 * 
 *      def ystep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ystep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3189ystep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3188ystep, "From Giac's documentation:\n        Help for ystep:\n        ystep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3189ystep = {"ystep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3189ystep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3188ystep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3189ystep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ystep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ystep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3188ystep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3188ystep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ystep", 1);

  /* "giacpy/auto-methods.pxi":19867
 * 
 *         '''
 *         return GiacMethods['ystep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def zeros(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ystep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19867, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19860
 *         return GiacMethods['xyztrange'](self,*args)
 * 
 *      def ystep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ystep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ystep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19869
 *         return GiacMethods['ystep'](self,*args)
 * 
 *      def zeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zeros:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3191zeros(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3190zeros, "From Giac's documentation:\n        Help for zeros:\n        zeros(Expr,[Var])\n        Returns the zeros (real or complex according to the mode) of the expression (or the matrix where the lines are the solutions of the system : expression1=0,expression2=0...).\n        See also: 1/  \n        Ex1:zeros(x^2+4)\n        Ex2:zeros(ln(x)^2-4)\n        Ex3:zeros(ln(y)^2-2,y)\n        Ex4:zeros([x^2-1,x^2-y^2],[x,y])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3191zeros = {"zeros", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3191zeros, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3190zeros};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3191zeros(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("zeros (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "zeros", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3190zeros(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3190zeros(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("zeros", 1);

  /* "giacpy/auto-methods.pxi":19881
 * 
 *         '''
 *         return GiacMethods['zeros'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def znorder(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19881, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19869
 *         return GiacMethods['ystep'](self,*args)
 * 
 *      def zeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zeros:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.zeros", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19883
 *         return GiacMethods['zeros'](self,*args)
 * 
 *      def znorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znorder:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3193znorder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3192znorder, "From Giac's documentation:\n        Help for znorder:\n        znorder(Intg)\n        Returns 0 or the order of k in (Z/nZ^*,*)\n        See also: 1/ znprimroot 2/ pari \n        Ex1:znorder(17,23)\n        Ex2:znorder(5,1234)\n        Ex3:znorder(17 mod 23)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3193znorder = {"znorder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3193znorder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3192znorder};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3193znorder(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("znorder (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "znorder", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3192znorder(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3192znorder(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("znorder", 1);

  /* "giacpy/auto-methods.pxi":19894
 * 
 *         '''
 *         return GiacMethods['znorder'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def znprimroot(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_znorder); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19894, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19883
 *         return GiacMethods['zeros'](self,*args)
 * 
 *      def znorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znorder:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.znorder", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19896
 *         return GiacMethods['znorder'](self,*args)
 * 
 *      def znprimroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znprimroot:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3195znprimroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3194znprimroot, "From Giac's documentation:\n        Help for znprimroot:\n        znprimroot(Intg)\n        Returns a generator of (Z/pZ^*,*)\n        See also: 1/ znorder 2/ pari \n        Ex1:znprimroot(23)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3195znprimroot = {"znprimroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3195znprimroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3194znprimroot};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3195znprimroot(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("znprimroot (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "znprimroot", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3194znprimroot(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3194znprimroot(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("znprimroot", 1);

  /* "giacpy/auto-methods.pxi":19905
 * 
 *         '''
 *         return GiacMethods['znprimroot'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def zstep(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_znprimroot); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19905, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19896
 *         return GiacMethods['znorder'](self,*args)
 * 
 *      def znprimroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znprimroot:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.znprimroot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19907
 *         return GiacMethods['znprimroot'](self,*args)
 * 
 *      def zstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zstep:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3197zstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3196zstep, "From Giac's documentation:\n        Help for zstep:\n        zstep(Opt)\n        Option for plotting commands.\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3197zstep = {"zstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3197zstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3196zstep};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3197zstep(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("zstep (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "zstep", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3196zstep(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3196zstep(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("zstep", 1);

  /* "giacpy/auto-methods.pxi":19914
 * 
 *         '''
 *         return GiacMethods['zstep'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def ztrans(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_zstep); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19914, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19907
 *         return GiacMethods['znprimroot'](self,*args)
 * 
 *      def zstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zstep:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.zstep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19916
 *         return GiacMethods['zstep'](self,*args)
 * 
 *      def ztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ztrans:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3199ztrans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3198ztrans, "From Giac's documentation:\n        Help for ztrans:\n        ztrans(Expr,[Var],[ZtransVar])\n        z transform of a sequence.\n        See also: 1/ invztrans 2/ laplace 3/ invlaplace \n        Ex1:ztrans(a^x)\n        Ex2:ztrans(a^n,n,z)\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3199ztrans = {"ztrans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3199ztrans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3198ztrans};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3199ztrans(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ztrans (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ztrans", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3198ztrans(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3198ztrans(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ztrans", 1);

  /* "giacpy/auto-methods.pxi":19926
 * 
 *         '''
 *         return GiacMethods['ztrans'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def type(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_ztrans); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19926, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19916
 *         return GiacMethods['zstep'](self,*args)
 * 
 *      def ztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ztrans:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.ztrans", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19928
 *         return GiacMethods['ztrans'](self,*args)
 * 
 *      def type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for type:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3201type(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3200type, "From Giac's documentation:\n        Help for type:\n        type(Expr)\n        Returns n in [1..12] that defines the type of the argument.\n        See also: 1/ DOM_FLOAT 2/ DOM_INT 3/ DOM_COMPLEX 4/ DOM_IDENT 5/ DOM_LIST 6/ DOM_SYMBOLIC 7/ DOM_RAT 8/ DOM_STRING 9/ DOM_FUNC 10/ subtype \n        Ex1:type(\"abc\")\n        Ex2:type([1,2,3])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3201type = {"type", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3201type, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3200type};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3201type(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("type (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "type", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3200type(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3200type(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("type", 1);

  /* "giacpy/auto-methods.pxi":19938
 * 
 *         '''
 *         return GiacMethods['type'](self,*args)             # <<<<<<<<<<<<<<
 * 
 *      def zip(self,*args):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19938, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19928
 *         return GiacMethods['ztrans'](self,*args)
 * 
 *      def type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for type:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/auto-methods.pxi":19940
 *         return GiacMethods['type'](self,*args)
 * 
 *      def zip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zip:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3203zip(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3202zip, "From Giac's documentation:\n        Help for zip:\n        zip(Fnc2d(f),Lst(l1),Lst(l2),[Val(default)])\n        Returns a list whose j-th entry is f(l1[j],l2[j]): without default value its length is the minimum of the lengths of the two input lists and otherwise the shorter list is padded with the default value.\n        See also: 1/  \n        Ex1:zip('+',[a,b,c,d], [1,2,3,4])\n        Ex2:zip('+',[a,b,c,d], [1,2,3])\n        Ex3:zip('+',[a,b,c,d], [1,2,3],5)\n        Ex4:zip(sum,[a,b,c,d], [1,2,3,4])\n        \n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3203zip = {"zip", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3203zip, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3202zip};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3203zip(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("zip (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "zip", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3202zip(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3202zip(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("zip", 1);

  /* "giacpy/auto-methods.pxi":19952
 * 
 *         '''
 *         return GiacMethods['zip'](self,*args)             # <<<<<<<<<<<<<<
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_zip); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(2, 19952, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 19952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 19952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/auto-methods.pxi":19940
 *         return GiacMethods['type'](self,*args)
 * 
 *      def zip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zip:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.zip", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3205__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3205__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3205__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3205__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3204__reduce_cython__(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3204__reduce_cython__(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_GiacMethods_base); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, None), state
 *     else:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_GiacMethods_base__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_GiacMethods_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_GiacMethods_base__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3207__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3207__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3207__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3207__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3206__setstate_cython__(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_16GiacMethods_base_3206__setstate_cython__(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_GiacMethods_base__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6giacpy_6giacpy___pyx_unpickle_GiacMethods_base__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_GiacMethods_base__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacMethods_base.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":815
 *      """
 * 
 *      def __cinit__(self, s=None):             # <<<<<<<<<<<<<<
 * 
 *          #NB: the  != here gives problems with  the __richcmp__ function
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_5Pygen_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6giacpy_6giacpy_5Pygen_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_s = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 815, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 815, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 815, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen___cinit__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_5Pygen___cinit__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_s) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  giac::gen *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PY_LONG_LONG __pyx_t_8;
  giac::gen __pyx_t_9;
  double __pyx_t_10;
  int __pyx_t_11;
  giac::vecteur __pyx_t_12;
  std::string __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_INCREF(__pyx_v_s);

  /* "giacpy/giacpy.pyx":820
 *          #if (s!=None):
 *          # so it's better to use isinstance
 *          if (isinstance(s,None.__class__)):             # <<<<<<<<<<<<<<
 *              # Do NOT replace with: self=GIACNULL  (cf the doctest in __repr__
 *              self.gptr = new gen ((<Pygen>GIACNULL).gptr[0])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(Py_None, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_s, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":822
 *          if (isinstance(s,None.__class__)):
 *              # Do NOT replace with: self=GIACNULL  (cf the doctest in __repr__
 *              self.gptr = new gen ((<Pygen>GIACNULL).gptr[0])             # <<<<<<<<<<<<<<
 *              return
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GIACNULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    try {
      __pyx_t_3 = new giac::gen((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_1)->gptr[0]));
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 822, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":823
 *              # Do NOT replace with: self=GIACNULL  (cf the doctest in __repr__
 *              self.gptr = new gen ((<Pygen>GIACNULL).gptr[0])
 *              return             # <<<<<<<<<<<<<<
 * 
 *          if isinstance(s,int):       # This looks 100 faster than the str initialisation
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":820
 *          #if (s!=None):
 *          # so it's better to use isinstance
 *          if (isinstance(s,None.__class__)):             # <<<<<<<<<<<<<<
 *              # Do NOT replace with: self=GIACNULL  (cf the doctest in __repr__
 *              self.gptr = new gen ((<Pygen>GIACNULL).gptr[0])
 */
  }

  /* "giacpy/giacpy.pyx":825
 *              return
 * 
 *          if isinstance(s,int):       # This looks 100 faster than the str initialisation             # <<<<<<<<<<<<<<
 *            if PythonVersion3:
 *              #in python3 int and long are int
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_s); 
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":826
 * 
 *          if isinstance(s,int):       # This looks 100 faster than the str initialisation
 *            if PythonVersion3:             # <<<<<<<<<<<<<<
 *              #in python3 int and long are int
 *              if s.bit_length()< Pymaxint.bit_length():
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_PythonVersion3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 826, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "giacpy/giacpy.pyx":828
 *            if PythonVersion3:
 *              #in python3 int and long are int
 *              if s.bit_length()< Pymaxint.bit_length():             # <<<<<<<<<<<<<<
 *                 self.gptr = new gen(<long long>s)
 *              else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_bit_length); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Pymaxint); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_bit_length); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_2) {

        /* "giacpy/giacpy.pyx":829
 *              #in python3 int and long are int
 *              if s.bit_length()< Pymaxint.bit_length():
 *                 self.gptr = new gen(<long long>s)             # <<<<<<<<<<<<<<
 *              else:
 *                 self.gptr = new gen(pylongtogen(s))
 */
        __pyx_t_8 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_v_s); if (unlikely((__pyx_t_8 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 829, __pyx_L1_error)
        try {
          __pyx_t_3 = new giac::gen(((PY_LONG_LONG)__pyx_t_8));
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 829, __pyx_L1_error)
        }
        __pyx_v_self->gptr = __pyx_t_3;

        /* "giacpy/giacpy.pyx":828
 *            if PythonVersion3:
 *              #in python3 int and long are int
 *              if s.bit_length()< Pymaxint.bit_length():             # <<<<<<<<<<<<<<
 *                 self.gptr = new gen(<long long>s)
 *              else:
 */
        goto __pyx_L6;
      }

      /* "giacpy/giacpy.pyx":831
 *                 self.gptr = new gen(<long long>s)
 *              else:
 *                 self.gptr = new gen(pylongtogen(s))             # <<<<<<<<<<<<<<
 *            else:
 *                 self.gptr = new gen(<long long>s)
 */
      /*else*/ {
        try {
          __pyx_t_9 = __pyx_f_6giacpy_6giacpy_pylongtogen(__pyx_v_s);
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 831, __pyx_L1_error)
        }
        try {
          __pyx_t_3 = new giac::gen(__pyx_t_9);
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 831, __pyx_L1_error)
        }
        __pyx_v_self->gptr = __pyx_t_3;
      }
      __pyx_L6:;

      /* "giacpy/giacpy.pyx":826
 * 
 *          if isinstance(s,int):       # This looks 100 faster than the str initialisation
 *            if PythonVersion3:             # <<<<<<<<<<<<<<
 *              #in python3 int and long are int
 *              if s.bit_length()< Pymaxint.bit_length():
 */
      goto __pyx_L5;
    }

    /* "giacpy/giacpy.pyx":833
 *                 self.gptr = new gen(pylongtogen(s))
 *            else:
 *                 self.gptr = new gen(<long long>s)             # <<<<<<<<<<<<<<
 * 
 *          #
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_v_s); if (unlikely((__pyx_t_8 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 833, __pyx_L1_error)
      try {
        __pyx_t_3 = new giac::gen(((PY_LONG_LONG)__pyx_t_8));
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 833, __pyx_L1_error)
      }
      __pyx_v_self->gptr = __pyx_t_3;
    }
    __pyx_L5:;

    /* "giacpy/giacpy.pyx":825
 *              return
 * 
 *          if isinstance(s,int):       # This looks 100 faster than the str initialisation             # <<<<<<<<<<<<<<
 *            if PythonVersion3:
 *              #in python3 int and long are int
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":839
 *          # not so much as it first look : giac(1/7.0)._double -1/7.0
 * 
 *          elif isinstance(s,float):             # <<<<<<<<<<<<<<
 *              self.gptr = new gen(<double>s)
 *          #
 */
  __pyx_t_2 = PyFloat_Check(__pyx_v_s); 
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":840
 * 
 *          elif isinstance(s,float):
 *              self.gptr = new gen(<double>s)             # <<<<<<<<<<<<<<
 *          #
 * 
 */
    __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_s); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 840, __pyx_L1_error)
    try {
      __pyx_t_3 = new giac::gen(((double)__pyx_t_10));
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 840, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":839
 *          # not so much as it first look : giac(1/7.0)._double -1/7.0
 * 
 *          elif isinstance(s,float):             # <<<<<<<<<<<<<<
 *              self.gptr = new gen(<double>s)
 *          #
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":844
 * 
 *          # Check if 'long' exists in builtins (Python 2 and Cython < 3.1)
 *          elif hasattr(__builtins__, 'long') and isinstance(s, __builtins__.long):             # <<<<<<<<<<<<<<
 *              # Python 2 path or older Cython with long support
 *              self.gptr = new gen(pylongtogen(s))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_builtins); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_11 = __Pyx_HasAttr(__pyx_t_7, __pyx_n_s_long); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_11) {
  } else {
    __pyx_t_2 = __pyx_t_11;
    goto __pyx_L7_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_builtins); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_long); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_11 = PyObject_IsInstance(__pyx_v_s, __pyx_t_4); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_11;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":846
 *          elif hasattr(__builtins__, 'long') and isinstance(s, __builtins__.long):
 *              # Python 2 path or older Cython with long support
 *              self.gptr = new gen(pylongtogen(s))             # <<<<<<<<<<<<<<
 *          elif type(s).__name__ == 'long':
 *              # Fallback for cases where isinstance doesn't work (Cython >= 3.1)
 */
    try {
      __pyx_t_9 = __pyx_f_6giacpy_6giacpy_pylongtogen(__pyx_v_s);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 846, __pyx_L1_error)
    }
    try {
      __pyx_t_3 = new giac::gen(__pyx_t_9);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 846, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":844
 * 
 *          # Check if 'long' exists in builtins (Python 2 and Cython < 3.1)
 *          elif hasattr(__builtins__, 'long') and isinstance(s, __builtins__.long):             # <<<<<<<<<<<<<<
 *              # Python 2 path or older Cython with long support
 *              self.gptr = new gen(pylongtogen(s))
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":847
 *              # Python 2 path or older Cython with long support
 *              self.gptr = new gen(pylongtogen(s))
 *          elif type(s).__name__ == 'long':             # <<<<<<<<<<<<<<
 *              # Fallback for cases where isinstance doesn't work (Cython >= 3.1)
 *              self.gptr = new gen(pylongtogen(s))
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_s)), __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_4, __pyx_n_s_long, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 847, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":849
 *          elif type(s).__name__ == 'long':
 *              # Fallback for cases where isinstance doesn't work (Cython >= 3.1)
 *              self.gptr = new gen(pylongtogen(s))             # <<<<<<<<<<<<<<
 * 
 * 
 */
    try {
      __pyx_t_9 = __pyx_f_6giacpy_6giacpy_pylongtogen(__pyx_v_s);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 849, __pyx_L1_error)
    }
    try {
      __pyx_t_3 = new giac::gen(__pyx_t_9);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 849, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":847
 *              # Python 2 path or older Cython with long support
 *              self.gptr = new gen(pylongtogen(s))
 *          elif type(s).__name__ == 'long':             # <<<<<<<<<<<<<<
 *              # Fallback for cases where isinstance doesn't work (Cython >= 3.1)
 *              self.gptr = new gen(pylongtogen(s))
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":852
 * 
 * 
 *          elif isinstance(s,Pygen):             # <<<<<<<<<<<<<<
 *              #in the test: x,y=Pygen('x,y');((x+2*y).sin()).texpand()
 *              # the y are lost without this case.
 */
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_s, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":855
 *              #in the test: x,y=Pygen('x,y');((x+2*y).sin()).texpand()
 *              # the y are lost without this case.
 *              self.gptr = new gen((<Pygen>s).gptr[0])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    try {
      __pyx_t_3 = new giac::gen((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_s)->gptr[0]));
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 855, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":852
 * 
 * 
 *          elif isinstance(s,Pygen):             # <<<<<<<<<<<<<<
 *              #in the test: x,y=Pygen('x,y');((x+2*y).sin()).texpand()
 *              # the y are lost without this case.
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":858
 * 
 * 
 *          elif isinstance(s,listrange):             # <<<<<<<<<<<<<<
 *              self.gptr = new gen(_wrap_pylist(<list>s),<short int>0)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_listrange); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_s, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":859
 * 
 *          elif isinstance(s,listrange):
 *              self.gptr = new gen(_wrap_pylist(<list>s),<short int>0)             # <<<<<<<<<<<<<<
 * 
 *          elif isinstance(s,tuple):
 */
    try {
      __pyx_t_12 = __pyx_f_6giacpy_6giacpy__wrap_pylist(__pyx_v_s);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 859, __pyx_L1_error)
    }
    try {
      __pyx_t_3 = new giac::gen(__pyx_t_12, ((short)0));
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 859, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":858
 * 
 * 
 *          elif isinstance(s,listrange):             # <<<<<<<<<<<<<<
 *              self.gptr = new gen(_wrap_pylist(<list>s),<short int>0)
 * 
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":861
 *              self.gptr = new gen(_wrap_pylist(<list>s),<short int>0)
 * 
 *          elif isinstance(s,tuple):             # <<<<<<<<<<<<<<
 *              self.gptr = new gen(_wrap_pylist(<tuple>s),<short int>1)
 * 
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_s); 
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":862
 * 
 *          elif isinstance(s,tuple):
 *              self.gptr = new gen(_wrap_pylist(<tuple>s),<short int>1)             # <<<<<<<<<<<<<<
 * 
 *          # Other types are converted with strings.
 */
    try {
      __pyx_t_12 = __pyx_f_6giacpy_6giacpy__wrap_pylist(__pyx_v_s);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 862, __pyx_L1_error)
    }
    try {
      __pyx_t_3 = new giac::gen(__pyx_t_12, ((short)1));
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 862, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;

    /* "giacpy/giacpy.pyx":861
 *              self.gptr = new gen(_wrap_pylist(<list>s),<short int>0)
 * 
 *          elif isinstance(s,tuple):             # <<<<<<<<<<<<<<
 *              self.gptr = new gen(_wrap_pylist(<tuple>s),<short int>1)
 * 
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":866
 *          # Other types are converted with strings.
 *          else:
 *            if not(isinstance(s,str)):  #modif python3             # <<<<<<<<<<<<<<
 *              s=s.__str__()
 *              #s=s.__repr__()   # with big gen repr is intercepted
 */
  /*else*/ {
    __pyx_t_2 = PyString_Check(__pyx_v_s); 
    __pyx_t_11 = (!__pyx_t_2);
    if (__pyx_t_11) {

      /* "giacpy/giacpy.pyx":867
 *          else:
 *            if not(isinstance(s,str)):  #modif python3
 *              s=s.__str__()             # <<<<<<<<<<<<<<
 *              #s=s.__repr__()   # with big gen repr is intercepted
 *            #self.gptr = new gen(<string>s,context_ptr)
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_str_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 867, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "giacpy/giacpy.pyx":866
 *          # Other types are converted with strings.
 *          else:
 *            if not(isinstance(s,str)):  #modif python3             # <<<<<<<<<<<<<<
 *              s=s.__str__()
 *              #s=s.__repr__()   # with big gen repr is intercepted
 */
    }

    /* "giacpy/giacpy.pyx":870
 *              #s=s.__repr__()   # with big gen repr is intercepted
 *            #self.gptr = new gen(<string>s,context_ptr)
 *            self.gptr = new gen(<string>encstring23(s),context_ptr)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_encstring23); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_s};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 870, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_13 = __pyx_convert_string_from_py_6libcpp_6string_std__in_string(__pyx_t_4); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    try {
      __pyx_t_3 = new giac::gen(((std::string)__pyx_t_13), __pyx_v_6giacpy_6giacpy_context_ptr);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 870, __pyx_L1_error)
    }
    __pyx_v_self->gptr = __pyx_t_3;
  }
  __pyx_L4:;

  /* "giacpy/giacpy.pyx":815
 *      """
 * 
 *      def __cinit__(self, s=None):             # <<<<<<<<<<<<<<
 * 
 *          #NB: the  != here gives problems with  the __richcmp__ function
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":873
 * 
 * 
 *      def __dealloc__(self):             # <<<<<<<<<<<<<<
 *          del self.gptr
 * 
 */

/* Python wrapper */
static void __pyx_pw_6giacpy_6giacpy_5Pygen_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6giacpy_6giacpy_5Pygen_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6giacpy_6giacpy_5Pygen_2__dealloc__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6giacpy_6giacpy_5Pygen_2__dealloc__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {

  /* "giacpy/giacpy.pyx":874
 * 
 *      def __dealloc__(self):
 *          del self.gptr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  delete __pyx_v_self->gptr;

  /* "giacpy/giacpy.pyx":873
 * 
 * 
 *      def __dealloc__(self):             # <<<<<<<<<<<<<<
 *          del self.gptr
 * 
 */

  /* function exit code */
}

/* "giacpy/giacpy.pyx":877
 * 
 * 
 *      def __repr__(self):             # <<<<<<<<<<<<<<
 *         """
 *          >>> vide=Pygen()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__(PyObject *__pyx_v_self); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_4__repr__, "\n         >>> vide=Pygen()\n         >>> \"giac version dpt: either NULL or seq[]\", vide    # doctest: +ELLIPSIS\n         ('giac version dpt: either NULL or seq[]', ...)\n\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_4__repr__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_4__repr__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_4__repr__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  unsigned int __pyx_v_t;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  std::string __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "giacpy/giacpy.pyx":886
 *         #if self.gptr == NULL:
 *         #  return ''
 *         try:             # <<<<<<<<<<<<<<
 *           # fast evaluation of the complexity of the gen. (it's not the number of char )
 *           t=GIAC_taille(self.gptr[0], 6000)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":888
 *         try:
 *           # fast evaluation of the complexity of the gen. (it's not the number of char )
 *           t=GIAC_taille(self.gptr[0], 6000)             # <<<<<<<<<<<<<<
 *         except:
 *           raise RuntimeError
 */
      try {
        __pyx_t_4 = taille((__pyx_v_self->gptr[0]), 0x1770);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 888, __pyx_L3_error)
      }
      __pyx_v_t = __pyx_t_4;

      /* "giacpy/giacpy.pyx":886
 *         #if self.gptr == NULL:
 *         #  return ''
 *         try:             # <<<<<<<<<<<<<<
 *           # fast evaluation of the complexity of the gen. (it's not the number of char )
 *           t=GIAC_taille(self.gptr[0], 6000)
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "giacpy/giacpy.pyx":889
 *           # fast evaluation of the complexity of the gen. (it's not the number of char )
 *           t=GIAC_taille(self.gptr[0], 6000)
 *         except:             # <<<<<<<<<<<<<<
 *           raise RuntimeError
 *         if (t<6000) :
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 889, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "giacpy/giacpy.pyx":890
 *           t=GIAC_taille(self.gptr[0], 6000)
 *         except:
 *           raise RuntimeError             # <<<<<<<<<<<<<<
 *         if (t<6000) :
 *            return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 890, __pyx_L5_except_error)
    }

    /* "giacpy/giacpy.pyx":886
 *         #if self.gptr == NULL:
 *         #  return ''
 *         try:             # <<<<<<<<<<<<<<
 *           # fast evaluation of the complexity of the gen. (it's not the number of char )
 *           t=GIAC_taille(self.gptr[0], 6000)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "giacpy/giacpy.pyx":891
 *         except:
 *           raise RuntimeError
 *         if (t<6000) :             # <<<<<<<<<<<<<<
 *            return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3
 *         else:
 */
  __pyx_t_8 = (__pyx_v_t < 0x1770);
  if (__pyx_t_8) {

    /* "giacpy/giacpy.pyx":892
 *           raise RuntimeError
 *         if (t<6000) :
 *            return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3             # <<<<<<<<<<<<<<
 *         else:
 *           return str(self.type)+"\nResult is too big for Display. If you really want to see it use print"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    try {
      __pyx_t_9 = print((__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 892, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_t_9.c_str()); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_5};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":891
 *         except:
 *           raise RuntimeError
 *         if (t<6000) :             # <<<<<<<<<<<<<<
 *            return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3
 *         else:
 */
  }

  /* "giacpy/giacpy.pyx":894
 *            return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3
 *         else:
 *           return str(self.type)+"\nResult is too big for Display. If you really want to see it use print"             # <<<<<<<<<<<<<<
 * 
 *      def __str__(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_type); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_Str(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_kp_s_Result_is_too_big_for_Display_I); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":877
 * 
 * 
 *      def __repr__(self):             # <<<<<<<<<<<<<<
 *         """
 *          >>> vide=Pygen()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":896
 *           return str(self.type)+"\nResult is too big for Display. If you really want to see it use print"
 * 
 *      def __str__(self):             # <<<<<<<<<<<<<<
 *         #if self.gptr == NULL:
 *         #  return ''
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_7__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_7__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_6__str__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_6__str__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  std::string __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "giacpy/giacpy.pyx":899
 *         #if self.gptr == NULL:
 *         #  return ''
 *         return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3             # <<<<<<<<<<<<<<
 * 
 *      def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  try {
    __pyx_t_3 = print((__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 899, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_t_3.c_str()); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":896
 *           return str(self.type)+"\nResult is too big for Display. If you really want to see it use print"
 * 
 *      def __str__(self):             # <<<<<<<<<<<<<<
 *         #if self.gptr == NULL:
 *         #  return ''
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":901
 *         return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3
 * 
 *      def __len__(self):             # <<<<<<<<<<<<<<
 *        #if (self.gptr != NULL):
 *          try:
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6giacpy_6giacpy_5Pygen_9__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6giacpy_6giacpy_5Pygen_9__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_8__len__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6giacpy_6giacpy_5Pygen_8__len__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  int __pyx_v_rep;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  giac::gen __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__len__", 1);

  /* "giacpy/giacpy.pyx":903
 *      def __len__(self):
 *        #if (self.gptr != NULL):
 *          try:             # <<<<<<<<<<<<<<
 *            rep=GIAC_size(self.gptr[0],context_ptr).val
 *            #GIAC_size return a gen. we take the int: val
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":904
 *        #if (self.gptr != NULL):
 *          try:
 *            rep=GIAC_size(self.gptr[0],context_ptr).val             # <<<<<<<<<<<<<<
 *            #GIAC_size return a gen. we take the int: val
 *            return rep
 */
      try {
        __pyx_t_4 = _size((__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 904, __pyx_L3_error)
      }
      __pyx_t_5 = __pyx_t_4.val;
      __pyx_v_rep = __pyx_t_5;

      /* "giacpy/giacpy.pyx":906
 *            rep=GIAC_size(self.gptr[0],context_ptr).val
 *            #GIAC_size return a gen. we take the int: val
 *            return rep             # <<<<<<<<<<<<<<
 *          except:
 *            raise RuntimeError
 */
      __pyx_r = __pyx_v_rep;
      goto __pyx_L7_try_return;

      /* "giacpy/giacpy.pyx":903
 *      def __len__(self):
 *        #if (self.gptr != NULL):
 *          try:             # <<<<<<<<<<<<<<
 *            rep=GIAC_size(self.gptr[0],context_ptr).val
 *            #GIAC_size return a gen. we take the int: val
 */
    }
    __pyx_L3_error:;

    /* "giacpy/giacpy.pyx":907
 *            #GIAC_size return a gen. we take the int: val
 *            return rep
 *          except:             # <<<<<<<<<<<<<<
 *            raise RuntimeError
 *        #else:
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 907, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "giacpy/giacpy.pyx":908
 *            return rep
 *          except:
 *            raise RuntimeError             # <<<<<<<<<<<<<<
 *        #else:
 *        #  raise MemoryError,"This Pygen is not associated to a giac gen"
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 908, __pyx_L5_except_error)
    }

    /* "giacpy/giacpy.pyx":903
 *      def __len__(self):
 *        #if (self.gptr != NULL):
 *          try:             # <<<<<<<<<<<<<<
 *            rep=GIAC_size(self.gptr[0],context_ptr).val
 *            #GIAC_size return a gen. we take the int: val
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":901
 *         return decstring23(GIAC_print(self.gptr[0], context_ptr).c_str()) #python3
 * 
 *      def __len__(self):             # <<<<<<<<<<<<<<
 *        #if (self.gptr != NULL):
 *          try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__len__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":913
 * 
 * 
 *      def __getitem__(self,i):  #TODO?: add gen support for indexes             # <<<<<<<<<<<<<<
 *         """
 *          Lists of 10**6 integers should be translated to giac easily
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_11__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_i); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_10__getitem__, "\n         Lists of 10**6 integers should be translated to giac easily\n\n           >>> l=giac(list(range(10**6)));l[5]   #python3\n           5\n           >>> l[35:50:7]\n           [35,42,49]\n           >>> t=giac(tuple(range(10)))\n           >>> t[:4:-1]\n           9,8,7,6,5\n           >>> x=giac('x'); sum([ x[i] for i in range(5)])**3\n           (x[0]+x[1]+x[2]+x[3]+x[4])**3\n           >>> import giacpy\n           >>> A=giacpy.ranm(5,10); A[3,7]-A[3][7]\n           0\n           >>> A.transpose()[8,2]-A[2][8]\n           0\n           >>> A=giac('[ranm(5,5),ranm(5,5)]')\n           >>> A[1,2,3]-A[1][2][3]\n           0\n\n        Crash test:\n\n           >>> l=Pygen()\n           >>> l[0]      # doctest: +SKIP\n           Traceback (most recent call last):\n           ...\n           RuntimeError\n\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_10__getitem__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_11__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_i) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_10__getitem__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_i));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_10__getitem__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_i) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_cmd = NULL;
  PyObject *__pyx_v_ans = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  giac::gen __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  giac::vecteur __pyx_t_12;
  short __pyx_t_13;
  unsigned int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);
  __Pyx_INCREF(__pyx_v_i);

  /* "giacpy/giacpy.pyx":946
 *         cdef gen result
 * 
 *         if(self._type == 7) or (self._type == 12):   #if self is a list or a string             # <<<<<<<<<<<<<<
 *           if isinstance(i,int):
 *             n=len(self)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_type_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_7, 7, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_type_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_12, 12, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":947
 * 
 *         if(self._type == 7) or (self._type == 12):   #if self is a list or a string
 *           if isinstance(i,int):             # <<<<<<<<<<<<<<
 *             n=len(self)
 *             if(i<n)and(-i<n):
 */
    __pyx_t_1 = PyInt_Check(__pyx_v_i); 
    if (__pyx_t_1) {

      /* "giacpy/giacpy.pyx":948
 *         if(self._type == 7) or (self._type == 12):   #if self is a list or a string
 *           if isinstance(i,int):
 *             n=len(self)             # <<<<<<<<<<<<<<
 *             if(i<n)and(-i<n):
 *                 if(i<0):
 */
      __pyx_t_4 = PyObject_Length(((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 948, __pyx_L1_error)
      __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 948, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_n = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "giacpy/giacpy.pyx":949
 *           if isinstance(i,int):
 *             n=len(self)
 *             if(i<n)and(-i<n):             # <<<<<<<<<<<<<<
 *                 if(i<0):
 *                   i=i+n
 */
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_i, __pyx_v_n, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 949, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_3) {
      } else {
        __pyx_t_1 = __pyx_t_3;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_2 = PyNumber_Negative(__pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_v_n, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_1 = __pyx_t_3;
      __pyx_L8_bool_binop_done:;
      if (likely(__pyx_t_1)) {

        /* "giacpy/giacpy.pyx":950
 *             n=len(self)
 *             if(i<n)and(-i<n):
 *                 if(i<0):             # <<<<<<<<<<<<<<
 *                   i=i+n
 *                 try:
 */
        __pyx_t_5 = PyObject_RichCompare(__pyx_v_i, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 950, __pyx_L1_error)
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 950, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (__pyx_t_1) {

          /* "giacpy/giacpy.pyx":951
 *             if(i<n)and(-i<n):
 *                 if(i<0):
 *                   i=i+n             # <<<<<<<<<<<<<<
 *                 try:
 *                   result=self.gptr[0][<int>i]
 */
          __pyx_t_5 = PyNumber_Add(__pyx_v_i, __pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 951, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "giacpy/giacpy.pyx":950
 *             n=len(self)
 *             if(i<n)and(-i<n):
 *                 if(i<0):             # <<<<<<<<<<<<<<
 *                   i=i+n
 *                 try:
 */
        }

        /* "giacpy/giacpy.pyx":952
 *                 if(i<0):
 *                   i=i+n
 *                 try:             # <<<<<<<<<<<<<<
 *                   result=self.gptr[0][<int>i]
 *                   return _wrap_gen(result)
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          /*try:*/ {

            /* "giacpy/giacpy.pyx":953
 *                   i=i+n
 *                 try:
 *                   result=self.gptr[0][<int>i]             # <<<<<<<<<<<<<<
 *                   return _wrap_gen(result)
 *                 except:
 */
            __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_i); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 953, __pyx_L11_error)
            try {
              __pyx_t_10 = (__pyx_v_self->gptr[0])[((int)__pyx_t_9)];
            } catch(...) {
              __Pyx_CppExn2PyErr();
              __PYX_ERR(0, 953, __pyx_L11_error)
            }
            __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_10);

            /* "giacpy/giacpy.pyx":954
 *                 try:
 *                   result=self.gptr[0][<int>i]
 *                   return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *                 except:
 *                   raise RuntimeError
 */
            __Pyx_XDECREF(__pyx_r);
            try {
              __pyx_t_5 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 954, __pyx_L11_error)
            } catch(...) {
              __Pyx_CppExn2PyErr();
              __PYX_ERR(0, 954, __pyx_L11_error)
            }
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_r = __pyx_t_5;
            __pyx_t_5 = 0;
            goto __pyx_L15_try_return;

            /* "giacpy/giacpy.pyx":952
 *                 if(i<0):
 *                   i=i+n
 *                 try:             # <<<<<<<<<<<<<<
 *                   result=self.gptr[0][<int>i]
 *                   return _wrap_gen(result)
 */
          }
          __pyx_L11_error:;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "giacpy/giacpy.pyx":955
 *                   result=self.gptr[0][<int>i]
 *                   return _wrap_gen(result)
 *                 except:             # <<<<<<<<<<<<<<
 *                   raise RuntimeError
 *             else:
 */
          /*except:*/ {
            __Pyx_AddTraceback("giacpy.giacpy.Pygen.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_2, &__pyx_t_11) < 0) __PYX_ERR(0, 955, __pyx_L13_except_error)
            __Pyx_XGOTREF(__pyx_t_5);
            __Pyx_XGOTREF(__pyx_t_2);
            __Pyx_XGOTREF(__pyx_t_11);

            /* "giacpy/giacpy.pyx":956
 *                   return _wrap_gen(result)
 *                 except:
 *                   raise RuntimeError             # <<<<<<<<<<<<<<
 *             else:
 *                 raise IndexError,'list index %s out of range'%(i)
 */
            __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
            __PYX_ERR(0, 956, __pyx_L13_except_error)
          }

          /* "giacpy/giacpy.pyx":952
 *                 if(i<0):
 *                   i=i+n
 *                 try:             # <<<<<<<<<<<<<<
 *                   result=self.gptr[0][<int>i]
 *                   return _wrap_gen(result)
 */
          __pyx_L13_except_error:;
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
          goto __pyx_L1_error;
          __pyx_L15_try_return:;
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
          goto __pyx_L0;
        }

        /* "giacpy/giacpy.pyx":949
 *           if isinstance(i,int):
 *             n=len(self)
 *             if(i<n)and(-i<n):             # <<<<<<<<<<<<<<
 *                 if(i<0):
 *                   i=i+n
 */
      }

      /* "giacpy/giacpy.pyx":958
 *                   raise RuntimeError
 *             else:
 *                 raise IndexError,'list index %s out of range'%(i)             # <<<<<<<<<<<<<<
 *           else:
 *             if isinstance(i,slice):
 */
      /*else*/ {
        __pyx_t_11 = __Pyx_PyString_FormatSafe(__pyx_kp_s_list_index_s_out_of_range, __pyx_v_i); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 958, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_11, 0, 0);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __PYX_ERR(0, 958, __pyx_L1_error)
      }

      /* "giacpy/giacpy.pyx":947
 * 
 *         if(self._type == 7) or (self._type == 12):   #if self is a list or a string
 *           if isinstance(i,int):             # <<<<<<<<<<<<<<
 *             n=len(self)
 *             if(i<n)and(-i<n):
 */
    }

    /* "giacpy/giacpy.pyx":960
 *                 raise IndexError,'list index %s out of range'%(i)
 *           else:
 *             if isinstance(i,slice):             # <<<<<<<<<<<<<<
 *               result=gen(_getgiacslice(self,i),<short int>self._subtype)
 *               return _wrap_gen(result)
 */
    /*else*/ {
      __pyx_t_1 = PySlice_Check(__pyx_v_i); 
      if (__pyx_t_1) {

        /* "giacpy/giacpy.pyx":961
 *           else:
 *             if isinstance(i,slice):
 *               result=gen(_getgiacslice(self,i),<short int>self._subtype)             # <<<<<<<<<<<<<<
 *               return _wrap_gen(result)
 * 
 */
        if (!(likely(PySlice_Check(__pyx_v_i))||((__pyx_v_i) == Py_None) || __Pyx_RaiseUnexpectedTypeError("slice", __pyx_v_i))) __PYX_ERR(0, 961, __pyx_L1_error)
        try {
          __pyx_t_12 = __pyx_f_6giacpy_6giacpy__getgiacslice(__pyx_v_self, ((PyObject*)__pyx_v_i));
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 961, __pyx_L1_error)
        }
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_subtype_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 961, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_13 = __Pyx_PyInt_As_short(__pyx_t_11); if (unlikely((__pyx_t_13 == (short)-1) && PyErr_Occurred())) __PYX_ERR(0, 961, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        try {
          __pyx_t_10 = giac::gen(__pyx_t_12, ((short)__pyx_t_13));
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 961, __pyx_L1_error)
        }
        __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_10);

        /* "giacpy/giacpy.pyx":962
 *             if isinstance(i,slice):
 *               result=gen(_getgiacslice(self,i),<short int>self._subtype)
 *               return _wrap_gen(result)             # <<<<<<<<<<<<<<
 * 
 *             # add support for multi indexes
 */
        __Pyx_XDECREF(__pyx_r);
        try {
          __pyx_t_11 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 962, __pyx_L1_error)
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 962, __pyx_L1_error)
        }
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_r = __pyx_t_11;
        __pyx_t_11 = 0;
        goto __pyx_L0;

        /* "giacpy/giacpy.pyx":960
 *                 raise IndexError,'list index %s out of range'%(i)
 *           else:
 *             if isinstance(i,slice):             # <<<<<<<<<<<<<<
 *               result=gen(_getgiacslice(self,i),<short int>self._subtype)
 *               return _wrap_gen(result)
 */
      }

      /* "giacpy/giacpy.pyx":965
 * 
 *             # add support for multi indexes
 *             elif isinstance(i,tuple):             # <<<<<<<<<<<<<<
 *                if(len(i)==2):
 *                   return self[i[0]][i[1]]
 */
      __pyx_t_1 = PyTuple_Check(__pyx_v_i); 
      if (likely(__pyx_t_1)) {

        /* "giacpy/giacpy.pyx":966
 *             # add support for multi indexes
 *             elif isinstance(i,tuple):
 *                if(len(i)==2):             # <<<<<<<<<<<<<<
 *                   return self[i[0]][i[1]]
 *                elif(len(i)==1):
 */
        __pyx_t_4 = PyObject_Length(__pyx_v_i); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 966, __pyx_L1_error)
        __pyx_t_1 = (__pyx_t_4 == 2);
        if (__pyx_t_1) {

          /* "giacpy/giacpy.pyx":967
 *             elif isinstance(i,tuple):
 *                if(len(i)==2):
 *                   return self[i[0]][i[1]]             # <<<<<<<<<<<<<<
 *                elif(len(i)==1):
 *                   # in case of a tuple like this: (3,)
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_11 = __Pyx_GetItemInt(__pyx_v_i, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 967, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_2 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 967, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = __Pyx_GetItemInt(__pyx_v_i, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 967, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 967, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_r = __pyx_t_5;
          __pyx_t_5 = 0;
          goto __pyx_L0;

          /* "giacpy/giacpy.pyx":966
 *             # add support for multi indexes
 *             elif isinstance(i,tuple):
 *                if(len(i)==2):             # <<<<<<<<<<<<<<
 *                   return self[i[0]][i[1]]
 *                elif(len(i)==1):
 */
        }

        /* "giacpy/giacpy.pyx":968
 *                if(len(i)==2):
 *                   return self[i[0]][i[1]]
 *                elif(len(i)==1):             # <<<<<<<<<<<<<<
 *                   # in case of a tuple like this: (3,)
 *                   return self[i[0]]
 */
        __pyx_t_4 = PyObject_Length(__pyx_v_i); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 968, __pyx_L1_error)
        __pyx_t_1 = (__pyx_t_4 == 1);
        if (__pyx_t_1) {

          /* "giacpy/giacpy.pyx":970
 *                elif(len(i)==1):
 *                   # in case of a tuple like this: (3,)
 *                   return self[i[0]]             # <<<<<<<<<<<<<<
 *                else:
 *                   return self[i[0],i[1]][tuple(i[2:])]
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_i, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 970, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_11 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_t_5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 970, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_r = __pyx_t_11;
          __pyx_t_11 = 0;
          goto __pyx_L0;

          /* "giacpy/giacpy.pyx":968
 *                if(len(i)==2):
 *                   return self[i[0]][i[1]]
 *                elif(len(i)==1):             # <<<<<<<<<<<<<<
 *                   # in case of a tuple like this: (3,)
 *                   return self[i[0]]
 */
        }

        /* "giacpy/giacpy.pyx":972
 *                   return self[i[0]]
 *                else:
 *                   return self[i[0],i[1]][tuple(i[2:])]             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
        /*else*/ {
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_11 = __Pyx_GetItemInt(__pyx_v_i, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_i, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_11);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_11)) __PYX_ERR(0, 972, __pyx_L1_error);
          __Pyx_GIVEREF(__pyx_t_5);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5)) __PYX_ERR(0, 972, __pyx_L1_error);
          __pyx_t_11 = 0;
          __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_i, 2, 0, NULL, NULL, &__pyx_slice__2, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_11 = __Pyx_PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 972, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_r = __pyx_t_2;
          __pyx_t_2 = 0;
          goto __pyx_L0;
        }

        /* "giacpy/giacpy.pyx":965
 * 
 *             # add support for multi indexes
 *             elif isinstance(i,tuple):             # <<<<<<<<<<<<<<
 *                if(len(i)==2):
 *                   return self[i[0]][i[1]]
 */
      }

      /* "giacpy/giacpy.pyx":975
 * 
 *             else:
 *               raise TypeError,'gen indexes are not yet implemented'             # <<<<<<<<<<<<<<
 *         # Here we add support to formal variable indexes:
 *         else:
 */
      /*else*/ {
        __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_gen_indexes_are_not_yet_implemen, 0, 0);
        __PYX_ERR(0, 975, __pyx_L1_error)
      }
    }

    /* "giacpy/giacpy.pyx":946
 *         cdef gen result
 * 
 *         if(self._type == 7) or (self._type == 12):   #if self is a list or a string             # <<<<<<<<<<<<<<
 *           if isinstance(i,int):
 *             n=len(self)
 */
  }

  /* "giacpy/giacpy.pyx":978
 *         # Here we add support to formal variable indexes:
 *         else:
 *           cmd='%s[%s]'%(self,i)             # <<<<<<<<<<<<<<
 *           ans=Pygen(cmd).eval()
 *           # if the answer is a string, it must be an error message because self is not a list or a string
 */
  /*else*/ {
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __Pyx_GIVEREF((PyObject *)__pyx_v_self);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(0, 978, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_i);
    __Pyx_GIVEREF(__pyx_v_i);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_i)) __PYX_ERR(0, 978, __pyx_L1_error);
    __pyx_t_11 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_cmd = ((PyObject*)__pyx_t_11);
    __pyx_t_11 = 0;

    /* "giacpy/giacpy.pyx":979
 *         else:
 *           cmd='%s[%s]'%(self,i)
 *           ans=Pygen(cmd).eval()             # <<<<<<<<<<<<<<
 *           # if the answer is a string, it must be an error message because self is not a list or a string
 *           if (ans._type == 12):
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_cmd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_14 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_14 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_14, 0+__pyx_t_14);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_ans = __pyx_t_11;
    __pyx_t_11 = 0;

    /* "giacpy/giacpy.pyx":981
 *           ans=Pygen(cmd).eval()
 *           # if the answer is a string, it must be an error message because self is not a list or a string
 *           if (ans._type == 12):             # <<<<<<<<<<<<<<
 *             raise TypeError, "Error executing code in Giac\nCODE:\n\t%s\nGiac ERROR:\n\t%s"%(cmd, ans)
 *           return ans
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_ans, __pyx_n_s_type_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_11, __pyx_int_12, 12, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 981, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(__pyx_t_1)) {

      /* "giacpy/giacpy.pyx":982
 *           # if the answer is a string, it must be an error message because self is not a list or a string
 *           if (ans._type == 12):
 *             raise TypeError, "Error executing code in Giac\nCODE:\n\t%s\nGiac ERROR:\n\t%s"%(cmd, ans)             # <<<<<<<<<<<<<<
 *           return ans
 * 
 */
      __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_v_cmd);
      __Pyx_GIVEREF(__pyx_v_cmd);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_v_cmd)) __PYX_ERR(0, 982, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_ans);
      __Pyx_GIVEREF(__pyx_v_ans);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_v_ans)) __PYX_ERR(0, 982, __pyx_L1_error);
      __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_Error_executing_code_in_Giac_COD, __pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 982, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_Raise(__pyx_builtin_TypeError, __pyx_t_5, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 982, __pyx_L1_error)

      /* "giacpy/giacpy.pyx":981
 *           ans=Pygen(cmd).eval()
 *           # if the answer is a string, it must be an error message because self is not a list or a string
 *           if (ans._type == 12):             # <<<<<<<<<<<<<<
 *             raise TypeError, "Error executing code in Giac\nCODE:\n\t%s\nGiac ERROR:\n\t%s"%(cmd, ans)
 *           return ans
 */
    }

    /* "giacpy/giacpy.pyx":983
 *           if (ans._type == 12):
 *             raise TypeError, "Error executing code in Giac\nCODE:\n\t%s\nGiac ERROR:\n\t%s"%(cmd, ans)
 *           return ans             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ans);
    __pyx_r = __pyx_v_ans;
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":913
 * 
 * 
 *      def __getitem__(self,i):  #TODO?: add gen support for indexes             # <<<<<<<<<<<<<<
 *         """
 *          Lists of 10**6 integers should be translated to giac easily
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_cmd);
  __Pyx_XDECREF(__pyx_v_ans);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":986
 * 
 * 
 *      def __setitem__(self,key,value):             # <<<<<<<<<<<<<<
 *         """
 *         Set the value of a coefficient of a giac vector or matrix or list.
 */

/* Python wrapper */
static int __pyx_pw_6giacpy_6giacpy_5Pygen_13__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_12__setitem__, "\n        Set the value of a coefficient of a giac vector or matrix or list.\n           Warning: It is an in place affectation.\n\n\n        >>> A=giac([ [ j+2*i for i in range(3)] for j in range(3)]); A\n        [[0,2,4],[1,3,5],[2,4,6]]\n        >>> A[1,2]=44;A\n        [[0,2,4],[1,3,44],[2,4,6]]\n        >>> A[2][2]=giac(1)/3;A\n        [[0,2,4],[1,3,44],[2,4,1/3]]\n        >>> x=giac('x')\n        >>> A[0,0]=x+1/x; A\n        [[x+1/x,2,4],[1,3,44],[2,4,1/3]]\n        >>> A[0]=[-1,-2,-3]; A\n        [[-1,-2,-3],[1,3,44],[2,4,1/3]]\n        >>> B=A; A[2,2]\n        1/3\n        >>> B[2,2]=6    # in place affectation\n        >>> A[2,2]      # so A is also modified\n        6\n        >>> A.pcar(x)\n        x**3-8*x**2-159*x\n\n\n        NB: For Large matrix it seems that the syntax A[i][j]= is faster that A[i,j]=\n\n        >>> import giacpy\n        >>> from time import time\n        >>> A=giacpy.ranm(4000,4000)\n        >>> t1=time(); A[500][500]=12345;t1=time()-t1\n        >>> t2=time(); A[501,501]=54321;t2=time()-t2\n        >>> t1,t2 # doctest: +SKIP\n        (0.0002014636993408203, 0.05124521255493164)\n        >>> A[500,500],A[501][501]\n        (12345, 54321)\n\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_12__setitem__;
#endif
static int __pyx_pw_6giacpy_6giacpy_5Pygen_13__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_12__setitem__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_key), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6giacpy_6giacpy_5Pygen_12__setitem__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value) {
  giac::gen __pyx_v_v;
  giac::gen __pyx_v_g;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  std::string __pyx_t_5;
  giac::gen __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 1);

  /* "giacpy/giacpy.pyx":1026
 *         """
 *         cdef gen v
 *         cdef gen g = gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003'),context_ptr)             # <<<<<<<<<<<<<<
 *         GIAC_sto((<Pygen>self).gptr[0],g,1,context_ptr)
 *         g=gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003[%s]'%(str(key))),context_ptr)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_encstring23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_s_GIACPY_TMP_NAME05026807096929010};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __pyx_convert_string_from_py_6libcpp_6string_std__in_string(__pyx_t_1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1026, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  try {
    __pyx_t_6 = giac::gen(((std::string)__pyx_t_5), __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1026, __pyx_L1_error)
  }
  __pyx_v_g = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_6);

  /* "giacpy/giacpy.pyx":1027
 *         cdef gen v
 *         cdef gen g = gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003'),context_ptr)
 *         GIAC_sto((<Pygen>self).gptr[0],g,1,context_ptr)             # <<<<<<<<<<<<<<
 *         g=gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003[%s]'%(str(key))),context_ptr)
 *         v=(<Pygen>(Pygen(value).eval())).gptr[0]
 */
  try {
    sto((__pyx_v_self->gptr[0]), __pyx_v_g, __pyx_int_1, __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1027, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1028
 *         cdef gen g = gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003'),context_ptr)
 *         GIAC_sto((<Pygen>self).gptr[0],g,1,context_ptr)
 *         g=gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003[%s]'%(str(key))),context_ptr)             # <<<<<<<<<<<<<<
 *         v=(<Pygen>(Pygen(value).eval())).gptr[0]
 *         GIAC_sto(v,g,1,context_ptr)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_encstring23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Str(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyString_FormatSafe(__pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __pyx_convert_string_from_py_6libcpp_6string_std__in_string(__pyx_t_1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1028, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  try {
    __pyx_t_6 = giac::gen(((std::string)__pyx_t_5), __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1028, __pyx_L1_error)
  }
  __pyx_v_g = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_6);

  /* "giacpy/giacpy.pyx":1029
 *         GIAC_sto((<Pygen>self).gptr[0],g,1,context_ptr)
 *         g=gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003[%s]'%(str(key))),context_ptr)
 *         v=(<Pygen>(Pygen(value).eval())).gptr[0]             # <<<<<<<<<<<<<<
 *         GIAC_sto(v,g,1,context_ptr)
 *         Pygen('purge(GIACPY_TMP_NAME050268070969290100291003):;').eval()
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_v = (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_1)->gptr[0]);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1030
 *         g=gen(<string>encstring23('GIACPY_TMP_NAME050268070969290100291003[%s]'%(str(key))),context_ptr)
 *         v=(<Pygen>(Pygen(value).eval())).gptr[0]
 *         GIAC_sto(v,g,1,context_ptr)             # <<<<<<<<<<<<<<
 *         Pygen('purge(GIACPY_TMP_NAME050268070969290100291003):;').eval()
 *         return
 */
  try {
    sto(__pyx_v_v, __pyx_v_g, __pyx_int_1, __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1030, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1031
 *         v=(<Pygen>(Pygen(value).eval())).gptr[0]
 *         GIAC_sto(v,g,1,context_ptr)
 *         Pygen('purge(GIACPY_TMP_NAME050268070969290100291003):;').eval()             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_eval); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1032
 *         GIAC_sto(v,g,1,context_ptr)
 *         Pygen('purge(GIACPY_TMP_NAME050268070969290100291003):;').eval()
 *         return             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":986
 * 
 * 
 *      def __setitem__(self,key,value):             # <<<<<<<<<<<<<<
 *         """
 *         Set the value of a coefficient of a giac vector or matrix or list.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6giacpy_6giacpy_5Pygen_16generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "giacpy/giacpy.pyx":1035
 * 
 * 
 *      def __iter__(self):             # <<<<<<<<<<<<<<
 *        """
 *          Pygen lists of 10**6 elements should be yield
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_15__iter__(PyObject *__pyx_v_self); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_14__iter__, "\n         Pygen lists of 10**6 elements should be yield\n\n           >>> from time import time\n           >>> l=giac(range(10**6))\n           >>> t=time();l1=[ i for i in l ];t1=time()-t;'time for a list of 10**6  i ',t1        # doctest: +ELLIPSIS\n           ('time for a list of 10**6  i ', ...)\n           >>> t=time();l1=[ i+i for i in l ];t2=time()-t;'time for a list of 10**6  i+i ',t2    # doctest: +ELLIPSIS\n           ('time for a list of 10**6  i+i ', ...)\n           >>> t=time();l1=[ 1+i for i in l ];t3=time()-t;\"time for a list of 10**6  1+i \",t3    # doctest: +ELLIPSIS\n           ('time for a list of 10**6  1+i ', ...)\n           >>> t=time();l1=[ i+1 for i in l ];t4=time()-t;\"time for a list of 10**6  i+1 \",t4    # doctest: +ELLIPSIS\n           ('time for a list of 10**6  i+1 ', ...)\n\n       ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_14__iter__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_15__iter__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_14__iter__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_14__iter__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *)__pyx_tp_new_6giacpy_6giacpy___pyx_scope_struct____iter__(__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1035, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6giacpy_6giacpy_5Pygen_16generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_Pygen___iter, __pyx_n_s_giacpy_giacpy); if (unlikely(!gen)) __PYX_ERR(0, 1035, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6giacpy_6giacpy_5Pygen_16generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *__pyx_cur_scope = ((struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1035, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1053
 *        cdef int i
 *        #FIXME, should be improved: is it slow? and needs sig_on()?
 *        ressetctrl_c()             # <<<<<<<<<<<<<<
 *        for i in range(len(self)):
 *           if(GIACctrl_c):
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1053, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1054
 *        #FIXME, should be improved: is it slow? and needs sig_on()?
 *        ressetctrl_c()
 *        for i in range(len(self)):             # <<<<<<<<<<<<<<
 *           if(GIACctrl_c):
 *             raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_cur_scope->__pyx_v_self)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1054, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_cur_scope->__pyx_v_i = __pyx_t_3;

    /* "giacpy/giacpy.pyx":1055
 *        ressetctrl_c()
 *        for i in range(len(self)):
 *           if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *             raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *           yield self[i]
 */
    __pyx_t_4 = (ctrl_c != 0);
    if (unlikely(__pyx_t_4)) {

      /* "giacpy/giacpy.pyx":1056
 *        for i in range(len(self)):
 *           if(GIACctrl_c):
 *             raise KeyboardInterrupt,"Interrupted by a ctrl-c event"             # <<<<<<<<<<<<<<
 *           yield self[i]
 * 
 */
      __Pyx_Raise(__pyx_builtin_KeyboardInterrupt, __pyx_kp_s_Interrupted_by_a_ctrl_c_event, 0, 0);
      __PYX_ERR(0, 1056, __pyx_L1_error)

      /* "giacpy/giacpy.pyx":1055
 *        ressetctrl_c()
 *        for i in range(len(self)):
 *           if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *             raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *           yield self[i]
 */
    }

    /* "giacpy/giacpy.pyx":1057
 *           if(GIACctrl_c):
 *             raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *           yield self[i]             # <<<<<<<<<<<<<<
 * 
 *      def __int__(self):
 */
    __pyx_t_5 = __Pyx_GetItemInt(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1057, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L7_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1057, __pyx_L1_error)
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "giacpy/giacpy.pyx":1035
 * 
 * 
 *      def __iter__(self):             # <<<<<<<<<<<<<<
 *        """
 *          Pygen lists of 10**6 elements should be yield
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1059
 *           yield self[i]
 * 
 *      def __int__(self):             # <<<<<<<<<<<<<<
 *         """
 *           Convert a giac integer (type Pygen in python) to  a Python <int>
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_18__int__(PyObject *__pyx_v_self); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_17__int__, "\n          Convert a giac integer (type Pygen in python) to  a Python <int>\n\n            >>> a=giac('2*pi')\n            >>> list(range((a.floor()).__int__()))\n            [0, 1, 2, 3, 4, 5]\n\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_17__int__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_18__int__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__int__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_17__int__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_17__int__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__int__", 1);

  /* "giacpy/giacpy.pyx":1068
 * 
 *         """
 *         tmp=self.eval()             # <<<<<<<<<<<<<<
 *         if(tmp._type==0):
 *            # C int
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_eval); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_tmp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1069
 *         """
 *         tmp=self.eval()
 *         if(tmp._type==0):             # <<<<<<<<<<<<<<
 *            # C int
 *            return tmp._val
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_type_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "giacpy/giacpy.pyx":1071
 *         if(tmp._type==0):
 *            # C int
 *            return tmp._val             # <<<<<<<<<<<<<<
 *         elif(tmp._type==2):
 *            # gmp int
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1071, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1069
 *         """
 *         tmp=self.eval()
 *         if(tmp._type==0):             # <<<<<<<<<<<<<<
 *            # C int
 *            return tmp._val
 */
  }

  /* "giacpy/giacpy.pyx":1072
 *            # C int
 *            return tmp._val
 *         elif(tmp._type==2):             # <<<<<<<<<<<<<<
 *            # gmp int
 *            return int(str(tmp))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_type_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_2, 2, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1072, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_5)) {

    /* "giacpy/giacpy.pyx":1074
 *         elif(tmp._type==2):
 *            # gmp int
 *            return int(str(tmp))             # <<<<<<<<<<<<<<
 *         else:
 *            raise TypeError,"self is not a giac integer"
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_Str(__pyx_v_tmp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1072
 *            # C int
 *            return tmp._val
 *         elif(tmp._type==2):             # <<<<<<<<<<<<<<
 *            # gmp int
 *            return int(str(tmp))
 */
  }

  /* "giacpy/giacpy.pyx":1076
 *            return int(str(tmp))
 *         else:
 *            raise TypeError,"self is not a giac integer"             # <<<<<<<<<<<<<<
 * 
 *      def __float__(self):
 */
  /*else*/ {
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_is_not_a_giac_integer, 0, 0);
    __PYX_ERR(0, 1076, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1059
 *           yield self[i]
 * 
 *      def __int__(self):             # <<<<<<<<<<<<<<
 *         """
 *           Convert a giac integer (type Pygen in python) to  a Python <int>
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__int__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1078
 *            raise TypeError,"self is not a giac integer"
 * 
 *      def __float__(self):             # <<<<<<<<<<<<<<
 *         """
 *            Convert a giac real to a Python <float>
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_20__float__(PyObject *__pyx_v_self); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_19__float__, "\n           Convert a giac real to a Python <float>\n\n             >>> a=giac('pi/4.0')\n             >>> import math\n             >>> math.sin(a)    # doctest: +SKIP\n             0.70710678118654...\n             >>> a=giac(2)\n             >>> math.sqrt(a) == math.sqrt(2)\n             True\n\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_19__float__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_20__float__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__float__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_19__float__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_19__float__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__float__", 1);

  /* "giacpy/giacpy.pyx":1093
 *         # round with 14 digits should give type 1
 *         # but if it depends on the arch we add the type 3 test
 *         tmp=self.round(14).eval()             # <<<<<<<<<<<<<<
 *         if(tmp._type==1):
 *            return tmp._double
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_round); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_int_14};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1093, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_eval); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1093, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_tmp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1094
 *         # but if it depends on the arch we add the type 3 test
 *         tmp=self.round(14).eval()
 *         if(tmp._type==1):             # <<<<<<<<<<<<<<
 *            return tmp._double
 *         elif(tmp._type==3):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_type_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "giacpy/giacpy.pyx":1095
 *         tmp=self.round(14).eval()
 *         if(tmp._type==1):
 *            return tmp._double             # <<<<<<<<<<<<<<
 *         elif(tmp._type==3):
 *            return float(str(tmp))
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_double); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1094
 *         # but if it depends on the arch we add the type 3 test
 *         tmp=self.round(14).eval()
 *         if(tmp._type==1):             # <<<<<<<<<<<<<<
 *            return tmp._double
 *         elif(tmp._type==3):
 */
  }

  /* "giacpy/giacpy.pyx":1096
 *         if(tmp._type==1):
 *            return tmp._double
 *         elif(tmp._type==3):             # <<<<<<<<<<<<<<
 *            return float(str(tmp))
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_type_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_3, 3, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1096, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_6)) {

    /* "giacpy/giacpy.pyx":1097
 *            return tmp._double
 *         elif(tmp._type==3):
 *            return float(str(tmp))             # <<<<<<<<<<<<<<
 *         else:
 *            raise TypeError,"self is not a giac real"
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_Str(__pyx_v_tmp); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyNumber_Float(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1096
 *         if(tmp._type==1):
 *            return tmp._double
 *         elif(tmp._type==3):             # <<<<<<<<<<<<<<
 *            return float(str(tmp))
 *         else:
 */
  }

  /* "giacpy/giacpy.pyx":1099
 *            return float(str(tmp))
 *         else:
 *            raise TypeError,"self is not a giac real"             # <<<<<<<<<<<<<<
 * 
 *      def eval(self):
 */
  /*else*/ {
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_is_not_a_giac_real, 0, 0);
    __PYX_ERR(0, 1099, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1078
 *            raise TypeError,"self is not a giac integer"
 * 
 *      def __float__(self):             # <<<<<<<<<<<<<<
 *         """
 *            Convert a giac real to a Python <float>
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__float__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1101
 *            raise TypeError,"self is not a giac real"
 * 
 *      def eval(self):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         ressetctrl_c()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_22eval(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_22eval = {"eval", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_22eval, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_22eval(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eval (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("eval", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "eval", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_21eval(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_21eval(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("eval", 1);

  /* "giacpy/giacpy.pyx":1103
 *      def eval(self):
 *         cdef gen result
 *         ressetctrl_c()             # <<<<<<<<<<<<<<
 *         try:
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1103, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1104
 *         cdef gen result
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)
 *            return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1105
 *         ressetctrl_c()
 *         try:
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)             # <<<<<<<<<<<<<<
 *            return _wrap_gen(result)
 *         except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_giacsettings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1105, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_eval_level); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1105, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1105, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      try {
        __pyx_t_7 = protecteval((__pyx_v_self->gptr[0]), __pyx_t_6, __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1105, __pyx_L3_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1106
 *         try:
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)
 *            return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *         except:
 *            raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_5 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1106, __pyx_L3_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1106, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L7_try_return;

      /* "giacpy/giacpy.pyx":1104
 *         cdef gen result
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)
 *            return _wrap_gen(result)
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1107
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)
 *            return _wrap_gen(result)
 *         except:             # <<<<<<<<<<<<<<
 *            raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.eval", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_8) < 0) __PYX_ERR(0, 1107, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "giacpy/giacpy.pyx":1108
 *            return _wrap_gen(result)
 *         except:
 *            raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def threadeval(self,*args):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1108, __pyx_L5_except_error)
    }

    /* "giacpy/giacpy.pyx":1104
 *         cdef gen result
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *            result=GIAC_protecteval(self.gptr[0],giacsettings.eval_level,context_ptr)
 *            return _wrap_gen(result)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1101
 *            raise TypeError,"self is not a giac real"
 * 
 *      def eval(self):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         ressetctrl_c()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.eval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1110
 *            raise RuntimeError
 * 
 *      def threadeval(self,*args):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         cdef gen * param
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_24threadeval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_24threadeval = {"threadeval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_24threadeval, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_24threadeval(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("threadeval (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "threadeval", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_23threadeval(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_23threadeval(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_args) {
  giac::gen __pyx_v_result;
  giac::gen *__pyx_v_param;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_v_maxcount = NULL;
  Py_ssize_t __pyx_v_n;
  PyObject *__pyx_v_right = NULL;
  int __pyx_v_condi;
  int __pyx_v_cont;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  giac::gen __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("threadeval", 1);

  /* "giacpy/giacpy.pyx":1113
 *         cdef gen result
 *         cdef gen * param
 *         param=&result             # <<<<<<<<<<<<<<
 * 
 *         count=0
 */
  __pyx_v_param = (&__pyx_v_result);

  /* "giacpy/giacpy.pyx":1115
 *         param=&result
 * 
 *         count=0             # <<<<<<<<<<<<<<
 *         maxcount=1000000
 * 
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_count = __pyx_int_0;

  /* "giacpy/giacpy.pyx":1116
 * 
 *         count=0
 *         maxcount=1000000             # <<<<<<<<<<<<<<
 * 
 *         n=len(args)
 */
  __Pyx_INCREF(__pyx_int_1000000);
  __pyx_v_maxcount = __pyx_int_1000000;

  /* "giacpy/giacpy.pyx":1118
 *         maxcount=1000000
 * 
 *         n=len(args)             # <<<<<<<<<<<<<<
 *         if (n>1):
 *            right=Pygen(args).eval()
 */
  __pyx_t_1 = __Pyx_PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1118, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "giacpy/giacpy.pyx":1119
 * 
 *         n=len(args)
 *         if (n>1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args).eval()
 *         elif (n==1):
 */
  __pyx_t_2 = (__pyx_v_n > 1);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1120
 *         n=len(args)
 *         if (n>1):
 *            right=Pygen(args).eval()             # <<<<<<<<<<<<<<
 *         elif (n==1):
 *            right=Pygen(args[0])
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_eval); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_right = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1119
 * 
 *         n=len(args)
 *         if (n>1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args).eval()
 *         elif (n==1):
 */
    goto __pyx_L3;
  }

  /* "giacpy/giacpy.pyx":1121
 *         if (n>1):
 *            right=Pygen(args).eval()
 *         elif (n==1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args[0])
 * #        if isinstance(self,Pygen)==False:
 */
  __pyx_t_2 = (__pyx_v_n == 1);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1122
 *            right=Pygen(args).eval()
 *         elif (n==1):
 *            right=Pygen(args[0])             # <<<<<<<<<<<<<<
 * #        if isinstance(self,Pygen)==False:
 * #           self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_right = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1121
 *         if (n>1):
 *            right=Pygen(args).eval()
 *         elif (n==1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args[0])
 * #        if isinstance(self,Pygen)==False:
 */
  }
  __pyx_L3:;

  /* "giacpy/giacpy.pyx":1126
 * #           self=Pygen(self)
 * 
 *         ressetctrl_c()             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1126, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1128
 *         ressetctrl_c()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *            if(n>0):
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1129
 * 
 *         try:
 *            if(n>0):             # <<<<<<<<<<<<<<
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)
 *            else:
 */
      __pyx_t_2 = (__pyx_v_n > 0);
      if (__pyx_t_2) {

        /* "giacpy/giacpy.pyx":1130
 *         try:
 *            if(n>0):
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)             # <<<<<<<<<<<<<<
 *            else:
 *               condi=CASmakethread((<Pygen>self).gptr[0],giacsettings.eval_level,param,context_ptr)
 */
        if (unlikely(!__pyx_v_right)) { __Pyx_RaiseUnboundLocalError("right"); __PYX_ERR(0, 1130, __pyx_L4_error) }
        try {
          __pyx_t_10 = symb_of((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]));
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 1130, __pyx_L4_error)
        }
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_giacsettings); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1130, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_eval_level); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1130, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1130, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        try {
          __pyx_t_12 = makethread(__pyx_t_10, __pyx_t_11, __pyx_v_param, __pyx_v_6giacpy_6giacpy_context_ptr);
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 1130, __pyx_L4_error)
        }
        __pyx_v_condi = __pyx_t_12;

        /* "giacpy/giacpy.pyx":1129
 * 
 *         try:
 *            if(n>0):             # <<<<<<<<<<<<<<
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)
 *            else:
 */
        goto __pyx_L10;
      }

      /* "giacpy/giacpy.pyx":1132
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)
 *            else:
 *               condi=CASmakethread((<Pygen>self).gptr[0],giacsettings.eval_level,param,context_ptr)             # <<<<<<<<<<<<<<
 *            if( condi == 1):
 *               cont=True
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_giacsettings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1132, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_eval_level); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1132, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1132, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        try {
          __pyx_t_11 = makethread((__pyx_v_self->gptr[0]), __pyx_t_12, __pyx_v_param, __pyx_v_6giacpy_6giacpy_context_ptr);
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 1132, __pyx_L4_error)
        }
        __pyx_v_condi = __pyx_t_11;
      }
      __pyx_L10:;

      /* "giacpy/giacpy.pyx":1133
 *            else:
 *               condi=CASmakethread((<Pygen>self).gptr[0],giacsettings.eval_level,param,context_ptr)
 *            if( condi == 1):             # <<<<<<<<<<<<<<
 *               cont=True
 * 
 */
      __pyx_t_2 = (__pyx_v_condi == 1);
      if (likely(__pyx_t_2)) {

        /* "giacpy/giacpy.pyx":1134
 *               condi=CASmakethread((<Pygen>self).gptr[0],giacsettings.eval_level,param,context_ptr)
 *            if( condi == 1):
 *               cont=True             # <<<<<<<<<<<<<<
 * 
 *               while(cont):
 */
        __pyx_v_cont = 1;

        /* "giacpy/giacpy.pyx":1136
 *               cont=True
 * 
 *               while(cont):             # <<<<<<<<<<<<<<
 *                    if(CASmonitor(context_ptr) == 1):
 *                       if(count <maxcount):
 */
        while (1) {
          if (!__pyx_v_cont) break;

          /* "giacpy/giacpy.pyx":1137
 * 
 *               while(cont):
 *                    if(CASmonitor(context_ptr) == 1):             # <<<<<<<<<<<<<<
 *                       if(count <maxcount):
 *                          count=count+1
 */
          try {
            __pyx_t_11 = check_thread(__pyx_v_6giacpy_6giacpy_context_ptr);
          } catch(...) {
            __Pyx_CppExn2PyErr();
            __PYX_ERR(0, 1137, __pyx_L4_error)
          }
          __pyx_t_2 = (__pyx_t_11 == 1);
          if (__pyx_t_2) {

            /* "giacpy/giacpy.pyx":1138
 *               while(cont):
 *                    if(CASmonitor(context_ptr) == 1):
 *                       if(count <maxcount):             # <<<<<<<<<<<<<<
 *                          count=count+1
 * 
 */
            __pyx_t_5 = PyObject_RichCompare(__pyx_v_count, __pyx_v_maxcount, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1138, __pyx_L4_error)
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1138, __pyx_L4_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_2) {

              /* "giacpy/giacpy.pyx":1139
 *                    if(CASmonitor(context_ptr) == 1):
 *                       if(count <maxcount):
 *                          count=count+1             # <<<<<<<<<<<<<<
 * 
 *                       PyErr_CheckSignals()
 */
              __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_count, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1139, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF_SET(__pyx_v_count, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "giacpy/giacpy.pyx":1138
 *               while(cont):
 *                    if(CASmonitor(context_ptr) == 1):
 *                       if(count <maxcount):             # <<<<<<<<<<<<<<
 *                          count=count+1
 * 
 */
            }

            /* "giacpy/giacpy.pyx":1141
 *                          count=count+1
 * 
 *                       PyErr_CheckSignals()             # <<<<<<<<<<<<<<
 *                       if(testctrl_c()==1):
 *                          sleep(2) # try to wait if the thread stops alone
 */
            __pyx_t_11 = PyErr_CheckSignals(); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 1141, __pyx_L4_error)

            /* "giacpy/giacpy.pyx":1142
 * 
 *                       PyErr_CheckSignals()
 *                       if(testctrl_c()==1):             # <<<<<<<<<<<<<<
 *                          sleep(2) # try to wait if the thread stops alone
 *                          cont=False
 */
            try {
              __pyx_t_11 = testctrl_c();
            } catch(...) {
              __Pyx_CppExn2PyErr();
              __PYX_ERR(0, 1142, __pyx_L4_error)
            }
            __pyx_t_2 = (__pyx_t_11 == 1);
            if (__pyx_t_2) {

              /* "giacpy/giacpy.pyx":1143
 *                       PyErr_CheckSignals()
 *                       if(testctrl_c()==1):
 *                          sleep(2) # try to wait if the thread stops alone             # <<<<<<<<<<<<<<
 *                          cont=False
 *                          if(CASmonitor(context_ptr) == 1):
 */
              __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sleep); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1143, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_4 = NULL;
              __pyx_t_6 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_3, function);
                  __pyx_t_6 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_int_2};
                __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1143, __pyx_L4_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              }
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "giacpy/giacpy.pyx":1144
 *                       if(testctrl_c()==1):
 *                          sleep(2) # try to wait if the thread stops alone
 *                          cont=False             # <<<<<<<<<<<<<<
 *                          if(CASmonitor(context_ptr) == 1):
 *                             print("killing thread")
 */
              __pyx_v_cont = 0;

              /* "giacpy/giacpy.pyx":1145
 *                          sleep(2) # try to wait if the thread stops alone
 *                          cont=False
 *                          if(CASmonitor(context_ptr) == 1):             # <<<<<<<<<<<<<<
 *                             print("killing thread")
 *                             CASkillthread(context_ptr)
 */
              try {
                __pyx_t_11 = check_thread(__pyx_v_6giacpy_6giacpy_context_ptr);
              } catch(...) {
                __Pyx_CppExn2PyErr();
                __PYX_ERR(0, 1145, __pyx_L4_error)
              }
              __pyx_t_2 = (__pyx_t_11 == 1);
              if (unlikely(__pyx_t_2)) {

                /* "giacpy/giacpy.pyx":1146
 *                          cont=False
 *                          if(CASmonitor(context_ptr) == 1):
 *                             print("killing thread")             # <<<<<<<<<<<<<<
 *                             CASkillthread(context_ptr)
 *                             raise KeyboardInterrupt
 */
                __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1146, __pyx_L4_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                /* "giacpy/giacpy.pyx":1147
 *                          if(CASmonitor(context_ptr) == 1):
 *                             print("killing thread")
 *                             CASkillthread(context_ptr)             # <<<<<<<<<<<<<<
 *                             raise KeyboardInterrupt
 * 
 */
                try {
                  killthread(__pyx_v_6giacpy_6giacpy_context_ptr);
                } catch(...) {
                  __Pyx_CppExn2PyErr();
                  __PYX_ERR(0, 1147, __pyx_L4_error)
                }

                /* "giacpy/giacpy.pyx":1148
 *                             print("killing thread")
 *                             CASkillthread(context_ptr)
 *                             raise KeyboardInterrupt             # <<<<<<<<<<<<<<
 * 
 *                       if(count >= maxcount):
 */
                __Pyx_Raise(__pyx_builtin_KeyboardInterrupt, 0, 0, 0);
                __PYX_ERR(0, 1148, __pyx_L4_error)

                /* "giacpy/giacpy.pyx":1145
 *                          sleep(2) # try to wait if the thread stops alone
 *                          cont=False
 *                          if(CASmonitor(context_ptr) == 1):             # <<<<<<<<<<<<<<
 *                             print("killing thread")
 *                             CASkillthread(context_ptr)
 */
              }

              /* "giacpy/giacpy.pyx":1142
 * 
 *                       PyErr_CheckSignals()
 *                       if(testctrl_c()==1):             # <<<<<<<<<<<<<<
 *                          sleep(2) # try to wait if the thread stops alone
 *                          cont=False
 */
            }

            /* "giacpy/giacpy.pyx":1150
 *                             raise KeyboardInterrupt
 * 
 *                       if(count >= maxcount):             # <<<<<<<<<<<<<<
 *                          sleep(0.05)
 *                       if(count >= maxcount//100):
 */
            __pyx_t_5 = PyObject_RichCompare(__pyx_v_count, __pyx_v_maxcount, Py_GE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1150, __pyx_L4_error)
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1150, __pyx_L4_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_2) {

              /* "giacpy/giacpy.pyx":1151
 * 
 *                       if(count >= maxcount):
 *                          sleep(0.05)             # <<<<<<<<<<<<<<
 *                       if(count >= maxcount//100):
 *                          sleep(0.001)
 */
              __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_sleep); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1151, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_4 = NULL;
              __pyx_t_6 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_3, function);
                  __pyx_t_6 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_float_0_05};
                __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1151, __pyx_L4_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              }
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "giacpy/giacpy.pyx":1150
 *                             raise KeyboardInterrupt
 * 
 *                       if(count >= maxcount):             # <<<<<<<<<<<<<<
 *                          sleep(0.05)
 *                       if(count >= maxcount//100):
 */
            }

            /* "giacpy/giacpy.pyx":1152
 *                       if(count >= maxcount):
 *                          sleep(0.05)
 *                       if(count >= maxcount//100):             # <<<<<<<<<<<<<<
 *                          sleep(0.001)
 *                    else:
 */
            __pyx_t_5 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_maxcount, __pyx_int_100, 0x64, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1152, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_3 = PyObject_RichCompare(__pyx_v_count, __pyx_t_5, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1152, __pyx_L4_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1152, __pyx_L4_error)
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (__pyx_t_2) {

              /* "giacpy/giacpy.pyx":1153
 *                          sleep(0.05)
 *                       if(count >= maxcount//100):
 *                          sleep(0.001)             # <<<<<<<<<<<<<<
 *                    else:
 *                       cont=False
 */
              __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_sleep); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1153, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_4 = NULL;
              __pyx_t_6 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_5))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_5, function);
                  __pyx_t_6 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_float_0_001};
                __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1153, __pyx_L4_error)
                __Pyx_GOTREF(__pyx_t_3);
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              }
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

              /* "giacpy/giacpy.pyx":1152
 *                       if(count >= maxcount):
 *                          sleep(0.05)
 *                       if(count >= maxcount//100):             # <<<<<<<<<<<<<<
 *                          sleep(0.001)
 *                    else:
 */
            }

            /* "giacpy/giacpy.pyx":1137
 * 
 *               while(cont):
 *                    if(CASmonitor(context_ptr) == 1):             # <<<<<<<<<<<<<<
 *                       if(count <maxcount):
 *                          count=count+1
 */
            goto __pyx_L14;
          }

          /* "giacpy/giacpy.pyx":1155
 *                          sleep(0.001)
 *                    else:
 *                       cont=False             # <<<<<<<<<<<<<<
 * 
 *               result=param[0]
 */
          /*else*/ {
            __pyx_v_cont = 0;
          }
          __pyx_L14:;
        }

        /* "giacpy/giacpy.pyx":1157
 *                       cont=False
 * 
 *               result=param[0]             # <<<<<<<<<<<<<<
 *               return _wrap_gen(result)
 * 
 */
        __pyx_v_result = (__pyx_v_param[0]);

        /* "giacpy/giacpy.pyx":1158
 * 
 *               result=param[0]
 *               return _wrap_gen(result)             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        try {
          __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1158, __pyx_L4_error)
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 1158, __pyx_L4_error)
        }
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L8_try_return;

        /* "giacpy/giacpy.pyx":1133
 *            else:
 *               condi=CASmakethread((<Pygen>self).gptr[0],giacsettings.eval_level,param,context_ptr)
 *            if( condi == 1):             # <<<<<<<<<<<<<<
 *               cont=True
 * 
 */
      }

      /* "giacpy/giacpy.pyx":1162
 * 
 *            else:
 *               raise RuntimeError,"Failed to start a thread"             # <<<<<<<<<<<<<<
 *         except:
 *            setctrl_c()
 */
      /*else*/ {
        __Pyx_Raise(__pyx_builtin_RuntimeError, __pyx_kp_s_Failed_to_start_a_thread, 0, 0);
        __PYX_ERR(0, 1162, __pyx_L4_error)
      }

      /* "giacpy/giacpy.pyx":1128
 *         ressetctrl_c()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *            if(n>0):
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)
 */
    }
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1163
 *            else:
 *               raise RuntimeError,"Failed to start a thread"
 *         except:             # <<<<<<<<<<<<<<
 *            setctrl_c()
 *            print("trying soft interruption (wait 2s)")
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.threadeval", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 1163, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "giacpy/giacpy.pyx":1164
 *               raise RuntimeError,"Failed to start a thread"
 *         except:
 *            setctrl_c()             # <<<<<<<<<<<<<<
 *            print("trying soft interruption (wait 2s)")
 *            sleep(2)
 */
      try {
        setctrl_c();
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1164, __pyx_L6_except_error)
      }

      /* "giacpy/giacpy.pyx":1165
 *         except:
 *            setctrl_c()
 *            print("trying soft interruption (wait 2s)")             # <<<<<<<<<<<<<<
 *            sleep(2)
 *            print("cas monitor status:",CASmonitor(context_ptr))
 */
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1165, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "giacpy/giacpy.pyx":1166
 *            setctrl_c()
 *            print("trying soft interruption (wait 2s)")
 *            sleep(2)             # <<<<<<<<<<<<<<
 *            print("cas monitor status:",CASmonitor(context_ptr))
 *            if(CASmonitor(context_ptr) == 1):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_sleep); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1166, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_15 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_15)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_int_2};
        __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1166, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "giacpy/giacpy.pyx":1167
 *            print("trying soft interruption (wait 2s)")
 *            sleep(2)
 *            print("cas monitor status:",CASmonitor(context_ptr))             # <<<<<<<<<<<<<<
 *            if(CASmonitor(context_ptr) == 1):
 *               print("warning: Killing thread")
 */
      try {
        __pyx_t_11 = check_thread(__pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1167, __pyx_L6_except_error)
      }
      __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1167, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1167, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_INCREF(__pyx_kp_s_cas_monitor_status);
      __Pyx_GIVEREF(__pyx_kp_s_cas_monitor_status);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_kp_s_cas_monitor_status)) __PYX_ERR(0, 1167, __pyx_L6_except_error);
      __Pyx_GIVEREF(__pyx_t_13);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_13)) __PYX_ERR(0, 1167, __pyx_L6_except_error);
      __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_14, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1167, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "giacpy/giacpy.pyx":1168
 *            sleep(2)
 *            print("cas monitor status:",CASmonitor(context_ptr))
 *            if(CASmonitor(context_ptr) == 1):             # <<<<<<<<<<<<<<
 *               print("warning: Killing thread")
 *               CASkillthread(context_ptr)
 */
      try {
        __pyx_t_11 = check_thread(__pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1168, __pyx_L6_except_error)
      }
      __pyx_t_2 = (__pyx_t_11 == 1);
      if (__pyx_t_2) {

        /* "giacpy/giacpy.pyx":1169
 *            print("cas monitor status:",CASmonitor(context_ptr))
 *            if(CASmonitor(context_ptr) == 1):
 *               print("warning: Killing thread")             # <<<<<<<<<<<<<<
 *               CASkillthread(context_ptr)
 *               sleep(2)
 */
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1169, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "giacpy/giacpy.pyx":1170
 *            if(CASmonitor(context_ptr) == 1):
 *               print("warning: Killing thread")
 *               CASkillthread(context_ptr)             # <<<<<<<<<<<<<<
 *               sleep(2)
 *               print("cas monitor status after killing thread:",CASmonitor(context_ptr))
 */
        try {
          killthread(__pyx_v_6giacpy_6giacpy_context_ptr);
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 1170, __pyx_L6_except_error)
        }

        /* "giacpy/giacpy.pyx":1171
 *               print("warning: Killing thread")
 *               CASkillthread(context_ptr)
 *               sleep(2)             # <<<<<<<<<<<<<<
 *               print("cas monitor status after killing thread:",CASmonitor(context_ptr))
 *            raise RuntimeError
 */
        __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_sleep); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1171, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_15 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_14, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_int_2};
          __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1171, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        }
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "giacpy/giacpy.pyx":1172
 *               CASkillthread(context_ptr)
 *               sleep(2)
 *               print("cas monitor status after killing thread:",CASmonitor(context_ptr))             # <<<<<<<<<<<<<<
 *            raise RuntimeError
 * 
 */
        try {
          __pyx_t_11 = check_thread(__pyx_v_6giacpy_6giacpy_context_ptr);
        } catch(...) {
          __Pyx_CppExn2PyErr();
          __PYX_ERR(0, 1172, __pyx_L6_except_error)
        }
        __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1172, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1172, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_kp_s_cas_monitor_status_after_killing);
        __Pyx_GIVEREF(__pyx_kp_s_cas_monitor_status_after_killing);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_kp_s_cas_monitor_status_after_killing)) __PYX_ERR(0, 1172, __pyx_L6_except_error);
        __Pyx_GIVEREF(__pyx_t_13);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_13)) __PYX_ERR(0, 1172, __pyx_L6_except_error);
        __pyx_t_13 = 0;
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_14, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1172, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "giacpy/giacpy.pyx":1168
 *            sleep(2)
 *            print("cas monitor status:",CASmonitor(context_ptr))
 *            if(CASmonitor(context_ptr) == 1):             # <<<<<<<<<<<<<<
 *               print("warning: Killing thread")
 *               CASkillthread(context_ptr)
 */
      }

      /* "giacpy/giacpy.pyx":1173
 *               sleep(2)
 *               print("cas monitor status after killing thread:",CASmonitor(context_ptr))
 *            raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1173, __pyx_L6_except_error)
    }

    /* "giacpy/giacpy.pyx":1128
 *         ressetctrl_c()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *            if(n>0):
 *               condi=CASmakethread(GIAC_symbof((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),giacsettings.eval_level,param,context_ptr)
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L8_try_return:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1110
 *            raise RuntimeError
 * 
 *      def threadeval(self,*args):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         cdef gen * param
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.threadeval", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_maxcount);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1176
 * 
 * 
 *      def __add__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_26__add__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_26__add__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_25__add__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_25__add__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1178
 *      def __add__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          # Curiously this case is important:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1179
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          # Curiously this case is important:
 *          # otherwise: f=1/(2+sin(5*x)) crash
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1178
 *      def __add__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          # Curiously this case is important:
 */
  }

  /* "giacpy/giacpy.pyx":1182
 *          # Curiously this case is important:
 *          # otherwise: f=1/(2+sin(5*x)) crash
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1183
 *          # otherwise: f=1/(2+sin(5*x)) crash
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1182
 *          # Curiously this case is important:
 *          # otherwise: f=1/(2+sin(5*x)) crash
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1184
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1184, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1185
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1186
 *          ressetctrl_c()
 *          try:
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = ((__pyx_v_self->gptr[0]) + (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]));
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1186, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1187
 *          try:
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1187, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1187, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1185
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1188
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1188, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1189
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1189, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1185
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>self).gptr[0] + (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1176
 * 
 * 
 *      def __add__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1192
 * 
 * 
 *      def __radd__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_28__radd__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_27__radd__, "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 1+d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                1+d\n\n         ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_27__radd__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_28__radd__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_27__radd__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_27__radd__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__radd__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1202
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          # Curiously this case is important:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1203
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          # Curiously this case is important:
 *          # otherwise: f=1/(2+sin(5*x)) crash
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1202
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          # Curiously this case is important:
 */
  }

  /* "giacpy/giacpy.pyx":1206
 *          # Curiously this case is important:
 *          # otherwise: f=1/(2+sin(5*x)) crash
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1207
 *          # otherwise: f=1/(2+sin(5*x)) crash
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1206
 *          # Curiously this case is important:
 *          # otherwise: f=1/(2+sin(5*x)) crash
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1208
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1208, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1209
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1210
 *          ressetctrl_c()
 *          try:
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = ((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]) + (__pyx_v_self->gptr[0]));
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1210, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1211
 *          try:
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1211, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1211, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1209
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1212
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1212, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1213
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1213, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1209
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>right).gptr[0] + (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1192
 * 
 * 
 *      def __radd__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1216
 * 
 * 
 *      def __call__(self, *args):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          n=len(args)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_30__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_30__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__call__", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_29__call__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_29__call__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_args) {
  giac::gen __pyx_v_result;
  Py_ssize_t __pyx_v_n;
  PyObject *__pyx_v_right = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  giac::gen __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);

  /* "giacpy/giacpy.pyx":1218
 *      def __call__(self, *args):
 *          cdef gen result
 *          n=len(args)             # <<<<<<<<<<<<<<
 *          if (n>1):
 *            right=Pygen(args).eval()
 */
  __pyx_t_1 = __Pyx_PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1218, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "giacpy/giacpy.pyx":1219
 *          cdef gen result
 *          n=len(args)
 *          if (n>1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args).eval()
 *          elif (n==1):
 */
  __pyx_t_2 = (__pyx_v_n > 1);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1220
 *          n=len(args)
 *          if (n>1):
 *            right=Pygen(args).eval()             # <<<<<<<<<<<<<<
 *          elif (n==1):
 *            right=Pygen(args[0])
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_eval); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1220, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_right = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1219
 *          cdef gen result
 *          n=len(args)
 *          if (n>1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args).eval()
 *          elif (n==1):
 */
    goto __pyx_L3;
  }

  /* "giacpy/giacpy.pyx":1221
 *          if (n>1):
 *            right=Pygen(args).eval()
 *          elif (n==1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args[0])
 *          else:
 */
  __pyx_t_2 = (__pyx_v_n == 1);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1222
 *            right=Pygen(args).eval()
 *          elif (n==1):
 *            right=Pygen(args[0])             # <<<<<<<<<<<<<<
 *          else:
 *            right=GIACNULL
 */
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_args, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_right = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1221
 *          if (n>1):
 *            right=Pygen(args).eval()
 *          elif (n==1):             # <<<<<<<<<<<<<<
 *            right=Pygen(args[0])
 *          else:
 */
    goto __pyx_L3;
  }

  /* "giacpy/giacpy.pyx":1224
 *            right=Pygen(args[0])
 *          else:
 *            right=GIACNULL             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *            self=Pygen(self)
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_GIACNULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_right = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_L3:;

  /* "giacpy/giacpy.pyx":1225
 *          else:
 *            right=GIACNULL
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *            self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_7 = (__pyx_t_2 == 0);
  if (__pyx_t_7) {

    /* "giacpy/giacpy.pyx":1226
 *            right=GIACNULL
 *          if isinstance(self,Pygen)==False:
 *            self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          #try:
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1225
 *          else:
 *            right=GIACNULL
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *            self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1227
 *          if isinstance(self,Pygen)==False:
 *            self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          #try:
 *          result= ((<Pygen>self).gptr[0])((<Pygen>right).gptr[0],context_ptr)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1227, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1229
 *          ressetctrl_c()
 *          #try:
 *          result= ((<Pygen>self).gptr[0])((<Pygen>right).gptr[0],context_ptr)             # <<<<<<<<<<<<<<
 *          return _wrap_gen(result)
 *          #except:
 */
  try {
    __pyx_t_8 = (__pyx_v_self->gptr[0])((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1229, __pyx_L1_error)
  }
  __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_8);

  /* "giacpy/giacpy.pyx":1230
 *          #try:
 *          result= ((<Pygen>self).gptr[0])((<Pygen>right).gptr[0],context_ptr)
 *          return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          #except:
 *          #   raise RuntimeError
 */
  __Pyx_XDECREF(__pyx_r);
  try {
    __pyx_t_5 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1230, __pyx_L1_error)
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1230, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1216
 * 
 * 
 *      def __call__(self, *args):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          n=len(args)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1235
 * 
 * 
 *      def __sub__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_32__sub__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_32__sub__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sub__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_31__sub__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_31__sub__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__sub__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1237
 *      def __sub__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1238
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1237
 *      def __sub__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1239
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1240
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1239
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1241
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1241, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1242
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1243
 *          ressetctrl_c()
 *          try:
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = ((__pyx_v_self->gptr[0]) - (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]));
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1243, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1244
 *          try:
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1244, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1244, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1242
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1245
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1245, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1246
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __rsub__(self, right):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1246, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1242
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>self).gptr[0] - (<Pygen>right).gptr[0]
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1235
 * 
 * 
 *      def __sub__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1248
 *              raise RuntimeError
 * 
 *      def __rsub__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_34__rsub__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_33__rsub__, "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 2-d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                2-d\n\n         ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_33__rsub__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_34__rsub__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rsub__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_33__rsub__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_33__rsub__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rsub__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1258
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1259
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1258
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1260
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1261
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1260
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1262
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1262, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1263
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1264
 *          ressetctrl_c()
 *          try:
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = ((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]) - (__pyx_v_self->gptr[0]));
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1264, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1265
 *          try:
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1265, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1265, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1263
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1266
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1266, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1267
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __mul__(self, right):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1267, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1263
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= (<Pygen>right).gptr[0] - (<Pygen>self).gptr[0]
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1248
 *              raise RuntimeError
 * 
 *      def __rsub__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1269
 *              raise RuntimeError
 * 
 *      def __mul__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_36__mul__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_36__mul__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mul__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_35__mul__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_35__mul__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__mul__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1271
 *      def __mul__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1272
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1271
 *      def __mul__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1273
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1274
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1274, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1273
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1275
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              #result= (<Pygen>self).gptr[0] * (<Pygen>right).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1275, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1276
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] * (<Pygen>right).gptr[0]
 *              #NB: with the natural previous method, the following error generated by
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1281
 *              #giac causes python to quit instead of an error message.
 *              #l=Pygen([1,2]);l.transpose()*l;
 *              result= GIAC_giacmul((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0],context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacmul((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1281, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1282
 *              #l=Pygen([1,2]);l.transpose()*l;
 *              result= GIAC_giacmul((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0],context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1282, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1282, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1276
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] * (<Pygen>right).gptr[0]
 *              #NB: with the natural previous method, the following error generated by
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1283
 *              result= GIAC_giacmul((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1283, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1284
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __rmul__(self, right):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1284, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1276
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] * (<Pygen>right).gptr[0]
 *              #NB: with the natural previous method, the following error generated by
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1269
 *              raise RuntimeError
 * 
 *      def __mul__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1286
 *              raise RuntimeError
 * 
 *      def __rmul__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_38__rmul__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_37__rmul__, "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 7*d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                7*d\n\n         ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_37__rmul__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_38__rmul__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rmul__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_37__rmul__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_37__rmul__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rmul__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1296
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1297
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1296
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1298
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1299
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1298
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1300
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1300, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1301
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1302
 *          ressetctrl_c()
 *          try:
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacmul((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), (__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1302, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1303
 *          try:
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1303, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1303, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1301
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1304
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1304, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1305
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * #PB / in python3 is truediv
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1305, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1301
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_giacmul((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1286
 *              raise RuntimeError
 * 
 *      def __rmul__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1308
 * 
 * #PB / in python3 is truediv
 *      def __div__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

/* Python wrapper */
#if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_40__div__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_40__div__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__div__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_39__div__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
#endif /*!(#if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000))*/

#if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_39__div__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__div__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1310
 *      def __div__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1311
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1311, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1310
 *      def __div__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1312
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1313
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1312
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1314
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1314, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1315
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1317
 *          try:
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacdiv((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1317, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1318
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1318, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1318, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1315
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1319
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__div__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1319, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1320
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __truediv__(self, right):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1320, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1315
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1308
 * 
 * #PB / in python3 is truediv
 *      def __div__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__div__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
#endif /*!(#if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000))*/

/* "giacpy/giacpy.pyx":1322
 *              raise RuntimeError
 * 
 *      def __truediv__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_42__truediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_42__truediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__truediv__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_41__truediv__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_41__truediv__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__truediv__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1324
 *      def __truediv__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1325
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1324
 *      def __truediv__(self, right):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1326
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1327
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1326
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1328
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1328, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1329
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1331
 *          try:
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacdiv((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1331, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1332
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1332, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1332, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1329
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1333
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__truediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1333, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1334
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1334, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1329
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= (<Pygen>self).gptr[0] / (<Pygen>right).gptr[0]
 *              result= GIAC_giacdiv((<Pygen>self).gptr[0] , (<Pygen>right).gptr[0], context_ptr)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1322
 *              raise RuntimeError
 * 
 *      def __truediv__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__truediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1337
 * 
 * 
 *      def __rtruediv__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_44__rtruediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_43__rtruediv__, "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> 7/d   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                7/d\n\n         ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_43__rtruediv__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_44__rtruediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rtruediv__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_43__rtruediv__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_43__rtruediv__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rtruediv__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1347
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1348
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1347
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1349
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1350
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1349
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1351
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1351, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1352
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1353
 *          ressetctrl_c()
 *          try:
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacdiv((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), (__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1353, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1354
 *          try:
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1354, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1354, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1352
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1355
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rtruediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1355, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1356
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1356, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1352
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_giacdiv((<Pygen>right).gptr[0] , (<Pygen>self).gptr[0], context_ptr)
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1337
 * 
 * 
 *      def __rtruediv__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rtruediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1359
 * 
 * 
 *      def __pow__(self, right ,ignored):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_46__pow__(PyObject *__pyx_v_self, PyObject *__pyx_v_right, PyObject *__pyx_v_ignored); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_46__pow__(PyObject *__pyx_v_self, PyObject *__pyx_v_right, PyObject *__pyx_v_ignored) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pow__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_45__pow__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right), ((PyObject *)__pyx_v_ignored));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_45__pow__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right, CYTHON_UNUSED PyObject *__pyx_v_ignored) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pow__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1361
 *      def __pow__(self, right ,ignored):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1362
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1361
 *      def __pow__(self, right ,ignored):
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1363
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1364
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1363
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1365
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1365, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1366
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1367
 *          ressetctrl_c()
 *          try:
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = pow((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1367, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1368
 *          try:
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1368, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1368, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1366
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1369
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__pow__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1369, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1370
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __rpow__(self, right ,ignored):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1370, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1366
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_pow((<Pygen>self).gptr[0],(<Pygen>right).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1359
 * 
 * 
 *      def __pow__(self, right ,ignored):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__pow__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1372
 *              raise RuntimeError
 * 
 *      def __rpow__(self, right ,ignored):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_48__rpow__(PyObject *__pyx_v_self, PyObject *__pyx_v_right, PyObject *__pyx_v_ignored); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_47__rpow__, "\n            Reverse operator\n\n                >>> d=giac('d')\n                >>> (7**d)   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                7**d\n\n         ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_47__rpow__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_48__rpow__(PyObject *__pyx_v_self, PyObject *__pyx_v_right, PyObject *__pyx_v_ignored) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rpow__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_47__rpow__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right), ((PyObject *)__pyx_v_ignored));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_47__rpow__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right, CYTHON_UNUSED PyObject *__pyx_v_ignored) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rpow__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1382
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1383
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1382
 *          """
 *          cdef gen result
 *          if isinstance(right,Pygen)==False:             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1384
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1385
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1384
 *          if isinstance(right,Pygen)==False:
 *             right=Pygen(right)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1386
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1386, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1387
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1388
 *          ressetctrl_c()
 *          try:
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = pow((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), (__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1388, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1389
 *          try:
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1389, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1389, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1387
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1390
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rpow__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1390, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1391
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __mod__(self, right):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1391, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1387
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_pow((<Pygen>right).gptr[0],(<Pygen>self).gptr[0], context_ptr )
 *              return _wrap_gen(result)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1372
 *              raise RuntimeError
 * 
 *      def __rpow__(self, right ,ignored):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rpow__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1393
 *              raise RuntimeError
 * 
 *      def __mod__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if not isinstance(right,Pygen):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_50__mod__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_50__mod__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mod__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_49__mod__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_49__mod__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__mod__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1395
 *      def __mod__(self, right):
 *          cdef gen result
 *          if not isinstance(right,Pygen):             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1396
 *          cdef gen result
 *          if not isinstance(right,Pygen):
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if not isinstance(self,Pygen):
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1395
 *      def __mod__(self, right):
 *          cdef gen result
 *          if not isinstance(right,Pygen):             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):
 */
  }

  /* "giacpy/giacpy.pyx":1397
 *          if not isinstance(right,Pygen):
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (!__pyx_t_2);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1398
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1397
 *          if not isinstance(right,Pygen):
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1399
 *          if not isinstance(self,Pygen):
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              #result= gen(GIAC_makenewvecteur((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),<short int>1)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1399, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1400
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= gen(GIAC_makenewvecteur((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),<short int>1)
 *              #integer output:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1405
 *              #result= GIAC_smod(result,context_ptr)
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>self).gptr[0],(<Pygen>right).gptr[0],context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacmod((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1405, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1406
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>self).gptr[0],(<Pygen>right).gptr[0],context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1406, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1406, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1400
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= gen(GIAC_makenewvecteur((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),<short int>1)
 *              #integer output:
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1407
 *              result= GIAC_giacmod((<Pygen>self).gptr[0],(<Pygen>right).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__mod__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1407, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1408
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __rmod__(self, right):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1408, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1400
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #result= gen(GIAC_makenewvecteur((<Pygen>self).gptr[0],(<Pygen>right).gptr[0]),<short int>1)
 *              #integer output:
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1393
 *              raise RuntimeError
 * 
 *      def __mod__(self, right):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if not isinstance(right,Pygen):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__mod__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1410
 *              raise RuntimeError
 * 
 *      def __rmod__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_52__rmod__(PyObject *__pyx_v_self, PyObject *__pyx_v_right); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_51__rmod__, "\n            Reverse operator\n\n                >>> 7%giac(3)   # Called by Cython>3.0.0 when the type can't handle  the non reversed one\n                1 % 3\n\n         ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_51__rmod__;
#endif
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_52__rmod__(PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rmod__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_51__rmod__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_right));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_51__rmod__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_right) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rmod__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1419
 *          """
 *          cdef gen result
 *          if not isinstance(right,Pygen):             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_right, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1420
 *          cdef gen result
 *          if not isinstance(right,Pygen):
 *             right=Pygen(right)             # <<<<<<<<<<<<<<
 *          if not isinstance(self,Pygen):
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_right); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1419
 *          """
 *          cdef gen result
 *          if not isinstance(right,Pygen):             # <<<<<<<<<<<<<<
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):
 */
  }

  /* "giacpy/giacpy.pyx":1421
 *          if not isinstance(right,Pygen):
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (!__pyx_t_2);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1422
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1421
 *          if not isinstance(right,Pygen):
 *             right=Pygen(right)
 *          if not isinstance(self,Pygen):             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1423
 *          if not isinstance(self,Pygen):
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              #modular output:
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1423, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1424
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>right).gptr[0],(<Pygen>self).gptr[0],context_ptr)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1426
 *          try:
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>right).gptr[0],(<Pygen>self).gptr[0],context_ptr)             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = giacmod((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_right)->gptr[0]), (__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1426, __pyx_L5_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1427
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>right).gptr[0],(<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1427, __pyx_L5_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1427, __pyx_L5_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L9_try_return;

      /* "giacpy/giacpy.pyx":1424
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>right).gptr[0],(<Pygen>self).gptr[0],context_ptr)
 */
    }
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1428
 *              result= GIAC_giacmod((<Pygen>right).gptr[0],(<Pygen>self).gptr[0],context_ptr)
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rmod__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1428, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1429
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __neg__(self):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1429, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1424
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              #modular output:
 *              result= GIAC_giacmod((<Pygen>right).gptr[0],(<Pygen>self).gptr[0],context_ptr)
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1410
 *              raise RuntimeError
 * 
 *      def __rmod__(self, right):             # <<<<<<<<<<<<<<
 *          """
 *             Reverse operator
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__rmod__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1431
 *              raise RuntimeError
 * 
 *      def __neg__(self):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(self,Pygen)==False:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_54__neg__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_54__neg__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__neg__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_53__neg__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_53__neg__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  giac::gen __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__neg__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);

  /* "giacpy/giacpy.pyx":1433
 *      def __neg__(self):
 *          cdef gen result
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1434
 *          cdef gen result
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1434, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1433
 *      def __neg__(self):
 *          cdef gen result
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1435
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= GIAC_neg((<Pygen>self).gptr[0])
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1435, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1436
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_neg((<Pygen>self).gptr[0])
 *              return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1437
 *          ressetctrl_c()
 *          try:
 *              result= GIAC_neg((<Pygen>self).gptr[0])             # <<<<<<<<<<<<<<
 *              return _wrap_gen(result)
 *          except:
 */
      try {
        __pyx_t_7 = operator-((__pyx_v_self->gptr[0]));
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1437, __pyx_L4_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_7);

      /* "giacpy/giacpy.pyx":1438
 *          try:
 *              result= GIAC_neg((<Pygen>self).gptr[0])
 *              return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_3 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1438, __pyx_L4_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1438, __pyx_L4_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L8_try_return;

      /* "giacpy/giacpy.pyx":1436
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_neg((<Pygen>self).gptr[0])
 *              return _wrap_gen(result)
 */
    }
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1439
 *              result= GIAC_neg((<Pygen>self).gptr[0])
 *              return _wrap_gen(result)
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__neg__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1439, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1440
 *              return _wrap_gen(result)
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 *      def __pos__(self):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1440, __pyx_L6_except_error)
    }

    /* "giacpy/giacpy.pyx":1436
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= GIAC_neg((<Pygen>self).gptr[0])
 *              return _wrap_gen(result)
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L8_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1431
 *              raise RuntimeError
 * 
 *      def __neg__(self):             # <<<<<<<<<<<<<<
 *          cdef gen result
 *          if isinstance(self,Pygen)==False:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__neg__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1442
 *              raise RuntimeError
 * 
 *      def __pos__(self):             # <<<<<<<<<<<<<<
 *          return self
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_56__pos__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_56__pos__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pos__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_55__pos__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_55__pos__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pos__", 1);

  /* "giacpy/giacpy.pyx":1443
 * 
 *      def __pos__(self):
 *          return self             # <<<<<<<<<<<<<<
 * 
 *      # To be able to use the eval function before the GiacMethods initialisation
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1442
 *              raise RuntimeError
 * 
 *      def __pos__(self):             # <<<<<<<<<<<<<<
 *          return self
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1446
 * 
 *      # To be able to use the eval function before the GiacMethods initialisation
 *      def cas_setup(self,*args):             # <<<<<<<<<<<<<<
 *         return Pygen('cas_setup')(self,*args)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_58cas_setup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_58cas_setup = {"cas_setup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_58cas_setup, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_58cas_setup(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cas_setup (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cas_setup", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_57cas_setup(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_57cas_setup(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cas_setup", 1);

  /* "giacpy/giacpy.pyx":1447
 *      # To be able to use the eval function before the GiacMethods initialisation
 *      def cas_setup(self,*args):
 *         return Pygen('cas_setup')(self,*args)             # <<<<<<<<<<<<<<
 * 
 *      # ipython pretty printing
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(0, 1447, __pyx_L1_error);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1446
 * 
 *      # To be able to use the eval function before the GiacMethods initialisation
 *      def cas_setup(self,*args):             # <<<<<<<<<<<<<<
 *         return Pygen('cas_setup')(self,*args)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.cas_setup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1450
 * 
 *      # ipython pretty printing
 *      def _repr_latex_(self):             # <<<<<<<<<<<<<<
 *         # remove quotes
 *         #return str(self.latex())[1:-1]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_60_repr_latex_(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_60_repr_latex_ = {"_repr_latex_", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_60_repr_latex_, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_60_repr_latex_(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_latex_ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_repr_latex_", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_repr_latex_", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_59_repr_latex_(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_59_repr_latex_(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  std::string __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_repr_latex_", 1);

  /* "giacpy/giacpy.pyx":1454
 *         #return str(self.latex())[1:-1]
 *         # tester: a=ifactor(100) ; a._repr_latex_()
 *         return decstring23(GIAC_gen2tex(self.gptr[0], context_ptr).c_str()) #python3             # <<<<<<<<<<<<<<
 * 
 *      def _repr_html_(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  try {
    __pyx_t_3 = gen2tex((__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1454, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_t_3.c_str()); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1450
 * 
 *      # ipython pretty printing
 *      def _repr_latex_(self):             # <<<<<<<<<<<<<<
 *         # remove quotes
 *         #return str(self.latex())[1:-1]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen._repr_latex_", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1456
 *         return decstring23(GIAC_gen2tex(self.gptr[0], context_ptr).c_str()) #python3
 * 
 *      def _repr_html_(self):             # <<<<<<<<<<<<<<
 *         if self._type == 8:
 *            if self.sommet() == 'pnt':
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_62_repr_html_(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_62_repr_html_ = {"_repr_html_", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_62_repr_html_, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_62_repr_html_(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_html_ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_repr_html_", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_repr_html_", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_61_repr_html_(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_61_repr_html_(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  std::string __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_repr_html_", 1);

  /* "giacpy/giacpy.pyx":1457
 * 
 *      def _repr_html_(self):
 *         if self._type == 8:             # <<<<<<<<<<<<<<
 *            if self.sommet() == 'pnt':
 *               # no mathml output for graphics
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_type_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_8, 8, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1458
 *      def _repr_html_(self):
 *         if self._type == 8:
 *            if self.sommet() == 'pnt':             # <<<<<<<<<<<<<<
 *               # no mathml output for graphics
 *               return None
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sommet); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1458, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_pnt, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1458, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "giacpy/giacpy.pyx":1460
 *            if self.sommet() == 'pnt':
 *               # no mathml output for graphics
 *               return None             # <<<<<<<<<<<<<<
 *         # remove quotes
 *         #tmp = str(self.mathml())[1:-1]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "giacpy/giacpy.pyx":1458
 *      def _repr_html_(self):
 *         if self._type == 8:
 *            if self.sommet() == 'pnt':             # <<<<<<<<<<<<<<
 *               # no mathml output for graphics
 *               return None
 */
    }

    /* "giacpy/giacpy.pyx":1457
 * 
 *      def _repr_html_(self):
 *         if self._type == 8:             # <<<<<<<<<<<<<<
 *            if self.sommet() == 'pnt':
 *               # no mathml output for graphics
 */
  }

  /* "giacpy/giacpy.pyx":1466
 *         #tmp = tmp.replace('mode=""display"" xmlns=""http://www.w3.org/1998/Math/MathML""', 'display="block" xmlns="http://www.w3.org/1998/Math/MathML"')
 *         #return tmp
 *         return decstring23(GIAC_ingen2mathml(self.gptr[0],0, context_ptr).c_str()) #python3             # <<<<<<<<<<<<<<
 * 
 *      #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  try {
    __pyx_t_6 = ingen2mathml((__pyx_v_self->gptr[0]), __pyx_int_0, __pyx_v_6giacpy_6giacpy_context_ptr);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1466, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_t_6.c_str()); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1456
 *         return decstring23(GIAC_gen2tex(self.gptr[0], context_ptr).c_str()) #python3
 * 
 *      def _repr_html_(self):             # <<<<<<<<<<<<<<
 *         if self._type == 8:
 *            if self.sommet() == 'pnt':
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen._repr_html_", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1469
 * 
 *      #
 *      def save(self, str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Archive a Pygen element to a file in giac compressed format.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_64save(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_63save, "\n          Archive a Pygen element to a file in giac compressed format.\n\n          Use the loadgiacgen command to get back the Pygen from the file.\n\n          In C++ these files can be opened with giac::unarchive\n\n            >>> from giacpy import *\n            >>> f=giac('(x+y+z+2)**10'); g=f.normal()\n            >>> g.save(\"fichiertest\")           #  doctest: +SKIP\n            >>> a=loadgiacgen(\"fichiertest\")    #  doctest: +SKIP\n            >>> from tempfile import NamedTemporaryFile\n            >>> F=NamedTemporaryFile()   # chose a temporary file for a test\n            >>> Fname=F.name; F.close()  # so Fname can be our filename  \n            >>> g.save(Fname)\n            >>> a=loadgiacgen(Fname)\n            >>> a.factor()\n            (x+y+z+2)**10\n            >>> F.close()\n\n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_64save = {"save", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_64save, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_63save};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_64save(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_filename = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("save (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_filename,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_filename)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1469, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "save") < 0)) __PYX_ERR(0, 1469, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_filename = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("save", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1469, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.save", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_filename), (&PyString_Type), 1, "filename", 1))) __PYX_ERR(0, 1469, __pyx_L1_error)
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_63save(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_filename);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_63save(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_filename) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  std::string __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("save", 1);

  /* "giacpy/giacpy.pyx":1491
 * 
 *         """
 *         ressetctrl_c()             # <<<<<<<<<<<<<<
 *         try:
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1491, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1492
 *         """
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)
 *         except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1493
 *         ressetctrl_c()
 *         try:
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)             # <<<<<<<<<<<<<<
 *         except:
 *              raise RuntimeError
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_encstring23); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1493, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_filename};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1493, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_8 = __pyx_convert_string_from_py_6libcpp_6string_std__in_string(__pyx_t_4); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1493, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      try {
        archivegen(((std::string)__pyx_t_8), (__pyx_v_self->gptr[0]), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1493, __pyx_L3_error)
      }

      /* "giacpy/giacpy.pyx":1492
 *         """
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)
 *         except:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "giacpy/giacpy.pyx":1494
 *         try:
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)
 *         except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.save", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 1494, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "giacpy/giacpy.pyx":1495
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)
 *         except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1495, __pyx_L5_except_error)
    }

    /* "giacpy/giacpy.pyx":1492
 *         """
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *             GIAC_archive( <string>encstring23(filename), (<Pygen>self).gptr[0], context_ptr)
 *         except:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "giacpy/giacpy.pyx":1469
 * 
 *      #
 *      def save(self, str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Archive a Pygen element to a file in giac compressed format.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.save", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1498
 * 
 * 
 *      def htmlhelp(self, str lang='en'):             # <<<<<<<<<<<<<<
 *          """
 *          Open the giac  html  detailled help about self in an external  browser
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_66htmlhelp(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_65htmlhelp, "\n         Open the giac  html  detailled help about self in an external  browser\n\n         There are currently 3 supported languages: 'en', 'fr', 'el'\n\n          >>> from giacpy import gcd\n          >>> gcd.htmlhelp('fr')           # doctest: +SKIP\n\n         ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_66htmlhelp = {"htmlhelp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_66htmlhelp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_65htmlhelp};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_66htmlhelp(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lang = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("htmlhelp (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lang,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)__pyx_n_s_en));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lang);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1498, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "htmlhelp") < 0)) __PYX_ERR(0, 1498, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_lang = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("htmlhelp", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1498, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lang), (&PyString_Type), 1, "lang", 1))) __PYX_ERR(0, 1498, __pyx_L1_error)
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_65htmlhelp(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_lang);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_65htmlhelp(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_lang) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_giacbasedir = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  std::string __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  unsigned int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("htmlhelp", 0);
  __Pyx_INCREF(__pyx_v_lang);

  /* "giacpy/giacpy.pyx":1508
 * 
 *          """
 *          l={'fr':1 , 'en':2, 'el':4}             # <<<<<<<<<<<<<<
 *          if (not lang in ['en', 'fr', 'el']):
 *            lang='en'
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fr, __pyx_int_1) < 0) __PYX_ERR(0, 1508, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_en, __pyx_int_2) < 0) __PYX_ERR(0, 1508, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_el, __pyx_int_4) < 0) __PYX_ERR(0, 1508, __pyx_L1_error)
  __pyx_v_l = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1509
 *          """
 *          l={'fr':1 , 'en':2, 'el':4}
 *          if (not lang in ['en', 'fr', 'el']):             # <<<<<<<<<<<<<<
 *            lang='en'
 *          try:
 */
  __Pyx_INCREF(__pyx_v_lang);
  __pyx_t_2 = __pyx_v_lang;
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_en, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1509, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_fr, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1509, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_el, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1509, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_3;
  if (__pyx_t_4) {

    /* "giacpy/giacpy.pyx":1510
 *          l={'fr':1 , 'en':2, 'el':4}
 *          if (not lang in ['en', 'fr', 'el']):
 *            lang='en'             # <<<<<<<<<<<<<<
 *          try:
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3
 */
    __Pyx_INCREF(__pyx_n_s_en);
    __Pyx_DECREF_SET(__pyx_v_lang, __pyx_n_s_en);

    /* "giacpy/giacpy.pyx":1509
 *          """
 *          l={'fr':1 , 'en':2, 'el':4}
 *          if (not lang in ['en', 'fr', 'el']):             # <<<<<<<<<<<<<<
 *            lang='en'
 *          try:
 */
  }

  /* "giacpy/giacpy.pyx":1511
 *          if (not lang in ['en', 'fr', 'el']):
 *            lang='en'
 *          try:             # <<<<<<<<<<<<<<
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1512
 *            lang='en'
 *          try:
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3             # <<<<<<<<<<<<<<
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 *          except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1512, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_l, __pyx_v_lang); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1512, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_9); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1512, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      try {
        __pyx_t_11 = browser_help((__pyx_v_self->gptr[0]), __pyx_t_10);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1512, __pyx_L7_error)
      }
      __pyx_t_9 = __pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1512, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_12 = NULL;
      __pyx_t_13 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_13 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_9};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1512, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_v_url = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "giacpy/giacpy.pyx":1513
 *          try:
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3             # <<<<<<<<<<<<<<
 *          except:
 *            raise RuntimeError,'giac docs dir not found'
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1513, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_8);
      try {
        __pyx_t_11 = giac_aide_dir();
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1513, __pyx_L7_error)
      }
      __pyx_t_9 = __pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1513, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_12 = NULL;
      __pyx_t_13 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_13 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_9};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1513, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_v_giacbasedir = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "giacpy/giacpy.pyx":1511
 *          if (not lang in ['en', 'fr', 'el']):
 *            lang='en'
 *          try:             # <<<<<<<<<<<<<<
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L12_try_end;
    __pyx_L7_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "giacpy/giacpy.pyx":1514
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 *          except:             # <<<<<<<<<<<<<<
 *            raise RuntimeError,'giac docs dir not found'
 *          print(url)
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1514, __pyx_L9_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);

      /* "giacpy/giacpy.pyx":1515
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 *          except:
 *            raise RuntimeError,'giac docs dir not found'             # <<<<<<<<<<<<<<
 *          print(url)
 *          if os.access(giacbasedir,os.F_OK):
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, __pyx_kp_s_giac_docs_dir_not_found, 0, 0);
      __PYX_ERR(0, 1515, __pyx_L9_except_error)
    }

    /* "giacpy/giacpy.pyx":1511
 *          if (not lang in ['en', 'fr', 'el']):
 *            lang='en'
 *          try:             # <<<<<<<<<<<<<<
 *            url=decstring23(browser_help(self.gptr[0],l[lang])) #python3
 *            giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 */
    __pyx_L9_except_error:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L12_try_end:;
  }

  /* "giacpy/giacpy.pyx":1516
 *          except:
 *            raise RuntimeError,'giac docs dir not found'
 *          print(url)             # <<<<<<<<<<<<<<
 *          if os.access(giacbasedir,os.F_OK):
 *             url='file:'+url
 */
  __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_url); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "giacpy/giacpy.pyx":1517
 *            raise RuntimeError,'giac docs dir not found'
 *          print(url)
 *          if os.access(giacbasedir,os.F_OK):             # <<<<<<<<<<<<<<
 *             url='file:'+url
 *             wwwbrowseropen(url)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_os); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_access); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_os); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_F_OK); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_13 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_13 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_giacbasedir, __pyx_t_12};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_13, 2+__pyx_t_13);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__pyx_t_4) {

    /* "giacpy/giacpy.pyx":1518
 *          print(url)
 *          if os.access(giacbasedir,os.F_OK):
 *             url='file:'+url             # <<<<<<<<<<<<<<
 *             wwwbrowseropen(url)
 * 
 */
    __pyx_t_9 = PyNumber_Add(__pyx_kp_s_file, __pyx_v_url); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF_SET(__pyx_v_url, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "giacpy/giacpy.pyx":1519
 *          if os.access(giacbasedir,os.F_OK):
 *             url='file:'+url
 *             wwwbrowseropen(url)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_wwwbrowseropen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = NULL;
    __pyx_t_13 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_13 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_url};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "giacpy/giacpy.pyx":1517
 *            raise RuntimeError,'giac docs dir not found'
 *          print(url)
 *          if os.access(giacbasedir,os.F_OK):             # <<<<<<<<<<<<<<
 *             url='file:'+url
 *             wwwbrowseropen(url)
 */
  }

  /* "giacpy/giacpy.pyx":1498
 * 
 * 
 *      def htmlhelp(self, str lang='en'):             # <<<<<<<<<<<<<<
 *          """
 *          Open the giac  html  detailled help about self in an external  browser
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_giacbasedir);
  __Pyx_XDECREF(__pyx_v_lang);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1523
 * 
 * 
 *      def help(self):             # <<<<<<<<<<<<<<
 *         return self.findhelp()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_68help(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_68help = {"help", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_68help, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_68help(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("help (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("help", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "help", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_67help(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_67help(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("help", 1);

  /* "giacpy/giacpy.pyx":1524
 * 
 *      def help(self):
 *         return self.findhelp()             # <<<<<<<<<<<<<<
 * 
 *      def redim(self,a,b=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_findhelp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1523
 * 
 * 
 *      def help(self):             # <<<<<<<<<<<<<<
 *         return self.findhelp()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.help", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1526
 *         return self.findhelp()
 * 
 *      def redim(self,a,b=None):             # <<<<<<<<<<<<<<
 *         """
 *         * Increase the size of a matrix when possible, otherwise return self.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_70redim(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_69redim, "\n        * Increase the size of a matrix when possible, otherwise return self.\n\n        >>> C=giac([[1,2]])\n        >>> C.redim(2,3)\n        [[1,2,0],[0,0,0]]\n        >>> C.redim(2,1)\n        [[1,2]]\n\n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_70redim = {"redim", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_70redim, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_69redim};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_70redim(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("redim (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1526, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1526, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "redim") < 0)) __PYX_ERR(0, 1526, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("redim", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1526, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.redim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_69redim(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_a, __pyx_v_b);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_69redim(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_v_A = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("redim", 1);

  /* "giacpy/giacpy.pyx":1537
 * 
 *         """
 *         d=self.dim()             # <<<<<<<<<<<<<<
 *         if d.type()==7:
 *            if(a>d[0] and b>=d[1]):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_dim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_d = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1538
 *         """
 *         d=self.dim()
 *         if d.type()==7:             # <<<<<<<<<<<<<<
 *            if(a>d[0] and b>=d[1]):
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_7, 7, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_5)) {

    /* "giacpy/giacpy.pyx":1539
 *         d=self.dim()
 *         if d.type()==7:
 *            if(a>d[0] and b>=d[1]):             # <<<<<<<<<<<<<<
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 *                if(b>d[1]):
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_d, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_a, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_b, __pyx_t_2, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_5) {

      /* "giacpy/giacpy.pyx":1540
 *         if d.type()==7:
 *            if(a>d[0] and b>=d[1]):
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())             # <<<<<<<<<<<<<<
 *                if(b>d[1]):
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_semi_augment); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_d, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyNumber_Subtract(__pyx_v_a, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8)) __PYX_ERR(0, 1540, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_7);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_7)) __PYX_ERR(0, 1540, __pyx_L1_error);
      __pyx_t_8 = 0;
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_matrix); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_t_9 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_A = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "giacpy/giacpy.pyx":1541
 *            if(a>d[0] and b>=d[1]):
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 *                if(b>d[1]):             # <<<<<<<<<<<<<<
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())
 *                return A
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_b, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1541, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1541, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_5) {

        /* "giacpy/giacpy.pyx":1542
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 *                if(b>d[1]):
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())             # <<<<<<<<<<<<<<
 *                return A
 *            elif(b>d[1] and a==d[0]):
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_A, __pyx_n_s_augment); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_7 = PyNumber_Subtract(__pyx_v_b, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_a);
        __Pyx_GIVEREF(__pyx_v_a);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_a)) __PYX_ERR(0, 1542, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_7);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_7)) __PYX_ERR(0, 1542, __pyx_L1_error);
        __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_matrix); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1542, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_t_9 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1542, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF_SET(__pyx_v_A, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "giacpy/giacpy.pyx":1541
 *            if(a>d[0] and b>=d[1]):
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 *                if(b>d[1]):             # <<<<<<<<<<<<<<
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())
 *                return A
 */
      }

      /* "giacpy/giacpy.pyx":1543
 *                if(b>d[1]):
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())
 *                return A             # <<<<<<<<<<<<<<
 *            elif(b>d[1] and a==d[0]):
 *                return self.augment(Pygen((d[0],b-d[1])).matrix())
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_A);
      __pyx_r = __pyx_v_A;
      goto __pyx_L0;

      /* "giacpy/giacpy.pyx":1539
 *         d=self.dim()
 *         if d.type()==7:
 *            if(a>d[0] and b>=d[1]):             # <<<<<<<<<<<<<<
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 *                if(b>d[1]):
 */
    }

    /* "giacpy/giacpy.pyx":1544
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())
 *                return A
 *            elif(b>d[1] and a==d[0]):             # <<<<<<<<<<<<<<
 *                return self.augment(Pygen((d[0],b-d[1])).matrix())
 *            else:
 */
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_b, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_d, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_a, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = __pyx_t_6;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_5) {

      /* "giacpy/giacpy.pyx":1545
 *                return A
 *            elif(b>d[1] and a==d[0]):
 *                return self.augment(Pygen((d[0],b-d[1])).matrix())             # <<<<<<<<<<<<<<
 *            else:
 *               return self
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_augment); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_d, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_d, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyNumber_Subtract(__pyx_v_b, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_9);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9)) __PYX_ERR(0, 1545, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_8)) __PYX_ERR(0, 1545, __pyx_L1_error);
      __pyx_t_9 = 0;
      __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_matrix); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1545, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1545, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "giacpy/giacpy.pyx":1544
 *                    A=A.augment(Pygen((a,b-d[1])).matrix())
 *                return A
 *            elif(b>d[1] and a==d[0]):             # <<<<<<<<<<<<<<
 *                return self.augment(Pygen((d[0],b-d[1])).matrix())
 *            else:
 */
    }

    /* "giacpy/giacpy.pyx":1547
 *                return self.augment(Pygen((d[0],b-d[1])).matrix())
 *            else:
 *               return self             # <<<<<<<<<<<<<<
 *         else:
 *            raise TypeError, "self is not a giac List"
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF((PyObject *)__pyx_v_self);
      __pyx_r = ((PyObject *)__pyx_v_self);
      goto __pyx_L0;
    }

    /* "giacpy/giacpy.pyx":1538
 *         """
 *         d=self.dim()
 *         if d.type()==7:             # <<<<<<<<<<<<<<
 *            if(a>d[0] and b>=d[1]):
 *                A=self.semi_augment(Pygen((a-d[0],d[1])).matrix())
 */
  }

  /* "giacpy/giacpy.pyx":1549
 *               return self
 *         else:
 *            raise TypeError, "self is not a giac List"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_is_not_a_giac_List, 0, 0);
    __PYX_ERR(0, 1549, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1526
 *         return self.findhelp()
 * 
 *      def redim(self,a,b=None):             # <<<<<<<<<<<<<<
 *         """
 *         * Increase the size of a matrix when possible, otherwise return self.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.redim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_A);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1552
 * 
 * 
 *      def qcas(self,s=None):             # <<<<<<<<<<<<<<
 *        """
 *        * Send a giac graphic to qcas. (3D is currently not supported in qcas)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_72qcas(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_5Pygen_71qcas, "\n       * Send a giac graphic to qcas. (3D is currently not supported in qcas)\n\n        >>> d1=giac('plot(x*sin(x))')\n        >>> d1.qcas()    # doctest: +SKIP\n        >>> l=giac([(d1.homothety(0,t*0.1)).color(t) for t in range(10)])\n        >>> l.qcas()     # doctest: +SKIP\n\n       ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_72qcas = {"qcas", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_72qcas, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_71qcas};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_72qcas(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("qcas (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1552, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "qcas") < 0)) __PYX_ERR(0, 1552, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("qcas", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1552, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.qcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_71qcas(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_71qcas(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_v_toqcas = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("qcas", 1);

  /* "giacpy/giacpy.pyx":1562
 * 
 *        """
 *        ressetctrl_c()             # <<<<<<<<<<<<<<
 *        try:
 *           from giacpy2qcas import toqcas
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1562, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1563
 *        """
 *        ressetctrl_c()
 *        try:             # <<<<<<<<<<<<<<
 *           from giacpy2qcas import toqcas
 *           toqcas(self,s)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1564
 *        ressetctrl_c()
 *        try:
 *           from giacpy2qcas import toqcas             # <<<<<<<<<<<<<<
 *           toqcas(self,s)
 *        except:
 */
      __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_n_s_toqcas);
      __Pyx_GIVEREF(__pyx_n_s_toqcas);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_toqcas)) __PYX_ERR(0, 1564, __pyx_L3_error);
      __pyx_t_5 = __Pyx_Import(__pyx_n_s_giacpy2qcas, __pyx_t_4, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_5, __pyx_n_s_toqcas); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_toqcas = __pyx_t_4;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "giacpy/giacpy.pyx":1565
 *        try:
 *           from giacpy2qcas import toqcas
 *           toqcas(self,s)             # <<<<<<<<<<<<<<
 *        except:
 *           raise RuntimeError
 */
      __Pyx_INCREF(__pyx_v_toqcas);
      __pyx_t_4 = __pyx_v_toqcas; __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), __pyx_v_s};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1565, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "giacpy/giacpy.pyx":1563
 *        """
 *        ressetctrl_c()
 *        try:             # <<<<<<<<<<<<<<
 *           from giacpy2qcas import toqcas
 *           toqcas(self,s)
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "giacpy/giacpy.pyx":1566
 *           from giacpy2qcas import toqcas
 *           toqcas(self,s)
 *        except:             # <<<<<<<<<<<<<<
 *           raise RuntimeError
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.qcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_6) < 0) __PYX_ERR(0, 1566, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "giacpy/giacpy.pyx":1567
 *           toqcas(self,s)
 *        except:
 *           raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1567, __pyx_L5_except_error)
    }

    /* "giacpy/giacpy.pyx":1563
 *        """
 *        ressetctrl_c()
 *        try:             # <<<<<<<<<<<<<<
 *           from giacpy2qcas import toqcas
 *           toqcas(self,s)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "giacpy/giacpy.pyx":1552
 * 
 * 
 *      def qcas(self,s=None):             # <<<<<<<<<<<<<<
 *        """
 *        * Send a giac graphic to qcas. (3D is currently not supported in qcas)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.qcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_toqcas);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1579
 *      # # # # # # # # # # # # # # # # # # # # # # # # #
 * 
 *      def __richcmp__( self, other,op):             # <<<<<<<<<<<<<<
 *          if isinstance(other,Pygen)==False:
 *             other=Pygen(other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_74__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_74__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_arg_op) {
  PyObject *__pyx_v_op = 0;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__richcmp__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_v_op = __Pyx_PyInt_From_int(__pyx_arg_op); if (unlikely(!__pyx_v_op)) __PYX_ERR(0, 1579, __pyx_L3_error)
  __Pyx_GOTREF(__pyx_v_op);
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_73__richcmp__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), ((PyObject *)__pyx_v_other), ((PyObject *)__pyx_v_op));

  /* function exit code */
  __Pyx_DECREF(__pyx_v_op);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_73__richcmp__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_op) {
  int __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__richcmp__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_v_other);

  /* "giacpy/giacpy.pyx":1580
 * 
 *      def __richcmp__( self, other,op):
 *          if isinstance(other,Pygen)==False:             # <<<<<<<<<<<<<<
 *             other=Pygen(other)
 *          if isinstance(self,Pygen)==False:
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1581
 *      def __richcmp__( self, other,op):
 *          if isinstance(other,Pygen)==False:
 *             other=Pygen(other)             # <<<<<<<<<<<<<<
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_other); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1580
 * 
 *      def __richcmp__( self, other,op):
 *          if isinstance(other,Pygen)==False:             # <<<<<<<<<<<<<<
 *             other=Pygen(other)
 *          if isinstance(self,Pygen)==False:
 */
  }

  /* "giacpy/giacpy.pyx":1582
 *          if isinstance(other,Pygen)==False:
 *             other=Pygen(other)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6giacpy_6giacpy_Pygen); 
  __pyx_t_1 = (__pyx_t_2 == 0);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1583
 *             other=Pygen(other)
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)             # <<<<<<<<<<<<<<
 *          ressetctrl_c()
 *          try:
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_self, ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1582
 *          if isinstance(other,Pygen)==False:
 *             other=Pygen(other)
 *          if isinstance(self,Pygen)==False:             # <<<<<<<<<<<<<<
 *             self=Pygen(self)
 *          ressetctrl_c()
 */
  }

  /* "giacpy/giacpy.pyx":1584
 *          if isinstance(self,Pygen)==False:
 *             self=Pygen(self)
 *          ressetctrl_c()             # <<<<<<<<<<<<<<
 *          try:
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1584, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1585
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )
 *          except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1586
 *          ressetctrl_c()
 *          try:
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )             # <<<<<<<<<<<<<<
 *          except:
 *              raise RuntimeError
 */
      __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_v_op); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1586, __pyx_L5_error)
      try {
        __pyx_t_8 = giacgenrichcmp((__pyx_v_self->gptr[0]), (((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_other)->gptr[0]), __pyx_t_7, __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1586, __pyx_L5_error)
      }
      __pyx_v_result = __pyx_t_8;

      /* "giacpy/giacpy.pyx":1585
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )
 *          except:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":1587
 *          try:
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )
 *          except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 *          if result==1 :
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.Pygen.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_9, &__pyx_t_10) < 0) __PYX_ERR(0, 1587, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);

      /* "giacpy/giacpy.pyx":1588
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )
 *          except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 *          if result==1 :
 *              return True
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 1588, __pyx_L7_except_error)
    }

    /* "giacpy/giacpy.pyx":1585
 *             self=Pygen(self)
 *          ressetctrl_c()
 *          try:             # <<<<<<<<<<<<<<
 *              result= giacgenrichcmp((<Pygen>self).gptr[0],(<Pygen>other).gptr[0], op, context_ptr )
 *          except:
 */
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L10_try_end:;
  }

  /* "giacpy/giacpy.pyx":1589
 *          except:
 *              raise RuntimeError
 *          if result==1 :             # <<<<<<<<<<<<<<
 *              return True
 *          else:
 */
  __pyx_t_1 = (__pyx_v_result == 1);
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1590
 *              raise RuntimeError
 *          if result==1 :
 *              return True             # <<<<<<<<<<<<<<
 *          else:
 *              return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1589
 *          except:
 *              raise RuntimeError
 *          if result==1 :             # <<<<<<<<<<<<<<
 *              return True
 *          else:
 */
  }

  /* "giacpy/giacpy.pyx":1592
 *              return True
 *          else:
 *              return False             # <<<<<<<<<<<<<<
 * 
 *      #
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":1579
 *      # # # # # # # # # # # # # # # # # # # # # # # # #
 * 
 *      def __richcmp__( self, other,op):             # <<<<<<<<<<<<<<
 *          if isinstance(other,Pygen)==False:
 *             other=Pygen(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1598
 *      #
 *      property _type:
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr.type
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_5_type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_5_type_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_5_type___get__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_5_type___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":1600
 *          def __get__(self):
 *            #if (self.gptr != NULL):
 *              return self.gptr.type             # <<<<<<<<<<<<<<
 *            #else:
 *            #  raise MemoryError,"This Pygen is not associated to a giac gen"
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_unsigned_char(__pyx_v_self->gptr->type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1598
 *      #
 *      property _type:
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr.type
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen._type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1606
 * 
 *      property _subtype:
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr.subtype
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_8_subtype_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_8_subtype_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_8_subtype___get__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_8_subtype___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":1608
 *          def __get__(self):
 *            #if (self.gptr != NULL):
 *              return self.gptr.subtype             # <<<<<<<<<<<<<<
 *            #else:
 *            #  raise MemoryError,"This Pygen is not associated to a giac gen"
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_signed_char(__pyx_v_self->gptr->subtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1606
 * 
 *      property _subtype:
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr.subtype
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen._subtype.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1617
 *          immediate int value of an _INT_ type gen.
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr.val
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_4_val_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_4_val_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_4_val___get__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_4_val___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":1619
 *          def __get__(self):
 *            #if (self.gptr != NULL):
 *              return self.gptr.val             # <<<<<<<<<<<<<<
 *            #else:
 *            #  raise MemoryError,"This Pygen is not associated to a giac gen"
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->gptr->val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1617
 *          immediate int value of an _INT_ type gen.
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr.val
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen._val.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1628
 *          immediate conversion to float for a gen of _DOUBLE_ type.
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr._DOUBLE_val
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_7_double_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_7_double_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_7_double___get__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_7_double___get__(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "giacpy/giacpy.pyx":1630
 *          def __get__(self):
 *            #if (self.gptr != NULL):
 *              return self.gptr._DOUBLE_val             # <<<<<<<<<<<<<<
 *            #else:
 *            #  raise MemoryError,"This Pygen is not associated to a giac gen."
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->gptr->_DOUBLE_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1628
 *          immediate conversion to float for a gen of _DOUBLE_ type.
 *          """
 *          def __get__(self):             # <<<<<<<<<<<<<<
 *            #if (self.gptr != NULL):
 *              return self.gptr._DOUBLE_val
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.Pygen._double.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_76__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_76__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_76__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_76__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_75__reduce_cython__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_75__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_78__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_5Pygen_78__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_78__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_5Pygen_78__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_5Pygen_77__setstate_cython__(((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_5Pygen_77__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("giacpy.giacpy.Pygen.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1662
 * #   the Python object                                          #
 * ################################################################
 * cdef inline _wrap_gen(gen  g)except +:             # <<<<<<<<<<<<<<
 * 
 * #   cdef Pygen pyg=Pygen('NULL')
 */

static CYTHON_INLINE PyObject *__pyx_f_6giacpy_6giacpy__wrap_gen(giac::gen __pyx_v_g) {
  struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_pyg = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  giac::gen *__pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_wrap_gen", 1);

  /* "giacpy/giacpy.pyx":1681
 * # But beware when changing the None case in  Pygen init.
 * #
 *     cdef Pygen pyg=Pygen() # NB: for stability reasons it creates a full Pygen             # <<<<<<<<<<<<<<
 *     del pyg.gptr # so we have to free its gptr here to avoid a memory leak.
 *     pyg.gptr=new gen(g)
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pyg = ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1682
 * #
 *     cdef Pygen pyg=Pygen() # NB: for stability reasons it creates a full Pygen
 *     del pyg.gptr # so we have to free its gptr here to avoid a memory leak.             # <<<<<<<<<<<<<<
 *     pyg.gptr=new gen(g)
 *     return pyg
 */
  delete __pyx_v_pyg->gptr;

  /* "giacpy/giacpy.pyx":1683
 *     cdef Pygen pyg=Pygen() # NB: for stability reasons it creates a full Pygen
 *     del pyg.gptr # so we have to free its gptr here to avoid a memory leak.
 *     pyg.gptr=new gen(g)             # <<<<<<<<<<<<<<
 *     return pyg
 * #    if(pyg.gptr !=NULL):
 */
  try {
    __pyx_t_2 = new giac::gen(__pyx_v_g);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1683, __pyx_L1_error)
  }
  __pyx_v_pyg->gptr = __pyx_t_2;

  /* "giacpy/giacpy.pyx":1684
 *     del pyg.gptr # so we have to free its gptr here to avoid a memory leak.
 *     pyg.gptr=new gen(g)
 *     return pyg             # <<<<<<<<<<<<<<
 * #    if(pyg.gptr !=NULL):
 * #      return pyg
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_pyg);
  __pyx_r = ((PyObject *)__pyx_v_pyg);
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1662
 * #   the Python object                                          #
 * ################################################################
 * cdef inline _wrap_gen(gen  g)except +:             # <<<<<<<<<<<<<<
 * 
 * #   cdef Pygen pyg=Pygen('NULL')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy._wrap_gen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pyg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1699
 * ################################################################
 * 
 * cdef  vecteur _wrap_pylist(L) except +:             # <<<<<<<<<<<<<<
 *    cdef Pygen pyg=Pygen()
 *    cdef vecteur  * V
 */

static giac::vecteur __pyx_f_6giacpy_6giacpy__wrap_pylist(PyObject *__pyx_v_L) {
  CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_pyg = 0;
  giac::vecteur *__pyx_v_V;
  int __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  giac::vecteur __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_wrap_pylist", 1);

  /* "giacpy/giacpy.pyx":1700
 * 
 * cdef  vecteur _wrap_pylist(L) except +:
 *    cdef Pygen pyg=Pygen()             # <<<<<<<<<<<<<<
 *    cdef vecteur  * V
 *    cdef int i
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pyg = ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1704
 *    cdef int i
 * 
 *    if (isinstance(L,tuple) or isinstance(L,listrange)):             # <<<<<<<<<<<<<<
 *       n=len(L)
 *       V=new vecteur()
 */
  __pyx_t_3 = PyTuple_Check(__pyx_v_L); 
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_listrange); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_L, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 1704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (likely(__pyx_t_2)) {

    /* "giacpy/giacpy.pyx":1705
 * 
 *    if (isinstance(L,tuple) or isinstance(L,listrange)):
 *       n=len(L)             # <<<<<<<<<<<<<<
 *       V=new vecteur()
 *       ressetctrl_c()
 */
    __pyx_t_4 = PyObject_Length(__pyx_v_L); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1705, __pyx_L1_error)
    __pyx_v_n = __pyx_t_4;

    /* "giacpy/giacpy.pyx":1706
 *    if (isinstance(L,tuple) or isinstance(L,listrange)):
 *       n=len(L)
 *       V=new vecteur()             # <<<<<<<<<<<<<<
 *       ressetctrl_c()
 * #      sig_on()
 */
    __pyx_v_V = new giac::vecteur();

    /* "giacpy/giacpy.pyx":1707
 *       n=len(L)
 *       V=new vecteur()
 *       ressetctrl_c()             # <<<<<<<<<<<<<<
 * #      sig_on()
 *       for i in range(n):
 */
    try {
      ressetctrl_c();
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1707, __pyx_L1_error)
    }

    /* "giacpy/giacpy.pyx":1709
 *       ressetctrl_c()
 * #      sig_on()
 *       for i in range(n):             # <<<<<<<<<<<<<<
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 */
    __pyx_t_4 = __pyx_v_n;
    __pyx_t_5 = __pyx_t_4;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "giacpy/giacpy.pyx":1710
 * #      sig_on()
 *       for i in range(n):
 *         if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *         V.push_back((<Pygen>Pygen(L[i])).gptr[0])
 */
      __pyx_t_2 = (ctrl_c != 0);
      if (unlikely(__pyx_t_2)) {

        /* "giacpy/giacpy.pyx":1711
 *       for i in range(n):
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"             # <<<<<<<<<<<<<<
 *         V.push_back((<Pygen>Pygen(L[i])).gptr[0])
 * #      sig_off()
 */
        __Pyx_Raise(__pyx_builtin_KeyboardInterrupt, __pyx_kp_s_Interrupted_by_a_ctrl_c_event, 0, 0);
        __PYX_ERR(0, 1711, __pyx_L1_error)

        /* "giacpy/giacpy.pyx":1710
 * #      sig_on()
 *       for i in range(n):
 *         if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *         V.push_back((<Pygen>Pygen(L[i])).gptr[0])
 */
      }

      /* "giacpy/giacpy.pyx":1712
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *         V.push_back((<Pygen>Pygen(L[i])).gptr[0])             # <<<<<<<<<<<<<<
 * #      sig_off()
 *       return V[0]
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_L, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1712, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1712, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_V->push_back((((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_7)->gptr[0]));
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }

    /* "giacpy/giacpy.pyx":1714
 *         V.push_back((<Pygen>Pygen(L[i])).gptr[0])
 * #      sig_off()
 *       return V[0]             # <<<<<<<<<<<<<<
 *    else:
 *      raise TypeError,"argument must be a tuple or a list"
 */
    __pyx_r = (__pyx_v_V[0]);
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1704
 *    cdef int i
 * 
 *    if (isinstance(L,tuple) or isinstance(L,listrange)):             # <<<<<<<<<<<<<<
 *       n=len(L)
 *       V=new vecteur()
 */
  }

  /* "giacpy/giacpy.pyx":1716
 *       return V[0]
 *    else:
 *      raise TypeError,"argument must be a tuple or a list"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_argument_must_be_a_tuple_or_a_li, 0, 0);
    __PYX_ERR(0, 1716, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1699
 * ################################################################
 * 
 * cdef  vecteur _wrap_pylist(L) except +:             # <<<<<<<<<<<<<<
 *    cdef Pygen pyg=Pygen()
 *    cdef vecteur  * V
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy._wrap_pylist", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pyg);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1722
 * #  slice wrapper for a giac list
 * #################################
 * cdef  vecteur _getgiacslice(Pygen L,slice sl) except +:             # <<<<<<<<<<<<<<
 *    cdef Pygen pyg=Pygen()
 *    cdef vecteur  * V
 */

static giac::vecteur __pyx_f_6giacpy_6giacpy__getgiacslice(struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_L, PyObject *__pyx_v_sl) {
  CYTHON_UNUSED struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_pyg = 0;
  giac::vecteur *__pyx_v_V;
  int __pyx_v_u;
  Py_ssize_t __pyx_v_n;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_st = NULL;
  giac::vecteur __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  giac::gen __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_getgiacslice", 1);

  /* "giacpy/giacpy.pyx":1723
 * #################################
 * cdef  vecteur _getgiacslice(Pygen L,slice sl) except +:
 *    cdef Pygen pyg=Pygen()             # <<<<<<<<<<<<<<
 *    cdef vecteur  * V
 *    cdef int u
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pyg = ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1727
 *    cdef int u
 * 
 *    if (L.type()=="DOM_LIST"):             # <<<<<<<<<<<<<<
 *       n=len(L)
 *       V=new vecteur()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_L), __pyx_n_s_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1727, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_DOM_LIST, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_5)) {

    /* "giacpy/giacpy.pyx":1728
 * 
 *    if (L.type()=="DOM_LIST"):
 *       n=len(L)             # <<<<<<<<<<<<<<
 *       V=new vecteur()
 *       ressetctrl_c()
 */
    __pyx_t_6 = PyObject_Length(((PyObject *)__pyx_v_L)); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1728, __pyx_L1_error)
    __pyx_v_n = __pyx_t_6;

    /* "giacpy/giacpy.pyx":1729
 *    if (L.type()=="DOM_LIST"):
 *       n=len(L)
 *       V=new vecteur()             # <<<<<<<<<<<<<<
 *       ressetctrl_c()
 * #      sig_on()
 */
    __pyx_v_V = new giac::vecteur();

    /* "giacpy/giacpy.pyx":1730
 *       n=len(L)
 *       V=new vecteur()
 *       ressetctrl_c()             # <<<<<<<<<<<<<<
 * #      sig_on()
 * #      for u in range(n)[sl]:   #pb python3
 */
    try {
      ressetctrl_c();
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1730, __pyx_L1_error)
    }

    /* "giacpy/giacpy.pyx":1733
 * #      sig_on()
 * #      for u in range(n)[sl]:   #pb python3
 *       (b,e,st)=sl.indices(n)             # <<<<<<<<<<<<<<
 *       for u in range(b,e,st):
 *         if(GIACctrl_c):
 */
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PySlice_Type_indices, __pyx_v_sl, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1733, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1733, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1733, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1733, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1733, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_8);
      index = 0; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 1; __pyx_t_3 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 2; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L4_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < 0) __PYX_ERR(0, 1733, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_unpacking_done;
      __pyx_L4_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1733, __pyx_L1_error)
      __pyx_L5_unpacking_done:;
    }
    __pyx_v_b = __pyx_t_1;
    __pyx_t_1 = 0;
    __pyx_v_e = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_v_st = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "giacpy/giacpy.pyx":1734
 * #      for u in range(n)[sl]:   #pb python3
 *       (b,e,st)=sl.indices(n)
 *       for u in range(b,e,st):             # <<<<<<<<<<<<<<
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 */
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_b);
    __Pyx_GIVEREF(__pyx_v_b);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_b)) __PYX_ERR(0, 1734, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_e);
    __Pyx_GIVEREF(__pyx_v_e);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_e)) __PYX_ERR(0, 1734, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_st);
    __Pyx_GIVEREF(__pyx_v_st);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_st)) __PYX_ERR(0, 1734, __pyx_L1_error);
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_2, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
      __pyx_t_2 = __pyx_t_7; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_6 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1734, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1734, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1734, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_7); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1734, __pyx_L1_error)
          #else
          __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1734, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1734, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_7); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1734, __pyx_L1_error)
          #else
          __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1734, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        }
      } else {
        __pyx_t_7 = __pyx_t_10(__pyx_t_2);
        if (unlikely(!__pyx_t_7)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1734, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1734, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_u = __pyx_t_11;

      /* "giacpy/giacpy.pyx":1735
 *       (b,e,st)=sl.indices(n)
 *       for u in range(b,e,st):
 *         if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *         V.push_back((L.gptr[0])[u])
 */
      __pyx_t_5 = (ctrl_c != 0);
      if (unlikely(__pyx_t_5)) {

        /* "giacpy/giacpy.pyx":1736
 *       for u in range(b,e,st):
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"             # <<<<<<<<<<<<<<
 *         V.push_back((L.gptr[0])[u])
 * #      sig_off()
 */
        __Pyx_Raise(__pyx_builtin_KeyboardInterrupt, __pyx_kp_s_Interrupted_by_a_ctrl_c_event, 0, 0);
        __PYX_ERR(0, 1736, __pyx_L1_error)

        /* "giacpy/giacpy.pyx":1735
 *       (b,e,st)=sl.indices(n)
 *       for u in range(b,e,st):
 *         if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *         V.push_back((L.gptr[0])[u])
 */
      }

      /* "giacpy/giacpy.pyx":1737
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *         V.push_back((L.gptr[0])[u])             # <<<<<<<<<<<<<<
 * #      sig_off()
 *       return V[0]
 */
      try {
        __pyx_t_12 = (__pyx_v_L->gptr[0])[__pyx_v_u];
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 1737, __pyx_L1_error)
      }
      __pyx_v_V->push_back(__pyx_t_12);

      /* "giacpy/giacpy.pyx":1734
 * #      for u in range(n)[sl]:   #pb python3
 *       (b,e,st)=sl.indices(n)
 *       for u in range(b,e,st):             # <<<<<<<<<<<<<<
 *         if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":1739
 *         V.push_back((L.gptr[0])[u])
 * #      sig_off()
 *       return V[0]             # <<<<<<<<<<<<<<
 *    else:
 *      raise TypeError,"argument must be a Pygen list and a slice"
 */
    __pyx_r = (__pyx_v_V[0]);
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1727
 *    cdef int u
 * 
 *    if (L.type()=="DOM_LIST"):             # <<<<<<<<<<<<<<
 *       n=len(L)
 *       V=new vecteur()
 */
  }

  /* "giacpy/giacpy.pyx":1741
 *       return V[0]
 *    else:
 *      raise TypeError,"argument must be a Pygen list and a slice"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_argument_must_be_a_Pygen_list_an, 0, 0);
    __PYX_ERR(0, 1741, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1722
 * #  slice wrapper for a giac list
 * #################################
 * cdef  vecteur _getgiacslice(Pygen L,slice sl) except +:             # <<<<<<<<<<<<<<
 *    cdef Pygen pyg=Pygen()
 *    cdef vecteur  * V
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("giacpy.giacpy._getgiacslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pyg);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_st);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1747
 * 
 * 
 * cdef  gen pylongtogen(a) except +:             # <<<<<<<<<<<<<<
 *    #                                                                     #
 *    # basic conversion of Python long integers to gen via Horner's Method #
 */

static giac::gen __pyx_f_6giacpy_6giacpy_pylongtogen(PyObject *__pyx_v_a) {
  int __pyx_v_aneg;
  giac::gen __pyx_v_g;
  giac::gen __pyx_v_M;
  PyObject *__pyx_v_size = NULL;
  PyObject *__pyx_v_shift = NULL;
  PyObject *__pyx_v_i = NULL;
  giac::gen __pyx_r;
  __Pyx_RefNannyDeclarations
  giac::gen __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PY_LONG_LONG __pyx_t_10;
  giac::gen __pyx_t_11;
  giac::gen __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pylongtogen", 0);
  __Pyx_INCREF(__pyx_v_a);

  /* "giacpy/giacpy.pyx":1751
 *    # basic conversion of Python long integers to gen via Horner's Method #
 *    #                                                                     #
 *    ressetctrl_c()             # <<<<<<<<<<<<<<
 *    aneg=False
 *    cdef gen g=gen(<int>0)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1751, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1752
 *    #                                                                     #
 *    ressetctrl_c()
 *    aneg=False             # <<<<<<<<<<<<<<
 *    cdef gen g=gen(<int>0)
 *    cdef gen M
 */
  __pyx_v_aneg = 0;

  /* "giacpy/giacpy.pyx":1753
 *    ressetctrl_c()
 *    aneg=False
 *    cdef gen g=gen(<int>0)             # <<<<<<<<<<<<<<
 *    cdef gen M
 * 
 */
  try {
    __pyx_t_1 = giac::gen(((int)0));
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1753, __pyx_L1_error)
  }
  __pyx_v_g = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_1);

  /* "giacpy/giacpy.pyx":1756
 *    cdef gen M
 * 
 *    if (a<0):             # <<<<<<<<<<<<<<
 *      aneg=True
 *      a=-a
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_a, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1756, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "giacpy/giacpy.pyx":1757
 * 
 *    if (a<0):
 *      aneg=True             # <<<<<<<<<<<<<<
 *      a=-a
 *    if Pyversioninfo >= (2,7):
 */
    __pyx_v_aneg = 1;

    /* "giacpy/giacpy.pyx":1758
 *    if (a<0):
 *      aneg=True
 *      a=-a             # <<<<<<<<<<<<<<
 *    if Pyversioninfo >= (2,7):
 *       size=a.bit_length()  # bit_length python >= 2.7 required.
 */
    __pyx_t_2 = PyNumber_Negative(__pyx_v_a); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_a, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":1756
 *    cdef gen M
 * 
 *    if (a<0):             # <<<<<<<<<<<<<<
 *      aneg=True
 *      a=-a
 */
  }

  /* "giacpy/giacpy.pyx":1759
 *      aneg=True
 *      a=-a
 *    if Pyversioninfo >= (2,7):             # <<<<<<<<<<<<<<
 *       size=a.bit_length()  # bit_length python >= 2.7 required.
 *       shift=Pymaxint.bit_length()-1
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Pyversioninfo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_tuple__9, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "giacpy/giacpy.pyx":1760
 *      a=-a
 *    if Pyversioninfo >= (2,7):
 *       size=a.bit_length()  # bit_length python >= 2.7 required.             # <<<<<<<<<<<<<<
 *       shift=Pymaxint.bit_length()-1
 *    else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_a, __pyx_n_s_bit_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_size = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "giacpy/giacpy.pyx":1761
 *    if Pyversioninfo >= (2,7):
 *       size=a.bit_length()  # bit_length python >= 2.7 required.
 *       shift=Pymaxint.bit_length()-1             # <<<<<<<<<<<<<<
 *    else:
 *       size=math.trunc(math.log(a,2))+1
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Pymaxint); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_bit_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_shift = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1759
 *      aneg=True
 *      a=-a
 *    if Pyversioninfo >= (2,7):             # <<<<<<<<<<<<<<
 *       size=a.bit_length()  # bit_length python >= 2.7 required.
 *       shift=Pymaxint.bit_length()-1
 */
    goto __pyx_L4;
  }

  /* "giacpy/giacpy.pyx":1763
 *       shift=Pymaxint.bit_length()-1
 *    else:
 *       size=math.trunc(math.log(a,2))+1             # <<<<<<<<<<<<<<
 *       shift=math.trunc(math.log(Pymaxint))
 *    M=gen(<long long>(1<<shift))
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_math); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_trunc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_math); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_log); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_a, __pyx_int_2};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_5, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_size = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":1764
 *    else:
 *       size=math.trunc(math.log(a,2))+1
 *       shift=math.trunc(math.log(Pymaxint))             # <<<<<<<<<<<<<<
 *    M=gen(<long long>(1<<shift))
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_math); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_trunc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_math); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_log); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Pymaxint); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_shift = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L4:;

  /* "giacpy/giacpy.pyx":1765
 *       size=math.trunc(math.log(a,2))+1
 *       shift=math.trunc(math.log(Pymaxint))
 *    M=gen(<long long>(1<<shift))             # <<<<<<<<<<<<<<
 * 
 *    while (size>=shift):
 */
  __pyx_t_2 = PyNumber_Lshift(__pyx_int_1, __pyx_v_shift); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_t_2); if (unlikely((__pyx_t_10 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1765, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  try {
    __pyx_t_1 = giac::gen(((PY_LONG_LONG)__pyx_t_10));
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1765, __pyx_L1_error)
  }
  __pyx_v_M = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_1);

  /* "giacpy/giacpy.pyx":1767
 *    M=gen(<long long>(1<<shift))
 * 
 *    while (size>=shift):             # <<<<<<<<<<<<<<
 *      if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 */
  while (1) {
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_size, __pyx_v_shift, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1767, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1767, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!__pyx_t_3) break;

    /* "giacpy/giacpy.pyx":1768
 * 
 *    while (size>=shift):
 *      if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *      size=size-shift
 */
    __pyx_t_3 = (ctrl_c != 0);
    if (unlikely(__pyx_t_3)) {

      /* "giacpy/giacpy.pyx":1769
 *    while (size>=shift):
 *      if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"             # <<<<<<<<<<<<<<
 *      size=size-shift
 *      i=int(a>>size)
 */
      __Pyx_Raise(__pyx_builtin_KeyboardInterrupt, __pyx_kp_s_Interrupted_by_a_ctrl_c_event, 0, 0);
      __PYX_ERR(0, 1769, __pyx_L1_error)

      /* "giacpy/giacpy.pyx":1768
 * 
 *    while (size>=shift):
 *      if(GIACctrl_c):             # <<<<<<<<<<<<<<
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *      size=size-shift
 */
    }

    /* "giacpy/giacpy.pyx":1770
 *      if(GIACctrl_c):
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *      size=size-shift             # <<<<<<<<<<<<<<
 *      i=int(a>>size)
 *      g=(g*M+gen(<long long>i))
 */
    __pyx_t_2 = PyNumber_Subtract(__pyx_v_size, __pyx_v_shift); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1770, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_size, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":1771
 *           raise KeyboardInterrupt,"Interrupted by a ctrl-c event"
 *      size=size-shift
 *      i=int(a>>size)             # <<<<<<<<<<<<<<
 *      g=(g*M+gen(<long long>i))
 *      a=a-(i<<size)
 */
    __pyx_t_2 = PyNumber_Rshift(__pyx_v_a, __pyx_v_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "giacpy/giacpy.pyx":1772
 *      size=size-shift
 *      i=int(a>>size)
 *      g=(g*M+gen(<long long>i))             # <<<<<<<<<<<<<<
 *      a=a-(i<<size)
 * 
 */
    try {
      __pyx_t_1 = (__pyx_v_g * __pyx_v_M);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1772, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_v_i); if (unlikely((__pyx_t_10 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1772, __pyx_L1_error)
    try {
      __pyx_t_11 = giac::gen(((PY_LONG_LONG)__pyx_t_10));
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1772, __pyx_L1_error)
    }
    try {
      __pyx_t_12 = (__pyx_t_1 + __pyx_t_11);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1772, __pyx_L1_error)
    }
    __pyx_v_g = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_12);

    /* "giacpy/giacpy.pyx":1773
 *      i=int(a>>size)
 *      g=(g*M+gen(<long long>i))
 *      a=a-(i<<size)             # <<<<<<<<<<<<<<
 * 
 *    g=g*gen(<long long>(1<<size))+gen(<long long> a)
 */
    __pyx_t_4 = PyNumber_Lshift(__pyx_v_i, __pyx_v_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyNumber_Subtract(__pyx_v_a, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_a, __pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "giacpy/giacpy.pyx":1775
 *      a=a-(i<<size)
 * 
 *    g=g*gen(<long long>(1<<size))+gen(<long long> a)             # <<<<<<<<<<<<<<
 *    if aneg:
 *      # g=-g doesnt cythonize with cython 0.24, (- operator not declared?)
 */
  __pyx_t_2 = PyNumber_Lshift(__pyx_int_1, __pyx_v_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_t_2); if (unlikely((__pyx_t_10 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  try {
    __pyx_t_12 = giac::gen(((PY_LONG_LONG)__pyx_t_10));
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1775, __pyx_L1_error)
  }
  try {
    __pyx_t_11 = (__pyx_v_g * __pyx_t_12);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1775, __pyx_L1_error)
  }
  __pyx_t_10 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_v_a); if (unlikely((__pyx_t_10 == (PY_LONG_LONG)-1) && PyErr_Occurred())) __PYX_ERR(0, 1775, __pyx_L1_error)
  try {
    __pyx_t_12 = giac::gen(((PY_LONG_LONG)__pyx_t_10));
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1775, __pyx_L1_error)
  }
  try {
    __pyx_t_1 = (__pyx_t_11 + __pyx_t_12);
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1775, __pyx_L1_error)
  }
  __pyx_v_g = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_1);

  /* "giacpy/giacpy.pyx":1776
 * 
 *    g=g*gen(<long long>(1<<size))+gen(<long long> a)
 *    if aneg:             # <<<<<<<<<<<<<<
 *      # g=-g doesnt cythonize with cython 0.24, (- operator not declared?)
 *      g=GIAC_neg(g)
 */
  if (__pyx_v_aneg) {

    /* "giacpy/giacpy.pyx":1778
 *    if aneg:
 *      # g=-g doesnt cythonize with cython 0.24, (- operator not declared?)
 *      g=GIAC_neg(g)             # <<<<<<<<<<<<<<
 *    return g;
 * 
 */
    try {
      __pyx_t_1 = operator-(__pyx_v_g);
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1778, __pyx_L1_error)
    }
    __pyx_v_g = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_1);

    /* "giacpy/giacpy.pyx":1776
 * 
 *    g=g*gen(<long long>(1<<size))+gen(<long long> a)
 *    if aneg:             # <<<<<<<<<<<<<<
 *      # g=-g doesnt cythonize with cython 0.24, (- operator not declared?)
 *      g=GIAC_neg(g)
 */
  }

  /* "giacpy/giacpy.pyx":1779
 *      # g=-g doesnt cythonize with cython 0.24, (- operator not declared?)
 *      g=GIAC_neg(g)
 *    return g;             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_g;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1747
 * 
 * 
 * cdef  gen pylongtogen(a) except +:             # <<<<<<<<<<<<<<
 *    #                                                                     #
 *    # basic conversion of Python long integers to gen via Horner's Method #
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.pylongtogen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_pretend_to_initialize(&__pyx_r);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_size);
  __Pyx_XDECREF(__pyx_v_shift);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_a);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1849
 * 
 * 
 * def htmlhelp(s='en'):             # <<<<<<<<<<<<<<
 *    """
 *    Open the giac html detailled help in an external  browser
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_7htmlhelp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_6htmlhelp, "\n   Open the giac html detailled help in an external  browser\n\n   There are currently 3 supported lanquages: 'en', 'fr', 'el'\n    >>> htmlhelp('fr')         # doctest: +SKIP\n    >>> htmlhelp()             # doctest: +SKIP\n\n   ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_7htmlhelp = {"htmlhelp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_7htmlhelp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_6htmlhelp};
static PyObject *__pyx_pw_6giacpy_6giacpy_7htmlhelp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("htmlhelp (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_n_s_en)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1849, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "htmlhelp") < 0)) __PYX_ERR(0, 1849, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_s = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("htmlhelp", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 1849, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_6htmlhelp(__pyx_self, __pyx_v_s);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_6htmlhelp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_v_giacbasedir = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  std::string __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("htmlhelp", 0);
  __Pyx_INCREF(__pyx_v_s);

  /* "giacpy/giacpy.pyx":1858
 * 
 *    """
 *    giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3             # <<<<<<<<<<<<<<
 *    if (not s in ['en', 'fr', 'el']):
 *      s='en'
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_decstring23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  try {
    __pyx_t_3 = giac_aide_dir();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1858, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_convert_PyBytes_string_to_py_6libcpp_6string_std__in_string(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_giacbasedir = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1859
 *    """
 *    giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 *    if (not s in ['en', 'fr', 'el']):             # <<<<<<<<<<<<<<
 *      s='en'
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 */
  __Pyx_INCREF(__pyx_v_s);
  __pyx_t_1 = __pyx_v_s;
  __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_en, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1859, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_fr, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1859, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_el, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1859, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = __pyx_t_7;
  if (__pyx_t_8) {

    /* "giacpy/giacpy.pyx":1860
 *    giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 *    if (not s in ['en', 'fr', 'el']):
 *      s='en'             # <<<<<<<<<<<<<<
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 *    ressetctrl_c()
 */
    __Pyx_INCREF(__pyx_n_s_en);
    __Pyx_DECREF_SET(__pyx_v_s, __pyx_n_s_en);

    /* "giacpy/giacpy.pyx":1859
 *    """
 *    giacbasedir=decstring23(GIAC_giac_aide_dir())  # python3
 *    if (not s in ['en', 'fr', 'el']):             # <<<<<<<<<<<<<<
 *      s='en'
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 */
  }

  /* "giacpy/giacpy.pyx":1861
 *    if (not s in ['en', 'fr', 'el']):
 *      s='en'
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'             # <<<<<<<<<<<<<<
 *    ressetctrl_c()
 *    try:
 */
  __pyx_t_1 = PyNumber_Add(__pyx_kp_s_doc, __pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s_cascmd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_kp_s_index_html); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1862
 *      s='en'
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 *    ressetctrl_c()             # <<<<<<<<<<<<<<
 *    try:
 *      #if 1==htmlbrowserhelp(s) :
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 1862, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":1863
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 *    ressetctrl_c()
 *    try:             # <<<<<<<<<<<<<<
 *      #if 1==htmlbrowserhelp(s) :
 *      #  raise RuntimeError,'unable to launch browser'
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1866
 *      #if 1==htmlbrowserhelp(s) :
 *      #  raise RuntimeError,'unable to launch browser'
 *      url=giacbasedir+s             # <<<<<<<<<<<<<<
 *      if not os.access(url,os.F_OK):
 *          url='http://www-fourier.ujf-grenoble.fr/~parisse/giac/'+s
 */
      __pyx_t_2 = PyNumber_Add(__pyx_v_giacbasedir, __pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1866, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_url = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "giacpy/giacpy.pyx":1867
 *      #  raise RuntimeError,'unable to launch browser'
 *      url=giacbasedir+s
 *      if not os.access(url,os.F_OK):             # <<<<<<<<<<<<<<
 *          url='http://www-fourier.ujf-grenoble.fr/~parisse/giac/'+s
 *      else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1867, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_access); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1867, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1867, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_F_OK); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1867, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_url, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1867, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1867, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = (!__pyx_t_8);
      if (__pyx_t_7) {

        /* "giacpy/giacpy.pyx":1868
 *      url=giacbasedir+s
 *      if not os.access(url,os.F_OK):
 *          url='http://www-fourier.ujf-grenoble.fr/~parisse/giac/'+s             # <<<<<<<<<<<<<<
 *      else:
 *          url='file:'+url
 */
        __pyx_t_2 = PyNumber_Add(__pyx_kp_s_http_www_fourier_ujf_grenoble_fr, __pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1868, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_url, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "giacpy/giacpy.pyx":1867
 *      #  raise RuntimeError,'unable to launch browser'
 *      url=giacbasedir+s
 *      if not os.access(url,os.F_OK):             # <<<<<<<<<<<<<<
 *          url='http://www-fourier.ujf-grenoble.fr/~parisse/giac/'+s
 *      else:
 */
        goto __pyx_L13;
      }

      /* "giacpy/giacpy.pyx":1870
 *          url='http://www-fourier.ujf-grenoble.fr/~parisse/giac/'+s
 *      else:
 *          url='file:'+url             # <<<<<<<<<<<<<<
 *      wwwbrowseropen(url)
 *    except:
 */
      /*else*/ {
        __pyx_t_2 = PyNumber_Add(__pyx_kp_s_file, __pyx_v_url); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1870, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_url, __pyx_t_2);
        __pyx_t_2 = 0;
      }
      __pyx_L13:;

      /* "giacpy/giacpy.pyx":1871
 *      else:
 *          url='file:'+url
 *      wwwbrowseropen(url)             # <<<<<<<<<<<<<<
 *    except:
 *      raise
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_wwwbrowseropen); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1871, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_url};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1871, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "giacpy/giacpy.pyx":1863
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 *    ressetctrl_c()
 *    try:             # <<<<<<<<<<<<<<
 *      #if 1==htmlbrowserhelp(s) :
 *      #  raise RuntimeError,'unable to launch browser'
 */
    }
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    goto __pyx_L12_try_end;
    __pyx_L7_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":1872
 *          url='file:'+url
 *      wwwbrowseropen(url)
 *    except:             # <<<<<<<<<<<<<<
 *      raise
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1872, __pyx_L9_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "giacpy/giacpy.pyx":1873
 *      wwwbrowseropen(url)
 *    except:
 *      raise             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_4, __pyx_t_5);
      __pyx_t_2 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; 
      __PYX_ERR(0, 1873, __pyx_L9_except_error)
    }

    /* "giacpy/giacpy.pyx":1863
 *    s='doc/'+s+'/cascmd_'+s+'/index.html'
 *    ressetctrl_c()
 *    try:             # <<<<<<<<<<<<<<
 *      #if 1==htmlbrowserhelp(s) :
 *      #  raise RuntimeError,'unable to launch browser'
 */
    __pyx_L9_except_error:;
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L1_error;
    __pyx_L12_try_end:;
  }

  /* "giacpy/giacpy.pyx":1849
 * 
 * 
 * def htmlhelp(s='en'):             # <<<<<<<<<<<<<<
 *    """
 *    Open the giac html detailled help in an external  browser
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("giacpy.giacpy.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_giacbasedir);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1879
 * #  Qcas string interactive 2D geometry; string input
 * #############################################################
 * def qcas(str s):             # <<<<<<<<<<<<<<
 *    """
 *    * EXPERIMENTAL: Send a giac command to an  interactive 2D geometry display in qcas.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_9qcas(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_8qcas, "\n   * EXPERIMENTAL: Send a giac command to an  interactive 2D geometry display in qcas.\n     Current state: Geometric objects will be displayed, but only geometric objects STORED in a giac variable can be used for interactive geometric constructions in qcas.\n\n    >>> d1='A:=point(1+i);t:=element(10..100,1,10);C:=circle(A,t*0.05);M:=element(C);'\n    >>> qcas(d1)    # doctest: +SKIP\n\n   ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_9qcas = {"qcas", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_9qcas, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_8qcas};
static PyObject *__pyx_pw_6giacpy_6giacpy_9qcas(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("qcas (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1879, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "qcas") < 0)) __PYX_ERR(0, 1879, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_s = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("qcas", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1879, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.qcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), (&PyString_Type), 1, "s", 1))) __PYX_ERR(0, 1879, __pyx_L1_error)
  __pyx_r = __pyx_pf_6giacpy_6giacpy_8qcas(__pyx_self, __pyx_v_s);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_8qcas(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_s) {
  struct __pyx_obj_6giacpy_6giacpy_Pygen *__pyx_v_oldies = NULL;
  PyObject *__pyx_v_toqcas = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("qcas", 1);

  /* "giacpy/giacpy.pyx":1888
 * 
 *    """
 *    if s=='':             # <<<<<<<<<<<<<<
 *       return
 *    else:
 */
  __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_s, __pyx_kp_s__10, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1888, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "giacpy/giacpy.pyx":1889
 *    """
 *    if s=='':
 *       return             # <<<<<<<<<<<<<<
 *    else:
 *       oldies=Pygen('"using sendtext"')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "giacpy/giacpy.pyx":1888
 * 
 *    """
 *    if s=='':             # <<<<<<<<<<<<<<
 *       return
 *    else:
 */
  }

  /* "giacpy/giacpy.pyx":1891
 *       return
 *    else:
 *       oldies=Pygen('"using sendtext"')             # <<<<<<<<<<<<<<
 *       ressetctrl_c()
 *       try:
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_oldies = ((struct __pyx_obj_6giacpy_6giacpy_Pygen *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":1892
 *    else:
 *       oldies=Pygen('"using sendtext"')
 *       ressetctrl_c()             # <<<<<<<<<<<<<<
 *       try:
 *          from .giacpy2qcas import toqcas
 */
    try {
      ressetctrl_c();
    } catch(...) {
      __Pyx_CppExn2PyErr();
      __PYX_ERR(0, 1892, __pyx_L1_error)
    }

    /* "giacpy/giacpy.pyx":1893
 *       oldies=Pygen('"using sendtext"')
 *       ressetctrl_c()
 *       try:             # <<<<<<<<<<<<<<
 *          from .giacpy2qcas import toqcas
 *          toqcas(oldies,s)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "giacpy/giacpy.pyx":1894
 *       ressetctrl_c()
 *       try:
 *          from .giacpy2qcas import toqcas             # <<<<<<<<<<<<<<
 *          toqcas(oldies,s)
 *          return
 */
        __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1894, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_n_s_toqcas);
        __Pyx_GIVEREF(__pyx_n_s_toqcas);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_toqcas)) __PYX_ERR(0, 1894, __pyx_L4_error);
        __pyx_t_6 = __Pyx_Import(__pyx_n_s_giacpy2qcas, __pyx_t_2, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1894, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_6, __pyx_n_s_toqcas); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1894, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_2);
        __pyx_v_toqcas = __pyx_t_2;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "giacpy/giacpy.pyx":1895
 *       try:
 *          from .giacpy2qcas import toqcas
 *          toqcas(oldies,s)             # <<<<<<<<<<<<<<
 *          return
 *       except:
 */
        __Pyx_INCREF(__pyx_v_toqcas);
        __pyx_t_2 = __pyx_v_toqcas; __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_oldies), __pyx_v_s};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1895, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "giacpy/giacpy.pyx":1896
 *          from .giacpy2qcas import toqcas
 *          toqcas(oldies,s)
 *          return             # <<<<<<<<<<<<<<
 *       except:
 *          raise RuntimeError
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L8_try_return;

        /* "giacpy/giacpy.pyx":1893
 *       oldies=Pygen('"using sendtext"')
 *       ressetctrl_c()
 *       try:             # <<<<<<<<<<<<<<
 *          from .giacpy2qcas import toqcas
 *          toqcas(oldies,s)
 */
      }
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "giacpy/giacpy.pyx":1897
 *          toqcas(oldies,s)
 *          return
 *       except:             # <<<<<<<<<<<<<<
 *          raise RuntimeError
 * 
 */
      /*except:*/ {
        __Pyx_AddTraceback("giacpy.giacpy.qcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_2, &__pyx_t_7) < 0) __PYX_ERR(0, 1897, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_7);

        /* "giacpy/giacpy.pyx":1898
 *          return
 *       except:
 *          raise RuntimeError             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
        __PYX_ERR(0, 1898, __pyx_L6_except_error)
      }

      /* "giacpy/giacpy.pyx":1893
 *       oldies=Pygen('"using sendtext"')
 *       ressetctrl_c()
 *       try:             # <<<<<<<<<<<<<<
 *          from .giacpy2qcas import toqcas
 *          toqcas(oldies,s)
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L8_try_return:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L0;
    }
  }

  /* "giacpy/giacpy.pyx":1879
 * #  Qcas string interactive 2D geometry; string input
 * #############################################################
 * def qcas(str s):             # <<<<<<<<<<<<<<
 *    """
 *    * EXPERIMENTAL: Send a giac command to an  interactive 2D geometry display in qcas.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy.qcas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_oldies);
  __Pyx_XDECREF(__pyx_v_toqcas);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1927
 *    This class is used by GiacFunction
 *    """
 *    def __call__(self, *args):             # <<<<<<<<<<<<<<
 *       return self.threadeval(*args)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_13ThreadedPygen_1__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_13ThreadedPygen_1__call__ = {"__call__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_13ThreadedPygen_1__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_13ThreadedPygen_1__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1927, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "__call__") < 0)) __PYX_ERR(0, 1927, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 1927, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("giacpy.giacpy.ThreadedPygen.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_13ThreadedPygen___call__(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_13ThreadedPygen___call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 1);

  /* "giacpy/giacpy.pyx":1928
 *    """
 *    def __call__(self, *args):
 *       return self.threadeval(*args)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_threadeval); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_args, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1927
 *    This class is used by GiacFunction
 *    """
 *    def __call__(self, *args):             # <<<<<<<<<<<<<<
 *       return self.threadeval(*args)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("giacpy.giacpy.ThreadedPygen.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1934
 *    # docstring removed to show  self.__doc__  under IEP.
 * 
 *    def __init__(self,str s):             # <<<<<<<<<<<<<<
 * 
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_s = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_s,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1934, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1934, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 1934, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1934, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_s = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1934, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_s), (&PyString_Type), 1, "s", 1))) __PYX_ERR(0, 1934, __pyx_L1_error)
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction___init__(__pyx_self, __pyx_v_self, __pyx_v_s);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_s) {
  PyObject *__pyx_v_directevalued = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "giacpy/giacpy.pyx":1936
 *    def __init__(self,str s):
 * 
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']             # <<<<<<<<<<<<<<
 * 
 *       if (s in directevalued):
 */
  __pyx_t_1 = PyList_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_assume);
  __Pyx_GIVEREF(__pyx_n_s_assume);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_assume)) __PYX_ERR(0, 1936, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_supposons);
  __Pyx_GIVEREF(__pyx_n_s_supposons);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_supposons)) __PYX_ERR(0, 1936, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randseed);
  __Pyx_GIVEREF(__pyx_n_s_randseed);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_s_randseed)) __PYX_ERR(0, 1936, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_srand);
  __Pyx_GIVEREF(__pyx_n_s_srand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 3, __pyx_n_s_srand)) __PYX_ERR(0, 1936, __pyx_L1_error);
  __pyx_v_directevalued = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "giacpy/giacpy.pyx":1938
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']
 * 
 *       if (s in directevalued):             # <<<<<<<<<<<<<<
 *          self.Pygen=Pygen(s)
 *       else:
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_s, __pyx_v_directevalued, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1938, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1939
 * 
 *       if (s in directevalued):
 *          self.Pygen=Pygen(s)             # <<<<<<<<<<<<<<
 *       else:
 *          self.Pygen=ThreadedPygen(s)
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_v_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_Pygen, __pyx_t_1) < 0) __PYX_ERR(0, 1939, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1938
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']
 * 
 *       if (s in directevalued):             # <<<<<<<<<<<<<<
 *          self.Pygen=Pygen(s)
 *       else:
 */
    goto __pyx_L3;
  }

  /* "giacpy/giacpy.pyx":1941
 *          self.Pygen=Pygen(s)
 *       else:
 *          self.Pygen=ThreadedPygen(s)             # <<<<<<<<<<<<<<
 * 
 *       try:
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ThreadedPygen); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_s};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1941, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_Pygen, __pyx_t_1) < 0) __PYX_ERR(0, 1941, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "giacpy/giacpy.pyx":1943
 *          self.Pygen=ThreadedPygen(s)
 * 
 *       try:             # <<<<<<<<<<<<<<
 *          self.__doc__="(from giac's help:)"+Pygen('?'+s).eval().__str__()
 *       except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":1944
 * 
 *       try:
 *          self.__doc__="(from giac's help:)"+Pygen('?'+s).eval().__str__()             # <<<<<<<<<<<<<<
 *       except:
 *          self.__doc__="failed to init doc from giac's doc"
 */
      __pyx_t_4 = __Pyx_PyStr_ConcatSafe(__pyx_kp_s__12, __pyx_v_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1944, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1944, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_eval); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1944, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1944, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1944, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1944, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = PyNumber_Add(__pyx_kp_s_from_giac_s_help, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1944, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_doc_2, __pyx_t_4) < 0) __PYX_ERR(0, 1944, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "giacpy/giacpy.pyx":1943
 *          self.Pygen=ThreadedPygen(s)
 * 
 *       try:             # <<<<<<<<<<<<<<
 *          self.__doc__="(from giac's help:)"+Pygen('?'+s).eval().__str__()
 *       except:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "giacpy/giacpy.pyx":1945
 *       try:
 *          self.__doc__="(from giac's help:)"+Pygen('?'+s).eval().__str__()
 *       except:             # <<<<<<<<<<<<<<
 *          self.__doc__="failed to init doc from giac's doc"
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 1945, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "giacpy/giacpy.pyx":1946
 *          self.__doc__="(from giac's help:)"+Pygen('?'+s).eval().__str__()
 *       except:
 *          self.__doc__="failed to init doc from giac's doc"             # <<<<<<<<<<<<<<
 * 
 * 
 */
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_doc_2, __pyx_kp_s_failed_to_init_doc_from_giac_s_d) < 0) __PYX_ERR(0, 1946, __pyx_L6_except_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L5_exception_handled;
    }

    /* "giacpy/giacpy.pyx":1943
 *          self.Pygen=ThreadedPygen(s)
 * 
 *       try:             # <<<<<<<<<<<<<<
 *          self.__doc__="(from giac's help:)"+Pygen('?'+s).eval().__str__()
 *       except:
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L9_try_end:;
  }

  /* "giacpy/giacpy.pyx":1934
 *    # docstring removed to show  self.__doc__  under IEP.
 * 
 *    def __init__(self,str s):             # <<<<<<<<<<<<<<
 * 
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_directevalued);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1949
 * 
 * 
 *    def __call__(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen(*args)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_3__call__ = {"__call__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_3__call__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_3__call__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1949, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "__call__") < 0)) __PYX_ERR(0, 1949, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 1949, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_2__call__(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_2__call__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 1);

  /* "giacpy/giacpy.pyx":1950
 * 
 *    def __call__(self,*args):
 *       return self.Pygen(*args)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_args, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1949
 * 
 * 
 *    def __call__(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen(*args)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1953
 * 
 * 
 *    def __repr__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__repr__()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_5__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_5__repr__ = {"__repr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_5__repr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_5__repr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1953, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__repr__") < 0)) __PYX_ERR(0, 1953, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__repr__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1953, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_4__repr__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "giacpy/giacpy.pyx":1954
 * 
 *    def __repr__(self):
 *       return self.Pygen.__repr__()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_repr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1953
 * 
 * 
 *    def __repr__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__repr__()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1957
 * 
 * 
 *    def __str__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__str__()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_7__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_7__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_7__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_7__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1957, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 1957, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1957, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_6__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_6__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "giacpy/giacpy.pyx":1958
 * 
 *    def __str__(self):
 *       return self.Pygen.__str__()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_str_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1958, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1957
 * 
 * 
 *    def __str__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__str__()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1961
 * 
 * 
 *    def __add__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_9__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_9__add__ = {"__add__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_9__add__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_9__add__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_right = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_right,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1961, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_right)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1961, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, 1); __PYX_ERR(0, 1961, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__add__") < 0)) __PYX_ERR(0, 1961, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_right = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__add__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1961, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_8__add__(__pyx_self, __pyx_v_self, __pyx_v_right);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_8__add__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 0);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1962
 * 
 *    def __add__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_right, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1962, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1963
 *    def __add__(self,right):
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen             # <<<<<<<<<<<<<<
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_right, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1962
 * 
 *    def __add__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  }

  /* "giacpy/giacpy.pyx":1964
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self+right
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1965
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen             # <<<<<<<<<<<<<<
 *       return self+right
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1964
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self+right
 */
  }

  /* "giacpy/giacpy.pyx":1966
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 *       return self+right             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_self, __pyx_v_right); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1961
 * 
 * 
 *    def __add__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1969
 * 
 * 
 *    def __sub__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_11__sub__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_11__sub__ = {"__sub__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_11__sub__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_11__sub__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_right = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sub__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_right,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1969, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_right)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1969, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__sub__", 1, 2, 2, 1); __PYX_ERR(0, 1969, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__sub__") < 0)) __PYX_ERR(0, 1969, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_right = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__sub__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1969, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_10__sub__(__pyx_self, __pyx_v_self, __pyx_v_right);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_10__sub__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__sub__", 0);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1970
 * 
 *    def __sub__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_right, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1971
 *    def __sub__(self,right):
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen             # <<<<<<<<<<<<<<
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_right, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1971, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1970
 * 
 *    def __sub__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  }

  /* "giacpy/giacpy.pyx":1972
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self-right
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1973
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen             # <<<<<<<<<<<<<<
 *       return self-right
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1972
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self-right
 */
  }

  /* "giacpy/giacpy.pyx":1974
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 *       return self-right             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Subtract(__pyx_v_self, __pyx_v_right); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1969
 * 
 * 
 *    def __sub__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1977
 * 
 * 
 *    def __mul__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_13__mul__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_13__mul__ = {"__mul__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_13__mul__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_13__mul__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_right = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mul__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_right,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1977, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_right)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1977, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__mul__", 1, 2, 2, 1); __PYX_ERR(0, 1977, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__mul__") < 0)) __PYX_ERR(0, 1977, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_right = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__mul__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1977, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_12__mul__(__pyx_self, __pyx_v_self, __pyx_v_right);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_12__mul__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__mul__", 0);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1978
 * 
 *    def __mul__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_right, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1979
 *    def __mul__(self,right):
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen             # <<<<<<<<<<<<<<
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_right, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1979, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1978
 * 
 *    def __mul__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  }

  /* "giacpy/giacpy.pyx":1980
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self*right
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1981
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen             # <<<<<<<<<<<<<<
 *       return self*right
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1980
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self*right
 */
  }

  /* "giacpy/giacpy.pyx":1982
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 *       return self*right             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Multiply(__pyx_v_self, __pyx_v_right); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1977
 * 
 * 
 *    def __mul__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1985
 * 
 * 
 *    def __div__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_15__div__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_15__div__ = {"__div__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_15__div__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_15__div__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_right = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__div__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_right,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1985, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_right)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1985, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__div__", 1, 2, 2, 1); __PYX_ERR(0, 1985, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__div__") < 0)) __PYX_ERR(0, 1985, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_right = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__div__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1985, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__div__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_14__div__(__pyx_self, __pyx_v_self, __pyx_v_right);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_14__div__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__div__", 0);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1986
 * 
 *    def __div__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_right, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1987
 *    def __div__(self,right):
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen             # <<<<<<<<<<<<<<
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_right, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1986
 * 
 *    def __div__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  }

  /* "giacpy/giacpy.pyx":1988
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self/right
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1989
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen             # <<<<<<<<<<<<<<
 *       return self/right
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1988
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self/right
 */
  }

  /* "giacpy/giacpy.pyx":1990
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 *       return self/right             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_v_self, __pyx_v_right); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1985
 * 
 * 
 *    def __div__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__div__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":1993
 * 
 * 
 *    def __truediv__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_17__truediv__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_17__truediv__ = {"__truediv__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_17__truediv__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_17__truediv__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_right = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__truediv__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_right,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1993, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_right)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1993, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__truediv__", 1, 2, 2, 1); __PYX_ERR(0, 1993, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__truediv__") < 0)) __PYX_ERR(0, 1993, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_right = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__truediv__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1993, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__truediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_16__truediv__(__pyx_self, __pyx_v_self, __pyx_v_right);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_16__truediv__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__truediv__", 0);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":1994
 * 
 *    def __truediv__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_right, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1995
 *    def __truediv__(self,right):
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen             # <<<<<<<<<<<<<<
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_right, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1994
 * 
 *    def __truediv__(self,right):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  }

  /* "giacpy/giacpy.pyx":1996
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self*right
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":1997
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen             # <<<<<<<<<<<<<<
 *       return self*right
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":1996
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self*right
 */
  }

  /* "giacpy/giacpy.pyx":1998
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 *       return self*right             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Multiply(__pyx_v_self, __pyx_v_right); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":1993
 * 
 * 
 *    def __truediv__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__truediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2001
 * 
 * 
 *    def __pow__(self,right,ignored):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_19__pow__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_19__pow__ = {"__pow__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_19__pow__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_19__pow__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_right = 0;
  CYTHON_UNUSED PyObject *__pyx_v_ignored = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pow__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_right,&__pyx_n_s_ignored,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2001, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_right)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2001, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pow__", 1, 3, 3, 1); __PYX_ERR(0, 2001, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignored)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2001, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pow__", 1, 3, 3, 2); __PYX_ERR(0, 2001, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pow__") < 0)) __PYX_ERR(0, 2001, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_right = values[1];
    __pyx_v_ignored = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pow__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 2001, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__pow__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_18__pow__(__pyx_self, __pyx_v_self, __pyx_v_right, __pyx_v_ignored);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_18__pow__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_right, CYTHON_UNUSED PyObject *__pyx_v_ignored) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pow__", 0);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_INCREF(__pyx_v_right);

  /* "giacpy/giacpy.pyx":2002
 * 
 *    def __pow__(self,right,ignored):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_right, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2002, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":2003
 *    def __pow__(self,right,ignored):
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen             # <<<<<<<<<<<<<<
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_right, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_right, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":2002
 * 
 *    def __pow__(self,right,ignored):
 *       if isinstance(right,GiacFunction):             # <<<<<<<<<<<<<<
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 */
  }

  /* "giacpy/giacpy.pyx":2004
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self**right
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_self, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 2004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "giacpy/giacpy.pyx":2005
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen             # <<<<<<<<<<<<<<
 *       return self**right
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_self, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "giacpy/giacpy.pyx":2004
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 *       if isinstance(self,GiacFunction):             # <<<<<<<<<<<<<<
 *          self=self.Pygen
 *       return self**right
 */
  }

  /* "giacpy/giacpy.pyx":2006
 *       if isinstance(self,GiacFunction):
 *          self=self.Pygen
 *       return self**right             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Power(__pyx_v_self, __pyx_v_right, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2001
 * 
 * 
 *    def __pow__(self,right,ignored):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__pow__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_self);
  __Pyx_XDECREF(__pyx_v_right);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2009
 * 
 * 
 *    def __neg__(self):             # <<<<<<<<<<<<<<
 *       return -self.Pygen
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_21__neg__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_21__neg__ = {"__neg__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_21__neg__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_21__neg__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__neg__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2009, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__neg__") < 0)) __PYX_ERR(0, 2009, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__neg__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2009, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__neg__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_20__neg__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_20__neg__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__neg__", 1);

  /* "giacpy/giacpy.pyx":2010
 * 
 *    def __neg__(self):
 *       return -self.Pygen             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Negative(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2009
 * 
 * 
 *    def __neg__(self):             # <<<<<<<<<<<<<<
 *       return -self.Pygen
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.__neg__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2013
 * 
 * 
 *    def diff(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.diff(args)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_23diff(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_23diff = {"diff", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_23diff, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_23diff(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("diff (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2013, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "diff") < 0)) __PYX_ERR(0, 2013, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("diff", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 2013, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.diff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_22diff(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_22diff(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("diff", 1);

  /* "giacpy/giacpy.pyx":2014
 * 
 *    def diff(self,*args):
 *       return self.Pygen.diff(args)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_diff); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_args};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2013
 * 
 * 
 *    def diff(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.diff(args)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.diff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2017
 * 
 * 
 *    def int(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.int(args)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_25int(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_25int = {"int", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_25int, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_25int(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("int (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2017, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "int") < 0)) __PYX_ERR(0, 2017, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("int", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 2017, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_24int(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_24int(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("int", 1);

  /* "giacpy/giacpy.pyx":2018
 * 
 *    def int(self,*args):
 *       return self.Pygen.int(args)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_args};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2017
 * 
 * 
 *    def int(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.int(args)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2021
 * 
 * 
 *    def plot(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.plot(args)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_27plot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_27plot = {"plot", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_27plot, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_27plot(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_args = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("plot (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  __pyx_v_args = __Pyx_ArgsSlice_FASTCALL(__pyx_args, 1, __pyx_nargs);
  if (unlikely(!__pyx_v_args)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_v_args);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        default:
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2021, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        const Py_ssize_t used_pos_args = (kwd_pos_args < 1) ? kwd_pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, used_pos_args, "plot") < 0)) __PYX_ERR(0, 2021, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs < 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("plot", 0, 1, 1, __pyx_nargs); __PYX_ERR(0, 2021, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_26plot(__pyx_self, __pyx_v_self, __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_26plot(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("plot", 1);

  /* "giacpy/giacpy.pyx":2022
 * 
 *    def plot(self,*args):
 *       return self.Pygen.plot(args)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_plot); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_args};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2021
 * 
 * 
 *    def plot(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.plot(args)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.plot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2025
 * 
 * 
 *    def htmlhelp(self,str lang='en'):             # <<<<<<<<<<<<<<
 *       return self.Pygen.htmlhelp(lang)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_29htmlhelp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_12GiacFunction_29htmlhelp = {"htmlhelp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_12GiacFunction_29htmlhelp, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_12GiacFunction_29htmlhelp(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_lang = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("htmlhelp (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_lang,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)((PyObject*)__pyx_n_s_en)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2025, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lang);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2025, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "htmlhelp") < 0)) __PYX_ERR(0, 2025, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_lang = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("htmlhelp", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 2025, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lang), (&PyString_Type), 1, "lang", 1))) __PYX_ERR(0, 2025, __pyx_L1_error)
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12GiacFunction_28htmlhelp(__pyx_self, __pyx_v_self, __pyx_v_lang);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12GiacFunction_28htmlhelp(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lang) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("htmlhelp", 1);

  /* "giacpy/giacpy.pyx":2026
 * 
 *    def htmlhelp(self,str lang='en'):
 *       return self.Pygen.htmlhelp(lang)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_htmlhelp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_lang};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2025
 * 
 * 
 *    def htmlhelp(self,str lang='en'):             # <<<<<<<<<<<<<<
 *       return self.Pygen.htmlhelp(lang)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("giacpy.giacpy.GiacFunction.htmlhelp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2061
 *    GiacMethods[i]=tmp
 * ##
 * def moretests():             # <<<<<<<<<<<<<<
 *    """
 *      >>> from giacpy import giac
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_11moretests(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_10moretests, "\n     >>> from giacpy import giac\n     >>> giac(3**100)\n     515377520732011331036461129765621272702107522001\n     >>> giac(-3**100)\n     -515377520732011331036461129765621272702107522001\n     >>> giac(-11**1000)\n     -2469932918005826334124088385085221477709733385238396234869182951830739390375433175367866116456946191973803561189036523363533798726571008961243792655536655282201820357872673322901148243453211756020067624545609411212063417307681204817377763465511222635167942816318177424600927358163388910854695041070577642045540560963004207926938348086979035423732739933235077042750354729095729602516751896320598857608367865475244863114521391548985943858154775884418927768284663678512441565517194156946312753546771163991252528017732162399536497445066348868438762510366191040118080751580689254476068034620047646422315123643119627205531371694188794408120267120500325775293645416335230014278578281272863450085145349124727476223298887655183167465713337723258182649072572861625150703747030550736347589416285606367521524529665763903537989935510874657420361426804068643262800901916285076966174176854351055183740078763891951775452021781225066361670593917001215032839838911476044840388663443684517735022039957481918726697789827894303408292584258328090724141496484460001\n    >>> v=[1,58,1387,17715,131260,578697,1538013,2648041,3687447,4993299,5858116,5979221,5239798,4098561,3176188,1660466,705432]\n    >>> giac(v)*v\n    175925584603774\n    >>> giac([v])*(giac([v]).transpose())\n    matrix[[175925584603774]]\n    >>> v=giac('pari()')\n    >>> if len(v)>200:\n    ...    giac('pari(18446744073709551616)')\n    ... else:\n    ...    giac('2^64')\n    18446744073709551616\n\n    Testing substraction of table/sparse matrix\n    >>> A=giacpy.table(())\n    >>> B=giacpy.table([[1]])\n    >>> A-B\n    table(\n    (0,0) = -1\n    )\n\n    Testing randseed\n    >>> from giacpy import randvector,randseed,srand\n    >>> a=randvector(50)\n    >>> randseed(10)\n    10\n    >>> a=randvector(50)\n    >"">> srand(10)\n    10\n    >>> a==randvector(50)\n    True\n \n   ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_11moretests = {"moretests", (PyCFunction)__pyx_pw_6giacpy_6giacpy_11moretests, METH_NOARGS, __pyx_doc_6giacpy_6giacpy_10moretests};
static PyObject *__pyx_pw_6giacpy_6giacpy_11moretests(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("moretests (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6giacpy_6giacpy_10moretests(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_10moretests(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("moretests", 1);

  /* "giacpy/giacpy.pyx":2102
 * 
 *    """
 *    return             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "giacpy/giacpy.pyx":2061
 *    GiacMethods[i]=tmp
 * ##
 * def moretests():             # <<<<<<<<<<<<<<
 *    """
 *      >>> from giacpy import giac
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "giacpy/giacpy.pyx":2106
 * 
 * 
 * def loadgiacgen(str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Open a file in giac compressed format to create a Pygen element.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_13loadgiacgen(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6giacpy_6giacpy_12loadgiacgen, "\n          Open a file in giac compressed format to create a Pygen element.\n\n          Use the save method from Pygen elements to create such files.\n\n          In C++ these files can be opened with giac::unarchive and created with\n          giac::archive\n\n            >>> from giacpy import *\n            >>> g=texpand('tan(10*a+3*b)')\n            >>> g.save(\"fichiertest\")           #  doctest: +SKIP\n            >>> a=loadgiacgen(\"fichiertest\")    #  doctest: +SKIP\n\n        ");
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_13loadgiacgen = {"loadgiacgen", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_13loadgiacgen, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_12loadgiacgen};
static PyObject *__pyx_pw_6giacpy_6giacpy_13loadgiacgen(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_filename = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("loadgiacgen (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_filename,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_filename)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2106, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "loadgiacgen") < 0)) __PYX_ERR(0, 2106, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_filename = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("loadgiacgen", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2106, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.loadgiacgen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_filename), (&PyString_Type), 1, "filename", 1))) __PYX_ERR(0, 2106, __pyx_L1_error)
  __pyx_r = __pyx_pf_6giacpy_6giacpy_12loadgiacgen(__pyx_self, __pyx_v_filename);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_12loadgiacgen(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_filename) {
  giac::gen __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  std::string __pyx_t_8;
  giac::gen __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("loadgiacgen", 1);

  /* "giacpy/giacpy.pyx":2122
 *         """
 *         cdef gen result
 *         ressetctrl_c()             # <<<<<<<<<<<<<<
 *         try:
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 2122, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":2123
 *         cdef gen result
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)
 *             return _wrap_gen(result)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "giacpy/giacpy.pyx":2124
 *         ressetctrl_c()
 *         try:
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)             # <<<<<<<<<<<<<<
 *             return _wrap_gen(result)
 *         except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_encstring23); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2124, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_filename};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2124, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_8 = __pyx_convert_string_from_py_6libcpp_6string_std__in_string(__pyx_t_4); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2124, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      try {
        __pyx_t_9 = unarchivegen(((std::string)__pyx_t_8), __pyx_v_6giacpy_6giacpy_context_ptr);
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 2124, __pyx_L3_error)
      }
      __pyx_v_result = __PYX_STD_MOVE_IF_SUPPORTED(__pyx_t_9);

      /* "giacpy/giacpy.pyx":2125
 *         try:
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)
 *             return _wrap_gen(result)             # <<<<<<<<<<<<<<
 *         except:
 *              raise RuntimeError
 */
      __Pyx_XDECREF(__pyx_r);
      try {
        __pyx_t_4 = __pyx_f_6giacpy_6giacpy__wrap_gen(__pyx_v_result);
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2125, __pyx_L3_error)
      } catch(...) {
        __Pyx_CppExn2PyErr();
        __PYX_ERR(0, 2125, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "giacpy/giacpy.pyx":2123
 *         cdef gen result
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)
 *             return _wrap_gen(result)
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "giacpy/giacpy.pyx":2126
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)
 *             return _wrap_gen(result)
 *         except:             # <<<<<<<<<<<<<<
 *              raise RuntimeError
 */
    /*except:*/ {
      __Pyx_AddTraceback("giacpy.giacpy.loadgiacgen", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 2126, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);

      /* "giacpy/giacpy.pyx":2127
 *             return _wrap_gen(result)
 *         except:
 *              raise RuntimeError             # <<<<<<<<<<<<<<
 */
      __Pyx_Raise(__pyx_builtin_RuntimeError, 0, 0, 0);
      __PYX_ERR(0, 2127, __pyx_L5_except_error)
    }

    /* "giacpy/giacpy.pyx":2123
 *         cdef gen result
 *         ressetctrl_c()
 *         try:             # <<<<<<<<<<<<<<
 *             result=GIAC_unarchive( <string>encstring23(filename), context_ptr)
 *             return _wrap_gen(result)
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "giacpy/giacpy.pyx":2106
 * 
 * 
 * def loadgiacgen(str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Open a file in giac compressed format to create a Pygen element.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("giacpy.giacpy.loadgiacgen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_GiacMethods_base(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_6giacpy_6giacpy_15__pyx_unpickle_GiacMethods_base(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6giacpy_6giacpy_15__pyx_unpickle_GiacMethods_base = {"__pyx_unpickle_GiacMethods_base", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_15__pyx_unpickle_GiacMethods_base, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6giacpy_6giacpy_15__pyx_unpickle_GiacMethods_base(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_GiacMethods_base (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_GiacMethods_base", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_GiacMethods_base", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_GiacMethods_base") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_GiacMethods_base", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("giacpy.giacpy.__pyx_unpickle_GiacMethods_base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6giacpy_6giacpy_14__pyx_unpickle_GiacMethods_base(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6giacpy_6giacpy_14__pyx_unpickle_GiacMethods_base(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_GiacMethods_base", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__13, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = GiacMethods_base.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = GiacMethods_base.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = GiacMethods_base.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = GiacMethods_base.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = GiacMethods_base.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_6giacpy_6giacpy___pyx_unpickle_GiacMethods_base__set_state(((struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = GiacMethods_base.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_GiacMethods_base(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("giacpy.giacpy.__pyx_unpickle_GiacMethods_base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_f_6giacpy_6giacpy___pyx_unpickle_GiacMethods_base__set_state(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_GiacMethods_base__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 > 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_GiacMethods_base__set_state(<GiacMethods_base> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_GiacMethods_base__set_state(GiacMethods_base __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("giacpy.giacpy.__pyx_unpickle_GiacMethods_base__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_6giacpy_6giacpy_GiacMethods_base(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  return o;
}

static void __pyx_tp_dealloc_6giacpy_6giacpy_GiacMethods_base(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6giacpy_6giacpy_GiacMethods_base) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static PyMethodDef __pyx_methods_6giacpy_6giacpy_GiacMethods_base[] = {
  {"Airy_Ai", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1Airy_Ai, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_Airy_Ai},
  {"Airy_Bi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3Airy_Bi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2Airy_Bi},
  {"Archive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_5Archive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_4Archive},
  {"BesselJ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_7BesselJ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_6BesselJ},
  {"BesselY", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_9BesselY, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_8BesselY},
  {"Beta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_11Beta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_10Beta},
  {"BlockDiagonal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_13BlockDiagonal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_12BlockDiagonal},
  {"Ci", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_15Ci, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_14Ci},
  {"Circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_17Circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_16Circle},
  {"Col", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_19Col, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_18Col},
  {"CopyVar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_21CopyVar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_20CopyVar},
  {"Dirac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_23Dirac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_22Dirac},
  {"Ei", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_25Ei, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_24Ei},
  {"Factor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_27Factor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_26Factor},
  {"Fourier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_29Fourier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_28Fourier},
  {"GF", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_31GF, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_30GF},
  {"Gamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_33Gamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_32Gamma},
  {"Heaviside", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_35Heaviside, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_34Heaviside},
  {"Heaviside2sign", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_37Heaviside2sign, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_36Heaviside2sign},
  {"Hilbert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_39Hilbert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_38Hilbert},
  {"JordanBlock", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_41JordanBlock, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_40JordanBlock},
  {"LU", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_43LU, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_42LU},
  {"LambertW", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_45LambertW, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_44LambertW},
  {"Li", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_47Li, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_46Li},
  {"Line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_49Line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_48Line},
  {"LineHorz", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_51LineHorz, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_50LineHorz},
  {"LineTan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_53LineTan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_52LineTan},
  {"LineVert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_55LineVert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_54LineVert},
  {"MSE", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_57MSE, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_56MSE},
  {"Phi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_59Phi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_58Phi},
  {"Pi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_61Pi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_60Pi},
  {"Psi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_63Psi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_62Psi},
  {"QR", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_65QR, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_64QR},
  {"RandSeed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_67RandSeed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_66RandSeed},
  {"ReLU", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_69ReLU, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_68ReLU},
  {"Row", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_71Row, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_70Row},
  {"SortA", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_73SortA, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_72SortA},
  {"SortD", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_75SortD, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_74SortD},
  {"UTPC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_77UTPC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_76UTPC},
  {"UTPF", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_79UTPF, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_78UTPF},
  {"UTPN", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_81UTPN, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_80UTPN},
  {"UTPT", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_83UTPT, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_82UTPT},
  {"VARS", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_85VARS, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_84VARS},
  {"VAS", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_87VAS, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_86VAS},
  {"VAS_positive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_89VAS_positive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_88VAS_positive},
  {"Zeta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_91Zeta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_90Zeta},
  {"a2q", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_93a2q, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_92a2q},
  {"abcuv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_95abcuv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_94abcuv},
  {"about", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_97about, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_96about},
  {"abs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_99abs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_98abs},
  {"abscissa", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_101abscissa, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_100abscissa},
  {"accumulate_head_tail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_103accumulate_head_tail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_102accumulate_head_tail},
  {"acos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_105acos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_104acos},
  {"acos2asin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_107acos2asin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_106acos2asin},
  {"acos2atan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_109acos2atan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_108acos2atan},
  {"acosh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_111acosh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_110acosh},
  {"acot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_113acot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_112acot},
  {"acsc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_115acsc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_114acsc},
  {"acyclic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_117acyclic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_116acyclic},
  {"adaptive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_119adaptive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_118adaptive},
  {"add", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_121add, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_120add},
  {"add_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_123add_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_122add_arc},
  {"add_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_125add_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_124add_edge},
  {"add_vertex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_127add_vertex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_126add_vertex},
  {"additionally", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_129additionally, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_128additionally},
  {"addtable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_131addtable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_130addtable},
  {"adjacency_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_133adjacency_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_132adjacency_matrix},
  {"adjoint_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_135adjoint_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_134adjoint_matrix},
  {"affix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_137affix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_136affix},
  {"algsubs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_139algsubs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_138algsubs},
  {"algvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_141algvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_140algvar},
  {"all_trig_solutions", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_143all_trig_solutions, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_142all_trig_solutions},
  {"allpairs_distance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_145allpairs_distance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_144allpairs_distance},
  {"alog10", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_147alog10, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_146alog10},
  {"altitude", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_149altitude, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_148altitude},
  {"angle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_151angle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_150angle},
  {"angle_radian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_153angle_radian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_152angle_radian},
  {"angleat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_155angleat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_154angleat},
  {"angleatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_157angleatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_156angleatraw},
  {"ans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_159ans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_158ans},
  {"antiprism_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_161antiprism_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_160antiprism_graph},
  {"append", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_163append, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_162append},
  {"apply", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_165apply, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_164apply},
  {"approx", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_167approx, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_166approx},
  {"arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_169arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_168arc},
  {"arcLen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_171arcLen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_170arcLen},
  {"arccos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_173arccos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_172arccos},
  {"arccosh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_175arccosh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_174arccosh},
  {"arclen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_177arclen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_176arclen},
  {"arcsin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_179arcsin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_178arcsin},
  {"arcsinh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_181arcsinh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_180arcsinh},
  {"arctan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_183arctan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_182arctan},
  {"arctanh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_185arctanh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_184arctanh},
  {"area", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_187area, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_186area},
  {"areaat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_189areaat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_188areaat},
  {"areaatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_191areaatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_190areaatraw},
  {"areaplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_193areaplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_192areaplot},
  {"arg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_195arg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_194arg},
  {"array", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_197array, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_196array},
  {"arrivals", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_199arrivals, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_198arrivals},
  {"articulation_points", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_201articulation_points, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_200articulation_points},
  {"asin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_203asin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_202asin},
  {"asin2acos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_205asin2acos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_204asin2acos},
  {"asin2atan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_207asin2atan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_206asin2atan},
  {"asinh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_209asinh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_208asinh},
  {"assign_edge_weights", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_211assign_edge_weights, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_210assign_edge_weights},
  {"assume", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_213assume, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_212assume},
  {"at", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_215at, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_214at},
  {"atan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_217atan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_216atan},
  {"atan2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_219atan2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_218atan2},
  {"atan2acos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_221atan2acos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_220atan2acos},
  {"atan2asin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_223atan2asin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_222atan2asin},
  {"atanh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_225atanh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_224atanh},
  {"atrig2ln", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_227atrig2ln, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_226atrig2ln},
  {"augment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_229augment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_228augment},
  {"auto_correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_231auto_correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_230auto_correlation},
  {"autosimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_233autosimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_232autosimplify},
  {"avance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_235avance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_234avance},
  {"avgRC", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_237avgRC, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_236avgRC},
  {"axes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_239axes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_238axes},
  {"axis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_241axis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_240axis},
  {"back", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_243back, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_242back},
  {"backward", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_245backward, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_244backward},
  {"baisse_crayon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_247baisse_crayon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_246baisse_crayon},
  {"bandwidth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_249bandwidth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_248bandwidth},
  {"bar_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_251bar_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_250bar_plot},
  {"barplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_253barplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_252barplot},
  {"bartlett_hann_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_255bartlett_hann_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_254bartlett_hann_window},
  {"barycenter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_257barycenter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_256barycenter},
  {"base", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_259base, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_258base},
  {"basis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_261basis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_260basis},
  {"batons", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_263batons, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_262batons},
  {"bellman_ford", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_265bellman_ford, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_264bellman_ford},
  {"berlekamp_massey", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_267berlekamp_massey, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_266berlekamp_massey},
  {"bernoulli", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_269bernoulli, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_268bernoulli},
  {"bernoulli_mod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_271bernoulli_mod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_270bernoulli_mod},
  {"besselJ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_273besselJ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_272besselJ},
  {"besselY", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_275besselY, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_274besselY},
  {"betad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_277betad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_276betad},
  {"betad_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_279betad_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_278betad_cdf},
  {"betad_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_281betad_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_280betad_icdf},
  {"betavariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_283betavariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_282betavariate},
  {"betweenness_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_285betweenness_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_284betweenness_centrality},
  {"bezier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_287bezier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_286bezier},
  {"bezout_entiers", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_289bezout_entiers, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_288bezout_entiers},
  {"bezoutian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_291bezoutian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_290bezoutian},
  {"biconnected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_293biconnected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_292biconnected_components},
  {"binomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_295binomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_294binomial},
  {"binomial_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_297binomial_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_296binomial_cdf},
  {"binomial_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_299binomial_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_298binomial_icdf},
  {"bins", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_301bins, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_300bins},
  {"bipartite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_303bipartite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_302bipartite},
  {"bipartite_matching", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_305bipartite_matching, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_304bipartite_matching},
  {"bisection_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_307bisection_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_306bisection_solver},
  {"bisector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_309bisector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_308bisector},
  {"bit_depth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_311bit_depth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_310bit_depth},
  {"bitand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_313bitand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_312bitand},
  {"bitor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_315bitor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_314bitor},
  {"bitxor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_317bitxor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_316bitxor},
  {"blackman_harris_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_319blackman_harris_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_318blackman_harris_window},
  {"blackman_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_321blackman_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_320blackman_window},
  {"block_size", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_323block_size, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_322block_size},
  {"blockmatrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_325blockmatrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_324blockmatrix},
  {"bohman_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_327bohman_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_326bohman_window},
  {"border", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_329border, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_328border},
  {"box_constraints", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_331box_constraints, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_330box_constraints},
  {"boxcar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_333boxcar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_332boxcar},
  {"boxwhisker", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_335boxwhisker, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_334boxwhisker},
  {"brent_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_337brent_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_336brent_solver},
  {"brown", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_339brown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_338brown},
  {"bspline", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_341bspline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_340bspline},
  {"bvpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_343bvpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_342bvpsolve},
  {"cFactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_345cFactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_344cFactor},
  {"cSolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_347cSolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_346cSolve},
  {"cZeros", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_349cZeros, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_348cZeros},
  {"camembert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_351camembert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_350camembert},
  {"canonical_form", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_353canonical_form, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_352canonical_form},
  {"canonical_labeling", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_355canonical_labeling, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_354canonical_labeling},
  {"cartesian_product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_357cartesian_product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_356cartesian_product},
  {"cauchy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_359cauchy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_358cauchy},
  {"cauchy_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_361cauchy_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_360cauchy_cdf},
  {"cauchy_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_363cauchy_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_362cauchy_icdf},
  {"cauchyd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_365cauchyd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_364cauchyd},
  {"cauchyd_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_367cauchyd_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_366cauchyd_cdf},
  {"cauchyd_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_369cauchyd_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_368cauchyd_icdf},
  {"cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_371cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_370cdf},
  {"ceil", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_373ceil, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_372ceil},
  {"ceiling", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_375ceiling, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_374ceiling},
  {"center", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_377center, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_376center},
  {"center2interval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_379center2interval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_378center2interval},
  {"centered_cube", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_381centered_cube, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_380centered_cube},
  {"centered_tetrahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_383centered_tetrahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_382centered_tetrahedron},
  {"cfactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_385cfactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_384cfactor},
  {"cfsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_387cfsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_386cfsolve},
  {"changebase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_389changebase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_388changebase},
  {"channel_data", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_391channel_data, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_390channel_data},
  {"channels", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_393channels, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_392channels},
  {"char", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_395char, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_394char},
  {"charpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_397charpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_396charpoly},
  {"chinrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_399chinrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_398chinrem},
  {"chisquare", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_401chisquare, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_400chisquare},
  {"chisquare_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_403chisquare_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_402chisquare_cdf},
  {"chisquare_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_405chisquare_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_404chisquare_icdf},
  {"chisquared", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_407chisquared, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_406chisquared},
  {"chisquared_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_409chisquared_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_408chisquared_cdf},
  {"chisquared_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_411chisquared_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_410chisquared_icdf},
  {"chisquaret", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_413chisquaret, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_412chisquaret},
  {"choice", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_415choice, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_414choice},
  {"cholesky", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_417cholesky, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_416cholesky},
  {"chr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_419chr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_418chr},
  {"chrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_421chrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_420chrem},
  {"chromatic_index", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_423chromatic_index, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_422chromatic_index},
  {"chromatic_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_425chromatic_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_424chromatic_number},
  {"chromatic_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_427chromatic_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_426chromatic_polynomial},
  {"circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_429circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_428circle},
  {"circumcircle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_431circumcircle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_430circumcircle},
  {"classes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_433classes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_432classes},
  {"clear", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_435clear, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_434clear},
  {"clique_cover", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_437clique_cover, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_436clique_cover},
  {"clique_cover_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_439clique_cover_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_438clique_cover_number},
  {"clique_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_441clique_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_440clique_number},
  {"closeness_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_443closeness_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_442closeness_centrality},
  {"cluster", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_445cluster, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_444cluster},
  {"clustering_coefficient", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_447clustering_coefficient, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_446clustering_coefficient},
  {"coeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_449coeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_448coeff},
  {"coeffs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_451coeffs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_450coeffs},
  {"col", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_453col, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_452col},
  {"colDim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_455colDim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_454colDim},
  {"colNorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_457colNorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_456colNorm},
  {"colSwap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_459colSwap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_458colSwap},
  {"coldim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_461coldim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_460coldim},
  {"collect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_463collect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_462collect},
  {"colnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_465colnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_464colnorm},
  {"color", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_467color, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_466color},
  {"colormap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_469colormap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_468colormap},
  {"colspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_471colspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_470colspace},
  {"colswap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_473colswap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_472colswap},
  {"comDenom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_475comDenom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_474comDenom},
  {"comb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_477comb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_476comb},
  {"combine", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_479combine, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_478combine},
  {"comment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_481comment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_480comment},
  {"common_perpendicular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_483common_perpendicular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_482common_perpendicular},
  {"companion", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_485companion, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_484companion},
  {"compare", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_487compare, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_486compare},
  {"complete_binary_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_489complete_binary_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_488complete_binary_tree},
  {"complete_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_491complete_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_490complete_graph},
  {"complete_kary_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_493complete_kary_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_492complete_kary_tree},
  {"complex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_495complex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_494complex},
  {"complex_variables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_497complex_variables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_496complex_variables},
  {"complexroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_499complexroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_498complexroot},
  {"concat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_501concat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_500concat},
  {"cond", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_503cond, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_502cond},
  {"condensation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_505condensation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_504condensation},
  {"cone", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_507cone, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_506cone},
  {"confrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_509confrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_508confrac},
  {"conic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_511conic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_510conic},
  {"conj", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_513conj, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_512conj},
  {"conjugate_equation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_515conjugate_equation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_514conjugate_equation},
  {"conjugate_gradient", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_517conjugate_gradient, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_516conjugate_gradient},
  {"connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_519connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_518connected},
  {"connected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_521connected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_520connected_components},
  {"cont", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_523cont, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_522cont},
  {"contains", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_525contains, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_524contains},
  {"content", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_527content, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_526content},
  {"contourplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_529contourplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_528contourplot},
  {"contract_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_531contract_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_530contract_edge},
  {"contract_subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_533contract_subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_532contract_subgraph},
  {"convert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_535convert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_534convert},
  {"convertir", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_537convertir, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_536convertir},
  {"convex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_539convex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_538convex},
  {"convexhull", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_541convexhull, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_540convexhull},
  {"convolution", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_543convolution, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_542convolution},
  {"coordinates", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_545coordinates, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_544coordinates},
  {"copy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_547copy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_546copy},
  {"correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_549correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_548correlation},
  {"cos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_551cos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_550cos},
  {"cos2sintan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_553cos2sintan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_552cos2sintan},
  {"cosh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_555cosh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_554cosh},
  {"cosine_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_557cosine_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_556cosine_window},
  {"cot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_559cot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_558cot},
  {"cote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_561cote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_560cote},
  {"count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_563count, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_562count},
  {"count_eq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_565count_eq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_564count_eq},
  {"count_inf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_567count_inf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_566count_inf},
  {"count_sup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_569count_sup, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_568count_sup},
  {"courbe_parametrique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_571courbe_parametrique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_570courbe_parametrique},
  {"courbe_polaire", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_573courbe_polaire, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_572courbe_polaire},
  {"covariance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_575covariance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_574covariance},
  {"covariance_correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_577covariance_correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_576covariance_correlation},
  {"cpartfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_579cpartfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_578cpartfrac},
  {"crationalroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_581crationalroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_580crationalroot},
  {"crayon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_583crayon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_582crayon},
  {"createwav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_585createwav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_584createwav},
  {"cross", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_587cross, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_586cross},
  {"crossP", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_589crossP, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_588crossP},
  {"cross_correlation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_591cross_correlation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_590cross_correlation},
  {"cross_entropy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_593cross_entropy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_592cross_entropy},
  {"cross_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_595cross_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_594cross_point},
  {"cross_ratio", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_597cross_ratio, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_596cross_ratio},
  {"crossproduct", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_599crossproduct, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_598crossproduct},
  {"csc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_601csc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_600csc},
  {"csolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_603csolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_602csolve},
  {"csv2gen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_605csv2gen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_604csv2gen},
  {"cube", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_607cube, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_606cube},
  {"cumSum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_609cumSum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_608cumSum},
  {"cumsum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_611cumsum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_610cumsum},
  {"cumulated_frequencies", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_613cumulated_frequencies, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_612cumulated_frequencies},
  {"curl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_615curl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_614curl},
  {"current_sheet", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_617current_sheet, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_616current_sheet},
  {"curvature", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_619curvature, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_618curvature},
  {"curve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_621curve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_620curve},
  {"cyan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_623cyan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_622cyan},
  {"cycle2perm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_625cycle2perm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_624cycle2perm},
  {"cycle_basis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_627cycle_basis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_626cycle_basis},
  {"cycle_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_629cycle_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_628cycle_graph},
  {"cycleinv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_631cycleinv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_630cycleinv},
  {"cycles2permu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_633cycles2permu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_632cycles2permu},
  {"cyclotomic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_635cyclotomic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_634cyclotomic},
  {"cylinder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_637cylinder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_636cylinder},
  {"dash_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_639dash_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_638dash_line},
  {"dashdot_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_641dashdot_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_640dashdot_line},
  {"dashdotdot_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_643dashdotdot_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_642dashdotdot_line},
  {"dayofweek", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_645dayofweek, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_644dayofweek},
  {"deSolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_647deSolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_646deSolve},
  {"debut_enregistrement", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_649debut_enregistrement, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_648debut_enregistrement},
  {"degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_651degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_650degree},
  {"degree_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_653degree_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_652degree_centrality},
  {"degree_sequence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_655degree_sequence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_654degree_sequence},
  {"degrees", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_657degrees, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_656degrees},
  {"delcols", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_659delcols, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_658delcols},
  {"delete_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_661delete_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_660delete_arc},
  {"delete_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_663delete_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_662delete_edge},
  {"delete_vertex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_665delete_vertex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_664delete_vertex},
  {"delrows", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_667delrows, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_666delrows},
  {"deltalist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_669deltalist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_668deltalist},
  {"denom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_671denom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_670denom},
  {"densityplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_673densityplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_672densityplot},
  {"departures", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_675departures, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_674departures},
  {"derive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_677derive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_676derive},
  {"deriver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_679deriver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_678deriver},
  {"desolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_681desolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_680desolve},
  {"dessine_tortue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_683dessine_tortue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_682dessine_tortue},
  {"det", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_685det, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_684det},
  {"det_minor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_687det_minor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_686det_minor},
  {"developper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_689developper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_688developper},
  {"developper_transcendant", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_691developper_transcendant, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_690developper_transcendant},
  {"dfc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_693dfc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_692dfc},
  {"dfc2f", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_695dfc2f, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_694dfc2f},
  {"diag", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_697diag, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_696diag},
  {"diff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_699diff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_698diff},
  {"digraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_701digraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_700digraph},
  {"dijkstra", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_703dijkstra, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_702dijkstra},
  {"dim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_705dim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_704dim},
  {"directed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_707directed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_706directed},
  {"discard_edge_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_709discard_edge_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_708discard_edge_attribute},
  {"discard_graph_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_711discard_graph_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_710discard_graph_attribute},
  {"discard_vertex_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_713discard_vertex_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_712discard_vertex_attribute},
  {"disjoint_union", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_715disjoint_union, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_714disjoint_union},
  {"display", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_717display, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_716display},
  {"disque", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_719disque, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_718disque},
  {"disque_centre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_721disque_centre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_720disque_centre},
  {"distance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_723distance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_722distance},
  {"distance2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_725distance2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_724distance2},
  {"distanceat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_727distanceat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_726distanceat},
  {"distanceatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_729distanceatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_728distanceatraw},
  {"divergence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_731divergence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_730divergence},
  {"divide", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_733divide, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_732divide},
  {"divis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_735divis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_734divis},
  {"division_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_737division_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_736division_point},
  {"divisors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_739divisors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_738divisors},
  {"divmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_741divmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_740divmod},
  {"divpc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_743divpc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_742divpc},
  {"dnewton_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_745dnewton_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_744dnewton_solver},
  {"dodecahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_747dodecahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_746dodecahedron},
  {"domain", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_749domain, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_748domain},
  {"dot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_751dot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_750dot},
  {"dotP", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_753dotP, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_752dotP},
  {"dot_paper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_755dot_paper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_754dot_paper},
  {"dotprod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_757dotprod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_756dotprod},
  {"draw_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_759draw_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_758draw_arc},
  {"draw_circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_761draw_circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_760draw_circle},
  {"draw_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_763draw_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_762draw_graph},
  {"draw_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_765draw_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_764draw_line},
  {"draw_pixel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_767draw_pixel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_766draw_pixel},
  {"draw_polygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_769draw_polygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_768draw_polygon},
  {"draw_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_771draw_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_770draw_rectangle},
  {"droit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_773droit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_772droit},
  {"droite_tangente", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_775droite_tangente, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_774droite_tangente},
  {"dsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_777dsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_776dsolve},
  {"duration", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_779duration, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_778duration},
  {"dwt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_781dwt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_780dwt},
  {"e", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_783e, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_782e},
  {"e2r", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_785e2r, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_784e2r},
  {"ecart_type", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_787ecart_type, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_786ecart_type},
  {"ecart_type_population", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_789ecart_type_population, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_788ecart_type_population},
  {"ecef2geodetic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_791ecef2geodetic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_790ecef2geodetic},
  {"ecm_factor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_793ecm_factor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_792ecm_factor},
  {"edge_connectivity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_795edge_connectivity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_794edge_connectivity},
  {"edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_797edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_796edges},
  {"egcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_799egcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_798egcd},
  {"egv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_801egv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_800egv},
  {"egvl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_803egvl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_802egvl},
  {"eigVc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_805eigVc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_804eigVc},
  {"eigVl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_807eigVl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_806eigVl},
  {"eigenvals", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_809eigenvals, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_808eigenvals},
  {"eigenvalues", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_811eigenvalues, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_810eigenvalues},
  {"eigenvectors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_813eigenvectors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_812eigenvectors},
  {"eigenvects", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_815eigenvects, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_814eigenvects},
  {"element", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_817element, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_816element},
  {"eliminate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_819eliminate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_818eliminate},
  {"ellipse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_821ellipse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_820ellipse},
  {"emd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_823emd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_822emd},
  {"entry", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_825entry, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_824entry},
  {"envelope", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_827envelope, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_826envelope},
  {"epsilon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_829epsilon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_828epsilon},
  {"epsilon2zero", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_831epsilon2zero, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_830epsilon2zero},
  {"equal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_833equal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_832equal},
  {"equal2diff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_835equal2diff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_834equal2diff},
  {"equal2list", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_837equal2list, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_836equal2list},
  {"equation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_839equation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_838equation},
  {"equilateral_triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_841equilateral_triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_840equilateral_triangle},
  {"erf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_843erf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_842erf},
  {"erfc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_845erfc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_844erfc},
  {"error", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_847error, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_846error},
  {"est_permu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_849est_permu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_848est_permu},
  {"euler", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_851euler, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_850euler},
  {"euler_gamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_853euler_gamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_852euler_gamma},
  {"euler_lagrange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_855euler_lagrange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_854euler_lagrange},
  {"eval_level", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_857eval_level, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_856eval_level},
  {"evala", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_859evala, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_858evala},
  {"evalb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_861evalb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_860evalb},
  {"evalc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_863evalc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_862evalc},
  {"evalf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_865evalf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_864evalf},
  {"evalm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_867evalm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_866evalm},
  {"even", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_869even, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_868even},
  {"evolute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_871evolute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_870evolute},
  {"exact", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_873exact, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_872exact},
  {"exbisector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_875exbisector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_874exbisector},
  {"excircle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_877excircle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_876excircle},
  {"execute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_879execute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_878execute},
  {"exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_881exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_880exp},
  {"exp2list", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_883exp2list, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_882exp2list},
  {"exp2pow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_885exp2pow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_884exp2pow},
  {"exp2trig", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_887exp2trig, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_886exp2trig},
  {"expand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_889expand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_888expand},
  {"expexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_891expexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_890expexpand},
  {"expln", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_893expln, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_892expln},
  {"exponential", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_895exponential, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_894exponential},
  {"exponential_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_897exponential_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_896exponential_cdf},
  {"exponential_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_899exponential_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_898exponential_icdf},
  {"exponential_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_901exponential_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_900exponential_regression},
  {"exponential_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_903exponential_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_902exponential_regression_plot},
  {"exponentiald", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_905exponentiald, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_904exponentiald},
  {"exponentiald_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_907exponentiald_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_906exponentiald_cdf},
  {"exponentiald_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_909exponentiald_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_908exponentiald_icdf},
  {"export_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_911export_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_910export_graph},
  {"export_mathml", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_913export_mathml, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_912export_mathml},
  {"expovariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_915expovariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_914expovariate},
  {"expr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_917expr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_916expr},
  {"extend", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_919extend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_918extend},
  {"extract_measure", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_921extract_measure, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_920extract_measure},
  {"extrema", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_923extrema, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_922extrema},
  {"ezgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_925ezgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_924ezgcd},
  {"f2nd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_927f2nd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_926f2nd},
  {"fMax", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_929fMax, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_928fMax},
  {"fMin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_931fMin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_930fMin},
  {"fPart", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_933fPart, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_932fPart},
  {"faces", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_935faces, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_934faces},
  {"facteurs_premiers", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_937facteurs_premiers, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_936facteurs_premiers},
  {"factor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_939factor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_938factor},
  {"factor_xn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_941factor_xn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_940factor_xn},
  {"factorial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_943factorial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_942factorial},
  {"factoriser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_945factoriser, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_944factoriser},
  {"factoriser_entier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_947factoriser_entier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_946factoriser_entier},
  {"factoriser_sur_C", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_949factoriser_sur_C, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_948factoriser_sur_C},
  {"factors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_951factors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_950factors},
  {"fadeev", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_953fadeev, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_952fadeev},
  {"false", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_955false, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_954false},
  {"falsepos_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_957falsepos_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_956falsepos_solver},
  {"fclose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_959fclose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_958fclose},
  {"fcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_961fcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_960fcoeff},
  {"fdistrib", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_963fdistrib, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_962fdistrib},
  {"fft", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_965fft, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_964fft},
  {"fieldplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_967fieldplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_966fieldplot},
  {"find", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_969find, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_968find},
  {"find_cliques", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_971find_cliques, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_970find_cliques},
  {"find_cycles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_973find_cycles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_972find_cycles},
  {"find_minimum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_975find_minimum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_974find_minimum},
  {"find_vertex_cover", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_977find_vertex_cover, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_976find_vertex_cover},
  {"findhelp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_979findhelp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_978findhelp},
  {"fisher", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_981fisher, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_980fisher},
  {"fisher_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_983fisher_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_982fisher_cdf},
  {"fisher_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_985fisher_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_984fisher_icdf},
  {"fisherd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_987fisherd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_986fisherd},
  {"fisherd_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_989fisherd_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_988fisherd_cdf},
  {"fisherd_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_991fisherd_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_990fisherd_icdf},
  {"fitdistr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_993fitdistr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_992fitdistr},
  {"fitpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_995fitpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_994fitpoly},
  {"fitspline", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_997fitspline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_996fitspline},
  {"flatten", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_999flatten, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_998flatten},
  {"float2rational", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1001float2rational, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1000float2rational},
  {"floor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1003floor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1002floor},
  {"flow_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1005flow_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1004flow_polynomial},
  {"flower_snark", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1007flower_snark, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1006flower_snark},
  {"fmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1009fmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1008fmod},
  {"foldl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1011foldl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1010foldl},
  {"foldr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1013foldr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1012foldr},
  {"fonction_derivee", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1015fonction_derivee, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1014fonction_derivee},
  {"forward", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1017forward, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1016forward},
  {"fourier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1019fourier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1018fourier},
  {"fourier_an", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1021fourier_an, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1020fourier_an},
  {"fourier_bn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1023fourier_bn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1022fourier_bn},
  {"fourier_cn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1025fourier_cn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1024fourier_cn},
  {"fprint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1027fprint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1026fprint},
  {"frac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1029frac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1028frac},
  {"fracmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1031fracmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1030fracmod},
  {"frame_2d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1033frame_2d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1032frame_2d},
  {"frank_wolfe", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1035frank_wolfe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1034frank_wolfe},
  {"frequencies", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1037frequencies, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1036frequencies},
  {"frobenius_norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1039frobenius_norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1038frobenius_norm},
  {"froot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1041froot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1040froot},
  {"fsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1043fsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1042fsolve},
  {"fullparfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1045fullparfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1044fullparfrac},
  {"funcplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1047funcplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1046funcplot},
  {"function_diff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1049function_diff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1048function_diff},
  {"fundamental_cycle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1051fundamental_cycle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1050fundamental_cycle},
  {"fxnd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1053fxnd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1052fxnd},
  {"gammad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1055gammad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1054gammad},
  {"gammad_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1057gammad_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1056gammad_cdf},
  {"gammad_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1059gammad_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1058gammad_icdf},
  {"gammavariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1061gammavariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1060gammavariate},
  {"gauss", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1063gauss, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1062gauss},
  {"gauss15", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1065gauss15, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1064gauss15},
  {"gauss_seidel_linsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1067gauss_seidel_linsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1066gauss_seidel_linsolve},
  {"gaussian_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1069gaussian_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1068gaussian_window},
  {"gaussjord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1071gaussjord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1070gaussjord},
  {"gaussquad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1073gaussquad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1072gaussquad},
  {"gbasis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1075gbasis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1074gbasis},
  {"gbasis_max_pairs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1077gbasis_max_pairs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1076gbasis_max_pairs},
  {"gbasis_reinject", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1079gbasis_reinject, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1078gbasis_reinject},
  {"gbasis_simult_primes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1081gbasis_simult_primes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1080gbasis_simult_primes},
  {"gcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1083gcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1082gcd},
  {"gcdex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1085gcdex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1084gcdex},
  {"genpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1087genpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1086genpoly},
  {"geodetic2ecef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1089geodetic2ecef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1088geodetic2ecef},
  {"geometric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1091geometric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1090geometric},
  {"geometric_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1093geometric_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1092geometric_cdf},
  {"geometric_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1095geometric_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1094geometric_icdf},
  {"getDenom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1097getDenom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1096getDenom},
  {"getKey", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1099getKey, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1098getKey},
  {"getNum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1101getNum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1100getNum},
  {"getType", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1103getType, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1102getType},
  {"get_edge_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1105get_edge_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1104get_edge_attribute},
  {"get_edge_weight", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1107get_edge_weight, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1106get_edge_weight},
  {"get_graph_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1109get_graph_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1108get_graph_attribute},
  {"get_vertex_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1111get_vertex_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1110get_vertex_attribute},
  {"girth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1113girth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1112girth},
  {"gl_showaxes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1115gl_showaxes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1114gl_showaxes},
  {"gold", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1117gold, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1116gold},
  {"goldberg_snark", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1119goldberg_snark, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1118goldberg_snark},
  {"grad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1121grad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1120grad},
  {"gramschmidt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1123gramschmidt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1122gramschmidt},
  {"graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1125graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1124graph},
  {"graph_automorphisms", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1127graph_automorphisms, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1126graph_automorphisms},
  {"graph_charpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1129graph_charpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1128graph_charpoly},
  {"graph_complement", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1131graph_complement, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1130graph_complement},
  {"graph_diameter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1133graph_diameter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1132graph_diameter},
  {"graph_equal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1135graph_equal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1134graph_equal},
  {"graph_join", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1137graph_join, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1136graph_join},
  {"graph_power", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1139graph_power, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1138graph_power},
  {"graph_rank", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1141graph_rank, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1140graph_rank},
  {"graph_spectrum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1143graph_spectrum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1142graph_spectrum},
  {"graph_union", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1145graph_union, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1144graph_union},
  {"graph_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1147graph_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1146graph_vertices},
  {"greduce", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1149greduce, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1148greduce},
  {"greedy_clique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1151greedy_clique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1150greedy_clique},
  {"greedy_color", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1153greedy_color, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1152greedy_color},
  {"greedy_independent_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1155greedy_independent_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1154greedy_independent_set},
  {"grey", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1157grey, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1156grey},
  {"grid_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1159grid_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1158grid_graph},
  {"groupermu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1161groupermu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1160groupermu},
  {"haar_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1163haar_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1162haar_graph},
  {"hadamard", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1165hadamard, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1164hadamard},
  {"half_cone", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1167half_cone, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1166half_cone},
  {"half_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1169half_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1168half_line},
  {"halftan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1171halftan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1170halftan},
  {"halftan_hyp2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1173halftan_hyp2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1172halftan_hyp2exp},
  {"halt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1175halt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1174halt},
  {"hamdist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1177hamdist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1176hamdist},
  {"hamming", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1179hamming, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1178hamming},
  {"hamming_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1181hamming_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1180hamming_window},
  {"hann_poisson_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1183hann_poisson_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1182hann_poisson_window},
  {"hann_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1185hann_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1184hann_window},
  {"harmonic_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1187harmonic_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1186harmonic_centrality},
  {"harmonic_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1189harmonic_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1188harmonic_conjugate},
  {"harmonic_division", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1191harmonic_division, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1190harmonic_division},
  {"has", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1193has, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1192has},
  {"has_arc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1195has_arc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1194has_arc},
  {"has_edge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1197has_edge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1196has_edge},
  {"hasard", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1199hasard, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1198hasard},
  {"head", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1201head, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1200head},
  {"heading", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1203heading, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1202heading},
  {"heapify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1205heapify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1204heapify},
  {"heappop", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1207heappop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1206heappop},
  {"heappush", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1209heappush, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1208heappush},
  {"hermite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1211hermite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1210hermite},
  {"hessenberg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1213hessenberg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1212hessenberg},
  {"hessian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1215hessian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1214hessian},
  {"heugcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1217heugcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1216heugcd},
  {"hexagon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1219hexagon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1218hexagon},
  {"hht", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1221hht, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1220hht},
  {"highlight_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1223highlight_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1222highlight_edges},
  {"highlight_subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1225highlight_subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1224highlight_subgraph},
  {"highlight_trail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1227highlight_trail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1226highlight_trail},
  {"highlight_vertex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1229highlight_vertex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1228highlight_vertex},
  {"highpass", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1231highpass, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1230highpass},
  {"hilbert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1233hilbert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1232hilbert},
  {"histogram", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1235histogram, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1234histogram},
  {"hold", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1237hold, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1236hold},
  {"homogeneize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1239homogeneize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1238homogeneize},
  {"homothety", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1241homothety, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1240homothety},
  {"horner", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1243horner, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1242horner},
  {"hsv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1245hsv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1244hsv},
  {"hsv2rgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1247hsv2rgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1246hsv2rgb},
  {"hybrid_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1249hybrid_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1248hybrid_solver},
  {"hybridj_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1251hybridj_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1250hybridj_solver},
  {"hybrids_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1253hybrids_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1252hybrids_solver},
  {"hybridsj_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1255hybridsj_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1254hybridsj_solver},
  {"hyp2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1257hyp2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1256hyp2exp},
  {"hyperbola", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1259hyperbola, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1258hyperbola},
  {"hypercube_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1261hypercube_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1260hypercube_graph},
  {"iPart", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1263iPart, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1262iPart},
  {"iabcuv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1265iabcuv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1264iabcuv},
  {"ibasis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1267ibasis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1266ibasis},
  {"ibpdv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1269ibpdv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1268ibpdv},
  {"ibpu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1271ibpu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1270ibpu},
  {"icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1273icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1272icdf},
  {"ichinrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1275ichinrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1274ichinrem},
  {"ichrem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1277ichrem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1276ichrem},
  {"icomp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1279icomp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1278icomp},
  {"icontent", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1281icontent, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1280icontent},
  {"icosahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1283icosahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1282icosahedron},
  {"id", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1285id, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1284id},
  {"identify_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1287identify_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1286identify_graph},
  {"identity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1289identity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1288identity},
  {"idivis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1291idivis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1290idivis},
  {"idn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1293idn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1292idn},
  {"idwt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1295idwt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1294idwt},
  {"iegcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1297iegcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1296iegcd},
  {"ifactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1299ifactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1298ifactor},
  {"ifactors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1301ifactors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1300ifactors},
  {"ifourier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1303ifourier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1302ifourier},
  {"igamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1305igamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1304igamma},
  {"igcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1307igcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1306igcd},
  {"igcdex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1309igcdex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1308igcdex},
  {"ihermite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1311ihermite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1310ihermite},
  {"ilaplace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1313ilaplace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1312ilaplace},
  {"im", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1315im, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1314im},
  {"imag", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1317imag, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1316imag},
  {"image", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1319image, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1318image},
  {"imfplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1321imfplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1320imfplot},
  {"implicitdiff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1323implicitdiff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1322implicitdiff},
  {"implicitplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1325implicitplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1324implicitplot},
  {"import_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1327import_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1326import_graph},
  {"inString", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1329inString, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1328inString},
  {"in_ideal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1331in_ideal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1330in_ideal},
  {"incidence_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1333incidence_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1332incidence_matrix},
  {"incident_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1335incident_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1334incident_edges},
  {"incircle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1337incircle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1336incircle},
  {"increasing_power", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1339increasing_power, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1338increasing_power},
  {"independence_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1341independence_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1340independence_number},
  {"indets", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1343indets, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1342indets},
  {"index", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1345index, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1344index},
  {"induced_subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1347induced_subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1346induced_subgraph},
  {"inequationplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1349inequationplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1348inequationplot},
  {"inertia", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1351inertia, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1350inertia},
  {"inf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1353inf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1352inf},
  {"infinity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1355infinity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1354infinity},
  {"information_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1357information_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1356information_centrality},
  {"insert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1359insert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1358insert},
  {"insmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1361insmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1360insmod},
  {"instfreq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1363instfreq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1362instfreq},
  {"instphase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1365instphase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1364instphase},
  {"int", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1367int, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1366int},
  {"intDiv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1369intDiv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1368intDiv},
  {"integer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1371integer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1370integer},
  {"integrate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1373integrate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1372integrate},
  {"integrer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1375integrer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1374integrer},
  {"inter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1377inter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1376inter},
  {"interactive_odeplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1379interactive_odeplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1378interactive_odeplot},
  {"interactive_plotode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1381interactive_plotode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1380interactive_plotode},
  {"interp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1383interp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1382interp},
  {"interval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1385interval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1384interval},
  {"interval2center", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1387interval2center, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1386interval2center},
  {"interval_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1389interval_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1388interval_graph},
  {"inv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1391inv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1390inv},
  {"inverse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1393inverse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1392inverse},
  {"inversion", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1395inversion, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1394inversion},
  {"invisible_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1397invisible_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1396invisible_point},
  {"invlaplace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1399invlaplace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1398invlaplace},
  {"invztrans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1401invztrans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1400invztrans},
  {"iquo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1403iquo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1402iquo},
  {"iquorem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1405iquorem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1404iquorem},
  {"iratrecon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1407iratrecon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1406iratrecon},
  {"irem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1409irem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1408irem},
  {"isPrime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1411isPrime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1410isPrime},
  {"is_acyclic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1413is_acyclic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1412is_acyclic},
  {"is_arborescence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1415is_arborescence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1414is_arborescence},
  {"is_biconnected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1417is_biconnected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1416is_biconnected},
  {"is_bipartite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1419is_bipartite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1418is_bipartite},
  {"is_clique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1421is_clique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1420is_clique},
  {"is_collinear", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1423is_collinear, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1422is_collinear},
  {"is_concyclic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1425is_concyclic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1424is_concyclic},
  {"is_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1427is_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1426is_conjugate},
  {"is_connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1429is_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1428is_connected},
  {"is_coplanar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1431is_coplanar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1430is_coplanar},
  {"is_cospherical", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1433is_cospherical, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1432is_cospherical},
  {"is_cut_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1435is_cut_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1434is_cut_set},
  {"is_cycle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1437is_cycle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1436is_cycle},
  {"is_directed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1439is_directed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1438is_directed},
  {"is_element", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1441is_element, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1440is_element},
  {"is_equilateral", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1443is_equilateral, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1442is_equilateral},
  {"is_eulerian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1445is_eulerian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1444is_eulerian},
  {"is_forest", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1447is_forest, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1446is_forest},
  {"is_graphic_sequence", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1449is_graphic_sequence, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1448is_graphic_sequence},
  {"is_hamiltonian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1451is_hamiltonian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1450is_hamiltonian},
  {"is_harmonic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1453is_harmonic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1452is_harmonic},
  {"is_harmonic_circle_bundle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1455is_harmonic_circle_bundle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1454is_harmonic_circle_bundle},
  {"is_harmonic_line_bundle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1457is_harmonic_line_bundle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1456is_harmonic_line_bundle},
  {"is_inside", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1459is_inside, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1458is_inside},
  {"is_integer_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1461is_integer_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1460is_integer_graph},
  {"is_irreducible", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1463is_irreducible, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1462is_irreducible},
  {"is_isomorphic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1465is_isomorphic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1464is_isomorphic},
  {"is_isosceles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1467is_isosceles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1466is_isosceles},
  {"is_network", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1469is_network, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1468is_network},
  {"is_orthogonal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1471is_orthogonal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1470is_orthogonal},
  {"is_parallel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1473is_parallel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1472is_parallel},
  {"is_parallelogram", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1475is_parallelogram, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1474is_parallelogram},
  {"is_permu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1477is_permu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1476is_permu},
  {"is_perpendicular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1479is_perpendicular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1478is_perpendicular},
  {"is_planar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1481is_planar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1480is_planar},
  {"is_prime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1483is_prime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1482is_prime},
  {"is_pseudoprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1485is_pseudoprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1484is_pseudoprime},
  {"is_reachable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1487is_reachable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1486is_reachable},
  {"is_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1489is_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1488is_rectangle},
  {"is_regular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1491is_regular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1490is_regular},
  {"is_rhombus", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1493is_rhombus, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1492is_rhombus},
  {"is_split_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1495is_split_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1494is_split_graph},
  {"is_square", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1497is_square, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1496is_square},
  {"is_strongly_connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1499is_strongly_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1498is_strongly_connected},
  {"is_strongly_regular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1501is_strongly_regular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1500is_strongly_regular},
  {"is_subgraph_isomorphic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1503is_subgraph_isomorphic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1502is_subgraph_isomorphic},
  {"is_tournament", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1505is_tournament, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1504is_tournament},
  {"is_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1507is_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1506is_tree},
  {"is_triconnected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1509is_triconnected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1508is_triconnected},
  {"is_two_edge_connected", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1511is_two_edge_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1510is_two_edge_connected},
  {"is_vertex_colorable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1513is_vertex_colorable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1512is_vertex_colorable},
  {"is_weighted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1515is_weighted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1514is_weighted},
  {"isinf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1517isinf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1516isinf},
  {"ismith", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1519ismith, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1518ismith},
  {"isnan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1521isnan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1520isnan},
  {"isobarycenter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1523isobarycenter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1522isobarycenter},
  {"isolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1525isolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1524isolve},
  {"isom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1527isom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1526isom},
  {"isomorphic_copy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1529isomorphic_copy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1528isomorphic_copy},
  {"isopolygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1531isopolygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1530isopolygon},
  {"isosceles_triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1533isosceles_triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1532isosceles_triangle},
  {"isposdef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1535isposdef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1534isposdef},
  {"isprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1537isprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1536isprime},
  {"istft", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1539istft, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1538istft},
  {"ithprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1541ithprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1540ithprime},
  {"jacobi_equation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1543jacobi_equation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1542jacobi_equation},
  {"jacobi_linsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1545jacobi_linsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1544jacobi_linsolve},
  {"jacobi_symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1547jacobi_symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1546jacobi_symbol},
  {"johnson_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1549johnson_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1548johnson_graph},
  {"join", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1551join, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1550join},
  {"jordan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1553jordan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1552jordan},
  {"katz_centrality", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1555katz_centrality, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1554katz_centrality},
  {"kde", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1557kde, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1556kde},
  {"keep_pivot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1559keep_pivot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1558keep_pivot},
  {"ker", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1561ker, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1560ker},
  {"kernel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1563kernel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1562kernel},
  {"kernel_density", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1565kernel_density, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1564kernel_density},
  {"kmeans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1567kmeans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1566kmeans},
  {"kneser_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1569kneser_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1568kneser_graph},
  {"kolmogorovd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1571kolmogorovd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1570kolmogorovd},
  {"kolmogorovt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1573kolmogorovt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1572kolmogorovt},
  {"kovacicsols", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1575kovacicsols, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1574kovacicsols},
  {"kspaths", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1577kspaths, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1576kspaths},
  {"l1norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1579l1norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1578l1norm},
  {"l2norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1581l2norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1580l2norm},
  {"lagrange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1583lagrange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1582lagrange},
  {"laguerre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1585laguerre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1584laguerre},
  {"laplace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1587laplace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1586laplace},
  {"laplacian", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1589laplacian, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1588laplacian},
  {"laplacian_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1591laplacian_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1590laplacian_matrix},
  {"latex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1593latex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1592latex},
  {"lcf_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1595lcf_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1594lcf_graph},
  {"lcm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1597lcm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1596lcm},
  {"lcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1599lcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1598lcoeff},
  {"ldegree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1601ldegree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1600ldegree},
  {"ldl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1603ldl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1602ldl},
  {"learning_rate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1605learning_rate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1604learning_rate},
  {"left", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1607left, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1606left},
  {"left_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1609left_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1608left_rectangle},
  {"legend", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1611legend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1610legend},
  {"legendre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1613legendre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1612legendre},
  {"legendre_symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1615legendre_symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1614legendre_symbol},
  {"length", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1617length, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1616length},
  {"levenshtein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1619levenshtein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1618levenshtein},
  {"lgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1621lgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1620lgcd},
  {"lhs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1623lhs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1622lhs},
  {"ligne_chapeau_carre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1625ligne_chapeau_carre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1624ligne_chapeau_carre},
  {"ligne_chapeau_plat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1627ligne_chapeau_plat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1626ligne_chapeau_plat},
  {"ligne_chapeau_rond", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1629ligne_chapeau_rond, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1628ligne_chapeau_rond},
  {"ligne_polygonale", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1631ligne_polygonale, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1630ligne_polygonale},
  {"ligne_polygonale_pointee", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1633ligne_polygonale_pointee, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1632ligne_polygonale_pointee},
  {"ligne_tiret", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1635ligne_tiret, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1634ligne_tiret},
  {"ligne_tiret_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1637ligne_tiret_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1636ligne_tiret_point},
  {"ligne_tiret_pointpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1639ligne_tiret_pointpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1638ligne_tiret_pointpoint},
  {"ligne_trait_plein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1641ligne_trait_plein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1640ligne_trait_plein},
  {"limit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1643limit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1642limit},
  {"limite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1645limite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1644limite},
  {"lin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1647lin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1646lin},
  {"linabs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1649linabs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1648linabs},
  {"line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1651line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1650line},
  {"line_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1653line_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1652line_graph},
  {"line_inter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1655line_inter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1654line_inter},
  {"line_paper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1657line_paper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1656line_paper},
  {"line_segments", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1659line_segments, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1658line_segments},
  {"linear_interpolate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1661linear_interpolate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1660linear_interpolate},
  {"linear_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1663linear_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1662linear_regression},
  {"linear_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1665linear_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1664linear_regression_plot},
  {"lineariser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1667lineariser, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1666lineariser},
  {"lineariser_trigo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1669lineariser_trigo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1668lineariser_trigo},
  {"linfnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1671linfnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1670linfnorm},
  {"linsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1673linsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1672linsolve},
  {"linspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1675linspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1674linspace},
  {"linstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1677linstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1676linstep},
  {"lis_phrase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1679lis_phrase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1678lis_phrase},
  {"list2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1681list2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1680list2exp},
  {"list2mat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1683list2mat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1682list2mat},
  {"list_edge_attributes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1685list_edge_attributes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1684list_edge_attributes},
  {"list_graph_attributes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1687list_graph_attributes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1686list_graph_attributes},
  {"list_vertex_attributes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1689list_vertex_attributes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1688list_vertex_attributes},
  {"listplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1691listplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1690listplot},
  {"lll", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1693lll, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1692lll},
  {"ln", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1695ln, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1694ln},
  {"lname", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1697lname, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1696lname},
  {"lncollect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1699lncollect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1698lncollect},
  {"lnexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1701lnexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1700lnexpand},
  {"locus", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1703locus, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1702locus},
  {"log", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1705log, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1704log},
  {"log10", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1707log10, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1706log10},
  {"log2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1709log2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1708log2},
  {"log_loss", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1711log_loss, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1710log_loss},
  {"logarithmic_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1713logarithmic_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1712logarithmic_regression},
  {"logarithmic_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1715logarithmic_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1714logarithmic_regression_plot},
  {"logb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1717logb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1716logb},
  {"logistic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1719logistic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1718logistic},
  {"logistic_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1721logistic_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1720logistic_regression},
  {"logistic_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1723logistic_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1722logistic_regression_plot},
  {"lower", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1725lower, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1724lower},
  {"lowest_common_ancestor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1727lowest_common_ancestor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1726lowest_common_ancestor},
  {"lowpass", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1729lowpass, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1728lowpass},
  {"lp_assume", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1731lp_assume, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1730lp_assume},
  {"lp_bestlocalbound", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1733lp_bestlocalbound, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1732lp_bestlocalbound},
  {"lp_bestprojection", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1735lp_bestprojection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1734lp_bestprojection},
  {"lp_binary", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1737lp_binary, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1736lp_binary},
  {"lp_binaryvariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1739lp_binaryvariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1738lp_binaryvariables},
  {"lp_breadthfirst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1741lp_breadthfirst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1740lp_breadthfirst},
  {"lp_depthfirst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1743lp_depthfirst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1742lp_depthfirst},
  {"lp_depthlimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1745lp_depthlimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1744lp_depthlimit},
  {"lp_firstfractional", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1747lp_firstfractional, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1746lp_firstfractional},
  {"lp_gaptolerance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1749lp_gaptolerance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1748lp_gaptolerance},
  {"lp_heuristic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1751lp_heuristic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1750lp_heuristic},
  {"lp_hybrid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1753lp_hybrid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1752lp_hybrid},
  {"lp_integer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1755lp_integer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1754lp_integer},
  {"lp_integervariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1757lp_integervariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1756lp_integervariables},
  {"lp_interiorpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1759lp_interiorpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1758lp_interiorpoint},
  {"lp_iterationlimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1761lp_iterationlimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1760lp_iterationlimit},
  {"lp_lastfractional", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1763lp_lastfractional, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1762lp_lastfractional},
  {"lp_maxcuts", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1765lp_maxcuts, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1764lp_maxcuts},
  {"lp_maximize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1767lp_maximize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1766lp_maximize},
  {"lp_method", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1769lp_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1768lp_method},
  {"lp_mostfractional", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1771lp_mostfractional, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1770lp_mostfractional},
  {"lp_nodelimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1773lp_nodelimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1772lp_nodelimit},
  {"lp_nodeselect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1775lp_nodeselect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1774lp_nodeselect},
  {"lp_nonnegative", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1777lp_nonnegative, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1776lp_nonnegative},
  {"lp_nonnegint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1779lp_nonnegint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1778lp_nonnegint},
  {"lp_presolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1781lp_presolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1780lp_presolve},
  {"lp_pseudocost", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1783lp_pseudocost, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1782lp_pseudocost},
  {"lp_simplex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1785lp_simplex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1784lp_simplex},
  {"lp_timelimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1787lp_timelimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1786lp_timelimit},
  {"lp_varselect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1789lp_varselect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1788lp_varselect},
  {"lp_verbose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1791lp_verbose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1790lp_verbose},
  {"lpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1793lpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1792lpsolve},
  {"lsmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1795lsmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1794lsmod},
  {"lsq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1797lsq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1796lsq},
  {"lu", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1799lu, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1798lu},
  {"lvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1801lvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1800lvar},
  {"mRow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1803mRow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1802mRow},
  {"mRowAdd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1805mRowAdd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1804mRowAdd},
  {"magenta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1807magenta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1806magenta},
  {"make_directed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1809make_directed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1808make_directed},
  {"make_symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1811make_symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1810make_symbol},
  {"make_weighted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1813make_weighted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1812make_weighted},
  {"makelist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1815makelist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1814makelist},
  {"makemat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1817makemat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1816makemat},
  {"makesuite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1819makesuite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1818makesuite},
  {"makevector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1821makevector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1820makevector},
  {"map", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1823map, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1822map},
  {"maple2mupad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1825maple2mupad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1824maple2mupad},
  {"maple2xcas", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1827maple2xcas, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1826maple2xcas},
  {"maple_ifactors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1829maple_ifactors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1828maple_ifactors},
  {"maple_mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1831maple_mode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1830maple_mode},
  {"markov", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1833markov, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1832markov},
  {"mat2list", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1835mat2list, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1834mat2list},
  {"mathml", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1837mathml, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1836mathml},
  {"matpow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1839matpow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1838matpow},
  {"matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1841matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1840matrix},
  {"matrix_norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1843matrix_norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1842matrix_norm},
  {"max", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1845max, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1844max},
  {"maxflow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1847maxflow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1846maxflow},
  {"maximal_independent_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1849maximal_independent_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1848maximal_independent_set},
  {"maximize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1851maximize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1850maximize},
  {"maximum_clique", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1853maximum_clique, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1852maximum_clique},
  {"maximum_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1855maximum_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1854maximum_degree},
  {"maximum_independent_set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1857maximum_independent_set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1856maximum_independent_set},
  {"maximum_matching", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1859maximum_matching, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1858maximum_matching},
  {"maxnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1861maxnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1860maxnorm},
  {"mean", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1863mean, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1862mean},
  {"median", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1865median, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1864median},
  {"median_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1867median_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1866median_line},
  {"member", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1869member, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1868member},
  {"mgf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1871mgf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1870mgf},
  {"mid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1873mid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1872mid},
  {"middle_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1875middle_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1874middle_point},
  {"midpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1877midpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1876midpoint},
  {"min", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1879min, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1878min},
  {"minimal_edge_coloring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1881minimal_edge_coloring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1880minimal_edge_coloring},
  {"minimal_spanning_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1883minimal_spanning_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1882minimal_spanning_tree},
  {"minimal_vertex_coloring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1885minimal_vertex_coloring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1884minimal_vertex_coloring},
  {"minimax", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1887minimax, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1886minimax},
  {"minimize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1889minimize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1888minimize},
  {"minimum_cut", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1891minimum_cut, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1890minimum_cut},
  {"minimum_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1893minimum_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1892minimum_degree},
  {"minimum_vertex_cover", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1895minimum_vertex_cover, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1894minimum_vertex_cover},
  {"mixdown", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1897mixdown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1896mixdown},
  {"mkisom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1899mkisom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1898mkisom},
  {"mksa", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1901mksa, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1900mksa},
  {"modf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1903modf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1902modf},
  {"modgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1905modgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1904modgcd},
  {"mods", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1907mods, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1906mods},
  {"momentum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1909momentum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1908momentum},
  {"monotonic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1911monotonic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1910monotonic},
  {"montre_tortue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1913montre_tortue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1912montre_tortue},
  {"moustache", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1915moustache, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1914moustache},
  {"moving_average", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1917moving_average, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1916moving_average},
  {"moyal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1919moyal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1918moyal},
  {"moyenne", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1921moyenne, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1920moyenne},
  {"mul", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1923mul, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1922mul},
  {"mult_c_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1925mult_c_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1924mult_c_conjugate},
  {"mult_conjugate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1927mult_conjugate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1926mult_conjugate},
  {"multinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1929multinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1928multinomial},
  {"multiplier_conjugue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1931multiplier_conjugue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1930multiplier_conjugue},
  {"multiplier_conjugue_complexe", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1933multiplier_conjugue_complexe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1932multiplier_conjugue_complexe},
  {"multiply", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1935multiply, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1934multiply},
  {"mupad2maple", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1937mupad2maple, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1936mupad2maple},
  {"mupad2xcas", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1939mupad2xcas, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1938mupad2xcas},
  {"mycielski", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1941mycielski, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1940mycielski},
  {"nCr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1943nCr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1942nCr},
  {"nDeriv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1945nDeriv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1944nDeriv},
  {"nInt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1947nInt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1946nInt},
  {"nPr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1949nPr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1948nPr},
  {"nSolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1951nSolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1950nSolve},
  {"navy", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1953navy, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1952navy},
  {"ncols", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1955ncols, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1954ncols},
  {"negbinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1957negbinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1956negbinomial},
  {"negbinomial_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1959negbinomial_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1958negbinomial_cdf},
  {"negbinomial_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1961negbinomial_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1960negbinomial_icdf},
  {"neighbors", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1963neighbors, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1962neighbors},
  {"network_transitivity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1965network_transitivity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1964network_transitivity},
  {"neural_network", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1967neural_network, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1966neural_network},
  {"newList", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1969newList, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1968newList},
  {"newMat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1971newMat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1970newMat},
  {"newton", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1973newton, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1972newton},
  {"newton_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1975newton_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1974newton_solver},
  {"newtonj_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1977newtonj_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1976newtonj_solver},
  {"nextperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1979nextperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1978nextperm},
  {"nextprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1981nextprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1980nextprime},
  {"nlp_binary", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1983nlp_binary, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1982nlp_binary},
  {"nlp_binaryvariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1985nlp_binaryvariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1984nlp_binaryvariables},
  {"nlp_initialpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1987nlp_initialpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1986nlp_initialpoint},
  {"nlp_integer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1989nlp_integer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1988nlp_integer},
  {"nlp_integervariables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1991nlp_integervariables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1990nlp_integervariables},
  {"nlp_iterationlimit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1993nlp_iterationlimit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1992nlp_iterationlimit},
  {"nlp_maximize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1995nlp_maximize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1994nlp_maximize},
  {"nlp_method", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1997nlp_method, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1996nlp_method},
  {"nlp_nonnegative", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_1999nlp_nonnegative, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_1998nlp_nonnegative},
  {"nlp_nonnegint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2001nlp_nonnegint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2000nlp_nonnegint},
  {"nlp_precision", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2003nlp_precision, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2002nlp_precision},
  {"nlp_presolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2005nlp_presolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2004nlp_presolve},
  {"nlp_tolerance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2007nlp_tolerance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2006nlp_tolerance},
  {"nlp_verbose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2009nlp_verbose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2008nlp_verbose},
  {"nlpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2011nlpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2010nlpsolve},
  {"nodisp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2013nodisp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2012nodisp},
  {"non_recursive_normal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2015non_recursive_normal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2014non_recursive_normal},
  {"nonnegint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2017nonnegint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2016nonnegint},
  {"nop", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2019nop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2018nop},
  {"nops", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2021nops, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2020nops},
  {"norm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2023norm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2022norm},
  {"normal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2025normal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2024normal},
  {"normal_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2027normal_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2026normal_cdf},
  {"normal_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2029normal_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2028normal_icdf},
  {"normald", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2031normald, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2030normald},
  {"normald_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2033normald_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2032normald_cdf},
  {"normald_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2035normald_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2034normald_icdf},
  {"normalize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2037normalize, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2036normalize},
  {"normalt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2039normalt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2038normalt},
  {"normalvariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2041normalvariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2040normalvariate},
  {"nprimes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2043nprimes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2042nprimes},
  {"nrows", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2045nrows, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2044nrows},
  {"nstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2047nstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2046nstep},
  {"nuage_points", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2049nuage_points, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2048nuage_points},
  {"nullspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2051nullspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2050nullspace},
  {"number_of_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2053number_of_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2052number_of_edges},
  {"number_of_spanning_trees", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2055number_of_spanning_trees, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2054number_of_spanning_trees},
  {"number_of_triangles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2057number_of_triangles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2056number_of_triangles},
  {"number_of_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2059number_of_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2058number_of_vertices},
  {"numdiff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2061numdiff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2060numdiff},
  {"numer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2063numer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2062numer},
  {"octahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2065octahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2064octahedron},
  {"odd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2067odd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2066odd},
  {"odd_girth", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2069odd_girth, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2068odd_girth},
  {"odd_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2071odd_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2070odd_graph},
  {"odeplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2073odeplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2072odeplot},
  {"odesolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2075odesolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2074odesolve},
  {"olive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2077olive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2076olive},
  {"op", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2079op, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2078op},
  {"open_polygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2081open_polygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2080open_polygon},
  {"orange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2083orange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2082orange},
  {"ord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2085ord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2084ord},
  {"order", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2087order, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2086order},
  {"order_size", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2089order_size, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2088order_size},
  {"ordinate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2091ordinate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2090ordinate},
  {"orthocenter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2093orthocenter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2092orthocenter},
  {"orthogonal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2095orthogonal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2094orthogonal},
  {"osculating_circle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2097osculating_circle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2096osculating_circle},
  {"p1oc2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2099p1oc2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2098p1oc2},
  {"p1op2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2101p1op2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2100p1op2},
  {"pa2b2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2103pa2b2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2102pa2b2},
  {"pade", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2105pade, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2104pade},
  {"paley_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2107paley_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2106paley_graph},
  {"parabola", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2109parabola, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2108parabola},
  {"parallel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2111parallel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2110parallel},
  {"parallelepiped", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2113parallelepiped, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2112parallelepiped},
  {"parallelogram", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2115parallelogram, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2114parallelogram},
  {"parameq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2117parameq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2116parameq},
  {"parameter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2119parameter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2118parameter},
  {"paramplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2121paramplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2120paramplot},
  {"parfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2123parfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2122parfrac},
  {"pari", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2125pari, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2124pari},
  {"part", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2127part, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2126part},
  {"partfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2129partfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2128partfrac},
  {"parzen_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2131parzen_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2130parzen_window},
  {"pas_de_cote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2133pas_de_cote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2132pas_de_cote},
  {"path_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2135path_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2134path_graph},
  {"pcar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2137pcar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2136pcar},
  {"pcar_hessenberg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2139pcar_hessenberg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2138pcar_hessenberg},
  {"pcoef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2141pcoef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2140pcoef},
  {"pcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2143pcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2142pcoeff},
  {"pencolor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2145pencolor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2144pencolor},
  {"pendown", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2147pendown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2146pendown},
  {"penup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2149penup, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2148penup},
  {"perimeter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2151perimeter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2150perimeter},
  {"perimeterat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2153perimeterat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2152perimeterat},
  {"perimeteratraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2155perimeteratraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2154perimeteratraw},
  {"period", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2157period, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2156period},
  {"periodic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2159periodic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2158periodic},
  {"perm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2161perm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2160perm},
  {"perminv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2163perminv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2162perminv},
  {"permu2cycles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2165permu2cycles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2164permu2cycles},
  {"permu2mat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2167permu2mat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2166permu2mat},
  {"permuorder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2169permuorder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2168permuorder},
  {"permute_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2171permute_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2170permute_vertices},
  {"perpen_bisector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2173perpen_bisector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2172perpen_bisector},
  {"perpendicular", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2175perpendicular, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2174perpendicular},
  {"petersen_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2177petersen_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2176petersen_graph},
  {"peval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2179peval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2178peval},
  {"pi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2181pi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2180pi},
  {"pie", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2183pie, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2182pie},
  {"piecewise", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2185piecewise, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2184piecewise},
  {"pink", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2187pink, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2186pink},
  {"pivot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2189pivot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2188pivot},
  {"pixoff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2191pixoff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2190pixoff},
  {"pixon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2193pixon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2192pixon},
  {"planar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2195planar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2194planar},
  {"plane", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2197plane, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2196plane},
  {"plane_dual", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2199plane_dual, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2198plane_dual},
  {"playsnd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2201playsnd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2200playsnd},
  {"plex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2203plex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2202plex},
  {"plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2205plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2204plot},
  {"plot3d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2207plot3d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2206plot3d},
  {"plotarea", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2209plotarea, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2208plotarea},
  {"plotcdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2211plotcdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2210plotcdf},
  {"plotcontour", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2213plotcontour, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2212plotcontour},
  {"plotdensity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2215plotdensity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2214plotdensity},
  {"plotfield", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2217plotfield, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2216plotfield},
  {"plotfunc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2219plotfunc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2218plotfunc},
  {"plotimf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2221plotimf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2220plotimf},
  {"plotimplicit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2223plotimplicit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2222plotimplicit},
  {"plotinequation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2225plotinequation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2224plotinequation},
  {"plotlist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2227plotlist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2226plotlist},
  {"plotode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2229plotode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2228plotode},
  {"plotparam", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2231plotparam, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2230plotparam},
  {"plotpolar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2233plotpolar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2232plotpolar},
  {"plotproba", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2235plotproba, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2234plotproba},
  {"plotseq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2237plotseq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2236plotseq},
  {"plotspectrum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2239plotspectrum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2238plotspectrum},
  {"plotwav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2241plotwav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2240plotwav},
  {"plus_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2243plus_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2242plus_point},
  {"pmin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2245pmin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2244pmin},
  {"point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2247point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2246point},
  {"point2d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2249point2d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2248point2d},
  {"point3d", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2251point3d, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2250point3d},
  {"poisson", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2253poisson, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2252poisson},
  {"poisson_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2255poisson_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2254poisson_cdf},
  {"poisson_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2257poisson_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2256poisson_icdf},
  {"poisson_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2259poisson_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2258poisson_window},
  {"polar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2261polar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2260polar},
  {"polar_coordinates", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2263polar_coordinates, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2262polar_coordinates},
  {"polar_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2265polar_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2264polar_point},
  {"polarplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2267polarplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2266polarplot},
  {"pole", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2269pole, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2268pole},
  {"poly2symb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2271poly2symb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2270poly2symb},
  {"polyEval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2273polyEval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2272polyEval},
  {"polygon", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2275polygon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2274polygon},
  {"polygone_rempli", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2277polygone_rempli, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2276polygone_rempli},
  {"polygonplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2279polygonplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2278polygonplot},
  {"polygonscatterplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2281polygonscatterplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2280polygonscatterplot},
  {"polyhedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2283polyhedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2282polyhedron},
  {"polynom", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2285polynom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2284polynom},
  {"polynomial_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2287polynomial_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2286polynomial_regression},
  {"polynomial_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2289polynomial_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2288polynomial_regression_plot},
  {"position", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2291position, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2290position},
  {"poslbdLMQ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2293poslbdLMQ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2292poslbdLMQ},
  {"posubLMQ", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2295posubLMQ, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2294posubLMQ},
  {"potential", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2297potential, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2296potential},
  {"pow2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2299pow2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2298pow2exp},
  {"power_regression", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2301power_regression, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2300power_regression},
  {"power_regression_plot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2303power_regression_plot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2302power_regression_plot},
  {"powermod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2305powermod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2304powermod},
  {"powerpc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2307powerpc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2306powerpc},
  {"powexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2309powexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2308powexpand},
  {"powmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2311powmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2310powmod},
  {"prepend", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2313prepend, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2312prepend},
  {"preval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2315preval, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2314preval},
  {"prevperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2317prevperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2316prevperm},
  {"prevprime", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2319prevprime, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2318prevprime},
  {"primpart", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2321primpart, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2320primpart},
  {"printf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2323printf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2322printf},
  {"prism", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2325prism, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2324prism},
  {"prism_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2327prism_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2326prism_graph},
  {"product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2329product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2328product},
  {"projection", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2331projection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2330projection},
  {"proot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2333proot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2332proot},
  {"propFrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2335propFrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2334propFrac},
  {"propfrac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2337propfrac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2336propfrac},
  {"pruefer_code", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2339pruefer_code, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2338pruefer_code},
  {"psrgcd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2341psrgcd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2340psrgcd},
  {"ptayl", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2343ptayl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2342ptayl},
  {"purge", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2345purge, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2344purge},
  {"purple", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2347purple, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2346purple},
  {"pwd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2349pwd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2348pwd},
  {"pyramid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2351pyramid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2350pyramid},
  {"python_compat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2353python_compat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2352python_compat},
  {"q2a", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2355q2a, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2354q2a},
  {"qr", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2357qr, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2356qr},
  {"quadric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2359quadric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2358quadric},
  {"quadrilateral", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2361quadrilateral, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2360quadrilateral},
  {"quantile", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2363quantile, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2362quantile},
  {"quartile1", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2365quartile1, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2364quartile1},
  {"quartile3", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2367quartile3, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2366quartile3},
  {"quartiles", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2369quartiles, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2368quartiles},
  {"quest", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2371quest, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2370quest},
  {"quo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2373quo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2372quo},
  {"quorem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2375quorem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2374quorem},
  {"quote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2377quote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2376quote},
  {"r2e", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2379r2e, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2378r2e},
  {"radians", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2381radians, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2380radians},
  {"radical_axis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2383radical_axis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2382radical_axis},
  {"radius", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2385radius, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2384radius},
  {"ramene", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2387ramene, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2386ramene},
  {"rand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2389rand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2388rand},
  {"randMat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2391randMat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2390randMat},
  {"randNorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2393randNorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2392randNorm},
  {"randPoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2395randPoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2394randPoly},
  {"randbetad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2397randbetad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2396randbetad},
  {"randbinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2399randbinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2398randbinomial},
  {"randchisquare", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2401randchisquare, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2400randchisquare},
  {"randexp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2403randexp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2402randexp},
  {"randfisher", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2405randfisher, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2404randfisher},
  {"randgammad", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2407randgammad, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2406randgammad},
  {"randgeometric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2409randgeometric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2408randgeometric},
  {"randint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2411randint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2410randint},
  {"randmarkov", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2413randmarkov, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2412randmarkov},
  {"randmatrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2415randmatrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2414randmatrix},
  {"randmultinomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2417randmultinomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2416randmultinomial},
  {"randnorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2419randnorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2418randnorm},
  {"random", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2421random, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2420random},
  {"random_bipartite_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2423random_bipartite_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2422random_bipartite_graph},
  {"random_digraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2425random_digraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2424random_digraph},
  {"random_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2427random_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2426random_graph},
  {"random_network", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2429random_network, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2428random_network},
  {"random_planar_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2431random_planar_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2430random_planar_graph},
  {"random_regular_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2433random_regular_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2432random_regular_graph},
  {"random_sequence_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2435random_sequence_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2434random_sequence_graph},
  {"random_tournament", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2437random_tournament, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2436random_tournament},
  {"random_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2439random_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2438random_tree},
  {"random_variable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2441random_variable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2440random_variable},
  {"randperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2443randperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2442randperm},
  {"randpoisson", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2445randpoisson, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2444randpoisson},
  {"randpoly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2447randpoly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2446randpoly},
  {"randseed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2449randseed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2448randseed},
  {"randstudent", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2451randstudent, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2450randstudent},
  {"randvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2453randvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2452randvar},
  {"randvector", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2455randvector, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2454randvector},
  {"randweibulld", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2457randweibulld, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2456randweibulld},
  {"rank", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2459rank, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2458rank},
  {"ranm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2461ranm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2460ranm},
  {"ranv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2463ranv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2462ranv},
  {"rassembler_trigo", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2465rassembler_trigo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2464rassembler_trigo},
  {"rat_jordan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2467rat_jordan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2466rat_jordan},
  {"ratinterp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2469ratinterp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2468ratinterp},
  {"rational", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2471rational, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2470rational},
  {"rationalroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2473rationalroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2472rationalroot},
  {"ratnormal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2475ratnormal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2474ratnormal},
  {"rdiv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2477rdiv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2476rdiv},
  {"re", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2479re, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2478re},
  {"reachable", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2481reachable, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2480reachable},
  {"read", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2483read, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2482read},
  {"readrgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2485readrgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2484readrgb},
  {"readwav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2487readwav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2486readwav},
  {"real", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2489real, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2488real},
  {"realroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2491realroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2490realroot},
  {"reciprocation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2493reciprocation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2492reciprocation},
  {"rect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2495rect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2494rect},
  {"rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2497rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2496rectangle},
  {"rectangle_droit", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2499rectangle_droit, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2498rectangle_droit},
  {"rectangle_gauche", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2501rectangle_gauche, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2500rectangle_gauche},
  {"rectangle_plein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2503rectangle_plein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2502rectangle_plein},
  {"rectangular_coordinates", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2505rectangular_coordinates, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2504rectangular_coordinates},
  {"recule", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2507recule, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2506recule},
  {"red", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2509red, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2508red},
  {"reduced_conic", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2511reduced_conic, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2510reduced_conic},
  {"reduced_quadric", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2513reduced_quadric, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2512reduced_quadric},
  {"ref", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2515ref, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2514ref},
  {"reflection", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2517reflection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2516reflection},
  {"regroup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2519regroup, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2518regroup},
  {"relabel_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2521relabel_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2520relabel_vertices},
  {"reliability_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2523reliability_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2522reliability_polynomial},
  {"rem", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2525rem, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2524rem},
  {"remain", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2527remain, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2526remain},
  {"remove", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2529remove, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2528remove},
  {"reorder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2531reorder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2530reorder},
  {"resample", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2533resample, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2532resample},
  {"residue", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2535residue, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2534residue},
  {"resoudre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2537resoudre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2536resoudre},
  {"resoudre_dans_C", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2539resoudre_dans_C, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2538resoudre_dans_C},
  {"resoudre_systeme_lineaire", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2541resoudre_systeme_lineaire, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2540resoudre_systeme_lineaire},
  {"resultant", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2543resultant, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2542resultant},
  {"reverse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2545reverse, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2544reverse},
  {"reverse_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2547reverse_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2546reverse_graph},
  {"reverse_rsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2549reverse_rsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2548reverse_rsolve},
  {"revert", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2551revert, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2550revert},
  {"revlex", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2553revlex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2552revlex},
  {"revlist", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2555revlist, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2554revlist},
  {"rgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2557rgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2556rgb},
  {"rgb2hsv", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2559rgb2hsv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2558rgb2hsv},
  {"rgb2xyz", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2561rgb2xyz, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2560rgb2xyz},
  {"rhombus", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2563rhombus, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2562rhombus},
  {"rhombus_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2565rhombus_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2564rhombus_point},
  {"rhs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2567rhs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2566rhs},
  {"riemann_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2569riemann_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2568riemann_window},
  {"right", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2571right, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2570right},
  {"right_rectangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2573right_rectangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2572right_rectangle},
  {"right_triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2575right_triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2574right_triangle},
  {"risch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2577risch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2576risch},
  {"rm_a_z", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2579rm_a_z, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2578rm_a_z},
  {"rm_all_vars", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2581rm_all_vars, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2580rm_all_vars},
  {"rmbreakpoint", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2583rmbreakpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2582rmbreakpoint},
  {"rmmod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2585rmmod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2584rmmod},
  {"rms", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2587rms, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2586rms},
  {"rmwatch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2589rmwatch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2588rmwatch},
  {"romberg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2591romberg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2590romberg},
  {"rombergm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2593rombergm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2592rombergm},
  {"rombergt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2595rombergt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2594rombergt},
  {"rond", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2597rond, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2596rond},
  {"root", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2599root, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2598root},
  {"rootof", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2601rootof, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2600rootof},
  {"roots", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2603roots, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2602roots},
  {"rotate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2605rotate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2604rotate},
  {"rotation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2607rotation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2606rotation},
  {"round", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2609round, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2608round},
  {"row", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2611row, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2610row},
  {"rowAdd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2613rowAdd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2612rowAdd},
  {"rowDim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2615rowDim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2614rowDim},
  {"rowNorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2617rowNorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2616rowNorm},
  {"rowSwap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2619rowSwap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2618rowSwap},
  {"rowdim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2621rowdim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2620rowdim},
  {"rownorm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2623rownorm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2622rownorm},
  {"rowspace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2625rowspace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2624rowspace},
  {"rowswap", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2627rowswap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2626rowswap},
  {"rref", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2629rref, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2628rref},
  {"rsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2631rsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2630rsolve},
  {"rur", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2633rur, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2632rur},
  {"rur_certify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2635rur_certify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2634rur_certify},
  {"rur_gbasis", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2637rur_gbasis, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2636rur_gbasis},
  {"same", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2639same, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2638same},
  {"sample", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2641sample, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2640sample},
  {"samplerate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2643samplerate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2642samplerate},
  {"sans_factoriser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2645sans_factoriser, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2644sans_factoriser},
  {"saute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2647saute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2646saute},
  {"scalarProduct", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2649scalarProduct, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2648scalarProduct},
  {"scalar_product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2651scalar_product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2650scalar_product},
  {"scatterplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2653scatterplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2652scatterplot},
  {"schur", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2655schur, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2654schur},
  {"sec", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2657sec, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2656sec},
  {"secant_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2659secant_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2658secant_solver},
  {"segment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2661segment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2660segment},
  {"seidel_spectrum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2663seidel_spectrum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2662seidel_spectrum},
  {"seidel_switch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2665seidel_switch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2664seidel_switch},
  {"select", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2667select, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2666select},
  {"semi_augment", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2669semi_augment, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2668semi_augment},
  {"seq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2671seq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2670seq},
  {"seqplot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2673seqplot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2672seqplot},
  {"seqsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2675seqsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2674seqsolve},
  {"sequence_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2677sequence_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2676sequence_graph},
  {"series", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2679series, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2678series},
  {"set_channel_data", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2681set_channel_data, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2680set_channel_data},
  {"set_edge_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2683set_edge_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2682set_edge_attribute},
  {"set_edge_weight", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2685set_edge_weight, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2684set_edge_weight},
  {"set_graph_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2687set_graph_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2686set_graph_attribute},
  {"set_pixel", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2689set_pixel, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2688set_pixel},
  {"set_screen", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2691set_screen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2690set_screen},
  {"set_vertex_attribute", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2693set_vertex_attribute, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2692set_vertex_attribute},
  {"set_vertex_positions", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2695set_vertex_positions, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2694set_vertex_positions},
  {"shift", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2697shift, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2696shift},
  {"shift_phase", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2699shift_phase, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2698shift_phase},
  {"shortest_path", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2701shortest_path, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2700shortest_path},
  {"show_pixels", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2703show_pixels, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2702show_pixels},
  {"shuffle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2705shuffle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2704shuffle},
  {"sierpinski_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2707sierpinski_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2706sierpinski_graph},
  {"sign", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2709sign, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2708sign},
  {"sign2Heaviside", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2711sign2Heaviside, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2710sign2Heaviside},
  {"signature", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2713signature, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2712signature},
  {"signe", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2715signe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2714signe},
  {"similarity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2717similarity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2716similarity},
  {"simp2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2719simp2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2718simp2},
  {"simplex_reduce", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2721simplex_reduce, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2720simplex_reduce},
  {"simplicial_vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2723simplicial_vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2722simplicial_vertices},
  {"simplifier", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2725simplifier, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2724simplifier},
  {"simplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2727simplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2726simplify},
  {"simplifyDirac", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2729simplifyDirac, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2728simplifyDirac},
  {"simpson", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2731simpson, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2730simpson},
  {"simulated_annealing", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2733simulated_annealing, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2732simulated_annealing},
  {"simult", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2735simult, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2734simult},
  {"sin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2737sin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2736sin},
  {"sin2costan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2739sin2costan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2738sin2costan},
  {"sinc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2741sinc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2740sinc},
  {"sincos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2743sincos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2742sincos},
  {"single_inter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2745single_inter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2744single_inter},
  {"sinh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2747sinh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2746sinh},
  {"sizes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2749sizes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2748sizes},
  {"slope", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2751slope, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2750slope},
  {"slopeat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2753slopeat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2752slopeat},
  {"slopeatraw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2755slopeatraw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2754slopeatraw},
  {"smith", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2757smith, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2756smith},
  {"smod", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2759smod, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2758smod},
  {"snedecor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2761snedecor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2760snedecor},
  {"snedecor_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2763snedecor_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2762snedecor_cdf},
  {"snedecor_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2765snedecor_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2764snedecor_icdf},
  {"snedecord", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2767snedecord, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2766snedecord},
  {"snedecord_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2769snedecord_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2768snedecord_cdf},
  {"snedecord_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2771snedecord_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2770snedecord_icdf},
  {"solid_line", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2773solid_line, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2772solid_line},
  {"solve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2775solve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2774solve},
  {"somme", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2777somme, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2776somme},
  {"sommet", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2779sommet, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2778sommet},
  {"sort", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2781sort, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2780sort},
  {"sorta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2783sorta, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2782sorta},
  {"sortd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2785sortd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2784sortd},
  {"sorted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2787sorted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2786sorted},
  {"sortperm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2789sortperm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2788sortperm},
  {"soundsec", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2791soundsec, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2790soundsec},
  {"spanning_tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2793spanning_tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2792spanning_tree},
  {"sphere", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2795sphere, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2794sphere},
  {"splice", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2797splice, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2796splice},
  {"spline", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2799spline, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2798spline},
  {"split", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2801split, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2800split},
  {"spring", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2803spring, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2802spring},
  {"sq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2805sq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2804sq},
  {"sqrfree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2807sqrfree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2806sqrfree},
  {"sqrt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2809sqrt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2808sqrt},
  {"square", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2811square, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2810square},
  {"square_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2813square_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2812square_point},
  {"srand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2815srand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2814srand},
  {"sst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2817sst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2816sst},
  {"sst_in", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2819sst_in, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2818sst_in},
  {"st_ordering", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2821st_ordering, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2820st_ordering},
  {"star_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2823star_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2822star_graph},
  {"star_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2825star_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2824star_point},
  {"stdDev", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2827stdDev, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2826stdDev},
  {"stddev", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2829stddev, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2828stddev},
  {"stddevp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2831stddevp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2830stddevp},
  {"steffenson_solver", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2833steffenson_solver, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2832steffenson_solver},
  {"stereo2mono", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2835stereo2mono, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2834stereo2mono},
  {"stft", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2837stft, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2836stft},
  {"str", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2839str, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2838str},
  {"strip", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2841strip, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2840strip},
  {"strongly_connected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2843strongly_connected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2842strongly_connected_components},
  {"student", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2845student, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2844student},
  {"student_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2847student_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2846student_cdf},
  {"student_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2849student_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2848student_icdf},
  {"studentd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2851studentd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2850studentd},
  {"studentt", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2853studentt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2852studentt},
  {"sturm", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2855sturm, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2854sturm},
  {"sturmab", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2857sturmab, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2856sturmab},
  {"sturmseq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2859sturmseq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2858sturmseq},
  {"style", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2861style, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2860style},
  {"subMat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2863subMat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2862subMat},
  {"subdivide_edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2865subdivide_edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2864subdivide_edges},
  {"subgraph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2867subgraph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2866subgraph},
  {"subs", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2869subs, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2868subs},
  {"subsop", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2871subsop, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2870subsop},
  {"subst", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2873subst, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2872subst},
  {"substituer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2875substituer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2874substituer},
  {"subtype", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2877subtype, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2876subtype},
  {"sum", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2879sum, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2878sum},
  {"sum_riemann", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2881sum_riemann, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2880sum_riemann},
  {"suppress", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2883suppress, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2882suppress},
  {"surd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2885surd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2884surd},
  {"svd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2887svd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2886svd},
  {"swapcol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2889swapcol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2888swapcol},
  {"swaprow", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2891swaprow, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2890swaprow},
  {"switch_axes", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2893switch_axes, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2892switch_axes},
  {"sylvester", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2895sylvester, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2894sylvester},
  {"symb2poly", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2897symb2poly, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2896symb2poly},
  {"symbol", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2899symbol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2898symbol},
  {"symbol_array", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2901symbol_array, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2900symbol_array},
  {"syst2mat", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2903syst2mat, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2902syst2mat},
  {"tCollect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2905tCollect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2904tCollect},
  {"tExpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2907tExpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2906tExpand},
  {"table", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2909table, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2908table},
  {"tablefunc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2911tablefunc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2910tablefunc},
  {"tableseq", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2913tableseq, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2912tableseq},
  {"tabsign", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2915tabsign, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2914tabsign},
  {"tabvar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2917tabvar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2916tabvar},
  {"tail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2919tail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2918tail},
  {"tan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2921tan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2920tan},
  {"tan2cossin2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2923tan2cossin2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2922tan2cossin2},
  {"tan2sincos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2925tan2sincos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2924tan2sincos},
  {"tan2sincos2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2927tan2sincos2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2926tan2sincos2},
  {"tangent", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2929tangent, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2928tangent},
  {"tangente", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2931tangente, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2930tangente},
  {"tanh", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2933tanh, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2932tanh},
  {"tar", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2935tar, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2934tar},
  {"taux_accroissement", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2937taux_accroissement, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2936taux_accroissement},
  {"taylor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2939taylor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2938taylor},
  {"tchebyshev1", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2941tchebyshev1, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2940tchebyshev1},
  {"tchebyshev2", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2943tchebyshev2, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2942tchebyshev2},
  {"tcoeff", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2945tcoeff, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2944tcoeff},
  {"tcollect", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2947tcollect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2946tcollect},
  {"tdeg", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2949tdeg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2948tdeg},
  {"teal", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2951teal, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2950teal},
  {"tensor_product", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2953tensor_product, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2952tensor_product},
  {"tetrahedron", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2955tetrahedron, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2954tetrahedron},
  {"texpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2957texpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2956texpand},
  {"thickness", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2959thickness, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2958thickness},
  {"threshold", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2961threshold, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2960threshold},
  {"throw", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2963throw, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2962throw},
  {"title", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2965title, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2964title},
  {"titre", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2967titre, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2966titre},
  {"tlin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2969tlin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2968tlin},
  {"tonnetz", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2971tonnetz, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2970tonnetz},
  {"topologic_sort", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2973topologic_sort, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2972topologic_sort},
  {"topological_sort", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2975topological_sort, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2974topological_sort},
  {"topology", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2977topology, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2976topology},
  {"torus_grid_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2979torus_grid_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2978torus_grid_graph},
  {"total_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2981total_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2980total_degree},
  {"tourne_droite", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2983tourne_droite, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2982tourne_droite},
  {"tourne_gauche", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2985tourne_gauche, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2984tourne_gauche},
  {"tpsolve", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2987tpsolve, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2986tpsolve},
  {"trace", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2989trace, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2988trace},
  {"trail", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2991trail, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2990trail},
  {"trail2edges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2993trail2edges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2992trail2edges},
  {"train", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2995train, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2994train},
  {"trames", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2997trames, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2996trames},
  {"tran", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_2999tran, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_2998tran},
  {"transitive_closure", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3001transitive_closure, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3000transitive_closure},
  {"translation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3003translation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3002translation},
  {"transpose", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3005transpose, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3004transpose},
  {"trapeze", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3007trapeze, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3006trapeze},
  {"trapezoid", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3009trapezoid, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3008trapezoid},
  {"traveling_salesman", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3011traveling_salesman, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3010traveling_salesman},
  {"tree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3013tree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3012tree},
  {"tree_height", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3015tree_height, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3014tree_height},
  {"tri", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3017tri, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3016tri},
  {"triangle", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3019triangle, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3018triangle},
  {"triangle_paper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3021triangle_paper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3020triangle_paper},
  {"triangle_plein", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3023triangle_plein, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3022triangle_plein},
  {"triangle_point", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3025triangle_point, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3024triangle_point},
  {"triangle_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3027triangle_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3026triangle_window},
  {"trig2exp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3029trig2exp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3028trig2exp},
  {"trigcos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3031trigcos, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3030trigcos},
  {"trigexpand", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3033trigexpand, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3032trigexpand},
  {"triginterp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3035triginterp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3034triginterp},
  {"trigsimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3037trigsimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3036trigsimplify},
  {"trigsin", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3039trigsin, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3038trigsin},
  {"trigtan", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3041trigtan, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3040trigtan},
  {"trim", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3043trim, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3042trim},
  {"trn", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3045trn, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3044trn},
  {"true", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3047true, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3046true},
  {"trunc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3049trunc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3048trunc},
  {"truncate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3051truncate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3050truncate},
  {"truncate_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3053truncate_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3052truncate_graph},
  {"tsimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3055tsimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3054tsimplify},
  {"tstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3057tstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3056tstep},
  {"tuer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3059tuer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3058tuer},
  {"tukey_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3061tukey_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3060tukey_window},
  {"tutte_polynomial", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3063tutte_polynomial, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3062tutte_polynomial},
  {"two_edge_connected_components", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3065two_edge_connected_components, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3064two_edge_connected_components},
  {"ufactor", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3067ufactor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3066ufactor},
  {"ugamma", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3069ugamma, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3068ugamma},
  {"unapply", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3071unapply, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3070unapply},
  {"unarchive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3073unarchive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3072unarchive},
  {"undef", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3075undef, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3074undef},
  {"underlying_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3077underlying_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3076underlying_graph},
  {"unfactored", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3079unfactored, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3078unfactored},
  {"uniform", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3081uniform, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3080uniform},
  {"uniform_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3083uniform_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3082uniform_cdf},
  {"uniform_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3085uniform_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3084uniform_icdf},
  {"uniformd", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3087uniformd, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3086uniformd},
  {"uniformd_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3089uniformd_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3088uniformd_cdf},
  {"uniformd_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3091uniformd_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3090uniformd_icdf},
  {"unitV", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3093unitV, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3092unitV},
  {"unquote", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3095unquote, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3094unquote},
  {"upper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3097upper, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3096upper},
  {"user_operator", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3099user_operator, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3098user_operator},
  {"usimplify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3101usimplify, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3100usimplify},
  {"ustep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3103ustep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3102ustep},
  {"valuation", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3105valuation, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3104valuation},
  {"vandermonde", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3107vandermonde, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3106vandermonde},
  {"variables_are_files", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3109variables_are_files, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3108variables_are_files},
  {"variance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3111variance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3110variance},
  {"version", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3113version, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3112version},
  {"vertex_connectivity", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3115vertex_connectivity, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3114vertex_connectivity},
  {"vertex_cover_number", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3117vertex_cover_number, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3116vertex_cover_number},
  {"vertex_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3119vertex_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3118vertex_degree},
  {"vertex_distance", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3121vertex_distance, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3120vertex_distance},
  {"vertex_in_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3123vertex_in_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3122vertex_in_degree},
  {"vertex_out_degree", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3125vertex_out_degree, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3124vertex_out_degree},
  {"vertices", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3127vertices, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3126vertices},
  {"vertices_abc", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3129vertices_abc, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3128vertices_abc},
  {"vertices_abca", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3131vertices_abca, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3130vertices_abca},
  {"violet", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3133violet, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3132violet},
  {"vpotential", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3135vpotential, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3134vpotential},
  {"vstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3137vstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3136vstep},
  {"web_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3139web_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3138web_graph},
  {"weibull", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3141weibull, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3140weibull},
  {"weibull_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3143weibull_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3142weibull_cdf},
  {"weibull_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3145weibull_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3144weibull_icdf},
  {"weibulld", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3147weibulld, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3146weibulld},
  {"weibulld_cdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3149weibulld_cdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3148weibulld_cdf},
  {"weibulld_icdf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3151weibulld_icdf, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3150weibulld_icdf},
  {"weibullvariate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3153weibullvariate, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3152weibullvariate},
  {"weight_decay", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3155weight_decay, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3154weight_decay},
  {"weight_matrix", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3157weight_matrix, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3156weight_matrix},
  {"weighted", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3159weighted, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3158weighted},
  {"weights", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3161weights, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3160weights},
  {"welch_window", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3163welch_window, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3162welch_window},
  {"wheel_graph", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3165wheel_graph, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3164wheel_graph},
  {"widget_size", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3167widget_size, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3166widget_size},
  {"wilcoxonp", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3169wilcoxonp, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3168wilcoxonp},
  {"wilcoxons", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3171wilcoxons, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3170wilcoxons},
  {"wilcoxont", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3173wilcoxont, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3172wilcoxont},
  {"writergb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3175writergb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3174writergb},
  {"writewav", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3177writewav, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3176writewav},
  {"xcas_mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3179xcas_mode, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3178xcas_mode},
  {"xml_print", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3181xml_print, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3180xml_print},
  {"xstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3183xstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3182xstep},
  {"xyz2rgb", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3185xyz2rgb, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3184xyz2rgb},
  {"xyztrange", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3187xyztrange, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3186xyztrange},
  {"ystep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3189ystep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3188ystep},
  {"zeros", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3191zeros, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3190zeros},
  {"znorder", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3193znorder, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3192znorder},
  {"znprimroot", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3195znprimroot, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3194znprimroot},
  {"zstep", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3197zstep, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3196zstep},
  {"ztrans", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3199ztrans, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3198ztrans},
  {"type", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3201type, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3200type},
  {"zip", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3203zip, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_16GiacMethods_base_3202zip},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3205__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_16GiacMethods_base_3207__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6giacpy_6giacpy_GiacMethods_base_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6giacpy_6giacpy_GiacMethods_base},
  {Py_tp_doc, (void *)PyDoc_STR("\n     Wrapper for a giac ``gen`` containing auto-generated methods.\n\n     This class does not manage the ``gen`` inside in any way. It is just\n     a dumb wrapper.\n     You almost certainly want to use one of the derived class\n     :class:`Pygen`  instead.\n     ")},
  {Py_tp_methods, (void *)__pyx_methods_6giacpy_6giacpy_GiacMethods_base},
  {Py_tp_new, (void *)__pyx_tp_new_6giacpy_6giacpy_GiacMethods_base},
  {0, 0},
};
static PyType_Spec __pyx_type_6giacpy_6giacpy_GiacMethods_base_spec = {
  "giacpy.giacpy.GiacMethods_base",
  sizeof(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6giacpy_6giacpy_GiacMethods_base_slots,
};
#else

static PyTypeObject __pyx_type_6giacpy_6giacpy_GiacMethods_base = {
  PyVarObject_HEAD_INIT(0, 0)
  "giacpy.giacpy.""GiacMethods_base", /*tp_name*/
  sizeof(struct __pyx_obj_6giacpy_6giacpy_GiacMethods_base), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6giacpy_6giacpy_GiacMethods_base, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("\n     Wrapper for a giac ``gen`` containing auto-generated methods.\n\n     This class does not manage the ``gen`` inside in any way. It is just\n     a dumb wrapper.\n     You almost certainly want to use one of the derived class\n     :class:`Pygen`  instead.\n     "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6giacpy_6giacpy_GiacMethods_base, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6giacpy_6giacpy_GiacMethods_base, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6giacpy_6giacpy_Pygen(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = __pyx_tp_new_6giacpy_6giacpy_GiacMethods_base(t, a, k);
  if (unlikely(!o)) return 0;
  if (unlikely(__pyx_pw_6giacpy_6giacpy_5Pygen_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6giacpy_6giacpy_Pygen(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6giacpy_6giacpy_Pygen) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6giacpy_6giacpy_5Pygen_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6giacpy_6giacpy_GiacMethods_base(o);
}
static PyObject *__pyx_sq_item_6giacpy_6giacpy_Pygen(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_6giacpy_6giacpy_Pygen(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_5Pygen_13__setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    if (__pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_as_mapping && __pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_as_mapping->mp_ass_subscript)
      return __pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_as_mapping->mp_ass_subscript(o, i, v);
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static CYTHON_INLINE PyObject *__pyx_nb_add_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_add : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_add);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_add_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_add == &__pyx_nb_add_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_26__add__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_add == &__pyx_nb_add_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_pw_6giacpy_6giacpy_5Pygen_28__radd__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_subtract_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_subtract : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_subtract);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_subtract_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_subtract == &__pyx_nb_subtract_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_32__sub__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_subtract == &__pyx_nb_subtract_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_pw_6giacpy_6giacpy_5Pygen_34__rsub__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_multiply_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_multiply : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_multiply);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_multiply_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_multiply == &__pyx_nb_multiply_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_36__mul__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_multiply == &__pyx_nb_multiply_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_pw_6giacpy_6giacpy_5Pygen_38__rmul__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



#if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
static CYTHON_INLINE PyObject *__pyx_nb_divide_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_divide : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_divide);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_divide_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_divide == &__pyx_nb_divide_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_40__div__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_divide == &__pyx_nb_divide_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_nb_divide_6giacpy_6giacpy_Pygen_maybe_call_slot(__Pyx_PyType_GetSlot(__pyx_ptype_6giacpy_6giacpy_Pygen, tp_base, PyTypeObject*), left, right );
    }
    return __Pyx_NewRef(Py_NotImplemented);
}


#endif

static CYTHON_INLINE PyObject *__pyx_nb_remainder_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_remainder : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_remainder);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_remainder_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_remainder == &__pyx_nb_remainder_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_50__mod__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_remainder == &__pyx_nb_remainder_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_pw_6giacpy_6giacpy_5Pygen_52__rmod__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_power_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right , PyObject* extra_arg) {
    ternaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_power : NULL;
#else
    slot = (ternaryfunc) PyType_GetSlot(type, Py_nb_power);
#endif
    return slot ? slot(left, right , extra_arg) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_power_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right , PyObject* extra_arg) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_power == &__pyx_nb_power_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_46__pow__(left, right, extra_arg);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_power == &__pyx_nb_power_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_pw_6giacpy_6giacpy_5Pygen_48__rpow__(right, left, extra_arg);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_true_divide_6giacpy_6giacpy_Pygen_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_true_divide : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_true_divide);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_true_divide_6giacpy_6giacpy_Pygen(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_true_divide == &__pyx_nb_true_divide_6giacpy_6giacpy_Pygen)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6giacpy_6giacpy_5Pygen_42__truediv__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_true_divide == &__pyx_nb_true_divide_6giacpy_6giacpy_Pygen)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6giacpy_6giacpy_Pygen);
    if (maybe_self_is_right) {
        return __pyx_pw_6giacpy_6giacpy_5Pygen_44__rtruediv__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static PyObject *__pyx_getprop_6giacpy_6giacpy_5Pygen__type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_5Pygen_5_type_1__get__(o);
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_5Pygen__subtype(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_5Pygen_8_subtype_1__get__(o);
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_5Pygen__val(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_5Pygen_4_val_1__get__(o);
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_5Pygen__double(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_5Pygen_7_double_1__get__(o);
}

static PyObject *__pyx_specialmethod___pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__(self);
}

static PyMethodDef __pyx_methods_6giacpy_6giacpy_Pygen[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__, METH_NOARGS|METH_COEXIST, __pyx_doc_6giacpy_6giacpy_5Pygen_4__repr__},
  {"eval", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_22eval, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"threadeval", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_24threadeval, METH_VARARGS|METH_KEYWORDS, 0},
  {"__radd__", (PyCFunction)__pyx_pw_6giacpy_6giacpy_5Pygen_28__radd__, METH_O|METH_COEXIST, __pyx_doc_6giacpy_6giacpy_5Pygen_27__radd__},
  {"__rsub__", (PyCFunction)__pyx_pw_6giacpy_6giacpy_5Pygen_34__rsub__, METH_O|METH_COEXIST, __pyx_doc_6giacpy_6giacpy_5Pygen_33__rsub__},
  {"__rmul__", (PyCFunction)__pyx_pw_6giacpy_6giacpy_5Pygen_38__rmul__, METH_O|METH_COEXIST, __pyx_doc_6giacpy_6giacpy_5Pygen_37__rmul__},
  {"__rtruediv__", (PyCFunction)__pyx_pw_6giacpy_6giacpy_5Pygen_44__rtruediv__, METH_O|METH_COEXIST, __pyx_doc_6giacpy_6giacpy_5Pygen_43__rtruediv__},
  {"__rmod__", (PyCFunction)__pyx_pw_6giacpy_6giacpy_5Pygen_52__rmod__, METH_O|METH_COEXIST, __pyx_doc_6giacpy_6giacpy_5Pygen_51__rmod__},
  {"cas_setup", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_58cas_setup, METH_VARARGS|METH_KEYWORDS, 0},
  {"_repr_latex_", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_60_repr_latex_, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_repr_html_", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_62_repr_html_, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"save", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_64save, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_63save},
  {"htmlhelp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_66htmlhelp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_65htmlhelp},
  {"help", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_68help, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"redim", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_70redim, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_69redim},
  {"qcas", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_72qcas, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6giacpy_6giacpy_5Pygen_71qcas},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_76__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_5Pygen_78__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6giacpy_6giacpy_Pygen[] = {
  {(char *)"_type", __pyx_getprop_6giacpy_6giacpy_5Pygen__type, 0, (char *)0, 0},
  {(char *)"_subtype", __pyx_getprop_6giacpy_6giacpy_5Pygen__subtype, 0, (char *)0, 0},
  {(char *)"_val", __pyx_getprop_6giacpy_6giacpy_5Pygen__val, 0, (char *)PyDoc_STR("\n         immediate int value of an _INT_ type gen.\n         "), 0},
  {(char *)"_double", __pyx_getprop_6giacpy_6giacpy_5Pygen__double, 0, (char *)PyDoc_STR("\n         immediate conversion to float for a gen of _DOUBLE_ type.\n         "), 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6giacpy_6giacpy_Pygen_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6giacpy_6giacpy_Pygen},
  {Py_tp_repr, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__},
  {Py_nb_add, (void *)__pyx_nb_add_6giacpy_6giacpy_Pygen},
  {Py_nb_subtract, (void *)__pyx_nb_subtract_6giacpy_6giacpy_Pygen},
  {Py_nb_multiply, (void *)__pyx_nb_multiply_6giacpy_6giacpy_Pygen},
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  {Py_nb_divide, (void *)__pyx_nb_divide_6giacpy_6giacpy_Pygen},
  #endif
  {Py_nb_remainder, (void *)__pyx_nb_remainder_6giacpy_6giacpy_Pygen},
  {Py_nb_power, (void *)__pyx_nb_power_6giacpy_6giacpy_Pygen},
  {Py_nb_negative, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_54__neg__},
  {Py_nb_positive, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_56__pos__},
  {Py_nb_int, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_18__int__},
  #if PY_MAJOR_VERSION < 3
  {Py_nb_long, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_18__int__},
  #endif
  {Py_nb_float, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_20__float__},
  {Py_nb_true_divide, (void *)__pyx_nb_true_divide_6giacpy_6giacpy_Pygen},
  {Py_sq_length, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_9__len__},
  {Py_sq_item, (void *)__pyx_sq_item_6giacpy_6giacpy_Pygen},
  {Py_mp_length, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_9__len__},
  {Py_mp_subscript, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_11__getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_6giacpy_6giacpy_Pygen},
  {Py_tp_call, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_30__call__},
  {Py_tp_str, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_7__str__},
  {Py_tp_doc, (void *)PyDoc_STR("\n     The class Pygen is the main tool to interact from python/sage with the c++\n     library giac via cython.  The initialisation of a Pygen just create an object\n     in giac, but the mathematical computation  is not done. This class is mainly\n     for cython users.  Here A is a Pygen element, and it is ready for any giac\n     function.::\n\n     >>> from giacpy import Pygen\n     >>> A = Pygen('2+2')\n     >>> A\n     2+2\n     >>> A.eval()\n     4\n\n     In general, you may prefer to directly create a Pygen and execute the\n     evaluation in giac. This is exactly the meaning of the :func:`libgiac`\n     function.::\n\n     >>> a = giac('2+2')\n     >>> a\n     4\n     >>> isinstance(a, Pygen)\n     True\n\n     ")},
  {Py_tp_richcompare, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_74__richcmp__},
  {Py_tp_iter, (void *)__pyx_pw_6giacpy_6giacpy_5Pygen_15__iter__},
  {Py_tp_methods, (void *)__pyx_methods_6giacpy_6giacpy_Pygen},
  {Py_tp_getset, (void *)__pyx_getsets_6giacpy_6giacpy_Pygen},
  {Py_tp_new, (void *)__pyx_tp_new_6giacpy_6giacpy_Pygen},
  {0, 0},
};
static PyType_Spec __pyx_type_6giacpy_6giacpy_Pygen_spec = {
  "giacpy.giacpy.Pygen",
  sizeof(struct __pyx_obj_6giacpy_6giacpy_Pygen),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6giacpy_6giacpy_Pygen_slots,
};
#else

static PyNumberMethods __pyx_tp_as_number_Pygen = {
  __pyx_nb_add_6giacpy_6giacpy_Pygen, /*nb_add*/
  __pyx_nb_subtract_6giacpy_6giacpy_Pygen, /*nb_subtract*/
  __pyx_nb_multiply_6giacpy_6giacpy_Pygen, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  __pyx_nb_divide_6giacpy_6giacpy_Pygen, /*nb_divide*/
  #endif
  __pyx_nb_remainder_6giacpy_6giacpy_Pygen, /*nb_remainder*/
  0, /*nb_divmod*/
  __pyx_nb_power_6giacpy_6giacpy_Pygen, /*nb_power*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_54__neg__, /*nb_negative*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_56__pos__, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_bool*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_coerce*/
  #endif
  __pyx_pw_6giacpy_6giacpy_5Pygen_18__int__, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  __pyx_pw_6giacpy_6giacpy_5Pygen_18__int__, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  __pyx_pw_6giacpy_6giacpy_5Pygen_20__float__, /*nb_float*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  __pyx_nb_true_divide_6giacpy_6giacpy_Pygen, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  0, /*nb_index*/
  #if PY_VERSION_HEX >= 0x03050000
  0, /*nb_matrix_multiply*/
  #endif
  #if PY_VERSION_HEX >= 0x03050000
  0, /*nb_inplace_matrix_multiply*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_Pygen = {
  __pyx_pw_6giacpy_6giacpy_5Pygen_9__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_6giacpy_6giacpy_Pygen, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Pygen = {
  __pyx_pw_6giacpy_6giacpy_5Pygen_9__len__, /*mp_length*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_11__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_6giacpy_6giacpy_Pygen, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6giacpy_6giacpy_Pygen = {
  PyVarObject_HEAD_INIT(0, 0)
  "giacpy.giacpy.""Pygen", /*tp_name*/
  sizeof(struct __pyx_obj_6giacpy_6giacpy_Pygen), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6giacpy_6giacpy_Pygen, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6giacpy_6giacpy_5Pygen_5__repr__, /*tp_repr*/
  &__pyx_tp_as_number_Pygen, /*tp_as_number*/
  &__pyx_tp_as_sequence_Pygen, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Pygen, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_30__call__, /*tp_call*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_7__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("\n     The class Pygen is the main tool to interact from python/sage with the c++\n     library giac via cython.  The initialisation of a Pygen just create an object\n     in giac, but the mathematical computation  is not done. This class is mainly\n     for cython users.  Here A is a Pygen element, and it is ready for any giac\n     function.::\n\n     >>> from giacpy import Pygen\n     >>> A = Pygen('2+2')\n     >>> A\n     2+2\n     >>> A.eval()\n     4\n\n     In general, you may prefer to directly create a Pygen and execute the\n     evaluation in giac. This is exactly the meaning of the :func:`libgiac`\n     function.::\n\n     >>> a = giac('2+2')\n     >>> a\n     4\n     >>> isinstance(a, Pygen)\n     True\n\n     "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_74__richcmp__, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_6giacpy_6giacpy_5Pygen_15__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6giacpy_6giacpy_Pygen, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6giacpy_6giacpy_Pygen, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6giacpy_6giacpy_Pygen, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_digits(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_6digits_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_digits(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_6digits_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_sqrtflag(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_8sqrtflag_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_sqrtflag(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_8sqrtflag_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_complexflag(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_11complexflag_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_complexflag(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_11complexflag_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_eval_level(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_10eval_level_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_eval_level(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_10eval_level_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_proba_epsilon(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_proba_epsilon(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_13proba_epsilon_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_epsilon(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_7epsilon_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_epsilon(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_7epsilon_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6giacpy_6giacpy_11GiacSetting_threads(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_7threads_1__get__(o);
}

static int __pyx_setprop_6giacpy_6giacpy_11GiacSetting_threads(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6giacpy_6giacpy_11GiacSetting_7threads_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_specialmethod___pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__(self);
}

static PyMethodDef __pyx_methods_6giacpy_6giacpy_GiacSetting[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__, METH_NOARGS|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_11GiacSetting_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6giacpy_6giacpy_11GiacSetting_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6giacpy_6giacpy_GiacSetting[] = {
  {(char *)"digits", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_digits, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_digits, (char *)PyDoc_STR("\n         Default digits number used for approximations:\n\n         ::\n\n            >>> from giacpy import giac,giacsettings\n            >>> giacsettings.digits=20;giacsettings.digits\n            20\n            >>> giac('1/7').approx()\n            0.14285714285714285714\n            >>> giacsettings.digits=12;\n\n         "), 0},
  {(char *)"sqrtflag", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_sqrtflag, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_sqrtflag, (char *)PyDoc_STR("\n         Flag to allow square roots in solving equations or factorizations:\n\n         ::\n\n            >>> from giacpy import giac,giacsettings\n            >>> giacsettings.sqrtflag=False;giacsettings.sqrtflag\n            False\n            >>> giac('x**2-2').factor()\n            x**2-2\n            >>> giacsettings.sqrtflag=True;\n            >>> giac('x**2-2').factor()\n            (x-sqrt(2))*(x+sqrt(2))\n\n         "), 0},
  {(char *)"complexflag", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_complexflag, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_complexflag, (char *)PyDoc_STR("\n         Flag to allow complex number in solving equations or factorizations:\n\n         ::\n\n            >>> from giacpy import giac,giacsettings\n            >>> giacsettings.complexflag=False;giacsettings.complexflag\n            False\n            >>> giac('x**2+4').factor()\n            x**2+4\n            >>> giacsettings.complexflag=True;\n            >>> giac('x**2+4').factor()\n            (x+2*i)*(x-2*i)\n\n         "), 0},
  {(char *)"eval_level", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_eval_level, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_eval_level, (char *)PyDoc_STR("\n         Recursive level of substitution of variables during an evaluation:\n\n            >>> from giacpy import giacsettings,purge\n            >>> giacsettings.eval_level=1\n            >>> giac(\"purge(a):;b:=a;a:=1;b\")\n            \"Done\",a,1,a\n            >>> giacsettings.eval_level=25; giacsettings.eval_level\n            25\n            >>> giac(\"purge(a):;b:=a;a:=1;b\")\n            \"Done\",a,1,1\n\n         "), 0},
  {(char *)"proba_epsilon", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_proba_epsilon, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_proba_epsilon, (char *)PyDoc_STR("\n         Maximum probability of a wrong answer with a probabilist algorithm.\n         Set this number to 0 to disable probabilist algorithms (slower):\n\n            >>> from giacpy import giacsettings,giac\n            >>> giacsettings.proba_epsilon=0;giac('proba_epsilon')\n            0.0\n            >>> giacsettings.proba_epsilon=10**(-15);giac('proba_epsilon')=='1e-15'\n            True\n\n         "), 0},
  {(char *)"epsilon", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_epsilon, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_epsilon, (char *)PyDoc_STR("\n         Value used by the epsilon2zero function:\n\n         ::\n\n            >>> from giacpy import giac,giacsettings\n            >>> giacsettings.epsilon=1e-10\n            >>> P=giac('1e-11+x+5')\n            >>> P==x+5\n            False\n            >>> (P.epsilon2zero()).simplify()\n            x+5\n\n         "), 0},
  {(char *)"threads", __pyx_getprop_6giacpy_6giacpy_11GiacSetting_threads, __pyx_setprop_6giacpy_6giacpy_11GiacSetting_threads, (char *)PyDoc_STR("\n         Maximal number of allowed theads in giac\n         "), 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6giacpy_6giacpy_GiacSetting_slots[] = {
  {Py_tp_repr, (void *)__pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__},
  {Py_tp_doc, (void *)PyDoc_STR("\n     A class to customise the Computer Algebra  System settings\n\n     * property threads:\n\n         Maximal number of allowed theads in giac\n\n     * property digits:\n\n         Default digits number used for approximations:\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.digits=20;giacsettings.digits\n             20\n             >>> giac('1/7').approx()\n             0.14285714285714285714\n             >>> giacsettings.digits=12;\n\n     * property sqrtflag:\n\n         Flag to allow sqrt extractions during solve and factorizations:\n\n         ::\n\n             >>> from giacpy import giac,giacsettings\n             >>> giacsettings.sqrtflag=False;giacsettings.sqrtflag\n             False\n             >>> giac('x**2-2').factor()\n             x**2-2\n             >>> giacsettings.sqrtflag=True;\n             >>> giac('x**2-2').factor()\n             (x-sqrt(2))*(x+sqrt(2))\n\n     * property complexflag:\n\n         Flag to allow complex number in solving equations or factorizations:\n\n         ::\n\n            >>> from giacpy import giac,giacsettings\n            >>> giacsettings.complexflag=False;giacsettings.complexflag\n            False\n            >>> giac('x**2+4').factor()\n            x**2+4\n            >>> giacsettings.complexflag=True;\n            >>> giac('x**2+4').factor()\n            (x+2*i)*(x-2*i)\n\n\n     * property eval_level:\n\n         Recursive level of substitution of variables during an evaluation:\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.eval_level=1\n             >>> giac(\"purge(a):;b:=a;a:=1;b\")\n             \"Done\",a,1,a\n             >>> giacsettings.eval_level=25; giacsettings.eval_level\n             25\n             >>> giac(\"purge(a):;b:=a;a:=1;b\")\n             \"Done\",a,1,1\n\n     * property proba_epsilon:\n\n         Maximum probability of a wrong answer with a probabilist algorithm.""\n         Set this number to 0 to disable probabilist algorithms (slower):\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.proba_epsilon=0;giac('proba_epsilon')\n             0.0\n             >>> giacsettings.proba_epsilon=10^(-13)\n             >>> giac('proba_epsilon')<10^(-14)\n             False\n\n     * property epsilon:\n\n         Value used by the epsilon2zero function:\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.epsilon=1e-10\n             >>> x=giac('x')\n             >>> P=giac('1e-11+x+5')\n             >>> P==x+5\n             False\n             >>> (P.epsilon2zero()).simplify()\n             x+5\n\n     ")},
  {Py_tp_methods, (void *)__pyx_methods_6giacpy_6giacpy_GiacSetting},
  {Py_tp_getset, (void *)__pyx_getsets_6giacpy_6giacpy_GiacSetting},
  {Py_tp_new, (void *)__pyx_tp_new_6giacpy_6giacpy_Pygen},
  {0, 0},
};
static PyType_Spec __pyx_type_6giacpy_6giacpy_GiacSetting_spec = {
  "giacpy.giacpy.GiacSetting",
  sizeof(struct __pyx_obj_6giacpy_6giacpy_GiacSetting),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6giacpy_6giacpy_GiacSetting_slots,
};
#else

static PyTypeObject __pyx_type_6giacpy_6giacpy_GiacSetting = {
  PyVarObject_HEAD_INIT(0, 0)
  "giacpy.giacpy.""GiacSetting", /*tp_name*/
  sizeof(struct __pyx_obj_6giacpy_6giacpy_GiacSetting), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6giacpy_6giacpy_Pygen, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6giacpy_6giacpy_11GiacSetting_1__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6giacpy_6giacpy_5Pygen_30__call__, /*tp_call*/
  #else
  0, /*tp_call*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6giacpy_6giacpy_5Pygen_7__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("\n     A class to customise the Computer Algebra  System settings\n\n     * property threads:\n\n         Maximal number of allowed theads in giac\n\n     * property digits:\n\n         Default digits number used for approximations:\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.digits=20;giacsettings.digits\n             20\n             >>> giac('1/7').approx()\n             0.14285714285714285714\n             >>> giacsettings.digits=12;\n\n     * property sqrtflag:\n\n         Flag to allow sqrt extractions during solve and factorizations:\n\n         ::\n\n             >>> from giacpy import giac,giacsettings\n             >>> giacsettings.sqrtflag=False;giacsettings.sqrtflag\n             False\n             >>> giac('x**2-2').factor()\n             x**2-2\n             >>> giacsettings.sqrtflag=True;\n             >>> giac('x**2-2').factor()\n             (x-sqrt(2))*(x+sqrt(2))\n\n     * property complexflag:\n\n         Flag to allow complex number in solving equations or factorizations:\n\n         ::\n\n            >>> from giacpy import giac,giacsettings\n            >>> giacsettings.complexflag=False;giacsettings.complexflag\n            False\n            >>> giac('x**2+4').factor()\n            x**2+4\n            >>> giacsettings.complexflag=True;\n            >>> giac('x**2+4').factor()\n            (x+2*i)*(x-2*i)\n\n\n     * property eval_level:\n\n         Recursive level of substitution of variables during an evaluation:\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.eval_level=1\n             >>> giac(\"purge(a):;b:=a;a:=1;b\")\n             \"Done\",a,1,a\n             >>> giacsettings.eval_level=25; giacsettings.eval_level\n             25\n             >>> giac(\"purge(a):;b:=a;a:=1;b\")\n             \"Done\",a,1,1\n\n     * property proba_epsilon:\n\n         Maximum probability of a wrong answer with a probabilist algorithm.""\n         Set this number to 0 to disable probabilist algorithms (slower):\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.proba_epsilon=0;giac('proba_epsilon')\n             0.0\n             >>> giacsettings.proba_epsilon=10^(-13)\n             >>> giac('proba_epsilon')<10^(-14)\n             False\n\n     * property epsilon:\n\n         Value used by the epsilon2zero function:\n\n         ::\n\n             >>> from giacpy import giacsettings,giac\n             >>> giacsettings.epsilon=1e-10\n             >>> x=giac('x')\n             >>> P=giac('1e-11+x+5')\n             >>> P==x+5\n             False\n             >>> (P.epsilon2zero()).simplify()\n             x+5\n\n     "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6giacpy_6giacpy_5Pygen_15__iter__, /*tp_iter*/
  #else
  0, /*tp_iter*/
  #endif
  0, /*tp_iternext*/
  __pyx_methods_6giacpy_6giacpy_GiacSetting, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6giacpy_6giacpy_GiacSetting, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6giacpy_6giacpy_Pygen, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *__pyx_freelist_6giacpy_6giacpy___pyx_scope_struct____iter__[8];
static int __pyx_freecount_6giacpy_6giacpy___pyx_scope_struct____iter__ = 0;
#endif

static PyObject *__pyx_tp_new_6giacpy_6giacpy___pyx_scope_struct____iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_6giacpy_6giacpy___pyx_scope_struct____iter__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__)))) {
    o = (PyObject*)__pyx_freelist_6giacpy_6giacpy___pyx_scope_struct____iter__[--__pyx_freecount_6giacpy_6giacpy___pyx_scope_struct____iter__];
    memset(o, 0, sizeof(struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6giacpy_6giacpy___pyx_scope_struct____iter__(PyObject *o) {
  struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *p = (struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6giacpy_6giacpy___pyx_scope_struct____iter__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_6giacpy_6giacpy___pyx_scope_struct____iter__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__)))) {
    __pyx_freelist_6giacpy_6giacpy___pyx_scope_struct____iter__[__pyx_freecount_6giacpy_6giacpy___pyx_scope_struct____iter__++] = ((struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6giacpy_6giacpy___pyx_scope_struct____iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *p = (struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6giacpy_6giacpy___pyx_scope_struct____iter__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6giacpy_6giacpy___pyx_scope_struct____iter__},
  {Py_tp_new, (void *)__pyx_tp_new_6giacpy_6giacpy___pyx_scope_struct____iter__},
  {0, 0},
};
static PyType_Spec __pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter___spec = {
  "giacpy.giacpy.__pyx_scope_struct____iter__",
  sizeof(struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter___slots,
};
#else

static PyTypeObject __pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "giacpy.giacpy.""__pyx_scope_struct____iter__", /*tp_name*/
  sizeof(struct __pyx_obj_6giacpy_6giacpy___pyx_scope_struct____iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6giacpy_6giacpy___pyx_scope_struct____iter__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6giacpy_6giacpy___pyx_scope_struct____iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6giacpy_6giacpy___pyx_scope_struct____iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_n_s_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 0, 1, 1},
    {&__pyx_n_s_ACOSH, __pyx_k_ACOSH, sizeof(__pyx_k_ACOSH), 0, 0, 1, 1},
    {&__pyx_n_s_ACOT, __pyx_k_ACOT, sizeof(__pyx_k_ACOT), 0, 0, 1, 1},
    {&__pyx_n_s_ACSC, __pyx_k_ACSC, sizeof(__pyx_k_ACSC), 0, 0, 1, 1},
    {&__pyx_n_s_ASEC, __pyx_k_ASEC, sizeof(__pyx_k_ASEC), 0, 0, 1, 1},
    {&__pyx_n_s_ASIN, __pyx_k_ASIN, sizeof(__pyx_k_ASIN), 0, 0, 1, 1},
    {&__pyx_n_s_ASINH, __pyx_k_ASINH, sizeof(__pyx_k_ASINH), 0, 0, 1, 1},
    {&__pyx_n_s_ATAN, __pyx_k_ATAN, sizeof(__pyx_k_ATAN), 0, 0, 1, 1},
    {&__pyx_n_s_ATANH, __pyx_k_ATANH, sizeof(__pyx_k_ATANH), 0, 0, 1, 1},
    {&__pyx_n_s_A_2, __pyx_k_A_2, sizeof(__pyx_k_A_2), 0, 0, 1, 1},
    {&__pyx_n_s_Airy_Ai, __pyx_k_Airy_Ai, sizeof(__pyx_k_Airy_Ai), 0, 0, 1, 1},
    {&__pyx_n_s_Airy_Bi, __pyx_k_Airy_Bi, sizeof(__pyx_k_Airy_Bi), 0, 0, 1, 1},
    {&__pyx_n_s_Angstrom, __pyx_k_Angstrom, sizeof(__pyx_k_Angstrom), 0, 0, 1, 1},
    {&__pyx_n_s_Archive, __pyx_k_Archive, sizeof(__pyx_k_Archive), 0, 0, 1, 1},
    {&__pyx_kp_u_Archive_a_Pygen_element_to_a_fi, __pyx_k_Archive_a_Pygen_element_to_a_fi, sizeof(__pyx_k_Archive_a_Pygen_element_to_a_fi), 0, 1, 0, 0},
    {&__pyx_n_s_BesselJ, __pyx_k_BesselJ, sizeof(__pyx_k_BesselJ), 0, 0, 1, 1},
    {&__pyx_n_s_BesselY, __pyx_k_BesselY, sizeof(__pyx_k_BesselY), 0, 0, 1, 1},
    {&__pyx_n_s_Beta, __pyx_k_Beta, sizeof(__pyx_k_Beta), 0, 0, 1, 1},
    {&__pyx_n_s_BlockDiagonal, __pyx_k_BlockDiagonal, sizeof(__pyx_k_BlockDiagonal), 0, 0, 1, 1},
    {&__pyx_n_s_Bq, __pyx_k_Bq, sizeof(__pyx_k_Bq), 0, 0, 1, 1},
    {&__pyx_n_s_Btu, __pyx_k_Btu, sizeof(__pyx_k_Btu), 0, 0, 1, 1},
    {&__pyx_n_s_COND, __pyx_k_COND, sizeof(__pyx_k_COND), 0, 0, 1, 1},
    {&__pyx_n_s_COS, __pyx_k_COS, sizeof(__pyx_k_COS), 0, 0, 1, 1},
    {&__pyx_n_s_COSH, __pyx_k_COSH, sizeof(__pyx_k_COSH), 0, 0, 1, 1},
    {&__pyx_n_s_COT, __pyx_k_COT, sizeof(__pyx_k_COT), 0, 0, 1, 1},
    {&__pyx_n_s_CSC, __pyx_k_CSC, sizeof(__pyx_k_CSC), 0, 0, 1, 1},
    {&__pyx_n_s_CST, __pyx_k_CST, sizeof(__pyx_k_CST), 0, 0, 1, 1},
    {&__pyx_n_s_Celsius2Fahrenheit, __pyx_k_Celsius2Fahrenheit, sizeof(__pyx_k_Celsius2Fahrenheit), 0, 0, 1, 1},
    {&__pyx_n_s_Ci, __pyx_k_Ci, sizeof(__pyx_k_Ci), 0, 0, 1, 1},
    {&__pyx_n_s_Ci_2, __pyx_k_Ci_2, sizeof(__pyx_k_Ci_2), 0, 0, 1, 1},
    {&__pyx_n_s_Circle, __pyx_k_Circle, sizeof(__pyx_k_Circle), 0, 0, 1, 1},
    {&__pyx_n_s_ClrDraw, __pyx_k_ClrDraw, sizeof(__pyx_k_ClrDraw), 0, 0, 1, 1},
    {&__pyx_n_s_ClrGraph, __pyx_k_ClrGraph, sizeof(__pyx_k_ClrGraph), 0, 0, 1, 1},
    {&__pyx_n_s_ClrIO, __pyx_k_ClrIO, sizeof(__pyx_k_ClrIO), 0, 0, 1, 1},
    {&__pyx_n_s_Col, __pyx_k_Col, sizeof(__pyx_k_Col), 0, 0, 1, 1},
    {&__pyx_kp_u_Convert_a_giac_integer_type_Pyg, __pyx_k_Convert_a_giac_integer_type_Pyg, sizeof(__pyx_k_Convert_a_giac_integer_type_Pyg), 0, 1, 0, 0},
    {&__pyx_kp_u_Convert_a_giac_real_to_a_Python, __pyx_k_Convert_a_giac_real_to_a_Python, sizeof(__pyx_k_Convert_a_giac_real_to_a_Python), 0, 1, 0, 0},
    {&__pyx_n_s_CopyVar, __pyx_k_CopyVar, sizeof(__pyx_k_CopyVar), 0, 0, 1, 1},
    {&__pyx_n_s_CyclePic, __pyx_k_CyclePic, sizeof(__pyx_k_CyclePic), 0, 0, 1, 1},
    {&__pyx_n_s_DIGITS, __pyx_k_DIGITS, sizeof(__pyx_k_DIGITS), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_COMPLEX, __pyx_k_DOM_COMPLEX, sizeof(__pyx_k_DOM_COMPLEX), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_FLOAT, __pyx_k_DOM_FLOAT, sizeof(__pyx_k_DOM_FLOAT), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_FUNC, __pyx_k_DOM_FUNC, sizeof(__pyx_k_DOM_FUNC), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_IDENT, __pyx_k_DOM_IDENT, sizeof(__pyx_k_DOM_IDENT), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_INT, __pyx_k_DOM_INT, sizeof(__pyx_k_DOM_INT), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_LIST, __pyx_k_DOM_LIST, sizeof(__pyx_k_DOM_LIST), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_RAT, __pyx_k_DOM_RAT, sizeof(__pyx_k_DOM_RAT), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_STRING, __pyx_k_DOM_STRING, sizeof(__pyx_k_DOM_STRING), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_SYMBOLIC, __pyx_k_DOM_SYMBOLIC, sizeof(__pyx_k_DOM_SYMBOLIC), 0, 0, 1, 1},
    {&__pyx_n_s_DOM_int, __pyx_k_DOM_int, sizeof(__pyx_k_DOM_int), 0, 0, 1, 1},
    {&__pyx_n_s_DelFold, __pyx_k_DelFold, sizeof(__pyx_k_DelFold), 0, 0, 1, 1},
    {&__pyx_n_s_DelVar, __pyx_k_DelVar, sizeof(__pyx_k_DelVar), 0, 0, 1, 1},
    {&__pyx_n_s_Det, __pyx_k_Det, sizeof(__pyx_k_Det), 0, 0, 1, 1},
    {&__pyx_n_s_Dialog, __pyx_k_Dialog, sizeof(__pyx_k_Dialog), 0, 0, 1, 1},
    {&__pyx_n_s_Digits, __pyx_k_Digits, sizeof(__pyx_k_Digits), 0, 0, 1, 1},
    {&__pyx_n_s_Dirac, __pyx_k_Dirac, sizeof(__pyx_k_Dirac), 0, 0, 1, 1},
    {&__pyx_n_s_Disp, __pyx_k_Disp, sizeof(__pyx_k_Disp), 0, 0, 1, 1},
    {&__pyx_n_s_DispG, __pyx_k_DispG, sizeof(__pyx_k_DispG), 0, 0, 1, 1},
    {&__pyx_n_s_DispHome, __pyx_k_DispHome, sizeof(__pyx_k_DispHome), 0, 0, 1, 1},
    {&__pyx_n_s_DrawFunc, __pyx_k_DrawFunc, sizeof(__pyx_k_DrawFunc), 0, 0, 1, 1},
    {&__pyx_n_s_DrawInv, __pyx_k_DrawInv, sizeof(__pyx_k_DrawInv), 0, 0, 1, 1},
    {&__pyx_n_s_DrawParm, __pyx_k_DrawParm, sizeof(__pyx_k_DrawParm), 0, 0, 1, 1},
    {&__pyx_n_s_DrawPol, __pyx_k_DrawPol, sizeof(__pyx_k_DrawPol), 0, 0, 1, 1},
    {&__pyx_n_s_DrawSlp, __pyx_k_DrawSlp, sizeof(__pyx_k_DrawSlp), 0, 0, 1, 1},
    {&__pyx_n_s_DropDown, __pyx_k_DropDown, sizeof(__pyx_k_DropDown), 0, 0, 1, 1},
    {&__pyx_n_s_DrwCtour, __pyx_k_DrwCtour, sizeof(__pyx_k_DrwCtour), 0, 0, 1, 1},
    {&__pyx_n_s_ERROR, __pyx_k_ERROR, sizeof(__pyx_k_ERROR), 0, 0, 1, 1},
    {&__pyx_n_s_EXP, __pyx_k_EXP, sizeof(__pyx_k_EXP), 0, 0, 1, 1},
    {&__pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman, __pyx_k_EXPERIMENTAL_Send_a_giac_comman, sizeof(__pyx_k_EXPERIMENTAL_Send_a_giac_comman), 0, 1, 0, 0},
    {&__pyx_n_s_Ei, __pyx_k_Ei, sizeof(__pyx_k_Ei), 0, 0, 1, 1},
    {&__pyx_n_s_EndDlog, __pyx_k_EndDlog, sizeof(__pyx_k_EndDlog), 0, 0, 1, 1},
    {&__pyx_kp_s_Error_executing_code_in_Giac_COD, __pyx_k_Error_executing_code_in_Giac_COD, sizeof(__pyx_k_Error_executing_code_in_Giac_COD), 0, 0, 1, 0},
    {&__pyx_n_s_F, __pyx_k_F, sizeof(__pyx_k_F), 0, 0, 1, 1},
    {&__pyx_n_s_FALSE, __pyx_k_FALSE, sizeof(__pyx_k_FALSE), 0, 0, 1, 1},
    {&__pyx_n_s_F_2, __pyx_k_F_2, sizeof(__pyx_k_F_2), 0, 0, 1, 1},
    {&__pyx_n_s_F_OK, __pyx_k_F_OK, sizeof(__pyx_k_F_OK), 0, 0, 1, 1},
    {&__pyx_n_s_Factor, __pyx_k_Factor, sizeof(__pyx_k_Factor), 0, 0, 1, 1},
    {&__pyx_n_s_Fahrenheit2Celsius, __pyx_k_Fahrenheit2Celsius, sizeof(__pyx_k_Fahrenheit2Celsius), 0, 0, 1, 1},
    {&__pyx_kp_s_Failed_to_start_a_thread, __pyx_k_Failed_to_start_a_thread, sizeof(__pyx_k_Failed_to_start_a_thread), 0, 0, 1, 0},
    {&__pyx_n_s_False, __pyx_k_False, sizeof(__pyx_k_False), 0, 0, 1, 1},
    {&__pyx_n_s_Fdy, __pyx_k_Fdy, sizeof(__pyx_k_Fdy), 0, 0, 1, 1},
    {&__pyx_n_s_Fill, __pyx_k_Fill, sizeof(__pyx_k_Fill), 0, 0, 1, 1},
    {&__pyx_n_s_Fourier, __pyx_k_Fourier, sizeof(__pyx_k_Fourier), 0, 0, 1, 1},
    {&__pyx_n_s_G, __pyx_k_G, sizeof(__pyx_k_G), 0, 0, 1, 1},
    {&__pyx_n_s_GF, __pyx_k_GF, sizeof(__pyx_k_GF), 0, 0, 1, 1},
    {&__pyx_n_s_GIACNULL, __pyx_k_GIACNULL, sizeof(__pyx_k_GIACNULL), 0, 0, 1, 1},
    {&__pyx_n_s_GIACPY_TMP_NAME05026807096929010, __pyx_k_GIACPY_TMP_NAME05026807096929010, sizeof(__pyx_k_GIACPY_TMP_NAME05026807096929010), 0, 0, 1, 1},
    {&__pyx_kp_s_GIACPY_TMP_NAME05026807096929010_2, __pyx_k_GIACPY_TMP_NAME05026807096929010_2, sizeof(__pyx_k_GIACPY_TMP_NAME05026807096929010_2), 0, 0, 1, 0},
    {&__pyx_n_s_Gal, __pyx_k_Gal, sizeof(__pyx_k_Gal), 0, 0, 1, 1},
    {&__pyx_n_s_Gamma, __pyx_k_Gamma, sizeof(__pyx_k_Gamma), 0, 0, 1, 1},
    {&__pyx_n_s_Gcd, __pyx_k_Gcd, sizeof(__pyx_k_Gcd), 0, 0, 1, 1},
    {&__pyx_n_s_GetFold, __pyx_k_GetFold, sizeof(__pyx_k_GetFold), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction, __pyx_k_GiacFunction, sizeof(__pyx_k_GiacFunction), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___add, __pyx_k_GiacFunction___add, sizeof(__pyx_k_GiacFunction___add), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___call, __pyx_k_GiacFunction___call, sizeof(__pyx_k_GiacFunction___call), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___div, __pyx_k_GiacFunction___div, sizeof(__pyx_k_GiacFunction___div), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___init, __pyx_k_GiacFunction___init, sizeof(__pyx_k_GiacFunction___init), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___mul, __pyx_k_GiacFunction___mul, sizeof(__pyx_k_GiacFunction___mul), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___neg, __pyx_k_GiacFunction___neg, sizeof(__pyx_k_GiacFunction___neg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___pow, __pyx_k_GiacFunction___pow, sizeof(__pyx_k_GiacFunction___pow), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___repr, __pyx_k_GiacFunction___repr, sizeof(__pyx_k_GiacFunction___repr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___str, __pyx_k_GiacFunction___str, sizeof(__pyx_k_GiacFunction___str), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___sub, __pyx_k_GiacFunction___sub, sizeof(__pyx_k_GiacFunction___sub), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction___truediv, __pyx_k_GiacFunction___truediv, sizeof(__pyx_k_GiacFunction___truediv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction_diff, __pyx_k_GiacFunction_diff, sizeof(__pyx_k_GiacFunction_diff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction_htmlhelp, __pyx_k_GiacFunction_htmlhelp, sizeof(__pyx_k_GiacFunction_htmlhelp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction_int, __pyx_k_GiacFunction_int, sizeof(__pyx_k_GiacFunction_int), 0, 0, 1, 1},
    {&__pyx_n_s_GiacFunction_plot, __pyx_k_GiacFunction_plot, sizeof(__pyx_k_GiacFunction_plot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods, __pyx_k_GiacMethods, sizeof(__pyx_k_GiacMethods), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base, __pyx_k_GiacMethods_base, sizeof(__pyx_k_GiacMethods_base), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Airy_Ai, __pyx_k_GiacMethods_base_Airy_Ai, sizeof(__pyx_k_GiacMethods_base_Airy_Ai), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Airy_Bi, __pyx_k_GiacMethods_base_Airy_Bi, sizeof(__pyx_k_GiacMethods_base_Airy_Bi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Archive, __pyx_k_GiacMethods_base_Archive, sizeof(__pyx_k_GiacMethods_base_Archive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_BesselJ, __pyx_k_GiacMethods_base_BesselJ, sizeof(__pyx_k_GiacMethods_base_BesselJ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_BesselY, __pyx_k_GiacMethods_base_BesselY, sizeof(__pyx_k_GiacMethods_base_BesselY), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Beta, __pyx_k_GiacMethods_base_Beta, sizeof(__pyx_k_GiacMethods_base_Beta), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_BlockDiagonal, __pyx_k_GiacMethods_base_BlockDiagonal, sizeof(__pyx_k_GiacMethods_base_BlockDiagonal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Ci, __pyx_k_GiacMethods_base_Ci, sizeof(__pyx_k_GiacMethods_base_Ci), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Circle, __pyx_k_GiacMethods_base_Circle, sizeof(__pyx_k_GiacMethods_base_Circle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Col, __pyx_k_GiacMethods_base_Col, sizeof(__pyx_k_GiacMethods_base_Col), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_CopyVar, __pyx_k_GiacMethods_base_CopyVar, sizeof(__pyx_k_GiacMethods_base_CopyVar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Dirac, __pyx_k_GiacMethods_base_Dirac, sizeof(__pyx_k_GiacMethods_base_Dirac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Ei, __pyx_k_GiacMethods_base_Ei, sizeof(__pyx_k_GiacMethods_base_Ei), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Factor, __pyx_k_GiacMethods_base_Factor, sizeof(__pyx_k_GiacMethods_base_Factor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Fourier, __pyx_k_GiacMethods_base_Fourier, sizeof(__pyx_k_GiacMethods_base_Fourier), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_GF, __pyx_k_GiacMethods_base_GF, sizeof(__pyx_k_GiacMethods_base_GF), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Gamma, __pyx_k_GiacMethods_base_Gamma, sizeof(__pyx_k_GiacMethods_base_Gamma), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Heaviside, __pyx_k_GiacMethods_base_Heaviside, sizeof(__pyx_k_GiacMethods_base_Heaviside), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Heaviside2sign, __pyx_k_GiacMethods_base_Heaviside2sign, sizeof(__pyx_k_GiacMethods_base_Heaviside2sign), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Hilbert, __pyx_k_GiacMethods_base_Hilbert, sizeof(__pyx_k_GiacMethods_base_Hilbert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_JordanBlock, __pyx_k_GiacMethods_base_JordanBlock, sizeof(__pyx_k_GiacMethods_base_JordanBlock), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_LU, __pyx_k_GiacMethods_base_LU, sizeof(__pyx_k_GiacMethods_base_LU), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_LambertW, __pyx_k_GiacMethods_base_LambertW, sizeof(__pyx_k_GiacMethods_base_LambertW), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Li, __pyx_k_GiacMethods_base_Li, sizeof(__pyx_k_GiacMethods_base_Li), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Line, __pyx_k_GiacMethods_base_Line, sizeof(__pyx_k_GiacMethods_base_Line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_LineHorz, __pyx_k_GiacMethods_base_LineHorz, sizeof(__pyx_k_GiacMethods_base_LineHorz), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_LineTan, __pyx_k_GiacMethods_base_LineTan, sizeof(__pyx_k_GiacMethods_base_LineTan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_LineVert, __pyx_k_GiacMethods_base_LineVert, sizeof(__pyx_k_GiacMethods_base_LineVert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_MSE, __pyx_k_GiacMethods_base_MSE, sizeof(__pyx_k_GiacMethods_base_MSE), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Phi, __pyx_k_GiacMethods_base_Phi, sizeof(__pyx_k_GiacMethods_base_Phi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Pi, __pyx_k_GiacMethods_base_Pi, sizeof(__pyx_k_GiacMethods_base_Pi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Psi, __pyx_k_GiacMethods_base_Psi, sizeof(__pyx_k_GiacMethods_base_Psi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_QR, __pyx_k_GiacMethods_base_QR, sizeof(__pyx_k_GiacMethods_base_QR), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_RandSeed, __pyx_k_GiacMethods_base_RandSeed, sizeof(__pyx_k_GiacMethods_base_RandSeed), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ReLU, __pyx_k_GiacMethods_base_ReLU, sizeof(__pyx_k_GiacMethods_base_ReLU), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Row, __pyx_k_GiacMethods_base_Row, sizeof(__pyx_k_GiacMethods_base_Row), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_SortA, __pyx_k_GiacMethods_base_SortA, sizeof(__pyx_k_GiacMethods_base_SortA), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_SortD, __pyx_k_GiacMethods_base_SortD, sizeof(__pyx_k_GiacMethods_base_SortD), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_UTPC, __pyx_k_GiacMethods_base_UTPC, sizeof(__pyx_k_GiacMethods_base_UTPC), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_UTPF, __pyx_k_GiacMethods_base_UTPF, sizeof(__pyx_k_GiacMethods_base_UTPF), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_UTPN, __pyx_k_GiacMethods_base_UTPN, sizeof(__pyx_k_GiacMethods_base_UTPN), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_UTPT, __pyx_k_GiacMethods_base_UTPT, sizeof(__pyx_k_GiacMethods_base_UTPT), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_VARS, __pyx_k_GiacMethods_base_VARS, sizeof(__pyx_k_GiacMethods_base_VARS), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_VAS, __pyx_k_GiacMethods_base_VAS, sizeof(__pyx_k_GiacMethods_base_VAS), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_VAS_positive, __pyx_k_GiacMethods_base_VAS_positive, sizeof(__pyx_k_GiacMethods_base_VAS_positive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_Zeta, __pyx_k_GiacMethods_base_Zeta, sizeof(__pyx_k_GiacMethods_base_Zeta), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base___reduce_cython, __pyx_k_GiacMethods_base___reduce_cython, sizeof(__pyx_k_GiacMethods_base___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base___setstate_cyth, __pyx_k_GiacMethods_base___setstate_cyth, sizeof(__pyx_k_GiacMethods_base___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_a2q, __pyx_k_GiacMethods_base_a2q, sizeof(__pyx_k_GiacMethods_base_a2q), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_abcuv, __pyx_k_GiacMethods_base_abcuv, sizeof(__pyx_k_GiacMethods_base_abcuv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_about, __pyx_k_GiacMethods_base_about, sizeof(__pyx_k_GiacMethods_base_about), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_abs, __pyx_k_GiacMethods_base_abs, sizeof(__pyx_k_GiacMethods_base_abs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_abscissa, __pyx_k_GiacMethods_base_abscissa, sizeof(__pyx_k_GiacMethods_base_abscissa), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_accumulate_head, __pyx_k_GiacMethods_base_accumulate_head, sizeof(__pyx_k_GiacMethods_base_accumulate_head), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acos, __pyx_k_GiacMethods_base_acos, sizeof(__pyx_k_GiacMethods_base_acos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acos2asin, __pyx_k_GiacMethods_base_acos2asin, sizeof(__pyx_k_GiacMethods_base_acos2asin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acos2atan, __pyx_k_GiacMethods_base_acos2atan, sizeof(__pyx_k_GiacMethods_base_acos2atan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acosh, __pyx_k_GiacMethods_base_acosh, sizeof(__pyx_k_GiacMethods_base_acosh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acot, __pyx_k_GiacMethods_base_acot, sizeof(__pyx_k_GiacMethods_base_acot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acsc, __pyx_k_GiacMethods_base_acsc, sizeof(__pyx_k_GiacMethods_base_acsc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_acyclic, __pyx_k_GiacMethods_base_acyclic, sizeof(__pyx_k_GiacMethods_base_acyclic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_adaptive, __pyx_k_GiacMethods_base_adaptive, sizeof(__pyx_k_GiacMethods_base_adaptive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_add, __pyx_k_GiacMethods_base_add, sizeof(__pyx_k_GiacMethods_base_add), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_add_arc, __pyx_k_GiacMethods_base_add_arc, sizeof(__pyx_k_GiacMethods_base_add_arc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_add_edge, __pyx_k_GiacMethods_base_add_edge, sizeof(__pyx_k_GiacMethods_base_add_edge), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_add_vertex, __pyx_k_GiacMethods_base_add_vertex, sizeof(__pyx_k_GiacMethods_base_add_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_additionally, __pyx_k_GiacMethods_base_additionally, sizeof(__pyx_k_GiacMethods_base_additionally), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_addtable, __pyx_k_GiacMethods_base_addtable, sizeof(__pyx_k_GiacMethods_base_addtable), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_adjacency_matri, __pyx_k_GiacMethods_base_adjacency_matri, sizeof(__pyx_k_GiacMethods_base_adjacency_matri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_adjoint_matrix, __pyx_k_GiacMethods_base_adjoint_matrix, sizeof(__pyx_k_GiacMethods_base_adjoint_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_affix, __pyx_k_GiacMethods_base_affix, sizeof(__pyx_k_GiacMethods_base_affix), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_algsubs, __pyx_k_GiacMethods_base_algsubs, sizeof(__pyx_k_GiacMethods_base_algsubs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_algvar, __pyx_k_GiacMethods_base_algvar, sizeof(__pyx_k_GiacMethods_base_algvar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_all_trig_soluti, __pyx_k_GiacMethods_base_all_trig_soluti, sizeof(__pyx_k_GiacMethods_base_all_trig_soluti), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_allpairs_distan, __pyx_k_GiacMethods_base_allpairs_distan, sizeof(__pyx_k_GiacMethods_base_allpairs_distan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_alog10, __pyx_k_GiacMethods_base_alog10, sizeof(__pyx_k_GiacMethods_base_alog10), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_altitude, __pyx_k_GiacMethods_base_altitude, sizeof(__pyx_k_GiacMethods_base_altitude), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_angle, __pyx_k_GiacMethods_base_angle, sizeof(__pyx_k_GiacMethods_base_angle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_angle_radian, __pyx_k_GiacMethods_base_angle_radian, sizeof(__pyx_k_GiacMethods_base_angle_radian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_angleat, __pyx_k_GiacMethods_base_angleat, sizeof(__pyx_k_GiacMethods_base_angleat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_angleatraw, __pyx_k_GiacMethods_base_angleatraw, sizeof(__pyx_k_GiacMethods_base_angleatraw), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ans, __pyx_k_GiacMethods_base_ans, sizeof(__pyx_k_GiacMethods_base_ans), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_antiprism_graph, __pyx_k_GiacMethods_base_antiprism_graph, sizeof(__pyx_k_GiacMethods_base_antiprism_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_append, __pyx_k_GiacMethods_base_append, sizeof(__pyx_k_GiacMethods_base_append), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_apply, __pyx_k_GiacMethods_base_apply, sizeof(__pyx_k_GiacMethods_base_apply), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_approx, __pyx_k_GiacMethods_base_approx, sizeof(__pyx_k_GiacMethods_base_approx), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arc, __pyx_k_GiacMethods_base_arc, sizeof(__pyx_k_GiacMethods_base_arc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arcLen, __pyx_k_GiacMethods_base_arcLen, sizeof(__pyx_k_GiacMethods_base_arcLen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arccos, __pyx_k_GiacMethods_base_arccos, sizeof(__pyx_k_GiacMethods_base_arccos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arccosh, __pyx_k_GiacMethods_base_arccosh, sizeof(__pyx_k_GiacMethods_base_arccosh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arclen, __pyx_k_GiacMethods_base_arclen, sizeof(__pyx_k_GiacMethods_base_arclen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arcsin, __pyx_k_GiacMethods_base_arcsin, sizeof(__pyx_k_GiacMethods_base_arcsin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arcsinh, __pyx_k_GiacMethods_base_arcsinh, sizeof(__pyx_k_GiacMethods_base_arcsinh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arctan, __pyx_k_GiacMethods_base_arctan, sizeof(__pyx_k_GiacMethods_base_arctan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arctanh, __pyx_k_GiacMethods_base_arctanh, sizeof(__pyx_k_GiacMethods_base_arctanh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_area, __pyx_k_GiacMethods_base_area, sizeof(__pyx_k_GiacMethods_base_area), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_areaat, __pyx_k_GiacMethods_base_areaat, sizeof(__pyx_k_GiacMethods_base_areaat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_areaatraw, __pyx_k_GiacMethods_base_areaatraw, sizeof(__pyx_k_GiacMethods_base_areaatraw), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_areaplot, __pyx_k_GiacMethods_base_areaplot, sizeof(__pyx_k_GiacMethods_base_areaplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arg, __pyx_k_GiacMethods_base_arg, sizeof(__pyx_k_GiacMethods_base_arg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_array, __pyx_k_GiacMethods_base_array, sizeof(__pyx_k_GiacMethods_base_array), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_arrivals, __pyx_k_GiacMethods_base_arrivals, sizeof(__pyx_k_GiacMethods_base_arrivals), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_articulation_po, __pyx_k_GiacMethods_base_articulation_po, sizeof(__pyx_k_GiacMethods_base_articulation_po), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_asin, __pyx_k_GiacMethods_base_asin, sizeof(__pyx_k_GiacMethods_base_asin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_asin2acos, __pyx_k_GiacMethods_base_asin2acos, sizeof(__pyx_k_GiacMethods_base_asin2acos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_asin2atan, __pyx_k_GiacMethods_base_asin2atan, sizeof(__pyx_k_GiacMethods_base_asin2atan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_asinh, __pyx_k_GiacMethods_base_asinh, sizeof(__pyx_k_GiacMethods_base_asinh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_assign_edge_wei, __pyx_k_GiacMethods_base_assign_edge_wei, sizeof(__pyx_k_GiacMethods_base_assign_edge_wei), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_assume, __pyx_k_GiacMethods_base_assume, sizeof(__pyx_k_GiacMethods_base_assume), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_at, __pyx_k_GiacMethods_base_at, sizeof(__pyx_k_GiacMethods_base_at), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_atan, __pyx_k_GiacMethods_base_atan, sizeof(__pyx_k_GiacMethods_base_atan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_atan2, __pyx_k_GiacMethods_base_atan2, sizeof(__pyx_k_GiacMethods_base_atan2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_atan2acos, __pyx_k_GiacMethods_base_atan2acos, sizeof(__pyx_k_GiacMethods_base_atan2acos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_atan2asin, __pyx_k_GiacMethods_base_atan2asin, sizeof(__pyx_k_GiacMethods_base_atan2asin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_atanh, __pyx_k_GiacMethods_base_atanh, sizeof(__pyx_k_GiacMethods_base_atanh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_atrig2ln, __pyx_k_GiacMethods_base_atrig2ln, sizeof(__pyx_k_GiacMethods_base_atrig2ln), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_augment, __pyx_k_GiacMethods_base_augment, sizeof(__pyx_k_GiacMethods_base_augment), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_auto_correlatio, __pyx_k_GiacMethods_base_auto_correlatio, sizeof(__pyx_k_GiacMethods_base_auto_correlatio), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_autosimplify, __pyx_k_GiacMethods_base_autosimplify, sizeof(__pyx_k_GiacMethods_base_autosimplify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_avance, __pyx_k_GiacMethods_base_avance, sizeof(__pyx_k_GiacMethods_base_avance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_avgRC, __pyx_k_GiacMethods_base_avgRC, sizeof(__pyx_k_GiacMethods_base_avgRC), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_axes, __pyx_k_GiacMethods_base_axes, sizeof(__pyx_k_GiacMethods_base_axes), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_axis, __pyx_k_GiacMethods_base_axis, sizeof(__pyx_k_GiacMethods_base_axis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_back, __pyx_k_GiacMethods_base_back, sizeof(__pyx_k_GiacMethods_base_back), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_backward, __pyx_k_GiacMethods_base_backward, sizeof(__pyx_k_GiacMethods_base_backward), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_baisse_crayon, __pyx_k_GiacMethods_base_baisse_crayon, sizeof(__pyx_k_GiacMethods_base_baisse_crayon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bandwidth, __pyx_k_GiacMethods_base_bandwidth, sizeof(__pyx_k_GiacMethods_base_bandwidth), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bar_plot, __pyx_k_GiacMethods_base_bar_plot, sizeof(__pyx_k_GiacMethods_base_bar_plot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_barplot, __pyx_k_GiacMethods_base_barplot, sizeof(__pyx_k_GiacMethods_base_barplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bartlett_hann_w, __pyx_k_GiacMethods_base_bartlett_hann_w, sizeof(__pyx_k_GiacMethods_base_bartlett_hann_w), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_barycenter, __pyx_k_GiacMethods_base_barycenter, sizeof(__pyx_k_GiacMethods_base_barycenter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_base, __pyx_k_GiacMethods_base_base, sizeof(__pyx_k_GiacMethods_base_base), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_basis, __pyx_k_GiacMethods_base_basis, sizeof(__pyx_k_GiacMethods_base_basis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_batons, __pyx_k_GiacMethods_base_batons, sizeof(__pyx_k_GiacMethods_base_batons), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bellman_ford, __pyx_k_GiacMethods_base_bellman_ford, sizeof(__pyx_k_GiacMethods_base_bellman_ford), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_berlekamp_masse, __pyx_k_GiacMethods_base_berlekamp_masse, sizeof(__pyx_k_GiacMethods_base_berlekamp_masse), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bernoulli, __pyx_k_GiacMethods_base_bernoulli, sizeof(__pyx_k_GiacMethods_base_bernoulli), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bernoulli_mod, __pyx_k_GiacMethods_base_bernoulli_mod, sizeof(__pyx_k_GiacMethods_base_bernoulli_mod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_besselJ, __pyx_k_GiacMethods_base_besselJ, sizeof(__pyx_k_GiacMethods_base_besselJ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_besselY, __pyx_k_GiacMethods_base_besselY, sizeof(__pyx_k_GiacMethods_base_besselY), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_betad, __pyx_k_GiacMethods_base_betad, sizeof(__pyx_k_GiacMethods_base_betad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_betad_cdf, __pyx_k_GiacMethods_base_betad_cdf, sizeof(__pyx_k_GiacMethods_base_betad_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_betad_icdf, __pyx_k_GiacMethods_base_betad_icdf, sizeof(__pyx_k_GiacMethods_base_betad_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_betavariate, __pyx_k_GiacMethods_base_betavariate, sizeof(__pyx_k_GiacMethods_base_betavariate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_betweenness_cen, __pyx_k_GiacMethods_base_betweenness_cen, sizeof(__pyx_k_GiacMethods_base_betweenness_cen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bezier, __pyx_k_GiacMethods_base_bezier, sizeof(__pyx_k_GiacMethods_base_bezier), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bezout_entiers, __pyx_k_GiacMethods_base_bezout_entiers, sizeof(__pyx_k_GiacMethods_base_bezout_entiers), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bezoutian, __pyx_k_GiacMethods_base_bezoutian, sizeof(__pyx_k_GiacMethods_base_bezoutian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_biconnected_com, __pyx_k_GiacMethods_base_biconnected_com, sizeof(__pyx_k_GiacMethods_base_biconnected_com), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_binomial, __pyx_k_GiacMethods_base_binomial, sizeof(__pyx_k_GiacMethods_base_binomial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_binomial_cdf, __pyx_k_GiacMethods_base_binomial_cdf, sizeof(__pyx_k_GiacMethods_base_binomial_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_binomial_icdf, __pyx_k_GiacMethods_base_binomial_icdf, sizeof(__pyx_k_GiacMethods_base_binomial_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bins, __pyx_k_GiacMethods_base_bins, sizeof(__pyx_k_GiacMethods_base_bins), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bipartite, __pyx_k_GiacMethods_base_bipartite, sizeof(__pyx_k_GiacMethods_base_bipartite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bipartite_match, __pyx_k_GiacMethods_base_bipartite_match, sizeof(__pyx_k_GiacMethods_base_bipartite_match), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bisection_solve, __pyx_k_GiacMethods_base_bisection_solve, sizeof(__pyx_k_GiacMethods_base_bisection_solve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bisector, __pyx_k_GiacMethods_base_bisector, sizeof(__pyx_k_GiacMethods_base_bisector), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bit_depth, __pyx_k_GiacMethods_base_bit_depth, sizeof(__pyx_k_GiacMethods_base_bit_depth), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bitand, __pyx_k_GiacMethods_base_bitand, sizeof(__pyx_k_GiacMethods_base_bitand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bitor, __pyx_k_GiacMethods_base_bitor, sizeof(__pyx_k_GiacMethods_base_bitor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bitxor, __pyx_k_GiacMethods_base_bitxor, sizeof(__pyx_k_GiacMethods_base_bitxor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_blackman_harris, __pyx_k_GiacMethods_base_blackman_harris, sizeof(__pyx_k_GiacMethods_base_blackman_harris), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_blackman_window, __pyx_k_GiacMethods_base_blackman_window, sizeof(__pyx_k_GiacMethods_base_blackman_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_block_size, __pyx_k_GiacMethods_base_block_size, sizeof(__pyx_k_GiacMethods_base_block_size), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_blockmatrix, __pyx_k_GiacMethods_base_blockmatrix, sizeof(__pyx_k_GiacMethods_base_blockmatrix), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bohman_window, __pyx_k_GiacMethods_base_bohman_window, sizeof(__pyx_k_GiacMethods_base_bohman_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_border, __pyx_k_GiacMethods_base_border, sizeof(__pyx_k_GiacMethods_base_border), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_box_constraints, __pyx_k_GiacMethods_base_box_constraints, sizeof(__pyx_k_GiacMethods_base_box_constraints), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_boxcar, __pyx_k_GiacMethods_base_boxcar, sizeof(__pyx_k_GiacMethods_base_boxcar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_boxwhisker, __pyx_k_GiacMethods_base_boxwhisker, sizeof(__pyx_k_GiacMethods_base_boxwhisker), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_brent_solver, __pyx_k_GiacMethods_base_brent_solver, sizeof(__pyx_k_GiacMethods_base_brent_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_brown, __pyx_k_GiacMethods_base_brown, sizeof(__pyx_k_GiacMethods_base_brown), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bspline, __pyx_k_GiacMethods_base_bspline, sizeof(__pyx_k_GiacMethods_base_bspline), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_bvpsolve, __pyx_k_GiacMethods_base_bvpsolve, sizeof(__pyx_k_GiacMethods_base_bvpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cFactor, __pyx_k_GiacMethods_base_cFactor, sizeof(__pyx_k_GiacMethods_base_cFactor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cSolve, __pyx_k_GiacMethods_base_cSolve, sizeof(__pyx_k_GiacMethods_base_cSolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cZeros, __pyx_k_GiacMethods_base_cZeros, sizeof(__pyx_k_GiacMethods_base_cZeros), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_camembert, __pyx_k_GiacMethods_base_camembert, sizeof(__pyx_k_GiacMethods_base_camembert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_canonical_form, __pyx_k_GiacMethods_base_canonical_form, sizeof(__pyx_k_GiacMethods_base_canonical_form), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_canonical_label, __pyx_k_GiacMethods_base_canonical_label, sizeof(__pyx_k_GiacMethods_base_canonical_label), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cartesian_produ, __pyx_k_GiacMethods_base_cartesian_produ, sizeof(__pyx_k_GiacMethods_base_cartesian_produ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cauchy, __pyx_k_GiacMethods_base_cauchy, sizeof(__pyx_k_GiacMethods_base_cauchy), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cauchy_cdf, __pyx_k_GiacMethods_base_cauchy_cdf, sizeof(__pyx_k_GiacMethods_base_cauchy_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cauchy_icdf, __pyx_k_GiacMethods_base_cauchy_icdf, sizeof(__pyx_k_GiacMethods_base_cauchy_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cauchyd, __pyx_k_GiacMethods_base_cauchyd, sizeof(__pyx_k_GiacMethods_base_cauchyd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cauchyd_cdf, __pyx_k_GiacMethods_base_cauchyd_cdf, sizeof(__pyx_k_GiacMethods_base_cauchyd_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cauchyd_icdf, __pyx_k_GiacMethods_base_cauchyd_icdf, sizeof(__pyx_k_GiacMethods_base_cauchyd_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cdf, __pyx_k_GiacMethods_base_cdf, sizeof(__pyx_k_GiacMethods_base_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ceil, __pyx_k_GiacMethods_base_ceil, sizeof(__pyx_k_GiacMethods_base_ceil), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ceiling, __pyx_k_GiacMethods_base_ceiling, sizeof(__pyx_k_GiacMethods_base_ceiling), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_center, __pyx_k_GiacMethods_base_center, sizeof(__pyx_k_GiacMethods_base_center), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_center2interval, __pyx_k_GiacMethods_base_center2interval, sizeof(__pyx_k_GiacMethods_base_center2interval), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_centered_cube, __pyx_k_GiacMethods_base_centered_cube, sizeof(__pyx_k_GiacMethods_base_centered_cube), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_centered_tetrah, __pyx_k_GiacMethods_base_centered_tetrah, sizeof(__pyx_k_GiacMethods_base_centered_tetrah), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cfactor, __pyx_k_GiacMethods_base_cfactor, sizeof(__pyx_k_GiacMethods_base_cfactor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cfsolve, __pyx_k_GiacMethods_base_cfsolve, sizeof(__pyx_k_GiacMethods_base_cfsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_changebase, __pyx_k_GiacMethods_base_changebase, sizeof(__pyx_k_GiacMethods_base_changebase), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_channel_data, __pyx_k_GiacMethods_base_channel_data, sizeof(__pyx_k_GiacMethods_base_channel_data), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_channels, __pyx_k_GiacMethods_base_channels, sizeof(__pyx_k_GiacMethods_base_channels), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_char, __pyx_k_GiacMethods_base_char, sizeof(__pyx_k_GiacMethods_base_char), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_charpoly, __pyx_k_GiacMethods_base_charpoly, sizeof(__pyx_k_GiacMethods_base_charpoly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chinrem, __pyx_k_GiacMethods_base_chinrem, sizeof(__pyx_k_GiacMethods_base_chinrem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquare, __pyx_k_GiacMethods_base_chisquare, sizeof(__pyx_k_GiacMethods_base_chisquare), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquare_cdf, __pyx_k_GiacMethods_base_chisquare_cdf, sizeof(__pyx_k_GiacMethods_base_chisquare_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquare_icdf, __pyx_k_GiacMethods_base_chisquare_icdf, sizeof(__pyx_k_GiacMethods_base_chisquare_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquared, __pyx_k_GiacMethods_base_chisquared, sizeof(__pyx_k_GiacMethods_base_chisquared), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquared_cdf, __pyx_k_GiacMethods_base_chisquared_cdf, sizeof(__pyx_k_GiacMethods_base_chisquared_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquared_icdf, __pyx_k_GiacMethods_base_chisquared_icdf, sizeof(__pyx_k_GiacMethods_base_chisquared_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chisquaret, __pyx_k_GiacMethods_base_chisquaret, sizeof(__pyx_k_GiacMethods_base_chisquaret), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_choice, __pyx_k_GiacMethods_base_choice, sizeof(__pyx_k_GiacMethods_base_choice), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cholesky, __pyx_k_GiacMethods_base_cholesky, sizeof(__pyx_k_GiacMethods_base_cholesky), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chr, __pyx_k_GiacMethods_base_chr, sizeof(__pyx_k_GiacMethods_base_chr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chrem, __pyx_k_GiacMethods_base_chrem, sizeof(__pyx_k_GiacMethods_base_chrem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chromatic_index, __pyx_k_GiacMethods_base_chromatic_index, sizeof(__pyx_k_GiacMethods_base_chromatic_index), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chromatic_numbe, __pyx_k_GiacMethods_base_chromatic_numbe, sizeof(__pyx_k_GiacMethods_base_chromatic_numbe), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_chromatic_polyn, __pyx_k_GiacMethods_base_chromatic_polyn, sizeof(__pyx_k_GiacMethods_base_chromatic_polyn), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_circle, __pyx_k_GiacMethods_base_circle, sizeof(__pyx_k_GiacMethods_base_circle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_circumcircle, __pyx_k_GiacMethods_base_circumcircle, sizeof(__pyx_k_GiacMethods_base_circumcircle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_classes, __pyx_k_GiacMethods_base_classes, sizeof(__pyx_k_GiacMethods_base_classes), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_clear, __pyx_k_GiacMethods_base_clear, sizeof(__pyx_k_GiacMethods_base_clear), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_clique_cover, __pyx_k_GiacMethods_base_clique_cover, sizeof(__pyx_k_GiacMethods_base_clique_cover), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_clique_cover_nu, __pyx_k_GiacMethods_base_clique_cover_nu, sizeof(__pyx_k_GiacMethods_base_clique_cover_nu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_clique_number, __pyx_k_GiacMethods_base_clique_number, sizeof(__pyx_k_GiacMethods_base_clique_number), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_closeness_centr, __pyx_k_GiacMethods_base_closeness_centr, sizeof(__pyx_k_GiacMethods_base_closeness_centr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cluster, __pyx_k_GiacMethods_base_cluster, sizeof(__pyx_k_GiacMethods_base_cluster), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_clustering_coef, __pyx_k_GiacMethods_base_clustering_coef, sizeof(__pyx_k_GiacMethods_base_clustering_coef), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_coeff, __pyx_k_GiacMethods_base_coeff, sizeof(__pyx_k_GiacMethods_base_coeff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_coeffs, __pyx_k_GiacMethods_base_coeffs, sizeof(__pyx_k_GiacMethods_base_coeffs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_col, __pyx_k_GiacMethods_base_col, sizeof(__pyx_k_GiacMethods_base_col), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colDim, __pyx_k_GiacMethods_base_colDim, sizeof(__pyx_k_GiacMethods_base_colDim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colNorm, __pyx_k_GiacMethods_base_colNorm, sizeof(__pyx_k_GiacMethods_base_colNorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colSwap, __pyx_k_GiacMethods_base_colSwap, sizeof(__pyx_k_GiacMethods_base_colSwap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_coldim, __pyx_k_GiacMethods_base_coldim, sizeof(__pyx_k_GiacMethods_base_coldim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_collect, __pyx_k_GiacMethods_base_collect, sizeof(__pyx_k_GiacMethods_base_collect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colnorm, __pyx_k_GiacMethods_base_colnorm, sizeof(__pyx_k_GiacMethods_base_colnorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_color, __pyx_k_GiacMethods_base_color, sizeof(__pyx_k_GiacMethods_base_color), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colormap, __pyx_k_GiacMethods_base_colormap, sizeof(__pyx_k_GiacMethods_base_colormap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colspace, __pyx_k_GiacMethods_base_colspace, sizeof(__pyx_k_GiacMethods_base_colspace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_colswap, __pyx_k_GiacMethods_base_colswap, sizeof(__pyx_k_GiacMethods_base_colswap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_comDenom, __pyx_k_GiacMethods_base_comDenom, sizeof(__pyx_k_GiacMethods_base_comDenom), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_comb, __pyx_k_GiacMethods_base_comb, sizeof(__pyx_k_GiacMethods_base_comb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_combine, __pyx_k_GiacMethods_base_combine, sizeof(__pyx_k_GiacMethods_base_combine), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_comment, __pyx_k_GiacMethods_base_comment, sizeof(__pyx_k_GiacMethods_base_comment), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_common_perpendi, __pyx_k_GiacMethods_base_common_perpendi, sizeof(__pyx_k_GiacMethods_base_common_perpendi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_companion, __pyx_k_GiacMethods_base_companion, sizeof(__pyx_k_GiacMethods_base_companion), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_compare, __pyx_k_GiacMethods_base_compare, sizeof(__pyx_k_GiacMethods_base_compare), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_complete_binary, __pyx_k_GiacMethods_base_complete_binary, sizeof(__pyx_k_GiacMethods_base_complete_binary), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_complete_graph, __pyx_k_GiacMethods_base_complete_graph, sizeof(__pyx_k_GiacMethods_base_complete_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_complete_kary_t, __pyx_k_GiacMethods_base_complete_kary_t, sizeof(__pyx_k_GiacMethods_base_complete_kary_t), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_complex, __pyx_k_GiacMethods_base_complex, sizeof(__pyx_k_GiacMethods_base_complex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_complex_variabl, __pyx_k_GiacMethods_base_complex_variabl, sizeof(__pyx_k_GiacMethods_base_complex_variabl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_complexroot, __pyx_k_GiacMethods_base_complexroot, sizeof(__pyx_k_GiacMethods_base_complexroot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_concat, __pyx_k_GiacMethods_base_concat, sizeof(__pyx_k_GiacMethods_base_concat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cond, __pyx_k_GiacMethods_base_cond, sizeof(__pyx_k_GiacMethods_base_cond), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_condensation, __pyx_k_GiacMethods_base_condensation, sizeof(__pyx_k_GiacMethods_base_condensation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cone, __pyx_k_GiacMethods_base_cone, sizeof(__pyx_k_GiacMethods_base_cone), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_confrac, __pyx_k_GiacMethods_base_confrac, sizeof(__pyx_k_GiacMethods_base_confrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_conic, __pyx_k_GiacMethods_base_conic, sizeof(__pyx_k_GiacMethods_base_conic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_conj, __pyx_k_GiacMethods_base_conj, sizeof(__pyx_k_GiacMethods_base_conj), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_conjugate_equat, __pyx_k_GiacMethods_base_conjugate_equat, sizeof(__pyx_k_GiacMethods_base_conjugate_equat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_conjugate_gradi, __pyx_k_GiacMethods_base_conjugate_gradi, sizeof(__pyx_k_GiacMethods_base_conjugate_gradi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_connected, __pyx_k_GiacMethods_base_connected, sizeof(__pyx_k_GiacMethods_base_connected), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_connected_compo, __pyx_k_GiacMethods_base_connected_compo, sizeof(__pyx_k_GiacMethods_base_connected_compo), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cont, __pyx_k_GiacMethods_base_cont, sizeof(__pyx_k_GiacMethods_base_cont), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_contains, __pyx_k_GiacMethods_base_contains, sizeof(__pyx_k_GiacMethods_base_contains), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_content, __pyx_k_GiacMethods_base_content, sizeof(__pyx_k_GiacMethods_base_content), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_contourplot, __pyx_k_GiacMethods_base_contourplot, sizeof(__pyx_k_GiacMethods_base_contourplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_contract_edge, __pyx_k_GiacMethods_base_contract_edge, sizeof(__pyx_k_GiacMethods_base_contract_edge), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_contract_subgra, __pyx_k_GiacMethods_base_contract_subgra, sizeof(__pyx_k_GiacMethods_base_contract_subgra), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_convert, __pyx_k_GiacMethods_base_convert, sizeof(__pyx_k_GiacMethods_base_convert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_convertir, __pyx_k_GiacMethods_base_convertir, sizeof(__pyx_k_GiacMethods_base_convertir), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_convex, __pyx_k_GiacMethods_base_convex, sizeof(__pyx_k_GiacMethods_base_convex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_convexhull, __pyx_k_GiacMethods_base_convexhull, sizeof(__pyx_k_GiacMethods_base_convexhull), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_convolution, __pyx_k_GiacMethods_base_convolution, sizeof(__pyx_k_GiacMethods_base_convolution), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_coordinates, __pyx_k_GiacMethods_base_coordinates, sizeof(__pyx_k_GiacMethods_base_coordinates), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_copy, __pyx_k_GiacMethods_base_copy, sizeof(__pyx_k_GiacMethods_base_copy), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_correlation, __pyx_k_GiacMethods_base_correlation, sizeof(__pyx_k_GiacMethods_base_correlation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cos, __pyx_k_GiacMethods_base_cos, sizeof(__pyx_k_GiacMethods_base_cos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cos2sintan, __pyx_k_GiacMethods_base_cos2sintan, sizeof(__pyx_k_GiacMethods_base_cos2sintan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cosh, __pyx_k_GiacMethods_base_cosh, sizeof(__pyx_k_GiacMethods_base_cosh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cosine_window, __pyx_k_GiacMethods_base_cosine_window, sizeof(__pyx_k_GiacMethods_base_cosine_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cot, __pyx_k_GiacMethods_base_cot, sizeof(__pyx_k_GiacMethods_base_cot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cote, __pyx_k_GiacMethods_base_cote, sizeof(__pyx_k_GiacMethods_base_cote), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_count, __pyx_k_GiacMethods_base_count, sizeof(__pyx_k_GiacMethods_base_count), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_count_eq, __pyx_k_GiacMethods_base_count_eq, sizeof(__pyx_k_GiacMethods_base_count_eq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_count_inf, __pyx_k_GiacMethods_base_count_inf, sizeof(__pyx_k_GiacMethods_base_count_inf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_count_sup, __pyx_k_GiacMethods_base_count_sup, sizeof(__pyx_k_GiacMethods_base_count_sup), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_courbe_parametr, __pyx_k_GiacMethods_base_courbe_parametr, sizeof(__pyx_k_GiacMethods_base_courbe_parametr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_courbe_polaire, __pyx_k_GiacMethods_base_courbe_polaire, sizeof(__pyx_k_GiacMethods_base_courbe_polaire), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_covariance, __pyx_k_GiacMethods_base_covariance, sizeof(__pyx_k_GiacMethods_base_covariance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_covariance_corr, __pyx_k_GiacMethods_base_covariance_corr, sizeof(__pyx_k_GiacMethods_base_covariance_corr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cpartfrac, __pyx_k_GiacMethods_base_cpartfrac, sizeof(__pyx_k_GiacMethods_base_cpartfrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_crationalroot, __pyx_k_GiacMethods_base_crationalroot, sizeof(__pyx_k_GiacMethods_base_crationalroot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_crayon, __pyx_k_GiacMethods_base_crayon, sizeof(__pyx_k_GiacMethods_base_crayon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_createwav, __pyx_k_GiacMethods_base_createwav, sizeof(__pyx_k_GiacMethods_base_createwav), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cross, __pyx_k_GiacMethods_base_cross, sizeof(__pyx_k_GiacMethods_base_cross), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_crossP, __pyx_k_GiacMethods_base_crossP, sizeof(__pyx_k_GiacMethods_base_crossP), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cross_correlati, __pyx_k_GiacMethods_base_cross_correlati, sizeof(__pyx_k_GiacMethods_base_cross_correlati), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cross_entropy, __pyx_k_GiacMethods_base_cross_entropy, sizeof(__pyx_k_GiacMethods_base_cross_entropy), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cross_point, __pyx_k_GiacMethods_base_cross_point, sizeof(__pyx_k_GiacMethods_base_cross_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cross_ratio, __pyx_k_GiacMethods_base_cross_ratio, sizeof(__pyx_k_GiacMethods_base_cross_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_crossproduct, __pyx_k_GiacMethods_base_crossproduct, sizeof(__pyx_k_GiacMethods_base_crossproduct), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_csc, __pyx_k_GiacMethods_base_csc, sizeof(__pyx_k_GiacMethods_base_csc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_csolve, __pyx_k_GiacMethods_base_csolve, sizeof(__pyx_k_GiacMethods_base_csolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_csv2gen, __pyx_k_GiacMethods_base_csv2gen, sizeof(__pyx_k_GiacMethods_base_csv2gen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cube, __pyx_k_GiacMethods_base_cube, sizeof(__pyx_k_GiacMethods_base_cube), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cumSum, __pyx_k_GiacMethods_base_cumSum, sizeof(__pyx_k_GiacMethods_base_cumSum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cumsum, __pyx_k_GiacMethods_base_cumsum, sizeof(__pyx_k_GiacMethods_base_cumsum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cumulated_frequ, __pyx_k_GiacMethods_base_cumulated_frequ, sizeof(__pyx_k_GiacMethods_base_cumulated_frequ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_curl, __pyx_k_GiacMethods_base_curl, sizeof(__pyx_k_GiacMethods_base_curl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_current_sheet, __pyx_k_GiacMethods_base_current_sheet, sizeof(__pyx_k_GiacMethods_base_current_sheet), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_curvature, __pyx_k_GiacMethods_base_curvature, sizeof(__pyx_k_GiacMethods_base_curvature), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_curve, __pyx_k_GiacMethods_base_curve, sizeof(__pyx_k_GiacMethods_base_curve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cyan, __pyx_k_GiacMethods_base_cyan, sizeof(__pyx_k_GiacMethods_base_cyan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cycle2perm, __pyx_k_GiacMethods_base_cycle2perm, sizeof(__pyx_k_GiacMethods_base_cycle2perm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cycle_basis, __pyx_k_GiacMethods_base_cycle_basis, sizeof(__pyx_k_GiacMethods_base_cycle_basis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cycle_graph, __pyx_k_GiacMethods_base_cycle_graph, sizeof(__pyx_k_GiacMethods_base_cycle_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cycleinv, __pyx_k_GiacMethods_base_cycleinv, sizeof(__pyx_k_GiacMethods_base_cycleinv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cycles2permu, __pyx_k_GiacMethods_base_cycles2permu, sizeof(__pyx_k_GiacMethods_base_cycles2permu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cyclotomic, __pyx_k_GiacMethods_base_cyclotomic, sizeof(__pyx_k_GiacMethods_base_cyclotomic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_cylinder, __pyx_k_GiacMethods_base_cylinder, sizeof(__pyx_k_GiacMethods_base_cylinder), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dash_line, __pyx_k_GiacMethods_base_dash_line, sizeof(__pyx_k_GiacMethods_base_dash_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dashdot_line, __pyx_k_GiacMethods_base_dashdot_line, sizeof(__pyx_k_GiacMethods_base_dashdot_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dashdotdot_line, __pyx_k_GiacMethods_base_dashdotdot_line, sizeof(__pyx_k_GiacMethods_base_dashdotdot_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dayofweek, __pyx_k_GiacMethods_base_dayofweek, sizeof(__pyx_k_GiacMethods_base_dayofweek), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_deSolve, __pyx_k_GiacMethods_base_deSolve, sizeof(__pyx_k_GiacMethods_base_deSolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_debut_enregistr, __pyx_k_GiacMethods_base_debut_enregistr, sizeof(__pyx_k_GiacMethods_base_debut_enregistr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_degree, __pyx_k_GiacMethods_base_degree, sizeof(__pyx_k_GiacMethods_base_degree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_degree_centrali, __pyx_k_GiacMethods_base_degree_centrali, sizeof(__pyx_k_GiacMethods_base_degree_centrali), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_degree_sequence, __pyx_k_GiacMethods_base_degree_sequence, sizeof(__pyx_k_GiacMethods_base_degree_sequence), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_degrees, __pyx_k_GiacMethods_base_degrees, sizeof(__pyx_k_GiacMethods_base_degrees), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_delcols, __pyx_k_GiacMethods_base_delcols, sizeof(__pyx_k_GiacMethods_base_delcols), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_delete_arc, __pyx_k_GiacMethods_base_delete_arc, sizeof(__pyx_k_GiacMethods_base_delete_arc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_delete_edge, __pyx_k_GiacMethods_base_delete_edge, sizeof(__pyx_k_GiacMethods_base_delete_edge), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_delete_vertex, __pyx_k_GiacMethods_base_delete_vertex, sizeof(__pyx_k_GiacMethods_base_delete_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_delrows, __pyx_k_GiacMethods_base_delrows, sizeof(__pyx_k_GiacMethods_base_delrows), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_deltalist, __pyx_k_GiacMethods_base_deltalist, sizeof(__pyx_k_GiacMethods_base_deltalist), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_denom, __pyx_k_GiacMethods_base_denom, sizeof(__pyx_k_GiacMethods_base_denom), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_densityplot, __pyx_k_GiacMethods_base_densityplot, sizeof(__pyx_k_GiacMethods_base_densityplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_departures, __pyx_k_GiacMethods_base_departures, sizeof(__pyx_k_GiacMethods_base_departures), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_derive, __pyx_k_GiacMethods_base_derive, sizeof(__pyx_k_GiacMethods_base_derive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_deriver, __pyx_k_GiacMethods_base_deriver, sizeof(__pyx_k_GiacMethods_base_deriver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_desolve, __pyx_k_GiacMethods_base_desolve, sizeof(__pyx_k_GiacMethods_base_desolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dessine_tortue, __pyx_k_GiacMethods_base_dessine_tortue, sizeof(__pyx_k_GiacMethods_base_dessine_tortue), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_det, __pyx_k_GiacMethods_base_det, sizeof(__pyx_k_GiacMethods_base_det), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_det_minor, __pyx_k_GiacMethods_base_det_minor, sizeof(__pyx_k_GiacMethods_base_det_minor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_developper, __pyx_k_GiacMethods_base_developper, sizeof(__pyx_k_GiacMethods_base_developper), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_developper_tran, __pyx_k_GiacMethods_base_developper_tran, sizeof(__pyx_k_GiacMethods_base_developper_tran), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dfc, __pyx_k_GiacMethods_base_dfc, sizeof(__pyx_k_GiacMethods_base_dfc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dfc2f, __pyx_k_GiacMethods_base_dfc2f, sizeof(__pyx_k_GiacMethods_base_dfc2f), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_diag, __pyx_k_GiacMethods_base_diag, sizeof(__pyx_k_GiacMethods_base_diag), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_diff, __pyx_k_GiacMethods_base_diff, sizeof(__pyx_k_GiacMethods_base_diff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_digraph, __pyx_k_GiacMethods_base_digraph, sizeof(__pyx_k_GiacMethods_base_digraph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dijkstra, __pyx_k_GiacMethods_base_dijkstra, sizeof(__pyx_k_GiacMethods_base_dijkstra), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dim, __pyx_k_GiacMethods_base_dim, sizeof(__pyx_k_GiacMethods_base_dim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_directed, __pyx_k_GiacMethods_base_directed, sizeof(__pyx_k_GiacMethods_base_directed), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_discard_edge_at, __pyx_k_GiacMethods_base_discard_edge_at, sizeof(__pyx_k_GiacMethods_base_discard_edge_at), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_discard_graph_a, __pyx_k_GiacMethods_base_discard_graph_a, sizeof(__pyx_k_GiacMethods_base_discard_graph_a), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_discard_vertex, __pyx_k_GiacMethods_base_discard_vertex, sizeof(__pyx_k_GiacMethods_base_discard_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_disjoint_union, __pyx_k_GiacMethods_base_disjoint_union, sizeof(__pyx_k_GiacMethods_base_disjoint_union), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_display, __pyx_k_GiacMethods_base_display, sizeof(__pyx_k_GiacMethods_base_display), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_disque, __pyx_k_GiacMethods_base_disque, sizeof(__pyx_k_GiacMethods_base_disque), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_disque_centre, __pyx_k_GiacMethods_base_disque_centre, sizeof(__pyx_k_GiacMethods_base_disque_centre), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_distance, __pyx_k_GiacMethods_base_distance, sizeof(__pyx_k_GiacMethods_base_distance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_distance2, __pyx_k_GiacMethods_base_distance2, sizeof(__pyx_k_GiacMethods_base_distance2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_distanceat, __pyx_k_GiacMethods_base_distanceat, sizeof(__pyx_k_GiacMethods_base_distanceat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_distanceatraw, __pyx_k_GiacMethods_base_distanceatraw, sizeof(__pyx_k_GiacMethods_base_distanceatraw), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_divergence, __pyx_k_GiacMethods_base_divergence, sizeof(__pyx_k_GiacMethods_base_divergence), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_divide, __pyx_k_GiacMethods_base_divide, sizeof(__pyx_k_GiacMethods_base_divide), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_divis, __pyx_k_GiacMethods_base_divis, sizeof(__pyx_k_GiacMethods_base_divis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_division_point, __pyx_k_GiacMethods_base_division_point, sizeof(__pyx_k_GiacMethods_base_division_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_divisors, __pyx_k_GiacMethods_base_divisors, sizeof(__pyx_k_GiacMethods_base_divisors), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_divmod, __pyx_k_GiacMethods_base_divmod, sizeof(__pyx_k_GiacMethods_base_divmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_divpc, __pyx_k_GiacMethods_base_divpc, sizeof(__pyx_k_GiacMethods_base_divpc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dnewton_solver, __pyx_k_GiacMethods_base_dnewton_solver, sizeof(__pyx_k_GiacMethods_base_dnewton_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dodecahedron, __pyx_k_GiacMethods_base_dodecahedron, sizeof(__pyx_k_GiacMethods_base_dodecahedron), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_domain, __pyx_k_GiacMethods_base_domain, sizeof(__pyx_k_GiacMethods_base_domain), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dot, __pyx_k_GiacMethods_base_dot, sizeof(__pyx_k_GiacMethods_base_dot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dotP, __pyx_k_GiacMethods_base_dotP, sizeof(__pyx_k_GiacMethods_base_dotP), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dot_paper, __pyx_k_GiacMethods_base_dot_paper, sizeof(__pyx_k_GiacMethods_base_dot_paper), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dotprod, __pyx_k_GiacMethods_base_dotprod, sizeof(__pyx_k_GiacMethods_base_dotprod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_arc, __pyx_k_GiacMethods_base_draw_arc, sizeof(__pyx_k_GiacMethods_base_draw_arc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_circle, __pyx_k_GiacMethods_base_draw_circle, sizeof(__pyx_k_GiacMethods_base_draw_circle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_graph, __pyx_k_GiacMethods_base_draw_graph, sizeof(__pyx_k_GiacMethods_base_draw_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_line, __pyx_k_GiacMethods_base_draw_line, sizeof(__pyx_k_GiacMethods_base_draw_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_pixel, __pyx_k_GiacMethods_base_draw_pixel, sizeof(__pyx_k_GiacMethods_base_draw_pixel), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_polygon, __pyx_k_GiacMethods_base_draw_polygon, sizeof(__pyx_k_GiacMethods_base_draw_polygon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_draw_rectangle, __pyx_k_GiacMethods_base_draw_rectangle, sizeof(__pyx_k_GiacMethods_base_draw_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_droit, __pyx_k_GiacMethods_base_droit, sizeof(__pyx_k_GiacMethods_base_droit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_droite_tangente, __pyx_k_GiacMethods_base_droite_tangente, sizeof(__pyx_k_GiacMethods_base_droite_tangente), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dsolve, __pyx_k_GiacMethods_base_dsolve, sizeof(__pyx_k_GiacMethods_base_dsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_duration, __pyx_k_GiacMethods_base_duration, sizeof(__pyx_k_GiacMethods_base_duration), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_dwt, __pyx_k_GiacMethods_base_dwt, sizeof(__pyx_k_GiacMethods_base_dwt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_e, __pyx_k_GiacMethods_base_e, sizeof(__pyx_k_GiacMethods_base_e), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_e2r, __pyx_k_GiacMethods_base_e2r, sizeof(__pyx_k_GiacMethods_base_e2r), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ecart_type, __pyx_k_GiacMethods_base_ecart_type, sizeof(__pyx_k_GiacMethods_base_ecart_type), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ecart_type_popu, __pyx_k_GiacMethods_base_ecart_type_popu, sizeof(__pyx_k_GiacMethods_base_ecart_type_popu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ecef2geodetic, __pyx_k_GiacMethods_base_ecef2geodetic, sizeof(__pyx_k_GiacMethods_base_ecef2geodetic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ecm_factor, __pyx_k_GiacMethods_base_ecm_factor, sizeof(__pyx_k_GiacMethods_base_ecm_factor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_edge_connectivi, __pyx_k_GiacMethods_base_edge_connectivi, sizeof(__pyx_k_GiacMethods_base_edge_connectivi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_edges, __pyx_k_GiacMethods_base_edges, sizeof(__pyx_k_GiacMethods_base_edges), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_egcd, __pyx_k_GiacMethods_base_egcd, sizeof(__pyx_k_GiacMethods_base_egcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_egv, __pyx_k_GiacMethods_base_egv, sizeof(__pyx_k_GiacMethods_base_egv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_egvl, __pyx_k_GiacMethods_base_egvl, sizeof(__pyx_k_GiacMethods_base_egvl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eigVc, __pyx_k_GiacMethods_base_eigVc, sizeof(__pyx_k_GiacMethods_base_eigVc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eigVl, __pyx_k_GiacMethods_base_eigVl, sizeof(__pyx_k_GiacMethods_base_eigVl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eigenvals, __pyx_k_GiacMethods_base_eigenvals, sizeof(__pyx_k_GiacMethods_base_eigenvals), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eigenvalues, __pyx_k_GiacMethods_base_eigenvalues, sizeof(__pyx_k_GiacMethods_base_eigenvalues), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eigenvectors, __pyx_k_GiacMethods_base_eigenvectors, sizeof(__pyx_k_GiacMethods_base_eigenvectors), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eigenvects, __pyx_k_GiacMethods_base_eigenvects, sizeof(__pyx_k_GiacMethods_base_eigenvects), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_element, __pyx_k_GiacMethods_base_element, sizeof(__pyx_k_GiacMethods_base_element), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eliminate, __pyx_k_GiacMethods_base_eliminate, sizeof(__pyx_k_GiacMethods_base_eliminate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ellipse, __pyx_k_GiacMethods_base_ellipse, sizeof(__pyx_k_GiacMethods_base_ellipse), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_emd, __pyx_k_GiacMethods_base_emd, sizeof(__pyx_k_GiacMethods_base_emd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_entry, __pyx_k_GiacMethods_base_entry, sizeof(__pyx_k_GiacMethods_base_entry), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_envelope, __pyx_k_GiacMethods_base_envelope, sizeof(__pyx_k_GiacMethods_base_envelope), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_epsilon, __pyx_k_GiacMethods_base_epsilon, sizeof(__pyx_k_GiacMethods_base_epsilon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_epsilon2zero, __pyx_k_GiacMethods_base_epsilon2zero, sizeof(__pyx_k_GiacMethods_base_epsilon2zero), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_equal, __pyx_k_GiacMethods_base_equal, sizeof(__pyx_k_GiacMethods_base_equal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_equal2diff, __pyx_k_GiacMethods_base_equal2diff, sizeof(__pyx_k_GiacMethods_base_equal2diff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_equal2list, __pyx_k_GiacMethods_base_equal2list, sizeof(__pyx_k_GiacMethods_base_equal2list), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_equation, __pyx_k_GiacMethods_base_equation, sizeof(__pyx_k_GiacMethods_base_equation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_equilateral_tri, __pyx_k_GiacMethods_base_equilateral_tri, sizeof(__pyx_k_GiacMethods_base_equilateral_tri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_erf, __pyx_k_GiacMethods_base_erf, sizeof(__pyx_k_GiacMethods_base_erf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_erfc, __pyx_k_GiacMethods_base_erfc, sizeof(__pyx_k_GiacMethods_base_erfc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_error, __pyx_k_GiacMethods_base_error, sizeof(__pyx_k_GiacMethods_base_error), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_est_permu, __pyx_k_GiacMethods_base_est_permu, sizeof(__pyx_k_GiacMethods_base_est_permu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_euler, __pyx_k_GiacMethods_base_euler, sizeof(__pyx_k_GiacMethods_base_euler), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_euler_gamma, __pyx_k_GiacMethods_base_euler_gamma, sizeof(__pyx_k_GiacMethods_base_euler_gamma), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_euler_lagrange, __pyx_k_GiacMethods_base_euler_lagrange, sizeof(__pyx_k_GiacMethods_base_euler_lagrange), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_eval_level, __pyx_k_GiacMethods_base_eval_level, sizeof(__pyx_k_GiacMethods_base_eval_level), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_evala, __pyx_k_GiacMethods_base_evala, sizeof(__pyx_k_GiacMethods_base_evala), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_evalb, __pyx_k_GiacMethods_base_evalb, sizeof(__pyx_k_GiacMethods_base_evalb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_evalc, __pyx_k_GiacMethods_base_evalc, sizeof(__pyx_k_GiacMethods_base_evalc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_evalf, __pyx_k_GiacMethods_base_evalf, sizeof(__pyx_k_GiacMethods_base_evalf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_evalm, __pyx_k_GiacMethods_base_evalm, sizeof(__pyx_k_GiacMethods_base_evalm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_even, __pyx_k_GiacMethods_base_even, sizeof(__pyx_k_GiacMethods_base_even), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_evolute, __pyx_k_GiacMethods_base_evolute, sizeof(__pyx_k_GiacMethods_base_evolute), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exact, __pyx_k_GiacMethods_base_exact, sizeof(__pyx_k_GiacMethods_base_exact), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exbisector, __pyx_k_GiacMethods_base_exbisector, sizeof(__pyx_k_GiacMethods_base_exbisector), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_excircle, __pyx_k_GiacMethods_base_excircle, sizeof(__pyx_k_GiacMethods_base_excircle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_execute, __pyx_k_GiacMethods_base_execute, sizeof(__pyx_k_GiacMethods_base_execute), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exp, __pyx_k_GiacMethods_base_exp, sizeof(__pyx_k_GiacMethods_base_exp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exp2list, __pyx_k_GiacMethods_base_exp2list, sizeof(__pyx_k_GiacMethods_base_exp2list), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exp2pow, __pyx_k_GiacMethods_base_exp2pow, sizeof(__pyx_k_GiacMethods_base_exp2pow), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exp2trig, __pyx_k_GiacMethods_base_exp2trig, sizeof(__pyx_k_GiacMethods_base_exp2trig), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_expand, __pyx_k_GiacMethods_base_expand, sizeof(__pyx_k_GiacMethods_base_expand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_expexpand, __pyx_k_GiacMethods_base_expexpand, sizeof(__pyx_k_GiacMethods_base_expexpand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_expln, __pyx_k_GiacMethods_base_expln, sizeof(__pyx_k_GiacMethods_base_expln), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponential, __pyx_k_GiacMethods_base_exponential, sizeof(__pyx_k_GiacMethods_base_exponential), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponential_cdf, __pyx_k_GiacMethods_base_exponential_cdf, sizeof(__pyx_k_GiacMethods_base_exponential_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponential_icd, __pyx_k_GiacMethods_base_exponential_icd, sizeof(__pyx_k_GiacMethods_base_exponential_icd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponential_reg, __pyx_k_GiacMethods_base_exponential_reg, sizeof(__pyx_k_GiacMethods_base_exponential_reg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponential_reg_2, __pyx_k_GiacMethods_base_exponential_reg_2, sizeof(__pyx_k_GiacMethods_base_exponential_reg_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponentiald, __pyx_k_GiacMethods_base_exponentiald, sizeof(__pyx_k_GiacMethods_base_exponentiald), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponentiald_cd, __pyx_k_GiacMethods_base_exponentiald_cd, sizeof(__pyx_k_GiacMethods_base_exponentiald_cd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_exponentiald_ic, __pyx_k_GiacMethods_base_exponentiald_ic, sizeof(__pyx_k_GiacMethods_base_exponentiald_ic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_export_graph, __pyx_k_GiacMethods_base_export_graph, sizeof(__pyx_k_GiacMethods_base_export_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_export_mathml, __pyx_k_GiacMethods_base_export_mathml, sizeof(__pyx_k_GiacMethods_base_export_mathml), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_expovariate, __pyx_k_GiacMethods_base_expovariate, sizeof(__pyx_k_GiacMethods_base_expovariate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_expr, __pyx_k_GiacMethods_base_expr, sizeof(__pyx_k_GiacMethods_base_expr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_extend, __pyx_k_GiacMethods_base_extend, sizeof(__pyx_k_GiacMethods_base_extend), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_extract_measure, __pyx_k_GiacMethods_base_extract_measure, sizeof(__pyx_k_GiacMethods_base_extract_measure), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_extrema, __pyx_k_GiacMethods_base_extrema, sizeof(__pyx_k_GiacMethods_base_extrema), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ezgcd, __pyx_k_GiacMethods_base_ezgcd, sizeof(__pyx_k_GiacMethods_base_ezgcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_f2nd, __pyx_k_GiacMethods_base_f2nd, sizeof(__pyx_k_GiacMethods_base_f2nd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fMax, __pyx_k_GiacMethods_base_fMax, sizeof(__pyx_k_GiacMethods_base_fMax), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fMin, __pyx_k_GiacMethods_base_fMin, sizeof(__pyx_k_GiacMethods_base_fMin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fPart, __pyx_k_GiacMethods_base_fPart, sizeof(__pyx_k_GiacMethods_base_fPart), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_faces, __pyx_k_GiacMethods_base_faces, sizeof(__pyx_k_GiacMethods_base_faces), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_facteurs_premie, __pyx_k_GiacMethods_base_facteurs_premie, sizeof(__pyx_k_GiacMethods_base_facteurs_premie), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factor, __pyx_k_GiacMethods_base_factor, sizeof(__pyx_k_GiacMethods_base_factor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factor_xn, __pyx_k_GiacMethods_base_factor_xn, sizeof(__pyx_k_GiacMethods_base_factor_xn), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factorial, __pyx_k_GiacMethods_base_factorial, sizeof(__pyx_k_GiacMethods_base_factorial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factoriser, __pyx_k_GiacMethods_base_factoriser, sizeof(__pyx_k_GiacMethods_base_factoriser), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factoriser_enti, __pyx_k_GiacMethods_base_factoriser_enti, sizeof(__pyx_k_GiacMethods_base_factoriser_enti), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factoriser_sur, __pyx_k_GiacMethods_base_factoriser_sur, sizeof(__pyx_k_GiacMethods_base_factoriser_sur), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_factors, __pyx_k_GiacMethods_base_factors, sizeof(__pyx_k_GiacMethods_base_factors), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fadeev, __pyx_k_GiacMethods_base_fadeev, sizeof(__pyx_k_GiacMethods_base_fadeev), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_false, __pyx_k_GiacMethods_base_false, sizeof(__pyx_k_GiacMethods_base_false), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_falsepos_solver, __pyx_k_GiacMethods_base_falsepos_solver, sizeof(__pyx_k_GiacMethods_base_falsepos_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fclose, __pyx_k_GiacMethods_base_fclose, sizeof(__pyx_k_GiacMethods_base_fclose), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fcoeff, __pyx_k_GiacMethods_base_fcoeff, sizeof(__pyx_k_GiacMethods_base_fcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fdistrib, __pyx_k_GiacMethods_base_fdistrib, sizeof(__pyx_k_GiacMethods_base_fdistrib), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fft, __pyx_k_GiacMethods_base_fft, sizeof(__pyx_k_GiacMethods_base_fft), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fieldplot, __pyx_k_GiacMethods_base_fieldplot, sizeof(__pyx_k_GiacMethods_base_fieldplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_find, __pyx_k_GiacMethods_base_find, sizeof(__pyx_k_GiacMethods_base_find), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_find_cliques, __pyx_k_GiacMethods_base_find_cliques, sizeof(__pyx_k_GiacMethods_base_find_cliques), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_find_cycles, __pyx_k_GiacMethods_base_find_cycles, sizeof(__pyx_k_GiacMethods_base_find_cycles), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_find_minimum, __pyx_k_GiacMethods_base_find_minimum, sizeof(__pyx_k_GiacMethods_base_find_minimum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_find_vertex_cov, __pyx_k_GiacMethods_base_find_vertex_cov, sizeof(__pyx_k_GiacMethods_base_find_vertex_cov), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_findhelp, __pyx_k_GiacMethods_base_findhelp, sizeof(__pyx_k_GiacMethods_base_findhelp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fisher, __pyx_k_GiacMethods_base_fisher, sizeof(__pyx_k_GiacMethods_base_fisher), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fisher_cdf, __pyx_k_GiacMethods_base_fisher_cdf, sizeof(__pyx_k_GiacMethods_base_fisher_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fisher_icdf, __pyx_k_GiacMethods_base_fisher_icdf, sizeof(__pyx_k_GiacMethods_base_fisher_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fisherd, __pyx_k_GiacMethods_base_fisherd, sizeof(__pyx_k_GiacMethods_base_fisherd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fisherd_cdf, __pyx_k_GiacMethods_base_fisherd_cdf, sizeof(__pyx_k_GiacMethods_base_fisherd_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fisherd_icdf, __pyx_k_GiacMethods_base_fisherd_icdf, sizeof(__pyx_k_GiacMethods_base_fisherd_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fitdistr, __pyx_k_GiacMethods_base_fitdistr, sizeof(__pyx_k_GiacMethods_base_fitdistr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fitpoly, __pyx_k_GiacMethods_base_fitpoly, sizeof(__pyx_k_GiacMethods_base_fitpoly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fitspline, __pyx_k_GiacMethods_base_fitspline, sizeof(__pyx_k_GiacMethods_base_fitspline), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_flatten, __pyx_k_GiacMethods_base_flatten, sizeof(__pyx_k_GiacMethods_base_flatten), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_float2rational, __pyx_k_GiacMethods_base_float2rational, sizeof(__pyx_k_GiacMethods_base_float2rational), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_floor, __pyx_k_GiacMethods_base_floor, sizeof(__pyx_k_GiacMethods_base_floor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_flow_polynomial, __pyx_k_GiacMethods_base_flow_polynomial, sizeof(__pyx_k_GiacMethods_base_flow_polynomial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_flower_snark, __pyx_k_GiacMethods_base_flower_snark, sizeof(__pyx_k_GiacMethods_base_flower_snark), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fmod, __pyx_k_GiacMethods_base_fmod, sizeof(__pyx_k_GiacMethods_base_fmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_foldl, __pyx_k_GiacMethods_base_foldl, sizeof(__pyx_k_GiacMethods_base_foldl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_foldr, __pyx_k_GiacMethods_base_foldr, sizeof(__pyx_k_GiacMethods_base_foldr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fonction_derive, __pyx_k_GiacMethods_base_fonction_derive, sizeof(__pyx_k_GiacMethods_base_fonction_derive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_forward, __pyx_k_GiacMethods_base_forward, sizeof(__pyx_k_GiacMethods_base_forward), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fourier, __pyx_k_GiacMethods_base_fourier, sizeof(__pyx_k_GiacMethods_base_fourier), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fourier_an, __pyx_k_GiacMethods_base_fourier_an, sizeof(__pyx_k_GiacMethods_base_fourier_an), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fourier_bn, __pyx_k_GiacMethods_base_fourier_bn, sizeof(__pyx_k_GiacMethods_base_fourier_bn), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fourier_cn, __pyx_k_GiacMethods_base_fourier_cn, sizeof(__pyx_k_GiacMethods_base_fourier_cn), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fprint, __pyx_k_GiacMethods_base_fprint, sizeof(__pyx_k_GiacMethods_base_fprint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_frac, __pyx_k_GiacMethods_base_frac, sizeof(__pyx_k_GiacMethods_base_frac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fracmod, __pyx_k_GiacMethods_base_fracmod, sizeof(__pyx_k_GiacMethods_base_fracmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_frame_2d, __pyx_k_GiacMethods_base_frame_2d, sizeof(__pyx_k_GiacMethods_base_frame_2d), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_frank_wolfe, __pyx_k_GiacMethods_base_frank_wolfe, sizeof(__pyx_k_GiacMethods_base_frank_wolfe), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_frequencies, __pyx_k_GiacMethods_base_frequencies, sizeof(__pyx_k_GiacMethods_base_frequencies), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_frobenius_norm, __pyx_k_GiacMethods_base_frobenius_norm, sizeof(__pyx_k_GiacMethods_base_frobenius_norm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_froot, __pyx_k_GiacMethods_base_froot, sizeof(__pyx_k_GiacMethods_base_froot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fsolve, __pyx_k_GiacMethods_base_fsolve, sizeof(__pyx_k_GiacMethods_base_fsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fullparfrac, __pyx_k_GiacMethods_base_fullparfrac, sizeof(__pyx_k_GiacMethods_base_fullparfrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_funcplot, __pyx_k_GiacMethods_base_funcplot, sizeof(__pyx_k_GiacMethods_base_funcplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_function_diff, __pyx_k_GiacMethods_base_function_diff, sizeof(__pyx_k_GiacMethods_base_function_diff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fundamental_cyc, __pyx_k_GiacMethods_base_fundamental_cyc, sizeof(__pyx_k_GiacMethods_base_fundamental_cyc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_fxnd, __pyx_k_GiacMethods_base_fxnd, sizeof(__pyx_k_GiacMethods_base_fxnd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gammad, __pyx_k_GiacMethods_base_gammad, sizeof(__pyx_k_GiacMethods_base_gammad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gammad_cdf, __pyx_k_GiacMethods_base_gammad_cdf, sizeof(__pyx_k_GiacMethods_base_gammad_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gammad_icdf, __pyx_k_GiacMethods_base_gammad_icdf, sizeof(__pyx_k_GiacMethods_base_gammad_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gammavariate, __pyx_k_GiacMethods_base_gammavariate, sizeof(__pyx_k_GiacMethods_base_gammavariate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gauss, __pyx_k_GiacMethods_base_gauss, sizeof(__pyx_k_GiacMethods_base_gauss), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gauss15, __pyx_k_GiacMethods_base_gauss15, sizeof(__pyx_k_GiacMethods_base_gauss15), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gauss_seidel_li, __pyx_k_GiacMethods_base_gauss_seidel_li, sizeof(__pyx_k_GiacMethods_base_gauss_seidel_li), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gaussian_window, __pyx_k_GiacMethods_base_gaussian_window, sizeof(__pyx_k_GiacMethods_base_gaussian_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gaussjord, __pyx_k_GiacMethods_base_gaussjord, sizeof(__pyx_k_GiacMethods_base_gaussjord), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gaussquad, __pyx_k_GiacMethods_base_gaussquad, sizeof(__pyx_k_GiacMethods_base_gaussquad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gbasis, __pyx_k_GiacMethods_base_gbasis, sizeof(__pyx_k_GiacMethods_base_gbasis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gbasis_max_pair, __pyx_k_GiacMethods_base_gbasis_max_pair, sizeof(__pyx_k_GiacMethods_base_gbasis_max_pair), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gbasis_reinject, __pyx_k_GiacMethods_base_gbasis_reinject, sizeof(__pyx_k_GiacMethods_base_gbasis_reinject), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gbasis_simult_p, __pyx_k_GiacMethods_base_gbasis_simult_p, sizeof(__pyx_k_GiacMethods_base_gbasis_simult_p), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gcd, __pyx_k_GiacMethods_base_gcd, sizeof(__pyx_k_GiacMethods_base_gcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gcdex, __pyx_k_GiacMethods_base_gcdex, sizeof(__pyx_k_GiacMethods_base_gcdex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_genpoly, __pyx_k_GiacMethods_base_genpoly, sizeof(__pyx_k_GiacMethods_base_genpoly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_geodetic2ecef, __pyx_k_GiacMethods_base_geodetic2ecef, sizeof(__pyx_k_GiacMethods_base_geodetic2ecef), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_geometric, __pyx_k_GiacMethods_base_geometric, sizeof(__pyx_k_GiacMethods_base_geometric), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_geometric_cdf, __pyx_k_GiacMethods_base_geometric_cdf, sizeof(__pyx_k_GiacMethods_base_geometric_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_geometric_icdf, __pyx_k_GiacMethods_base_geometric_icdf, sizeof(__pyx_k_GiacMethods_base_geometric_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_getDenom, __pyx_k_GiacMethods_base_getDenom, sizeof(__pyx_k_GiacMethods_base_getDenom), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_getKey, __pyx_k_GiacMethods_base_getKey, sizeof(__pyx_k_GiacMethods_base_getKey), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_getNum, __pyx_k_GiacMethods_base_getNum, sizeof(__pyx_k_GiacMethods_base_getNum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_getType, __pyx_k_GiacMethods_base_getType, sizeof(__pyx_k_GiacMethods_base_getType), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_get_edge_attrib, __pyx_k_GiacMethods_base_get_edge_attrib, sizeof(__pyx_k_GiacMethods_base_get_edge_attrib), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_get_edge_weight, __pyx_k_GiacMethods_base_get_edge_weight, sizeof(__pyx_k_GiacMethods_base_get_edge_weight), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_get_graph_attri, __pyx_k_GiacMethods_base_get_graph_attri, sizeof(__pyx_k_GiacMethods_base_get_graph_attri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_get_vertex_attr, __pyx_k_GiacMethods_base_get_vertex_attr, sizeof(__pyx_k_GiacMethods_base_get_vertex_attr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_girth, __pyx_k_GiacMethods_base_girth, sizeof(__pyx_k_GiacMethods_base_girth), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gl_showaxes, __pyx_k_GiacMethods_base_gl_showaxes, sizeof(__pyx_k_GiacMethods_base_gl_showaxes), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gold, __pyx_k_GiacMethods_base_gold, sizeof(__pyx_k_GiacMethods_base_gold), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_goldberg_snark, __pyx_k_GiacMethods_base_goldberg_snark, sizeof(__pyx_k_GiacMethods_base_goldberg_snark), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_grad, __pyx_k_GiacMethods_base_grad, sizeof(__pyx_k_GiacMethods_base_grad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_gramschmidt, __pyx_k_GiacMethods_base_gramschmidt, sizeof(__pyx_k_GiacMethods_base_gramschmidt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph, __pyx_k_GiacMethods_base_graph, sizeof(__pyx_k_GiacMethods_base_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_automorph, __pyx_k_GiacMethods_base_graph_automorph, sizeof(__pyx_k_GiacMethods_base_graph_automorph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_charpoly, __pyx_k_GiacMethods_base_graph_charpoly, sizeof(__pyx_k_GiacMethods_base_graph_charpoly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_complemen, __pyx_k_GiacMethods_base_graph_complemen, sizeof(__pyx_k_GiacMethods_base_graph_complemen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_diameter, __pyx_k_GiacMethods_base_graph_diameter, sizeof(__pyx_k_GiacMethods_base_graph_diameter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_equal, __pyx_k_GiacMethods_base_graph_equal, sizeof(__pyx_k_GiacMethods_base_graph_equal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_join, __pyx_k_GiacMethods_base_graph_join, sizeof(__pyx_k_GiacMethods_base_graph_join), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_power, __pyx_k_GiacMethods_base_graph_power, sizeof(__pyx_k_GiacMethods_base_graph_power), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_rank, __pyx_k_GiacMethods_base_graph_rank, sizeof(__pyx_k_GiacMethods_base_graph_rank), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_spectrum, __pyx_k_GiacMethods_base_graph_spectrum, sizeof(__pyx_k_GiacMethods_base_graph_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_union, __pyx_k_GiacMethods_base_graph_union, sizeof(__pyx_k_GiacMethods_base_graph_union), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_graph_vertices, __pyx_k_GiacMethods_base_graph_vertices, sizeof(__pyx_k_GiacMethods_base_graph_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_greduce, __pyx_k_GiacMethods_base_greduce, sizeof(__pyx_k_GiacMethods_base_greduce), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_greedy_clique, __pyx_k_GiacMethods_base_greedy_clique, sizeof(__pyx_k_GiacMethods_base_greedy_clique), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_greedy_color, __pyx_k_GiacMethods_base_greedy_color, sizeof(__pyx_k_GiacMethods_base_greedy_color), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_greedy_independ, __pyx_k_GiacMethods_base_greedy_independ, sizeof(__pyx_k_GiacMethods_base_greedy_independ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_grey, __pyx_k_GiacMethods_base_grey, sizeof(__pyx_k_GiacMethods_base_grey), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_grid_graph, __pyx_k_GiacMethods_base_grid_graph, sizeof(__pyx_k_GiacMethods_base_grid_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_groupermu, __pyx_k_GiacMethods_base_groupermu, sizeof(__pyx_k_GiacMethods_base_groupermu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_haar_graph, __pyx_k_GiacMethods_base_haar_graph, sizeof(__pyx_k_GiacMethods_base_haar_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hadamard, __pyx_k_GiacMethods_base_hadamard, sizeof(__pyx_k_GiacMethods_base_hadamard), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_half_cone, __pyx_k_GiacMethods_base_half_cone, sizeof(__pyx_k_GiacMethods_base_half_cone), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_half_line, __pyx_k_GiacMethods_base_half_line, sizeof(__pyx_k_GiacMethods_base_half_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_halftan, __pyx_k_GiacMethods_base_halftan, sizeof(__pyx_k_GiacMethods_base_halftan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_halftan_hyp2exp, __pyx_k_GiacMethods_base_halftan_hyp2exp, sizeof(__pyx_k_GiacMethods_base_halftan_hyp2exp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_halt, __pyx_k_GiacMethods_base_halt, sizeof(__pyx_k_GiacMethods_base_halt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hamdist, __pyx_k_GiacMethods_base_hamdist, sizeof(__pyx_k_GiacMethods_base_hamdist), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hamming, __pyx_k_GiacMethods_base_hamming, sizeof(__pyx_k_GiacMethods_base_hamming), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hamming_window, __pyx_k_GiacMethods_base_hamming_window, sizeof(__pyx_k_GiacMethods_base_hamming_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hann_poisson_wi, __pyx_k_GiacMethods_base_hann_poisson_wi, sizeof(__pyx_k_GiacMethods_base_hann_poisson_wi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hann_window, __pyx_k_GiacMethods_base_hann_window, sizeof(__pyx_k_GiacMethods_base_hann_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_harmonic_centra, __pyx_k_GiacMethods_base_harmonic_centra, sizeof(__pyx_k_GiacMethods_base_harmonic_centra), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_harmonic_conjug, __pyx_k_GiacMethods_base_harmonic_conjug, sizeof(__pyx_k_GiacMethods_base_harmonic_conjug), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_harmonic_divisi, __pyx_k_GiacMethods_base_harmonic_divisi, sizeof(__pyx_k_GiacMethods_base_harmonic_divisi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_has, __pyx_k_GiacMethods_base_has, sizeof(__pyx_k_GiacMethods_base_has), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_has_arc, __pyx_k_GiacMethods_base_has_arc, sizeof(__pyx_k_GiacMethods_base_has_arc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_has_edge, __pyx_k_GiacMethods_base_has_edge, sizeof(__pyx_k_GiacMethods_base_has_edge), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hasard, __pyx_k_GiacMethods_base_hasard, sizeof(__pyx_k_GiacMethods_base_hasard), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_head, __pyx_k_GiacMethods_base_head, sizeof(__pyx_k_GiacMethods_base_head), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_heading, __pyx_k_GiacMethods_base_heading, sizeof(__pyx_k_GiacMethods_base_heading), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_heapify, __pyx_k_GiacMethods_base_heapify, sizeof(__pyx_k_GiacMethods_base_heapify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_heappop, __pyx_k_GiacMethods_base_heappop, sizeof(__pyx_k_GiacMethods_base_heappop), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_heappush, __pyx_k_GiacMethods_base_heappush, sizeof(__pyx_k_GiacMethods_base_heappush), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hermite, __pyx_k_GiacMethods_base_hermite, sizeof(__pyx_k_GiacMethods_base_hermite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hessenberg, __pyx_k_GiacMethods_base_hessenberg, sizeof(__pyx_k_GiacMethods_base_hessenberg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hessian, __pyx_k_GiacMethods_base_hessian, sizeof(__pyx_k_GiacMethods_base_hessian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_heugcd, __pyx_k_GiacMethods_base_heugcd, sizeof(__pyx_k_GiacMethods_base_heugcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hexagon, __pyx_k_GiacMethods_base_hexagon, sizeof(__pyx_k_GiacMethods_base_hexagon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hht, __pyx_k_GiacMethods_base_hht, sizeof(__pyx_k_GiacMethods_base_hht), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_highlight_edges, __pyx_k_GiacMethods_base_highlight_edges, sizeof(__pyx_k_GiacMethods_base_highlight_edges), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_highlight_subgr, __pyx_k_GiacMethods_base_highlight_subgr, sizeof(__pyx_k_GiacMethods_base_highlight_subgr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_highlight_trail, __pyx_k_GiacMethods_base_highlight_trail, sizeof(__pyx_k_GiacMethods_base_highlight_trail), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_highlight_verte, __pyx_k_GiacMethods_base_highlight_verte, sizeof(__pyx_k_GiacMethods_base_highlight_verte), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_highpass, __pyx_k_GiacMethods_base_highpass, sizeof(__pyx_k_GiacMethods_base_highpass), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hilbert, __pyx_k_GiacMethods_base_hilbert, sizeof(__pyx_k_GiacMethods_base_hilbert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_histogram, __pyx_k_GiacMethods_base_histogram, sizeof(__pyx_k_GiacMethods_base_histogram), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hold, __pyx_k_GiacMethods_base_hold, sizeof(__pyx_k_GiacMethods_base_hold), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_homogeneize, __pyx_k_GiacMethods_base_homogeneize, sizeof(__pyx_k_GiacMethods_base_homogeneize), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_homothety, __pyx_k_GiacMethods_base_homothety, sizeof(__pyx_k_GiacMethods_base_homothety), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_horner, __pyx_k_GiacMethods_base_horner, sizeof(__pyx_k_GiacMethods_base_horner), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hsv, __pyx_k_GiacMethods_base_hsv, sizeof(__pyx_k_GiacMethods_base_hsv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hsv2rgb, __pyx_k_GiacMethods_base_hsv2rgb, sizeof(__pyx_k_GiacMethods_base_hsv2rgb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hybrid_solver, __pyx_k_GiacMethods_base_hybrid_solver, sizeof(__pyx_k_GiacMethods_base_hybrid_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hybridj_solver, __pyx_k_GiacMethods_base_hybridj_solver, sizeof(__pyx_k_GiacMethods_base_hybridj_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hybrids_solver, __pyx_k_GiacMethods_base_hybrids_solver, sizeof(__pyx_k_GiacMethods_base_hybrids_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hybridsj_solver, __pyx_k_GiacMethods_base_hybridsj_solver, sizeof(__pyx_k_GiacMethods_base_hybridsj_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hyp2exp, __pyx_k_GiacMethods_base_hyp2exp, sizeof(__pyx_k_GiacMethods_base_hyp2exp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hyperbola, __pyx_k_GiacMethods_base_hyperbola, sizeof(__pyx_k_GiacMethods_base_hyperbola), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_hypercube_graph, __pyx_k_GiacMethods_base_hypercube_graph, sizeof(__pyx_k_GiacMethods_base_hypercube_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_iPart, __pyx_k_GiacMethods_base_iPart, sizeof(__pyx_k_GiacMethods_base_iPart), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_iabcuv, __pyx_k_GiacMethods_base_iabcuv, sizeof(__pyx_k_GiacMethods_base_iabcuv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ibasis, __pyx_k_GiacMethods_base_ibasis, sizeof(__pyx_k_GiacMethods_base_ibasis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ibpdv, __pyx_k_GiacMethods_base_ibpdv, sizeof(__pyx_k_GiacMethods_base_ibpdv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ibpu, __pyx_k_GiacMethods_base_ibpu, sizeof(__pyx_k_GiacMethods_base_ibpu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_icdf, __pyx_k_GiacMethods_base_icdf, sizeof(__pyx_k_GiacMethods_base_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ichinrem, __pyx_k_GiacMethods_base_ichinrem, sizeof(__pyx_k_GiacMethods_base_ichinrem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ichrem, __pyx_k_GiacMethods_base_ichrem, sizeof(__pyx_k_GiacMethods_base_ichrem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_icomp, __pyx_k_GiacMethods_base_icomp, sizeof(__pyx_k_GiacMethods_base_icomp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_icontent, __pyx_k_GiacMethods_base_icontent, sizeof(__pyx_k_GiacMethods_base_icontent), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_icosahedron, __pyx_k_GiacMethods_base_icosahedron, sizeof(__pyx_k_GiacMethods_base_icosahedron), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_id, __pyx_k_GiacMethods_base_id, sizeof(__pyx_k_GiacMethods_base_id), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_identify_graph, __pyx_k_GiacMethods_base_identify_graph, sizeof(__pyx_k_GiacMethods_base_identify_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_identity, __pyx_k_GiacMethods_base_identity, sizeof(__pyx_k_GiacMethods_base_identity), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_idivis, __pyx_k_GiacMethods_base_idivis, sizeof(__pyx_k_GiacMethods_base_idivis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_idn, __pyx_k_GiacMethods_base_idn, sizeof(__pyx_k_GiacMethods_base_idn), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_idwt, __pyx_k_GiacMethods_base_idwt, sizeof(__pyx_k_GiacMethods_base_idwt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_iegcd, __pyx_k_GiacMethods_base_iegcd, sizeof(__pyx_k_GiacMethods_base_iegcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ifactor, __pyx_k_GiacMethods_base_ifactor, sizeof(__pyx_k_GiacMethods_base_ifactor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ifactors, __pyx_k_GiacMethods_base_ifactors, sizeof(__pyx_k_GiacMethods_base_ifactors), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ifourier, __pyx_k_GiacMethods_base_ifourier, sizeof(__pyx_k_GiacMethods_base_ifourier), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_igamma, __pyx_k_GiacMethods_base_igamma, sizeof(__pyx_k_GiacMethods_base_igamma), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_igcd, __pyx_k_GiacMethods_base_igcd, sizeof(__pyx_k_GiacMethods_base_igcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_igcdex, __pyx_k_GiacMethods_base_igcdex, sizeof(__pyx_k_GiacMethods_base_igcdex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ihermite, __pyx_k_GiacMethods_base_ihermite, sizeof(__pyx_k_GiacMethods_base_ihermite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ilaplace, __pyx_k_GiacMethods_base_ilaplace, sizeof(__pyx_k_GiacMethods_base_ilaplace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_im, __pyx_k_GiacMethods_base_im, sizeof(__pyx_k_GiacMethods_base_im), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_imag, __pyx_k_GiacMethods_base_imag, sizeof(__pyx_k_GiacMethods_base_imag), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_image, __pyx_k_GiacMethods_base_image, sizeof(__pyx_k_GiacMethods_base_image), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_imfplot, __pyx_k_GiacMethods_base_imfplot, sizeof(__pyx_k_GiacMethods_base_imfplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_implicitdiff, __pyx_k_GiacMethods_base_implicitdiff, sizeof(__pyx_k_GiacMethods_base_implicitdiff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_implicitplot, __pyx_k_GiacMethods_base_implicitplot, sizeof(__pyx_k_GiacMethods_base_implicitplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_import_graph, __pyx_k_GiacMethods_base_import_graph, sizeof(__pyx_k_GiacMethods_base_import_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inString, __pyx_k_GiacMethods_base_inString, sizeof(__pyx_k_GiacMethods_base_inString), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_in_ideal, __pyx_k_GiacMethods_base_in_ideal, sizeof(__pyx_k_GiacMethods_base_in_ideal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_incidence_matri, __pyx_k_GiacMethods_base_incidence_matri, sizeof(__pyx_k_GiacMethods_base_incidence_matri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_incident_edges, __pyx_k_GiacMethods_base_incident_edges, sizeof(__pyx_k_GiacMethods_base_incident_edges), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_incircle, __pyx_k_GiacMethods_base_incircle, sizeof(__pyx_k_GiacMethods_base_incircle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_increasing_powe, __pyx_k_GiacMethods_base_increasing_powe, sizeof(__pyx_k_GiacMethods_base_increasing_powe), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_independence_nu, __pyx_k_GiacMethods_base_independence_nu, sizeof(__pyx_k_GiacMethods_base_independence_nu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_indets, __pyx_k_GiacMethods_base_indets, sizeof(__pyx_k_GiacMethods_base_indets), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_index, __pyx_k_GiacMethods_base_index, sizeof(__pyx_k_GiacMethods_base_index), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_induced_subgrap, __pyx_k_GiacMethods_base_induced_subgrap, sizeof(__pyx_k_GiacMethods_base_induced_subgrap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inequationplot, __pyx_k_GiacMethods_base_inequationplot, sizeof(__pyx_k_GiacMethods_base_inequationplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inertia, __pyx_k_GiacMethods_base_inertia, sizeof(__pyx_k_GiacMethods_base_inertia), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inf, __pyx_k_GiacMethods_base_inf, sizeof(__pyx_k_GiacMethods_base_inf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_infinity, __pyx_k_GiacMethods_base_infinity, sizeof(__pyx_k_GiacMethods_base_infinity), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_information_cen, __pyx_k_GiacMethods_base_information_cen, sizeof(__pyx_k_GiacMethods_base_information_cen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_insert, __pyx_k_GiacMethods_base_insert, sizeof(__pyx_k_GiacMethods_base_insert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_insmod, __pyx_k_GiacMethods_base_insmod, sizeof(__pyx_k_GiacMethods_base_insmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_instfreq, __pyx_k_GiacMethods_base_instfreq, sizeof(__pyx_k_GiacMethods_base_instfreq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_instphase, __pyx_k_GiacMethods_base_instphase, sizeof(__pyx_k_GiacMethods_base_instphase), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_int, __pyx_k_GiacMethods_base_int, sizeof(__pyx_k_GiacMethods_base_int), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_intDiv, __pyx_k_GiacMethods_base_intDiv, sizeof(__pyx_k_GiacMethods_base_intDiv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_integer, __pyx_k_GiacMethods_base_integer, sizeof(__pyx_k_GiacMethods_base_integer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_integrate, __pyx_k_GiacMethods_base_integrate, sizeof(__pyx_k_GiacMethods_base_integrate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_integrer, __pyx_k_GiacMethods_base_integrer, sizeof(__pyx_k_GiacMethods_base_integrer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inter, __pyx_k_GiacMethods_base_inter, sizeof(__pyx_k_GiacMethods_base_inter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_interactive_ode, __pyx_k_GiacMethods_base_interactive_ode, sizeof(__pyx_k_GiacMethods_base_interactive_ode), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_interactive_plo, __pyx_k_GiacMethods_base_interactive_plo, sizeof(__pyx_k_GiacMethods_base_interactive_plo), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_interp, __pyx_k_GiacMethods_base_interp, sizeof(__pyx_k_GiacMethods_base_interp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_interval, __pyx_k_GiacMethods_base_interval, sizeof(__pyx_k_GiacMethods_base_interval), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_interval2center, __pyx_k_GiacMethods_base_interval2center, sizeof(__pyx_k_GiacMethods_base_interval2center), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_interval_graph, __pyx_k_GiacMethods_base_interval_graph, sizeof(__pyx_k_GiacMethods_base_interval_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inv, __pyx_k_GiacMethods_base_inv, sizeof(__pyx_k_GiacMethods_base_inv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inverse, __pyx_k_GiacMethods_base_inverse, sizeof(__pyx_k_GiacMethods_base_inverse), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_inversion, __pyx_k_GiacMethods_base_inversion, sizeof(__pyx_k_GiacMethods_base_inversion), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_invisible_point, __pyx_k_GiacMethods_base_invisible_point, sizeof(__pyx_k_GiacMethods_base_invisible_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_invlaplace, __pyx_k_GiacMethods_base_invlaplace, sizeof(__pyx_k_GiacMethods_base_invlaplace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_invztrans, __pyx_k_GiacMethods_base_invztrans, sizeof(__pyx_k_GiacMethods_base_invztrans), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_iquo, __pyx_k_GiacMethods_base_iquo, sizeof(__pyx_k_GiacMethods_base_iquo), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_iquorem, __pyx_k_GiacMethods_base_iquorem, sizeof(__pyx_k_GiacMethods_base_iquorem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_iratrecon, __pyx_k_GiacMethods_base_iratrecon, sizeof(__pyx_k_GiacMethods_base_iratrecon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_irem, __pyx_k_GiacMethods_base_irem, sizeof(__pyx_k_GiacMethods_base_irem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isPrime, __pyx_k_GiacMethods_base_isPrime, sizeof(__pyx_k_GiacMethods_base_isPrime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_acyclic, __pyx_k_GiacMethods_base_is_acyclic, sizeof(__pyx_k_GiacMethods_base_is_acyclic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_arborescence, __pyx_k_GiacMethods_base_is_arborescence, sizeof(__pyx_k_GiacMethods_base_is_arborescence), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_biconnected, __pyx_k_GiacMethods_base_is_biconnected, sizeof(__pyx_k_GiacMethods_base_is_biconnected), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_bipartite, __pyx_k_GiacMethods_base_is_bipartite, sizeof(__pyx_k_GiacMethods_base_is_bipartite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_clique, __pyx_k_GiacMethods_base_is_clique, sizeof(__pyx_k_GiacMethods_base_is_clique), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_collinear, __pyx_k_GiacMethods_base_is_collinear, sizeof(__pyx_k_GiacMethods_base_is_collinear), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_concyclic, __pyx_k_GiacMethods_base_is_concyclic, sizeof(__pyx_k_GiacMethods_base_is_concyclic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_conjugate, __pyx_k_GiacMethods_base_is_conjugate, sizeof(__pyx_k_GiacMethods_base_is_conjugate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_connected, __pyx_k_GiacMethods_base_is_connected, sizeof(__pyx_k_GiacMethods_base_is_connected), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_coplanar, __pyx_k_GiacMethods_base_is_coplanar, sizeof(__pyx_k_GiacMethods_base_is_coplanar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_cospherical, __pyx_k_GiacMethods_base_is_cospherical, sizeof(__pyx_k_GiacMethods_base_is_cospherical), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_cut_set, __pyx_k_GiacMethods_base_is_cut_set, sizeof(__pyx_k_GiacMethods_base_is_cut_set), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_cycle, __pyx_k_GiacMethods_base_is_cycle, sizeof(__pyx_k_GiacMethods_base_is_cycle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_directed, __pyx_k_GiacMethods_base_is_directed, sizeof(__pyx_k_GiacMethods_base_is_directed), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_element, __pyx_k_GiacMethods_base_is_element, sizeof(__pyx_k_GiacMethods_base_is_element), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_equilateral, __pyx_k_GiacMethods_base_is_equilateral, sizeof(__pyx_k_GiacMethods_base_is_equilateral), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_eulerian, __pyx_k_GiacMethods_base_is_eulerian, sizeof(__pyx_k_GiacMethods_base_is_eulerian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_forest, __pyx_k_GiacMethods_base_is_forest, sizeof(__pyx_k_GiacMethods_base_is_forest), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_graphic_sequ, __pyx_k_GiacMethods_base_is_graphic_sequ, sizeof(__pyx_k_GiacMethods_base_is_graphic_sequ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_hamiltonian, __pyx_k_GiacMethods_base_is_hamiltonian, sizeof(__pyx_k_GiacMethods_base_is_hamiltonian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_harmonic, __pyx_k_GiacMethods_base_is_harmonic, sizeof(__pyx_k_GiacMethods_base_is_harmonic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_harmonic_cir, __pyx_k_GiacMethods_base_is_harmonic_cir, sizeof(__pyx_k_GiacMethods_base_is_harmonic_cir), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_harmonic_lin, __pyx_k_GiacMethods_base_is_harmonic_lin, sizeof(__pyx_k_GiacMethods_base_is_harmonic_lin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_inside, __pyx_k_GiacMethods_base_is_inside, sizeof(__pyx_k_GiacMethods_base_is_inside), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_integer_grap, __pyx_k_GiacMethods_base_is_integer_grap, sizeof(__pyx_k_GiacMethods_base_is_integer_grap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_irreducible, __pyx_k_GiacMethods_base_is_irreducible, sizeof(__pyx_k_GiacMethods_base_is_irreducible), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_isomorphic, __pyx_k_GiacMethods_base_is_isomorphic, sizeof(__pyx_k_GiacMethods_base_is_isomorphic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_isosceles, __pyx_k_GiacMethods_base_is_isosceles, sizeof(__pyx_k_GiacMethods_base_is_isosceles), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_network, __pyx_k_GiacMethods_base_is_network, sizeof(__pyx_k_GiacMethods_base_is_network), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_orthogonal, __pyx_k_GiacMethods_base_is_orthogonal, sizeof(__pyx_k_GiacMethods_base_is_orthogonal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_parallel, __pyx_k_GiacMethods_base_is_parallel, sizeof(__pyx_k_GiacMethods_base_is_parallel), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_parallelogra, __pyx_k_GiacMethods_base_is_parallelogra, sizeof(__pyx_k_GiacMethods_base_is_parallelogra), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_permu, __pyx_k_GiacMethods_base_is_permu, sizeof(__pyx_k_GiacMethods_base_is_permu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_perpendicula, __pyx_k_GiacMethods_base_is_perpendicula, sizeof(__pyx_k_GiacMethods_base_is_perpendicula), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_planar, __pyx_k_GiacMethods_base_is_planar, sizeof(__pyx_k_GiacMethods_base_is_planar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_prime, __pyx_k_GiacMethods_base_is_prime, sizeof(__pyx_k_GiacMethods_base_is_prime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_pseudoprime, __pyx_k_GiacMethods_base_is_pseudoprime, sizeof(__pyx_k_GiacMethods_base_is_pseudoprime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_reachable, __pyx_k_GiacMethods_base_is_reachable, sizeof(__pyx_k_GiacMethods_base_is_reachable), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_rectangle, __pyx_k_GiacMethods_base_is_rectangle, sizeof(__pyx_k_GiacMethods_base_is_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_regular, __pyx_k_GiacMethods_base_is_regular, sizeof(__pyx_k_GiacMethods_base_is_regular), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_rhombus, __pyx_k_GiacMethods_base_is_rhombus, sizeof(__pyx_k_GiacMethods_base_is_rhombus), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_split_graph, __pyx_k_GiacMethods_base_is_split_graph, sizeof(__pyx_k_GiacMethods_base_is_split_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_square, __pyx_k_GiacMethods_base_is_square, sizeof(__pyx_k_GiacMethods_base_is_square), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_strongly_con, __pyx_k_GiacMethods_base_is_strongly_con, sizeof(__pyx_k_GiacMethods_base_is_strongly_con), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_strongly_reg, __pyx_k_GiacMethods_base_is_strongly_reg, sizeof(__pyx_k_GiacMethods_base_is_strongly_reg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_subgraph_iso, __pyx_k_GiacMethods_base_is_subgraph_iso, sizeof(__pyx_k_GiacMethods_base_is_subgraph_iso), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_tournament, __pyx_k_GiacMethods_base_is_tournament, sizeof(__pyx_k_GiacMethods_base_is_tournament), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_tree, __pyx_k_GiacMethods_base_is_tree, sizeof(__pyx_k_GiacMethods_base_is_tree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_triconnected, __pyx_k_GiacMethods_base_is_triconnected, sizeof(__pyx_k_GiacMethods_base_is_triconnected), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_two_edge_con, __pyx_k_GiacMethods_base_is_two_edge_con, sizeof(__pyx_k_GiacMethods_base_is_two_edge_con), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_vertex_color, __pyx_k_GiacMethods_base_is_vertex_color, sizeof(__pyx_k_GiacMethods_base_is_vertex_color), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_is_weighted, __pyx_k_GiacMethods_base_is_weighted, sizeof(__pyx_k_GiacMethods_base_is_weighted), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isinf, __pyx_k_GiacMethods_base_isinf, sizeof(__pyx_k_GiacMethods_base_isinf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ismith, __pyx_k_GiacMethods_base_ismith, sizeof(__pyx_k_GiacMethods_base_ismith), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isnan, __pyx_k_GiacMethods_base_isnan, sizeof(__pyx_k_GiacMethods_base_isnan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isobarycenter, __pyx_k_GiacMethods_base_isobarycenter, sizeof(__pyx_k_GiacMethods_base_isobarycenter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isolve, __pyx_k_GiacMethods_base_isolve, sizeof(__pyx_k_GiacMethods_base_isolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isom, __pyx_k_GiacMethods_base_isom, sizeof(__pyx_k_GiacMethods_base_isom), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isomorphic_copy, __pyx_k_GiacMethods_base_isomorphic_copy, sizeof(__pyx_k_GiacMethods_base_isomorphic_copy), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isopolygon, __pyx_k_GiacMethods_base_isopolygon, sizeof(__pyx_k_GiacMethods_base_isopolygon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isosceles_trian, __pyx_k_GiacMethods_base_isosceles_trian, sizeof(__pyx_k_GiacMethods_base_isosceles_trian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isposdef, __pyx_k_GiacMethods_base_isposdef, sizeof(__pyx_k_GiacMethods_base_isposdef), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_isprime, __pyx_k_GiacMethods_base_isprime, sizeof(__pyx_k_GiacMethods_base_isprime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_istft, __pyx_k_GiacMethods_base_istft, sizeof(__pyx_k_GiacMethods_base_istft), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ithprime, __pyx_k_GiacMethods_base_ithprime, sizeof(__pyx_k_GiacMethods_base_ithprime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_jacobi_equation, __pyx_k_GiacMethods_base_jacobi_equation, sizeof(__pyx_k_GiacMethods_base_jacobi_equation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_jacobi_linsolve, __pyx_k_GiacMethods_base_jacobi_linsolve, sizeof(__pyx_k_GiacMethods_base_jacobi_linsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_jacobi_symbol, __pyx_k_GiacMethods_base_jacobi_symbol, sizeof(__pyx_k_GiacMethods_base_jacobi_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_johnson_graph, __pyx_k_GiacMethods_base_johnson_graph, sizeof(__pyx_k_GiacMethods_base_johnson_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_join, __pyx_k_GiacMethods_base_join, sizeof(__pyx_k_GiacMethods_base_join), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_jordan, __pyx_k_GiacMethods_base_jordan, sizeof(__pyx_k_GiacMethods_base_jordan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_katz_centrality, __pyx_k_GiacMethods_base_katz_centrality, sizeof(__pyx_k_GiacMethods_base_katz_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kde, __pyx_k_GiacMethods_base_kde, sizeof(__pyx_k_GiacMethods_base_kde), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_keep_pivot, __pyx_k_GiacMethods_base_keep_pivot, sizeof(__pyx_k_GiacMethods_base_keep_pivot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ker, __pyx_k_GiacMethods_base_ker, sizeof(__pyx_k_GiacMethods_base_ker), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kernel, __pyx_k_GiacMethods_base_kernel, sizeof(__pyx_k_GiacMethods_base_kernel), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kernel_density, __pyx_k_GiacMethods_base_kernel_density, sizeof(__pyx_k_GiacMethods_base_kernel_density), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kmeans, __pyx_k_GiacMethods_base_kmeans, sizeof(__pyx_k_GiacMethods_base_kmeans), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kneser_graph, __pyx_k_GiacMethods_base_kneser_graph, sizeof(__pyx_k_GiacMethods_base_kneser_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kolmogorovd, __pyx_k_GiacMethods_base_kolmogorovd, sizeof(__pyx_k_GiacMethods_base_kolmogorovd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kolmogorovt, __pyx_k_GiacMethods_base_kolmogorovt, sizeof(__pyx_k_GiacMethods_base_kolmogorovt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kovacicsols, __pyx_k_GiacMethods_base_kovacicsols, sizeof(__pyx_k_GiacMethods_base_kovacicsols), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_kspaths, __pyx_k_GiacMethods_base_kspaths, sizeof(__pyx_k_GiacMethods_base_kspaths), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_l1norm, __pyx_k_GiacMethods_base_l1norm, sizeof(__pyx_k_GiacMethods_base_l1norm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_l2norm, __pyx_k_GiacMethods_base_l2norm, sizeof(__pyx_k_GiacMethods_base_l2norm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lagrange, __pyx_k_GiacMethods_base_lagrange, sizeof(__pyx_k_GiacMethods_base_lagrange), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_laguerre, __pyx_k_GiacMethods_base_laguerre, sizeof(__pyx_k_GiacMethods_base_laguerre), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_laplace, __pyx_k_GiacMethods_base_laplace, sizeof(__pyx_k_GiacMethods_base_laplace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_laplacian, __pyx_k_GiacMethods_base_laplacian, sizeof(__pyx_k_GiacMethods_base_laplacian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_laplacian_matri, __pyx_k_GiacMethods_base_laplacian_matri, sizeof(__pyx_k_GiacMethods_base_laplacian_matri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_latex, __pyx_k_GiacMethods_base_latex, sizeof(__pyx_k_GiacMethods_base_latex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lcf_graph, __pyx_k_GiacMethods_base_lcf_graph, sizeof(__pyx_k_GiacMethods_base_lcf_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lcm, __pyx_k_GiacMethods_base_lcm, sizeof(__pyx_k_GiacMethods_base_lcm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lcoeff, __pyx_k_GiacMethods_base_lcoeff, sizeof(__pyx_k_GiacMethods_base_lcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ldegree, __pyx_k_GiacMethods_base_ldegree, sizeof(__pyx_k_GiacMethods_base_ldegree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ldl, __pyx_k_GiacMethods_base_ldl, sizeof(__pyx_k_GiacMethods_base_ldl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_learning_rate, __pyx_k_GiacMethods_base_learning_rate, sizeof(__pyx_k_GiacMethods_base_learning_rate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_left, __pyx_k_GiacMethods_base_left, sizeof(__pyx_k_GiacMethods_base_left), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_left_rectangle, __pyx_k_GiacMethods_base_left_rectangle, sizeof(__pyx_k_GiacMethods_base_left_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_legend, __pyx_k_GiacMethods_base_legend, sizeof(__pyx_k_GiacMethods_base_legend), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_legendre, __pyx_k_GiacMethods_base_legendre, sizeof(__pyx_k_GiacMethods_base_legendre), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_legendre_symbol, __pyx_k_GiacMethods_base_legendre_symbol, sizeof(__pyx_k_GiacMethods_base_legendre_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_length, __pyx_k_GiacMethods_base_length, sizeof(__pyx_k_GiacMethods_base_length), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_levenshtein, __pyx_k_GiacMethods_base_levenshtein, sizeof(__pyx_k_GiacMethods_base_levenshtein), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lgcd, __pyx_k_GiacMethods_base_lgcd, sizeof(__pyx_k_GiacMethods_base_lgcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lhs, __pyx_k_GiacMethods_base_lhs, sizeof(__pyx_k_GiacMethods_base_lhs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_chapeau_c, __pyx_k_GiacMethods_base_ligne_chapeau_c, sizeof(__pyx_k_GiacMethods_base_ligne_chapeau_c), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_chapeau_p, __pyx_k_GiacMethods_base_ligne_chapeau_p, sizeof(__pyx_k_GiacMethods_base_ligne_chapeau_p), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_chapeau_r, __pyx_k_GiacMethods_base_ligne_chapeau_r, sizeof(__pyx_k_GiacMethods_base_ligne_chapeau_r), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_polygonal, __pyx_k_GiacMethods_base_ligne_polygonal, sizeof(__pyx_k_GiacMethods_base_ligne_polygonal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_polygonal_2, __pyx_k_GiacMethods_base_ligne_polygonal_2, sizeof(__pyx_k_GiacMethods_base_ligne_polygonal_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_tiret, __pyx_k_GiacMethods_base_ligne_tiret, sizeof(__pyx_k_GiacMethods_base_ligne_tiret), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_tiret_poi, __pyx_k_GiacMethods_base_ligne_tiret_poi, sizeof(__pyx_k_GiacMethods_base_ligne_tiret_poi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_tiret_poi_2, __pyx_k_GiacMethods_base_ligne_tiret_poi_2, sizeof(__pyx_k_GiacMethods_base_ligne_tiret_poi_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ligne_trait_ple, __pyx_k_GiacMethods_base_ligne_trait_ple, sizeof(__pyx_k_GiacMethods_base_ligne_trait_ple), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_limit, __pyx_k_GiacMethods_base_limit, sizeof(__pyx_k_GiacMethods_base_limit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_limite, __pyx_k_GiacMethods_base_limite, sizeof(__pyx_k_GiacMethods_base_limite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lin, __pyx_k_GiacMethods_base_lin, sizeof(__pyx_k_GiacMethods_base_lin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linabs, __pyx_k_GiacMethods_base_linabs, sizeof(__pyx_k_GiacMethods_base_linabs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_line, __pyx_k_GiacMethods_base_line, sizeof(__pyx_k_GiacMethods_base_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_line_graph, __pyx_k_GiacMethods_base_line_graph, sizeof(__pyx_k_GiacMethods_base_line_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_line_inter, __pyx_k_GiacMethods_base_line_inter, sizeof(__pyx_k_GiacMethods_base_line_inter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_line_paper, __pyx_k_GiacMethods_base_line_paper, sizeof(__pyx_k_GiacMethods_base_line_paper), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_line_segments, __pyx_k_GiacMethods_base_line_segments, sizeof(__pyx_k_GiacMethods_base_line_segments), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linear_interpol, __pyx_k_GiacMethods_base_linear_interpol, sizeof(__pyx_k_GiacMethods_base_linear_interpol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linear_regressi, __pyx_k_GiacMethods_base_linear_regressi, sizeof(__pyx_k_GiacMethods_base_linear_regressi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linear_regressi_2, __pyx_k_GiacMethods_base_linear_regressi_2, sizeof(__pyx_k_GiacMethods_base_linear_regressi_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lineariser, __pyx_k_GiacMethods_base_lineariser, sizeof(__pyx_k_GiacMethods_base_lineariser), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lineariser_trig, __pyx_k_GiacMethods_base_lineariser_trig, sizeof(__pyx_k_GiacMethods_base_lineariser_trig), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linfnorm, __pyx_k_GiacMethods_base_linfnorm, sizeof(__pyx_k_GiacMethods_base_linfnorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linsolve, __pyx_k_GiacMethods_base_linsolve, sizeof(__pyx_k_GiacMethods_base_linsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linspace, __pyx_k_GiacMethods_base_linspace, sizeof(__pyx_k_GiacMethods_base_linspace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_linstep, __pyx_k_GiacMethods_base_linstep, sizeof(__pyx_k_GiacMethods_base_linstep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lis_phrase, __pyx_k_GiacMethods_base_lis_phrase, sizeof(__pyx_k_GiacMethods_base_lis_phrase), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_list2exp, __pyx_k_GiacMethods_base_list2exp, sizeof(__pyx_k_GiacMethods_base_list2exp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_list2mat, __pyx_k_GiacMethods_base_list2mat, sizeof(__pyx_k_GiacMethods_base_list2mat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_list_edge_attri, __pyx_k_GiacMethods_base_list_edge_attri, sizeof(__pyx_k_GiacMethods_base_list_edge_attri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_list_graph_attr, __pyx_k_GiacMethods_base_list_graph_attr, sizeof(__pyx_k_GiacMethods_base_list_graph_attr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_list_vertex_att, __pyx_k_GiacMethods_base_list_vertex_att, sizeof(__pyx_k_GiacMethods_base_list_vertex_att), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_listplot, __pyx_k_GiacMethods_base_listplot, sizeof(__pyx_k_GiacMethods_base_listplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lll, __pyx_k_GiacMethods_base_lll, sizeof(__pyx_k_GiacMethods_base_lll), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ln, __pyx_k_GiacMethods_base_ln, sizeof(__pyx_k_GiacMethods_base_ln), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lname, __pyx_k_GiacMethods_base_lname, sizeof(__pyx_k_GiacMethods_base_lname), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lncollect, __pyx_k_GiacMethods_base_lncollect, sizeof(__pyx_k_GiacMethods_base_lncollect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lnexpand, __pyx_k_GiacMethods_base_lnexpand, sizeof(__pyx_k_GiacMethods_base_lnexpand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_locus, __pyx_k_GiacMethods_base_locus, sizeof(__pyx_k_GiacMethods_base_locus), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_log, __pyx_k_GiacMethods_base_log, sizeof(__pyx_k_GiacMethods_base_log), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_log10, __pyx_k_GiacMethods_base_log10, sizeof(__pyx_k_GiacMethods_base_log10), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_log2, __pyx_k_GiacMethods_base_log2, sizeof(__pyx_k_GiacMethods_base_log2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_log_loss, __pyx_k_GiacMethods_base_log_loss, sizeof(__pyx_k_GiacMethods_base_log_loss), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_logarithmic_reg, __pyx_k_GiacMethods_base_logarithmic_reg, sizeof(__pyx_k_GiacMethods_base_logarithmic_reg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_logarithmic_reg_2, __pyx_k_GiacMethods_base_logarithmic_reg_2, sizeof(__pyx_k_GiacMethods_base_logarithmic_reg_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_logb, __pyx_k_GiacMethods_base_logb, sizeof(__pyx_k_GiacMethods_base_logb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_logistic, __pyx_k_GiacMethods_base_logistic, sizeof(__pyx_k_GiacMethods_base_logistic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_logistic_regres, __pyx_k_GiacMethods_base_logistic_regres, sizeof(__pyx_k_GiacMethods_base_logistic_regres), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_logistic_regres_2, __pyx_k_GiacMethods_base_logistic_regres_2, sizeof(__pyx_k_GiacMethods_base_logistic_regres_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lower, __pyx_k_GiacMethods_base_lower, sizeof(__pyx_k_GiacMethods_base_lower), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lowest_common_a, __pyx_k_GiacMethods_base_lowest_common_a, sizeof(__pyx_k_GiacMethods_base_lowest_common_a), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lowpass, __pyx_k_GiacMethods_base_lowpass, sizeof(__pyx_k_GiacMethods_base_lowpass), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_assume, __pyx_k_GiacMethods_base_lp_assume, sizeof(__pyx_k_GiacMethods_base_lp_assume), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_bestlocalbou, __pyx_k_GiacMethods_base_lp_bestlocalbou, sizeof(__pyx_k_GiacMethods_base_lp_bestlocalbou), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_bestprojecti, __pyx_k_GiacMethods_base_lp_bestprojecti, sizeof(__pyx_k_GiacMethods_base_lp_bestprojecti), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_binary, __pyx_k_GiacMethods_base_lp_binary, sizeof(__pyx_k_GiacMethods_base_lp_binary), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_binaryvariab, __pyx_k_GiacMethods_base_lp_binaryvariab, sizeof(__pyx_k_GiacMethods_base_lp_binaryvariab), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_breadthfirst, __pyx_k_GiacMethods_base_lp_breadthfirst, sizeof(__pyx_k_GiacMethods_base_lp_breadthfirst), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_depthfirst, __pyx_k_GiacMethods_base_lp_depthfirst, sizeof(__pyx_k_GiacMethods_base_lp_depthfirst), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_depthlimit, __pyx_k_GiacMethods_base_lp_depthlimit, sizeof(__pyx_k_GiacMethods_base_lp_depthlimit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_firstfractio, __pyx_k_GiacMethods_base_lp_firstfractio, sizeof(__pyx_k_GiacMethods_base_lp_firstfractio), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_gaptolerance, __pyx_k_GiacMethods_base_lp_gaptolerance, sizeof(__pyx_k_GiacMethods_base_lp_gaptolerance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_heuristic, __pyx_k_GiacMethods_base_lp_heuristic, sizeof(__pyx_k_GiacMethods_base_lp_heuristic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_hybrid, __pyx_k_GiacMethods_base_lp_hybrid, sizeof(__pyx_k_GiacMethods_base_lp_hybrid), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_integer, __pyx_k_GiacMethods_base_lp_integer, sizeof(__pyx_k_GiacMethods_base_lp_integer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_integervaria, __pyx_k_GiacMethods_base_lp_integervaria, sizeof(__pyx_k_GiacMethods_base_lp_integervaria), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_interiorpoin, __pyx_k_GiacMethods_base_lp_interiorpoin, sizeof(__pyx_k_GiacMethods_base_lp_interiorpoin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_iterationlim, __pyx_k_GiacMethods_base_lp_iterationlim, sizeof(__pyx_k_GiacMethods_base_lp_iterationlim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_lastfraction, __pyx_k_GiacMethods_base_lp_lastfraction, sizeof(__pyx_k_GiacMethods_base_lp_lastfraction), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_maxcuts, __pyx_k_GiacMethods_base_lp_maxcuts, sizeof(__pyx_k_GiacMethods_base_lp_maxcuts), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_maximize, __pyx_k_GiacMethods_base_lp_maximize, sizeof(__pyx_k_GiacMethods_base_lp_maximize), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_method, __pyx_k_GiacMethods_base_lp_method, sizeof(__pyx_k_GiacMethods_base_lp_method), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_mostfraction, __pyx_k_GiacMethods_base_lp_mostfraction, sizeof(__pyx_k_GiacMethods_base_lp_mostfraction), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_nodelimit, __pyx_k_GiacMethods_base_lp_nodelimit, sizeof(__pyx_k_GiacMethods_base_lp_nodelimit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_nodeselect, __pyx_k_GiacMethods_base_lp_nodeselect, sizeof(__pyx_k_GiacMethods_base_lp_nodeselect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_nonnegative, __pyx_k_GiacMethods_base_lp_nonnegative, sizeof(__pyx_k_GiacMethods_base_lp_nonnegative), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_nonnegint, __pyx_k_GiacMethods_base_lp_nonnegint, sizeof(__pyx_k_GiacMethods_base_lp_nonnegint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_presolve, __pyx_k_GiacMethods_base_lp_presolve, sizeof(__pyx_k_GiacMethods_base_lp_presolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_pseudocost, __pyx_k_GiacMethods_base_lp_pseudocost, sizeof(__pyx_k_GiacMethods_base_lp_pseudocost), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_simplex, __pyx_k_GiacMethods_base_lp_simplex, sizeof(__pyx_k_GiacMethods_base_lp_simplex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_timelimit, __pyx_k_GiacMethods_base_lp_timelimit, sizeof(__pyx_k_GiacMethods_base_lp_timelimit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_varselect, __pyx_k_GiacMethods_base_lp_varselect, sizeof(__pyx_k_GiacMethods_base_lp_varselect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lp_verbose, __pyx_k_GiacMethods_base_lp_verbose, sizeof(__pyx_k_GiacMethods_base_lp_verbose), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lpsolve, __pyx_k_GiacMethods_base_lpsolve, sizeof(__pyx_k_GiacMethods_base_lpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lsmod, __pyx_k_GiacMethods_base_lsmod, sizeof(__pyx_k_GiacMethods_base_lsmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lsq, __pyx_k_GiacMethods_base_lsq, sizeof(__pyx_k_GiacMethods_base_lsq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lu, __pyx_k_GiacMethods_base_lu, sizeof(__pyx_k_GiacMethods_base_lu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_lvar, __pyx_k_GiacMethods_base_lvar, sizeof(__pyx_k_GiacMethods_base_lvar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mRow, __pyx_k_GiacMethods_base_mRow, sizeof(__pyx_k_GiacMethods_base_mRow), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mRowAdd, __pyx_k_GiacMethods_base_mRowAdd, sizeof(__pyx_k_GiacMethods_base_mRowAdd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_magenta, __pyx_k_GiacMethods_base_magenta, sizeof(__pyx_k_GiacMethods_base_magenta), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_make_directed, __pyx_k_GiacMethods_base_make_directed, sizeof(__pyx_k_GiacMethods_base_make_directed), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_make_symbol, __pyx_k_GiacMethods_base_make_symbol, sizeof(__pyx_k_GiacMethods_base_make_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_make_weighted, __pyx_k_GiacMethods_base_make_weighted, sizeof(__pyx_k_GiacMethods_base_make_weighted), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_makelist, __pyx_k_GiacMethods_base_makelist, sizeof(__pyx_k_GiacMethods_base_makelist), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_makemat, __pyx_k_GiacMethods_base_makemat, sizeof(__pyx_k_GiacMethods_base_makemat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_makesuite, __pyx_k_GiacMethods_base_makesuite, sizeof(__pyx_k_GiacMethods_base_makesuite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_makevector, __pyx_k_GiacMethods_base_makevector, sizeof(__pyx_k_GiacMethods_base_makevector), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_map, __pyx_k_GiacMethods_base_map, sizeof(__pyx_k_GiacMethods_base_map), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maple2mupad, __pyx_k_GiacMethods_base_maple2mupad, sizeof(__pyx_k_GiacMethods_base_maple2mupad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maple2xcas, __pyx_k_GiacMethods_base_maple2xcas, sizeof(__pyx_k_GiacMethods_base_maple2xcas), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maple_ifactors, __pyx_k_GiacMethods_base_maple_ifactors, sizeof(__pyx_k_GiacMethods_base_maple_ifactors), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maple_mode, __pyx_k_GiacMethods_base_maple_mode, sizeof(__pyx_k_GiacMethods_base_maple_mode), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_markov, __pyx_k_GiacMethods_base_markov, sizeof(__pyx_k_GiacMethods_base_markov), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mat2list, __pyx_k_GiacMethods_base_mat2list, sizeof(__pyx_k_GiacMethods_base_mat2list), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mathml, __pyx_k_GiacMethods_base_mathml, sizeof(__pyx_k_GiacMethods_base_mathml), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_matpow, __pyx_k_GiacMethods_base_matpow, sizeof(__pyx_k_GiacMethods_base_matpow), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_matrix, __pyx_k_GiacMethods_base_matrix, sizeof(__pyx_k_GiacMethods_base_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_matrix_norm, __pyx_k_GiacMethods_base_matrix_norm, sizeof(__pyx_k_GiacMethods_base_matrix_norm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_max, __pyx_k_GiacMethods_base_max, sizeof(__pyx_k_GiacMethods_base_max), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maxflow, __pyx_k_GiacMethods_base_maxflow, sizeof(__pyx_k_GiacMethods_base_maxflow), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maximal_indepen, __pyx_k_GiacMethods_base_maximal_indepen, sizeof(__pyx_k_GiacMethods_base_maximal_indepen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maximize, __pyx_k_GiacMethods_base_maximize, sizeof(__pyx_k_GiacMethods_base_maximize), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maximum_clique, __pyx_k_GiacMethods_base_maximum_clique, sizeof(__pyx_k_GiacMethods_base_maximum_clique), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maximum_degree, __pyx_k_GiacMethods_base_maximum_degree, sizeof(__pyx_k_GiacMethods_base_maximum_degree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maximum_indepen, __pyx_k_GiacMethods_base_maximum_indepen, sizeof(__pyx_k_GiacMethods_base_maximum_indepen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maximum_matchin, __pyx_k_GiacMethods_base_maximum_matchin, sizeof(__pyx_k_GiacMethods_base_maximum_matchin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_maxnorm, __pyx_k_GiacMethods_base_maxnorm, sizeof(__pyx_k_GiacMethods_base_maxnorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mean, __pyx_k_GiacMethods_base_mean, sizeof(__pyx_k_GiacMethods_base_mean), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_median, __pyx_k_GiacMethods_base_median, sizeof(__pyx_k_GiacMethods_base_median), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_median_line, __pyx_k_GiacMethods_base_median_line, sizeof(__pyx_k_GiacMethods_base_median_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_member, __pyx_k_GiacMethods_base_member, sizeof(__pyx_k_GiacMethods_base_member), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mgf, __pyx_k_GiacMethods_base_mgf, sizeof(__pyx_k_GiacMethods_base_mgf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mid, __pyx_k_GiacMethods_base_mid, sizeof(__pyx_k_GiacMethods_base_mid), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_middle_point, __pyx_k_GiacMethods_base_middle_point, sizeof(__pyx_k_GiacMethods_base_middle_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_midpoint, __pyx_k_GiacMethods_base_midpoint, sizeof(__pyx_k_GiacMethods_base_midpoint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_min, __pyx_k_GiacMethods_base_min, sizeof(__pyx_k_GiacMethods_base_min), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimal_edge_co, __pyx_k_GiacMethods_base_minimal_edge_co, sizeof(__pyx_k_GiacMethods_base_minimal_edge_co), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimal_spannin, __pyx_k_GiacMethods_base_minimal_spannin, sizeof(__pyx_k_GiacMethods_base_minimal_spannin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimal_vertex, __pyx_k_GiacMethods_base_minimal_vertex, sizeof(__pyx_k_GiacMethods_base_minimal_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimax, __pyx_k_GiacMethods_base_minimax, sizeof(__pyx_k_GiacMethods_base_minimax), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimize, __pyx_k_GiacMethods_base_minimize, sizeof(__pyx_k_GiacMethods_base_minimize), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimum_cut, __pyx_k_GiacMethods_base_minimum_cut, sizeof(__pyx_k_GiacMethods_base_minimum_cut), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimum_degree, __pyx_k_GiacMethods_base_minimum_degree, sizeof(__pyx_k_GiacMethods_base_minimum_degree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_minimum_vertex, __pyx_k_GiacMethods_base_minimum_vertex, sizeof(__pyx_k_GiacMethods_base_minimum_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mixdown, __pyx_k_GiacMethods_base_mixdown, sizeof(__pyx_k_GiacMethods_base_mixdown), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mkisom, __pyx_k_GiacMethods_base_mkisom, sizeof(__pyx_k_GiacMethods_base_mkisom), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mksa, __pyx_k_GiacMethods_base_mksa, sizeof(__pyx_k_GiacMethods_base_mksa), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_modf, __pyx_k_GiacMethods_base_modf, sizeof(__pyx_k_GiacMethods_base_modf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_modgcd, __pyx_k_GiacMethods_base_modgcd, sizeof(__pyx_k_GiacMethods_base_modgcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mods, __pyx_k_GiacMethods_base_mods, sizeof(__pyx_k_GiacMethods_base_mods), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_momentum, __pyx_k_GiacMethods_base_momentum, sizeof(__pyx_k_GiacMethods_base_momentum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_monotonic, __pyx_k_GiacMethods_base_monotonic, sizeof(__pyx_k_GiacMethods_base_monotonic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_montre_tortue, __pyx_k_GiacMethods_base_montre_tortue, sizeof(__pyx_k_GiacMethods_base_montre_tortue), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_moustache, __pyx_k_GiacMethods_base_moustache, sizeof(__pyx_k_GiacMethods_base_moustache), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_moving_average, __pyx_k_GiacMethods_base_moving_average, sizeof(__pyx_k_GiacMethods_base_moving_average), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_moyal, __pyx_k_GiacMethods_base_moyal, sizeof(__pyx_k_GiacMethods_base_moyal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_moyenne, __pyx_k_GiacMethods_base_moyenne, sizeof(__pyx_k_GiacMethods_base_moyenne), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mul, __pyx_k_GiacMethods_base_mul, sizeof(__pyx_k_GiacMethods_base_mul), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mult_c_conjugat, __pyx_k_GiacMethods_base_mult_c_conjugat, sizeof(__pyx_k_GiacMethods_base_mult_c_conjugat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mult_conjugate, __pyx_k_GiacMethods_base_mult_conjugate, sizeof(__pyx_k_GiacMethods_base_mult_conjugate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_multinomial, __pyx_k_GiacMethods_base_multinomial, sizeof(__pyx_k_GiacMethods_base_multinomial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_multiplier_conj, __pyx_k_GiacMethods_base_multiplier_conj, sizeof(__pyx_k_GiacMethods_base_multiplier_conj), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_multiplier_conj_2, __pyx_k_GiacMethods_base_multiplier_conj_2, sizeof(__pyx_k_GiacMethods_base_multiplier_conj_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_multiply, __pyx_k_GiacMethods_base_multiply, sizeof(__pyx_k_GiacMethods_base_multiply), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mupad2maple, __pyx_k_GiacMethods_base_mupad2maple, sizeof(__pyx_k_GiacMethods_base_mupad2maple), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mupad2xcas, __pyx_k_GiacMethods_base_mupad2xcas, sizeof(__pyx_k_GiacMethods_base_mupad2xcas), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_mycielski, __pyx_k_GiacMethods_base_mycielski, sizeof(__pyx_k_GiacMethods_base_mycielski), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nCr, __pyx_k_GiacMethods_base_nCr, sizeof(__pyx_k_GiacMethods_base_nCr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nDeriv, __pyx_k_GiacMethods_base_nDeriv, sizeof(__pyx_k_GiacMethods_base_nDeriv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nInt, __pyx_k_GiacMethods_base_nInt, sizeof(__pyx_k_GiacMethods_base_nInt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nPr, __pyx_k_GiacMethods_base_nPr, sizeof(__pyx_k_GiacMethods_base_nPr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nSolve, __pyx_k_GiacMethods_base_nSolve, sizeof(__pyx_k_GiacMethods_base_nSolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_navy, __pyx_k_GiacMethods_base_navy, sizeof(__pyx_k_GiacMethods_base_navy), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ncols, __pyx_k_GiacMethods_base_ncols, sizeof(__pyx_k_GiacMethods_base_ncols), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_negbinomial, __pyx_k_GiacMethods_base_negbinomial, sizeof(__pyx_k_GiacMethods_base_negbinomial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_negbinomial_cdf, __pyx_k_GiacMethods_base_negbinomial_cdf, sizeof(__pyx_k_GiacMethods_base_negbinomial_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_negbinomial_icd, __pyx_k_GiacMethods_base_negbinomial_icd, sizeof(__pyx_k_GiacMethods_base_negbinomial_icd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_neighbors, __pyx_k_GiacMethods_base_neighbors, sizeof(__pyx_k_GiacMethods_base_neighbors), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_network_transit, __pyx_k_GiacMethods_base_network_transit, sizeof(__pyx_k_GiacMethods_base_network_transit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_neural_network, __pyx_k_GiacMethods_base_neural_network, sizeof(__pyx_k_GiacMethods_base_neural_network), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_newList, __pyx_k_GiacMethods_base_newList, sizeof(__pyx_k_GiacMethods_base_newList), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_newMat, __pyx_k_GiacMethods_base_newMat, sizeof(__pyx_k_GiacMethods_base_newMat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_newton, __pyx_k_GiacMethods_base_newton, sizeof(__pyx_k_GiacMethods_base_newton), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_newton_solver, __pyx_k_GiacMethods_base_newton_solver, sizeof(__pyx_k_GiacMethods_base_newton_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_newtonj_solver, __pyx_k_GiacMethods_base_newtonj_solver, sizeof(__pyx_k_GiacMethods_base_newtonj_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nextperm, __pyx_k_GiacMethods_base_nextperm, sizeof(__pyx_k_GiacMethods_base_nextperm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nextprime, __pyx_k_GiacMethods_base_nextprime, sizeof(__pyx_k_GiacMethods_base_nextprime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_binary, __pyx_k_GiacMethods_base_nlp_binary, sizeof(__pyx_k_GiacMethods_base_nlp_binary), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_binaryvaria, __pyx_k_GiacMethods_base_nlp_binaryvaria, sizeof(__pyx_k_GiacMethods_base_nlp_binaryvaria), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_initialpoin, __pyx_k_GiacMethods_base_nlp_initialpoin, sizeof(__pyx_k_GiacMethods_base_nlp_initialpoin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_integer, __pyx_k_GiacMethods_base_nlp_integer, sizeof(__pyx_k_GiacMethods_base_nlp_integer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_integervari, __pyx_k_GiacMethods_base_nlp_integervari, sizeof(__pyx_k_GiacMethods_base_nlp_integervari), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_iterationli, __pyx_k_GiacMethods_base_nlp_iterationli, sizeof(__pyx_k_GiacMethods_base_nlp_iterationli), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_maximize, __pyx_k_GiacMethods_base_nlp_maximize, sizeof(__pyx_k_GiacMethods_base_nlp_maximize), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_method, __pyx_k_GiacMethods_base_nlp_method, sizeof(__pyx_k_GiacMethods_base_nlp_method), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_nonnegative, __pyx_k_GiacMethods_base_nlp_nonnegative, sizeof(__pyx_k_GiacMethods_base_nlp_nonnegative), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_nonnegint, __pyx_k_GiacMethods_base_nlp_nonnegint, sizeof(__pyx_k_GiacMethods_base_nlp_nonnegint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_precision, __pyx_k_GiacMethods_base_nlp_precision, sizeof(__pyx_k_GiacMethods_base_nlp_precision), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_presolve, __pyx_k_GiacMethods_base_nlp_presolve, sizeof(__pyx_k_GiacMethods_base_nlp_presolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_tolerance, __pyx_k_GiacMethods_base_nlp_tolerance, sizeof(__pyx_k_GiacMethods_base_nlp_tolerance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlp_verbose, __pyx_k_GiacMethods_base_nlp_verbose, sizeof(__pyx_k_GiacMethods_base_nlp_verbose), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nlpsolve, __pyx_k_GiacMethods_base_nlpsolve, sizeof(__pyx_k_GiacMethods_base_nlpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nodisp, __pyx_k_GiacMethods_base_nodisp, sizeof(__pyx_k_GiacMethods_base_nodisp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_non_recursive_n, __pyx_k_GiacMethods_base_non_recursive_n, sizeof(__pyx_k_GiacMethods_base_non_recursive_n), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nonnegint, __pyx_k_GiacMethods_base_nonnegint, sizeof(__pyx_k_GiacMethods_base_nonnegint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nop, __pyx_k_GiacMethods_base_nop, sizeof(__pyx_k_GiacMethods_base_nop), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nops, __pyx_k_GiacMethods_base_nops, sizeof(__pyx_k_GiacMethods_base_nops), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_norm, __pyx_k_GiacMethods_base_norm, sizeof(__pyx_k_GiacMethods_base_norm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normal, __pyx_k_GiacMethods_base_normal, sizeof(__pyx_k_GiacMethods_base_normal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normal_cdf, __pyx_k_GiacMethods_base_normal_cdf, sizeof(__pyx_k_GiacMethods_base_normal_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normal_icdf, __pyx_k_GiacMethods_base_normal_icdf, sizeof(__pyx_k_GiacMethods_base_normal_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normald, __pyx_k_GiacMethods_base_normald, sizeof(__pyx_k_GiacMethods_base_normald), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normald_cdf, __pyx_k_GiacMethods_base_normald_cdf, sizeof(__pyx_k_GiacMethods_base_normald_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normald_icdf, __pyx_k_GiacMethods_base_normald_icdf, sizeof(__pyx_k_GiacMethods_base_normald_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normalize, __pyx_k_GiacMethods_base_normalize, sizeof(__pyx_k_GiacMethods_base_normalize), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normalt, __pyx_k_GiacMethods_base_normalt, sizeof(__pyx_k_GiacMethods_base_normalt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_normalvariate, __pyx_k_GiacMethods_base_normalvariate, sizeof(__pyx_k_GiacMethods_base_normalvariate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nprimes, __pyx_k_GiacMethods_base_nprimes, sizeof(__pyx_k_GiacMethods_base_nprimes), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nrows, __pyx_k_GiacMethods_base_nrows, sizeof(__pyx_k_GiacMethods_base_nrows), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nstep, __pyx_k_GiacMethods_base_nstep, sizeof(__pyx_k_GiacMethods_base_nstep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nuage_points, __pyx_k_GiacMethods_base_nuage_points, sizeof(__pyx_k_GiacMethods_base_nuage_points), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_nullspace, __pyx_k_GiacMethods_base_nullspace, sizeof(__pyx_k_GiacMethods_base_nullspace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_number_of_edges, __pyx_k_GiacMethods_base_number_of_edges, sizeof(__pyx_k_GiacMethods_base_number_of_edges), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_number_of_spann, __pyx_k_GiacMethods_base_number_of_spann, sizeof(__pyx_k_GiacMethods_base_number_of_spann), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_number_of_trian, __pyx_k_GiacMethods_base_number_of_trian, sizeof(__pyx_k_GiacMethods_base_number_of_trian), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_number_of_verti, __pyx_k_GiacMethods_base_number_of_verti, sizeof(__pyx_k_GiacMethods_base_number_of_verti), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_numdiff, __pyx_k_GiacMethods_base_numdiff, sizeof(__pyx_k_GiacMethods_base_numdiff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_numer, __pyx_k_GiacMethods_base_numer, sizeof(__pyx_k_GiacMethods_base_numer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_octahedron, __pyx_k_GiacMethods_base_octahedron, sizeof(__pyx_k_GiacMethods_base_octahedron), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_odd, __pyx_k_GiacMethods_base_odd, sizeof(__pyx_k_GiacMethods_base_odd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_odd_girth, __pyx_k_GiacMethods_base_odd_girth, sizeof(__pyx_k_GiacMethods_base_odd_girth), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_odd_graph, __pyx_k_GiacMethods_base_odd_graph, sizeof(__pyx_k_GiacMethods_base_odd_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_odeplot, __pyx_k_GiacMethods_base_odeplot, sizeof(__pyx_k_GiacMethods_base_odeplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_odesolve, __pyx_k_GiacMethods_base_odesolve, sizeof(__pyx_k_GiacMethods_base_odesolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_olive, __pyx_k_GiacMethods_base_olive, sizeof(__pyx_k_GiacMethods_base_olive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_op, __pyx_k_GiacMethods_base_op, sizeof(__pyx_k_GiacMethods_base_op), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_open_polygon, __pyx_k_GiacMethods_base_open_polygon, sizeof(__pyx_k_GiacMethods_base_open_polygon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_orange, __pyx_k_GiacMethods_base_orange, sizeof(__pyx_k_GiacMethods_base_orange), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ord, __pyx_k_GiacMethods_base_ord, sizeof(__pyx_k_GiacMethods_base_ord), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_order, __pyx_k_GiacMethods_base_order, sizeof(__pyx_k_GiacMethods_base_order), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_order_size, __pyx_k_GiacMethods_base_order_size, sizeof(__pyx_k_GiacMethods_base_order_size), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ordinate, __pyx_k_GiacMethods_base_ordinate, sizeof(__pyx_k_GiacMethods_base_ordinate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_orthocenter, __pyx_k_GiacMethods_base_orthocenter, sizeof(__pyx_k_GiacMethods_base_orthocenter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_orthogonal, __pyx_k_GiacMethods_base_orthogonal, sizeof(__pyx_k_GiacMethods_base_orthogonal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_osculating_circ, __pyx_k_GiacMethods_base_osculating_circ, sizeof(__pyx_k_GiacMethods_base_osculating_circ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_p1oc2, __pyx_k_GiacMethods_base_p1oc2, sizeof(__pyx_k_GiacMethods_base_p1oc2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_p1op2, __pyx_k_GiacMethods_base_p1op2, sizeof(__pyx_k_GiacMethods_base_p1op2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pa2b2, __pyx_k_GiacMethods_base_pa2b2, sizeof(__pyx_k_GiacMethods_base_pa2b2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pade, __pyx_k_GiacMethods_base_pade, sizeof(__pyx_k_GiacMethods_base_pade), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_paley_graph, __pyx_k_GiacMethods_base_paley_graph, sizeof(__pyx_k_GiacMethods_base_paley_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parabola, __pyx_k_GiacMethods_base_parabola, sizeof(__pyx_k_GiacMethods_base_parabola), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parallel, __pyx_k_GiacMethods_base_parallel, sizeof(__pyx_k_GiacMethods_base_parallel), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parallelepiped, __pyx_k_GiacMethods_base_parallelepiped, sizeof(__pyx_k_GiacMethods_base_parallelepiped), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parallelogram, __pyx_k_GiacMethods_base_parallelogram, sizeof(__pyx_k_GiacMethods_base_parallelogram), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parameq, __pyx_k_GiacMethods_base_parameq, sizeof(__pyx_k_GiacMethods_base_parameq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parameter, __pyx_k_GiacMethods_base_parameter, sizeof(__pyx_k_GiacMethods_base_parameter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_paramplot, __pyx_k_GiacMethods_base_paramplot, sizeof(__pyx_k_GiacMethods_base_paramplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parfrac, __pyx_k_GiacMethods_base_parfrac, sizeof(__pyx_k_GiacMethods_base_parfrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pari, __pyx_k_GiacMethods_base_pari, sizeof(__pyx_k_GiacMethods_base_pari), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_part, __pyx_k_GiacMethods_base_part, sizeof(__pyx_k_GiacMethods_base_part), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_partfrac, __pyx_k_GiacMethods_base_partfrac, sizeof(__pyx_k_GiacMethods_base_partfrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_parzen_window, __pyx_k_GiacMethods_base_parzen_window, sizeof(__pyx_k_GiacMethods_base_parzen_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pas_de_cote, __pyx_k_GiacMethods_base_pas_de_cote, sizeof(__pyx_k_GiacMethods_base_pas_de_cote), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_path_graph, __pyx_k_GiacMethods_base_path_graph, sizeof(__pyx_k_GiacMethods_base_path_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pcar, __pyx_k_GiacMethods_base_pcar, sizeof(__pyx_k_GiacMethods_base_pcar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pcar_hessenberg, __pyx_k_GiacMethods_base_pcar_hessenberg, sizeof(__pyx_k_GiacMethods_base_pcar_hessenberg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pcoef, __pyx_k_GiacMethods_base_pcoef, sizeof(__pyx_k_GiacMethods_base_pcoef), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pcoeff, __pyx_k_GiacMethods_base_pcoeff, sizeof(__pyx_k_GiacMethods_base_pcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pencolor, __pyx_k_GiacMethods_base_pencolor, sizeof(__pyx_k_GiacMethods_base_pencolor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pendown, __pyx_k_GiacMethods_base_pendown, sizeof(__pyx_k_GiacMethods_base_pendown), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_penup, __pyx_k_GiacMethods_base_penup, sizeof(__pyx_k_GiacMethods_base_penup), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perimeter, __pyx_k_GiacMethods_base_perimeter, sizeof(__pyx_k_GiacMethods_base_perimeter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perimeterat, __pyx_k_GiacMethods_base_perimeterat, sizeof(__pyx_k_GiacMethods_base_perimeterat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perimeteratraw, __pyx_k_GiacMethods_base_perimeteratraw, sizeof(__pyx_k_GiacMethods_base_perimeteratraw), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_period, __pyx_k_GiacMethods_base_period, sizeof(__pyx_k_GiacMethods_base_period), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_periodic, __pyx_k_GiacMethods_base_periodic, sizeof(__pyx_k_GiacMethods_base_periodic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perm, __pyx_k_GiacMethods_base_perm, sizeof(__pyx_k_GiacMethods_base_perm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perminv, __pyx_k_GiacMethods_base_perminv, sizeof(__pyx_k_GiacMethods_base_perminv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_permu2cycles, __pyx_k_GiacMethods_base_permu2cycles, sizeof(__pyx_k_GiacMethods_base_permu2cycles), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_permu2mat, __pyx_k_GiacMethods_base_permu2mat, sizeof(__pyx_k_GiacMethods_base_permu2mat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_permuorder, __pyx_k_GiacMethods_base_permuorder, sizeof(__pyx_k_GiacMethods_base_permuorder), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_permute_vertice, __pyx_k_GiacMethods_base_permute_vertice, sizeof(__pyx_k_GiacMethods_base_permute_vertice), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perpen_bisector, __pyx_k_GiacMethods_base_perpen_bisector, sizeof(__pyx_k_GiacMethods_base_perpen_bisector), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_perpendicular, __pyx_k_GiacMethods_base_perpendicular, sizeof(__pyx_k_GiacMethods_base_perpendicular), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_petersen_graph, __pyx_k_GiacMethods_base_petersen_graph, sizeof(__pyx_k_GiacMethods_base_petersen_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_peval, __pyx_k_GiacMethods_base_peval, sizeof(__pyx_k_GiacMethods_base_peval), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pi, __pyx_k_GiacMethods_base_pi, sizeof(__pyx_k_GiacMethods_base_pi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pie, __pyx_k_GiacMethods_base_pie, sizeof(__pyx_k_GiacMethods_base_pie), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_piecewise, __pyx_k_GiacMethods_base_piecewise, sizeof(__pyx_k_GiacMethods_base_piecewise), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pink, __pyx_k_GiacMethods_base_pink, sizeof(__pyx_k_GiacMethods_base_pink), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pivot, __pyx_k_GiacMethods_base_pivot, sizeof(__pyx_k_GiacMethods_base_pivot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pixoff, __pyx_k_GiacMethods_base_pixoff, sizeof(__pyx_k_GiacMethods_base_pixoff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pixon, __pyx_k_GiacMethods_base_pixon, sizeof(__pyx_k_GiacMethods_base_pixon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_planar, __pyx_k_GiacMethods_base_planar, sizeof(__pyx_k_GiacMethods_base_planar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plane, __pyx_k_GiacMethods_base_plane, sizeof(__pyx_k_GiacMethods_base_plane), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plane_dual, __pyx_k_GiacMethods_base_plane_dual, sizeof(__pyx_k_GiacMethods_base_plane_dual), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_playsnd, __pyx_k_GiacMethods_base_playsnd, sizeof(__pyx_k_GiacMethods_base_playsnd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plex, __pyx_k_GiacMethods_base_plex, sizeof(__pyx_k_GiacMethods_base_plex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plot, __pyx_k_GiacMethods_base_plot, sizeof(__pyx_k_GiacMethods_base_plot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plot3d, __pyx_k_GiacMethods_base_plot3d, sizeof(__pyx_k_GiacMethods_base_plot3d), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotarea, __pyx_k_GiacMethods_base_plotarea, sizeof(__pyx_k_GiacMethods_base_plotarea), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotcdf, __pyx_k_GiacMethods_base_plotcdf, sizeof(__pyx_k_GiacMethods_base_plotcdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotcontour, __pyx_k_GiacMethods_base_plotcontour, sizeof(__pyx_k_GiacMethods_base_plotcontour), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotdensity, __pyx_k_GiacMethods_base_plotdensity, sizeof(__pyx_k_GiacMethods_base_plotdensity), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotfield, __pyx_k_GiacMethods_base_plotfield, sizeof(__pyx_k_GiacMethods_base_plotfield), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotfunc, __pyx_k_GiacMethods_base_plotfunc, sizeof(__pyx_k_GiacMethods_base_plotfunc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotimf, __pyx_k_GiacMethods_base_plotimf, sizeof(__pyx_k_GiacMethods_base_plotimf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotimplicit, __pyx_k_GiacMethods_base_plotimplicit, sizeof(__pyx_k_GiacMethods_base_plotimplicit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotinequation, __pyx_k_GiacMethods_base_plotinequation, sizeof(__pyx_k_GiacMethods_base_plotinequation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotlist, __pyx_k_GiacMethods_base_plotlist, sizeof(__pyx_k_GiacMethods_base_plotlist), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotode, __pyx_k_GiacMethods_base_plotode, sizeof(__pyx_k_GiacMethods_base_plotode), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotparam, __pyx_k_GiacMethods_base_plotparam, sizeof(__pyx_k_GiacMethods_base_plotparam), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotpolar, __pyx_k_GiacMethods_base_plotpolar, sizeof(__pyx_k_GiacMethods_base_plotpolar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotproba, __pyx_k_GiacMethods_base_plotproba, sizeof(__pyx_k_GiacMethods_base_plotproba), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotseq, __pyx_k_GiacMethods_base_plotseq, sizeof(__pyx_k_GiacMethods_base_plotseq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotspectrum, __pyx_k_GiacMethods_base_plotspectrum, sizeof(__pyx_k_GiacMethods_base_plotspectrum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plotwav, __pyx_k_GiacMethods_base_plotwav, sizeof(__pyx_k_GiacMethods_base_plotwav), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_plus_point, __pyx_k_GiacMethods_base_plus_point, sizeof(__pyx_k_GiacMethods_base_plus_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pmin, __pyx_k_GiacMethods_base_pmin, sizeof(__pyx_k_GiacMethods_base_pmin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_point, __pyx_k_GiacMethods_base_point, sizeof(__pyx_k_GiacMethods_base_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_point2d, __pyx_k_GiacMethods_base_point2d, sizeof(__pyx_k_GiacMethods_base_point2d), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_point3d, __pyx_k_GiacMethods_base_point3d, sizeof(__pyx_k_GiacMethods_base_point3d), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_poisson, __pyx_k_GiacMethods_base_poisson, sizeof(__pyx_k_GiacMethods_base_poisson), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_poisson_cdf, __pyx_k_GiacMethods_base_poisson_cdf, sizeof(__pyx_k_GiacMethods_base_poisson_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_poisson_icdf, __pyx_k_GiacMethods_base_poisson_icdf, sizeof(__pyx_k_GiacMethods_base_poisson_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_poisson_window, __pyx_k_GiacMethods_base_poisson_window, sizeof(__pyx_k_GiacMethods_base_poisson_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polar, __pyx_k_GiacMethods_base_polar, sizeof(__pyx_k_GiacMethods_base_polar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polar_coordinat, __pyx_k_GiacMethods_base_polar_coordinat, sizeof(__pyx_k_GiacMethods_base_polar_coordinat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polar_point, __pyx_k_GiacMethods_base_polar_point, sizeof(__pyx_k_GiacMethods_base_polar_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polarplot, __pyx_k_GiacMethods_base_polarplot, sizeof(__pyx_k_GiacMethods_base_polarplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pole, __pyx_k_GiacMethods_base_pole, sizeof(__pyx_k_GiacMethods_base_pole), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_poly2symb, __pyx_k_GiacMethods_base_poly2symb, sizeof(__pyx_k_GiacMethods_base_poly2symb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polyEval, __pyx_k_GiacMethods_base_polyEval, sizeof(__pyx_k_GiacMethods_base_polyEval), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polygon, __pyx_k_GiacMethods_base_polygon, sizeof(__pyx_k_GiacMethods_base_polygon), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polygone_rempli, __pyx_k_GiacMethods_base_polygone_rempli, sizeof(__pyx_k_GiacMethods_base_polygone_rempli), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polygonplot, __pyx_k_GiacMethods_base_polygonplot, sizeof(__pyx_k_GiacMethods_base_polygonplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polygonscatterp, __pyx_k_GiacMethods_base_polygonscatterp, sizeof(__pyx_k_GiacMethods_base_polygonscatterp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polyhedron, __pyx_k_GiacMethods_base_polyhedron, sizeof(__pyx_k_GiacMethods_base_polyhedron), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polynom, __pyx_k_GiacMethods_base_polynom, sizeof(__pyx_k_GiacMethods_base_polynom), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polynomial_regr, __pyx_k_GiacMethods_base_polynomial_regr, sizeof(__pyx_k_GiacMethods_base_polynomial_regr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_polynomial_regr_2, __pyx_k_GiacMethods_base_polynomial_regr_2, sizeof(__pyx_k_GiacMethods_base_polynomial_regr_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_position, __pyx_k_GiacMethods_base_position, sizeof(__pyx_k_GiacMethods_base_position), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_poslbdLMQ, __pyx_k_GiacMethods_base_poslbdLMQ, sizeof(__pyx_k_GiacMethods_base_poslbdLMQ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_posubLMQ, __pyx_k_GiacMethods_base_posubLMQ, sizeof(__pyx_k_GiacMethods_base_posubLMQ), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_potential, __pyx_k_GiacMethods_base_potential, sizeof(__pyx_k_GiacMethods_base_potential), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pow2exp, __pyx_k_GiacMethods_base_pow2exp, sizeof(__pyx_k_GiacMethods_base_pow2exp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_power_regressio, __pyx_k_GiacMethods_base_power_regressio, sizeof(__pyx_k_GiacMethods_base_power_regressio), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_power_regressio_2, __pyx_k_GiacMethods_base_power_regressio_2, sizeof(__pyx_k_GiacMethods_base_power_regressio_2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_powermod, __pyx_k_GiacMethods_base_powermod, sizeof(__pyx_k_GiacMethods_base_powermod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_powerpc, __pyx_k_GiacMethods_base_powerpc, sizeof(__pyx_k_GiacMethods_base_powerpc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_powexpand, __pyx_k_GiacMethods_base_powexpand, sizeof(__pyx_k_GiacMethods_base_powexpand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_powmod, __pyx_k_GiacMethods_base_powmod, sizeof(__pyx_k_GiacMethods_base_powmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_prepend, __pyx_k_GiacMethods_base_prepend, sizeof(__pyx_k_GiacMethods_base_prepend), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_preval, __pyx_k_GiacMethods_base_preval, sizeof(__pyx_k_GiacMethods_base_preval), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_prevperm, __pyx_k_GiacMethods_base_prevperm, sizeof(__pyx_k_GiacMethods_base_prevperm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_prevprime, __pyx_k_GiacMethods_base_prevprime, sizeof(__pyx_k_GiacMethods_base_prevprime), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_primpart, __pyx_k_GiacMethods_base_primpart, sizeof(__pyx_k_GiacMethods_base_primpart), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_printf, __pyx_k_GiacMethods_base_printf, sizeof(__pyx_k_GiacMethods_base_printf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_prism, __pyx_k_GiacMethods_base_prism, sizeof(__pyx_k_GiacMethods_base_prism), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_prism_graph, __pyx_k_GiacMethods_base_prism_graph, sizeof(__pyx_k_GiacMethods_base_prism_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_product, __pyx_k_GiacMethods_base_product, sizeof(__pyx_k_GiacMethods_base_product), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_projection, __pyx_k_GiacMethods_base_projection, sizeof(__pyx_k_GiacMethods_base_projection), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_proot, __pyx_k_GiacMethods_base_proot, sizeof(__pyx_k_GiacMethods_base_proot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_propFrac, __pyx_k_GiacMethods_base_propFrac, sizeof(__pyx_k_GiacMethods_base_propFrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_propfrac, __pyx_k_GiacMethods_base_propfrac, sizeof(__pyx_k_GiacMethods_base_propfrac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pruefer_code, __pyx_k_GiacMethods_base_pruefer_code, sizeof(__pyx_k_GiacMethods_base_pruefer_code), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_psrgcd, __pyx_k_GiacMethods_base_psrgcd, sizeof(__pyx_k_GiacMethods_base_psrgcd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ptayl, __pyx_k_GiacMethods_base_ptayl, sizeof(__pyx_k_GiacMethods_base_ptayl), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_purge, __pyx_k_GiacMethods_base_purge, sizeof(__pyx_k_GiacMethods_base_purge), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_purple, __pyx_k_GiacMethods_base_purple, sizeof(__pyx_k_GiacMethods_base_purple), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pwd, __pyx_k_GiacMethods_base_pwd, sizeof(__pyx_k_GiacMethods_base_pwd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_pyramid, __pyx_k_GiacMethods_base_pyramid, sizeof(__pyx_k_GiacMethods_base_pyramid), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_python_compat, __pyx_k_GiacMethods_base_python_compat, sizeof(__pyx_k_GiacMethods_base_python_compat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_q2a, __pyx_k_GiacMethods_base_q2a, sizeof(__pyx_k_GiacMethods_base_q2a), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_qr, __pyx_k_GiacMethods_base_qr, sizeof(__pyx_k_GiacMethods_base_qr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quadric, __pyx_k_GiacMethods_base_quadric, sizeof(__pyx_k_GiacMethods_base_quadric), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quadrilateral, __pyx_k_GiacMethods_base_quadrilateral, sizeof(__pyx_k_GiacMethods_base_quadrilateral), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quantile, __pyx_k_GiacMethods_base_quantile, sizeof(__pyx_k_GiacMethods_base_quantile), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quartile1, __pyx_k_GiacMethods_base_quartile1, sizeof(__pyx_k_GiacMethods_base_quartile1), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quartile3, __pyx_k_GiacMethods_base_quartile3, sizeof(__pyx_k_GiacMethods_base_quartile3), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quartiles, __pyx_k_GiacMethods_base_quartiles, sizeof(__pyx_k_GiacMethods_base_quartiles), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quest, __pyx_k_GiacMethods_base_quest, sizeof(__pyx_k_GiacMethods_base_quest), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quo, __pyx_k_GiacMethods_base_quo, sizeof(__pyx_k_GiacMethods_base_quo), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quorem, __pyx_k_GiacMethods_base_quorem, sizeof(__pyx_k_GiacMethods_base_quorem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_quote, __pyx_k_GiacMethods_base_quote, sizeof(__pyx_k_GiacMethods_base_quote), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_r2e, __pyx_k_GiacMethods_base_r2e, sizeof(__pyx_k_GiacMethods_base_r2e), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_radians, __pyx_k_GiacMethods_base_radians, sizeof(__pyx_k_GiacMethods_base_radians), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_radical_axis, __pyx_k_GiacMethods_base_radical_axis, sizeof(__pyx_k_GiacMethods_base_radical_axis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_radius, __pyx_k_GiacMethods_base_radius, sizeof(__pyx_k_GiacMethods_base_radius), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ramene, __pyx_k_GiacMethods_base_ramene, sizeof(__pyx_k_GiacMethods_base_ramene), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rand, __pyx_k_GiacMethods_base_rand, sizeof(__pyx_k_GiacMethods_base_rand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randMat, __pyx_k_GiacMethods_base_randMat, sizeof(__pyx_k_GiacMethods_base_randMat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randNorm, __pyx_k_GiacMethods_base_randNorm, sizeof(__pyx_k_GiacMethods_base_randNorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randPoly, __pyx_k_GiacMethods_base_randPoly, sizeof(__pyx_k_GiacMethods_base_randPoly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randbetad, __pyx_k_GiacMethods_base_randbetad, sizeof(__pyx_k_GiacMethods_base_randbetad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randbinomial, __pyx_k_GiacMethods_base_randbinomial, sizeof(__pyx_k_GiacMethods_base_randbinomial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randchisquare, __pyx_k_GiacMethods_base_randchisquare, sizeof(__pyx_k_GiacMethods_base_randchisquare), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randexp, __pyx_k_GiacMethods_base_randexp, sizeof(__pyx_k_GiacMethods_base_randexp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randfisher, __pyx_k_GiacMethods_base_randfisher, sizeof(__pyx_k_GiacMethods_base_randfisher), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randgammad, __pyx_k_GiacMethods_base_randgammad, sizeof(__pyx_k_GiacMethods_base_randgammad), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randgeometric, __pyx_k_GiacMethods_base_randgeometric, sizeof(__pyx_k_GiacMethods_base_randgeometric), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randint, __pyx_k_GiacMethods_base_randint, sizeof(__pyx_k_GiacMethods_base_randint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randmarkov, __pyx_k_GiacMethods_base_randmarkov, sizeof(__pyx_k_GiacMethods_base_randmarkov), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randmatrix, __pyx_k_GiacMethods_base_randmatrix, sizeof(__pyx_k_GiacMethods_base_randmatrix), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randmultinomial, __pyx_k_GiacMethods_base_randmultinomial, sizeof(__pyx_k_GiacMethods_base_randmultinomial), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randnorm, __pyx_k_GiacMethods_base_randnorm, sizeof(__pyx_k_GiacMethods_base_randnorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random, __pyx_k_GiacMethods_base_random, sizeof(__pyx_k_GiacMethods_base_random), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_bipartit, __pyx_k_GiacMethods_base_random_bipartit, sizeof(__pyx_k_GiacMethods_base_random_bipartit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_digraph, __pyx_k_GiacMethods_base_random_digraph, sizeof(__pyx_k_GiacMethods_base_random_digraph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_graph, __pyx_k_GiacMethods_base_random_graph, sizeof(__pyx_k_GiacMethods_base_random_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_network, __pyx_k_GiacMethods_base_random_network, sizeof(__pyx_k_GiacMethods_base_random_network), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_planar_g, __pyx_k_GiacMethods_base_random_planar_g, sizeof(__pyx_k_GiacMethods_base_random_planar_g), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_regular, __pyx_k_GiacMethods_base_random_regular, sizeof(__pyx_k_GiacMethods_base_random_regular), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_sequence, __pyx_k_GiacMethods_base_random_sequence, sizeof(__pyx_k_GiacMethods_base_random_sequence), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_tourname, __pyx_k_GiacMethods_base_random_tourname, sizeof(__pyx_k_GiacMethods_base_random_tourname), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_tree, __pyx_k_GiacMethods_base_random_tree, sizeof(__pyx_k_GiacMethods_base_random_tree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_random_variable, __pyx_k_GiacMethods_base_random_variable, sizeof(__pyx_k_GiacMethods_base_random_variable), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randperm, __pyx_k_GiacMethods_base_randperm, sizeof(__pyx_k_GiacMethods_base_randperm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randpoisson, __pyx_k_GiacMethods_base_randpoisson, sizeof(__pyx_k_GiacMethods_base_randpoisson), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randpoly, __pyx_k_GiacMethods_base_randpoly, sizeof(__pyx_k_GiacMethods_base_randpoly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randseed, __pyx_k_GiacMethods_base_randseed, sizeof(__pyx_k_GiacMethods_base_randseed), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randstudent, __pyx_k_GiacMethods_base_randstudent, sizeof(__pyx_k_GiacMethods_base_randstudent), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randvar, __pyx_k_GiacMethods_base_randvar, sizeof(__pyx_k_GiacMethods_base_randvar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randvector, __pyx_k_GiacMethods_base_randvector, sizeof(__pyx_k_GiacMethods_base_randvector), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_randweibulld, __pyx_k_GiacMethods_base_randweibulld, sizeof(__pyx_k_GiacMethods_base_randweibulld), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rank, __pyx_k_GiacMethods_base_rank, sizeof(__pyx_k_GiacMethods_base_rank), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ranm, __pyx_k_GiacMethods_base_ranm, sizeof(__pyx_k_GiacMethods_base_ranm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ranv, __pyx_k_GiacMethods_base_ranv, sizeof(__pyx_k_GiacMethods_base_ranv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rassembler_trig, __pyx_k_GiacMethods_base_rassembler_trig, sizeof(__pyx_k_GiacMethods_base_rassembler_trig), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rat_jordan, __pyx_k_GiacMethods_base_rat_jordan, sizeof(__pyx_k_GiacMethods_base_rat_jordan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ratinterp, __pyx_k_GiacMethods_base_ratinterp, sizeof(__pyx_k_GiacMethods_base_ratinterp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rational, __pyx_k_GiacMethods_base_rational, sizeof(__pyx_k_GiacMethods_base_rational), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rationalroot, __pyx_k_GiacMethods_base_rationalroot, sizeof(__pyx_k_GiacMethods_base_rationalroot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ratnormal, __pyx_k_GiacMethods_base_ratnormal, sizeof(__pyx_k_GiacMethods_base_ratnormal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rdiv, __pyx_k_GiacMethods_base_rdiv, sizeof(__pyx_k_GiacMethods_base_rdiv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_re, __pyx_k_GiacMethods_base_re, sizeof(__pyx_k_GiacMethods_base_re), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reachable, __pyx_k_GiacMethods_base_reachable, sizeof(__pyx_k_GiacMethods_base_reachable), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_read, __pyx_k_GiacMethods_base_read, sizeof(__pyx_k_GiacMethods_base_read), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_readrgb, __pyx_k_GiacMethods_base_readrgb, sizeof(__pyx_k_GiacMethods_base_readrgb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_readwav, __pyx_k_GiacMethods_base_readwav, sizeof(__pyx_k_GiacMethods_base_readwav), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_real, __pyx_k_GiacMethods_base_real, sizeof(__pyx_k_GiacMethods_base_real), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_realroot, __pyx_k_GiacMethods_base_realroot, sizeof(__pyx_k_GiacMethods_base_realroot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reciprocation, __pyx_k_GiacMethods_base_reciprocation, sizeof(__pyx_k_GiacMethods_base_reciprocation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rect, __pyx_k_GiacMethods_base_rect, sizeof(__pyx_k_GiacMethods_base_rect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rectangle, __pyx_k_GiacMethods_base_rectangle, sizeof(__pyx_k_GiacMethods_base_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rectangle_droit, __pyx_k_GiacMethods_base_rectangle_droit, sizeof(__pyx_k_GiacMethods_base_rectangle_droit), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rectangle_gauch, __pyx_k_GiacMethods_base_rectangle_gauch, sizeof(__pyx_k_GiacMethods_base_rectangle_gauch), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rectangle_plein, __pyx_k_GiacMethods_base_rectangle_plein, sizeof(__pyx_k_GiacMethods_base_rectangle_plein), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rectangular_coo, __pyx_k_GiacMethods_base_rectangular_coo, sizeof(__pyx_k_GiacMethods_base_rectangular_coo), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_recule, __pyx_k_GiacMethods_base_recule, sizeof(__pyx_k_GiacMethods_base_recule), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_red, __pyx_k_GiacMethods_base_red, sizeof(__pyx_k_GiacMethods_base_red), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reduced_conic, __pyx_k_GiacMethods_base_reduced_conic, sizeof(__pyx_k_GiacMethods_base_reduced_conic), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reduced_quadric, __pyx_k_GiacMethods_base_reduced_quadric, sizeof(__pyx_k_GiacMethods_base_reduced_quadric), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ref, __pyx_k_GiacMethods_base_ref, sizeof(__pyx_k_GiacMethods_base_ref), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reflection, __pyx_k_GiacMethods_base_reflection, sizeof(__pyx_k_GiacMethods_base_reflection), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_regroup, __pyx_k_GiacMethods_base_regroup, sizeof(__pyx_k_GiacMethods_base_regroup), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_relabel_vertice, __pyx_k_GiacMethods_base_relabel_vertice, sizeof(__pyx_k_GiacMethods_base_relabel_vertice), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reliability_pol, __pyx_k_GiacMethods_base_reliability_pol, sizeof(__pyx_k_GiacMethods_base_reliability_pol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rem, __pyx_k_GiacMethods_base_rem, sizeof(__pyx_k_GiacMethods_base_rem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_remain, __pyx_k_GiacMethods_base_remain, sizeof(__pyx_k_GiacMethods_base_remain), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_remove, __pyx_k_GiacMethods_base_remove, sizeof(__pyx_k_GiacMethods_base_remove), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reorder, __pyx_k_GiacMethods_base_reorder, sizeof(__pyx_k_GiacMethods_base_reorder), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_resample, __pyx_k_GiacMethods_base_resample, sizeof(__pyx_k_GiacMethods_base_resample), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_residue, __pyx_k_GiacMethods_base_residue, sizeof(__pyx_k_GiacMethods_base_residue), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_resoudre, __pyx_k_GiacMethods_base_resoudre, sizeof(__pyx_k_GiacMethods_base_resoudre), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_resoudre_dans_C, __pyx_k_GiacMethods_base_resoudre_dans_C, sizeof(__pyx_k_GiacMethods_base_resoudre_dans_C), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_resoudre_system, __pyx_k_GiacMethods_base_resoudre_system, sizeof(__pyx_k_GiacMethods_base_resoudre_system), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_resultant, __pyx_k_GiacMethods_base_resultant, sizeof(__pyx_k_GiacMethods_base_resultant), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reverse, __pyx_k_GiacMethods_base_reverse, sizeof(__pyx_k_GiacMethods_base_reverse), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reverse_graph, __pyx_k_GiacMethods_base_reverse_graph, sizeof(__pyx_k_GiacMethods_base_reverse_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_reverse_rsolve, __pyx_k_GiacMethods_base_reverse_rsolve, sizeof(__pyx_k_GiacMethods_base_reverse_rsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_revert, __pyx_k_GiacMethods_base_revert, sizeof(__pyx_k_GiacMethods_base_revert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_revlex, __pyx_k_GiacMethods_base_revlex, sizeof(__pyx_k_GiacMethods_base_revlex), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_revlist, __pyx_k_GiacMethods_base_revlist, sizeof(__pyx_k_GiacMethods_base_revlist), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rgb, __pyx_k_GiacMethods_base_rgb, sizeof(__pyx_k_GiacMethods_base_rgb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rgb2hsv, __pyx_k_GiacMethods_base_rgb2hsv, sizeof(__pyx_k_GiacMethods_base_rgb2hsv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rgb2xyz, __pyx_k_GiacMethods_base_rgb2xyz, sizeof(__pyx_k_GiacMethods_base_rgb2xyz), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rhombus, __pyx_k_GiacMethods_base_rhombus, sizeof(__pyx_k_GiacMethods_base_rhombus), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rhombus_point, __pyx_k_GiacMethods_base_rhombus_point, sizeof(__pyx_k_GiacMethods_base_rhombus_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rhs, __pyx_k_GiacMethods_base_rhs, sizeof(__pyx_k_GiacMethods_base_rhs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_riemann_window, __pyx_k_GiacMethods_base_riemann_window, sizeof(__pyx_k_GiacMethods_base_riemann_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_right, __pyx_k_GiacMethods_base_right, sizeof(__pyx_k_GiacMethods_base_right), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_right_rectangle, __pyx_k_GiacMethods_base_right_rectangle, sizeof(__pyx_k_GiacMethods_base_right_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_right_triangle, __pyx_k_GiacMethods_base_right_triangle, sizeof(__pyx_k_GiacMethods_base_right_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_risch, __pyx_k_GiacMethods_base_risch, sizeof(__pyx_k_GiacMethods_base_risch), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rm_a_z, __pyx_k_GiacMethods_base_rm_a_z, sizeof(__pyx_k_GiacMethods_base_rm_a_z), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rm_all_vars, __pyx_k_GiacMethods_base_rm_all_vars, sizeof(__pyx_k_GiacMethods_base_rm_all_vars), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rmbreakpoint, __pyx_k_GiacMethods_base_rmbreakpoint, sizeof(__pyx_k_GiacMethods_base_rmbreakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rmmod, __pyx_k_GiacMethods_base_rmmod, sizeof(__pyx_k_GiacMethods_base_rmmod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rms, __pyx_k_GiacMethods_base_rms, sizeof(__pyx_k_GiacMethods_base_rms), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rmwatch, __pyx_k_GiacMethods_base_rmwatch, sizeof(__pyx_k_GiacMethods_base_rmwatch), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_romberg, __pyx_k_GiacMethods_base_romberg, sizeof(__pyx_k_GiacMethods_base_romberg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rombergm, __pyx_k_GiacMethods_base_rombergm, sizeof(__pyx_k_GiacMethods_base_rombergm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rombergt, __pyx_k_GiacMethods_base_rombergt, sizeof(__pyx_k_GiacMethods_base_rombergt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rond, __pyx_k_GiacMethods_base_rond, sizeof(__pyx_k_GiacMethods_base_rond), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_root, __pyx_k_GiacMethods_base_root, sizeof(__pyx_k_GiacMethods_base_root), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rootof, __pyx_k_GiacMethods_base_rootof, sizeof(__pyx_k_GiacMethods_base_rootof), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_roots, __pyx_k_GiacMethods_base_roots, sizeof(__pyx_k_GiacMethods_base_roots), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rotate, __pyx_k_GiacMethods_base_rotate, sizeof(__pyx_k_GiacMethods_base_rotate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rotation, __pyx_k_GiacMethods_base_rotation, sizeof(__pyx_k_GiacMethods_base_rotation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_round, __pyx_k_GiacMethods_base_round, sizeof(__pyx_k_GiacMethods_base_round), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_row, __pyx_k_GiacMethods_base_row, sizeof(__pyx_k_GiacMethods_base_row), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowAdd, __pyx_k_GiacMethods_base_rowAdd, sizeof(__pyx_k_GiacMethods_base_rowAdd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowDim, __pyx_k_GiacMethods_base_rowDim, sizeof(__pyx_k_GiacMethods_base_rowDim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowNorm, __pyx_k_GiacMethods_base_rowNorm, sizeof(__pyx_k_GiacMethods_base_rowNorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowSwap, __pyx_k_GiacMethods_base_rowSwap, sizeof(__pyx_k_GiacMethods_base_rowSwap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowdim, __pyx_k_GiacMethods_base_rowdim, sizeof(__pyx_k_GiacMethods_base_rowdim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rownorm, __pyx_k_GiacMethods_base_rownorm, sizeof(__pyx_k_GiacMethods_base_rownorm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowspace, __pyx_k_GiacMethods_base_rowspace, sizeof(__pyx_k_GiacMethods_base_rowspace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rowswap, __pyx_k_GiacMethods_base_rowswap, sizeof(__pyx_k_GiacMethods_base_rowswap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rref, __pyx_k_GiacMethods_base_rref, sizeof(__pyx_k_GiacMethods_base_rref), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rsolve, __pyx_k_GiacMethods_base_rsolve, sizeof(__pyx_k_GiacMethods_base_rsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rur, __pyx_k_GiacMethods_base_rur, sizeof(__pyx_k_GiacMethods_base_rur), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rur_certify, __pyx_k_GiacMethods_base_rur_certify, sizeof(__pyx_k_GiacMethods_base_rur_certify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_rur_gbasis, __pyx_k_GiacMethods_base_rur_gbasis, sizeof(__pyx_k_GiacMethods_base_rur_gbasis), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_same, __pyx_k_GiacMethods_base_same, sizeof(__pyx_k_GiacMethods_base_same), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sample, __pyx_k_GiacMethods_base_sample, sizeof(__pyx_k_GiacMethods_base_sample), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_samplerate, __pyx_k_GiacMethods_base_samplerate, sizeof(__pyx_k_GiacMethods_base_samplerate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sans_factoriser, __pyx_k_GiacMethods_base_sans_factoriser, sizeof(__pyx_k_GiacMethods_base_sans_factoriser), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_saute, __pyx_k_GiacMethods_base_saute, sizeof(__pyx_k_GiacMethods_base_saute), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_scalarProduct, __pyx_k_GiacMethods_base_scalarProduct, sizeof(__pyx_k_GiacMethods_base_scalarProduct), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_scalar_product, __pyx_k_GiacMethods_base_scalar_product, sizeof(__pyx_k_GiacMethods_base_scalar_product), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_scatterplot, __pyx_k_GiacMethods_base_scatterplot, sizeof(__pyx_k_GiacMethods_base_scatterplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_schur, __pyx_k_GiacMethods_base_schur, sizeof(__pyx_k_GiacMethods_base_schur), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sec, __pyx_k_GiacMethods_base_sec, sizeof(__pyx_k_GiacMethods_base_sec), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_secant_solver, __pyx_k_GiacMethods_base_secant_solver, sizeof(__pyx_k_GiacMethods_base_secant_solver), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_segment, __pyx_k_GiacMethods_base_segment, sizeof(__pyx_k_GiacMethods_base_segment), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_seidel_spectrum, __pyx_k_GiacMethods_base_seidel_spectrum, sizeof(__pyx_k_GiacMethods_base_seidel_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_seidel_switch, __pyx_k_GiacMethods_base_seidel_switch, sizeof(__pyx_k_GiacMethods_base_seidel_switch), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_select, __pyx_k_GiacMethods_base_select, sizeof(__pyx_k_GiacMethods_base_select), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_semi_augment, __pyx_k_GiacMethods_base_semi_augment, sizeof(__pyx_k_GiacMethods_base_semi_augment), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_seq, __pyx_k_GiacMethods_base_seq, sizeof(__pyx_k_GiacMethods_base_seq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_seqplot, __pyx_k_GiacMethods_base_seqplot, sizeof(__pyx_k_GiacMethods_base_seqplot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_seqsolve, __pyx_k_GiacMethods_base_seqsolve, sizeof(__pyx_k_GiacMethods_base_seqsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sequence_graph, __pyx_k_GiacMethods_base_sequence_graph, sizeof(__pyx_k_GiacMethods_base_sequence_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_series, __pyx_k_GiacMethods_base_series, sizeof(__pyx_k_GiacMethods_base_series), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_channel_dat, __pyx_k_GiacMethods_base_set_channel_dat, sizeof(__pyx_k_GiacMethods_base_set_channel_dat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_edge_attrib, __pyx_k_GiacMethods_base_set_edge_attrib, sizeof(__pyx_k_GiacMethods_base_set_edge_attrib), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_edge_weight, __pyx_k_GiacMethods_base_set_edge_weight, sizeof(__pyx_k_GiacMethods_base_set_edge_weight), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_graph_attri, __pyx_k_GiacMethods_base_set_graph_attri, sizeof(__pyx_k_GiacMethods_base_set_graph_attri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_pixel, __pyx_k_GiacMethods_base_set_pixel, sizeof(__pyx_k_GiacMethods_base_set_pixel), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_screen, __pyx_k_GiacMethods_base_set_screen, sizeof(__pyx_k_GiacMethods_base_set_screen), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_vertex_attr, __pyx_k_GiacMethods_base_set_vertex_attr, sizeof(__pyx_k_GiacMethods_base_set_vertex_attr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_set_vertex_posi, __pyx_k_GiacMethods_base_set_vertex_posi, sizeof(__pyx_k_GiacMethods_base_set_vertex_posi), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_shift, __pyx_k_GiacMethods_base_shift, sizeof(__pyx_k_GiacMethods_base_shift), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_shift_phase, __pyx_k_GiacMethods_base_shift_phase, sizeof(__pyx_k_GiacMethods_base_shift_phase), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_shortest_path, __pyx_k_GiacMethods_base_shortest_path, sizeof(__pyx_k_GiacMethods_base_shortest_path), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_show_pixels, __pyx_k_GiacMethods_base_show_pixels, sizeof(__pyx_k_GiacMethods_base_show_pixels), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_shuffle, __pyx_k_GiacMethods_base_shuffle, sizeof(__pyx_k_GiacMethods_base_shuffle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sierpinski_grap, __pyx_k_GiacMethods_base_sierpinski_grap, sizeof(__pyx_k_GiacMethods_base_sierpinski_grap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sign, __pyx_k_GiacMethods_base_sign, sizeof(__pyx_k_GiacMethods_base_sign), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sign2Heaviside, __pyx_k_GiacMethods_base_sign2Heaviside, sizeof(__pyx_k_GiacMethods_base_sign2Heaviside), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_signature, __pyx_k_GiacMethods_base_signature, sizeof(__pyx_k_GiacMethods_base_signature), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_signe, __pyx_k_GiacMethods_base_signe, sizeof(__pyx_k_GiacMethods_base_signe), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_similarity, __pyx_k_GiacMethods_base_similarity, sizeof(__pyx_k_GiacMethods_base_similarity), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simp2, __pyx_k_GiacMethods_base_simp2, sizeof(__pyx_k_GiacMethods_base_simp2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simplex_reduce, __pyx_k_GiacMethods_base_simplex_reduce, sizeof(__pyx_k_GiacMethods_base_simplex_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simplicial_vert, __pyx_k_GiacMethods_base_simplicial_vert, sizeof(__pyx_k_GiacMethods_base_simplicial_vert), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simplifier, __pyx_k_GiacMethods_base_simplifier, sizeof(__pyx_k_GiacMethods_base_simplifier), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simplify, __pyx_k_GiacMethods_base_simplify, sizeof(__pyx_k_GiacMethods_base_simplify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simplifyDirac, __pyx_k_GiacMethods_base_simplifyDirac, sizeof(__pyx_k_GiacMethods_base_simplifyDirac), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simpson, __pyx_k_GiacMethods_base_simpson, sizeof(__pyx_k_GiacMethods_base_simpson), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simulated_annea, __pyx_k_GiacMethods_base_simulated_annea, sizeof(__pyx_k_GiacMethods_base_simulated_annea), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_simult, __pyx_k_GiacMethods_base_simult, sizeof(__pyx_k_GiacMethods_base_simult), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sin, __pyx_k_GiacMethods_base_sin, sizeof(__pyx_k_GiacMethods_base_sin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sin2costan, __pyx_k_GiacMethods_base_sin2costan, sizeof(__pyx_k_GiacMethods_base_sin2costan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sinc, __pyx_k_GiacMethods_base_sinc, sizeof(__pyx_k_GiacMethods_base_sinc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sincos, __pyx_k_GiacMethods_base_sincos, sizeof(__pyx_k_GiacMethods_base_sincos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_single_inter, __pyx_k_GiacMethods_base_single_inter, sizeof(__pyx_k_GiacMethods_base_single_inter), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sinh, __pyx_k_GiacMethods_base_sinh, sizeof(__pyx_k_GiacMethods_base_sinh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sizes, __pyx_k_GiacMethods_base_sizes, sizeof(__pyx_k_GiacMethods_base_sizes), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_slope, __pyx_k_GiacMethods_base_slope, sizeof(__pyx_k_GiacMethods_base_slope), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_slopeat, __pyx_k_GiacMethods_base_slopeat, sizeof(__pyx_k_GiacMethods_base_slopeat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_slopeatraw, __pyx_k_GiacMethods_base_slopeatraw, sizeof(__pyx_k_GiacMethods_base_slopeatraw), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_smith, __pyx_k_GiacMethods_base_smith, sizeof(__pyx_k_GiacMethods_base_smith), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_smod, __pyx_k_GiacMethods_base_smod, sizeof(__pyx_k_GiacMethods_base_smod), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_snedecor, __pyx_k_GiacMethods_base_snedecor, sizeof(__pyx_k_GiacMethods_base_snedecor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_snedecor_cdf, __pyx_k_GiacMethods_base_snedecor_cdf, sizeof(__pyx_k_GiacMethods_base_snedecor_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_snedecor_icdf, __pyx_k_GiacMethods_base_snedecor_icdf, sizeof(__pyx_k_GiacMethods_base_snedecor_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_snedecord, __pyx_k_GiacMethods_base_snedecord, sizeof(__pyx_k_GiacMethods_base_snedecord), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_snedecord_cdf, __pyx_k_GiacMethods_base_snedecord_cdf, sizeof(__pyx_k_GiacMethods_base_snedecord_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_snedecord_icdf, __pyx_k_GiacMethods_base_snedecord_icdf, sizeof(__pyx_k_GiacMethods_base_snedecord_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_solid_line, __pyx_k_GiacMethods_base_solid_line, sizeof(__pyx_k_GiacMethods_base_solid_line), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_solve, __pyx_k_GiacMethods_base_solve, sizeof(__pyx_k_GiacMethods_base_solve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_somme, __pyx_k_GiacMethods_base_somme, sizeof(__pyx_k_GiacMethods_base_somme), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sommet, __pyx_k_GiacMethods_base_sommet, sizeof(__pyx_k_GiacMethods_base_sommet), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sort, __pyx_k_GiacMethods_base_sort, sizeof(__pyx_k_GiacMethods_base_sort), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sorta, __pyx_k_GiacMethods_base_sorta, sizeof(__pyx_k_GiacMethods_base_sorta), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sortd, __pyx_k_GiacMethods_base_sortd, sizeof(__pyx_k_GiacMethods_base_sortd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sorted, __pyx_k_GiacMethods_base_sorted, sizeof(__pyx_k_GiacMethods_base_sorted), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sortperm, __pyx_k_GiacMethods_base_sortperm, sizeof(__pyx_k_GiacMethods_base_sortperm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_soundsec, __pyx_k_GiacMethods_base_soundsec, sizeof(__pyx_k_GiacMethods_base_soundsec), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_spanning_tree, __pyx_k_GiacMethods_base_spanning_tree, sizeof(__pyx_k_GiacMethods_base_spanning_tree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sphere, __pyx_k_GiacMethods_base_sphere, sizeof(__pyx_k_GiacMethods_base_sphere), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_splice, __pyx_k_GiacMethods_base_splice, sizeof(__pyx_k_GiacMethods_base_splice), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_spline, __pyx_k_GiacMethods_base_spline, sizeof(__pyx_k_GiacMethods_base_spline), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_split, __pyx_k_GiacMethods_base_split, sizeof(__pyx_k_GiacMethods_base_split), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_spring, __pyx_k_GiacMethods_base_spring, sizeof(__pyx_k_GiacMethods_base_spring), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sq, __pyx_k_GiacMethods_base_sq, sizeof(__pyx_k_GiacMethods_base_sq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sqrfree, __pyx_k_GiacMethods_base_sqrfree, sizeof(__pyx_k_GiacMethods_base_sqrfree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sqrt, __pyx_k_GiacMethods_base_sqrt, sizeof(__pyx_k_GiacMethods_base_sqrt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_square, __pyx_k_GiacMethods_base_square, sizeof(__pyx_k_GiacMethods_base_square), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_square_point, __pyx_k_GiacMethods_base_square_point, sizeof(__pyx_k_GiacMethods_base_square_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_srand, __pyx_k_GiacMethods_base_srand, sizeof(__pyx_k_GiacMethods_base_srand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sst, __pyx_k_GiacMethods_base_sst, sizeof(__pyx_k_GiacMethods_base_sst), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sst_in, __pyx_k_GiacMethods_base_sst_in, sizeof(__pyx_k_GiacMethods_base_sst_in), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_st_ordering, __pyx_k_GiacMethods_base_st_ordering, sizeof(__pyx_k_GiacMethods_base_st_ordering), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_star_graph, __pyx_k_GiacMethods_base_star_graph, sizeof(__pyx_k_GiacMethods_base_star_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_star_point, __pyx_k_GiacMethods_base_star_point, sizeof(__pyx_k_GiacMethods_base_star_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_stdDev, __pyx_k_GiacMethods_base_stdDev, sizeof(__pyx_k_GiacMethods_base_stdDev), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_stddev, __pyx_k_GiacMethods_base_stddev, sizeof(__pyx_k_GiacMethods_base_stddev), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_stddevp, __pyx_k_GiacMethods_base_stddevp, sizeof(__pyx_k_GiacMethods_base_stddevp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_steffenson_solv, __pyx_k_GiacMethods_base_steffenson_solv, sizeof(__pyx_k_GiacMethods_base_steffenson_solv), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_stereo2mono, __pyx_k_GiacMethods_base_stereo2mono, sizeof(__pyx_k_GiacMethods_base_stereo2mono), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_stft, __pyx_k_GiacMethods_base_stft, sizeof(__pyx_k_GiacMethods_base_stft), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_str, __pyx_k_GiacMethods_base_str, sizeof(__pyx_k_GiacMethods_base_str), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_strip, __pyx_k_GiacMethods_base_strip, sizeof(__pyx_k_GiacMethods_base_strip), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_strongly_connec, __pyx_k_GiacMethods_base_strongly_connec, sizeof(__pyx_k_GiacMethods_base_strongly_connec), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_student, __pyx_k_GiacMethods_base_student, sizeof(__pyx_k_GiacMethods_base_student), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_student_cdf, __pyx_k_GiacMethods_base_student_cdf, sizeof(__pyx_k_GiacMethods_base_student_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_student_icdf, __pyx_k_GiacMethods_base_student_icdf, sizeof(__pyx_k_GiacMethods_base_student_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_studentd, __pyx_k_GiacMethods_base_studentd, sizeof(__pyx_k_GiacMethods_base_studentd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_studentt, __pyx_k_GiacMethods_base_studentt, sizeof(__pyx_k_GiacMethods_base_studentt), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sturm, __pyx_k_GiacMethods_base_sturm, sizeof(__pyx_k_GiacMethods_base_sturm), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sturmab, __pyx_k_GiacMethods_base_sturmab, sizeof(__pyx_k_GiacMethods_base_sturmab), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sturmseq, __pyx_k_GiacMethods_base_sturmseq, sizeof(__pyx_k_GiacMethods_base_sturmseq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_style, __pyx_k_GiacMethods_base_style, sizeof(__pyx_k_GiacMethods_base_style), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subMat, __pyx_k_GiacMethods_base_subMat, sizeof(__pyx_k_GiacMethods_base_subMat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subdivide_edges, __pyx_k_GiacMethods_base_subdivide_edges, sizeof(__pyx_k_GiacMethods_base_subdivide_edges), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subgraph, __pyx_k_GiacMethods_base_subgraph, sizeof(__pyx_k_GiacMethods_base_subgraph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subs, __pyx_k_GiacMethods_base_subs, sizeof(__pyx_k_GiacMethods_base_subs), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subsop, __pyx_k_GiacMethods_base_subsop, sizeof(__pyx_k_GiacMethods_base_subsop), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subst, __pyx_k_GiacMethods_base_subst, sizeof(__pyx_k_GiacMethods_base_subst), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_substituer, __pyx_k_GiacMethods_base_substituer, sizeof(__pyx_k_GiacMethods_base_substituer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_subtype, __pyx_k_GiacMethods_base_subtype, sizeof(__pyx_k_GiacMethods_base_subtype), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sum, __pyx_k_GiacMethods_base_sum, sizeof(__pyx_k_GiacMethods_base_sum), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sum_riemann, __pyx_k_GiacMethods_base_sum_riemann, sizeof(__pyx_k_GiacMethods_base_sum_riemann), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_suppress, __pyx_k_GiacMethods_base_suppress, sizeof(__pyx_k_GiacMethods_base_suppress), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_surd, __pyx_k_GiacMethods_base_surd, sizeof(__pyx_k_GiacMethods_base_surd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_svd, __pyx_k_GiacMethods_base_svd, sizeof(__pyx_k_GiacMethods_base_svd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_swapcol, __pyx_k_GiacMethods_base_swapcol, sizeof(__pyx_k_GiacMethods_base_swapcol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_swaprow, __pyx_k_GiacMethods_base_swaprow, sizeof(__pyx_k_GiacMethods_base_swaprow), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_switch_axes, __pyx_k_GiacMethods_base_switch_axes, sizeof(__pyx_k_GiacMethods_base_switch_axes), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_sylvester, __pyx_k_GiacMethods_base_sylvester, sizeof(__pyx_k_GiacMethods_base_sylvester), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_symb2poly, __pyx_k_GiacMethods_base_symb2poly, sizeof(__pyx_k_GiacMethods_base_symb2poly), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_symbol, __pyx_k_GiacMethods_base_symbol, sizeof(__pyx_k_GiacMethods_base_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_symbol_array, __pyx_k_GiacMethods_base_symbol_array, sizeof(__pyx_k_GiacMethods_base_symbol_array), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_syst2mat, __pyx_k_GiacMethods_base_syst2mat, sizeof(__pyx_k_GiacMethods_base_syst2mat), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tCollect, __pyx_k_GiacMethods_base_tCollect, sizeof(__pyx_k_GiacMethods_base_tCollect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tExpand, __pyx_k_GiacMethods_base_tExpand, sizeof(__pyx_k_GiacMethods_base_tExpand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_table, __pyx_k_GiacMethods_base_table, sizeof(__pyx_k_GiacMethods_base_table), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tablefunc, __pyx_k_GiacMethods_base_tablefunc, sizeof(__pyx_k_GiacMethods_base_tablefunc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tableseq, __pyx_k_GiacMethods_base_tableseq, sizeof(__pyx_k_GiacMethods_base_tableseq), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tabsign, __pyx_k_GiacMethods_base_tabsign, sizeof(__pyx_k_GiacMethods_base_tabsign), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tabvar, __pyx_k_GiacMethods_base_tabvar, sizeof(__pyx_k_GiacMethods_base_tabvar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tail, __pyx_k_GiacMethods_base_tail, sizeof(__pyx_k_GiacMethods_base_tail), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tan, __pyx_k_GiacMethods_base_tan, sizeof(__pyx_k_GiacMethods_base_tan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tan2cossin2, __pyx_k_GiacMethods_base_tan2cossin2, sizeof(__pyx_k_GiacMethods_base_tan2cossin2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tan2sincos, __pyx_k_GiacMethods_base_tan2sincos, sizeof(__pyx_k_GiacMethods_base_tan2sincos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tan2sincos2, __pyx_k_GiacMethods_base_tan2sincos2, sizeof(__pyx_k_GiacMethods_base_tan2sincos2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tangent, __pyx_k_GiacMethods_base_tangent, sizeof(__pyx_k_GiacMethods_base_tangent), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tangente, __pyx_k_GiacMethods_base_tangente, sizeof(__pyx_k_GiacMethods_base_tangente), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tanh, __pyx_k_GiacMethods_base_tanh, sizeof(__pyx_k_GiacMethods_base_tanh), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tar, __pyx_k_GiacMethods_base_tar, sizeof(__pyx_k_GiacMethods_base_tar), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_taux_accroissem, __pyx_k_GiacMethods_base_taux_accroissem, sizeof(__pyx_k_GiacMethods_base_taux_accroissem), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_taylor, __pyx_k_GiacMethods_base_taylor, sizeof(__pyx_k_GiacMethods_base_taylor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tchebyshev1, __pyx_k_GiacMethods_base_tchebyshev1, sizeof(__pyx_k_GiacMethods_base_tchebyshev1), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tchebyshev2, __pyx_k_GiacMethods_base_tchebyshev2, sizeof(__pyx_k_GiacMethods_base_tchebyshev2), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tcoeff, __pyx_k_GiacMethods_base_tcoeff, sizeof(__pyx_k_GiacMethods_base_tcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tcollect, __pyx_k_GiacMethods_base_tcollect, sizeof(__pyx_k_GiacMethods_base_tcollect), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tdeg, __pyx_k_GiacMethods_base_tdeg, sizeof(__pyx_k_GiacMethods_base_tdeg), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_teal, __pyx_k_GiacMethods_base_teal, sizeof(__pyx_k_GiacMethods_base_teal), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tensor_product, __pyx_k_GiacMethods_base_tensor_product, sizeof(__pyx_k_GiacMethods_base_tensor_product), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tetrahedron, __pyx_k_GiacMethods_base_tetrahedron, sizeof(__pyx_k_GiacMethods_base_tetrahedron), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_texpand, __pyx_k_GiacMethods_base_texpand, sizeof(__pyx_k_GiacMethods_base_texpand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_thickness, __pyx_k_GiacMethods_base_thickness, sizeof(__pyx_k_GiacMethods_base_thickness), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_threshold, __pyx_k_GiacMethods_base_threshold, sizeof(__pyx_k_GiacMethods_base_threshold), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_throw, __pyx_k_GiacMethods_base_throw, sizeof(__pyx_k_GiacMethods_base_throw), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_title, __pyx_k_GiacMethods_base_title, sizeof(__pyx_k_GiacMethods_base_title), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_titre, __pyx_k_GiacMethods_base_titre, sizeof(__pyx_k_GiacMethods_base_titre), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tlin, __pyx_k_GiacMethods_base_tlin, sizeof(__pyx_k_GiacMethods_base_tlin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tonnetz, __pyx_k_GiacMethods_base_tonnetz, sizeof(__pyx_k_GiacMethods_base_tonnetz), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_topologic_sort, __pyx_k_GiacMethods_base_topologic_sort, sizeof(__pyx_k_GiacMethods_base_topologic_sort), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_topological_sor, __pyx_k_GiacMethods_base_topological_sor, sizeof(__pyx_k_GiacMethods_base_topological_sor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_topology, __pyx_k_GiacMethods_base_topology, sizeof(__pyx_k_GiacMethods_base_topology), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_torus_grid_grap, __pyx_k_GiacMethods_base_torus_grid_grap, sizeof(__pyx_k_GiacMethods_base_torus_grid_grap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_total_degree, __pyx_k_GiacMethods_base_total_degree, sizeof(__pyx_k_GiacMethods_base_total_degree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tourne_droite, __pyx_k_GiacMethods_base_tourne_droite, sizeof(__pyx_k_GiacMethods_base_tourne_droite), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tourne_gauche, __pyx_k_GiacMethods_base_tourne_gauche, sizeof(__pyx_k_GiacMethods_base_tourne_gauche), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tpsolve, __pyx_k_GiacMethods_base_tpsolve, sizeof(__pyx_k_GiacMethods_base_tpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trace, __pyx_k_GiacMethods_base_trace, sizeof(__pyx_k_GiacMethods_base_trace), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trail, __pyx_k_GiacMethods_base_trail, sizeof(__pyx_k_GiacMethods_base_trail), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trail2edges, __pyx_k_GiacMethods_base_trail2edges, sizeof(__pyx_k_GiacMethods_base_trail2edges), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_train, __pyx_k_GiacMethods_base_train, sizeof(__pyx_k_GiacMethods_base_train), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trames, __pyx_k_GiacMethods_base_trames, sizeof(__pyx_k_GiacMethods_base_trames), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tran, __pyx_k_GiacMethods_base_tran, sizeof(__pyx_k_GiacMethods_base_tran), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_transitive_clos, __pyx_k_GiacMethods_base_transitive_clos, sizeof(__pyx_k_GiacMethods_base_transitive_clos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_translation, __pyx_k_GiacMethods_base_translation, sizeof(__pyx_k_GiacMethods_base_translation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_transpose, __pyx_k_GiacMethods_base_transpose, sizeof(__pyx_k_GiacMethods_base_transpose), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trapeze, __pyx_k_GiacMethods_base_trapeze, sizeof(__pyx_k_GiacMethods_base_trapeze), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trapezoid, __pyx_k_GiacMethods_base_trapezoid, sizeof(__pyx_k_GiacMethods_base_trapezoid), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_traveling_sales, __pyx_k_GiacMethods_base_traveling_sales, sizeof(__pyx_k_GiacMethods_base_traveling_sales), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tree, __pyx_k_GiacMethods_base_tree, sizeof(__pyx_k_GiacMethods_base_tree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tree_height, __pyx_k_GiacMethods_base_tree_height, sizeof(__pyx_k_GiacMethods_base_tree_height), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tri, __pyx_k_GiacMethods_base_tri, sizeof(__pyx_k_GiacMethods_base_tri), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_triangle, __pyx_k_GiacMethods_base_triangle, sizeof(__pyx_k_GiacMethods_base_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_triangle_paper, __pyx_k_GiacMethods_base_triangle_paper, sizeof(__pyx_k_GiacMethods_base_triangle_paper), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_triangle_plein, __pyx_k_GiacMethods_base_triangle_plein, sizeof(__pyx_k_GiacMethods_base_triangle_plein), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_triangle_point, __pyx_k_GiacMethods_base_triangle_point, sizeof(__pyx_k_GiacMethods_base_triangle_point), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_triangle_window, __pyx_k_GiacMethods_base_triangle_window, sizeof(__pyx_k_GiacMethods_base_triangle_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trig2exp, __pyx_k_GiacMethods_base_trig2exp, sizeof(__pyx_k_GiacMethods_base_trig2exp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trigcos, __pyx_k_GiacMethods_base_trigcos, sizeof(__pyx_k_GiacMethods_base_trigcos), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trigexpand, __pyx_k_GiacMethods_base_trigexpand, sizeof(__pyx_k_GiacMethods_base_trigexpand), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_triginterp, __pyx_k_GiacMethods_base_triginterp, sizeof(__pyx_k_GiacMethods_base_triginterp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trigsimplify, __pyx_k_GiacMethods_base_trigsimplify, sizeof(__pyx_k_GiacMethods_base_trigsimplify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trigsin, __pyx_k_GiacMethods_base_trigsin, sizeof(__pyx_k_GiacMethods_base_trigsin), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trigtan, __pyx_k_GiacMethods_base_trigtan, sizeof(__pyx_k_GiacMethods_base_trigtan), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trim, __pyx_k_GiacMethods_base_trim, sizeof(__pyx_k_GiacMethods_base_trim), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trn, __pyx_k_GiacMethods_base_trn, sizeof(__pyx_k_GiacMethods_base_trn), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_true, __pyx_k_GiacMethods_base_true, sizeof(__pyx_k_GiacMethods_base_true), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_trunc, __pyx_k_GiacMethods_base_trunc, sizeof(__pyx_k_GiacMethods_base_trunc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_truncate, __pyx_k_GiacMethods_base_truncate, sizeof(__pyx_k_GiacMethods_base_truncate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_truncate_graph, __pyx_k_GiacMethods_base_truncate_graph, sizeof(__pyx_k_GiacMethods_base_truncate_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tsimplify, __pyx_k_GiacMethods_base_tsimplify, sizeof(__pyx_k_GiacMethods_base_tsimplify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tstep, __pyx_k_GiacMethods_base_tstep, sizeof(__pyx_k_GiacMethods_base_tstep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tuer, __pyx_k_GiacMethods_base_tuer, sizeof(__pyx_k_GiacMethods_base_tuer), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tukey_window, __pyx_k_GiacMethods_base_tukey_window, sizeof(__pyx_k_GiacMethods_base_tukey_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_tutte_polynomia, __pyx_k_GiacMethods_base_tutte_polynomia, sizeof(__pyx_k_GiacMethods_base_tutte_polynomia), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_two_edge_connec, __pyx_k_GiacMethods_base_two_edge_connec, sizeof(__pyx_k_GiacMethods_base_two_edge_connec), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_type, __pyx_k_GiacMethods_base_type, sizeof(__pyx_k_GiacMethods_base_type), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ufactor, __pyx_k_GiacMethods_base_ufactor, sizeof(__pyx_k_GiacMethods_base_ufactor), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ugamma, __pyx_k_GiacMethods_base_ugamma, sizeof(__pyx_k_GiacMethods_base_ugamma), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_unapply, __pyx_k_GiacMethods_base_unapply, sizeof(__pyx_k_GiacMethods_base_unapply), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_unarchive, __pyx_k_GiacMethods_base_unarchive, sizeof(__pyx_k_GiacMethods_base_unarchive), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_undef, __pyx_k_GiacMethods_base_undef, sizeof(__pyx_k_GiacMethods_base_undef), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_underlying_grap, __pyx_k_GiacMethods_base_underlying_grap, sizeof(__pyx_k_GiacMethods_base_underlying_grap), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_unfactored, __pyx_k_GiacMethods_base_unfactored, sizeof(__pyx_k_GiacMethods_base_unfactored), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_uniform, __pyx_k_GiacMethods_base_uniform, sizeof(__pyx_k_GiacMethods_base_uniform), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_uniform_cdf, __pyx_k_GiacMethods_base_uniform_cdf, sizeof(__pyx_k_GiacMethods_base_uniform_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_uniform_icdf, __pyx_k_GiacMethods_base_uniform_icdf, sizeof(__pyx_k_GiacMethods_base_uniform_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_uniformd, __pyx_k_GiacMethods_base_uniformd, sizeof(__pyx_k_GiacMethods_base_uniformd), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_uniformd_cdf, __pyx_k_GiacMethods_base_uniformd_cdf, sizeof(__pyx_k_GiacMethods_base_uniformd_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_uniformd_icdf, __pyx_k_GiacMethods_base_uniformd_icdf, sizeof(__pyx_k_GiacMethods_base_uniformd_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_unitV, __pyx_k_GiacMethods_base_unitV, sizeof(__pyx_k_GiacMethods_base_unitV), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_unquote, __pyx_k_GiacMethods_base_unquote, sizeof(__pyx_k_GiacMethods_base_unquote), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_upper, __pyx_k_GiacMethods_base_upper, sizeof(__pyx_k_GiacMethods_base_upper), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_user_operator, __pyx_k_GiacMethods_base_user_operator, sizeof(__pyx_k_GiacMethods_base_user_operator), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_usimplify, __pyx_k_GiacMethods_base_usimplify, sizeof(__pyx_k_GiacMethods_base_usimplify), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ustep, __pyx_k_GiacMethods_base_ustep, sizeof(__pyx_k_GiacMethods_base_ustep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_valuation, __pyx_k_GiacMethods_base_valuation, sizeof(__pyx_k_GiacMethods_base_valuation), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vandermonde, __pyx_k_GiacMethods_base_vandermonde, sizeof(__pyx_k_GiacMethods_base_vandermonde), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_variables_are_f, __pyx_k_GiacMethods_base_variables_are_f, sizeof(__pyx_k_GiacMethods_base_variables_are_f), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_variance, __pyx_k_GiacMethods_base_variance, sizeof(__pyx_k_GiacMethods_base_variance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_version, __pyx_k_GiacMethods_base_version, sizeof(__pyx_k_GiacMethods_base_version), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertex_connecti, __pyx_k_GiacMethods_base_vertex_connecti, sizeof(__pyx_k_GiacMethods_base_vertex_connecti), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertex_cover_nu, __pyx_k_GiacMethods_base_vertex_cover_nu, sizeof(__pyx_k_GiacMethods_base_vertex_cover_nu), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertex_degree, __pyx_k_GiacMethods_base_vertex_degree, sizeof(__pyx_k_GiacMethods_base_vertex_degree), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertex_distance, __pyx_k_GiacMethods_base_vertex_distance, sizeof(__pyx_k_GiacMethods_base_vertex_distance), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertex_in_degre, __pyx_k_GiacMethods_base_vertex_in_degre, sizeof(__pyx_k_GiacMethods_base_vertex_in_degre), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertex_out_degr, __pyx_k_GiacMethods_base_vertex_out_degr, sizeof(__pyx_k_GiacMethods_base_vertex_out_degr), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertices, __pyx_k_GiacMethods_base_vertices, sizeof(__pyx_k_GiacMethods_base_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertices_abc, __pyx_k_GiacMethods_base_vertices_abc, sizeof(__pyx_k_GiacMethods_base_vertices_abc), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vertices_abca, __pyx_k_GiacMethods_base_vertices_abca, sizeof(__pyx_k_GiacMethods_base_vertices_abca), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_violet, __pyx_k_GiacMethods_base_violet, sizeof(__pyx_k_GiacMethods_base_violet), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vpotential, __pyx_k_GiacMethods_base_vpotential, sizeof(__pyx_k_GiacMethods_base_vpotential), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_vstep, __pyx_k_GiacMethods_base_vstep, sizeof(__pyx_k_GiacMethods_base_vstep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_web_graph, __pyx_k_GiacMethods_base_web_graph, sizeof(__pyx_k_GiacMethods_base_web_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibull, __pyx_k_GiacMethods_base_weibull, sizeof(__pyx_k_GiacMethods_base_weibull), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibull_cdf, __pyx_k_GiacMethods_base_weibull_cdf, sizeof(__pyx_k_GiacMethods_base_weibull_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibull_icdf, __pyx_k_GiacMethods_base_weibull_icdf, sizeof(__pyx_k_GiacMethods_base_weibull_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibulld, __pyx_k_GiacMethods_base_weibulld, sizeof(__pyx_k_GiacMethods_base_weibulld), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibulld_cdf, __pyx_k_GiacMethods_base_weibulld_cdf, sizeof(__pyx_k_GiacMethods_base_weibulld_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibulld_icdf, __pyx_k_GiacMethods_base_weibulld_icdf, sizeof(__pyx_k_GiacMethods_base_weibulld_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weibullvariate, __pyx_k_GiacMethods_base_weibullvariate, sizeof(__pyx_k_GiacMethods_base_weibullvariate), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weight_decay, __pyx_k_GiacMethods_base_weight_decay, sizeof(__pyx_k_GiacMethods_base_weight_decay), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weight_matrix, __pyx_k_GiacMethods_base_weight_matrix, sizeof(__pyx_k_GiacMethods_base_weight_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weighted, __pyx_k_GiacMethods_base_weighted, sizeof(__pyx_k_GiacMethods_base_weighted), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_weights, __pyx_k_GiacMethods_base_weights, sizeof(__pyx_k_GiacMethods_base_weights), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_welch_window, __pyx_k_GiacMethods_base_welch_window, sizeof(__pyx_k_GiacMethods_base_welch_window), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_wheel_graph, __pyx_k_GiacMethods_base_wheel_graph, sizeof(__pyx_k_GiacMethods_base_wheel_graph), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_widget_size, __pyx_k_GiacMethods_base_widget_size, sizeof(__pyx_k_GiacMethods_base_widget_size), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_wilcoxonp, __pyx_k_GiacMethods_base_wilcoxonp, sizeof(__pyx_k_GiacMethods_base_wilcoxonp), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_wilcoxons, __pyx_k_GiacMethods_base_wilcoxons, sizeof(__pyx_k_GiacMethods_base_wilcoxons), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_wilcoxont, __pyx_k_GiacMethods_base_wilcoxont, sizeof(__pyx_k_GiacMethods_base_wilcoxont), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_writergb, __pyx_k_GiacMethods_base_writergb, sizeof(__pyx_k_GiacMethods_base_writergb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_writewav, __pyx_k_GiacMethods_base_writewav, sizeof(__pyx_k_GiacMethods_base_writewav), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_xcas_mode, __pyx_k_GiacMethods_base_xcas_mode, sizeof(__pyx_k_GiacMethods_base_xcas_mode), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_xml_print, __pyx_k_GiacMethods_base_xml_print, sizeof(__pyx_k_GiacMethods_base_xml_print), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_xstep, __pyx_k_GiacMethods_base_xstep, sizeof(__pyx_k_GiacMethods_base_xstep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_xyz2rgb, __pyx_k_GiacMethods_base_xyz2rgb, sizeof(__pyx_k_GiacMethods_base_xyz2rgb), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_xyztrange, __pyx_k_GiacMethods_base_xyztrange, sizeof(__pyx_k_GiacMethods_base_xyztrange), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ystep, __pyx_k_GiacMethods_base_ystep, sizeof(__pyx_k_GiacMethods_base_ystep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_zeros, __pyx_k_GiacMethods_base_zeros, sizeof(__pyx_k_GiacMethods_base_zeros), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_zip, __pyx_k_GiacMethods_base_zip, sizeof(__pyx_k_GiacMethods_base_zip), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_znorder, __pyx_k_GiacMethods_base_znorder, sizeof(__pyx_k_GiacMethods_base_znorder), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_znprimroot, __pyx_k_GiacMethods_base_znprimroot, sizeof(__pyx_k_GiacMethods_base_znprimroot), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_zstep, __pyx_k_GiacMethods_base_zstep, sizeof(__pyx_k_GiacMethods_base_zstep), 0, 0, 1, 1},
    {&__pyx_n_s_GiacMethods_base_ztrans, __pyx_k_GiacMethods_base_ztrans, sizeof(__pyx_k_GiacMethods_base_ztrans), 0, 0, 1, 1},
    {&__pyx_n_s_GiacSetting, __pyx_k_GiacSetting, sizeof(__pyx_k_GiacSetting), 0, 0, 1, 1},
    {&__pyx_n_s_GiacSetting___reduce_cython, __pyx_k_GiacSetting___reduce_cython, sizeof(__pyx_k_GiacSetting___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_GiacSetting___setstate_cython, __pyx_k_GiacSetting___setstate_cython, sizeof(__pyx_k_GiacSetting___setstate_cython), 0, 0, 1, 1},
    {&__pyx_kp_s_Giac_Settings, __pyx_k_Giac_Settings, sizeof(__pyx_k_Giac_Settings), 0, 0, 1, 0},
    {&__pyx_n_s_Graph, __pyx_k_Graph, sizeof(__pyx_k_Graph), 0, 0, 1, 1},
    {&__pyx_n_s_Gy, __pyx_k_Gy, sizeof(__pyx_k_Gy), 0, 0, 1, 1},
    {&__pyx_n_s_H, __pyx_k_H, sizeof(__pyx_k_H), 0, 0, 1, 1},
    {&__pyx_n_s_Heaviside, __pyx_k_Heaviside, sizeof(__pyx_k_Heaviside), 0, 0, 1, 1},
    {&__pyx_n_s_Heaviside2sign, __pyx_k_Heaviside2sign, sizeof(__pyx_k_Heaviside2sign), 0, 0, 1, 1},
    {&__pyx_n_s_Hilbert, __pyx_k_Hilbert, sizeof(__pyx_k_Hilbert), 0, 0, 1, 1},
    {&__pyx_n_s_Hz, __pyx_k_Hz, sizeof(__pyx_k_Hz), 0, 0, 1, 1},
    {&__pyx_n_s_I, __pyx_k_I, sizeof(__pyx_k_I), 0, 0, 1, 1},
    {&__pyx_n_s_I0, __pyx_k_I0, sizeof(__pyx_k_I0), 0, 0, 1, 1},
    {&__pyx_n_s_IFTE, __pyx_k_IFTE, sizeof(__pyx_k_IFTE), 0, 0, 1, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_kp_u_Increase_the_size_of_a_matrix_w, __pyx_k_Increase_the_size_of_a_matrix_w, sizeof(__pyx_k_Increase_the_size_of_a_matrix_w), 0, 1, 0, 0},
    {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
    {&__pyx_n_s_Input, __pyx_k_Input, sizeof(__pyx_k_Input), 0, 0, 1, 1},
    {&__pyx_n_s_InputStr, __pyx_k_InputStr, sizeof(__pyx_k_InputStr), 0, 0, 1, 1},
    {&__pyx_n_s_Int, __pyx_k_Int, sizeof(__pyx_k_Int), 0, 0, 1, 1},
    {&__pyx_kp_s_Interrupted_by_a_ctrl_c_event, __pyx_k_Interrupted_by_a_ctrl_c_event, sizeof(__pyx_k_Interrupted_by_a_ctrl_c_event), 0, 0, 1, 0},
    {&__pyx_n_s_Inverse, __pyx_k_Inverse, sizeof(__pyx_k_Inverse), 0, 0, 1, 1},
    {&__pyx_n_s_J, __pyx_k_J, sizeof(__pyx_k_J), 0, 0, 1, 1},
    {&__pyx_n_s_JordanBlock, __pyx_k_JordanBlock, sizeof(__pyx_k_JordanBlock), 0, 0, 1, 1},
    {&__pyx_n_s_K, __pyx_k_K, sizeof(__pyx_k_K), 0, 0, 1, 1},
    {&__pyx_n_s_Kcal, __pyx_k_Kcal, sizeof(__pyx_k_Kcal), 0, 0, 1, 1},
    {&__pyx_n_s_KeyboardInterrupt, __pyx_k_KeyboardInterrupt, sizeof(__pyx_k_KeyboardInterrupt), 0, 0, 1, 1},
    {&__pyx_n_s_LN, __pyx_k_LN, sizeof(__pyx_k_LN), 0, 0, 1, 1},
    {&__pyx_n_s_LQ, __pyx_k_LQ, sizeof(__pyx_k_LQ), 0, 0, 1, 1},
    {&__pyx_n_s_LSQ, __pyx_k_LSQ, sizeof(__pyx_k_LSQ), 0, 0, 1, 1},
    {&__pyx_n_s_LU, __pyx_k_LU, sizeof(__pyx_k_LU), 0, 0, 1, 1},
    {&__pyx_n_s_LambertW, __pyx_k_LambertW, sizeof(__pyx_k_LambertW), 0, 0, 1, 1},
    {&__pyx_n_s_Li, __pyx_k_Li, sizeof(__pyx_k_Li), 0, 0, 1, 1},
    {&__pyx_n_s_Line, __pyx_k_Line, sizeof(__pyx_k_Line), 0, 0, 1, 1},
    {&__pyx_n_s_LineHorz, __pyx_k_LineHorz, sizeof(__pyx_k_LineHorz), 0, 0, 1, 1},
    {&__pyx_n_s_LineTan, __pyx_k_LineTan, sizeof(__pyx_k_LineTan), 0, 0, 1, 1},
    {&__pyx_n_s_LineVert, __pyx_k_LineVert, sizeof(__pyx_k_LineVert), 0, 0, 1, 1},
    {&__pyx_kp_u_Lists_of_10_6_integers_should_b, __pyx_k_Lists_of_10_6_integers_should_b, sizeof(__pyx_k_Lists_of_10_6_integers_should_b), 0, 1, 0, 0},
    {&__pyx_n_s_MHz, __pyx_k_MHz, sizeof(__pyx_k_MHz), 0, 0, 1, 1},
    {&__pyx_n_s_MSE, __pyx_k_MSE, sizeof(__pyx_k_MSE), 0, 0, 1, 1},
    {&__pyx_n_s_MW, __pyx_k_MW, sizeof(__pyx_k_MW), 0, 0, 1, 1},
    {&__pyx_n_s_MeV, __pyx_k_MeV, sizeof(__pyx_k_MeV), 0, 0, 1, 1},
    {&__pyx_n_s_N, __pyx_k_N, sizeof(__pyx_k_N), 0, 0, 1, 1},
    {&__pyx_n_s_NA, __pyx_k_NA, sizeof(__pyx_k_NA), 0, 0, 1, 1},
    {&__pyx_n_s_NORMALD, __pyx_k_NORMALD, sizeof(__pyx_k_NORMALD), 0, 0, 1, 1},
    {&__pyx_n_s_NULL, __pyx_k_NULL, sizeof(__pyx_k_NULL), 0, 0, 1, 1},
    {&__pyx_n_s_NewFold, __pyx_k_NewFold, sizeof(__pyx_k_NewFold), 0, 0, 1, 1},
    {&__pyx_n_s_NewPic, __pyx_k_NewPic, sizeof(__pyx_k_NewPic), 0, 0, 1, 1},
    {&__pyx_n_s_Nullspace, __pyx_k_Nullspace, sizeof(__pyx_k_Nullspace), 0, 0, 1, 1},
    {&__pyx_n_s_Ohm, __pyx_k_Ohm, sizeof(__pyx_k_Ohm), 0, 0, 1, 1},
    {&__pyx_kp_u_Open_a_file_in_giac_compressed, __pyx_k_Open_a_file_in_giac_compressed, sizeof(__pyx_k_Open_a_file_in_giac_compressed), 0, 1, 0, 0},
    {&__pyx_kp_u_Open_the_giac_html_detailled_he, __pyx_k_Open_the_giac_html_detailled_he, sizeof(__pyx_k_Open_the_giac_html_detailled_he), 0, 1, 0, 0},
    {&__pyx_kp_u_Open_the_giac_html_detailled_he_2, __pyx_k_Open_the_giac_html_detailled_he_2, sizeof(__pyx_k_Open_the_giac_html_detailled_he_2), 0, 1, 0, 0},
    {&__pyx_n_s_Output, __pyx_k_Output, sizeof(__pyx_k_Output), 0, 0, 1, 1},
    {&__pyx_n_s_Ox_2d_unit_vector, __pyx_k_Ox_2d_unit_vector, sizeof(__pyx_k_Ox_2d_unit_vector), 0, 0, 1, 1},
    {&__pyx_n_s_Ox_3d_unit_vector, __pyx_k_Ox_3d_unit_vector, sizeof(__pyx_k_Ox_3d_unit_vector), 0, 0, 1, 1},
    {&__pyx_n_s_Oy_2d_unit_vector, __pyx_k_Oy_2d_unit_vector, sizeof(__pyx_k_Oy_2d_unit_vector), 0, 0, 1, 1},
    {&__pyx_n_s_Oy_3d_unit_vector, __pyx_k_Oy_3d_unit_vector, sizeof(__pyx_k_Oy_3d_unit_vector), 0, 0, 1, 1},
    {&__pyx_n_s_Oz_3d_unit_vector, __pyx_k_Oz_3d_unit_vector, sizeof(__pyx_k_Oz_3d_unit_vector), 0, 0, 1, 1},
    {&__pyx_n_s_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 0, 1, 1},
    {&__pyx_n_s_PSun, __pyx_k_PSun, sizeof(__pyx_k_PSun), 0, 0, 1, 1},
    {&__pyx_n_s_Pa, __pyx_k_Pa, sizeof(__pyx_k_Pa), 0, 0, 1, 1},
    {&__pyx_n_s_Pause, __pyx_k_Pause, sizeof(__pyx_k_Pause), 0, 0, 1, 1},
    {&__pyx_n_s_Phi, __pyx_k_Phi, sizeof(__pyx_k_Phi), 0, 0, 1, 1},
    {&__pyx_n_s_Pi, __pyx_k_Pi, sizeof(__pyx_k_Pi), 0, 0, 1, 1},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_PopUp, __pyx_k_PopUp, sizeof(__pyx_k_PopUp), 0, 0, 1, 1},
    {&__pyx_n_s_Psi, __pyx_k_Psi, sizeof(__pyx_k_Psi), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen, __pyx_k_Pygen, sizeof(__pyx_k_Pygen), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen___float___line_1078, __pyx_k_Pygen___float___line_1078, sizeof(__pyx_k_Pygen___float___line_1078), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___getitem___line_913, __pyx_k_Pygen___getitem___line_913, sizeof(__pyx_k_Pygen___getitem___line_913), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___int___line_1059, __pyx_k_Pygen___int___line_1059, sizeof(__pyx_k_Pygen___int___line_1059), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen___iter, __pyx_k_Pygen___iter, sizeof(__pyx_k_Pygen___iter), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen___iter___line_1035, __pyx_k_Pygen___iter___line_1035, sizeof(__pyx_k_Pygen___iter___line_1035), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___radd___line_1192, __pyx_k_Pygen___radd___line_1192, sizeof(__pyx_k_Pygen___radd___line_1192), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen___reduce_cython, __pyx_k_Pygen___reduce_cython, sizeof(__pyx_k_Pygen___reduce_cython), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen___repr___line_877, __pyx_k_Pygen___repr___line_877, sizeof(__pyx_k_Pygen___repr___line_877), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___rmod___line_1410, __pyx_k_Pygen___rmod___line_1410, sizeof(__pyx_k_Pygen___rmod___line_1410), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___rmul___line_1286, __pyx_k_Pygen___rmul___line_1286, sizeof(__pyx_k_Pygen___rmul___line_1286), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___rpow___line_1372, __pyx_k_Pygen___rpow___line_1372, sizeof(__pyx_k_Pygen___rpow___line_1372), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___rsub___line_1248, __pyx_k_Pygen___rsub___line_1248, sizeof(__pyx_k_Pygen___rsub___line_1248), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___rtruediv___line_1337, __pyx_k_Pygen___rtruediv___line_1337, sizeof(__pyx_k_Pygen___rtruediv___line_1337), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen___setitem___line_986, __pyx_k_Pygen___setitem___line_986, sizeof(__pyx_k_Pygen___setitem___line_986), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen___setstate_cython, __pyx_k_Pygen___setstate_cython, sizeof(__pyx_k_Pygen___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen__repr_html, __pyx_k_Pygen__repr_html, sizeof(__pyx_k_Pygen__repr_html), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen__repr_latex, __pyx_k_Pygen__repr_latex, sizeof(__pyx_k_Pygen__repr_latex), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen_cas_setup, __pyx_k_Pygen_cas_setup, sizeof(__pyx_k_Pygen_cas_setup), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen_eval, __pyx_k_Pygen_eval, sizeof(__pyx_k_Pygen_eval), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen_help, __pyx_k_Pygen_help, sizeof(__pyx_k_Pygen_help), 0, 0, 1, 1},
    {&__pyx_n_s_Pygen_htmlhelp, __pyx_k_Pygen_htmlhelp, sizeof(__pyx_k_Pygen_htmlhelp), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen_htmlhelp_line_1498, __pyx_k_Pygen_htmlhelp_line_1498, sizeof(__pyx_k_Pygen_htmlhelp_line_1498), 0, 1, 0, 0},
    {&__pyx_kp_u_Pygen_lists_of_10_6_elements_sh, __pyx_k_Pygen_lists_of_10_6_elements_sh, sizeof(__pyx_k_Pygen_lists_of_10_6_elements_sh), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen_qcas, __pyx_k_Pygen_qcas, sizeof(__pyx_k_Pygen_qcas), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen_qcas_line_1552, __pyx_k_Pygen_qcas_line_1552, sizeof(__pyx_k_Pygen_qcas_line_1552), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen_redim, __pyx_k_Pygen_redim, sizeof(__pyx_k_Pygen_redim), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen_redim_line_1526, __pyx_k_Pygen_redim_line_1526, sizeof(__pyx_k_Pygen_redim_line_1526), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen_save, __pyx_k_Pygen_save, sizeof(__pyx_k_Pygen_save), 0, 0, 1, 1},
    {&__pyx_kp_u_Pygen_save_line_1469, __pyx_k_Pygen_save_line_1469, sizeof(__pyx_k_Pygen_save_line_1469), 0, 1, 0, 0},
    {&__pyx_n_s_Pygen_threadeval, __pyx_k_Pygen_threadeval, sizeof(__pyx_k_Pygen_threadeval), 0, 0, 1, 1},
    {&__pyx_n_s_Pymaxint, __pyx_k_Pymaxint, sizeof(__pyx_k_Pymaxint), 0, 0, 1, 1},
    {&__pyx_n_s_PythonVersion3, __pyx_k_PythonVersion3, sizeof(__pyx_k_PythonVersion3), 0, 0, 1, 1},
    {&__pyx_n_s_Pyversioninfo, __pyx_k_Pyversioninfo, sizeof(__pyx_k_Pyversioninfo), 0, 0, 1, 1},
    {&__pyx_n_s_QR, __pyx_k_QR, sizeof(__pyx_k_QR), 0, 0, 1, 1},
    {&__pyx_n_s_Quo, __pyx_k_Quo, sizeof(__pyx_k_Quo), 0, 0, 1, 1},
    {&__pyx_n_s_R, __pyx_k_R, sizeof(__pyx_k_R), 0, 0, 1, 1},
    {&__pyx_n_s_REDIM, __pyx_k_REDIM, sizeof(__pyx_k_REDIM), 0, 0, 1, 1},
    {&__pyx_n_s_REPLACE, __pyx_k_REPLACE, sizeof(__pyx_k_REPLACE), 0, 0, 1, 1},
    {&__pyx_n_s_REarth, __pyx_k_REarth, sizeof(__pyx_k_REarth), 0, 0, 1, 1},
    {&__pyx_n_s_RSun, __pyx_k_RSun, sizeof(__pyx_k_RSun), 0, 0, 1, 1},
    {&__pyx_n_s_R_2, __pyx_k_R_2, sizeof(__pyx_k_R_2), 0, 0, 1, 1},
    {&__pyx_n_s_RandSeed, __pyx_k_RandSeed, sizeof(__pyx_k_RandSeed), 0, 0, 1, 1},
    {&__pyx_n_s_Rankine, __pyx_k_Rankine, sizeof(__pyx_k_Rankine), 0, 0, 1, 1},
    {&__pyx_n_s_RclPic, __pyx_k_RclPic, sizeof(__pyx_k_RclPic), 0, 0, 1, 1},
    {&__pyx_n_s_ReLU, __pyx_k_ReLU, sizeof(__pyx_k_ReLU), 0, 0, 1, 1},
    {&__pyx_n_s_Rem, __pyx_k_Rem, sizeof(__pyx_k_Rem), 0, 0, 1, 1},
    {&__pyx_n_s_Request, __pyx_k_Request, sizeof(__pyx_k_Request), 0, 0, 1, 1},
    {&__pyx_kp_s_Result_is_too_big_for_Display_I, __pyx_k_Result_is_too_big_for_Display_I, sizeof(__pyx_k_Result_is_too_big_for_Display_I), 0, 0, 1, 0},
    {&__pyx_n_s_Resultant, __pyx_k_Resultant, sizeof(__pyx_k_Resultant), 0, 0, 1, 1},
    {&__pyx_kp_u_Reverse_operator_7_giac_3_Calle, __pyx_k_Reverse_operator_7_giac_3_Calle, sizeof(__pyx_k_Reverse_operator_7_giac_3_Calle), 0, 1, 0, 0},
    {&__pyx_kp_u_Reverse_operator_d_giac_d_1_d_C, __pyx_k_Reverse_operator_d_giac_d_1_d_C, sizeof(__pyx_k_Reverse_operator_d_giac_d_1_d_C), 0, 1, 0, 0},
    {&__pyx_kp_u_Reverse_operator_d_giac_d_2_d_C, __pyx_k_Reverse_operator_d_giac_d_2_d_C, sizeof(__pyx_k_Reverse_operator_d_giac_d_2_d_C), 0, 1, 0, 0},
    {&__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C, __pyx_k_Reverse_operator_d_giac_d_7_d_C, sizeof(__pyx_k_Reverse_operator_d_giac_d_7_d_C), 0, 1, 0, 0},
    {&__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2, __pyx_k_Reverse_operator_d_giac_d_7_d_C_2, sizeof(__pyx_k_Reverse_operator_d_giac_d_7_d_C_2), 0, 1, 0, 0},
    {&__pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3, __pyx_k_Reverse_operator_d_giac_d_7_d_C_3, sizeof(__pyx_k_Reverse_operator_d_giac_d_7_d_C_3), 0, 1, 0, 0},
    {&__pyx_n_s_Rinfinity, __pyx_k_Rinfinity, sizeof(__pyx_k_Rinfinity), 0, 0, 1, 1},
    {&__pyx_n_s_Row, __pyx_k_Row, sizeof(__pyx_k_Row), 0, 0, 1, 1},
    {&__pyx_n_s_RplcPic, __pyx_k_RplcPic, sizeof(__pyx_k_RplcPic), 0, 0, 1, 1},
    {&__pyx_n_s_Rref, __pyx_k_Rref, sizeof(__pyx_k_Rref), 0, 0, 1, 1},
    {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
    {&__pyx_n_s_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 0, 1, 1},
    {&__pyx_n_s_SCALE, __pyx_k_SCALE, sizeof(__pyx_k_SCALE), 0, 0, 1, 1},
    {&__pyx_n_s_SCALEADD, __pyx_k_SCALEADD, sizeof(__pyx_k_SCALEADD), 0, 0, 1, 1},
    {&__pyx_n_s_SCHUR, __pyx_k_SCHUR, sizeof(__pyx_k_SCHUR), 0, 0, 1, 1},
    {&__pyx_n_s_SIN, __pyx_k_SIN, sizeof(__pyx_k_SIN), 0, 0, 1, 1},
    {&__pyx_n_s_SVD, __pyx_k_SVD, sizeof(__pyx_k_SVD), 0, 0, 1, 1},
    {&__pyx_n_s_SVL, __pyx_k_SVL, sizeof(__pyx_k_SVL), 0, 0, 1, 1},
    {&__pyx_n_s_SWAPCOL, __pyx_k_SWAPCOL, sizeof(__pyx_k_SWAPCOL), 0, 0, 1, 1},
    {&__pyx_n_s_SWAPROW, __pyx_k_SWAPROW, sizeof(__pyx_k_SWAPROW), 0, 0, 1, 1},
    {&__pyx_kp_u_Send_a_giac_graphic_to_qcas_3D, __pyx_k_Send_a_giac_graphic_to_qcas_3D, sizeof(__pyx_k_Send_a_giac_graphic_to_qcas_3D), 0, 1, 0, 0},
    {&__pyx_n_s_SetFold, __pyx_k_SetFold, sizeof(__pyx_k_SetFold), 0, 0, 1, 1},
    {&__pyx_kp_u_Set_the_value_of_a_coefficient, __pyx_k_Set_the_value_of_a_coefficient, sizeof(__pyx_k_Set_the_value_of_a_coefficient), 0, 1, 0, 0},
    {&__pyx_n_s_Si, __pyx_k_Si, sizeof(__pyx_k_Si), 0, 0, 1, 1},
    {&__pyx_n_s_SortA, __pyx_k_SortA, sizeof(__pyx_k_SortA), 0, 0, 1, 1},
    {&__pyx_n_s_SortD, __pyx_k_SortD, sizeof(__pyx_k_SortD), 0, 0, 1, 1},
    {&__pyx_n_s_St, __pyx_k_St, sizeof(__pyx_k_St), 0, 0, 1, 1},
    {&__pyx_n_s_StdP, __pyx_k_StdP, sizeof(__pyx_k_StdP), 0, 0, 1, 1},
    {&__pyx_n_s_StdT, __pyx_k_StdT, sizeof(__pyx_k_StdT), 0, 0, 1, 1},
    {&__pyx_n_s_StoPic, __pyx_k_StoPic, sizeof(__pyx_k_StoPic), 0, 0, 1, 1},
    {&__pyx_n_s_Store, __pyx_k_Store, sizeof(__pyx_k_Store), 0, 0, 1, 1},
    {&__pyx_n_s_Sv, __pyx_k_Sv, sizeof(__pyx_k_Sv), 0, 0, 1, 1},
    {&__pyx_n_s_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 0, 1, 1},
    {&__pyx_n_s_TAN, __pyx_k_TAN, sizeof(__pyx_k_TAN), 0, 0, 1, 1},
    {&__pyx_n_s_TRUE, __pyx_k_TRUE, sizeof(__pyx_k_TRUE), 0, 0, 1, 1},
    {&__pyx_n_s_TeX, __pyx_k_TeX, sizeof(__pyx_k_TeX), 0, 0, 1, 1},
    {&__pyx_n_s_Text, __pyx_k_Text, sizeof(__pyx_k_Text), 0, 0, 1, 1},
    {&__pyx_kp_u_This_function_evaluate_a_python, __pyx_k_This_function_evaluate_a_python, sizeof(__pyx_k_This_function_evaluate_a_python), 0, 1, 0, 0},
    {&__pyx_n_s_ThreadedPygen, __pyx_k_ThreadedPygen, sizeof(__pyx_k_ThreadedPygen), 0, 0, 1, 1},
    {&__pyx_n_s_ThreadedPygen___call, __pyx_k_ThreadedPygen___call, sizeof(__pyx_k_ThreadedPygen___call), 0, 0, 1, 1},
    {&__pyx_n_s_Title, __pyx_k_Title, sizeof(__pyx_k_Title), 0, 0, 1, 1},
    {&__pyx_n_s_True, __pyx_k_True, sizeof(__pyx_k_True), 0, 0, 1, 1},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_kp_s_UTF_8, __pyx_k_UTF_8, sizeof(__pyx_k_UTF_8), 0, 0, 1, 0},
    {&__pyx_n_s_UTPC, __pyx_k_UTPC, sizeof(__pyx_k_UTPC), 0, 0, 1, 1},
    {&__pyx_n_s_UTPF, __pyx_k_UTPF, sizeof(__pyx_k_UTPF), 0, 0, 1, 1},
    {&__pyx_n_s_UTPN, __pyx_k_UTPN, sizeof(__pyx_k_UTPN), 0, 0, 1, 1},
    {&__pyx_n_s_UTPT, __pyx_k_UTPT, sizeof(__pyx_k_UTPT), 0, 0, 1, 1},
    {&__pyx_n_s_Unarchiv, __pyx_k_Unarchiv, sizeof(__pyx_k_Unarchiv), 0, 0, 1, 1},
    {&__pyx_kp_s_Use_this_subclass_of_to_call_yo, __pyx_k_Use_this_subclass_of_to_call_yo, sizeof(__pyx_k_Use_this_subclass_of_to_call_yo), 0, 0, 1, 0},
    {&__pyx_n_s_V, __pyx_k_V, sizeof(__pyx_k_V), 0, 0, 1, 1},
    {&__pyx_n_s_VARS, __pyx_k_VARS, sizeof(__pyx_k_VARS), 0, 0, 1, 1},
    {&__pyx_n_s_VAS, __pyx_k_VAS, sizeof(__pyx_k_VAS), 0, 0, 1, 1},
    {&__pyx_n_s_VAS_positive, __pyx_k_VAS_positive, sizeof(__pyx_k_VAS_positive), 0, 0, 1, 1},
    {&__pyx_n_s_Vm, __pyx_k_Vm, sizeof(__pyx_k_Vm), 0, 0, 1, 1},
    {&__pyx_n_s_W, __pyx_k_W, sizeof(__pyx_k_W), 0, 0, 1, 1},
    {&__pyx_n_s_WAIT, __pyx_k_WAIT, sizeof(__pyx_k_WAIT), 0, 0, 1, 1},
    {&__pyx_n_s_Wb, __pyx_k_Wb, sizeof(__pyx_k_Wb), 0, 0, 1, 1},
    {&__pyx_n_s_Wh, __pyx_k_Wh, sizeof(__pyx_k_Wh), 0, 0, 1, 1},
    {&__pyx_n_s_Zeta, __pyx_k_Zeta, sizeof(__pyx_k_Zeta), 0, 0, 1, 1},
    {&__pyx_kp_s__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 1, 0},
    {&__pyx_kp_s__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 0, 1, 0},
    {&__pyx_n_s__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 0, 1, 1},
    {&__pyx_kp_s__1655, __pyx_k__1655, sizeof(__pyx_k__1655), 0, 0, 1, 0},
    {&__pyx_kp_s__1656, __pyx_k__1656, sizeof(__pyx_k__1656), 0, 0, 1, 0},
    {&__pyx_kp_s__1657, __pyx_k__1657, sizeof(__pyx_k__1657), 0, 0, 1, 0},
    {&__pyx_kp_s__1658, __pyx_k__1658, sizeof(__pyx_k__1658), 0, 0, 1, 0},
    {&__pyx_kp_s__1659, __pyx_k__1659, sizeof(__pyx_k__1659), 0, 0, 1, 0},
    {&__pyx_kp_s__1660, __pyx_k__1660, sizeof(__pyx_k__1660), 0, 0, 1, 0},
    {&__pyx_kp_s__1661, __pyx_k__1661, sizeof(__pyx_k__1661), 0, 0, 1, 0},
    {&__pyx_kp_s__1662, __pyx_k__1662, sizeof(__pyx_k__1662), 0, 0, 1, 0},
    {&__pyx_kp_s__1663, __pyx_k__1663, sizeof(__pyx_k__1663), 0, 0, 1, 0},
    {&__pyx_kp_s__1664, __pyx_k__1664, sizeof(__pyx_k__1664), 0, 0, 1, 0},
    {&__pyx_kp_s__1665, __pyx_k__1665, sizeof(__pyx_k__1665), 0, 0, 1, 0},
    {&__pyx_kp_s__1666, __pyx_k__1666, sizeof(__pyx_k__1666), 0, 0, 1, 0},
    {&__pyx_kp_s__1667, __pyx_k__1667, sizeof(__pyx_k__1667), 0, 0, 1, 0},
    {&__pyx_kp_s__1668, __pyx_k__1668, sizeof(__pyx_k__1668), 0, 0, 1, 0},
    {&__pyx_kp_s__1669, __pyx_k__1669, sizeof(__pyx_k__1669), 0, 0, 1, 0},
    {&__pyx_kp_s__1670, __pyx_k__1670, sizeof(__pyx_k__1670), 0, 0, 1, 0},
    {&__pyx_kp_s__1671, __pyx_k__1671, sizeof(__pyx_k__1671), 0, 0, 1, 0},
    {&__pyx_kp_s__1672, __pyx_k__1672, sizeof(__pyx_k__1672), 0, 0, 1, 0},
    {&__pyx_kp_s__1673, __pyx_k__1673, sizeof(__pyx_k__1673), 0, 0, 1, 0},
    {&__pyx_kp_s__1674, __pyx_k__1674, sizeof(__pyx_k__1674), 0, 0, 1, 0},
    {&__pyx_kp_s__1675, __pyx_k__1675, sizeof(__pyx_k__1675), 0, 0, 1, 0},
    {&__pyx_kp_s__1676, __pyx_k__1676, sizeof(__pyx_k__1676), 0, 0, 1, 0},
    {&__pyx_kp_s__1677, __pyx_k__1677, sizeof(__pyx_k__1677), 0, 0, 1, 0},
    {&__pyx_kp_s__1678, __pyx_k__1678, sizeof(__pyx_k__1678), 0, 0, 1, 0},
    {&__pyx_kp_s__1679, __pyx_k__1679, sizeof(__pyx_k__1679), 0, 0, 1, 0},
    {&__pyx_kp_s__1680, __pyx_k__1680, sizeof(__pyx_k__1680), 0, 0, 1, 0},
    {&__pyx_kp_s__1681, __pyx_k__1681, sizeof(__pyx_k__1681), 0, 0, 1, 0},
    {&__pyx_kp_s__1682, __pyx_k__1682, sizeof(__pyx_k__1682), 0, 0, 1, 0},
    {&__pyx_kp_s__1683, __pyx_k__1683, sizeof(__pyx_k__1683), 0, 0, 1, 0},
    {&__pyx_kp_s__1684, __pyx_k__1684, sizeof(__pyx_k__1684), 0, 0, 1, 0},
    {&__pyx_kp_s__1685, __pyx_k__1685, sizeof(__pyx_k__1685), 0, 0, 1, 0},
    {&__pyx_kp_s__1686, __pyx_k__1686, sizeof(__pyx_k__1686), 0, 0, 1, 0},
    {&__pyx_kp_s__1687, __pyx_k__1687, sizeof(__pyx_k__1687), 0, 0, 1, 0},
    {&__pyx_kp_s__1688, __pyx_k__1688, sizeof(__pyx_k__1688), 0, 0, 1, 0},
    {&__pyx_kp_s__1689, __pyx_k__1689, sizeof(__pyx_k__1689), 0, 0, 1, 0},
    {&__pyx_kp_s__1690, __pyx_k__1690, sizeof(__pyx_k__1690), 0, 0, 1, 0},
    {&__pyx_kp_s__1691, __pyx_k__1691, sizeof(__pyx_k__1691), 0, 0, 1, 0},
    {&__pyx_kp_s__1692, __pyx_k__1692, sizeof(__pyx_k__1692), 0, 0, 1, 0},
    {&__pyx_kp_s__1693, __pyx_k__1693, sizeof(__pyx_k__1693), 0, 0, 1, 0},
    {&__pyx_kp_s__1694, __pyx_k__1694, sizeof(__pyx_k__1694), 0, 0, 1, 0},
    {&__pyx_kp_s__1695, __pyx_k__1695, sizeof(__pyx_k__1695), 0, 0, 1, 0},
    {&__pyx_kp_s__1696, __pyx_k__1696, sizeof(__pyx_k__1696), 0, 0, 1, 0},
    {&__pyx_kp_s__1697, __pyx_k__1697, sizeof(__pyx_k__1697), 0, 0, 1, 0},
    {&__pyx_kp_s__1698, __pyx_k__1698, sizeof(__pyx_k__1698), 0, 0, 1, 0},
    {&__pyx_kp_s__1699, __pyx_k__1699, sizeof(__pyx_k__1699), 0, 0, 1, 0},
    {&__pyx_kp_s__1700, __pyx_k__1700, sizeof(__pyx_k__1700), 0, 0, 1, 0},
    {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
    {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
    {&__pyx_n_s_a0, __pyx_k_a0, sizeof(__pyx_k_a0), 0, 0, 1, 1},
    {&__pyx_n_s_a2q, __pyx_k_a2q, sizeof(__pyx_k_a2q), 0, 0, 1, 1},
    {&__pyx_n_s_a_2, __pyx_k_a_2, sizeof(__pyx_k_a_2), 0, 0, 1, 1},
    {&__pyx_n_s_abcuv, __pyx_k_abcuv, sizeof(__pyx_k_abcuv), 0, 0, 1, 1},
    {&__pyx_n_s_about, __pyx_k_about, sizeof(__pyx_k_about), 0, 0, 1, 1},
    {&__pyx_n_s_abs, __pyx_k_abs, sizeof(__pyx_k_abs), 0, 0, 1, 1},
    {&__pyx_n_s_abscissa, __pyx_k_abscissa, sizeof(__pyx_k_abscissa), 0, 0, 1, 1},
    {&__pyx_n_s_access, __pyx_k_access, sizeof(__pyx_k_access), 0, 0, 1, 1},
    {&__pyx_n_s_accumulate_head_tail, __pyx_k_accumulate_head_tail, sizeof(__pyx_k_accumulate_head_tail), 0, 0, 1, 1},
    {&__pyx_n_s_acos, __pyx_k_acos, sizeof(__pyx_k_acos), 0, 0, 1, 1},
    {&__pyx_n_s_acos2asin, __pyx_k_acos2asin, sizeof(__pyx_k_acos2asin), 0, 0, 1, 1},
    {&__pyx_n_s_acos2atan, __pyx_k_acos2atan, sizeof(__pyx_k_acos2atan), 0, 0, 1, 1},
    {&__pyx_n_s_acosh, __pyx_k_acosh, sizeof(__pyx_k_acosh), 0, 0, 1, 1},
    {&__pyx_n_s_acot, __pyx_k_acot, sizeof(__pyx_k_acot), 0, 0, 1, 1},
    {&__pyx_n_s_acre, __pyx_k_acre, sizeof(__pyx_k_acre), 0, 0, 1, 1},
    {&__pyx_n_s_acsc, __pyx_k_acsc, sizeof(__pyx_k_acsc), 0, 0, 1, 1},
    {&__pyx_n_s_acyclic, __pyx_k_acyclic, sizeof(__pyx_k_acyclic), 0, 0, 1, 1},
    {&__pyx_n_s_adaptive, __pyx_k_adaptive, sizeof(__pyx_k_adaptive), 0, 0, 1, 1},
    {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
    {&__pyx_n_s_add_2, __pyx_k_add_2, sizeof(__pyx_k_add_2), 0, 0, 1, 1},
    {&__pyx_n_s_add_arc, __pyx_k_add_arc, sizeof(__pyx_k_add_arc), 0, 0, 1, 1},
    {&__pyx_n_s_add_edge, __pyx_k_add_edge, sizeof(__pyx_k_add_edge), 0, 0, 1, 1},
    {&__pyx_kp_s_add_language_1, __pyx_k_add_language_1, sizeof(__pyx_k_add_language_1), 0, 0, 1, 0},
    {&__pyx_n_s_add_vertex, __pyx_k_add_vertex, sizeof(__pyx_k_add_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_additionally, __pyx_k_additionally, sizeof(__pyx_k_additionally), 0, 0, 1, 1},
    {&__pyx_n_s_addtable, __pyx_k_addtable, sizeof(__pyx_k_addtable), 0, 0, 1, 1},
    {&__pyx_n_s_adjacency_matrix, __pyx_k_adjacency_matrix, sizeof(__pyx_k_adjacency_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_adjoint_matrix, __pyx_k_adjoint_matrix, sizeof(__pyx_k_adjoint_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_affichage, __pyx_k_affichage, sizeof(__pyx_k_affichage), 0, 0, 1, 1},
    {&__pyx_n_s_affix, __pyx_k_affix, sizeof(__pyx_k_affix), 0, 0, 1, 1},
    {&__pyx_n_s_algsubs, __pyx_k_algsubs, sizeof(__pyx_k_algsubs), 0, 0, 1, 1},
    {&__pyx_n_s_algvar, __pyx_k_algvar, sizeof(__pyx_k_algvar), 0, 0, 1, 1},
    {&__pyx_n_s_all, __pyx_k_all, sizeof(__pyx_k_all), 0, 0, 1, 1},
    {&__pyx_n_s_all_trig_solutions, __pyx_k_all_trig_solutions, sizeof(__pyx_k_all_trig_solutions), 0, 0, 1, 1},
    {&__pyx_n_s_allpairs_distance, __pyx_k_allpairs_distance, sizeof(__pyx_k_allpairs_distance), 0, 0, 1, 1},
    {&__pyx_n_s_alog10, __pyx_k_alog10, sizeof(__pyx_k_alog10), 0, 0, 1, 1},
    {&__pyx_n_s_alors, __pyx_k_alors, sizeof(__pyx_k_alors), 0, 0, 1, 1},
    {&__pyx_n_s_alpha, __pyx_k_alpha, sizeof(__pyx_k_alpha), 0, 0, 1, 1},
    {&__pyx_n_s_altitude, __pyx_k_altitude, sizeof(__pyx_k_altitude), 0, 0, 1, 1},
    {&__pyx_n_s_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 0, 1, 1},
    {&__pyx_n_s_angl, __pyx_k_angl, sizeof(__pyx_k_angl), 0, 0, 1, 1},
    {&__pyx_n_s_angle, __pyx_k_angle, sizeof(__pyx_k_angle), 0, 0, 1, 1},
    {&__pyx_n_s_angle_radian, __pyx_k_angle_radian, sizeof(__pyx_k_angle_radian), 0, 0, 1, 1},
    {&__pyx_n_s_angleat, __pyx_k_angleat, sizeof(__pyx_k_angleat), 0, 0, 1, 1},
    {&__pyx_n_s_angleatraw, __pyx_k_angleatraw, sizeof(__pyx_k_angleatraw), 0, 0, 1, 1},
    {&__pyx_n_s_animate, __pyx_k_animate, sizeof(__pyx_k_animate), 0, 0, 1, 1},
    {&__pyx_n_s_animate3d, __pyx_k_animate3d, sizeof(__pyx_k_animate3d), 0, 0, 1, 1},
    {&__pyx_n_s_animation, __pyx_k_animation, sizeof(__pyx_k_animation), 0, 0, 1, 1},
    {&__pyx_n_s_ans, __pyx_k_ans, sizeof(__pyx_k_ans), 0, 0, 1, 1},
    {&__pyx_n_s_antiprism_graph, __pyx_k_antiprism_graph, sizeof(__pyx_k_antiprism_graph), 0, 0, 1, 1},
    {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
    {&__pyx_n_s_apply, __pyx_k_apply, sizeof(__pyx_k_apply), 0, 0, 1, 1},
    {&__pyx_n_s_approx, __pyx_k_approx, sizeof(__pyx_k_approx), 0, 0, 1, 1},
    {&__pyx_n_s_approx_mode, __pyx_k_approx_mode, sizeof(__pyx_k_approx_mode), 0, 0, 1, 1},
    {&__pyx_n_s_arc, __pyx_k_arc, sizeof(__pyx_k_arc), 0, 0, 1, 1},
    {&__pyx_n_s_arcLen, __pyx_k_arcLen, sizeof(__pyx_k_arcLen), 0, 0, 1, 1},
    {&__pyx_n_s_arccos, __pyx_k_arccos, sizeof(__pyx_k_arccos), 0, 0, 1, 1},
    {&__pyx_n_s_arccosh, __pyx_k_arccosh, sizeof(__pyx_k_arccosh), 0, 0, 1, 1},
    {&__pyx_n_s_archive, __pyx_k_archive, sizeof(__pyx_k_archive), 0, 0, 1, 1},
    {&__pyx_n_s_arclen, __pyx_k_arclen, sizeof(__pyx_k_arclen), 0, 0, 1, 1},
    {&__pyx_n_s_arcmin, __pyx_k_arcmin, sizeof(__pyx_k_arcmin), 0, 0, 1, 1},
    {&__pyx_n_s_arcs, __pyx_k_arcs, sizeof(__pyx_k_arcs), 0, 0, 1, 1},
    {&__pyx_n_s_arcsin, __pyx_k_arcsin, sizeof(__pyx_k_arcsin), 0, 0, 1, 1},
    {&__pyx_n_s_arcsinh, __pyx_k_arcsinh, sizeof(__pyx_k_arcsinh), 0, 0, 1, 1},
    {&__pyx_n_s_arctan, __pyx_k_arctan, sizeof(__pyx_k_arctan), 0, 0, 1, 1},
    {&__pyx_n_s_arctanh, __pyx_k_arctanh, sizeof(__pyx_k_arctanh), 0, 0, 1, 1},
    {&__pyx_n_s_area, __pyx_k_area, sizeof(__pyx_k_area), 0, 0, 1, 1},
    {&__pyx_n_s_areaat, __pyx_k_areaat, sizeof(__pyx_k_areaat), 0, 0, 1, 1},
    {&__pyx_n_s_areaatraw, __pyx_k_areaatraw, sizeof(__pyx_k_areaatraw), 0, 0, 1, 1},
    {&__pyx_n_s_areaplot, __pyx_k_areaplot, sizeof(__pyx_k_areaplot), 0, 0, 1, 1},
    {&__pyx_n_s_arg, __pyx_k_arg, sizeof(__pyx_k_arg), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_kp_s_argument_must_be_a_Pygen_list_an, __pyx_k_argument_must_be_a_Pygen_list_an, sizeof(__pyx_k_argument_must_be_a_Pygen_list_an), 0, 0, 1, 0},
    {&__pyx_kp_s_argument_must_be_a_tuple_or_a_li, __pyx_k_argument_must_be_a_tuple_or_a_li, sizeof(__pyx_k_argument_must_be_a_tuple_or_a_li), 0, 0, 1, 0},
    {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
    {&__pyx_n_s_arrivals, __pyx_k_arrivals, sizeof(__pyx_k_arrivals), 0, 0, 1, 1},
    {&__pyx_n_s_articulation_points, __pyx_k_articulation_points, sizeof(__pyx_k_articulation_points), 0, 0, 1, 1},
    {&__pyx_n_s_as_function_of, __pyx_k_as_function_of, sizeof(__pyx_k_as_function_of), 0, 0, 1, 1},
    {&__pyx_n_s_asc, __pyx_k_asc, sizeof(__pyx_k_asc), 0, 0, 1, 1},
    {&__pyx_n_s_asec, __pyx_k_asec, sizeof(__pyx_k_asec), 0, 0, 1, 1},
    {&__pyx_n_s_asin, __pyx_k_asin, sizeof(__pyx_k_asin), 0, 0, 1, 1},
    {&__pyx_n_s_asin2acos, __pyx_k_asin2acos, sizeof(__pyx_k_asin2acos), 0, 0, 1, 1},
    {&__pyx_n_s_asin2atan, __pyx_k_asin2atan, sizeof(__pyx_k_asin2atan), 0, 0, 1, 1},
    {&__pyx_n_s_asinh, __pyx_k_asinh, sizeof(__pyx_k_asinh), 0, 0, 1, 1},
    {&__pyx_n_s_assert, __pyx_k_assert, sizeof(__pyx_k_assert), 0, 0, 1, 1},
    {&__pyx_n_s_assign, __pyx_k_assign, sizeof(__pyx_k_assign), 0, 0, 1, 1},
    {&__pyx_n_s_assign_edge_weights, __pyx_k_assign_edge_weights, sizeof(__pyx_k_assign_edge_weights), 0, 0, 1, 1},
    {&__pyx_n_s_assume, __pyx_k_assume, sizeof(__pyx_k_assume), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_at, __pyx_k_at, sizeof(__pyx_k_at), 0, 0, 1, 1},
    {&__pyx_n_s_atan, __pyx_k_atan, sizeof(__pyx_k_atan), 0, 0, 1, 1},
    {&__pyx_n_s_atan2, __pyx_k_atan2, sizeof(__pyx_k_atan2), 0, 0, 1, 1},
    {&__pyx_n_s_atan2acos, __pyx_k_atan2acos, sizeof(__pyx_k_atan2acos), 0, 0, 1, 1},
    {&__pyx_n_s_atan2asin, __pyx_k_atan2asin, sizeof(__pyx_k_atan2asin), 0, 0, 1, 1},
    {&__pyx_n_s_atanh, __pyx_k_atanh, sizeof(__pyx_k_atanh), 0, 0, 1, 1},
    {&__pyx_n_s_atm, __pyx_k_atm, sizeof(__pyx_k_atm), 0, 0, 1, 1},
    {&__pyx_n_s_atrig2ln, __pyx_k_atrig2ln, sizeof(__pyx_k_atrig2ln), 0, 0, 1, 1},
    {&__pyx_n_s_au, __pyx_k_au, sizeof(__pyx_k_au), 0, 0, 1, 1},
    {&__pyx_n_s_augment, __pyx_k_augment, sizeof(__pyx_k_augment), 0, 0, 1, 1},
    {&__pyx_n_s_auto_correlation, __pyx_k_auto_correlation, sizeof(__pyx_k_auto_correlation), 0, 0, 1, 1},
    {&__pyx_n_s_autosimplify, __pyx_k_autosimplify, sizeof(__pyx_k_autosimplify), 0, 0, 1, 1},
    {&__pyx_n_s_avance, __pyx_k_avance, sizeof(__pyx_k_avance), 0, 0, 1, 1},
    {&__pyx_n_s_avgRC, __pyx_k_avgRC, sizeof(__pyx_k_avgRC), 0, 0, 1, 1},
    {&__pyx_n_s_axes, __pyx_k_axes, sizeof(__pyx_k_axes), 0, 0, 1, 1},
    {&__pyx_n_s_axis, __pyx_k_axis, sizeof(__pyx_k_axis), 0, 0, 1, 1},
    {&__pyx_n_s_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 0, 1, 1},
    {&__pyx_n_s_b_2, __pyx_k_b_2, sizeof(__pyx_k_b_2), 0, 0, 1, 1},
    {&__pyx_n_s_back, __pyx_k_back, sizeof(__pyx_k_back), 0, 0, 1, 1},
    {&__pyx_n_s_backquote, __pyx_k_backquote, sizeof(__pyx_k_backquote), 0, 0, 1, 1},
    {&__pyx_n_s_backward, __pyx_k_backward, sizeof(__pyx_k_backward), 0, 0, 1, 1},
    {&__pyx_n_s_baisse_crayon, __pyx_k_baisse_crayon, sizeof(__pyx_k_baisse_crayon), 0, 0, 1, 1},
    {&__pyx_n_s_bandwidth, __pyx_k_bandwidth, sizeof(__pyx_k_bandwidth), 0, 0, 1, 1},
    {&__pyx_n_s_bar, __pyx_k_bar, sizeof(__pyx_k_bar), 0, 0, 1, 1},
    {&__pyx_n_s_bar_plot, __pyx_k_bar_plot, sizeof(__pyx_k_bar_plot), 0, 0, 1, 1},
    {&__pyx_n_s_barplot, __pyx_k_barplot, sizeof(__pyx_k_barplot), 0, 0, 1, 1},
    {&__pyx_n_s_bartlett_hann_window, __pyx_k_bartlett_hann_window, sizeof(__pyx_k_bartlett_hann_window), 0, 0, 1, 1},
    {&__pyx_n_s_barycenter, __pyx_k_barycenter, sizeof(__pyx_k_barycenter), 0, 0, 1, 1},
    {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
    {&__pyx_n_s_basis, __pyx_k_basis, sizeof(__pyx_k_basis), 0, 0, 1, 1},
    {&__pyx_n_s_batons, __pyx_k_batons, sizeof(__pyx_k_batons), 0, 0, 1, 1},
    {&__pyx_n_s_bbl, __pyx_k_bbl, sizeof(__pyx_k_bbl), 0, 0, 1, 1},
    {&__pyx_n_s_bblep, __pyx_k_bblep, sizeof(__pyx_k_bblep), 0, 0, 1, 1},
    {&__pyx_n_s_begin, __pyx_k_begin, sizeof(__pyx_k_begin), 0, 0, 1, 1},
    {&__pyx_n_s_bellman_ford, __pyx_k_bellman_ford, sizeof(__pyx_k_bellman_ford), 0, 0, 1, 1},
    {&__pyx_n_s_berlekamp_massey, __pyx_k_berlekamp_massey, sizeof(__pyx_k_berlekamp_massey), 0, 0, 1, 1},
    {&__pyx_n_s_bernoulli, __pyx_k_bernoulli, sizeof(__pyx_k_bernoulli), 0, 0, 1, 1},
    {&__pyx_n_s_bernoulli_mod, __pyx_k_bernoulli_mod, sizeof(__pyx_k_bernoulli_mod), 0, 0, 1, 1},
    {&__pyx_n_s_besselJ, __pyx_k_besselJ, sizeof(__pyx_k_besselJ), 0, 0, 1, 1},
    {&__pyx_n_s_besselY, __pyx_k_besselY, sizeof(__pyx_k_besselY), 0, 0, 1, 1},
    {&__pyx_n_s_betad, __pyx_k_betad, sizeof(__pyx_k_betad), 0, 0, 1, 1},
    {&__pyx_n_s_betad_cdf, __pyx_k_betad_cdf, sizeof(__pyx_k_betad_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_betad_icdf, __pyx_k_betad_icdf, sizeof(__pyx_k_betad_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_betavariate, __pyx_k_betavariate, sizeof(__pyx_k_betavariate), 0, 0, 1, 1},
    {&__pyx_n_s_betweenness_centrality, __pyx_k_betweenness_centrality, sizeof(__pyx_k_betweenness_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_bezier, __pyx_k_bezier, sizeof(__pyx_k_bezier), 0, 0, 1, 1},
    {&__pyx_n_s_bezout_entiers, __pyx_k_bezout_entiers, sizeof(__pyx_k_bezout_entiers), 0, 0, 1, 1},
    {&__pyx_n_s_bezoutian, __pyx_k_bezoutian, sizeof(__pyx_k_bezoutian), 0, 0, 1, 1},
    {&__pyx_n_s_biconnected_components, __pyx_k_biconnected_components, sizeof(__pyx_k_biconnected_components), 0, 0, 1, 1},
    {&__pyx_n_s_binomial, __pyx_k_binomial, sizeof(__pyx_k_binomial), 0, 0, 1, 1},
    {&__pyx_n_s_binomial_cdf, __pyx_k_binomial_cdf, sizeof(__pyx_k_binomial_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_binomial_icdf, __pyx_k_binomial_icdf, sizeof(__pyx_k_binomial_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_bins, __pyx_k_bins, sizeof(__pyx_k_bins), 0, 0, 1, 1},
    {&__pyx_n_s_bipartite, __pyx_k_bipartite, sizeof(__pyx_k_bipartite), 0, 0, 1, 1},
    {&__pyx_n_s_bipartite_matching, __pyx_k_bipartite_matching, sizeof(__pyx_k_bipartite_matching), 0, 0, 1, 1},
    {&__pyx_n_s_bisection_solver, __pyx_k_bisection_solver, sizeof(__pyx_k_bisection_solver), 0, 0, 1, 1},
    {&__pyx_n_s_bisector, __pyx_k_bisector, sizeof(__pyx_k_bisector), 0, 0, 1, 1},
    {&__pyx_n_s_bit_depth, __pyx_k_bit_depth, sizeof(__pyx_k_bit_depth), 0, 0, 1, 1},
    {&__pyx_n_s_bit_length, __pyx_k_bit_length, sizeof(__pyx_k_bit_length), 0, 0, 1, 1},
    {&__pyx_n_s_bitand, __pyx_k_bitand, sizeof(__pyx_k_bitand), 0, 0, 1, 1},
    {&__pyx_n_s_bitor, __pyx_k_bitor, sizeof(__pyx_k_bitor), 0, 0, 1, 1},
    {&__pyx_n_s_bitxor, __pyx_k_bitxor, sizeof(__pyx_k_bitxor), 0, 0, 1, 1},
    {&__pyx_n_s_black, __pyx_k_black, sizeof(__pyx_k_black), 0, 0, 1, 1},
    {&__pyx_n_s_blacklist, __pyx_k_blacklist, sizeof(__pyx_k_blacklist), 0, 0, 1, 1},
    {&__pyx_n_s_blackman_harris_window, __pyx_k_blackman_harris_window, sizeof(__pyx_k_blackman_harris_window), 0, 0, 1, 1},
    {&__pyx_n_s_blackman_window, __pyx_k_blackman_window, sizeof(__pyx_k_blackman_window), 0, 0, 1, 1},
    {&__pyx_n_s_blanc, __pyx_k_blanc, sizeof(__pyx_k_blanc), 0, 0, 1, 1},
    {&__pyx_n_s_bleu, __pyx_k_bleu, sizeof(__pyx_k_bleu), 0, 0, 1, 1},
    {&__pyx_n_s_bloc, __pyx_k_bloc, sizeof(__pyx_k_bloc), 0, 0, 1, 1},
    {&__pyx_n_s_block_size, __pyx_k_block_size, sizeof(__pyx_k_block_size), 0, 0, 1, 1},
    {&__pyx_n_s_blockmatrix, __pyx_k_blockmatrix, sizeof(__pyx_k_blockmatrix), 0, 0, 1, 1},
    {&__pyx_n_s_blue, __pyx_k_blue, sizeof(__pyx_k_blue), 0, 0, 1, 1},
    {&__pyx_n_s_bohman_window, __pyx_k_bohman_window, sizeof(__pyx_k_bohman_window), 0, 0, 1, 1},
    {&__pyx_n_s_border, __pyx_k_border, sizeof(__pyx_k_border), 0, 0, 1, 1},
    {&__pyx_n_s_box_constraints, __pyx_k_box_constraints, sizeof(__pyx_k_box_constraints), 0, 0, 1, 1},
    {&__pyx_n_s_boxcar, __pyx_k_boxcar, sizeof(__pyx_k_boxcar), 0, 0, 1, 1},
    {&__pyx_n_s_boxwhisker, __pyx_k_boxwhisker, sizeof(__pyx_k_boxwhisker), 0, 0, 1, 1},
    {&__pyx_n_s_break, __pyx_k_break, sizeof(__pyx_k_break), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoint, __pyx_k_breakpoint, sizeof(__pyx_k_breakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_brent_solver, __pyx_k_brent_solver, sizeof(__pyx_k_brent_solver), 0, 0, 1, 1},
    {&__pyx_n_s_brown, __pyx_k_brown, sizeof(__pyx_k_brown), 0, 0, 1, 1},
    {&__pyx_n_s_bspline, __pyx_k_bspline, sizeof(__pyx_k_bspline), 0, 0, 1, 1},
    {&__pyx_n_s_bu, __pyx_k_bu, sizeof(__pyx_k_bu), 0, 0, 1, 1},
    {&__pyx_n_s_buUS, __pyx_k_buUS, sizeof(__pyx_k_buUS), 0, 0, 1, 1},
    {&__pyx_n_s_builtins, __pyx_k_builtins, sizeof(__pyx_k_builtins), 0, 0, 1, 1},
    {&__pyx_n_s_bvpsolve, __pyx_k_bvpsolve, sizeof(__pyx_k_bvpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_by, __pyx_k_by, sizeof(__pyx_k_by), 0, 0, 1, 1},
    {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
    {&__pyx_n_s_c1oc2, __pyx_k_c1oc2, sizeof(__pyx_k_c1oc2), 0, 0, 1, 1},
    {&__pyx_n_s_c1op2, __pyx_k_c1op2, sizeof(__pyx_k_c1op2), 0, 0, 1, 1},
    {&__pyx_n_s_c3, __pyx_k_c3, sizeof(__pyx_k_c3), 0, 0, 1, 1},
    {&__pyx_n_s_cFactor, __pyx_k_cFactor, sizeof(__pyx_k_cFactor), 0, 0, 1, 1},
    {&__pyx_n_s_cSolve, __pyx_k_cSolve, sizeof(__pyx_k_cSolve), 0, 0, 1, 1},
    {&__pyx_n_s_cZeros, __pyx_k_cZeros, sizeof(__pyx_k_cZeros), 0, 0, 1, 1},
    {&__pyx_n_s_cache_tortue, __pyx_k_cache_tortue, sizeof(__pyx_k_cache_tortue), 0, 0, 1, 1},
    {&__pyx_n_s_cal, __pyx_k_cal, sizeof(__pyx_k_cal), 0, 0, 1, 1},
    {&__pyx_n_s_call, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
    {&__pyx_n_s_camembert, __pyx_k_camembert, sizeof(__pyx_k_camembert), 0, 0, 1, 1},
    {&__pyx_n_s_canonical_form, __pyx_k_canonical_form, sizeof(__pyx_k_canonical_form), 0, 0, 1, 1},
    {&__pyx_n_s_canonical_labeling, __pyx_k_canonical_labeling, sizeof(__pyx_k_canonical_labeling), 0, 0, 1, 1},
    {&__pyx_n_s_cap, __pyx_k_cap, sizeof(__pyx_k_cap), 0, 0, 1, 1},
    {&__pyx_n_s_cap_flat_line, __pyx_k_cap_flat_line, sizeof(__pyx_k_cap_flat_line), 0, 0, 1, 1},
    {&__pyx_n_s_cap_round_line, __pyx_k_cap_round_line, sizeof(__pyx_k_cap_round_line), 0, 0, 1, 1},
    {&__pyx_n_s_cap_square_line, __pyx_k_cap_square_line, sizeof(__pyx_k_cap_square_line), 0, 0, 1, 1},
    {&__pyx_n_s_cartesian_product, __pyx_k_cartesian_product, sizeof(__pyx_k_cartesian_product), 0, 0, 1, 1},
    {&__pyx_kp_s_cas_monitor_status, __pyx_k_cas_monitor_status, sizeof(__pyx_k_cas_monitor_status), 0, 0, 1, 0},
    {&__pyx_kp_s_cas_monitor_status_after_killing, __pyx_k_cas_monitor_status_after_killing, sizeof(__pyx_k_cas_monitor_status_after_killing), 0, 0, 1, 0},
    {&__pyx_n_s_cas_setup, __pyx_k_cas_setup, sizeof(__pyx_k_cas_setup), 0, 0, 1, 1},
    {&__pyx_kp_s_cas_setup_2, __pyx_k_cas_setup_2, sizeof(__pyx_k_cas_setup_2), 0, 0, 1, 0},
    {&__pyx_kp_s_cas_setup_s, __pyx_k_cas_setup_s, sizeof(__pyx_k_cas_setup_s), 0, 0, 1, 0},
    {&__pyx_kp_s_cascmd, __pyx_k_cascmd, sizeof(__pyx_k_cascmd), 0, 0, 1, 0},
    {&__pyx_n_s_case, __pyx_k_case, sizeof(__pyx_k_case), 0, 0, 1, 1},
    {&__pyx_n_s_cat, __pyx_k_cat, sizeof(__pyx_k_cat), 0, 0, 1, 1},
    {&__pyx_n_s_catch, __pyx_k_catch, sizeof(__pyx_k_catch), 0, 0, 1, 1},
    {&__pyx_n_s_cauchy, __pyx_k_cauchy, sizeof(__pyx_k_cauchy), 0, 0, 1, 1},
    {&__pyx_n_s_cauchy_cdf, __pyx_k_cauchy_cdf, sizeof(__pyx_k_cauchy_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_cauchy_icdf, __pyx_k_cauchy_icdf, sizeof(__pyx_k_cauchy_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_cauchyd, __pyx_k_cauchyd, sizeof(__pyx_k_cauchyd), 0, 0, 1, 1},
    {&__pyx_n_s_cauchyd_cdf, __pyx_k_cauchyd_cdf, sizeof(__pyx_k_cauchyd_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_cauchyd_icdf, __pyx_k_cauchyd_icdf, sizeof(__pyx_k_cauchyd_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_cd, __pyx_k_cd, sizeof(__pyx_k_cd), 0, 0, 1, 1},
    {&__pyx_n_s_cd_2, __pyx_k_cd_2, sizeof(__pyx_k_cd_2), 0, 0, 1, 1},
    {&__pyx_n_s_cdf, __pyx_k_cdf, sizeof(__pyx_k_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_ceil, __pyx_k_ceil, sizeof(__pyx_k_ceil), 0, 0, 1, 1},
    {&__pyx_n_s_ceiling, __pyx_k_ceiling, sizeof(__pyx_k_ceiling), 0, 0, 1, 1},
    {&__pyx_n_s_center, __pyx_k_center, sizeof(__pyx_k_center), 0, 0, 1, 1},
    {&__pyx_n_s_center2interval, __pyx_k_center2interval, sizeof(__pyx_k_center2interval), 0, 0, 1, 1},
    {&__pyx_n_s_centered_cube, __pyx_k_centered_cube, sizeof(__pyx_k_centered_cube), 0, 0, 1, 1},
    {&__pyx_n_s_centered_tetrahedron, __pyx_k_centered_tetrahedron, sizeof(__pyx_k_centered_tetrahedron), 0, 0, 1, 1},
    {&__pyx_n_s_cfactor, __pyx_k_cfactor, sizeof(__pyx_k_cfactor), 0, 0, 1, 1},
    {&__pyx_n_s_cfsolve, __pyx_k_cfsolve, sizeof(__pyx_k_cfsolve), 0, 0, 1, 1},
    {&__pyx_n_s_chain, __pyx_k_chain, sizeof(__pyx_k_chain), 0, 0, 1, 1},
    {&__pyx_n_s_changebase, __pyx_k_changebase, sizeof(__pyx_k_changebase), 0, 0, 1, 1},
    {&__pyx_n_s_channel_data, __pyx_k_channel_data, sizeof(__pyx_k_channel_data), 0, 0, 1, 1},
    {&__pyx_n_s_channels, __pyx_k_channels, sizeof(__pyx_k_channels), 0, 0, 1, 1},
    {&__pyx_n_s_char, __pyx_k_char, sizeof(__pyx_k_char), 0, 0, 1, 1},
    {&__pyx_n_s_charpoly, __pyx_k_charpoly, sizeof(__pyx_k_charpoly), 0, 0, 1, 1},
    {&__pyx_n_s_chinrem, __pyx_k_chinrem, sizeof(__pyx_k_chinrem), 0, 0, 1, 1},
    {&__pyx_n_s_chisquare, __pyx_k_chisquare, sizeof(__pyx_k_chisquare), 0, 0, 1, 1},
    {&__pyx_n_s_chisquare_cdf, __pyx_k_chisquare_cdf, sizeof(__pyx_k_chisquare_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_chisquare_icdf, __pyx_k_chisquare_icdf, sizeof(__pyx_k_chisquare_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_chisquared, __pyx_k_chisquared, sizeof(__pyx_k_chisquared), 0, 0, 1, 1},
    {&__pyx_n_s_chisquared_cdf, __pyx_k_chisquared_cdf, sizeof(__pyx_k_chisquared_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_chisquared_icdf, __pyx_k_chisquared_icdf, sizeof(__pyx_k_chisquared_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_chisquaret, __pyx_k_chisquaret, sizeof(__pyx_k_chisquaret), 0, 0, 1, 1},
    {&__pyx_n_s_choice, __pyx_k_choice, sizeof(__pyx_k_choice), 0, 0, 1, 1},
    {&__pyx_n_s_cholesky, __pyx_k_cholesky, sizeof(__pyx_k_cholesky), 0, 0, 1, 1},
    {&__pyx_n_s_choosebox, __pyx_k_choosebox, sizeof(__pyx_k_choosebox), 0, 0, 1, 1},
    {&__pyx_n_s_chr, __pyx_k_chr, sizeof(__pyx_k_chr), 0, 0, 1, 1},
    {&__pyx_n_s_chrem, __pyx_k_chrem, sizeof(__pyx_k_chrem), 0, 0, 1, 1},
    {&__pyx_n_s_chromatic_index, __pyx_k_chromatic_index, sizeof(__pyx_k_chromatic_index), 0, 0, 1, 1},
    {&__pyx_n_s_chromatic_number, __pyx_k_chromatic_number, sizeof(__pyx_k_chromatic_number), 0, 0, 1, 1},
    {&__pyx_n_s_chromatic_polynomial, __pyx_k_chromatic_polynomial, sizeof(__pyx_k_chromatic_polynomial), 0, 0, 1, 1},
    {&__pyx_n_s_circle, __pyx_k_circle, sizeof(__pyx_k_circle), 0, 0, 1, 1},
    {&__pyx_n_s_circumcircle, __pyx_k_circumcircle, sizeof(__pyx_k_circumcircle), 0, 0, 1, 1},
    {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_classes, __pyx_k_classes, sizeof(__pyx_k_classes), 0, 0, 1, 1},
    {&__pyx_n_s_clear, __pyx_k_clear, sizeof(__pyx_k_clear), 0, 0, 1, 1},
    {&__pyx_n_s_click, __pyx_k_click, sizeof(__pyx_k_click), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_clique_cover, __pyx_k_clique_cover, sizeof(__pyx_k_clique_cover), 0, 0, 1, 1},
    {&__pyx_n_s_clique_cover_number, __pyx_k_clique_cover_number, sizeof(__pyx_k_clique_cover_number), 0, 0, 1, 1},
    {&__pyx_n_s_clique_number, __pyx_k_clique_number, sizeof(__pyx_k_clique_number), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_closeness_centrality, __pyx_k_closeness_centrality, sizeof(__pyx_k_closeness_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_cluster, __pyx_k_cluster, sizeof(__pyx_k_cluster), 0, 0, 1, 1},
    {&__pyx_n_s_clustering_coefficient, __pyx_k_clustering_coefficient, sizeof(__pyx_k_clustering_coefficient), 0, 0, 1, 1},
    {&__pyx_n_s_cm, __pyx_k_cm, sizeof(__pyx_k_cm), 0, 0, 1, 1},
    {&__pyx_kp_s_cm_2, __pyx_k_cm_2, sizeof(__pyx_k_cm_2), 0, 0, 1, 0},
    {&__pyx_kp_s_cm_3, __pyx_k_cm_3, sizeof(__pyx_k_cm_3), 0, 0, 1, 0},
    {&__pyx_kp_s_cm_s, __pyx_k_cm_s, sizeof(__pyx_k_cm_s), 0, 0, 1, 0},
    {&__pyx_n_s_coeff, __pyx_k_coeff, sizeof(__pyx_k_coeff), 0, 0, 1, 1},
    {&__pyx_n_s_coeffs, __pyx_k_coeffs, sizeof(__pyx_k_coeffs), 0, 0, 1, 1},
    {&__pyx_n_s_col, __pyx_k_col, sizeof(__pyx_k_col), 0, 0, 1, 1},
    {&__pyx_n_s_colDim, __pyx_k_colDim, sizeof(__pyx_k_colDim), 0, 0, 1, 1},
    {&__pyx_n_s_colNorm, __pyx_k_colNorm, sizeof(__pyx_k_colNorm), 0, 0, 1, 1},
    {&__pyx_n_s_colSwap, __pyx_k_colSwap, sizeof(__pyx_k_colSwap), 0, 0, 1, 1},
    {&__pyx_n_s_coldim, __pyx_k_coldim, sizeof(__pyx_k_coldim), 0, 0, 1, 1},
    {&__pyx_n_s_collect, __pyx_k_collect, sizeof(__pyx_k_collect), 0, 0, 1, 1},
    {&__pyx_n_s_colnorm, __pyx_k_colnorm, sizeof(__pyx_k_colnorm), 0, 0, 1, 1},
    {&__pyx_n_s_color, __pyx_k_color, sizeof(__pyx_k_color), 0, 0, 1, 1},
    {&__pyx_n_s_colormap, __pyx_k_colormap, sizeof(__pyx_k_colormap), 0, 0, 1, 1},
    {&__pyx_n_s_colspace, __pyx_k_colspace, sizeof(__pyx_k_colspace), 0, 0, 1, 1},
    {&__pyx_n_s_colswap, __pyx_k_colswap, sizeof(__pyx_k_colswap), 0, 0, 1, 1},
    {&__pyx_n_s_comDenom, __pyx_k_comDenom, sizeof(__pyx_k_comDenom), 0, 0, 1, 1},
    {&__pyx_n_s_comb, __pyx_k_comb, sizeof(__pyx_k_comb), 0, 0, 1, 1},
    {&__pyx_n_s_combine, __pyx_k_combine, sizeof(__pyx_k_combine), 0, 0, 1, 1},
    {&__pyx_n_s_comment, __pyx_k_comment, sizeof(__pyx_k_comment), 0, 0, 1, 1},
    {&__pyx_n_s_common_perpendicular, __pyx_k_common_perpendicular, sizeof(__pyx_k_common_perpendicular), 0, 0, 1, 1},
    {&__pyx_n_s_companion, __pyx_k_companion, sizeof(__pyx_k_companion), 0, 0, 1, 1},
    {&__pyx_n_s_compare, __pyx_k_compare, sizeof(__pyx_k_compare), 0, 0, 1, 1},
    {&__pyx_n_s_complete_binary_tree, __pyx_k_complete_binary_tree, sizeof(__pyx_k_complete_binary_tree), 0, 0, 1, 1},
    {&__pyx_n_s_complete_graph, __pyx_k_complete_graph, sizeof(__pyx_k_complete_graph), 0, 0, 1, 1},
    {&__pyx_n_s_complete_kary_tree, __pyx_k_complete_kary_tree, sizeof(__pyx_k_complete_kary_tree), 0, 0, 1, 1},
    {&__pyx_n_s_complex, __pyx_k_complex, sizeof(__pyx_k_complex), 0, 0, 1, 1},
    {&__pyx_n_s_complex_mode, __pyx_k_complex_mode, sizeof(__pyx_k_complex_mode), 0, 0, 1, 1},
    {&__pyx_n_s_complex_variables, __pyx_k_complex_variables, sizeof(__pyx_k_complex_variables), 0, 0, 1, 1},
    {&__pyx_n_s_complexroot, __pyx_k_complexroot, sizeof(__pyx_k_complexroot), 0, 0, 1, 1},
    {&__pyx_n_s_concat, __pyx_k_concat, sizeof(__pyx_k_concat), 0, 0, 1, 1},
    {&__pyx_n_s_cond, __pyx_k_cond, sizeof(__pyx_k_cond), 0, 0, 1, 1},
    {&__pyx_n_s_condensation, __pyx_k_condensation, sizeof(__pyx_k_condensation), 0, 0, 1, 1},
    {&__pyx_n_s_condi, __pyx_k_condi, sizeof(__pyx_k_condi), 0, 0, 1, 1},
    {&__pyx_n_s_cone, __pyx_k_cone, sizeof(__pyx_k_cone), 0, 0, 1, 1},
    {&__pyx_n_s_confrac, __pyx_k_confrac, sizeof(__pyx_k_confrac), 0, 0, 1, 1},
    {&__pyx_n_s_conic, __pyx_k_conic, sizeof(__pyx_k_conic), 0, 0, 1, 1},
    {&__pyx_n_s_conj, __pyx_k_conj, sizeof(__pyx_k_conj), 0, 0, 1, 1},
    {&__pyx_n_s_conjugate_equation, __pyx_k_conjugate_equation, sizeof(__pyx_k_conjugate_equation), 0, 0, 1, 1},
    {&__pyx_n_s_conjugate_gradient, __pyx_k_conjugate_gradient, sizeof(__pyx_k_conjugate_gradient), 0, 0, 1, 1},
    {&__pyx_n_s_connected, __pyx_k_connected, sizeof(__pyx_k_connected), 0, 0, 1, 1},
    {&__pyx_n_s_connected_components, __pyx_k_connected_components, sizeof(__pyx_k_connected_components), 0, 0, 1, 1},
    {&__pyx_n_s_cont, __pyx_k_cont, sizeof(__pyx_k_cont), 0, 0, 1, 1},
    {&__pyx_n_s_contains, __pyx_k_contains, sizeof(__pyx_k_contains), 0, 0, 1, 1},
    {&__pyx_n_s_content, __pyx_k_content, sizeof(__pyx_k_content), 0, 0, 1, 1},
    {&__pyx_n_s_context_ptr, __pyx_k_context_ptr, sizeof(__pyx_k_context_ptr), 0, 0, 1, 1},
    {&__pyx_n_s_continue, __pyx_k_continue, sizeof(__pyx_k_continue), 0, 0, 1, 1},
    {&__pyx_n_s_contourplot, __pyx_k_contourplot, sizeof(__pyx_k_contourplot), 0, 0, 1, 1},
    {&__pyx_n_s_contract_edge, __pyx_k_contract_edge, sizeof(__pyx_k_contract_edge), 0, 0, 1, 1},
    {&__pyx_n_s_contract_subgraph, __pyx_k_contract_subgraph, sizeof(__pyx_k_contract_subgraph), 0, 0, 1, 1},
    {&__pyx_n_s_convert, __pyx_k_convert, sizeof(__pyx_k_convert), 0, 0, 1, 1},
    {&__pyx_n_s_convertir, __pyx_k_convertir, sizeof(__pyx_k_convertir), 0, 0, 1, 1},
    {&__pyx_n_s_convex, __pyx_k_convex, sizeof(__pyx_k_convex), 0, 0, 1, 1},
    {&__pyx_n_s_convexhull, __pyx_k_convexhull, sizeof(__pyx_k_convexhull), 0, 0, 1, 1},
    {&__pyx_n_s_convolution, __pyx_k_convolution, sizeof(__pyx_k_convolution), 0, 0, 1, 1},
    {&__pyx_n_s_coordinates, __pyx_k_coordinates, sizeof(__pyx_k_coordinates), 0, 0, 1, 1},
    {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
    {&__pyx_n_s_correlation, __pyx_k_correlation, sizeof(__pyx_k_correlation), 0, 0, 1, 1},
    {&__pyx_n_s_cos, __pyx_k_cos, sizeof(__pyx_k_cos), 0, 0, 1, 1},
    {&__pyx_n_s_cos2sintan, __pyx_k_cos2sintan, sizeof(__pyx_k_cos2sintan), 0, 0, 1, 1},
    {&__pyx_n_s_cosh, __pyx_k_cosh, sizeof(__pyx_k_cosh), 0, 0, 1, 1},
    {&__pyx_n_s_cosine_window, __pyx_k_cosine_window, sizeof(__pyx_k_cosine_window), 0, 0, 1, 1},
    {&__pyx_n_s_cot, __pyx_k_cot, sizeof(__pyx_k_cot), 0, 0, 1, 1},
    {&__pyx_n_s_cote, __pyx_k_cote, sizeof(__pyx_k_cote), 0, 0, 1, 1},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_count_eq, __pyx_k_count_eq, sizeof(__pyx_k_count_eq), 0, 0, 1, 1},
    {&__pyx_n_s_count_inf, __pyx_k_count_inf, sizeof(__pyx_k_count_inf), 0, 0, 1, 1},
    {&__pyx_n_s_count_sup, __pyx_k_count_sup, sizeof(__pyx_k_count_sup), 0, 0, 1, 1},
    {&__pyx_n_s_courbe_parametrique, __pyx_k_courbe_parametrique, sizeof(__pyx_k_courbe_parametrique), 0, 0, 1, 1},
    {&__pyx_n_s_courbe_polaire, __pyx_k_courbe_polaire, sizeof(__pyx_k_courbe_polaire), 0, 0, 1, 1},
    {&__pyx_n_s_covariance, __pyx_k_covariance, sizeof(__pyx_k_covariance), 0, 0, 1, 1},
    {&__pyx_n_s_covariance_correlation, __pyx_k_covariance_correlation, sizeof(__pyx_k_covariance_correlation), 0, 0, 1, 1},
    {&__pyx_n_s_cpartfrac, __pyx_k_cpartfrac, sizeof(__pyx_k_cpartfrac), 0, 0, 1, 1},
    {&__pyx_n_s_crationalroot, __pyx_k_crationalroot, sizeof(__pyx_k_crationalroot), 0, 0, 1, 1},
    {&__pyx_n_s_crayon, __pyx_k_crayon, sizeof(__pyx_k_crayon), 0, 0, 1, 1},
    {&__pyx_n_s_createwav, __pyx_k_createwav, sizeof(__pyx_k_createwav), 0, 0, 1, 1},
    {&__pyx_n_s_cross, __pyx_k_cross, sizeof(__pyx_k_cross), 0, 0, 1, 1},
    {&__pyx_n_s_crossP, __pyx_k_crossP, sizeof(__pyx_k_crossP), 0, 0, 1, 1},
    {&__pyx_n_s_cross_correlation, __pyx_k_cross_correlation, sizeof(__pyx_k_cross_correlation), 0, 0, 1, 1},
    {&__pyx_n_s_cross_entropy, __pyx_k_cross_entropy, sizeof(__pyx_k_cross_entropy), 0, 0, 1, 1},
    {&__pyx_n_s_cross_point, __pyx_k_cross_point, sizeof(__pyx_k_cross_point), 0, 0, 1, 1},
    {&__pyx_n_s_cross_ratio, __pyx_k_cross_ratio, sizeof(__pyx_k_cross_ratio), 0, 0, 1, 1},
    {&__pyx_n_s_crossproduct, __pyx_k_crossproduct, sizeof(__pyx_k_crossproduct), 0, 0, 1, 1},
    {&__pyx_n_s_csc, __pyx_k_csc, sizeof(__pyx_k_csc), 0, 0, 1, 1},
    {&__pyx_n_s_csolve, __pyx_k_csolve, sizeof(__pyx_k_csolve), 0, 0, 1, 1},
    {&__pyx_n_s_csv2gen, __pyx_k_csv2gen, sizeof(__pyx_k_csv2gen), 0, 0, 1, 1},
    {&__pyx_n_s_ct, __pyx_k_ct, sizeof(__pyx_k_ct), 0, 0, 1, 1},
    {&__pyx_n_s_cu, __pyx_k_cu, sizeof(__pyx_k_cu), 0, 0, 1, 1},
    {&__pyx_n_s_cube, __pyx_k_cube, sizeof(__pyx_k_cube), 0, 0, 1, 1},
    {&__pyx_n_s_cumSum, __pyx_k_cumSum, sizeof(__pyx_k_cumSum), 0, 0, 1, 1},
    {&__pyx_n_s_cumsum, __pyx_k_cumsum, sizeof(__pyx_k_cumsum), 0, 0, 1, 1},
    {&__pyx_n_s_cumulated_frequencies, __pyx_k_cumulated_frequencies, sizeof(__pyx_k_cumulated_frequencies), 0, 0, 1, 1},
    {&__pyx_n_s_curl, __pyx_k_curl, sizeof(__pyx_k_curl), 0, 0, 1, 1},
    {&__pyx_n_s_current_sheet, __pyx_k_current_sheet, sizeof(__pyx_k_current_sheet), 0, 0, 1, 1},
    {&__pyx_n_s_curvature, __pyx_k_curvature, sizeof(__pyx_k_curvature), 0, 0, 1, 1},
    {&__pyx_n_s_curve, __pyx_k_curve, sizeof(__pyx_k_curve), 0, 0, 1, 1},
    {&__pyx_n_s_cyan, __pyx_k_cyan, sizeof(__pyx_k_cyan), 0, 0, 1, 1},
    {&__pyx_n_s_cycle2perm, __pyx_k_cycle2perm, sizeof(__pyx_k_cycle2perm), 0, 0, 1, 1},
    {&__pyx_n_s_cycle_basis, __pyx_k_cycle_basis, sizeof(__pyx_k_cycle_basis), 0, 0, 1, 1},
    {&__pyx_n_s_cycle_graph, __pyx_k_cycle_graph, sizeof(__pyx_k_cycle_graph), 0, 0, 1, 1},
    {&__pyx_n_s_cycleinv, __pyx_k_cycleinv, sizeof(__pyx_k_cycleinv), 0, 0, 1, 1},
    {&__pyx_n_s_cycles2permu, __pyx_k_cycles2permu, sizeof(__pyx_k_cycles2permu), 0, 0, 1, 1},
    {&__pyx_n_s_cyclotomic, __pyx_k_cyclotomic, sizeof(__pyx_k_cyclotomic), 0, 0, 1, 1},
    {&__pyx_n_s_cylinder, __pyx_k_cylinder, sizeof(__pyx_k_cylinder), 0, 0, 1, 1},
    {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
    {&__pyx_n_s_dB, __pyx_k_dB, sizeof(__pyx_k_dB), 0, 0, 1, 1},
    {&__pyx_n_s_d_2, __pyx_k_d_2, sizeof(__pyx_k_d_2), 0, 0, 1, 1},
    {&__pyx_n_s_dash_line, __pyx_k_dash_line, sizeof(__pyx_k_dash_line), 0, 0, 1, 1},
    {&__pyx_n_s_dashdot_line, __pyx_k_dashdot_line, sizeof(__pyx_k_dashdot_line), 0, 0, 1, 1},
    {&__pyx_n_s_dashdotdot_line, __pyx_k_dashdotdot_line, sizeof(__pyx_k_dashdotdot_line), 0, 0, 1, 1},
    {&__pyx_n_s_dayofweek, __pyx_k_dayofweek, sizeof(__pyx_k_dayofweek), 0, 0, 1, 1},
    {&__pyx_n_s_de, __pyx_k_de, sizeof(__pyx_k_de), 0, 0, 1, 1},
    {&__pyx_n_s_deSolve, __pyx_k_deSolve, sizeof(__pyx_k_deSolve), 0, 0, 1, 1},
    {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
    {&__pyx_n_s_debut_enregistrement, __pyx_k_debut_enregistrement, sizeof(__pyx_k_debut_enregistrement), 0, 0, 1, 1},
    {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
    {&__pyx_n_s_decstring23, __pyx_k_decstring23, sizeof(__pyx_k_decstring23), 0, 0, 1, 1},
    {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
    {&__pyx_n_s_deg, __pyx_k_deg, sizeof(__pyx_k_deg), 0, 0, 1, 1},
    {&__pyx_n_s_degree, __pyx_k_degree, sizeof(__pyx_k_degree), 0, 0, 1, 1},
    {&__pyx_n_s_degreeF, __pyx_k_degreeF, sizeof(__pyx_k_degreeF), 0, 0, 1, 1},
    {&__pyx_n_s_degree_centrality, __pyx_k_degree_centrality, sizeof(__pyx_k_degree_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_degree_sequence, __pyx_k_degree_sequence, sizeof(__pyx_k_degree_sequence), 0, 0, 1, 1},
    {&__pyx_n_s_degrees, __pyx_k_degrees, sizeof(__pyx_k_degrees), 0, 0, 1, 1},
    {&__pyx_n_s_del, __pyx_k_del, sizeof(__pyx_k_del), 0, 0, 1, 1},
    {&__pyx_n_s_delcols, __pyx_k_delcols, sizeof(__pyx_k_delcols), 0, 0, 1, 1},
    {&__pyx_n_s_delete_arc, __pyx_k_delete_arc, sizeof(__pyx_k_delete_arc), 0, 0, 1, 1},
    {&__pyx_n_s_delete_edge, __pyx_k_delete_edge, sizeof(__pyx_k_delete_edge), 0, 0, 1, 1},
    {&__pyx_n_s_delete_vertex, __pyx_k_delete_vertex, sizeof(__pyx_k_delete_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_delrows, __pyx_k_delrows, sizeof(__pyx_k_delrows), 0, 0, 1, 1},
    {&__pyx_n_s_deltalist, __pyx_k_deltalist, sizeof(__pyx_k_deltalist), 0, 0, 1, 1},
    {&__pyx_n_s_denom, __pyx_k_denom, sizeof(__pyx_k_denom), 0, 0, 1, 1},
    {&__pyx_n_s_densityplot, __pyx_k_densityplot, sizeof(__pyx_k_densityplot), 0, 0, 1, 1},
    {&__pyx_n_s_departures, __pyx_k_departures, sizeof(__pyx_k_departures), 0, 0, 1, 1},
    {&__pyx_n_s_derive, __pyx_k_derive, sizeof(__pyx_k_derive), 0, 0, 1, 1},
    {&__pyx_n_s_deriver, __pyx_k_deriver, sizeof(__pyx_k_deriver), 0, 0, 1, 1},
    {&__pyx_n_s_desolve, __pyx_k_desolve, sizeof(__pyx_k_desolve), 0, 0, 1, 1},
    {&__pyx_n_s_dessine_tortue, __pyx_k_dessine_tortue, sizeof(__pyx_k_dessine_tortue), 0, 0, 1, 1},
    {&__pyx_n_s_det, __pyx_k_det, sizeof(__pyx_k_det), 0, 0, 1, 1},
    {&__pyx_n_s_det_minor, __pyx_k_det_minor, sizeof(__pyx_k_det_minor), 0, 0, 1, 1},
    {&__pyx_n_s_developper, __pyx_k_developper, sizeof(__pyx_k_developper), 0, 0, 1, 1},
    {&__pyx_n_s_developper_transcendant, __pyx_k_developper_transcendant, sizeof(__pyx_k_developper_transcendant), 0, 0, 1, 1},
    {&__pyx_n_s_dfc, __pyx_k_dfc, sizeof(__pyx_k_dfc), 0, 0, 1, 1},
    {&__pyx_n_s_dfc2f, __pyx_k_dfc2f, sizeof(__pyx_k_dfc2f), 0, 0, 1, 1},
    {&__pyx_n_s_diag, __pyx_k_diag, sizeof(__pyx_k_diag), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_n_s_diff, __pyx_k_diff, sizeof(__pyx_k_diff), 0, 0, 1, 1},
    {&__pyx_n_s_digraph, __pyx_k_digraph, sizeof(__pyx_k_digraph), 0, 0, 1, 1},
    {&__pyx_n_s_dijkstra, __pyx_k_dijkstra, sizeof(__pyx_k_dijkstra), 0, 0, 1, 1},
    {&__pyx_n_s_dim, __pyx_k_dim, sizeof(__pyx_k_dim), 0, 0, 1, 1},
    {&__pyx_n_s_directed, __pyx_k_directed, sizeof(__pyx_k_directed), 0, 0, 1, 1},
    {&__pyx_n_s_directevalued, __pyx_k_directevalued, sizeof(__pyx_k_directevalued), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_discard_edge_attribute, __pyx_k_discard_edge_attribute, sizeof(__pyx_k_discard_edge_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_discard_graph_attribute, __pyx_k_discard_graph_attribute, sizeof(__pyx_k_discard_graph_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_discard_vertex_attribute, __pyx_k_discard_vertex_attribute, sizeof(__pyx_k_discard_vertex_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_disjoint_union, __pyx_k_disjoint_union, sizeof(__pyx_k_disjoint_union), 0, 0, 1, 1},
    {&__pyx_n_s_display, __pyx_k_display, sizeof(__pyx_k_display), 0, 0, 1, 1},
    {&__pyx_n_s_disque, __pyx_k_disque, sizeof(__pyx_k_disque), 0, 0, 1, 1},
    {&__pyx_n_s_disque_centre, __pyx_k_disque_centre, sizeof(__pyx_k_disque_centre), 0, 0, 1, 1},
    {&__pyx_n_s_distance, __pyx_k_distance, sizeof(__pyx_k_distance), 0, 0, 1, 1},
    {&__pyx_n_s_distance2, __pyx_k_distance2, sizeof(__pyx_k_distance2), 0, 0, 1, 1},
    {&__pyx_n_s_distanceat, __pyx_k_distanceat, sizeof(__pyx_k_distanceat), 0, 0, 1, 1},
    {&__pyx_n_s_distanceatraw, __pyx_k_distanceatraw, sizeof(__pyx_k_distanceatraw), 0, 0, 1, 1},
    {&__pyx_n_s_div, __pyx_k_div, sizeof(__pyx_k_div), 0, 0, 1, 1},
    {&__pyx_n_s_div_2, __pyx_k_div_2, sizeof(__pyx_k_div_2), 0, 0, 1, 1},
    {&__pyx_n_s_divergence, __pyx_k_divergence, sizeof(__pyx_k_divergence), 0, 0, 1, 1},
    {&__pyx_n_s_divide, __pyx_k_divide, sizeof(__pyx_k_divide), 0, 0, 1, 1},
    {&__pyx_n_s_divis, __pyx_k_divis, sizeof(__pyx_k_divis), 0, 0, 1, 1},
    {&__pyx_n_s_division_point, __pyx_k_division_point, sizeof(__pyx_k_division_point), 0, 0, 1, 1},
    {&__pyx_n_s_divisors, __pyx_k_divisors, sizeof(__pyx_k_divisors), 0, 0, 1, 1},
    {&__pyx_n_s_divmod, __pyx_k_divmod, sizeof(__pyx_k_divmod), 0, 0, 1, 1},
    {&__pyx_n_s_divpc, __pyx_k_divpc, sizeof(__pyx_k_divpc), 0, 0, 1, 1},
    {&__pyx_n_s_dnewton_solver, __pyx_k_dnewton_solver, sizeof(__pyx_k_dnewton_solver), 0, 0, 1, 1},
    {&__pyx_n_s_do, __pyx_k_do, sizeof(__pyx_k_do), 0, 0, 1, 1},
    {&__pyx_kp_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 0},
    {&__pyx_n_s_doc_2, __pyx_k_doc_2, sizeof(__pyx_k_doc_2), 0, 0, 1, 1},
    {&__pyx_n_s_dodecahedron, __pyx_k_dodecahedron, sizeof(__pyx_k_dodecahedron), 0, 0, 1, 1},
    {&__pyx_n_s_domain, __pyx_k_domain, sizeof(__pyx_k_domain), 0, 0, 1, 1},
    {&__pyx_n_s_dot, __pyx_k_dot, sizeof(__pyx_k_dot), 0, 0, 1, 1},
    {&__pyx_n_s_dotP, __pyx_k_dotP, sizeof(__pyx_k_dotP), 0, 0, 1, 1},
    {&__pyx_n_s_dot_paper, __pyx_k_dot_paper, sizeof(__pyx_k_dot_paper), 0, 0, 1, 1},
    {&__pyx_n_s_dotprod, __pyx_k_dotprod, sizeof(__pyx_k_dotprod), 0, 0, 1, 1},
    {&__pyx_n_s_double, __pyx_k_double, sizeof(__pyx_k_double), 0, 0, 1, 1},
    {&__pyx_n_s_double_2, __pyx_k_double_2, sizeof(__pyx_k_double_2), 0, 0, 1, 1},
    {&__pyx_n_s_draw_arc, __pyx_k_draw_arc, sizeof(__pyx_k_draw_arc), 0, 0, 1, 1},
    {&__pyx_n_s_draw_circle, __pyx_k_draw_circle, sizeof(__pyx_k_draw_circle), 0, 0, 1, 1},
    {&__pyx_n_s_draw_graph, __pyx_k_draw_graph, sizeof(__pyx_k_draw_graph), 0, 0, 1, 1},
    {&__pyx_n_s_draw_line, __pyx_k_draw_line, sizeof(__pyx_k_draw_line), 0, 0, 1, 1},
    {&__pyx_n_s_draw_pixel, __pyx_k_draw_pixel, sizeof(__pyx_k_draw_pixel), 0, 0, 1, 1},
    {&__pyx_n_s_draw_polygon, __pyx_k_draw_polygon, sizeof(__pyx_k_draw_polygon), 0, 0, 1, 1},
    {&__pyx_n_s_draw_rectangle, __pyx_k_draw_rectangle, sizeof(__pyx_k_draw_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_droit, __pyx_k_droit, sizeof(__pyx_k_droit), 0, 0, 1, 1},
    {&__pyx_n_s_droite_tangente, __pyx_k_droite_tangente, sizeof(__pyx_k_droite_tangente), 0, 0, 1, 1},
    {&__pyx_n_s_dsolve, __pyx_k_dsolve, sizeof(__pyx_k_dsolve), 0, 0, 1, 1},
    {&__pyx_n_s_duration, __pyx_k_duration, sizeof(__pyx_k_duration), 0, 0, 1, 1},
    {&__pyx_n_s_dwt, __pyx_k_dwt, sizeof(__pyx_k_dwt), 0, 0, 1, 1},
    {&__pyx_n_s_dyn, __pyx_k_dyn, sizeof(__pyx_k_dyn), 0, 0, 1, 1},
    {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
    {&__pyx_n_s_e2r, __pyx_k_e2r, sizeof(__pyx_k_e2r), 0, 0, 1, 1},
    {&__pyx_n_s_eV, __pyx_k_eV, sizeof(__pyx_k_eV), 0, 0, 1, 1},
    {&__pyx_n_s_ecart_type, __pyx_k_ecart_type, sizeof(__pyx_k_ecart_type), 0, 0, 1, 1},
    {&__pyx_n_s_ecart_type_population, __pyx_k_ecart_type_population, sizeof(__pyx_k_ecart_type_population), 0, 0, 1, 1},
    {&__pyx_n_s_ecef2geodetic, __pyx_k_ecef2geodetic, sizeof(__pyx_k_ecef2geodetic), 0, 0, 1, 1},
    {&__pyx_n_s_ecm_factor, __pyx_k_ecm_factor, sizeof(__pyx_k_ecm_factor), 0, 0, 1, 1},
    {&__pyx_n_s_ecris, __pyx_k_ecris, sizeof(__pyx_k_ecris), 0, 0, 1, 1},
    {&__pyx_n_s_edge_connectivity, __pyx_k_edge_connectivity, sizeof(__pyx_k_edge_connectivity), 0, 0, 1, 1},
    {&__pyx_n_s_edges, __pyx_k_edges, sizeof(__pyx_k_edges), 0, 0, 1, 1},
    {&__pyx_n_s_efface, __pyx_k_efface, sizeof(__pyx_k_efface), 0, 0, 1, 1},
    {&__pyx_n_s_egcd, __pyx_k_egcd, sizeof(__pyx_k_egcd), 0, 0, 1, 1},
    {&__pyx_n_s_egv, __pyx_k_egv, sizeof(__pyx_k_egv), 0, 0, 1, 1},
    {&__pyx_n_s_egvl, __pyx_k_egvl, sizeof(__pyx_k_egvl), 0, 0, 1, 1},
    {&__pyx_n_s_eigVc, __pyx_k_eigVc, sizeof(__pyx_k_eigVc), 0, 0, 1, 1},
    {&__pyx_n_s_eigVl, __pyx_k_eigVl, sizeof(__pyx_k_eigVl), 0, 0, 1, 1},
    {&__pyx_n_s_eigenvals, __pyx_k_eigenvals, sizeof(__pyx_k_eigenvals), 0, 0, 1, 1},
    {&__pyx_n_s_eigenvalues, __pyx_k_eigenvalues, sizeof(__pyx_k_eigenvalues), 0, 0, 1, 1},
    {&__pyx_n_s_eigenvectors, __pyx_k_eigenvectors, sizeof(__pyx_k_eigenvectors), 0, 0, 1, 1},
    {&__pyx_n_s_eigenvects, __pyx_k_eigenvects, sizeof(__pyx_k_eigenvects), 0, 0, 1, 1},
    {&__pyx_n_s_el, __pyx_k_el, sizeof(__pyx_k_el), 0, 0, 1, 1},
    {&__pyx_n_s_element, __pyx_k_element, sizeof(__pyx_k_element), 0, 0, 1, 1},
    {&__pyx_n_s_elif, __pyx_k_elif, sizeof(__pyx_k_elif), 0, 0, 1, 1},
    {&__pyx_n_s_eliminate, __pyx_k_eliminate, sizeof(__pyx_k_eliminate), 0, 0, 1, 1},
    {&__pyx_n_s_ellipse, __pyx_k_ellipse, sizeof(__pyx_k_ellipse), 0, 0, 1, 1},
    {&__pyx_n_s_else, __pyx_k_else, sizeof(__pyx_k_else), 0, 0, 1, 1},
    {&__pyx_n_s_emd, __pyx_k_emd, sizeof(__pyx_k_emd), 0, 0, 1, 1},
    {&__pyx_n_s_en, __pyx_k_en, sizeof(__pyx_k_en), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_encstring23, __pyx_k_encstring23, sizeof(__pyx_k_encstring23), 0, 0, 1, 1},
    {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
    {&__pyx_n_s_end_for, __pyx_k_end_for, sizeof(__pyx_k_end_for), 0, 0, 1, 1},
    {&__pyx_n_s_end_if, __pyx_k_end_if, sizeof(__pyx_k_end_if), 0, 0, 1, 1},
    {&__pyx_n_s_end_while, __pyx_k_end_while, sizeof(__pyx_k_end_while), 0, 0, 1, 1},
    {&__pyx_n_s_entry, __pyx_k_entry, sizeof(__pyx_k_entry), 0, 0, 1, 1},
    {&__pyx_n_s_envelope, __pyx_k_envelope, sizeof(__pyx_k_envelope), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur, __pyx_k_epaisseur, sizeof(__pyx_k_epaisseur), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_1, __pyx_k_epaisseur_ligne_1, sizeof(__pyx_k_epaisseur_ligne_1), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_2, __pyx_k_epaisseur_ligne_2, sizeof(__pyx_k_epaisseur_ligne_2), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_3, __pyx_k_epaisseur_ligne_3, sizeof(__pyx_k_epaisseur_ligne_3), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_4, __pyx_k_epaisseur_ligne_4, sizeof(__pyx_k_epaisseur_ligne_4), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_5, __pyx_k_epaisseur_ligne_5, sizeof(__pyx_k_epaisseur_ligne_5), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_6, __pyx_k_epaisseur_ligne_6, sizeof(__pyx_k_epaisseur_ligne_6), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_ligne_7, __pyx_k_epaisseur_ligne_7, sizeof(__pyx_k_epaisseur_ligne_7), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_1, __pyx_k_epaisseur_point_1, sizeof(__pyx_k_epaisseur_point_1), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_2, __pyx_k_epaisseur_point_2, sizeof(__pyx_k_epaisseur_point_2), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_3, __pyx_k_epaisseur_point_3, sizeof(__pyx_k_epaisseur_point_3), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_4, __pyx_k_epaisseur_point_4, sizeof(__pyx_k_epaisseur_point_4), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_5, __pyx_k_epaisseur_point_5, sizeof(__pyx_k_epaisseur_point_5), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_6, __pyx_k_epaisseur_point_6, sizeof(__pyx_k_epaisseur_point_6), 0, 0, 1, 1},
    {&__pyx_n_s_epaisseur_point_7, __pyx_k_epaisseur_point_7, sizeof(__pyx_k_epaisseur_point_7), 0, 0, 1, 1},
    {&__pyx_n_s_epsilon, __pyx_k_epsilon, sizeof(__pyx_k_epsilon), 0, 0, 1, 1},
    {&__pyx_n_s_epsilon0, __pyx_k_epsilon0, sizeof(__pyx_k_epsilon0), 0, 0, 1, 1},
    {&__pyx_n_s_epsilon0q, __pyx_k_epsilon0q, sizeof(__pyx_k_epsilon0q), 0, 0, 1, 1},
    {&__pyx_n_s_epsilon2zero, __pyx_k_epsilon2zero, sizeof(__pyx_k_epsilon2zero), 0, 0, 1, 1},
    {&__pyx_n_s_epsilonox, __pyx_k_epsilonox, sizeof(__pyx_k_epsilonox), 0, 0, 1, 1},
    {&__pyx_n_s_epsilonsi, __pyx_k_epsilonsi, sizeof(__pyx_k_epsilonsi), 0, 0, 1, 1},
    {&__pyx_n_s_equal, __pyx_k_equal, sizeof(__pyx_k_equal), 0, 0, 1, 1},
    {&__pyx_n_s_equal2diff, __pyx_k_equal2diff, sizeof(__pyx_k_equal2diff), 0, 0, 1, 1},
    {&__pyx_n_s_equal2list, __pyx_k_equal2list, sizeof(__pyx_k_equal2list), 0, 0, 1, 1},
    {&__pyx_n_s_equation, __pyx_k_equation, sizeof(__pyx_k_equation), 0, 0, 1, 1},
    {&__pyx_n_s_equilateral_triangle, __pyx_k_equilateral_triangle, sizeof(__pyx_k_equilateral_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_erase, __pyx_k_erase, sizeof(__pyx_k_erase), 0, 0, 1, 1},
    {&__pyx_n_s_erase3d, __pyx_k_erase3d, sizeof(__pyx_k_erase3d), 0, 0, 1, 1},
    {&__pyx_n_s_erf, __pyx_k_erf, sizeof(__pyx_k_erf), 0, 0, 1, 1},
    {&__pyx_n_s_erfc, __pyx_k_erfc, sizeof(__pyx_k_erfc), 0, 0, 1, 1},
    {&__pyx_n_s_erg, __pyx_k_erg, sizeof(__pyx_k_erg), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_n_s_est_cocyclique, __pyx_k_est_cocyclique, sizeof(__pyx_k_est_cocyclique), 0, 0, 1, 1},
    {&__pyx_n_s_est_inclus, __pyx_k_est_inclus, sizeof(__pyx_k_est_inclus), 0, 0, 1, 1},
    {&__pyx_n_s_est_permu, __pyx_k_est_permu, sizeof(__pyx_k_est_permu), 0, 0, 1, 1},
    {&__pyx_n_s_et, __pyx_k_et, sizeof(__pyx_k_et), 0, 0, 1, 1},
    {&__pyx_n_s_euler, __pyx_k_euler, sizeof(__pyx_k_euler), 0, 0, 1, 1},
    {&__pyx_n_s_euler_gamma, __pyx_k_euler_gamma, sizeof(__pyx_k_euler_gamma), 0, 0, 1, 1},
    {&__pyx_n_s_euler_lagrange, __pyx_k_euler_lagrange, sizeof(__pyx_k_euler_lagrange), 0, 0, 1, 1},
    {&__pyx_n_s_eval, __pyx_k_eval, sizeof(__pyx_k_eval), 0, 0, 1, 1},
    {&__pyx_n_s_eval_level, __pyx_k_eval_level, sizeof(__pyx_k_eval_level), 0, 0, 1, 1},
    {&__pyx_n_s_evala, __pyx_k_evala, sizeof(__pyx_k_evala), 0, 0, 1, 1},
    {&__pyx_n_s_evalb, __pyx_k_evalb, sizeof(__pyx_k_evalb), 0, 0, 1, 1},
    {&__pyx_n_s_evalc, __pyx_k_evalc, sizeof(__pyx_k_evalc), 0, 0, 1, 1},
    {&__pyx_n_s_evalf, __pyx_k_evalf, sizeof(__pyx_k_evalf), 0, 0, 1, 1},
    {&__pyx_n_s_evalm, __pyx_k_evalm, sizeof(__pyx_k_evalm), 0, 0, 1, 1},
    {&__pyx_n_s_even, __pyx_k_even, sizeof(__pyx_k_even), 0, 0, 1, 1},
    {&__pyx_n_s_evolute, __pyx_k_evolute, sizeof(__pyx_k_evolute), 0, 0, 1, 1},
    {&__pyx_n_s_exact, __pyx_k_exact, sizeof(__pyx_k_exact), 0, 0, 1, 1},
    {&__pyx_n_s_exbisector, __pyx_k_exbisector, sizeof(__pyx_k_exbisector), 0, 0, 1, 1},
    {&__pyx_n_s_excircle, __pyx_k_excircle, sizeof(__pyx_k_excircle), 0, 0, 1, 1},
    {&__pyx_n_s_execute, __pyx_k_execute, sizeof(__pyx_k_execute), 0, 0, 1, 1},
    {&__pyx_n_s_exp, __pyx_k_exp, sizeof(__pyx_k_exp), 0, 0, 1, 1},
    {&__pyx_n_s_exp2list, __pyx_k_exp2list, sizeof(__pyx_k_exp2list), 0, 0, 1, 1},
    {&__pyx_n_s_exp2pow, __pyx_k_exp2pow, sizeof(__pyx_k_exp2pow), 0, 0, 1, 1},
    {&__pyx_n_s_exp2trig, __pyx_k_exp2trig, sizeof(__pyx_k_exp2trig), 0, 0, 1, 1},
    {&__pyx_n_s_expand, __pyx_k_expand, sizeof(__pyx_k_expand), 0, 0, 1, 1},
    {&__pyx_n_s_expexpand, __pyx_k_expexpand, sizeof(__pyx_k_expexpand), 0, 0, 1, 1},
    {&__pyx_n_s_expln, __pyx_k_expln, sizeof(__pyx_k_expln), 0, 0, 1, 1},
    {&__pyx_n_s_exponential, __pyx_k_exponential, sizeof(__pyx_k_exponential), 0, 0, 1, 1},
    {&__pyx_n_s_exponential_cdf, __pyx_k_exponential_cdf, sizeof(__pyx_k_exponential_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_exponential_icdf, __pyx_k_exponential_icdf, sizeof(__pyx_k_exponential_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_exponential_regression, __pyx_k_exponential_regression, sizeof(__pyx_k_exponential_regression), 0, 0, 1, 1},
    {&__pyx_n_s_exponential_regression_plot, __pyx_k_exponential_regression_plot, sizeof(__pyx_k_exponential_regression_plot), 0, 0, 1, 1},
    {&__pyx_n_s_exponentiald, __pyx_k_exponentiald, sizeof(__pyx_k_exponentiald), 0, 0, 1, 1},
    {&__pyx_n_s_exponentiald_cdf, __pyx_k_exponentiald_cdf, sizeof(__pyx_k_exponentiald_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_exponentiald_icdf, __pyx_k_exponentiald_icdf, sizeof(__pyx_k_exponentiald_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_export_graph, __pyx_k_export_graph, sizeof(__pyx_k_export_graph), 0, 0, 1, 1},
    {&__pyx_n_s_export_mathml, __pyx_k_export_mathml, sizeof(__pyx_k_export_mathml), 0, 0, 1, 1},
    {&__pyx_n_s_expovariate, __pyx_k_expovariate, sizeof(__pyx_k_expovariate), 0, 0, 1, 1},
    {&__pyx_n_s_expr, __pyx_k_expr, sizeof(__pyx_k_expr), 0, 0, 1, 1},
    {&__pyx_n_s_expression, __pyx_k_expression, sizeof(__pyx_k_expression), 0, 0, 1, 1},
    {&__pyx_n_s_extend, __pyx_k_extend, sizeof(__pyx_k_extend), 0, 0, 1, 1},
    {&__pyx_n_s_extract_measure, __pyx_k_extract_measure, sizeof(__pyx_k_extract_measure), 0, 0, 1, 1},
    {&__pyx_n_s_extrema, __pyx_k_extrema, sizeof(__pyx_k_extrema), 0, 0, 1, 1},
    {&__pyx_n_s_ezgcd, __pyx_k_ezgcd, sizeof(__pyx_k_ezgcd), 0, 0, 1, 1},
    {&__pyx_n_s_f0, __pyx_k_f0, sizeof(__pyx_k_f0), 0, 0, 1, 1},
    {&__pyx_n_s_f2nd, __pyx_k_f2nd, sizeof(__pyx_k_f2nd), 0, 0, 1, 1},
    {&__pyx_n_s_fMax, __pyx_k_fMax, sizeof(__pyx_k_fMax), 0, 0, 1, 1},
    {&__pyx_n_s_fMin, __pyx_k_fMin, sizeof(__pyx_k_fMin), 0, 0, 1, 1},
    {&__pyx_n_s_fPart, __pyx_k_fPart, sizeof(__pyx_k_fPart), 0, 0, 1, 1},
    {&__pyx_n_s_faces, __pyx_k_faces, sizeof(__pyx_k_faces), 0, 0, 1, 1},
    {&__pyx_n_s_facteurs_premiers, __pyx_k_facteurs_premiers, sizeof(__pyx_k_facteurs_premiers), 0, 0, 1, 1},
    {&__pyx_n_s_factor, __pyx_k_factor, sizeof(__pyx_k_factor), 0, 0, 1, 1},
    {&__pyx_n_s_factor_xn, __pyx_k_factor_xn, sizeof(__pyx_k_factor_xn), 0, 0, 1, 1},
    {&__pyx_n_s_factorial, __pyx_k_factorial, sizeof(__pyx_k_factorial), 0, 0, 1, 1},
    {&__pyx_n_s_factoriser, __pyx_k_factoriser, sizeof(__pyx_k_factoriser), 0, 0, 1, 1},
    {&__pyx_n_s_factoriser_entier, __pyx_k_factoriser_entier, sizeof(__pyx_k_factoriser_entier), 0, 0, 1, 1},
    {&__pyx_n_s_factoriser_sur_C, __pyx_k_factoriser_sur_C, sizeof(__pyx_k_factoriser_sur_C), 0, 0, 1, 1},
    {&__pyx_n_s_factors, __pyx_k_factors, sizeof(__pyx_k_factors), 0, 0, 1, 1},
    {&__pyx_n_s_fadeev, __pyx_k_fadeev, sizeof(__pyx_k_fadeev), 0, 0, 1, 1},
    {&__pyx_kp_s_failed_to_init_doc_from_giac_s_d, __pyx_k_failed_to_init_doc_from_giac_s_d, sizeof(__pyx_k_failed_to_init_doc_from_giac_s_d), 0, 0, 1, 0},
    {&__pyx_n_s_faire, __pyx_k_faire, sizeof(__pyx_k_faire), 0, 0, 1, 1},
    {&__pyx_n_s_false, __pyx_k_false, sizeof(__pyx_k_false), 0, 0, 1, 1},
    {&__pyx_n_s_falsepos_solver, __pyx_k_falsepos_solver, sizeof(__pyx_k_falsepos_solver), 0, 0, 1, 1},
    {&__pyx_n_s_fath, __pyx_k_fath, sizeof(__pyx_k_fath), 0, 0, 1, 1},
    {&__pyx_n_s_faux, __pyx_k_faux, sizeof(__pyx_k_faux), 0, 0, 1, 1},
    {&__pyx_n_s_fbm, __pyx_k_fbm, sizeof(__pyx_k_fbm), 0, 0, 1, 1},
    {&__pyx_n_s_fc, __pyx_k_fc, sizeof(__pyx_k_fc), 0, 0, 1, 1},
    {&__pyx_n_s_fclose, __pyx_k_fclose, sizeof(__pyx_k_fclose), 0, 0, 1, 1},
    {&__pyx_n_s_fcoeff, __pyx_k_fcoeff, sizeof(__pyx_k_fcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_fdistrib, __pyx_k_fdistrib, sizeof(__pyx_k_fdistrib), 0, 0, 1, 1},
    {&__pyx_n_s_fermi, __pyx_k_fermi, sizeof(__pyx_k_fermi), 0, 0, 1, 1},
    {&__pyx_n_s_feuille, __pyx_k_feuille, sizeof(__pyx_k_feuille), 0, 0, 1, 1},
    {&__pyx_n_s_ffaire, __pyx_k_ffaire, sizeof(__pyx_k_ffaire), 0, 0, 1, 1},
    {&__pyx_n_s_ffonction, __pyx_k_ffonction, sizeof(__pyx_k_ffonction), 0, 0, 1, 1},
    {&__pyx_n_s_fft, __pyx_k_fft, sizeof(__pyx_k_fft), 0, 0, 1, 1},
    {&__pyx_n_s_ffunction, __pyx_k_ffunction, sizeof(__pyx_k_ffunction), 0, 0, 1, 1},
    {&__pyx_n_s_fi, __pyx_k_fi, sizeof(__pyx_k_fi), 0, 0, 1, 1},
    {&__pyx_n_s_fieldplot, __pyx_k_fieldplot, sizeof(__pyx_k_fieldplot), 0, 0, 1, 1},
    {&__pyx_kp_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 0},
    {&__pyx_n_s_filename, __pyx_k_filename, sizeof(__pyx_k_filename), 0, 0, 1, 1},
    {&__pyx_n_s_filled, __pyx_k_filled, sizeof(__pyx_k_filled), 0, 0, 1, 1},
    {&__pyx_n_s_fin_enregistrement, __pyx_k_fin_enregistrement, sizeof(__pyx_k_fin_enregistrement), 0, 0, 1, 1},
    {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
    {&__pyx_n_s_find_cliques, __pyx_k_find_cliques, sizeof(__pyx_k_find_cliques), 0, 0, 1, 1},
    {&__pyx_n_s_find_cycles, __pyx_k_find_cycles, sizeof(__pyx_k_find_cycles), 0, 0, 1, 1},
    {&__pyx_n_s_find_minimum, __pyx_k_find_minimum, sizeof(__pyx_k_find_minimum), 0, 0, 1, 1},
    {&__pyx_n_s_find_vertex_cover, __pyx_k_find_vertex_cover, sizeof(__pyx_k_find_vertex_cover), 0, 0, 1, 1},
    {&__pyx_n_s_findhelp, __pyx_k_findhelp, sizeof(__pyx_k_findhelp), 0, 0, 1, 1},
    {&__pyx_n_s_fisher, __pyx_k_fisher, sizeof(__pyx_k_fisher), 0, 0, 1, 1},
    {&__pyx_n_s_fisher_cdf, __pyx_k_fisher_cdf, sizeof(__pyx_k_fisher_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_fisher_icdf, __pyx_k_fisher_icdf, sizeof(__pyx_k_fisher_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_fisherd, __pyx_k_fisherd, sizeof(__pyx_k_fisherd), 0, 0, 1, 1},
    {&__pyx_n_s_fisherd_cdf, __pyx_k_fisherd_cdf, sizeof(__pyx_k_fisherd_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_fisherd_icdf, __pyx_k_fisherd_icdf, sizeof(__pyx_k_fisherd_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_fitdistr, __pyx_k_fitdistr, sizeof(__pyx_k_fitdistr), 0, 0, 1, 1},
    {&__pyx_n_s_fitpoly, __pyx_k_fitpoly, sizeof(__pyx_k_fitpoly), 0, 0, 1, 1},
    {&__pyx_n_s_fitspline, __pyx_k_fitspline, sizeof(__pyx_k_fitspline), 0, 0, 1, 1},
    {&__pyx_n_s_flam, __pyx_k_flam, sizeof(__pyx_k_flam), 0, 0, 1, 1},
    {&__pyx_n_s_flatten, __pyx_k_flatten, sizeof(__pyx_k_flatten), 0, 0, 1, 1},
    {&__pyx_n_s_float, __pyx_k_float, sizeof(__pyx_k_float), 0, 0, 1, 1},
    {&__pyx_n_s_float2rational, __pyx_k_float2rational, sizeof(__pyx_k_float2rational), 0, 0, 1, 1},
    {&__pyx_n_s_floor, __pyx_k_floor, sizeof(__pyx_k_floor), 0, 0, 1, 1},
    {&__pyx_n_s_flow_polynomial, __pyx_k_flow_polynomial, sizeof(__pyx_k_flow_polynomial), 0, 0, 1, 1},
    {&__pyx_n_s_flower_snark, __pyx_k_flower_snark, sizeof(__pyx_k_flower_snark), 0, 0, 1, 1},
    {&__pyx_n_s_fm, __pyx_k_fm, sizeof(__pyx_k_fm), 0, 0, 1, 1},
    {&__pyx_n_s_fmod, __pyx_k_fmod, sizeof(__pyx_k_fmod), 0, 0, 1, 1},
    {&__pyx_n_s_foldl, __pyx_k_foldl, sizeof(__pyx_k_foldl), 0, 0, 1, 1},
    {&__pyx_n_s_foldr, __pyx_k_foldr, sizeof(__pyx_k_foldr), 0, 0, 1, 1},
    {&__pyx_n_s_fonction, __pyx_k_fonction, sizeof(__pyx_k_fonction), 0, 0, 1, 1},
    {&__pyx_n_s_fonction_derivee, __pyx_k_fonction_derivee, sizeof(__pyx_k_fonction_derivee), 0, 0, 1, 1},
    {&__pyx_n_s_fopen, __pyx_k_fopen, sizeof(__pyx_k_fopen), 0, 0, 1, 1},
    {&__pyx_n_s_for, __pyx_k_for, sizeof(__pyx_k_for), 0, 0, 1, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_forward, __pyx_k_forward, sizeof(__pyx_k_forward), 0, 0, 1, 1},
    {&__pyx_n_s_fourier, __pyx_k_fourier, sizeof(__pyx_k_fourier), 0, 0, 1, 1},
    {&__pyx_n_s_fourier_an, __pyx_k_fourier_an, sizeof(__pyx_k_fourier_an), 0, 0, 1, 1},
    {&__pyx_n_s_fourier_bn, __pyx_k_fourier_bn, sizeof(__pyx_k_fourier_bn), 0, 0, 1, 1},
    {&__pyx_n_s_fourier_cn, __pyx_k_fourier_cn, sizeof(__pyx_k_fourier_cn), 0, 0, 1, 1},
    {&__pyx_n_s_fpour, __pyx_k_fpour, sizeof(__pyx_k_fpour), 0, 0, 1, 1},
    {&__pyx_n_s_fprint, __pyx_k_fprint, sizeof(__pyx_k_fprint), 0, 0, 1, 1},
    {&__pyx_n_s_fr, __pyx_k_fr, sizeof(__pyx_k_fr), 0, 0, 1, 1},
    {&__pyx_n_s_frac, __pyx_k_frac, sizeof(__pyx_k_frac), 0, 0, 1, 1},
    {&__pyx_n_s_fracmod, __pyx_k_fracmod, sizeof(__pyx_k_fracmod), 0, 0, 1, 1},
    {&__pyx_n_s_frame_2d, __pyx_k_frame_2d, sizeof(__pyx_k_frame_2d), 0, 0, 1, 1},
    {&__pyx_n_s_frame_3d, __pyx_k_frame_3d, sizeof(__pyx_k_frame_3d), 0, 0, 1, 1},
    {&__pyx_n_s_frames, __pyx_k_frames, sizeof(__pyx_k_frames), 0, 0, 1, 1},
    {&__pyx_n_s_frank_wolfe, __pyx_k_frank_wolfe, sizeof(__pyx_k_frank_wolfe), 0, 0, 1, 1},
    {&__pyx_n_s_frequencies, __pyx_k_frequencies, sizeof(__pyx_k_frequencies), 0, 0, 1, 1},
    {&__pyx_n_s_frobenius_norm, __pyx_k_frobenius_norm, sizeof(__pyx_k_frobenius_norm), 0, 0, 1, 1},
    {&__pyx_n_s_from, __pyx_k_from, sizeof(__pyx_k_from), 0, 0, 1, 1},
    {&__pyx_kp_s_from_giac_s_help, __pyx_k_from_giac_s_help, sizeof(__pyx_k_from_giac_s_help), 0, 0, 1, 0},
    {&__pyx_kp_u_from_giacpy_import_giac_giac_3, __pyx_k_from_giacpy_import_giac_giac_3, sizeof(__pyx_k_from_giacpy_import_giac_giac_3), 0, 1, 0, 0},
    {&__pyx_n_s_froot, __pyx_k_froot, sizeof(__pyx_k_froot), 0, 0, 1, 1},
    {&__pyx_n_s_fsi, __pyx_k_fsi, sizeof(__pyx_k_fsi), 0, 0, 1, 1},
    {&__pyx_n_s_fsolve, __pyx_k_fsolve, sizeof(__pyx_k_fsolve), 0, 0, 1, 1},
    {&__pyx_n_s_ft, __pyx_k_ft, sizeof(__pyx_k_ft), 0, 0, 1, 1},
    {&__pyx_n_s_ftUS, __pyx_k_ftUS, sizeof(__pyx_k_ftUS), 0, 0, 1, 1},
    {&__pyx_kp_s_ft_2, __pyx_k_ft_2, sizeof(__pyx_k_ft_2), 0, 0, 1, 0},
    {&__pyx_kp_s_ft_3, __pyx_k_ft_3, sizeof(__pyx_k_ft_3), 0, 0, 1, 0},
    {&__pyx_kp_s_ft_lb, __pyx_k_ft_lb, sizeof(__pyx_k_ft_lb), 0, 0, 1, 0},
    {&__pyx_kp_s_ft_lb_2, __pyx_k_ft_lb_2, sizeof(__pyx_k_ft_lb_2), 0, 0, 1, 0},
    {&__pyx_kp_s_ft_s, __pyx_k_ft_s, sizeof(__pyx_k_ft_s), 0, 0, 1, 0},
    {&__pyx_n_s_ftantque, __pyx_k_ftantque, sizeof(__pyx_k_ftantque), 0, 0, 1, 1},
    {&__pyx_n_s_fullparfrac, __pyx_k_fullparfrac, sizeof(__pyx_k_fullparfrac), 0, 0, 1, 1},
    {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
    {&__pyx_n_s_funcplot, __pyx_k_funcplot, sizeof(__pyx_k_funcplot), 0, 0, 1, 1},
    {&__pyx_n_s_function, __pyx_k_function, sizeof(__pyx_k_function), 0, 0, 1, 1},
    {&__pyx_n_s_function_diff, __pyx_k_function_diff, sizeof(__pyx_k_function_diff), 0, 0, 1, 1},
    {&__pyx_n_s_fundamental_cycle, __pyx_k_fundamental_cycle, sizeof(__pyx_k_fundamental_cycle), 0, 0, 1, 1},
    {&__pyx_n_s_fxnd, __pyx_k_fxnd, sizeof(__pyx_k_fxnd), 0, 0, 1, 1},
    {&__pyx_n_s_g, __pyx_k_g, sizeof(__pyx_k_g), 0, 0, 1, 1},
    {&__pyx_n_s_g_2, __pyx_k_g_2, sizeof(__pyx_k_g_2), 0, 0, 1, 1},
    {&__pyx_n_s_ga, __pyx_k_ga, sizeof(__pyx_k_ga), 0, 0, 1, 1},
    {&__pyx_n_s_galC, __pyx_k_galC, sizeof(__pyx_k_galC), 0, 0, 1, 1},
    {&__pyx_n_s_galUK, __pyx_k_galUK, sizeof(__pyx_k_galUK), 0, 0, 1, 1},
    {&__pyx_n_s_galUS, __pyx_k_galUS, sizeof(__pyx_k_galUS), 0, 0, 1, 1},
    {&__pyx_n_s_gammad, __pyx_k_gammad, sizeof(__pyx_k_gammad), 0, 0, 1, 1},
    {&__pyx_n_s_gammad_cdf, __pyx_k_gammad_cdf, sizeof(__pyx_k_gammad_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_gammad_icdf, __pyx_k_gammad_icdf, sizeof(__pyx_k_gammad_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_gammavariate, __pyx_k_gammavariate, sizeof(__pyx_k_gammavariate), 0, 0, 1, 1},
    {&__pyx_n_s_gauche, __pyx_k_gauche, sizeof(__pyx_k_gauche), 0, 0, 1, 1},
    {&__pyx_n_s_gauss, __pyx_k_gauss, sizeof(__pyx_k_gauss), 0, 0, 1, 1},
    {&__pyx_n_s_gauss15, __pyx_k_gauss15, sizeof(__pyx_k_gauss15), 0, 0, 1, 1},
    {&__pyx_n_s_gauss_seidel_linsolve, __pyx_k_gauss_seidel_linsolve, sizeof(__pyx_k_gauss_seidel_linsolve), 0, 0, 1, 1},
    {&__pyx_n_s_gaussian_window, __pyx_k_gaussian_window, sizeof(__pyx_k_gaussian_window), 0, 0, 1, 1},
    {&__pyx_n_s_gaussjord, __pyx_k_gaussjord, sizeof(__pyx_k_gaussjord), 0, 0, 1, 1},
    {&__pyx_n_s_gaussquad, __pyx_k_gaussquad, sizeof(__pyx_k_gaussquad), 0, 0, 1, 1},
    {&__pyx_n_s_gbasis, __pyx_k_gbasis, sizeof(__pyx_k_gbasis), 0, 0, 1, 1},
    {&__pyx_n_s_gbasis_max_pairs, __pyx_k_gbasis_max_pairs, sizeof(__pyx_k_gbasis_max_pairs), 0, 0, 1, 1},
    {&__pyx_n_s_gbasis_reinject, __pyx_k_gbasis_reinject, sizeof(__pyx_k_gbasis_reinject), 0, 0, 1, 1},
    {&__pyx_n_s_gbasis_simult_primes, __pyx_k_gbasis_simult_primes, sizeof(__pyx_k_gbasis_simult_primes), 0, 0, 1, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_gcd, __pyx_k_gcd, sizeof(__pyx_k_gcd), 0, 0, 1, 1},
    {&__pyx_n_s_gcdex, __pyx_k_gcdex, sizeof(__pyx_k_gcdex), 0, 0, 1, 1},
    {&__pyx_kp_s_gen_indexes_are_not_yet_implemen, __pyx_k_gen_indexes_are_not_yet_implemen, sizeof(__pyx_k_gen_indexes_are_not_yet_implemen), 0, 0, 1, 0},
    {&__pyx_n_s_genpoly, __pyx_k_genpoly, sizeof(__pyx_k_genpoly), 0, 0, 1, 1},
    {&__pyx_n_s_geodetic2ecef, __pyx_k_geodetic2ecef, sizeof(__pyx_k_geodetic2ecef), 0, 0, 1, 1},
    {&__pyx_n_s_geometric, __pyx_k_geometric, sizeof(__pyx_k_geometric), 0, 0, 1, 1},
    {&__pyx_n_s_geometric_cdf, __pyx_k_geometric_cdf, sizeof(__pyx_k_geometric_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_geometric_icdf, __pyx_k_geometric_icdf, sizeof(__pyx_k_geometric_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_getDenom, __pyx_k_getDenom, sizeof(__pyx_k_getDenom), 0, 0, 1, 1},
    {&__pyx_n_s_getKey, __pyx_k_getKey, sizeof(__pyx_k_getKey), 0, 0, 1, 1},
    {&__pyx_n_s_getNum, __pyx_k_getNum, sizeof(__pyx_k_getNum), 0, 0, 1, 1},
    {&__pyx_n_s_getType, __pyx_k_getType, sizeof(__pyx_k_getType), 0, 0, 1, 1},
    {&__pyx_n_s_get_edge_attribute, __pyx_k_get_edge_attribute, sizeof(__pyx_k_get_edge_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_get_edge_weight, __pyx_k_get_edge_weight, sizeof(__pyx_k_get_edge_weight), 0, 0, 1, 1},
    {&__pyx_n_s_get_graph_attribute, __pyx_k_get_graph_attribute, sizeof(__pyx_k_get_graph_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_get_vertex_attribute, __pyx_k_get_vertex_attribute, sizeof(__pyx_k_get_vertex_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_n_s_gf, __pyx_k_gf, sizeof(__pyx_k_gf), 0, 0, 1, 1},
    {&__pyx_n_s_giac, __pyx_k_giac, sizeof(__pyx_k_giac), 0, 0, 1, 1},
    {&__pyx_kp_s_giac_docs_dir_not_found, __pyx_k_giac_docs_dir_not_found, sizeof(__pyx_k_giac_docs_dir_not_found), 0, 0, 1, 0},
    {&__pyx_kp_u_giac_line_163, __pyx_k_giac_line_163, sizeof(__pyx_k_giac_line_163), 0, 1, 0, 0},
    {&__pyx_n_s_giacbasedir, __pyx_k_giacbasedir, sizeof(__pyx_k_giacbasedir), 0, 0, 1, 1},
    {&__pyx_n_s_giacpy2qcas, __pyx_k_giacpy2qcas, sizeof(__pyx_k_giacpy2qcas), 0, 0, 1, 1},
    {&__pyx_kp_s_giacpy_auto_methods_pxi, __pyx_k_giacpy_auto_methods_pxi, sizeof(__pyx_k_giacpy_auto_methods_pxi), 0, 0, 1, 0},
    {&__pyx_n_s_giacpy_giacpy, __pyx_k_giacpy_giacpy, sizeof(__pyx_k_giacpy_giacpy), 0, 0, 1, 1},
    {&__pyx_kp_s_giacpy_giacpy_pyx, __pyx_k_giacpy_giacpy_pyx, sizeof(__pyx_k_giacpy_giacpy_pyx), 0, 0, 1, 0},
    {&__pyx_n_s_giacsettings, __pyx_k_giacsettings, sizeof(__pyx_k_giacsettings), 0, 0, 1, 1},
    {&__pyx_n_s_girth, __pyx_k_girth, sizeof(__pyx_k_girth), 0, 0, 1, 1},
    {&__pyx_n_s_gl_ortho, __pyx_k_gl_ortho, sizeof(__pyx_k_gl_ortho), 0, 0, 1, 1},
    {&__pyx_n_s_gl_quaternion, __pyx_k_gl_quaternion, sizeof(__pyx_k_gl_quaternion), 0, 0, 1, 1},
    {&__pyx_n_s_gl_rotation, __pyx_k_gl_rotation, sizeof(__pyx_k_gl_rotation), 0, 0, 1, 1},
    {&__pyx_n_s_gl_showaxes, __pyx_k_gl_showaxes, sizeof(__pyx_k_gl_showaxes), 0, 0, 1, 1},
    {&__pyx_n_s_gl_shownames, __pyx_k_gl_shownames, sizeof(__pyx_k_gl_shownames), 0, 0, 1, 1},
    {&__pyx_n_s_gl_texture, __pyx_k_gl_texture, sizeof(__pyx_k_gl_texture), 0, 0, 1, 1},
    {&__pyx_n_s_gl_x, __pyx_k_gl_x, sizeof(__pyx_k_gl_x), 0, 0, 1, 1},
    {&__pyx_n_s_gl_x_axis_color, __pyx_k_gl_x_axis_color, sizeof(__pyx_k_gl_x_axis_color), 0, 0, 1, 1},
    {&__pyx_n_s_gl_x_axis_name, __pyx_k_gl_x_axis_name, sizeof(__pyx_k_gl_x_axis_name), 0, 0, 1, 1},
    {&__pyx_n_s_gl_x_axis_unit, __pyx_k_gl_x_axis_unit, sizeof(__pyx_k_gl_x_axis_unit), 0, 0, 1, 1},
    {&__pyx_n_s_gl_xtick, __pyx_k_gl_xtick, sizeof(__pyx_k_gl_xtick), 0, 0, 1, 1},
    {&__pyx_n_s_gl_y, __pyx_k_gl_y, sizeof(__pyx_k_gl_y), 0, 0, 1, 1},
    {&__pyx_n_s_gl_y_axis_color, __pyx_k_gl_y_axis_color, sizeof(__pyx_k_gl_y_axis_color), 0, 0, 1, 1},
    {&__pyx_n_s_gl_y_axis_name, __pyx_k_gl_y_axis_name, sizeof(__pyx_k_gl_y_axis_name), 0, 0, 1, 1},
    {&__pyx_n_s_gl_y_axis_unit, __pyx_k_gl_y_axis_unit, sizeof(__pyx_k_gl_y_axis_unit), 0, 0, 1, 1},
    {&__pyx_n_s_gl_ytick, __pyx_k_gl_ytick, sizeof(__pyx_k_gl_ytick), 0, 0, 1, 1},
    {&__pyx_n_s_gl_z, __pyx_k_gl_z, sizeof(__pyx_k_gl_z), 0, 0, 1, 1},
    {&__pyx_n_s_gl_z_axis_color, __pyx_k_gl_z_axis_color, sizeof(__pyx_k_gl_z_axis_color), 0, 0, 1, 1},
    {&__pyx_n_s_gl_z_axis_name, __pyx_k_gl_z_axis_name, sizeof(__pyx_k_gl_z_axis_name), 0, 0, 1, 1},
    {&__pyx_n_s_gl_z_axis_unit, __pyx_k_gl_z_axis_unit, sizeof(__pyx_k_gl_z_axis_unit), 0, 0, 1, 1},
    {&__pyx_n_s_gl_ztick, __pyx_k_gl_ztick, sizeof(__pyx_k_gl_ztick), 0, 0, 1, 1},
    {&__pyx_n_s_gmol, __pyx_k_gmol, sizeof(__pyx_k_gmol), 0, 0, 1, 1},
    {&__pyx_n_s_gnuplot, __pyx_k_gnuplot, sizeof(__pyx_k_gnuplot), 0, 0, 1, 1},
    {&__pyx_n_s_gold, __pyx_k_gold, sizeof(__pyx_k_gold), 0, 0, 1, 1},
    {&__pyx_n_s_goldberg_snark, __pyx_k_goldberg_snark, sizeof(__pyx_k_goldberg_snark), 0, 0, 1, 1},
    {&__pyx_n_s_gon, __pyx_k_gon, sizeof(__pyx_k_gon), 0, 0, 1, 1},
    {&__pyx_n_s_goto, __pyx_k_goto, sizeof(__pyx_k_goto), 0, 0, 1, 1},
    {&__pyx_n_s_grad, __pyx_k_grad, sizeof(__pyx_k_grad), 0, 0, 1, 1},
    {&__pyx_n_s_grad_2, __pyx_k_grad_2, sizeof(__pyx_k_grad_2), 0, 0, 1, 1},
    {&__pyx_n_s_grain, __pyx_k_grain, sizeof(__pyx_k_grain), 0, 0, 1, 1},
    {&__pyx_n_s_gramschmidt, __pyx_k_gramschmidt, sizeof(__pyx_k_gramschmidt), 0, 0, 1, 1},
    {&__pyx_n_s_graph, __pyx_k_graph, sizeof(__pyx_k_graph), 0, 0, 1, 1},
    {&__pyx_n_s_graph2tex, __pyx_k_graph2tex, sizeof(__pyx_k_graph2tex), 0, 0, 1, 1},
    {&__pyx_n_s_graph3d2tex, __pyx_k_graph3d2tex, sizeof(__pyx_k_graph3d2tex), 0, 0, 1, 1},
    {&__pyx_n_s_graph_automorphisms, __pyx_k_graph_automorphisms, sizeof(__pyx_k_graph_automorphisms), 0, 0, 1, 1},
    {&__pyx_n_s_graph_charpoly, __pyx_k_graph_charpoly, sizeof(__pyx_k_graph_charpoly), 0, 0, 1, 1},
    {&__pyx_n_s_graph_complement, __pyx_k_graph_complement, sizeof(__pyx_k_graph_complement), 0, 0, 1, 1},
    {&__pyx_n_s_graph_diameter, __pyx_k_graph_diameter, sizeof(__pyx_k_graph_diameter), 0, 0, 1, 1},
    {&__pyx_n_s_graph_equal, __pyx_k_graph_equal, sizeof(__pyx_k_graph_equal), 0, 0, 1, 1},
    {&__pyx_n_s_graph_join, __pyx_k_graph_join, sizeof(__pyx_k_graph_join), 0, 0, 1, 1},
    {&__pyx_n_s_graph_power, __pyx_k_graph_power, sizeof(__pyx_k_graph_power), 0, 0, 1, 1},
    {&__pyx_n_s_graph_rank, __pyx_k_graph_rank, sizeof(__pyx_k_graph_rank), 0, 0, 1, 1},
    {&__pyx_n_s_graph_spectrum, __pyx_k_graph_spectrum, sizeof(__pyx_k_graph_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_graph_union, __pyx_k_graph_union, sizeof(__pyx_k_graph_union), 0, 0, 1, 1},
    {&__pyx_n_s_graph_vertices, __pyx_k_graph_vertices, sizeof(__pyx_k_graph_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_graphe, __pyx_k_graphe, sizeof(__pyx_k_graphe), 0, 0, 1, 1},
    {&__pyx_n_s_graphe3d, __pyx_k_graphe3d, sizeof(__pyx_k_graphe3d), 0, 0, 1, 1},
    {&__pyx_n_s_graphe_probabiliste, __pyx_k_graphe_probabiliste, sizeof(__pyx_k_graphe_probabiliste), 0, 0, 1, 1},
    {&__pyx_n_s_graphe_suite, __pyx_k_graphe_suite, sizeof(__pyx_k_graphe_suite), 0, 0, 1, 1},
    {&__pyx_n_s_greduce, __pyx_k_greduce, sizeof(__pyx_k_greduce), 0, 0, 1, 1},
    {&__pyx_n_s_greedy_clique, __pyx_k_greedy_clique, sizeof(__pyx_k_greedy_clique), 0, 0, 1, 1},
    {&__pyx_n_s_greedy_color, __pyx_k_greedy_color, sizeof(__pyx_k_greedy_color), 0, 0, 1, 1},
    {&__pyx_n_s_greedy_independent_set, __pyx_k_greedy_independent_set, sizeof(__pyx_k_greedy_independent_set), 0, 0, 1, 1},
    {&__pyx_n_s_green, __pyx_k_green, sizeof(__pyx_k_green), 0, 0, 1, 1},
    {&__pyx_n_s_grey, __pyx_k_grey, sizeof(__pyx_k_grey), 0, 0, 1, 1},
    {&__pyx_n_s_grid_graph, __pyx_k_grid_graph, sizeof(__pyx_k_grid_graph), 0, 0, 1, 1},
    {&__pyx_n_s_grid_paper, __pyx_k_grid_paper, sizeof(__pyx_k_grid_paper), 0, 0, 1, 1},
    {&__pyx_n_s_groupermu, __pyx_k_groupermu, sizeof(__pyx_k_groupermu), 0, 0, 1, 1},
    {&__pyx_n_s_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 0, 1, 1},
    {&__pyx_n_s_h_2, __pyx_k_h_2, sizeof(__pyx_k_h_2), 0, 0, 1, 1},
    {&__pyx_n_s_ha, __pyx_k_ha, sizeof(__pyx_k_ha), 0, 0, 1, 1},
    {&__pyx_n_s_haar_graph, __pyx_k_haar_graph, sizeof(__pyx_k_haar_graph), 0, 0, 1, 1},
    {&__pyx_n_s_hadamard, __pyx_k_hadamard, sizeof(__pyx_k_hadamard), 0, 0, 1, 1},
    {&__pyx_n_s_half_cone, __pyx_k_half_cone, sizeof(__pyx_k_half_cone), 0, 0, 1, 1},
    {&__pyx_n_s_half_line, __pyx_k_half_line, sizeof(__pyx_k_half_line), 0, 0, 1, 1},
    {&__pyx_n_s_halftan, __pyx_k_halftan, sizeof(__pyx_k_halftan), 0, 0, 1, 1},
    {&__pyx_n_s_halftan_hyp2exp, __pyx_k_halftan_hyp2exp, sizeof(__pyx_k_halftan_hyp2exp), 0, 0, 1, 1},
    {&__pyx_n_s_halt, __pyx_k_halt, sizeof(__pyx_k_halt), 0, 0, 1, 1},
    {&__pyx_n_s_hamdist, __pyx_k_hamdist, sizeof(__pyx_k_hamdist), 0, 0, 1, 1},
    {&__pyx_n_s_hamming, __pyx_k_hamming, sizeof(__pyx_k_hamming), 0, 0, 1, 1},
    {&__pyx_n_s_hamming_window, __pyx_k_hamming_window, sizeof(__pyx_k_hamming_window), 0, 0, 1, 1},
    {&__pyx_n_s_hann_poisson_window, __pyx_k_hann_poisson_window, sizeof(__pyx_k_hann_poisson_window), 0, 0, 1, 1},
    {&__pyx_n_s_hann_window, __pyx_k_hann_window, sizeof(__pyx_k_hann_window), 0, 0, 1, 1},
    {&__pyx_n_s_harmonic_centrality, __pyx_k_harmonic_centrality, sizeof(__pyx_k_harmonic_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_harmonic_conjugate, __pyx_k_harmonic_conjugate, sizeof(__pyx_k_harmonic_conjugate), 0, 0, 1, 1},
    {&__pyx_n_s_harmonic_division, __pyx_k_harmonic_division, sizeof(__pyx_k_harmonic_division), 0, 0, 1, 1},
    {&__pyx_n_s_has, __pyx_k_has, sizeof(__pyx_k_has), 0, 0, 1, 1},
    {&__pyx_n_s_has_arc, __pyx_k_has_arc, sizeof(__pyx_k_has_arc), 0, 0, 1, 1},
    {&__pyx_n_s_has_edge, __pyx_k_has_edge, sizeof(__pyx_k_has_edge), 0, 0, 1, 1},
    {&__pyx_n_s_hasard, __pyx_k_hasard, sizeof(__pyx_k_hasard), 0, 0, 1, 1},
    {&__pyx_n_s_hbar, __pyx_k_hbar, sizeof(__pyx_k_hbar), 0, 0, 1, 1},
    {&__pyx_n_s_head, __pyx_k_head, sizeof(__pyx_k_head), 0, 0, 1, 1},
    {&__pyx_n_s_heading, __pyx_k_heading, sizeof(__pyx_k_heading), 0, 0, 1, 1},
    {&__pyx_n_s_heapify, __pyx_k_heapify, sizeof(__pyx_k_heapify), 0, 0, 1, 1},
    {&__pyx_n_s_heappop, __pyx_k_heappop, sizeof(__pyx_k_heappop), 0, 0, 1, 1},
    {&__pyx_n_s_heappush, __pyx_k_heappush, sizeof(__pyx_k_heappush), 0, 0, 1, 1},
    {&__pyx_n_s_help, __pyx_k_help, sizeof(__pyx_k_help), 0, 0, 1, 1},
    {&__pyx_n_s_hermite, __pyx_k_hermite, sizeof(__pyx_k_hermite), 0, 0, 1, 1},
    {&__pyx_n_s_hessenberg, __pyx_k_hessenberg, sizeof(__pyx_k_hessenberg), 0, 0, 1, 1},
    {&__pyx_n_s_hessian, __pyx_k_hessian, sizeof(__pyx_k_hessian), 0, 0, 1, 1},
    {&__pyx_n_s_heugcd, __pyx_k_heugcd, sizeof(__pyx_k_heugcd), 0, 0, 1, 1},
    {&__pyx_n_s_hexagon, __pyx_k_hexagon, sizeof(__pyx_k_hexagon), 0, 0, 1, 1},
    {&__pyx_n_s_hht, __pyx_k_hht, sizeof(__pyx_k_hht), 0, 0, 1, 1},
    {&__pyx_n_s_hidden_name, __pyx_k_hidden_name, sizeof(__pyx_k_hidden_name), 0, 0, 1, 1},
    {&__pyx_n_s_highlight_edges, __pyx_k_highlight_edges, sizeof(__pyx_k_highlight_edges), 0, 0, 1, 1},
    {&__pyx_n_s_highlight_subgraph, __pyx_k_highlight_subgraph, sizeof(__pyx_k_highlight_subgraph), 0, 0, 1, 1},
    {&__pyx_n_s_highlight_trail, __pyx_k_highlight_trail, sizeof(__pyx_k_highlight_trail), 0, 0, 1, 1},
    {&__pyx_n_s_highlight_vertex, __pyx_k_highlight_vertex, sizeof(__pyx_k_highlight_vertex), 0, 0, 1, 1},
    {&__pyx_n_s_highpass, __pyx_k_highpass, sizeof(__pyx_k_highpass), 0, 0, 1, 1},
    {&__pyx_n_s_hilbert, __pyx_k_hilbert, sizeof(__pyx_k_hilbert), 0, 0, 1, 1},
    {&__pyx_n_s_histogram, __pyx_k_histogram, sizeof(__pyx_k_histogram), 0, 0, 1, 1},
    {&__pyx_n_s_hold, __pyx_k_hold, sizeof(__pyx_k_hold), 0, 0, 1, 1},
    {&__pyx_n_s_homogeneize, __pyx_k_homogeneize, sizeof(__pyx_k_homogeneize), 0, 0, 1, 1},
    {&__pyx_n_s_homothety, __pyx_k_homothety, sizeof(__pyx_k_homothety), 0, 0, 1, 1},
    {&__pyx_n_s_horner, __pyx_k_horner, sizeof(__pyx_k_horner), 0, 0, 1, 1},
    {&__pyx_n_s_hp, __pyx_k_hp, sizeof(__pyx_k_hp), 0, 0, 1, 1},
    {&__pyx_n_s_hsv, __pyx_k_hsv, sizeof(__pyx_k_hsv), 0, 0, 1, 1},
    {&__pyx_n_s_hsv2rgb, __pyx_k_hsv2rgb, sizeof(__pyx_k_hsv2rgb), 0, 0, 1, 1},
    {&__pyx_n_s_htmlhelp, __pyx_k_htmlhelp, sizeof(__pyx_k_htmlhelp), 0, 0, 1, 1},
    {&__pyx_kp_u_htmlhelp_line_1849, __pyx_k_htmlhelp_line_1849, sizeof(__pyx_k_htmlhelp_line_1849), 0, 1, 0, 0},
    {&__pyx_kp_s_http_www_fourier_ujf_grenoble_fr, __pyx_k_http_www_fourier_ujf_grenoble_fr, sizeof(__pyx_k_http_www_fourier_ujf_grenoble_fr), 0, 0, 1, 0},
    {&__pyx_n_s_hybrid_solver, __pyx_k_hybrid_solver, sizeof(__pyx_k_hybrid_solver), 0, 0, 1, 1},
    {&__pyx_n_s_hybridj_solver, __pyx_k_hybridj_solver, sizeof(__pyx_k_hybridj_solver), 0, 0, 1, 1},
    {&__pyx_n_s_hybrids_solver, __pyx_k_hybrids_solver, sizeof(__pyx_k_hybrids_solver), 0, 0, 1, 1},
    {&__pyx_n_s_hybridsj_solver, __pyx_k_hybridsj_solver, sizeof(__pyx_k_hybridsj_solver), 0, 0, 1, 1},
    {&__pyx_n_s_hyp2exp, __pyx_k_hyp2exp, sizeof(__pyx_k_hyp2exp), 0, 0, 1, 1},
    {&__pyx_n_s_hyperbola, __pyx_k_hyperbola, sizeof(__pyx_k_hyperbola), 0, 0, 1, 1},
    {&__pyx_n_s_hypercube_graph, __pyx_k_hypercube_graph, sizeof(__pyx_k_hypercube_graph), 0, 0, 1, 1},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_s_iPart, __pyx_k_iPart, sizeof(__pyx_k_iPart), 0, 0, 1, 1},
    {&__pyx_kp_s_i_2, __pyx_k_i_2, sizeof(__pyx_k_i_2), 0, 0, 1, 0},
    {&__pyx_n_s_iabcuv, __pyx_k_iabcuv, sizeof(__pyx_k_iabcuv), 0, 0, 1, 1},
    {&__pyx_n_s_ibasis, __pyx_k_ibasis, sizeof(__pyx_k_ibasis), 0, 0, 1, 1},
    {&__pyx_n_s_ibpdv, __pyx_k_ibpdv, sizeof(__pyx_k_ibpdv), 0, 0, 1, 1},
    {&__pyx_n_s_ibpu, __pyx_k_ibpu, sizeof(__pyx_k_ibpu), 0, 0, 1, 1},
    {&__pyx_n_s_icdf, __pyx_k_icdf, sizeof(__pyx_k_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_ichinrem, __pyx_k_ichinrem, sizeof(__pyx_k_ichinrem), 0, 0, 1, 1},
    {&__pyx_n_s_ichrem, __pyx_k_ichrem, sizeof(__pyx_k_ichrem), 0, 0, 1, 1},
    {&__pyx_n_s_icomp, __pyx_k_icomp, sizeof(__pyx_k_icomp), 0, 0, 1, 1},
    {&__pyx_n_s_icontent, __pyx_k_icontent, sizeof(__pyx_k_icontent), 0, 0, 1, 1},
    {&__pyx_n_s_icosahedron, __pyx_k_icosahedron, sizeof(__pyx_k_icosahedron), 0, 0, 1, 1},
    {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
    {&__pyx_n_s_identifier, __pyx_k_identifier, sizeof(__pyx_k_identifier), 0, 0, 1, 1},
    {&__pyx_n_s_identify_graph, __pyx_k_identify_graph, sizeof(__pyx_k_identify_graph), 0, 0, 1, 1},
    {&__pyx_n_s_identity, __pyx_k_identity, sizeof(__pyx_k_identity), 0, 0, 1, 1},
    {&__pyx_n_s_idivis, __pyx_k_idivis, sizeof(__pyx_k_idivis), 0, 0, 1, 1},
    {&__pyx_n_s_idn, __pyx_k_idn, sizeof(__pyx_k_idn), 0, 0, 1, 1},
    {&__pyx_n_s_idwt, __pyx_k_idwt, sizeof(__pyx_k_idwt), 0, 0, 1, 1},
    {&__pyx_n_s_iegcd, __pyx_k_iegcd, sizeof(__pyx_k_iegcd), 0, 0, 1, 1},
    {&__pyx_n_s_if, __pyx_k_if, sizeof(__pyx_k_if), 0, 0, 1, 1},
    {&__pyx_n_s_ifactor, __pyx_k_ifactor, sizeof(__pyx_k_ifactor), 0, 0, 1, 1},
    {&__pyx_n_s_ifactors, __pyx_k_ifactors, sizeof(__pyx_k_ifactors), 0, 0, 1, 1},
    {&__pyx_n_s_ifft, __pyx_k_ifft, sizeof(__pyx_k_ifft), 0, 0, 1, 1},
    {&__pyx_n_s_ifourier, __pyx_k_ifourier, sizeof(__pyx_k_ifourier), 0, 0, 1, 1},
    {&__pyx_n_s_ifte, __pyx_k_ifte, sizeof(__pyx_k_ifte), 0, 0, 1, 1},
    {&__pyx_n_s_igamma, __pyx_k_igamma, sizeof(__pyx_k_igamma), 0, 0, 1, 1},
    {&__pyx_n_s_igcd, __pyx_k_igcd, sizeof(__pyx_k_igcd), 0, 0, 1, 1},
    {&__pyx_n_s_igcdex, __pyx_k_igcdex, sizeof(__pyx_k_igcdex), 0, 0, 1, 1},
    {&__pyx_n_s_ignored, __pyx_k_ignored, sizeof(__pyx_k_ignored), 0, 0, 1, 1},
    {&__pyx_n_s_ihermite, __pyx_k_ihermite, sizeof(__pyx_k_ihermite), 0, 0, 1, 1},
    {&__pyx_n_s_ilaplace, __pyx_k_ilaplace, sizeof(__pyx_k_ilaplace), 0, 0, 1, 1},
    {&__pyx_n_s_im, __pyx_k_im, sizeof(__pyx_k_im), 0, 0, 1, 1},
    {&__pyx_n_s_imag, __pyx_k_imag, sizeof(__pyx_k_imag), 0, 0, 1, 1},
    {&__pyx_n_s_image, __pyx_k_image, sizeof(__pyx_k_image), 0, 0, 1, 1},
    {&__pyx_n_s_imfplot, __pyx_k_imfplot, sizeof(__pyx_k_imfplot), 0, 0, 1, 1},
    {&__pyx_n_s_implicitdiff, __pyx_k_implicitdiff, sizeof(__pyx_k_implicitdiff), 0, 0, 1, 1},
    {&__pyx_n_s_implicitplot, __pyx_k_implicitplot, sizeof(__pyx_k_implicitplot), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_import_graph, __pyx_k_import_graph, sizeof(__pyx_k_import_graph), 0, 0, 1, 1},
    {&__pyx_n_s_in, __pyx_k_in, sizeof(__pyx_k_in), 0, 0, 1, 1},
    {&__pyx_n_s_inH20, __pyx_k_inH20, sizeof(__pyx_k_inH20), 0, 0, 1, 1},
    {&__pyx_n_s_inHg, __pyx_k_inHg, sizeof(__pyx_k_inHg), 0, 0, 1, 1},
    {&__pyx_n_s_inString, __pyx_k_inString, sizeof(__pyx_k_inString), 0, 0, 1, 1},
    {&__pyx_n_s_in_2, __pyx_k_in_2, sizeof(__pyx_k_in_2), 0, 0, 1, 1},
    {&__pyx_kp_s_in_2_2, __pyx_k_in_2_2, sizeof(__pyx_k_in_2_2), 0, 0, 1, 0},
    {&__pyx_kp_s_in_3, __pyx_k_in_3, sizeof(__pyx_k_in_3), 0, 0, 1, 0},
    {&__pyx_n_s_in_ideal, __pyx_k_in_ideal, sizeof(__pyx_k_in_ideal), 0, 0, 1, 1},
    {&__pyx_n_s_incidence_matrix, __pyx_k_incidence_matrix, sizeof(__pyx_k_incidence_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_incident_edges, __pyx_k_incident_edges, sizeof(__pyx_k_incident_edges), 0, 0, 1, 1},
    {&__pyx_n_s_incircle, __pyx_k_incircle, sizeof(__pyx_k_incircle), 0, 0, 1, 1},
    {&__pyx_n_s_increasing_power, __pyx_k_increasing_power, sizeof(__pyx_k_increasing_power), 0, 0, 1, 1},
    {&__pyx_n_s_independence_number, __pyx_k_independence_number, sizeof(__pyx_k_independence_number), 0, 0, 1, 1},
    {&__pyx_n_s_indets, __pyx_k_indets, sizeof(__pyx_k_indets), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_kp_s_index_html, __pyx_k_index_html, sizeof(__pyx_k_index_html), 0, 0, 1, 0},
    {&__pyx_n_s_indices, __pyx_k_indices, sizeof(__pyx_k_indices), 0, 0, 1, 1},
    {&__pyx_n_s_induced_subgraph, __pyx_k_induced_subgraph, sizeof(__pyx_k_induced_subgraph), 0, 0, 1, 1},
    {&__pyx_n_s_inequationplot, __pyx_k_inequationplot, sizeof(__pyx_k_inequationplot), 0, 0, 1, 1},
    {&__pyx_n_s_inertia, __pyx_k_inertia, sizeof(__pyx_k_inertia), 0, 0, 1, 1},
    {&__pyx_n_s_inf, __pyx_k_inf, sizeof(__pyx_k_inf), 0, 0, 1, 1},
    {&__pyx_n_s_infinity, __pyx_k_infinity, sizeof(__pyx_k_infinity), 0, 0, 1, 1},
    {&__pyx_kp_s_infinity_2, __pyx_k_infinity_2, sizeof(__pyx_k_infinity_2), 0, 0, 1, 0},
    {&__pyx_kp_s_infinity_3, __pyx_k_infinity_3, sizeof(__pyx_k_infinity_3), 0, 0, 1, 0},
    {&__pyx_n_s_information_centrality, __pyx_k_information_centrality, sizeof(__pyx_k_information_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_input, __pyx_k_input, sizeof(__pyx_k_input), 0, 0, 1, 1},
    {&__pyx_n_s_inputform, __pyx_k_inputform, sizeof(__pyx_k_inputform), 0, 0, 1, 1},
    {&__pyx_n_s_insert, __pyx_k_insert, sizeof(__pyx_k_insert), 0, 0, 1, 1},
    {&__pyx_n_s_insmod, __pyx_k_insmod, sizeof(__pyx_k_insmod), 0, 0, 1, 1},
    {&__pyx_n_s_instfreq, __pyx_k_instfreq, sizeof(__pyx_k_instfreq), 0, 0, 1, 1},
    {&__pyx_n_s_instphase, __pyx_k_instphase, sizeof(__pyx_k_instphase), 0, 0, 1, 1},
    {&__pyx_n_s_int, __pyx_k_int, sizeof(__pyx_k_int), 0, 0, 1, 1},
    {&__pyx_n_s_intDiv, __pyx_k_intDiv, sizeof(__pyx_k_intDiv), 0, 0, 1, 1},
    {&__pyx_n_s_integer, __pyx_k_integer, sizeof(__pyx_k_integer), 0, 0, 1, 1},
    {&__pyx_n_s_integrate, __pyx_k_integrate, sizeof(__pyx_k_integrate), 0, 0, 1, 1},
    {&__pyx_n_s_integrer, __pyx_k_integrer, sizeof(__pyx_k_integrer), 0, 0, 1, 1},
    {&__pyx_n_s_inter, __pyx_k_inter, sizeof(__pyx_k_inter), 0, 0, 1, 1},
    {&__pyx_n_s_interactive_odeplot, __pyx_k_interactive_odeplot, sizeof(__pyx_k_interactive_odeplot), 0, 0, 1, 1},
    {&__pyx_n_s_interactive_plotode, __pyx_k_interactive_plotode, sizeof(__pyx_k_interactive_plotode), 0, 0, 1, 1},
    {&__pyx_n_s_interp, __pyx_k_interp, sizeof(__pyx_k_interp), 0, 0, 1, 1},
    {&__pyx_n_s_intersect, __pyx_k_intersect, sizeof(__pyx_k_intersect), 0, 0, 1, 1},
    {&__pyx_n_s_interval, __pyx_k_interval, sizeof(__pyx_k_interval), 0, 0, 1, 1},
    {&__pyx_n_s_interval2center, __pyx_k_interval2center, sizeof(__pyx_k_interval2center), 0, 0, 1, 1},
    {&__pyx_n_s_interval_graph, __pyx_k_interval_graph, sizeof(__pyx_k_interval_graph), 0, 0, 1, 1},
    {&__pyx_n_s_inv, __pyx_k_inv, sizeof(__pyx_k_inv), 0, 0, 1, 1},
    {&__pyx_n_s_inverse, __pyx_k_inverse, sizeof(__pyx_k_inverse), 0, 0, 1, 1},
    {&__pyx_n_s_inversion, __pyx_k_inversion, sizeof(__pyx_k_inversion), 0, 0, 1, 1},
    {&__pyx_n_s_invisible_point, __pyx_k_invisible_point, sizeof(__pyx_k_invisible_point), 0, 0, 1, 1},
    {&__pyx_n_s_invlaplace, __pyx_k_invlaplace, sizeof(__pyx_k_invlaplace), 0, 0, 1, 1},
    {&__pyx_n_s_invztrans, __pyx_k_invztrans, sizeof(__pyx_k_invztrans), 0, 0, 1, 1},
    {&__pyx_n_s_iquo, __pyx_k_iquo, sizeof(__pyx_k_iquo), 0, 0, 1, 1},
    {&__pyx_n_s_iquorem, __pyx_k_iquorem, sizeof(__pyx_k_iquorem), 0, 0, 1, 1},
    {&__pyx_n_s_iratrecon, __pyx_k_iratrecon, sizeof(__pyx_k_iratrecon), 0, 0, 1, 1},
    {&__pyx_n_s_irem, __pyx_k_irem, sizeof(__pyx_k_irem), 0, 0, 1, 1},
    {&__pyx_n_s_isPrime, __pyx_k_isPrime, sizeof(__pyx_k_isPrime), 0, 0, 1, 1},
    {&__pyx_n_s_is_acyclic, __pyx_k_is_acyclic, sizeof(__pyx_k_is_acyclic), 0, 0, 1, 1},
    {&__pyx_n_s_is_arborescence, __pyx_k_is_arborescence, sizeof(__pyx_k_is_arborescence), 0, 0, 1, 1},
    {&__pyx_n_s_is_biconnected, __pyx_k_is_biconnected, sizeof(__pyx_k_is_biconnected), 0, 0, 1, 1},
    {&__pyx_n_s_is_bipartite, __pyx_k_is_bipartite, sizeof(__pyx_k_is_bipartite), 0, 0, 1, 1},
    {&__pyx_n_s_is_clique, __pyx_k_is_clique, sizeof(__pyx_k_is_clique), 0, 0, 1, 1},
    {&__pyx_n_s_is_collinear, __pyx_k_is_collinear, sizeof(__pyx_k_is_collinear), 0, 0, 1, 1},
    {&__pyx_n_s_is_concyclic, __pyx_k_is_concyclic, sizeof(__pyx_k_is_concyclic), 0, 0, 1, 1},
    {&__pyx_n_s_is_conjugate, __pyx_k_is_conjugate, sizeof(__pyx_k_is_conjugate), 0, 0, 1, 1},
    {&__pyx_n_s_is_connected, __pyx_k_is_connected, sizeof(__pyx_k_is_connected), 0, 0, 1, 1},
    {&__pyx_n_s_is_coplanar, __pyx_k_is_coplanar, sizeof(__pyx_k_is_coplanar), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_cospherical, __pyx_k_is_cospherical, sizeof(__pyx_k_is_cospherical), 0, 0, 1, 1},
    {&__pyx_n_s_is_cut_set, __pyx_k_is_cut_set, sizeof(__pyx_k_is_cut_set), 0, 0, 1, 1},
    {&__pyx_n_s_is_cycle, __pyx_k_is_cycle, sizeof(__pyx_k_is_cycle), 0, 0, 1, 1},
    {&__pyx_n_s_is_directed, __pyx_k_is_directed, sizeof(__pyx_k_is_directed), 0, 0, 1, 1},
    {&__pyx_n_s_is_element, __pyx_k_is_element, sizeof(__pyx_k_is_element), 0, 0, 1, 1},
    {&__pyx_n_s_is_equilateral, __pyx_k_is_equilateral, sizeof(__pyx_k_is_equilateral), 0, 0, 1, 1},
    {&__pyx_n_s_is_eulerian, __pyx_k_is_eulerian, sizeof(__pyx_k_is_eulerian), 0, 0, 1, 1},
    {&__pyx_n_s_is_forest, __pyx_k_is_forest, sizeof(__pyx_k_is_forest), 0, 0, 1, 1},
    {&__pyx_n_s_is_graphic_sequence, __pyx_k_is_graphic_sequence, sizeof(__pyx_k_is_graphic_sequence), 0, 0, 1, 1},
    {&__pyx_n_s_is_hamiltonian, __pyx_k_is_hamiltonian, sizeof(__pyx_k_is_hamiltonian), 0, 0, 1, 1},
    {&__pyx_n_s_is_harmonic, __pyx_k_is_harmonic, sizeof(__pyx_k_is_harmonic), 0, 0, 1, 1},
    {&__pyx_n_s_is_harmonic_circle_bundle, __pyx_k_is_harmonic_circle_bundle, sizeof(__pyx_k_is_harmonic_circle_bundle), 0, 0, 1, 1},
    {&__pyx_n_s_is_harmonic_line_bundle, __pyx_k_is_harmonic_line_bundle, sizeof(__pyx_k_is_harmonic_line_bundle), 0, 0, 1, 1},
    {&__pyx_n_s_is_included, __pyx_k_is_included, sizeof(__pyx_k_is_included), 0, 0, 1, 1},
    {&__pyx_n_s_is_inside, __pyx_k_is_inside, sizeof(__pyx_k_is_inside), 0, 0, 1, 1},
    {&__pyx_n_s_is_integer_graph, __pyx_k_is_integer_graph, sizeof(__pyx_k_is_integer_graph), 0, 0, 1, 1},
    {&__pyx_n_s_is_irreducible, __pyx_k_is_irreducible, sizeof(__pyx_k_is_irreducible), 0, 0, 1, 1},
    {&__pyx_n_s_is_isomorphic, __pyx_k_is_isomorphic, sizeof(__pyx_k_is_isomorphic), 0, 0, 1, 1},
    {&__pyx_n_s_is_isosceles, __pyx_k_is_isosceles, sizeof(__pyx_k_is_isosceles), 0, 0, 1, 1},
    {&__pyx_n_s_is_network, __pyx_k_is_network, sizeof(__pyx_k_is_network), 0, 0, 1, 1},
    {&__pyx_n_s_is_orthogonal, __pyx_k_is_orthogonal, sizeof(__pyx_k_is_orthogonal), 0, 0, 1, 1},
    {&__pyx_n_s_is_parallel, __pyx_k_is_parallel, sizeof(__pyx_k_is_parallel), 0, 0, 1, 1},
    {&__pyx_n_s_is_parallelogram, __pyx_k_is_parallelogram, sizeof(__pyx_k_is_parallelogram), 0, 0, 1, 1},
    {&__pyx_n_s_is_permu, __pyx_k_is_permu, sizeof(__pyx_k_is_permu), 0, 0, 1, 1},
    {&__pyx_n_s_is_perpendicular, __pyx_k_is_perpendicular, sizeof(__pyx_k_is_perpendicular), 0, 0, 1, 1},
    {&__pyx_n_s_is_planar, __pyx_k_is_planar, sizeof(__pyx_k_is_planar), 0, 0, 1, 1},
    {&__pyx_n_s_is_prime, __pyx_k_is_prime, sizeof(__pyx_k_is_prime), 0, 0, 1, 1},
    {&__pyx_n_s_is_pseudoprime, __pyx_k_is_pseudoprime, sizeof(__pyx_k_is_pseudoprime), 0, 0, 1, 1},
    {&__pyx_n_s_is_reachable, __pyx_k_is_reachable, sizeof(__pyx_k_is_reachable), 0, 0, 1, 1},
    {&__pyx_n_s_is_rectangle, __pyx_k_is_rectangle, sizeof(__pyx_k_is_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_is_regular, __pyx_k_is_regular, sizeof(__pyx_k_is_regular), 0, 0, 1, 1},
    {&__pyx_n_s_is_rhombus, __pyx_k_is_rhombus, sizeof(__pyx_k_is_rhombus), 0, 0, 1, 1},
    {&__pyx_n_s_is_split_graph, __pyx_k_is_split_graph, sizeof(__pyx_k_is_split_graph), 0, 0, 1, 1},
    {&__pyx_n_s_is_square, __pyx_k_is_square, sizeof(__pyx_k_is_square), 0, 0, 1, 1},
    {&__pyx_n_s_is_strongly_connected, __pyx_k_is_strongly_connected, sizeof(__pyx_k_is_strongly_connected), 0, 0, 1, 1},
    {&__pyx_n_s_is_strongly_regular, __pyx_k_is_strongly_regular, sizeof(__pyx_k_is_strongly_regular), 0, 0, 1, 1},
    {&__pyx_n_s_is_subgraph_isomorphic, __pyx_k_is_subgraph_isomorphic, sizeof(__pyx_k_is_subgraph_isomorphic), 0, 0, 1, 1},
    {&__pyx_n_s_is_tournament, __pyx_k_is_tournament, sizeof(__pyx_k_is_tournament), 0, 0, 1, 1},
    {&__pyx_n_s_is_tree, __pyx_k_is_tree, sizeof(__pyx_k_is_tree), 0, 0, 1, 1},
    {&__pyx_n_s_is_triconnected, __pyx_k_is_triconnected, sizeof(__pyx_k_is_triconnected), 0, 0, 1, 1},
    {&__pyx_n_s_is_two_edge_connected, __pyx_k_is_two_edge_connected, sizeof(__pyx_k_is_two_edge_connected), 0, 0, 1, 1},
    {&__pyx_n_s_is_vertex_colorable, __pyx_k_is_vertex_colorable, sizeof(__pyx_k_is_vertex_colorable), 0, 0, 1, 1},
    {&__pyx_n_s_is_weighted, __pyx_k_is_weighted, sizeof(__pyx_k_is_weighted), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_isinf, __pyx_k_isinf, sizeof(__pyx_k_isinf), 0, 0, 1, 1},
    {&__pyx_n_s_ismith, __pyx_k_ismith, sizeof(__pyx_k_ismith), 0, 0, 1, 1},
    {&__pyx_n_s_isnan, __pyx_k_isnan, sizeof(__pyx_k_isnan), 0, 0, 1, 1},
    {&__pyx_n_s_isobarycenter, __pyx_k_isobarycenter, sizeof(__pyx_k_isobarycenter), 0, 0, 1, 1},
    {&__pyx_n_s_isolve, __pyx_k_isolve, sizeof(__pyx_k_isolve), 0, 0, 1, 1},
    {&__pyx_n_s_isom, __pyx_k_isom, sizeof(__pyx_k_isom), 0, 0, 1, 1},
    {&__pyx_n_s_isomorphic_copy, __pyx_k_isomorphic_copy, sizeof(__pyx_k_isomorphic_copy), 0, 0, 1, 1},
    {&__pyx_n_s_isopolygon, __pyx_k_isopolygon, sizeof(__pyx_k_isopolygon), 0, 0, 1, 1},
    {&__pyx_n_s_isosceles_triangle, __pyx_k_isosceles_triangle, sizeof(__pyx_k_isosceles_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_isposdef, __pyx_k_isposdef, sizeof(__pyx_k_isposdef), 0, 0, 1, 1},
    {&__pyx_n_s_isprime, __pyx_k_isprime, sizeof(__pyx_k_isprime), 0, 0, 1, 1},
    {&__pyx_n_s_istft, __pyx_k_istft, sizeof(__pyx_k_istft), 0, 0, 1, 1},
    {&__pyx_n_s_iter, __pyx_k_iter, sizeof(__pyx_k_iter), 0, 0, 1, 1},
    {&__pyx_n_s_ithprime, __pyx_k_ithprime, sizeof(__pyx_k_ithprime), 0, 0, 1, 1},
    {&__pyx_n_s_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 0, 1, 1},
    {&__pyx_n_s_jacobi_equation, __pyx_k_jacobi_equation, sizeof(__pyx_k_jacobi_equation), 0, 0, 1, 1},
    {&__pyx_n_s_jacobi_linsolve, __pyx_k_jacobi_linsolve, sizeof(__pyx_k_jacobi_linsolve), 0, 0, 1, 1},
    {&__pyx_n_s_jacobi_symbol, __pyx_k_jacobi_symbol, sizeof(__pyx_k_jacobi_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_johnson_graph, __pyx_k_johnson_graph, sizeof(__pyx_k_johnson_graph), 0, 0, 1, 1},
    {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
    {&__pyx_n_s_jordan, __pyx_k_jordan, sizeof(__pyx_k_jordan), 0, 0, 1, 1},
    {&__pyx_n_s_jusqu_a, __pyx_k_jusqu_a, sizeof(__pyx_k_jusqu_a), 0, 0, 1, 1},
    {&__pyx_n_s_jusqua, __pyx_k_jusqua, sizeof(__pyx_k_jusqua), 0, 0, 1, 1},
    {&__pyx_n_s_jusque, __pyx_k_jusque, sizeof(__pyx_k_jusque), 0, 0, 1, 1},
    {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
    {&__pyx_n_s_kWh, __pyx_k_kWh, sizeof(__pyx_k_kWh), 0, 0, 1, 1},
    {&__pyx_n_s_katz_centrality, __pyx_k_katz_centrality, sizeof(__pyx_k_katz_centrality), 0, 0, 1, 1},
    {&__pyx_n_s_kde, __pyx_k_kde, sizeof(__pyx_k_kde), 0, 0, 1, 1},
    {&__pyx_n_s_keep_algext, __pyx_k_keep_algext, sizeof(__pyx_k_keep_algext), 0, 0, 1, 1},
    {&__pyx_n_s_keep_pivot, __pyx_k_keep_pivot, sizeof(__pyx_k_keep_pivot), 0, 0, 1, 1},
    {&__pyx_n_s_ker, __pyx_k_ker, sizeof(__pyx_k_ker), 0, 0, 1, 1},
    {&__pyx_n_s_kernel, __pyx_k_kernel, sizeof(__pyx_k_kernel), 0, 0, 1, 1},
    {&__pyx_n_s_kernel_density, __pyx_k_kernel_density, sizeof(__pyx_k_kernel_density), 0, 0, 1, 1},
    {&__pyx_n_s_kg, __pyx_k_kg, sizeof(__pyx_k_kg), 0, 0, 1, 1},
    {&__pyx_n_s_kill, __pyx_k_kill, sizeof(__pyx_k_kill), 0, 0, 1, 1},
    {&__pyx_kp_s_killing_thread, __pyx_k_killing_thread, sizeof(__pyx_k_killing_thread), 0, 0, 1, 0},
    {&__pyx_n_s_kip, __pyx_k_kip, sizeof(__pyx_k_kip), 0, 0, 1, 1},
    {&__pyx_n_s_km, __pyx_k_km, sizeof(__pyx_k_km), 0, 0, 1, 1},
    {&__pyx_kp_s_km_2, __pyx_k_km_2, sizeof(__pyx_k_km_2), 0, 0, 1, 0},
    {&__pyx_n_s_kmeans, __pyx_k_kmeans, sizeof(__pyx_k_kmeans), 0, 0, 1, 1},
    {&__pyx_n_s_kneser_graph, __pyx_k_kneser_graph, sizeof(__pyx_k_kneser_graph), 0, 0, 1, 1},
    {&__pyx_n_s_knot, __pyx_k_knot, sizeof(__pyx_k_knot), 0, 0, 1, 1},
    {&__pyx_n_s_kolmogorovd, __pyx_k_kolmogorovd, sizeof(__pyx_k_kolmogorovd), 0, 0, 1, 1},
    {&__pyx_n_s_kolmogorovt, __pyx_k_kolmogorovt, sizeof(__pyx_k_kolmogorovt), 0, 0, 1, 1},
    {&__pyx_n_s_kovacicsols, __pyx_k_kovacicsols, sizeof(__pyx_k_kovacicsols), 0, 0, 1, 1},
    {&__pyx_n_s_kph, __pyx_k_kph, sizeof(__pyx_k_kph), 0, 0, 1, 1},
    {&__pyx_n_s_kq, __pyx_k_kq, sizeof(__pyx_k_kq), 0, 0, 1, 1},
    {&__pyx_n_s_kspaths, __pyx_k_kspaths, sizeof(__pyx_k_kspaths), 0, 0, 1, 1},
    {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
    {&__pyx_n_s_l1norm, __pyx_k_l1norm, sizeof(__pyx_k_l1norm), 0, 0, 1, 1},
    {&__pyx_n_s_l2norm, __pyx_k_l2norm, sizeof(__pyx_k_l2norm), 0, 0, 1, 1},
    {&__pyx_n_s_l_2, __pyx_k_l_2, sizeof(__pyx_k_l_2), 0, 0, 1, 1},
    {&__pyx_n_s_label, __pyx_k_label, sizeof(__pyx_k_label), 0, 0, 1, 1},
    {&__pyx_n_s_labels, __pyx_k_labels, sizeof(__pyx_k_labels), 0, 0, 1, 1},
    {&__pyx_n_s_lagrange, __pyx_k_lagrange, sizeof(__pyx_k_lagrange), 0, 0, 1, 1},
    {&__pyx_n_s_laguerre, __pyx_k_laguerre, sizeof(__pyx_k_laguerre), 0, 0, 1, 1},
    {&__pyx_n_s_lam, __pyx_k_lam, sizeof(__pyx_k_lam), 0, 0, 1, 1},
    {&__pyx_n_s_lambda0, __pyx_k_lambda0, sizeof(__pyx_k_lambda0), 0, 0, 1, 1},
    {&__pyx_n_s_lambdac, __pyx_k_lambdac, sizeof(__pyx_k_lambdac), 0, 0, 1, 1},
    {&__pyx_n_s_lang, __pyx_k_lang, sizeof(__pyx_k_lang), 0, 0, 1, 1},
    {&__pyx_n_s_laplace, __pyx_k_laplace, sizeof(__pyx_k_laplace), 0, 0, 1, 1},
    {&__pyx_n_s_laplacian, __pyx_k_laplacian, sizeof(__pyx_k_laplacian), 0, 0, 1, 1},
    {&__pyx_n_s_laplacian_matrix, __pyx_k_laplacian_matrix, sizeof(__pyx_k_laplacian_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_latex, __pyx_k_latex, sizeof(__pyx_k_latex), 0, 0, 1, 1},
    {&__pyx_n_s_lb, __pyx_k_lb, sizeof(__pyx_k_lb), 0, 0, 1, 1},
    {&__pyx_n_s_lbf, __pyx_k_lbf, sizeof(__pyx_k_lbf), 0, 0, 1, 1},
    {&__pyx_n_s_lbmol, __pyx_k_lbmol, sizeof(__pyx_k_lbmol), 0, 0, 1, 1},
    {&__pyx_n_s_lbt, __pyx_k_lbt, sizeof(__pyx_k_lbt), 0, 0, 1, 1},
    {&__pyx_n_s_lcf_graph, __pyx_k_lcf_graph, sizeof(__pyx_k_lcf_graph), 0, 0, 1, 1},
    {&__pyx_n_s_lcm, __pyx_k_lcm, sizeof(__pyx_k_lcm), 0, 0, 1, 1},
    {&__pyx_n_s_lcoeff, __pyx_k_lcoeff, sizeof(__pyx_k_lcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_ldegree, __pyx_k_ldegree, sizeof(__pyx_k_ldegree), 0, 0, 1, 1},
    {&__pyx_n_s_ldl, __pyx_k_ldl, sizeof(__pyx_k_ldl), 0, 0, 1, 1},
    {&__pyx_n_s_learning_rate, __pyx_k_learning_rate, sizeof(__pyx_k_learning_rate), 0, 0, 1, 1},
    {&__pyx_n_s_left, __pyx_k_left, sizeof(__pyx_k_left), 0, 0, 1, 1},
    {&__pyx_n_s_left_rectangle, __pyx_k_left_rectangle, sizeof(__pyx_k_left_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_legend, __pyx_k_legend, sizeof(__pyx_k_legend), 0, 0, 1, 1},
    {&__pyx_n_s_legendre, __pyx_k_legendre, sizeof(__pyx_k_legendre), 0, 0, 1, 1},
    {&__pyx_n_s_legendre_symbol, __pyx_k_legendre_symbol, sizeof(__pyx_k_legendre_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_len, __pyx_k_len, sizeof(__pyx_k_len), 0, 0, 1, 1},
    {&__pyx_n_s_length, __pyx_k_length, sizeof(__pyx_k_length), 0, 0, 1, 1},
    {&__pyx_n_s_lep, __pyx_k_lep, sizeof(__pyx_k_lep), 0, 0, 1, 1},
    {&__pyx_n_s_leve_crayon, __pyx_k_leve_crayon, sizeof(__pyx_k_leve_crayon), 0, 0, 1, 1},
    {&__pyx_n_s_levenshtein, __pyx_k_levenshtein, sizeof(__pyx_k_levenshtein), 0, 0, 1, 1},
    {&__pyx_n_s_lgcd, __pyx_k_lgcd, sizeof(__pyx_k_lgcd), 0, 0, 1, 1},
    {&__pyx_n_s_lhs, __pyx_k_lhs, sizeof(__pyx_k_lhs), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_chapeau_carre, __pyx_k_ligne_chapeau_carre, sizeof(__pyx_k_ligne_chapeau_carre), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_chapeau_plat, __pyx_k_ligne_chapeau_plat, sizeof(__pyx_k_ligne_chapeau_plat), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_chapeau_rond, __pyx_k_ligne_chapeau_rond, sizeof(__pyx_k_ligne_chapeau_rond), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_polygonale, __pyx_k_ligne_polygonale, sizeof(__pyx_k_ligne_polygonale), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_polygonale_pointee, __pyx_k_ligne_polygonale_pointee, sizeof(__pyx_k_ligne_polygonale_pointee), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_tiret, __pyx_k_ligne_tiret, sizeof(__pyx_k_ligne_tiret), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_tiret_point, __pyx_k_ligne_tiret_point, sizeof(__pyx_k_ligne_tiret_point), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_tiret_pointpoint, __pyx_k_ligne_tiret_pointpoint, sizeof(__pyx_k_ligne_tiret_pointpoint), 0, 0, 1, 1},
    {&__pyx_n_s_ligne_trait_plein, __pyx_k_ligne_trait_plein, sizeof(__pyx_k_ligne_trait_plein), 0, 0, 1, 1},
    {&__pyx_n_s_limit, __pyx_k_limit, sizeof(__pyx_k_limit), 0, 0, 1, 1},
    {&__pyx_n_s_limite, __pyx_k_limite, sizeof(__pyx_k_limite), 0, 0, 1, 1},
    {&__pyx_n_s_lin, __pyx_k_lin, sizeof(__pyx_k_lin), 0, 0, 1, 1},
    {&__pyx_n_s_linabs, __pyx_k_linabs, sizeof(__pyx_k_linabs), 0, 0, 1, 1},
    {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
    {&__pyx_n_s_line_graph, __pyx_k_line_graph, sizeof(__pyx_k_line_graph), 0, 0, 1, 1},
    {&__pyx_n_s_line_inter, __pyx_k_line_inter, sizeof(__pyx_k_line_inter), 0, 0, 1, 1},
    {&__pyx_n_s_line_paper, __pyx_k_line_paper, sizeof(__pyx_k_line_paper), 0, 0, 1, 1},
    {&__pyx_n_s_line_segments, __pyx_k_line_segments, sizeof(__pyx_k_line_segments), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_1, __pyx_k_line_width_1, sizeof(__pyx_k_line_width_1), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_2, __pyx_k_line_width_2, sizeof(__pyx_k_line_width_2), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_3, __pyx_k_line_width_3, sizeof(__pyx_k_line_width_3), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_4, __pyx_k_line_width_4, sizeof(__pyx_k_line_width_4), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_5, __pyx_k_line_width_5, sizeof(__pyx_k_line_width_5), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_6, __pyx_k_line_width_6, sizeof(__pyx_k_line_width_6), 0, 0, 1, 1},
    {&__pyx_n_s_line_width_7, __pyx_k_line_width_7, sizeof(__pyx_k_line_width_7), 0, 0, 1, 1},
    {&__pyx_n_s_linear_interpolate, __pyx_k_linear_interpolate, sizeof(__pyx_k_linear_interpolate), 0, 0, 1, 1},
    {&__pyx_n_s_linear_regression, __pyx_k_linear_regression, sizeof(__pyx_k_linear_regression), 0, 0, 1, 1},
    {&__pyx_n_s_linear_regression_plot, __pyx_k_linear_regression_plot, sizeof(__pyx_k_linear_regression_plot), 0, 0, 1, 1},
    {&__pyx_n_s_lineariser, __pyx_k_lineariser, sizeof(__pyx_k_lineariser), 0, 0, 1, 1},
    {&__pyx_n_s_lineariser_trigo, __pyx_k_lineariser_trigo, sizeof(__pyx_k_lineariser_trigo), 0, 0, 1, 1},
    {&__pyx_n_s_linfnorm, __pyx_k_linfnorm, sizeof(__pyx_k_linfnorm), 0, 0, 1, 1},
    {&__pyx_n_s_linsolve, __pyx_k_linsolve, sizeof(__pyx_k_linsolve), 0, 0, 1, 1},
    {&__pyx_n_s_linspace, __pyx_k_linspace, sizeof(__pyx_k_linspace), 0, 0, 1, 1},
    {&__pyx_n_s_linstep, __pyx_k_linstep, sizeof(__pyx_k_linstep), 0, 0, 1, 1},
    {&__pyx_n_s_liqpt, __pyx_k_liqpt, sizeof(__pyx_k_liqpt), 0, 0, 1, 1},
    {&__pyx_n_s_lis, __pyx_k_lis, sizeof(__pyx_k_lis), 0, 0, 1, 1},
    {&__pyx_n_s_lis_phrase, __pyx_k_lis_phrase, sizeof(__pyx_k_lis_phrase), 0, 0, 1, 1},
    {&__pyx_n_s_list, __pyx_k_list, sizeof(__pyx_k_list), 0, 0, 1, 1},
    {&__pyx_n_s_list2exp, __pyx_k_list2exp, sizeof(__pyx_k_list2exp), 0, 0, 1, 1},
    {&__pyx_n_s_list2mat, __pyx_k_list2mat, sizeof(__pyx_k_list2mat), 0, 0, 1, 1},
    {&__pyx_n_s_list_edge_attributes, __pyx_k_list_edge_attributes, sizeof(__pyx_k_list_edge_attributes), 0, 0, 1, 1},
    {&__pyx_n_s_list_graph_attributes, __pyx_k_list_graph_attributes, sizeof(__pyx_k_list_graph_attributes), 0, 0, 1, 1},
    {&__pyx_kp_s_list_index_s_out_of_range, __pyx_k_list_index_s_out_of_range, sizeof(__pyx_k_list_index_s_out_of_range), 0, 0, 1, 0},
    {&__pyx_n_s_list_vertex_attributes, __pyx_k_list_vertex_attributes, sizeof(__pyx_k_list_vertex_attributes), 0, 0, 1, 1},
    {&__pyx_n_s_listplot, __pyx_k_listplot, sizeof(__pyx_k_listplot), 0, 0, 1, 1},
    {&__pyx_n_s_listrange, __pyx_k_listrange, sizeof(__pyx_k_listrange), 0, 0, 1, 1},
    {&__pyx_n_s_lll, __pyx_k_lll, sizeof(__pyx_k_lll), 0, 0, 1, 1},
    {&__pyx_n_s_lm, __pyx_k_lm, sizeof(__pyx_k_lm), 0, 0, 1, 1},
    {&__pyx_n_s_ln, __pyx_k_ln, sizeof(__pyx_k_ln), 0, 0, 1, 1},
    {&__pyx_n_s_lname, __pyx_k_lname, sizeof(__pyx_k_lname), 0, 0, 1, 1},
    {&__pyx_n_s_lncollect, __pyx_k_lncollect, sizeof(__pyx_k_lncollect), 0, 0, 1, 1},
    {&__pyx_n_s_lnexpand, __pyx_k_lnexpand, sizeof(__pyx_k_lnexpand), 0, 0, 1, 1},
    {&__pyx_n_s_loadgiacgen, __pyx_k_loadgiacgen, sizeof(__pyx_k_loadgiacgen), 0, 0, 1, 1},
    {&__pyx_kp_u_loadgiacgen_line_2106, __pyx_k_loadgiacgen_line_2106, sizeof(__pyx_k_loadgiacgen_line_2106), 0, 1, 0, 0},
    {&__pyx_n_s_local, __pyx_k_local, sizeof(__pyx_k_local), 0, 0, 1, 1},
    {&__pyx_n_s_locus, __pyx_k_locus, sizeof(__pyx_k_locus), 0, 0, 1, 1},
    {&__pyx_n_s_log, __pyx_k_log, sizeof(__pyx_k_log), 0, 0, 1, 1},
    {&__pyx_n_s_log10, __pyx_k_log10, sizeof(__pyx_k_log10), 0, 0, 1, 1},
    {&__pyx_n_s_log2, __pyx_k_log2, sizeof(__pyx_k_log2), 0, 0, 1, 1},
    {&__pyx_n_s_log_loss, __pyx_k_log_loss, sizeof(__pyx_k_log_loss), 0, 0, 1, 1},
    {&__pyx_n_s_logarithmic_regression, __pyx_k_logarithmic_regression, sizeof(__pyx_k_logarithmic_regression), 0, 0, 1, 1},
    {&__pyx_n_s_logarithmic_regression_plot, __pyx_k_logarithmic_regression_plot, sizeof(__pyx_k_logarithmic_regression_plot), 0, 0, 1, 1},
    {&__pyx_n_s_logb, __pyx_k_logb, sizeof(__pyx_k_logb), 0, 0, 1, 1},
    {&__pyx_n_s_logistic, __pyx_k_logistic, sizeof(__pyx_k_logistic), 0, 0, 1, 1},
    {&__pyx_n_s_logistic_regression, __pyx_k_logistic_regression, sizeof(__pyx_k_logistic_regression), 0, 0, 1, 1},
    {&__pyx_n_s_logistic_regression_plot, __pyx_k_logistic_regression_plot, sizeof(__pyx_k_logistic_regression_plot), 0, 0, 1, 1},
    {&__pyx_n_s_long, __pyx_k_long, sizeof(__pyx_k_long), 0, 0, 1, 1},
    {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
    {&__pyx_n_s_lowest_common_ancestor, __pyx_k_lowest_common_ancestor, sizeof(__pyx_k_lowest_common_ancestor), 0, 0, 1, 1},
    {&__pyx_n_s_lowpass, __pyx_k_lowpass, sizeof(__pyx_k_lowpass), 0, 0, 1, 1},
    {&__pyx_n_s_lp_assume, __pyx_k_lp_assume, sizeof(__pyx_k_lp_assume), 0, 0, 1, 1},
    {&__pyx_n_s_lp_bestlocalbound, __pyx_k_lp_bestlocalbound, sizeof(__pyx_k_lp_bestlocalbound), 0, 0, 1, 1},
    {&__pyx_n_s_lp_bestprojection, __pyx_k_lp_bestprojection, sizeof(__pyx_k_lp_bestprojection), 0, 0, 1, 1},
    {&__pyx_n_s_lp_binary, __pyx_k_lp_binary, sizeof(__pyx_k_lp_binary), 0, 0, 1, 1},
    {&__pyx_n_s_lp_binaryvariables, __pyx_k_lp_binaryvariables, sizeof(__pyx_k_lp_binaryvariables), 0, 0, 1, 1},
    {&__pyx_n_s_lp_breadthfirst, __pyx_k_lp_breadthfirst, sizeof(__pyx_k_lp_breadthfirst), 0, 0, 1, 1},
    {&__pyx_n_s_lp_depthfirst, __pyx_k_lp_depthfirst, sizeof(__pyx_k_lp_depthfirst), 0, 0, 1, 1},
    {&__pyx_n_s_lp_depthlimit, __pyx_k_lp_depthlimit, sizeof(__pyx_k_lp_depthlimit), 0, 0, 1, 1},
    {&__pyx_n_s_lp_firstfractional, __pyx_k_lp_firstfractional, sizeof(__pyx_k_lp_firstfractional), 0, 0, 1, 1},
    {&__pyx_n_s_lp_gaptolerance, __pyx_k_lp_gaptolerance, sizeof(__pyx_k_lp_gaptolerance), 0, 0, 1, 1},
    {&__pyx_n_s_lp_heuristic, __pyx_k_lp_heuristic, sizeof(__pyx_k_lp_heuristic), 0, 0, 1, 1},
    {&__pyx_n_s_lp_hybrid, __pyx_k_lp_hybrid, sizeof(__pyx_k_lp_hybrid), 0, 0, 1, 1},
    {&__pyx_n_s_lp_integer, __pyx_k_lp_integer, sizeof(__pyx_k_lp_integer), 0, 0, 1, 1},
    {&__pyx_n_s_lp_integervariables, __pyx_k_lp_integervariables, sizeof(__pyx_k_lp_integervariables), 0, 0, 1, 1},
    {&__pyx_n_s_lp_interiorpoint, __pyx_k_lp_interiorpoint, sizeof(__pyx_k_lp_interiorpoint), 0, 0, 1, 1},
    {&__pyx_n_s_lp_iterationlimit, __pyx_k_lp_iterationlimit, sizeof(__pyx_k_lp_iterationlimit), 0, 0, 1, 1},
    {&__pyx_n_s_lp_lastfractional, __pyx_k_lp_lastfractional, sizeof(__pyx_k_lp_lastfractional), 0, 0, 1, 1},
    {&__pyx_n_s_lp_maxcuts, __pyx_k_lp_maxcuts, sizeof(__pyx_k_lp_maxcuts), 0, 0, 1, 1},
    {&__pyx_n_s_lp_maximize, __pyx_k_lp_maximize, sizeof(__pyx_k_lp_maximize), 0, 0, 1, 1},
    {&__pyx_n_s_lp_method, __pyx_k_lp_method, sizeof(__pyx_k_lp_method), 0, 0, 1, 1},
    {&__pyx_n_s_lp_mostfractional, __pyx_k_lp_mostfractional, sizeof(__pyx_k_lp_mostfractional), 0, 0, 1, 1},
    {&__pyx_n_s_lp_nodelimit, __pyx_k_lp_nodelimit, sizeof(__pyx_k_lp_nodelimit), 0, 0, 1, 1},
    {&__pyx_n_s_lp_nodeselect, __pyx_k_lp_nodeselect, sizeof(__pyx_k_lp_nodeselect), 0, 0, 1, 1},
    {&__pyx_n_s_lp_nonnegative, __pyx_k_lp_nonnegative, sizeof(__pyx_k_lp_nonnegative), 0, 0, 1, 1},
    {&__pyx_n_s_lp_nonnegint, __pyx_k_lp_nonnegint, sizeof(__pyx_k_lp_nonnegint), 0, 0, 1, 1},
    {&__pyx_n_s_lp_presolve, __pyx_k_lp_presolve, sizeof(__pyx_k_lp_presolve), 0, 0, 1, 1},
    {&__pyx_n_s_lp_pseudocost, __pyx_k_lp_pseudocost, sizeof(__pyx_k_lp_pseudocost), 0, 0, 1, 1},
    {&__pyx_n_s_lp_simplex, __pyx_k_lp_simplex, sizeof(__pyx_k_lp_simplex), 0, 0, 1, 1},
    {&__pyx_n_s_lp_timelimit, __pyx_k_lp_timelimit, sizeof(__pyx_k_lp_timelimit), 0, 0, 1, 1},
    {&__pyx_n_s_lp_varselect, __pyx_k_lp_varselect, sizeof(__pyx_k_lp_varselect), 0, 0, 1, 1},
    {&__pyx_n_s_lp_verbose, __pyx_k_lp_verbose, sizeof(__pyx_k_lp_verbose), 0, 0, 1, 1},
    {&__pyx_n_s_lpsolve, __pyx_k_lpsolve, sizeof(__pyx_k_lpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_lsmod, __pyx_k_lsmod, sizeof(__pyx_k_lsmod), 0, 0, 1, 1},
    {&__pyx_n_s_lsq, __pyx_k_lsq, sizeof(__pyx_k_lsq), 0, 0, 1, 1},
    {&__pyx_n_s_lu, __pyx_k_lu, sizeof(__pyx_k_lu), 0, 0, 1, 1},
    {&__pyx_n_s_lvar, __pyx_k_lvar, sizeof(__pyx_k_lvar), 0, 0, 1, 1},
    {&__pyx_n_s_lx, __pyx_k_lx, sizeof(__pyx_k_lx), 0, 0, 1, 1},
    {&__pyx_n_s_lyr, __pyx_k_lyr, sizeof(__pyx_k_lyr), 0, 0, 1, 1},
    {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
    {&__pyx_n_s_mEarth, __pyx_k_mEarth, sizeof(__pyx_k_mEarth), 0, 0, 1, 1},
    {&__pyx_n_s_mRow, __pyx_k_mRow, sizeof(__pyx_k_mRow), 0, 0, 1, 1},
    {&__pyx_n_s_mRowAdd, __pyx_k_mRowAdd, sizeof(__pyx_k_mRowAdd), 0, 0, 1, 1},
    {&__pyx_kp_s_m_2, __pyx_k_m_2, sizeof(__pyx_k_m_2), 0, 0, 1, 0},
    {&__pyx_kp_s_m_3, __pyx_k_m_3, sizeof(__pyx_k_m_3), 0, 0, 1, 0},
    {&__pyx_kp_s_m_s, __pyx_k_m_s, sizeof(__pyx_k_m_s), 0, 0, 1, 0},
    {&__pyx_kp_s_m_s_2, __pyx_k_m_s_2, sizeof(__pyx_k_m_s_2), 0, 0, 1, 0},
    {&__pyx_n_s_magenta, __pyx_k_magenta, sizeof(__pyx_k_magenta), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_make_directed, __pyx_k_make_directed, sizeof(__pyx_k_make_directed), 0, 0, 1, 1},
    {&__pyx_n_s_make_symbol, __pyx_k_make_symbol, sizeof(__pyx_k_make_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_make_weighted, __pyx_k_make_weighted, sizeof(__pyx_k_make_weighted), 0, 0, 1, 1},
    {&__pyx_n_s_makelist, __pyx_k_makelist, sizeof(__pyx_k_makelist), 0, 0, 1, 1},
    {&__pyx_n_s_makemat, __pyx_k_makemat, sizeof(__pyx_k_makemat), 0, 0, 1, 1},
    {&__pyx_n_s_makesuite, __pyx_k_makesuite, sizeof(__pyx_k_makesuite), 0, 0, 1, 1},
    {&__pyx_n_s_makevector, __pyx_k_makevector, sizeof(__pyx_k_makevector), 0, 0, 1, 1},
    {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
    {&__pyx_n_s_maple2mupad, __pyx_k_maple2mupad, sizeof(__pyx_k_maple2mupad), 0, 0, 1, 1},
    {&__pyx_n_s_maple2xcas, __pyx_k_maple2xcas, sizeof(__pyx_k_maple2xcas), 0, 0, 1, 1},
    {&__pyx_n_s_maple_ifactors, __pyx_k_maple_ifactors, sizeof(__pyx_k_maple_ifactors), 0, 0, 1, 1},
    {&__pyx_n_s_maple_mode, __pyx_k_maple_mode, sizeof(__pyx_k_maple_mode), 0, 0, 1, 1},
    {&__pyx_n_s_markov, __pyx_k_markov, sizeof(__pyx_k_markov), 0, 0, 1, 1},
    {&__pyx_n_s_mat2list, __pyx_k_mat2list, sizeof(__pyx_k_mat2list), 0, 0, 1, 1},
    {&__pyx_n_s_math, __pyx_k_math, sizeof(__pyx_k_math), 0, 0, 1, 1},
    {&__pyx_n_s_mathml, __pyx_k_mathml, sizeof(__pyx_k_mathml), 0, 0, 1, 1},
    {&__pyx_n_s_matpow, __pyx_k_matpow, sizeof(__pyx_k_matpow), 0, 0, 1, 1},
    {&__pyx_n_s_matrix, __pyx_k_matrix, sizeof(__pyx_k_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_matrix_norm, __pyx_k_matrix_norm, sizeof(__pyx_k_matrix_norm), 0, 0, 1, 1},
    {&__pyx_n_s_max, __pyx_k_max, sizeof(__pyx_k_max), 0, 0, 1, 1},
    {&__pyx_n_s_maxcount, __pyx_k_maxcount, sizeof(__pyx_k_maxcount), 0, 0, 1, 1},
    {&__pyx_n_s_maxflow, __pyx_k_maxflow, sizeof(__pyx_k_maxflow), 0, 0, 1, 1},
    {&__pyx_n_s_maximal_independent_set, __pyx_k_maximal_independent_set, sizeof(__pyx_k_maximal_independent_set), 0, 0, 1, 1},
    {&__pyx_n_s_maximize, __pyx_k_maximize, sizeof(__pyx_k_maximize), 0, 0, 1, 1},
    {&__pyx_n_s_maximum_clique, __pyx_k_maximum_clique, sizeof(__pyx_k_maximum_clique), 0, 0, 1, 1},
    {&__pyx_n_s_maximum_degree, __pyx_k_maximum_degree, sizeof(__pyx_k_maximum_degree), 0, 0, 1, 1},
    {&__pyx_n_s_maximum_independent_set, __pyx_k_maximum_independent_set, sizeof(__pyx_k_maximum_independent_set), 0, 0, 1, 1},
    {&__pyx_n_s_maximum_matching, __pyx_k_maximum_matching, sizeof(__pyx_k_maximum_matching), 0, 0, 1, 1},
    {&__pyx_n_s_maxnorm, __pyx_k_maxnorm, sizeof(__pyx_k_maxnorm), 0, 0, 1, 1},
    {&__pyx_n_s_maxsize, __pyx_k_maxsize, sizeof(__pyx_k_maxsize), 0, 0, 1, 1},
    {&__pyx_n_s_me, __pyx_k_me, sizeof(__pyx_k_me), 0, 0, 1, 1},
    {&__pyx_n_s_mean, __pyx_k_mean, sizeof(__pyx_k_mean), 0, 0, 1, 1},
    {&__pyx_n_s_median, __pyx_k_median, sizeof(__pyx_k_median), 0, 0, 1, 1},
    {&__pyx_n_s_median_line, __pyx_k_median_line, sizeof(__pyx_k_median_line), 0, 0, 1, 1},
    {&__pyx_n_s_member, __pyx_k_member, sizeof(__pyx_k_member), 0, 0, 1, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_mgf, __pyx_k_mgf, sizeof(__pyx_k_mgf), 0, 0, 1, 1},
    {&__pyx_n_s_mho, __pyx_k_mho, sizeof(__pyx_k_mho), 0, 0, 1, 1},
    {&__pyx_n_s_miUS, __pyx_k_miUS, sizeof(__pyx_k_miUS), 0, 0, 1, 1},
    {&__pyx_kp_s_miUS_2, __pyx_k_miUS_2, sizeof(__pyx_k_miUS_2), 0, 0, 1, 0},
    {&__pyx_kp_s_mi_2, __pyx_k_mi_2, sizeof(__pyx_k_mi_2), 0, 0, 1, 0},
    {&__pyx_n_s_mid, __pyx_k_mid, sizeof(__pyx_k_mid), 0, 0, 1, 1},
    {&__pyx_n_s_middle_point, __pyx_k_middle_point, sizeof(__pyx_k_middle_point), 0, 0, 1, 1},
    {&__pyx_n_s_midpoint, __pyx_k_midpoint, sizeof(__pyx_k_midpoint), 0, 0, 1, 1},
    {&__pyx_n_s_mil, __pyx_k_mil, sizeof(__pyx_k_mil), 0, 0, 1, 1},
    {&__pyx_n_s_mile, __pyx_k_mile, sizeof(__pyx_k_mile), 0, 0, 1, 1},
    {&__pyx_n_s_mille, __pyx_k_mille, sizeof(__pyx_k_mille), 0, 0, 1, 1},
    {&__pyx_n_s_min, __pyx_k_min, sizeof(__pyx_k_min), 0, 0, 1, 1},
    {&__pyx_n_s_minimal_edge_coloring, __pyx_k_minimal_edge_coloring, sizeof(__pyx_k_minimal_edge_coloring), 0, 0, 1, 1},
    {&__pyx_n_s_minimal_spanning_tree, __pyx_k_minimal_spanning_tree, sizeof(__pyx_k_minimal_spanning_tree), 0, 0, 1, 1},
    {&__pyx_n_s_minimal_vertex_coloring, __pyx_k_minimal_vertex_coloring, sizeof(__pyx_k_minimal_vertex_coloring), 0, 0, 1, 1},
    {&__pyx_n_s_minimax, __pyx_k_minimax, sizeof(__pyx_k_minimax), 0, 0, 1, 1},
    {&__pyx_n_s_minimize, __pyx_k_minimize, sizeof(__pyx_k_minimize), 0, 0, 1, 1},
    {&__pyx_n_s_minimum_cut, __pyx_k_minimum_cut, sizeof(__pyx_k_minimum_cut), 0, 0, 1, 1},
    {&__pyx_n_s_minimum_degree, __pyx_k_minimum_degree, sizeof(__pyx_k_minimum_degree), 0, 0, 1, 1},
    {&__pyx_n_s_minimum_vertex_cover, __pyx_k_minimum_vertex_cover, sizeof(__pyx_k_minimum_vertex_cover), 0, 0, 1, 1},
    {&__pyx_n_s_minus, __pyx_k_minus, sizeof(__pyx_k_minus), 0, 0, 1, 1},
    {&__pyx_n_s_mixdown, __pyx_k_mixdown, sizeof(__pyx_k_mixdown), 0, 0, 1, 1},
    {&__pyx_n_s_mkisom, __pyx_k_mkisom, sizeof(__pyx_k_mkisom), 0, 0, 1, 1},
    {&__pyx_n_s_mksa, __pyx_k_mksa, sizeof(__pyx_k_mksa), 0, 0, 1, 1},
    {&__pyx_n_s_ml, __pyx_k_ml, sizeof(__pyx_k_ml), 0, 0, 1, 1},
    {&__pyx_n_s_mm, __pyx_k_mm, sizeof(__pyx_k_mm), 0, 0, 1, 1},
    {&__pyx_n_s_mmHg, __pyx_k_mmHg, sizeof(__pyx_k_mmHg), 0, 0, 1, 1},
    {&__pyx_n_s_mn, __pyx_k_mn, sizeof(__pyx_k_mn), 0, 0, 1, 1},
    {&__pyx_n_s_mod, __pyx_k_mod, sizeof(__pyx_k_mod), 0, 0, 1, 1},
    {&__pyx_n_s_modf, __pyx_k_modf, sizeof(__pyx_k_modf), 0, 0, 1, 1},
    {&__pyx_n_s_modgcd, __pyx_k_modgcd, sizeof(__pyx_k_modgcd), 0, 0, 1, 1},
    {&__pyx_n_s_mods, __pyx_k_mods, sizeof(__pyx_k_mods), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_n_s_mol, __pyx_k_mol, sizeof(__pyx_k_mol), 0, 0, 1, 1},
    {&__pyx_n_s_momentum, __pyx_k_momentum, sizeof(__pyx_k_momentum), 0, 0, 1, 1},
    {&__pyx_n_s_monotonic, __pyx_k_monotonic, sizeof(__pyx_k_monotonic), 0, 0, 1, 1},
    {&__pyx_n_s_montre_tortue, __pyx_k_montre_tortue, sizeof(__pyx_k_montre_tortue), 0, 0, 1, 1},
    {&__pyx_n_s_moremethods, __pyx_k_moremethods, sizeof(__pyx_k_moremethods), 0, 0, 1, 1},
    {&__pyx_n_s_moretests, __pyx_k_moretests, sizeof(__pyx_k_moretests), 0, 0, 1, 1},
    {&__pyx_kp_u_moretests_line_2061, __pyx_k_moretests_line_2061, sizeof(__pyx_k_moretests_line_2061), 0, 1, 0, 0},
    {&__pyx_n_s_mostkeywords, __pyx_k_mostkeywords, sizeof(__pyx_k_mostkeywords), 0, 0, 1, 1},
    {&__pyx_n_s_moustache, __pyx_k_moustache, sizeof(__pyx_k_moustache), 0, 0, 1, 1},
    {&__pyx_n_s_moving_average, __pyx_k_moving_average, sizeof(__pyx_k_moving_average), 0, 0, 1, 1},
    {&__pyx_n_s_moyal, __pyx_k_moyal, sizeof(__pyx_k_moyal), 0, 0, 1, 1},
    {&__pyx_n_s_moyenne, __pyx_k_moyenne, sizeof(__pyx_k_moyenne), 0, 0, 1, 1},
    {&__pyx_n_s_mp, __pyx_k_mp, sizeof(__pyx_k_mp), 0, 0, 1, 1},
    {&__pyx_n_s_mph, __pyx_k_mph, sizeof(__pyx_k_mph), 0, 0, 1, 1},
    {&__pyx_n_s_mpme, __pyx_k_mpme, sizeof(__pyx_k_mpme), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_s_mu0, __pyx_k_mu0, sizeof(__pyx_k_mu0), 0, 0, 1, 1},
    {&__pyx_n_s_muB, __pyx_k_muB, sizeof(__pyx_k_muB), 0, 0, 1, 1},
    {&__pyx_n_s_muN, __pyx_k_muN, sizeof(__pyx_k_muN), 0, 0, 1, 1},
    {&__pyx_n_s_mul, __pyx_k_mul, sizeof(__pyx_k_mul), 0, 0, 1, 1},
    {&__pyx_n_s_mul_2, __pyx_k_mul_2, sizeof(__pyx_k_mul_2), 0, 0, 1, 1},
    {&__pyx_n_s_mult_c_conjugate, __pyx_k_mult_c_conjugate, sizeof(__pyx_k_mult_c_conjugate), 0, 0, 1, 1},
    {&__pyx_n_s_mult_conjugate, __pyx_k_mult_conjugate, sizeof(__pyx_k_mult_conjugate), 0, 0, 1, 1},
    {&__pyx_n_s_multinomial, __pyx_k_multinomial, sizeof(__pyx_k_multinomial), 0, 0, 1, 1},
    {&__pyx_n_s_multiplier_conjugue, __pyx_k_multiplier_conjugue, sizeof(__pyx_k_multiplier_conjugue), 0, 0, 1, 1},
    {&__pyx_n_s_multiplier_conjugue_complexe, __pyx_k_multiplier_conjugue_complexe, sizeof(__pyx_k_multiplier_conjugue_complexe), 0, 0, 1, 1},
    {&__pyx_n_s_multiply, __pyx_k_multiply, sizeof(__pyx_k_multiply), 0, 0, 1, 1},
    {&__pyx_n_s_mupad2maple, __pyx_k_mupad2maple, sizeof(__pyx_k_mupad2maple), 0, 0, 1, 1},
    {&__pyx_n_s_mupad2xcas, __pyx_k_mupad2xcas, sizeof(__pyx_k_mupad2xcas), 0, 0, 1, 1},
    {&__pyx_n_s_mycielski, __pyx_k_mycielski, sizeof(__pyx_k_mycielski), 0, 0, 1, 1},
    {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
    {&__pyx_n_s_nCr, __pyx_k_nCr, sizeof(__pyx_k_nCr), 0, 0, 1, 1},
    {&__pyx_n_s_nDeriv, __pyx_k_nDeriv, sizeof(__pyx_k_nDeriv), 0, 0, 1, 1},
    {&__pyx_n_s_nInt, __pyx_k_nInt, sizeof(__pyx_k_nInt), 0, 0, 1, 1},
    {&__pyx_n_s_nPr, __pyx_k_nPr, sizeof(__pyx_k_nPr), 0, 0, 1, 1},
    {&__pyx_n_s_nSolve, __pyx_k_nSolve, sizeof(__pyx_k_nSolve), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_navy, __pyx_k_navy, sizeof(__pyx_k_navy), 0, 0, 1, 1},
    {&__pyx_n_s_ncols, __pyx_k_ncols, sizeof(__pyx_k_ncols), 0, 0, 1, 1},
    {&__pyx_n_s_neg, __pyx_k_neg, sizeof(__pyx_k_neg), 0, 0, 1, 1},
    {&__pyx_n_s_negbinomial, __pyx_k_negbinomial, sizeof(__pyx_k_negbinomial), 0, 0, 1, 1},
    {&__pyx_n_s_negbinomial_cdf, __pyx_k_negbinomial_cdf, sizeof(__pyx_k_negbinomial_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_negbinomial_icdf, __pyx_k_negbinomial_icdf, sizeof(__pyx_k_negbinomial_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_neighbors, __pyx_k_neighbors, sizeof(__pyx_k_neighbors), 0, 0, 1, 1},
    {&__pyx_n_s_network_transitivity, __pyx_k_network_transitivity, sizeof(__pyx_k_network_transitivity), 0, 0, 1, 1},
    {&__pyx_n_s_neural_network, __pyx_k_neural_network, sizeof(__pyx_k_neural_network), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_newList, __pyx_k_newList, sizeof(__pyx_k_newList), 0, 0, 1, 1},
    {&__pyx_n_s_newMat, __pyx_k_newMat, sizeof(__pyx_k_newMat), 0, 0, 1, 1},
    {&__pyx_n_s_newton, __pyx_k_newton, sizeof(__pyx_k_newton), 0, 0, 1, 1},
    {&__pyx_n_s_newton_solver, __pyx_k_newton_solver, sizeof(__pyx_k_newton_solver), 0, 0, 1, 1},
    {&__pyx_n_s_newtonj_solver, __pyx_k_newtonj_solver, sizeof(__pyx_k_newtonj_solver), 0, 0, 1, 1},
    {&__pyx_n_s_nextperm, __pyx_k_nextperm, sizeof(__pyx_k_nextperm), 0, 0, 1, 1},
    {&__pyx_n_s_nextprime, __pyx_k_nextprime, sizeof(__pyx_k_nextprime), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_binary, __pyx_k_nlp_binary, sizeof(__pyx_k_nlp_binary), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_binaryvariables, __pyx_k_nlp_binaryvariables, sizeof(__pyx_k_nlp_binaryvariables), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_initialpoint, __pyx_k_nlp_initialpoint, sizeof(__pyx_k_nlp_initialpoint), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_integer, __pyx_k_nlp_integer, sizeof(__pyx_k_nlp_integer), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_integervariables, __pyx_k_nlp_integervariables, sizeof(__pyx_k_nlp_integervariables), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_iterationlimit, __pyx_k_nlp_iterationlimit, sizeof(__pyx_k_nlp_iterationlimit), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_maximize, __pyx_k_nlp_maximize, sizeof(__pyx_k_nlp_maximize), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_method, __pyx_k_nlp_method, sizeof(__pyx_k_nlp_method), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_nonnegative, __pyx_k_nlp_nonnegative, sizeof(__pyx_k_nlp_nonnegative), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_nonnegint, __pyx_k_nlp_nonnegint, sizeof(__pyx_k_nlp_nonnegint), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_precision, __pyx_k_nlp_precision, sizeof(__pyx_k_nlp_precision), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_presolve, __pyx_k_nlp_presolve, sizeof(__pyx_k_nlp_presolve), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_tolerance, __pyx_k_nlp_tolerance, sizeof(__pyx_k_nlp_tolerance), 0, 0, 1, 1},
    {&__pyx_n_s_nlp_verbose, __pyx_k_nlp_verbose, sizeof(__pyx_k_nlp_verbose), 0, 0, 1, 1},
    {&__pyx_n_s_nlpsolve, __pyx_k_nlpsolve, sizeof(__pyx_k_nlpsolve), 0, 0, 1, 1},
    {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
    {&__pyx_n_s_nodisp, __pyx_k_nodisp, sizeof(__pyx_k_nodisp), 0, 0, 1, 1},
    {&__pyx_n_s_noir, __pyx_k_noir, sizeof(__pyx_k_noir), 0, 0, 1, 1},
    {&__pyx_n_s_nom_cache, __pyx_k_nom_cache, sizeof(__pyx_k_nom_cache), 0, 0, 1, 1},
    {&__pyx_n_s_non, __pyx_k_non, sizeof(__pyx_k_non), 0, 0, 1, 1},
    {&__pyx_n_s_non_recursive_normal, __pyx_k_non_recursive_normal, sizeof(__pyx_k_non_recursive_normal), 0, 0, 1, 1},
    {&__pyx_n_s_nonevaluable, __pyx_k_nonevaluable, sizeof(__pyx_k_nonevaluable), 0, 0, 1, 1},
    {&__pyx_n_s_nonnegint, __pyx_k_nonnegint, sizeof(__pyx_k_nonnegint), 0, 0, 1, 1},
    {&__pyx_n_s_nop, __pyx_k_nop, sizeof(__pyx_k_nop), 0, 0, 1, 1},
    {&__pyx_n_s_nops, __pyx_k_nops, sizeof(__pyx_k_nops), 0, 0, 1, 1},
    {&__pyx_n_s_norm, __pyx_k_norm, sizeof(__pyx_k_norm), 0, 0, 1, 1},
    {&__pyx_n_s_normal, __pyx_k_normal, sizeof(__pyx_k_normal), 0, 0, 1, 1},
    {&__pyx_n_s_normal_cdf, __pyx_k_normal_cdf, sizeof(__pyx_k_normal_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_normal_icdf, __pyx_k_normal_icdf, sizeof(__pyx_k_normal_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_normald, __pyx_k_normald, sizeof(__pyx_k_normald), 0, 0, 1, 1},
    {&__pyx_n_s_normald_cdf, __pyx_k_normald_cdf, sizeof(__pyx_k_normald_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_normald_icdf, __pyx_k_normald_icdf, sizeof(__pyx_k_normald_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_normalize, __pyx_k_normalize, sizeof(__pyx_k_normalize), 0, 0, 1, 1},
    {&__pyx_n_s_normalt, __pyx_k_normalt, sizeof(__pyx_k_normalt), 0, 0, 1, 1},
    {&__pyx_n_s_normalvariate, __pyx_k_normalvariate, sizeof(__pyx_k_normalvariate), 0, 0, 1, 1},
    {&__pyx_n_s_not, __pyx_k_not, sizeof(__pyx_k_not), 0, 0, 1, 1},
    {&__pyx_n_s_nprimes, __pyx_k_nprimes, sizeof(__pyx_k_nprimes), 0, 0, 1, 1},
    {&__pyx_n_s_nrows, __pyx_k_nrows, sizeof(__pyx_k_nrows), 0, 0, 1, 1},
    {&__pyx_n_s_nstep, __pyx_k_nstep, sizeof(__pyx_k_nstep), 0, 0, 1, 1},
    {&__pyx_n_s_nuage_points, __pyx_k_nuage_points, sizeof(__pyx_k_nuage_points), 0, 0, 1, 1},
    {&__pyx_n_s_nullspace, __pyx_k_nullspace, sizeof(__pyx_k_nullspace), 0, 0, 1, 1},
    {&__pyx_n_s_number_of_edges, __pyx_k_number_of_edges, sizeof(__pyx_k_number_of_edges), 0, 0, 1, 1},
    {&__pyx_n_s_number_of_spanning_trees, __pyx_k_number_of_spanning_trees, sizeof(__pyx_k_number_of_spanning_trees), 0, 0, 1, 1},
    {&__pyx_n_s_number_of_triangles, __pyx_k_number_of_triangles, sizeof(__pyx_k_number_of_triangles), 0, 0, 1, 1},
    {&__pyx_n_s_number_of_vertices, __pyx_k_number_of_vertices, sizeof(__pyx_k_number_of_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_numdiff, __pyx_k_numdiff, sizeof(__pyx_k_numdiff), 0, 0, 1, 1},
    {&__pyx_n_s_numer, __pyx_k_numer, sizeof(__pyx_k_numer), 0, 0, 1, 1},
    {&__pyx_n_s_octahedron, __pyx_k_octahedron, sizeof(__pyx_k_octahedron), 0, 0, 1, 1},
    {&__pyx_n_s_od, __pyx_k_od, sizeof(__pyx_k_od), 0, 0, 1, 1},
    {&__pyx_n_s_odd, __pyx_k_odd, sizeof(__pyx_k_odd), 0, 0, 1, 1},
    {&__pyx_n_s_odd_girth, __pyx_k_odd_girth, sizeof(__pyx_k_odd_girth), 0, 0, 1, 1},
    {&__pyx_n_s_odd_graph, __pyx_k_odd_graph, sizeof(__pyx_k_odd_graph), 0, 0, 1, 1},
    {&__pyx_n_s_odeplot, __pyx_k_odeplot, sizeof(__pyx_k_odeplot), 0, 0, 1, 1},
    {&__pyx_n_s_odesolve, __pyx_k_odesolve, sizeof(__pyx_k_odesolve), 0, 0, 1, 1},
    {&__pyx_n_s_of, __pyx_k_of, sizeof(__pyx_k_of), 0, 0, 1, 1},
    {&__pyx_n_s_oldies, __pyx_k_oldies, sizeof(__pyx_k_oldies), 0, 0, 1, 1},
    {&__pyx_n_s_olive, __pyx_k_olive, sizeof(__pyx_k_olive), 0, 0, 1, 1},
    {&__pyx_n_s_op, __pyx_k_op, sizeof(__pyx_k_op), 0, 0, 1, 1},
    {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
    {&__pyx_n_s_open_polygon, __pyx_k_open_polygon, sizeof(__pyx_k_open_polygon), 0, 0, 1, 1},
    {&__pyx_n_s_option, __pyx_k_option, sizeof(__pyx_k_option), 0, 0, 1, 1},
    {&__pyx_n_s_or, __pyx_k_or, sizeof(__pyx_k_or), 0, 0, 1, 1},
    {&__pyx_n_s_orange, __pyx_k_orange, sizeof(__pyx_k_orange), 0, 0, 1, 1},
    {&__pyx_n_s_ord, __pyx_k_ord, sizeof(__pyx_k_ord), 0, 0, 1, 1},
    {&__pyx_n_s_order, __pyx_k_order, sizeof(__pyx_k_order), 0, 0, 1, 1},
    {&__pyx_n_s_order_size, __pyx_k_order_size, sizeof(__pyx_k_order_size), 0, 0, 1, 1},
    {&__pyx_n_s_ordinate, __pyx_k_ordinate, sizeof(__pyx_k_ordinate), 0, 0, 1, 1},
    {&__pyx_n_s_orthocenter, __pyx_k_orthocenter, sizeof(__pyx_k_orthocenter), 0, 0, 1, 1},
    {&__pyx_n_s_orthogonal, __pyx_k_orthogonal, sizeof(__pyx_k_orthogonal), 0, 0, 1, 1},
    {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
    {&__pyx_n_s_osculating_circle, __pyx_k_osculating_circle, sizeof(__pyx_k_osculating_circle), 0, 0, 1, 1},
    {&__pyx_n_s_otherwise, __pyx_k_otherwise, sizeof(__pyx_k_otherwise), 0, 0, 1, 1},
    {&__pyx_n_s_ou, __pyx_k_ou, sizeof(__pyx_k_ou), 0, 0, 1, 1},
    {&__pyx_n_s_output, __pyx_k_output, sizeof(__pyx_k_output), 0, 0, 1, 1},
    {&__pyx_n_s_oz, __pyx_k_oz, sizeof(__pyx_k_oz), 0, 0, 1, 1},
    {&__pyx_n_s_ozUK, __pyx_k_ozUK, sizeof(__pyx_k_ozUK), 0, 0, 1, 1},
    {&__pyx_n_s_ozfl, __pyx_k_ozfl, sizeof(__pyx_k_ozfl), 0, 0, 1, 1},
    {&__pyx_n_s_ozt, __pyx_k_ozt, sizeof(__pyx_k_ozt), 0, 0, 1, 1},
    {&__pyx_n_s_p1oc2, __pyx_k_p1oc2, sizeof(__pyx_k_p1oc2), 0, 0, 1, 1},
    {&__pyx_n_s_p1op2, __pyx_k_p1op2, sizeof(__pyx_k_p1op2), 0, 0, 1, 1},
    {&__pyx_n_s_pa2b2, __pyx_k_pa2b2, sizeof(__pyx_k_pa2b2), 0, 0, 1, 1},
    {&__pyx_n_s_pade, __pyx_k_pade, sizeof(__pyx_k_pade), 0, 0, 1, 1},
    {&__pyx_n_s_paley_graph, __pyx_k_paley_graph, sizeof(__pyx_k_paley_graph), 0, 0, 1, 1},
    {&__pyx_n_s_parabola, __pyx_k_parabola, sizeof(__pyx_k_parabola), 0, 0, 1, 1},
    {&__pyx_n_s_parallel, __pyx_k_parallel, sizeof(__pyx_k_parallel), 0, 0, 1, 1},
    {&__pyx_n_s_parallelepiped, __pyx_k_parallelepiped, sizeof(__pyx_k_parallelepiped), 0, 0, 1, 1},
    {&__pyx_n_s_parallelogram, __pyx_k_parallelogram, sizeof(__pyx_k_parallelogram), 0, 0, 1, 1},
    {&__pyx_n_s_param, __pyx_k_param, sizeof(__pyx_k_param), 0, 0, 1, 1},
    {&__pyx_n_s_parameq, __pyx_k_parameq, sizeof(__pyx_k_parameq), 0, 0, 1, 1},
    {&__pyx_n_s_parameter, __pyx_k_parameter, sizeof(__pyx_k_parameter), 0, 0, 1, 1},
    {&__pyx_n_s_paramplot, __pyx_k_paramplot, sizeof(__pyx_k_paramplot), 0, 0, 1, 1},
    {&__pyx_n_s_parfrac, __pyx_k_parfrac, sizeof(__pyx_k_parfrac), 0, 0, 1, 1},
    {&__pyx_n_s_pari, __pyx_k_pari, sizeof(__pyx_k_pari), 0, 0, 1, 1},
    {&__pyx_n_s_part, __pyx_k_part, sizeof(__pyx_k_part), 0, 0, 1, 1},
    {&__pyx_n_s_partfrac, __pyx_k_partfrac, sizeof(__pyx_k_partfrac), 0, 0, 1, 1},
    {&__pyx_n_s_parzen_window, __pyx_k_parzen_window, sizeof(__pyx_k_parzen_window), 0, 0, 1, 1},
    {&__pyx_n_s_pas, __pyx_k_pas, sizeof(__pyx_k_pas), 0, 0, 1, 1},
    {&__pyx_n_s_pas_de_cote, __pyx_k_pas_de_cote, sizeof(__pyx_k_pas_de_cote), 0, 0, 1, 1},
    {&__pyx_n_s_path_graph, __pyx_k_path_graph, sizeof(__pyx_k_path_graph), 0, 0, 1, 1},
    {&__pyx_n_s_pc, __pyx_k_pc, sizeof(__pyx_k_pc), 0, 0, 1, 1},
    {&__pyx_n_s_pcar, __pyx_k_pcar, sizeof(__pyx_k_pcar), 0, 0, 1, 1},
    {&__pyx_n_s_pcar_hessenberg, __pyx_k_pcar_hessenberg, sizeof(__pyx_k_pcar_hessenberg), 0, 0, 1, 1},
    {&__pyx_n_s_pcoef, __pyx_k_pcoef, sizeof(__pyx_k_pcoef), 0, 0, 1, 1},
    {&__pyx_n_s_pcoeff, __pyx_k_pcoeff, sizeof(__pyx_k_pcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_pdl, __pyx_k_pdl, sizeof(__pyx_k_pdl), 0, 0, 1, 1},
    {&__pyx_n_s_pencolor, __pyx_k_pencolor, sizeof(__pyx_k_pencolor), 0, 0, 1, 1},
    {&__pyx_n_s_pendown, __pyx_k_pendown, sizeof(__pyx_k_pendown), 0, 0, 1, 1},
    {&__pyx_n_s_penup, __pyx_k_penup, sizeof(__pyx_k_penup), 0, 0, 1, 1},
    {&__pyx_n_s_perimeter, __pyx_k_perimeter, sizeof(__pyx_k_perimeter), 0, 0, 1, 1},
    {&__pyx_n_s_perimeterat, __pyx_k_perimeterat, sizeof(__pyx_k_perimeterat), 0, 0, 1, 1},
    {&__pyx_n_s_perimeteratraw, __pyx_k_perimeteratraw, sizeof(__pyx_k_perimeteratraw), 0, 0, 1, 1},
    {&__pyx_n_s_period, __pyx_k_period, sizeof(__pyx_k_period), 0, 0, 1, 1},
    {&__pyx_n_s_periodic, __pyx_k_periodic, sizeof(__pyx_k_periodic), 0, 0, 1, 1},
    {&__pyx_n_s_perm, __pyx_k_perm, sizeof(__pyx_k_perm), 0, 0, 1, 1},
    {&__pyx_n_s_perminv, __pyx_k_perminv, sizeof(__pyx_k_perminv), 0, 0, 1, 1},
    {&__pyx_n_s_permu2cycles, __pyx_k_permu2cycles, sizeof(__pyx_k_permu2cycles), 0, 0, 1, 1},
    {&__pyx_n_s_permu2mat, __pyx_k_permu2mat, sizeof(__pyx_k_permu2mat), 0, 0, 1, 1},
    {&__pyx_n_s_permuorder, __pyx_k_permuorder, sizeof(__pyx_k_permuorder), 0, 0, 1, 1},
    {&__pyx_n_s_permute_vertices, __pyx_k_permute_vertices, sizeof(__pyx_k_permute_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_perpen_bisector, __pyx_k_perpen_bisector, sizeof(__pyx_k_perpen_bisector), 0, 0, 1, 1},
    {&__pyx_n_s_perpendicular, __pyx_k_perpendicular, sizeof(__pyx_k_perpendicular), 0, 0, 1, 1},
    {&__pyx_n_s_petersen_graph, __pyx_k_petersen_graph, sizeof(__pyx_k_petersen_graph), 0, 0, 1, 1},
    {&__pyx_n_s_peval, __pyx_k_peval, sizeof(__pyx_k_peval), 0, 0, 1, 1},
    {&__pyx_n_s_ph, __pyx_k_ph, sizeof(__pyx_k_ph), 0, 0, 1, 1},
    {&__pyx_n_s_phi, __pyx_k_phi, sizeof(__pyx_k_phi), 0, 0, 1, 1},
    {&__pyx_n_s_pi, __pyx_k_pi, sizeof(__pyx_k_pi), 0, 0, 1, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_pie, __pyx_k_pie, sizeof(__pyx_k_pie), 0, 0, 1, 1},
    {&__pyx_n_s_piecewise, __pyx_k_piecewise, sizeof(__pyx_k_piecewise), 0, 0, 1, 1},
    {&__pyx_n_s_pink, __pyx_k_pink, sizeof(__pyx_k_pink), 0, 0, 1, 1},
    {&__pyx_n_s_pivot, __pyx_k_pivot, sizeof(__pyx_k_pivot), 0, 0, 1, 1},
    {&__pyx_n_s_pixoff, __pyx_k_pixoff, sizeof(__pyx_k_pixoff), 0, 0, 1, 1},
    {&__pyx_n_s_pixon, __pyx_k_pixon, sizeof(__pyx_k_pixon), 0, 0, 1, 1},
    {&__pyx_n_s_pk, __pyx_k_pk, sizeof(__pyx_k_pk), 0, 0, 1, 1},
    {&__pyx_n_s_planar, __pyx_k_planar, sizeof(__pyx_k_planar), 0, 0, 1, 1},
    {&__pyx_n_s_plane, __pyx_k_plane, sizeof(__pyx_k_plane), 0, 0, 1, 1},
    {&__pyx_n_s_plane_dual, __pyx_k_plane_dual, sizeof(__pyx_k_plane_dual), 0, 0, 1, 1},
    {&__pyx_n_s_playsnd, __pyx_k_playsnd, sizeof(__pyx_k_playsnd), 0, 0, 1, 1},
    {&__pyx_n_s_plex, __pyx_k_plex, sizeof(__pyx_k_plex), 0, 0, 1, 1},
    {&__pyx_n_s_plot, __pyx_k_plot, sizeof(__pyx_k_plot), 0, 0, 1, 1},
    {&__pyx_n_s_plot3d, __pyx_k_plot3d, sizeof(__pyx_k_plot3d), 0, 0, 1, 1},
    {&__pyx_n_s_plotarea, __pyx_k_plotarea, sizeof(__pyx_k_plotarea), 0, 0, 1, 1},
    {&__pyx_n_s_plotcdf, __pyx_k_plotcdf, sizeof(__pyx_k_plotcdf), 0, 0, 1, 1},
    {&__pyx_n_s_plotcontour, __pyx_k_plotcontour, sizeof(__pyx_k_plotcontour), 0, 0, 1, 1},
    {&__pyx_n_s_plotdensity, __pyx_k_plotdensity, sizeof(__pyx_k_plotdensity), 0, 0, 1, 1},
    {&__pyx_n_s_plotfield, __pyx_k_plotfield, sizeof(__pyx_k_plotfield), 0, 0, 1, 1},
    {&__pyx_n_s_plotfunc, __pyx_k_plotfunc, sizeof(__pyx_k_plotfunc), 0, 0, 1, 1},
    {&__pyx_n_s_plotimf, __pyx_k_plotimf, sizeof(__pyx_k_plotimf), 0, 0, 1, 1},
    {&__pyx_n_s_plotimplicit, __pyx_k_plotimplicit, sizeof(__pyx_k_plotimplicit), 0, 0, 1, 1},
    {&__pyx_n_s_plotinequation, __pyx_k_plotinequation, sizeof(__pyx_k_plotinequation), 0, 0, 1, 1},
    {&__pyx_n_s_plotlist, __pyx_k_plotlist, sizeof(__pyx_k_plotlist), 0, 0, 1, 1},
    {&__pyx_n_s_plotode, __pyx_k_plotode, sizeof(__pyx_k_plotode), 0, 0, 1, 1},
    {&__pyx_n_s_plotparam, __pyx_k_plotparam, sizeof(__pyx_k_plotparam), 0, 0, 1, 1},
    {&__pyx_n_s_plotpolar, __pyx_k_plotpolar, sizeof(__pyx_k_plotpolar), 0, 0, 1, 1},
    {&__pyx_n_s_plotproba, __pyx_k_plotproba, sizeof(__pyx_k_plotproba), 0, 0, 1, 1},
    {&__pyx_n_s_plotseq, __pyx_k_plotseq, sizeof(__pyx_k_plotseq), 0, 0, 1, 1},
    {&__pyx_n_s_plotspectrum, __pyx_k_plotspectrum, sizeof(__pyx_k_plotspectrum), 0, 0, 1, 1},
    {&__pyx_n_s_plotwav, __pyx_k_plotwav, sizeof(__pyx_k_plotwav), 0, 0, 1, 1},
    {&__pyx_n_s_plus_point, __pyx_k_plus_point, sizeof(__pyx_k_plus_point), 0, 0, 1, 1},
    {&__pyx_n_s_pmin, __pyx_k_pmin, sizeof(__pyx_k_pmin), 0, 0, 1, 1},
    {&__pyx_n_s_pnt, __pyx_k_pnt, sizeof(__pyx_k_pnt), 0, 0, 1, 1},
    {&__pyx_n_s_point, __pyx_k_point, sizeof(__pyx_k_point), 0, 0, 1, 1},
    {&__pyx_n_s_point2d, __pyx_k_point2d, sizeof(__pyx_k_point2d), 0, 0, 1, 1},
    {&__pyx_n_s_point3d, __pyx_k_point3d, sizeof(__pyx_k_point3d), 0, 0, 1, 1},
    {&__pyx_n_s_point_arret, __pyx_k_point_arret, sizeof(__pyx_k_point_arret), 0, 0, 1, 1},
    {&__pyx_n_s_point_carre, __pyx_k_point_carre, sizeof(__pyx_k_point_carre), 0, 0, 1, 1},
    {&__pyx_n_s_point_croix, __pyx_k_point_croix, sizeof(__pyx_k_point_croix), 0, 0, 1, 1},
    {&__pyx_n_s_point_div, __pyx_k_point_div, sizeof(__pyx_k_point_div), 0, 0, 1, 1},
    {&__pyx_n_s_point_etoile, __pyx_k_point_etoile, sizeof(__pyx_k_point_etoile), 0, 0, 1, 1},
    {&__pyx_n_s_point_invisible, __pyx_k_point_invisible, sizeof(__pyx_k_point_invisible), 0, 0, 1, 1},
    {&__pyx_n_s_point_losange, __pyx_k_point_losange, sizeof(__pyx_k_point_losange), 0, 0, 1, 1},
    {&__pyx_n_s_point_milieu, __pyx_k_point_milieu, sizeof(__pyx_k_point_milieu), 0, 0, 1, 1},
    {&__pyx_n_s_point_plus, __pyx_k_point_plus, sizeof(__pyx_k_point_plus), 0, 0, 1, 1},
    {&__pyx_n_s_point_point, __pyx_k_point_point, sizeof(__pyx_k_point_point), 0, 0, 1, 1},
    {&__pyx_n_s_point_polaire, __pyx_k_point_polaire, sizeof(__pyx_k_point_polaire), 0, 0, 1, 1},
    {&__pyx_n_s_point_triangle, __pyx_k_point_triangle, sizeof(__pyx_k_point_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_1, __pyx_k_point_width_1, sizeof(__pyx_k_point_width_1), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_2, __pyx_k_point_width_2, sizeof(__pyx_k_point_width_2), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_3, __pyx_k_point_width_3, sizeof(__pyx_k_point_width_3), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_4, __pyx_k_point_width_4, sizeof(__pyx_k_point_width_4), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_5, __pyx_k_point_width_5, sizeof(__pyx_k_point_width_5), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_6, __pyx_k_point_width_6, sizeof(__pyx_k_point_width_6), 0, 0, 1, 1},
    {&__pyx_n_s_point_width_7, __pyx_k_point_width_7, sizeof(__pyx_k_point_width_7), 0, 0, 1, 1},
    {&__pyx_n_s_poisson, __pyx_k_poisson, sizeof(__pyx_k_poisson), 0, 0, 1, 1},
    {&__pyx_n_s_poisson_cdf, __pyx_k_poisson_cdf, sizeof(__pyx_k_poisson_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_poisson_icdf, __pyx_k_poisson_icdf, sizeof(__pyx_k_poisson_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_poisson_window, __pyx_k_poisson_window, sizeof(__pyx_k_poisson_window), 0, 0, 1, 1},
    {&__pyx_n_s_polar, __pyx_k_polar, sizeof(__pyx_k_polar), 0, 0, 1, 1},
    {&__pyx_n_s_polar_coordinates, __pyx_k_polar_coordinates, sizeof(__pyx_k_polar_coordinates), 0, 0, 1, 1},
    {&__pyx_n_s_polar_point, __pyx_k_polar_point, sizeof(__pyx_k_polar_point), 0, 0, 1, 1},
    {&__pyx_n_s_polarplot, __pyx_k_polarplot, sizeof(__pyx_k_polarplot), 0, 0, 1, 1},
    {&__pyx_n_s_pole, __pyx_k_pole, sizeof(__pyx_k_pole), 0, 0, 1, 1},
    {&__pyx_n_s_poly2symb, __pyx_k_poly2symb, sizeof(__pyx_k_poly2symb), 0, 0, 1, 1},
    {&__pyx_n_s_polyEval, __pyx_k_polyEval, sizeof(__pyx_k_polyEval), 0, 0, 1, 1},
    {&__pyx_n_s_polygon, __pyx_k_polygon, sizeof(__pyx_k_polygon), 0, 0, 1, 1},
    {&__pyx_n_s_polygone_rempli, __pyx_k_polygone_rempli, sizeof(__pyx_k_polygone_rempli), 0, 0, 1, 1},
    {&__pyx_n_s_polygonplot, __pyx_k_polygonplot, sizeof(__pyx_k_polygonplot), 0, 0, 1, 1},
    {&__pyx_n_s_polygonscatterplot, __pyx_k_polygonscatterplot, sizeof(__pyx_k_polygonscatterplot), 0, 0, 1, 1},
    {&__pyx_n_s_polyhedron, __pyx_k_polyhedron, sizeof(__pyx_k_polyhedron), 0, 0, 1, 1},
    {&__pyx_n_s_polynom, __pyx_k_polynom, sizeof(__pyx_k_polynom), 0, 0, 1, 1},
    {&__pyx_n_s_polynomial_regression, __pyx_k_polynomial_regression, sizeof(__pyx_k_polynomial_regression), 0, 0, 1, 1},
    {&__pyx_n_s_polynomial_regression_plot, __pyx_k_polynomial_regression_plot, sizeof(__pyx_k_polynomial_regression_plot), 0, 0, 1, 1},
    {&__pyx_n_s_position, __pyx_k_position, sizeof(__pyx_k_position), 0, 0, 1, 1},
    {&__pyx_n_s_poslbdLMQ, __pyx_k_poslbdLMQ, sizeof(__pyx_k_poslbdLMQ), 0, 0, 1, 1},
    {&__pyx_n_s_posubLMQ, __pyx_k_posubLMQ, sizeof(__pyx_k_posubLMQ), 0, 0, 1, 1},
    {&__pyx_n_s_potential, __pyx_k_potential, sizeof(__pyx_k_potential), 0, 0, 1, 1},
    {&__pyx_n_s_pour, __pyx_k_pour, sizeof(__pyx_k_pour), 0, 0, 1, 1},
    {&__pyx_n_s_pow, __pyx_k_pow, sizeof(__pyx_k_pow), 0, 0, 1, 1},
    {&__pyx_n_s_pow2exp, __pyx_k_pow2exp, sizeof(__pyx_k_pow2exp), 0, 0, 1, 1},
    {&__pyx_n_s_pow_2, __pyx_k_pow_2, sizeof(__pyx_k_pow_2), 0, 0, 1, 1},
    {&__pyx_n_s_power_regression, __pyx_k_power_regression, sizeof(__pyx_k_power_regression), 0, 0, 1, 1},
    {&__pyx_n_s_power_regression_plot, __pyx_k_power_regression_plot, sizeof(__pyx_k_power_regression_plot), 0, 0, 1, 1},
    {&__pyx_n_s_powermod, __pyx_k_powermod, sizeof(__pyx_k_powermod), 0, 0, 1, 1},
    {&__pyx_n_s_powerpc, __pyx_k_powerpc, sizeof(__pyx_k_powerpc), 0, 0, 1, 1},
    {&__pyx_n_s_powexpand, __pyx_k_powexpand, sizeof(__pyx_k_powexpand), 0, 0, 1, 1},
    {&__pyx_n_s_powmod, __pyx_k_powmod, sizeof(__pyx_k_powmod), 0, 0, 1, 1},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_s_prepend, __pyx_k_prepend, sizeof(__pyx_k_prepend), 0, 0, 1, 1},
    {&__pyx_n_s_preval, __pyx_k_preval, sizeof(__pyx_k_preval), 0, 0, 1, 1},
    {&__pyx_n_s_prevperm, __pyx_k_prevperm, sizeof(__pyx_k_prevperm), 0, 0, 1, 1},
    {&__pyx_n_s_prevprime, __pyx_k_prevprime, sizeof(__pyx_k_prevprime), 0, 0, 1, 1},
    {&__pyx_n_s_primpart, __pyx_k_primpart, sizeof(__pyx_k_primpart), 0, 0, 1, 1},
    {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
    {&__pyx_n_s_printf, __pyx_k_printf, sizeof(__pyx_k_printf), 0, 0, 1, 1},
    {&__pyx_kp_s_printpow_1, __pyx_k_printpow_1, sizeof(__pyx_k_printpow_1), 0, 0, 1, 0},
    {&__pyx_n_s_prism, __pyx_k_prism, sizeof(__pyx_k_prism), 0, 0, 1, 1},
    {&__pyx_n_s_prism_graph, __pyx_k_prism_graph, sizeof(__pyx_k_prism_graph), 0, 0, 1, 1},
    {&__pyx_n_s_proc, __pyx_k_proc, sizeof(__pyx_k_proc), 0, 0, 1, 1},
    {&__pyx_n_s_product, __pyx_k_product, sizeof(__pyx_k_product), 0, 0, 1, 1},
    {&__pyx_n_s_program, __pyx_k_program, sizeof(__pyx_k_program), 0, 0, 1, 1},
    {&__pyx_n_s_projection, __pyx_k_projection, sizeof(__pyx_k_projection), 0, 0, 1, 1},
    {&__pyx_n_s_proot, __pyx_k_proot, sizeof(__pyx_k_proot), 0, 0, 1, 1},
    {&__pyx_n_s_propFrac, __pyx_k_propFrac, sizeof(__pyx_k_propFrac), 0, 0, 1, 1},
    {&__pyx_n_s_propfrac, __pyx_k_propfrac, sizeof(__pyx_k_propfrac), 0, 0, 1, 1},
    {&__pyx_n_s_pruefer_code, __pyx_k_pruefer_code, sizeof(__pyx_k_pruefer_code), 0, 0, 1, 1},
    {&__pyx_n_s_psi, __pyx_k_psi, sizeof(__pyx_k_psi), 0, 0, 1, 1},
    {&__pyx_n_s_psrgcd, __pyx_k_psrgcd, sizeof(__pyx_k_psrgcd), 0, 0, 1, 1},
    {&__pyx_n_s_ptUK, __pyx_k_ptUK, sizeof(__pyx_k_ptUK), 0, 0, 1, 1},
    {&__pyx_n_s_ptayl, __pyx_k_ptayl, sizeof(__pyx_k_ptayl), 0, 0, 1, 1},
    {&__pyx_n_s_purge, __pyx_k_purge, sizeof(__pyx_k_purge), 0, 0, 1, 1},
    {&__pyx_kp_s_purge_GIACPY_TMP_NAME05026807096, __pyx_k_purge_GIACPY_TMP_NAME05026807096, sizeof(__pyx_k_purge_GIACPY_TMP_NAME05026807096), 0, 0, 1, 0},
    {&__pyx_n_s_purple, __pyx_k_purple, sizeof(__pyx_k_purple), 0, 0, 1, 1},
    {&__pyx_n_s_pwd, __pyx_k_pwd, sizeof(__pyx_k_pwd), 0, 0, 1, 1},
    {&__pyx_n_s_pyramid, __pyx_k_pyramid, sizeof(__pyx_k_pyramid), 0, 0, 1, 1},
    {&__pyx_n_s_python_compat, __pyx_k_python_compat, sizeof(__pyx_k_python_compat), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_capi, __pyx_k_pyx_capi, sizeof(__pyx_k_pyx_capi), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_GiacMethods_base, __pyx_k_pyx_unpickle_GiacMethods_base, sizeof(__pyx_k_pyx_unpickle_GiacMethods_base), 0, 0, 1, 1},
    {&__pyx_n_s_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 0, 1, 1},
    {&__pyx_n_s_q2a, __pyx_k_q2a, sizeof(__pyx_k_q2a), 0, 0, 1, 1},
    {&__pyx_n_s_qcas, __pyx_k_qcas, sizeof(__pyx_k_qcas), 0, 0, 1, 1},
    {&__pyx_kp_u_qcas_line_1879, __pyx_k_qcas_line_1879, sizeof(__pyx_k_qcas_line_1879), 0, 1, 0, 0},
    {&__pyx_n_s_qe, __pyx_k_qe, sizeof(__pyx_k_qe), 0, 0, 1, 1},
    {&__pyx_n_s_qepsilon0, __pyx_k_qepsilon0, sizeof(__pyx_k_qepsilon0), 0, 0, 1, 1},
    {&__pyx_n_s_qme, __pyx_k_qme, sizeof(__pyx_k_qme), 0, 0, 1, 1},
    {&__pyx_n_s_qr, __pyx_k_qr, sizeof(__pyx_k_qr), 0, 0, 1, 1},
    {&__pyx_n_s_qt, __pyx_k_qt, sizeof(__pyx_k_qt), 0, 0, 1, 1},
    {&__pyx_n_s_quadrant1, __pyx_k_quadrant1, sizeof(__pyx_k_quadrant1), 0, 0, 1, 1},
    {&__pyx_n_s_quadrant2, __pyx_k_quadrant2, sizeof(__pyx_k_quadrant2), 0, 0, 1, 1},
    {&__pyx_n_s_quadrant3, __pyx_k_quadrant3, sizeof(__pyx_k_quadrant3), 0, 0, 1, 1},
    {&__pyx_n_s_quadrant4, __pyx_k_quadrant4, sizeof(__pyx_k_quadrant4), 0, 0, 1, 1},
    {&__pyx_n_s_quadric, __pyx_k_quadric, sizeof(__pyx_k_quadric), 0, 0, 1, 1},
    {&__pyx_n_s_quadrilateral, __pyx_k_quadrilateral, sizeof(__pyx_k_quadrilateral), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_quantile, __pyx_k_quantile, sizeof(__pyx_k_quantile), 0, 0, 1, 1},
    {&__pyx_n_s_quartile1, __pyx_k_quartile1, sizeof(__pyx_k_quartile1), 0, 0, 1, 1},
    {&__pyx_n_s_quartile3, __pyx_k_quartile3, sizeof(__pyx_k_quartile3), 0, 0, 1, 1},
    {&__pyx_n_s_quartiles, __pyx_k_quartiles, sizeof(__pyx_k_quartiles), 0, 0, 1, 1},
    {&__pyx_n_s_quest, __pyx_k_quest, sizeof(__pyx_k_quest), 0, 0, 1, 1},
    {&__pyx_n_s_quo, __pyx_k_quo, sizeof(__pyx_k_quo), 0, 0, 1, 1},
    {&__pyx_n_s_quorem, __pyx_k_quorem, sizeof(__pyx_k_quorem), 0, 0, 1, 1},
    {&__pyx_n_s_quote, __pyx_k_quote, sizeof(__pyx_k_quote), 0, 0, 1, 1},
    {&__pyx_n_s_r2e, __pyx_k_r2e, sizeof(__pyx_k_r2e), 0, 0, 1, 1},
    {&__pyx_n_s_rad, __pyx_k_rad, sizeof(__pyx_k_rad), 0, 0, 1, 1},
    {&__pyx_n_s_rad_2, __pyx_k_rad_2, sizeof(__pyx_k_rad_2), 0, 0, 1, 1},
    {&__pyx_kp_s_rad_s, __pyx_k_rad_s, sizeof(__pyx_k_rad_s), 0, 0, 1, 0},
    {&__pyx_kp_s_rad_s_2, __pyx_k_rad_s_2, sizeof(__pyx_k_rad_s_2), 0, 0, 1, 0},
    {&__pyx_n_s_radians, __pyx_k_radians, sizeof(__pyx_k_radians), 0, 0, 1, 1},
    {&__pyx_n_s_radical_axis, __pyx_k_radical_axis, sizeof(__pyx_k_radical_axis), 0, 0, 1, 1},
    {&__pyx_n_s_radius, __pyx_k_radius, sizeof(__pyx_k_radius), 0, 0, 1, 1},
    {&__pyx_n_s_ramene, __pyx_k_ramene, sizeof(__pyx_k_ramene), 0, 0, 1, 1},
    {&__pyx_n_s_rand, __pyx_k_rand, sizeof(__pyx_k_rand), 0, 0, 1, 1},
    {&__pyx_n_s_randMat, __pyx_k_randMat, sizeof(__pyx_k_randMat), 0, 0, 1, 1},
    {&__pyx_n_s_randNorm, __pyx_k_randNorm, sizeof(__pyx_k_randNorm), 0, 0, 1, 1},
    {&__pyx_n_s_randPoly, __pyx_k_randPoly, sizeof(__pyx_k_randPoly), 0, 0, 1, 1},
    {&__pyx_n_s_randbetad, __pyx_k_randbetad, sizeof(__pyx_k_randbetad), 0, 0, 1, 1},
    {&__pyx_n_s_randbinomial, __pyx_k_randbinomial, sizeof(__pyx_k_randbinomial), 0, 0, 1, 1},
    {&__pyx_n_s_randchisquare, __pyx_k_randchisquare, sizeof(__pyx_k_randchisquare), 0, 0, 1, 1},
    {&__pyx_n_s_randexp, __pyx_k_randexp, sizeof(__pyx_k_randexp), 0, 0, 1, 1},
    {&__pyx_n_s_randfisher, __pyx_k_randfisher, sizeof(__pyx_k_randfisher), 0, 0, 1, 1},
    {&__pyx_n_s_randgammad, __pyx_k_randgammad, sizeof(__pyx_k_randgammad), 0, 0, 1, 1},
    {&__pyx_n_s_randgeometric, __pyx_k_randgeometric, sizeof(__pyx_k_randgeometric), 0, 0, 1, 1},
    {&__pyx_n_s_randint, __pyx_k_randint, sizeof(__pyx_k_randint), 0, 0, 1, 1},
    {&__pyx_n_s_randmarkov, __pyx_k_randmarkov, sizeof(__pyx_k_randmarkov), 0, 0, 1, 1},
    {&__pyx_n_s_randmatrix, __pyx_k_randmatrix, sizeof(__pyx_k_randmatrix), 0, 0, 1, 1},
    {&__pyx_n_s_randmultinomial, __pyx_k_randmultinomial, sizeof(__pyx_k_randmultinomial), 0, 0, 1, 1},
    {&__pyx_n_s_randnorm, __pyx_k_randnorm, sizeof(__pyx_k_randnorm), 0, 0, 1, 1},
    {&__pyx_n_s_random, __pyx_k_random, sizeof(__pyx_k_random), 0, 0, 1, 1},
    {&__pyx_n_s_random_bipartite_graph, __pyx_k_random_bipartite_graph, sizeof(__pyx_k_random_bipartite_graph), 0, 0, 1, 1},
    {&__pyx_n_s_random_digraph, __pyx_k_random_digraph, sizeof(__pyx_k_random_digraph), 0, 0, 1, 1},
    {&__pyx_n_s_random_graph, __pyx_k_random_graph, sizeof(__pyx_k_random_graph), 0, 0, 1, 1},
    {&__pyx_n_s_random_network, __pyx_k_random_network, sizeof(__pyx_k_random_network), 0, 0, 1, 1},
    {&__pyx_n_s_random_planar_graph, __pyx_k_random_planar_graph, sizeof(__pyx_k_random_planar_graph), 0, 0, 1, 1},
    {&__pyx_n_s_random_regular_graph, __pyx_k_random_regular_graph, sizeof(__pyx_k_random_regular_graph), 0, 0, 1, 1},
    {&__pyx_n_s_random_sequence_graph, __pyx_k_random_sequence_graph, sizeof(__pyx_k_random_sequence_graph), 0, 0, 1, 1},
    {&__pyx_n_s_random_tournament, __pyx_k_random_tournament, sizeof(__pyx_k_random_tournament), 0, 0, 1, 1},
    {&__pyx_n_s_random_tree, __pyx_k_random_tree, sizeof(__pyx_k_random_tree), 0, 0, 1, 1},
    {&__pyx_n_s_random_variable, __pyx_k_random_variable, sizeof(__pyx_k_random_variable), 0, 0, 1, 1},
    {&__pyx_n_s_randperm, __pyx_k_randperm, sizeof(__pyx_k_randperm), 0, 0, 1, 1},
    {&__pyx_n_s_randpoisson, __pyx_k_randpoisson, sizeof(__pyx_k_randpoisson), 0, 0, 1, 1},
    {&__pyx_n_s_randpoly, __pyx_k_randpoly, sizeof(__pyx_k_randpoly), 0, 0, 1, 1},
    {&__pyx_n_s_randseed, __pyx_k_randseed, sizeof(__pyx_k_randseed), 0, 0, 1, 1},
    {&__pyx_n_s_randstudent, __pyx_k_randstudent, sizeof(__pyx_k_randstudent), 0, 0, 1, 1},
    {&__pyx_n_s_randvar, __pyx_k_randvar, sizeof(__pyx_k_randvar), 0, 0, 1, 1},
    {&__pyx_n_s_randvector, __pyx_k_randvector, sizeof(__pyx_k_randvector), 0, 0, 1, 1},
    {&__pyx_n_s_randweibulld, __pyx_k_randweibulld, sizeof(__pyx_k_randweibulld), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_rank, __pyx_k_rank, sizeof(__pyx_k_rank), 0, 0, 1, 1},
    {&__pyx_n_s_ranm, __pyx_k_ranm, sizeof(__pyx_k_ranm), 0, 0, 1, 1},
    {&__pyx_n_s_ranv, __pyx_k_ranv, sizeof(__pyx_k_ranv), 0, 0, 1, 1},
    {&__pyx_n_s_rassembler_trigo, __pyx_k_rassembler_trigo, sizeof(__pyx_k_rassembler_trigo), 0, 0, 1, 1},
    {&__pyx_n_s_rat_jordan, __pyx_k_rat_jordan, sizeof(__pyx_k_rat_jordan), 0, 0, 1, 1},
    {&__pyx_n_s_ratinterp, __pyx_k_ratinterp, sizeof(__pyx_k_ratinterp), 0, 0, 1, 1},
    {&__pyx_n_s_rational, __pyx_k_rational, sizeof(__pyx_k_rational), 0, 0, 1, 1},
    {&__pyx_n_s_rationalroot, __pyx_k_rationalroot, sizeof(__pyx_k_rationalroot), 0, 0, 1, 1},
    {&__pyx_n_s_ratnormal, __pyx_k_ratnormal, sizeof(__pyx_k_ratnormal), 0, 0, 1, 1},
    {&__pyx_n_s_rd, __pyx_k_rd, sizeof(__pyx_k_rd), 0, 0, 1, 1},
    {&__pyx_n_s_rdiv, __pyx_k_rdiv, sizeof(__pyx_k_rdiv), 0, 0, 1, 1},
    {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
    {&__pyx_n_s_reachable, __pyx_k_reachable, sizeof(__pyx_k_reachable), 0, 0, 1, 1},
    {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
    {&__pyx_n_s_readrgb, __pyx_k_readrgb, sizeof(__pyx_k_readrgb), 0, 0, 1, 1},
    {&__pyx_n_s_readwav, __pyx_k_readwav, sizeof(__pyx_k_readwav), 0, 0, 1, 1},
    {&__pyx_n_s_real, __pyx_k_real, sizeof(__pyx_k_real), 0, 0, 1, 1},
    {&__pyx_n_s_realroot, __pyx_k_realroot, sizeof(__pyx_k_realroot), 0, 0, 1, 1},
    {&__pyx_n_s_reciprocation, __pyx_k_reciprocation, sizeof(__pyx_k_reciprocation), 0, 0, 1, 1},
    {&__pyx_n_s_rect, __pyx_k_rect, sizeof(__pyx_k_rect), 0, 0, 1, 1},
    {&__pyx_n_s_rectangle, __pyx_k_rectangle, sizeof(__pyx_k_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_rectangle_droit, __pyx_k_rectangle_droit, sizeof(__pyx_k_rectangle_droit), 0, 0, 1, 1},
    {&__pyx_n_s_rectangle_gauche, __pyx_k_rectangle_gauche, sizeof(__pyx_k_rectangle_gauche), 0, 0, 1, 1},
    {&__pyx_n_s_rectangle_plein, __pyx_k_rectangle_plein, sizeof(__pyx_k_rectangle_plein), 0, 0, 1, 1},
    {&__pyx_n_s_rectangular_coordinates, __pyx_k_rectangular_coordinates, sizeof(__pyx_k_rectangular_coordinates), 0, 0, 1, 1},
    {&__pyx_n_s_recule, __pyx_k_recule, sizeof(__pyx_k_recule), 0, 0, 1, 1},
    {&__pyx_n_s_red, __pyx_k_red, sizeof(__pyx_k_red), 0, 0, 1, 1},
    {&__pyx_n_s_redim, __pyx_k_redim, sizeof(__pyx_k_redim), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_reduced_conic, __pyx_k_reduced_conic, sizeof(__pyx_k_reduced_conic), 0, 0, 1, 1},
    {&__pyx_n_s_reduced_quadric, __pyx_k_reduced_quadric, sizeof(__pyx_k_reduced_quadric), 0, 0, 1, 1},
    {&__pyx_n_s_ref, __pyx_k_ref, sizeof(__pyx_k_ref), 0, 0, 1, 1},
    {&__pyx_n_s_reflection, __pyx_k_reflection, sizeof(__pyx_k_reflection), 0, 0, 1, 1},
    {&__pyx_n_s_regroup, __pyx_k_regroup, sizeof(__pyx_k_regroup), 0, 0, 1, 1},
    {&__pyx_n_s_relabel_vertices, __pyx_k_relabel_vertices, sizeof(__pyx_k_relabel_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_reliability_polynomial, __pyx_k_reliability_polynomial, sizeof(__pyx_k_reliability_polynomial), 0, 0, 1, 1},
    {&__pyx_n_s_rem, __pyx_k_rem, sizeof(__pyx_k_rem), 0, 0, 1, 1},
    {&__pyx_n_s_rem_2, __pyx_k_rem_2, sizeof(__pyx_k_rem_2), 0, 0, 1, 1},
    {&__pyx_n_s_remain, __pyx_k_remain, sizeof(__pyx_k_remain), 0, 0, 1, 1},
    {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
    {&__pyx_n_s_reorder, __pyx_k_reorder, sizeof(__pyx_k_reorder), 0, 0, 1, 1},
    {&__pyx_n_s_repeat, __pyx_k_repeat, sizeof(__pyx_k_repeat), 0, 0, 1, 1},
    {&__pyx_n_s_repete, __pyx_k_repete, sizeof(__pyx_k_repete), 0, 0, 1, 1},
    {&__pyx_n_s_repeter, __pyx_k_repeter, sizeof(__pyx_k_repeter), 0, 0, 1, 1},
    {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
    {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
    {&__pyx_n_s_repr_html, __pyx_k_repr_html, sizeof(__pyx_k_repr_html), 0, 0, 1, 1},
    {&__pyx_n_s_repr_latex, __pyx_k_repr_latex, sizeof(__pyx_k_repr_latex), 0, 0, 1, 1},
    {&__pyx_n_s_resample, __pyx_k_resample, sizeof(__pyx_k_resample), 0, 0, 1, 1},
    {&__pyx_n_s_residue, __pyx_k_residue, sizeof(__pyx_k_residue), 0, 0, 1, 1},
    {&__pyx_n_s_resoudre, __pyx_k_resoudre, sizeof(__pyx_k_resoudre), 0, 0, 1, 1},
    {&__pyx_n_s_resoudre_dans_C, __pyx_k_resoudre_dans_C, sizeof(__pyx_k_resoudre_dans_C), 0, 0, 1, 1},
    {&__pyx_n_s_resoudre_systeme_lineaire, __pyx_k_resoudre_systeme_lineaire, sizeof(__pyx_k_resoudre_systeme_lineaire), 0, 0, 1, 1},
    {&__pyx_n_s_restart, __pyx_k_restart, sizeof(__pyx_k_restart), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_resultant, __pyx_k_resultant, sizeof(__pyx_k_resultant), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_reverse, __pyx_k_reverse, sizeof(__pyx_k_reverse), 0, 0, 1, 1},
    {&__pyx_n_s_reverse_graph, __pyx_k_reverse_graph, sizeof(__pyx_k_reverse_graph), 0, 0, 1, 1},
    {&__pyx_n_s_reverse_rsolve, __pyx_k_reverse_rsolve, sizeof(__pyx_k_reverse_rsolve), 0, 0, 1, 1},
    {&__pyx_n_s_revert, __pyx_k_revert, sizeof(__pyx_k_revert), 0, 0, 1, 1},
    {&__pyx_n_s_revlex, __pyx_k_revlex, sizeof(__pyx_k_revlex), 0, 0, 1, 1},
    {&__pyx_n_s_revlist, __pyx_k_revlist, sizeof(__pyx_k_revlist), 0, 0, 1, 1},
    {&__pyx_n_s_rgb, __pyx_k_rgb, sizeof(__pyx_k_rgb), 0, 0, 1, 1},
    {&__pyx_n_s_rgb2hsv, __pyx_k_rgb2hsv, sizeof(__pyx_k_rgb2hsv), 0, 0, 1, 1},
    {&__pyx_n_s_rgb2xyz, __pyx_k_rgb2xyz, sizeof(__pyx_k_rgb2xyz), 0, 0, 1, 1},
    {&__pyx_n_s_rhombus, __pyx_k_rhombus, sizeof(__pyx_k_rhombus), 0, 0, 1, 1},
    {&__pyx_n_s_rhombus_point, __pyx_k_rhombus_point, sizeof(__pyx_k_rhombus_point), 0, 0, 1, 1},
    {&__pyx_n_s_rhs, __pyx_k_rhs, sizeof(__pyx_k_rhs), 0, 0, 1, 1},
    {&__pyx_n_s_riemann_window, __pyx_k_riemann_window, sizeof(__pyx_k_riemann_window), 0, 0, 1, 1},
    {&__pyx_n_s_right, __pyx_k_right, sizeof(__pyx_k_right), 0, 0, 1, 1},
    {&__pyx_n_s_right_rectangle, __pyx_k_right_rectangle, sizeof(__pyx_k_right_rectangle), 0, 0, 1, 1},
    {&__pyx_n_s_right_triangle, __pyx_k_right_triangle, sizeof(__pyx_k_right_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_risch, __pyx_k_risch, sizeof(__pyx_k_risch), 0, 0, 1, 1},
    {&__pyx_n_s_rm_a_z, __pyx_k_rm_a_z, sizeof(__pyx_k_rm_a_z), 0, 0, 1, 1},
    {&__pyx_n_s_rm_all_vars, __pyx_k_rm_all_vars, sizeof(__pyx_k_rm_all_vars), 0, 0, 1, 1},
    {&__pyx_n_s_rmbreakpoint, __pyx_k_rmbreakpoint, sizeof(__pyx_k_rmbreakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_rmmod, __pyx_k_rmmod, sizeof(__pyx_k_rmmod), 0, 0, 1, 1},
    {&__pyx_n_s_rms, __pyx_k_rms, sizeof(__pyx_k_rms), 0, 0, 1, 1},
    {&__pyx_n_s_rmwatch, __pyx_k_rmwatch, sizeof(__pyx_k_rmwatch), 0, 0, 1, 1},
    {&__pyx_n_s_rod, __pyx_k_rod, sizeof(__pyx_k_rod), 0, 0, 1, 1},
    {&__pyx_n_s_romberg, __pyx_k_romberg, sizeof(__pyx_k_romberg), 0, 0, 1, 1},
    {&__pyx_n_s_rombergm, __pyx_k_rombergm, sizeof(__pyx_k_rombergm), 0, 0, 1, 1},
    {&__pyx_n_s_rombergt, __pyx_k_rombergt, sizeof(__pyx_k_rombergt), 0, 0, 1, 1},
    {&__pyx_n_s_rond, __pyx_k_rond, sizeof(__pyx_k_rond), 0, 0, 1, 1},
    {&__pyx_n_s_root, __pyx_k_root, sizeof(__pyx_k_root), 0, 0, 1, 1},
    {&__pyx_n_s_rootof, __pyx_k_rootof, sizeof(__pyx_k_rootof), 0, 0, 1, 1},
    {&__pyx_n_s_roots, __pyx_k_roots, sizeof(__pyx_k_roots), 0, 0, 1, 1},
    {&__pyx_n_s_rotate, __pyx_k_rotate, sizeof(__pyx_k_rotate), 0, 0, 1, 1},
    {&__pyx_n_s_rotation, __pyx_k_rotation, sizeof(__pyx_k_rotation), 0, 0, 1, 1},
    {&__pyx_n_s_rouge, __pyx_k_rouge, sizeof(__pyx_k_rouge), 0, 0, 1, 1},
    {&__pyx_n_s_round, __pyx_k_round, sizeof(__pyx_k_round), 0, 0, 1, 1},
    {&__pyx_n_s_row, __pyx_k_row, sizeof(__pyx_k_row), 0, 0, 1, 1},
    {&__pyx_n_s_rowAdd, __pyx_k_rowAdd, sizeof(__pyx_k_rowAdd), 0, 0, 1, 1},
    {&__pyx_n_s_rowDim, __pyx_k_rowDim, sizeof(__pyx_k_rowDim), 0, 0, 1, 1},
    {&__pyx_n_s_rowNorm, __pyx_k_rowNorm, sizeof(__pyx_k_rowNorm), 0, 0, 1, 1},
    {&__pyx_n_s_rowSwap, __pyx_k_rowSwap, sizeof(__pyx_k_rowSwap), 0, 0, 1, 1},
    {&__pyx_n_s_rowdim, __pyx_k_rowdim, sizeof(__pyx_k_rowdim), 0, 0, 1, 1},
    {&__pyx_n_s_rownorm, __pyx_k_rownorm, sizeof(__pyx_k_rownorm), 0, 0, 1, 1},
    {&__pyx_n_s_rowspace, __pyx_k_rowspace, sizeof(__pyx_k_rowspace), 0, 0, 1, 1},
    {&__pyx_n_s_rowswap, __pyx_k_rowswap, sizeof(__pyx_k_rowswap), 0, 0, 1, 1},
    {&__pyx_n_s_rpm, __pyx_k_rpm, sizeof(__pyx_k_rpm), 0, 0, 1, 1},
    {&__pyx_n_s_rref, __pyx_k_rref, sizeof(__pyx_k_rref), 0, 0, 1, 1},
    {&__pyx_n_s_rsolve, __pyx_k_rsolve, sizeof(__pyx_k_rsolve), 0, 0, 1, 1},
    {&__pyx_n_s_rur, __pyx_k_rur, sizeof(__pyx_k_rur), 0, 0, 1, 1},
    {&__pyx_n_s_rur_certify, __pyx_k_rur_certify, sizeof(__pyx_k_rur_certify), 0, 0, 1, 1},
    {&__pyx_n_s_rur_gbasis, __pyx_k_rur_gbasis, sizeof(__pyx_k_rur_gbasis), 0, 0, 1, 1},
    {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
    {&__pyx_n_s_s_2, __pyx_k_s_2, sizeof(__pyx_k_s_2), 0, 0, 1, 1},
    {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
    {&__pyx_n_s_saisir, __pyx_k_saisir, sizeof(__pyx_k_saisir), 0, 0, 1, 1},
    {&__pyx_n_s_saisir_chaine, __pyx_k_saisir_chaine, sizeof(__pyx_k_saisir_chaine), 0, 0, 1, 1},
    {&__pyx_n_s_same, __pyx_k_same, sizeof(__pyx_k_same), 0, 0, 1, 1},
    {&__pyx_n_s_sample, __pyx_k_sample, sizeof(__pyx_k_sample), 0, 0, 1, 1},
    {&__pyx_n_s_samplerate, __pyx_k_samplerate, sizeof(__pyx_k_samplerate), 0, 0, 1, 1},
    {&__pyx_n_s_sans_factoriser, __pyx_k_sans_factoriser, sizeof(__pyx_k_sans_factoriser), 0, 0, 1, 1},
    {&__pyx_n_s_saute, __pyx_k_saute, sizeof(__pyx_k_saute), 0, 0, 1, 1},
    {&__pyx_n_s_sauve, __pyx_k_sauve, sizeof(__pyx_k_sauve), 0, 0, 1, 1},
    {&__pyx_n_s_save, __pyx_k_save, sizeof(__pyx_k_save), 0, 0, 1, 1},
    {&__pyx_n_s_save_history, __pyx_k_save_history, sizeof(__pyx_k_save_history), 0, 0, 1, 1},
    {&__pyx_n_s_sb, __pyx_k_sb, sizeof(__pyx_k_sb), 0, 0, 1, 1},
    {&__pyx_n_s_scalarProduct, __pyx_k_scalarProduct, sizeof(__pyx_k_scalarProduct), 0, 0, 1, 1},
    {&__pyx_n_s_scalar_product, __pyx_k_scalar_product, sizeof(__pyx_k_scalar_product), 0, 0, 1, 1},
    {&__pyx_n_s_scale, __pyx_k_scale, sizeof(__pyx_k_scale), 0, 0, 1, 1},
    {&__pyx_n_s_scaleadd, __pyx_k_scaleadd, sizeof(__pyx_k_scaleadd), 0, 0, 1, 1},
    {&__pyx_n_s_scatterplot, __pyx_k_scatterplot, sizeof(__pyx_k_scatterplot), 0, 0, 1, 1},
    {&__pyx_n_s_schur, __pyx_k_schur, sizeof(__pyx_k_schur), 0, 0, 1, 1},
    {&__pyx_n_s_sd, __pyx_k_sd, sizeof(__pyx_k_sd), 0, 0, 1, 1},
    {&__pyx_n_s_sec, __pyx_k_sec, sizeof(__pyx_k_sec), 0, 0, 1, 1},
    {&__pyx_n_s_secant_solver, __pyx_k_secant_solver, sizeof(__pyx_k_secant_solver), 0, 0, 1, 1},
    {&__pyx_n_s_segment, __pyx_k_segment, sizeof(__pyx_k_segment), 0, 0, 1, 1},
    {&__pyx_n_s_seidel_spectrum, __pyx_k_seidel_spectrum, sizeof(__pyx_k_seidel_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_seidel_switch, __pyx_k_seidel_switch, sizeof(__pyx_k_seidel_switch), 0, 0, 1, 1},
    {&__pyx_n_s_select, __pyx_k_select, sizeof(__pyx_k_select), 0, 0, 1, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_kp_s_self_is_not_a_giac_List, __pyx_k_self_is_not_a_giac_List, sizeof(__pyx_k_self_is_not_a_giac_List), 0, 0, 1, 0},
    {&__pyx_kp_s_self_is_not_a_giac_integer, __pyx_k_self_is_not_a_giac_integer, sizeof(__pyx_k_self_is_not_a_giac_integer), 0, 0, 1, 0},
    {&__pyx_kp_s_self_is_not_a_giac_real, __pyx_k_self_is_not_a_giac_real, sizeof(__pyx_k_self_is_not_a_giac_real), 0, 0, 1, 0},
    {&__pyx_n_s_semi_augment, __pyx_k_semi_augment, sizeof(__pyx_k_semi_augment), 0, 0, 1, 1},
    {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
    {&__pyx_n_s_seq, __pyx_k_seq, sizeof(__pyx_k_seq), 0, 0, 1, 1},
    {&__pyx_n_s_seqplot, __pyx_k_seqplot, sizeof(__pyx_k_seqplot), 0, 0, 1, 1},
    {&__pyx_n_s_seqsolve, __pyx_k_seqsolve, sizeof(__pyx_k_seqsolve), 0, 0, 1, 1},
    {&__pyx_n_s_sequence_graph, __pyx_k_sequence_graph, sizeof(__pyx_k_sequence_graph), 0, 0, 1, 1},
    {&__pyx_n_s_series, __pyx_k_series, sizeof(__pyx_k_series), 0, 0, 1, 1},
    {&__pyx_kp_s_set, __pyx_k_set, sizeof(__pyx_k_set), 0, 0, 1, 0},
    {&__pyx_n_s_set_channel_data, __pyx_k_set_channel_data, sizeof(__pyx_k_set_channel_data), 0, 0, 1, 1},
    {&__pyx_n_s_set_edge_attribute, __pyx_k_set_edge_attribute, sizeof(__pyx_k_set_edge_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_set_edge_weight, __pyx_k_set_edge_weight, sizeof(__pyx_k_set_edge_weight), 0, 0, 1, 1},
    {&__pyx_n_s_set_graph_attribute, __pyx_k_set_graph_attribute, sizeof(__pyx_k_set_graph_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_set_pixel, __pyx_k_set_pixel, sizeof(__pyx_k_set_pixel), 0, 0, 1, 1},
    {&__pyx_n_s_set_screen, __pyx_k_set_screen, sizeof(__pyx_k_set_screen), 0, 0, 1, 1},
    {&__pyx_n_s_set_vertex_attribute, __pyx_k_set_vertex_attribute, sizeof(__pyx_k_set_vertex_attribute), 0, 0, 1, 1},
    {&__pyx_n_s_set_vertex_positions, __pyx_k_set_vertex_positions, sizeof(__pyx_k_set_vertex_positions), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_shift, __pyx_k_shift, sizeof(__pyx_k_shift), 0, 0, 1, 1},
    {&__pyx_n_s_shift_phase, __pyx_k_shift_phase, sizeof(__pyx_k_shift_phase), 0, 0, 1, 1},
    {&__pyx_n_s_shortest_path, __pyx_k_shortest_path, sizeof(__pyx_k_shortest_path), 0, 0, 1, 1},
    {&__pyx_n_s_show_pixels, __pyx_k_show_pixels, sizeof(__pyx_k_show_pixels), 0, 0, 1, 1},
    {&__pyx_n_s_shuffle, __pyx_k_shuffle, sizeof(__pyx_k_shuffle), 0, 0, 1, 1},
    {&__pyx_n_s_si, __pyx_k_si, sizeof(__pyx_k_si), 0, 0, 1, 1},
    {&__pyx_n_s_sierpinski_graph, __pyx_k_sierpinski_graph, sizeof(__pyx_k_sierpinski_graph), 0, 0, 1, 1},
    {&__pyx_n_s_sigma, __pyx_k_sigma, sizeof(__pyx_k_sigma), 0, 0, 1, 1},
    {&__pyx_n_s_sign, __pyx_k_sign, sizeof(__pyx_k_sign), 0, 0, 1, 1},
    {&__pyx_n_s_sign2Heaviside, __pyx_k_sign2Heaviside, sizeof(__pyx_k_sign2Heaviside), 0, 0, 1, 1},
    {&__pyx_n_s_signature, __pyx_k_signature, sizeof(__pyx_k_signature), 0, 0, 1, 1},
    {&__pyx_n_s_signe, __pyx_k_signe, sizeof(__pyx_k_signe), 0, 0, 1, 1},
    {&__pyx_n_s_similarity, __pyx_k_similarity, sizeof(__pyx_k_similarity), 0, 0, 1, 1},
    {&__pyx_n_s_simp2, __pyx_k_simp2, sizeof(__pyx_k_simp2), 0, 0, 1, 1},
    {&__pyx_n_s_simplex_reduce, __pyx_k_simplex_reduce, sizeof(__pyx_k_simplex_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_simplicial_vertices, __pyx_k_simplicial_vertices, sizeof(__pyx_k_simplicial_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_simplifier, __pyx_k_simplifier, sizeof(__pyx_k_simplifier), 0, 0, 1, 1},
    {&__pyx_n_s_simplify, __pyx_k_simplify, sizeof(__pyx_k_simplify), 0, 0, 1, 1},
    {&__pyx_n_s_simplifyDirac, __pyx_k_simplifyDirac, sizeof(__pyx_k_simplifyDirac), 0, 0, 1, 1},
    {&__pyx_n_s_simpson, __pyx_k_simpson, sizeof(__pyx_k_simpson), 0, 0, 1, 1},
    {&__pyx_n_s_simulated_annealing, __pyx_k_simulated_annealing, sizeof(__pyx_k_simulated_annealing), 0, 0, 1, 1},
    {&__pyx_n_s_simult, __pyx_k_simult, sizeof(__pyx_k_simult), 0, 0, 1, 1},
    {&__pyx_n_s_sin, __pyx_k_sin, sizeof(__pyx_k_sin), 0, 0, 1, 1},
    {&__pyx_n_s_sin2costan, __pyx_k_sin2costan, sizeof(__pyx_k_sin2costan), 0, 0, 1, 1},
    {&__pyx_n_s_sinc, __pyx_k_sinc, sizeof(__pyx_k_sinc), 0, 0, 1, 1},
    {&__pyx_n_s_sincos, __pyx_k_sincos, sizeof(__pyx_k_sincos), 0, 0, 1, 1},
    {&__pyx_n_s_single_inter, __pyx_k_single_inter, sizeof(__pyx_k_single_inter), 0, 0, 1, 1},
    {&__pyx_n_s_sinh, __pyx_k_sinh, sizeof(__pyx_k_sinh), 0, 0, 1, 1},
    {&__pyx_n_s_sinon, __pyx_k_sinon, sizeof(__pyx_k_sinon), 0, 0, 1, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_sizes, __pyx_k_sizes, sizeof(__pyx_k_sizes), 0, 0, 1, 1},
    {&__pyx_n_s_sleep, __pyx_k_sleep, sizeof(__pyx_k_sleep), 0, 0, 1, 1},
    {&__pyx_n_s_slope, __pyx_k_slope, sizeof(__pyx_k_slope), 0, 0, 1, 1},
    {&__pyx_n_s_slopeat, __pyx_k_slopeat, sizeof(__pyx_k_slopeat), 0, 0, 1, 1},
    {&__pyx_n_s_slopeatraw, __pyx_k_slopeatraw, sizeof(__pyx_k_slopeatraw), 0, 0, 1, 1},
    {&__pyx_n_s_slug, __pyx_k_slug, sizeof(__pyx_k_slug), 0, 0, 1, 1},
    {&__pyx_n_s_smith, __pyx_k_smith, sizeof(__pyx_k_smith), 0, 0, 1, 1},
    {&__pyx_n_s_smod, __pyx_k_smod, sizeof(__pyx_k_smod), 0, 0, 1, 1},
    {&__pyx_n_s_snedecor, __pyx_k_snedecor, sizeof(__pyx_k_snedecor), 0, 0, 1, 1},
    {&__pyx_n_s_snedecor_cdf, __pyx_k_snedecor_cdf, sizeof(__pyx_k_snedecor_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_snedecor_icdf, __pyx_k_snedecor_icdf, sizeof(__pyx_k_snedecor_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_snedecord, __pyx_k_snedecord, sizeof(__pyx_k_snedecord), 0, 0, 1, 1},
    {&__pyx_n_s_snedecord_cdf, __pyx_k_snedecord_cdf, sizeof(__pyx_k_snedecord_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_snedecord_icdf, __pyx_k_snedecord_icdf, sizeof(__pyx_k_snedecord_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_solid_line, __pyx_k_solid_line, sizeof(__pyx_k_solid_line), 0, 0, 1, 1},
    {&__pyx_n_s_solve, __pyx_k_solve, sizeof(__pyx_k_solve), 0, 0, 1, 1},
    {&__pyx_n_s_somme, __pyx_k_somme, sizeof(__pyx_k_somme), 0, 0, 1, 1},
    {&__pyx_n_s_sommet, __pyx_k_sommet, sizeof(__pyx_k_sommet), 0, 0, 1, 1},
    {&__pyx_n_s_sort, __pyx_k_sort, sizeof(__pyx_k_sort), 0, 0, 1, 1},
    {&__pyx_n_s_sorta, __pyx_k_sorta, sizeof(__pyx_k_sorta), 0, 0, 1, 1},
    {&__pyx_n_s_sortd, __pyx_k_sortd, sizeof(__pyx_k_sortd), 0, 0, 1, 1},
    {&__pyx_n_s_sorted, __pyx_k_sorted, sizeof(__pyx_k_sorted), 0, 0, 1, 1},
    {&__pyx_n_s_sortperm, __pyx_k_sortperm, sizeof(__pyx_k_sortperm), 0, 0, 1, 1},
    {&__pyx_n_s_soundsec, __pyx_k_soundsec, sizeof(__pyx_k_soundsec), 0, 0, 1, 1},
    {&__pyx_n_s_spanning_tree, __pyx_k_spanning_tree, sizeof(__pyx_k_spanning_tree), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_sphere, __pyx_k_sphere, sizeof(__pyx_k_sphere), 0, 0, 1, 1},
    {&__pyx_n_s_splice, __pyx_k_splice, sizeof(__pyx_k_splice), 0, 0, 1, 1},
    {&__pyx_n_s_spline, __pyx_k_spline, sizeof(__pyx_k_spline), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_spring, __pyx_k_spring, sizeof(__pyx_k_spring), 0, 0, 1, 1},
    {&__pyx_n_s_sq, __pyx_k_sq, sizeof(__pyx_k_sq), 0, 0, 1, 1},
    {&__pyx_n_s_sqrfree, __pyx_k_sqrfree, sizeof(__pyx_k_sqrfree), 0, 0, 1, 1},
    {&__pyx_n_s_sqrt, __pyx_k_sqrt, sizeof(__pyx_k_sqrt), 0, 0, 1, 1},
    {&__pyx_n_s_square, __pyx_k_square, sizeof(__pyx_k_square), 0, 0, 1, 1},
    {&__pyx_n_s_square_point, __pyx_k_square_point, sizeof(__pyx_k_square_point), 0, 0, 1, 1},
    {&__pyx_n_s_sr, __pyx_k_sr, sizeof(__pyx_k_sr), 0, 0, 1, 1},
    {&__pyx_n_s_srand, __pyx_k_srand, sizeof(__pyx_k_srand), 0, 0, 1, 1},
    {&__pyx_n_s_sst, __pyx_k_sst, sizeof(__pyx_k_sst), 0, 0, 1, 1},
    {&__pyx_n_s_sst_in, __pyx_k_sst_in, sizeof(__pyx_k_sst_in), 0, 0, 1, 1},
    {&__pyx_n_s_st, __pyx_k_st, sizeof(__pyx_k_st), 0, 0, 1, 1},
    {&__pyx_n_s_st_ordering, __pyx_k_st_ordering, sizeof(__pyx_k_st_ordering), 0, 0, 1, 1},
    {&__pyx_n_s_stack, __pyx_k_stack, sizeof(__pyx_k_stack), 0, 0, 1, 1},
    {&__pyx_n_s_star_graph, __pyx_k_star_graph, sizeof(__pyx_k_star_graph), 0, 0, 1, 1},
    {&__pyx_n_s_star_point, __pyx_k_star_point, sizeof(__pyx_k_star_point), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_stdDev, __pyx_k_stdDev, sizeof(__pyx_k_stdDev), 0, 0, 1, 1},
    {&__pyx_n_s_stddev, __pyx_k_stddev, sizeof(__pyx_k_stddev), 0, 0, 1, 1},
    {&__pyx_n_s_stddevp, __pyx_k_stddevp, sizeof(__pyx_k_stddevp), 0, 0, 1, 1},
    {&__pyx_n_s_steffenson_solver, __pyx_k_steffenson_solver, sizeof(__pyx_k_steffenson_solver), 0, 0, 1, 1},
    {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
    {&__pyx_n_s_stereo2mono, __pyx_k_stereo2mono, sizeof(__pyx_k_stereo2mono), 0, 0, 1, 1},
    {&__pyx_n_s_stft, __pyx_k_stft, sizeof(__pyx_k_stft), 0, 0, 1, 1},
    {&__pyx_n_s_sto, __pyx_k_sto, sizeof(__pyx_k_sto), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_n_s_str_2, __pyx_k_str_2, sizeof(__pyx_k_str_2), 0, 0, 1, 1},
    {&__pyx_n_s_string, __pyx_k_string, sizeof(__pyx_k_string), 0, 0, 1, 1},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
    {&__pyx_n_s_strongly_connected_components, __pyx_k_strongly_connected_components, sizeof(__pyx_k_strongly_connected_components), 0, 0, 1, 1},
    {&__pyx_n_s_student, __pyx_k_student, sizeof(__pyx_k_student), 0, 0, 1, 1},
    {&__pyx_n_s_student_cdf, __pyx_k_student_cdf, sizeof(__pyx_k_student_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_student_icdf, __pyx_k_student_icdf, sizeof(__pyx_k_student_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_studentd, __pyx_k_studentd, sizeof(__pyx_k_studentd), 0, 0, 1, 1},
    {&__pyx_n_s_studentt, __pyx_k_studentt, sizeof(__pyx_k_studentt), 0, 0, 1, 1},
    {&__pyx_n_s_sturm, __pyx_k_sturm, sizeof(__pyx_k_sturm), 0, 0, 1, 1},
    {&__pyx_n_s_sturmab, __pyx_k_sturmab, sizeof(__pyx_k_sturmab), 0, 0, 1, 1},
    {&__pyx_n_s_sturmseq, __pyx_k_sturmseq, sizeof(__pyx_k_sturmseq), 0, 0, 1, 1},
    {&__pyx_n_s_style, __pyx_k_style, sizeof(__pyx_k_style), 0, 0, 1, 1},
    {&__pyx_n_s_sub, __pyx_k_sub, sizeof(__pyx_k_sub), 0, 0, 1, 1},
    {&__pyx_n_s_subMat, __pyx_k_subMat, sizeof(__pyx_k_subMat), 0, 0, 1, 1},
    {&__pyx_n_s_subdivide_edges, __pyx_k_subdivide_edges, sizeof(__pyx_k_subdivide_edges), 0, 0, 1, 1},
    {&__pyx_n_s_subgraph, __pyx_k_subgraph, sizeof(__pyx_k_subgraph), 0, 0, 1, 1},
    {&__pyx_n_s_subs, __pyx_k_subs, sizeof(__pyx_k_subs), 0, 0, 1, 1},
    {&__pyx_n_s_subsop, __pyx_k_subsop, sizeof(__pyx_k_subsop), 0, 0, 1, 1},
    {&__pyx_n_s_subst, __pyx_k_subst, sizeof(__pyx_k_subst), 0, 0, 1, 1},
    {&__pyx_n_s_substituer, __pyx_k_substituer, sizeof(__pyx_k_substituer), 0, 0, 1, 1},
    {&__pyx_n_s_subtype, __pyx_k_subtype, sizeof(__pyx_k_subtype), 0, 0, 1, 1},
    {&__pyx_n_s_subtype_2, __pyx_k_subtype_2, sizeof(__pyx_k_subtype_2), 0, 0, 1, 1},
    {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
    {&__pyx_n_s_sum_riemann, __pyx_k_sum_riemann, sizeof(__pyx_k_sum_riemann), 0, 0, 1, 1},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_supposons, __pyx_k_supposons, sizeof(__pyx_k_supposons), 0, 0, 1, 1},
    {&__pyx_n_s_suppress, __pyx_k_suppress, sizeof(__pyx_k_suppress), 0, 0, 1, 1},
    {&__pyx_n_s_surd, __pyx_k_surd, sizeof(__pyx_k_surd), 0, 0, 1, 1},
    {&__pyx_n_s_svd, __pyx_k_svd, sizeof(__pyx_k_svd), 0, 0, 1, 1},
    {&__pyx_n_s_swapcol, __pyx_k_swapcol, sizeof(__pyx_k_swapcol), 0, 0, 1, 1},
    {&__pyx_n_s_swaprow, __pyx_k_swaprow, sizeof(__pyx_k_swaprow), 0, 0, 1, 1},
    {&__pyx_n_s_switch, __pyx_k_switch, sizeof(__pyx_k_switch), 0, 0, 1, 1},
    {&__pyx_n_s_switch_axes, __pyx_k_switch_axes, sizeof(__pyx_k_switch_axes), 0, 0, 1, 1},
    {&__pyx_n_s_sylvester, __pyx_k_sylvester, sizeof(__pyx_k_sylvester), 0, 0, 1, 1},
    {&__pyx_n_s_symb2poly, __pyx_k_symb2poly, sizeof(__pyx_k_symb2poly), 0, 0, 1, 1},
    {&__pyx_n_s_symbol, __pyx_k_symbol, sizeof(__pyx_k_symbol), 0, 0, 1, 1},
    {&__pyx_n_s_symbol_array, __pyx_k_symbol_array, sizeof(__pyx_k_symbol_array), 0, 0, 1, 1},
    {&__pyx_n_s_syr, __pyx_k_syr, sizeof(__pyx_k_syr), 0, 0, 1, 1},
    {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
    {&__pyx_n_s_syst2mat, __pyx_k_syst2mat, sizeof(__pyx_k_syst2mat), 0, 0, 1, 1},
    {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
    {&__pyx_n_s_tCollect, __pyx_k_tCollect, sizeof(__pyx_k_tCollect), 0, 0, 1, 1},
    {&__pyx_n_s_tExpand, __pyx_k_tExpand, sizeof(__pyx_k_tExpand), 0, 0, 1, 1},
    {&__pyx_n_s_table, __pyx_k_table, sizeof(__pyx_k_table), 0, 0, 1, 1},
    {&__pyx_n_s_tablefunc, __pyx_k_tablefunc, sizeof(__pyx_k_tablefunc), 0, 0, 1, 1},
    {&__pyx_n_s_tableseq, __pyx_k_tableseq, sizeof(__pyx_k_tableseq), 0, 0, 1, 1},
    {&__pyx_n_s_tabsign, __pyx_k_tabsign, sizeof(__pyx_k_tabsign), 0, 0, 1, 1},
    {&__pyx_n_s_tabvar, __pyx_k_tabvar, sizeof(__pyx_k_tabvar), 0, 0, 1, 1},
    {&__pyx_n_s_tail, __pyx_k_tail, sizeof(__pyx_k_tail), 0, 0, 1, 1},
    {&__pyx_n_s_tan, __pyx_k_tan, sizeof(__pyx_k_tan), 0, 0, 1, 1},
    {&__pyx_n_s_tan2cossin2, __pyx_k_tan2cossin2, sizeof(__pyx_k_tan2cossin2), 0, 0, 1, 1},
    {&__pyx_n_s_tan2sincos, __pyx_k_tan2sincos, sizeof(__pyx_k_tan2sincos), 0, 0, 1, 1},
    {&__pyx_n_s_tan2sincos2, __pyx_k_tan2sincos2, sizeof(__pyx_k_tan2sincos2), 0, 0, 1, 1},
    {&__pyx_n_s_tangent, __pyx_k_tangent, sizeof(__pyx_k_tangent), 0, 0, 1, 1},
    {&__pyx_n_s_tangente, __pyx_k_tangente, sizeof(__pyx_k_tangente), 0, 0, 1, 1},
    {&__pyx_n_s_tanh, __pyx_k_tanh, sizeof(__pyx_k_tanh), 0, 0, 1, 1},
    {&__pyx_n_s_tantque, __pyx_k_tantque, sizeof(__pyx_k_tantque), 0, 0, 1, 1},
    {&__pyx_n_s_tar, __pyx_k_tar, sizeof(__pyx_k_tar), 0, 0, 1, 1},
    {&__pyx_n_s_taux_accroissement, __pyx_k_taux_accroissement, sizeof(__pyx_k_taux_accroissement), 0, 0, 1, 1},
    {&__pyx_n_s_taylor, __pyx_k_taylor, sizeof(__pyx_k_taylor), 0, 0, 1, 1},
    {&__pyx_n_s_tbsp, __pyx_k_tbsp, sizeof(__pyx_k_tbsp), 0, 0, 1, 1},
    {&__pyx_n_s_tchebyshev1, __pyx_k_tchebyshev1, sizeof(__pyx_k_tchebyshev1), 0, 0, 1, 1},
    {&__pyx_n_s_tchebyshev2, __pyx_k_tchebyshev2, sizeof(__pyx_k_tchebyshev2), 0, 0, 1, 1},
    {&__pyx_n_s_tcoeff, __pyx_k_tcoeff, sizeof(__pyx_k_tcoeff), 0, 0, 1, 1},
    {&__pyx_n_s_tcollect, __pyx_k_tcollect, sizeof(__pyx_k_tcollect), 0, 0, 1, 1},
    {&__pyx_n_s_tdeg, __pyx_k_tdeg, sizeof(__pyx_k_tdeg), 0, 0, 1, 1},
    {&__pyx_n_s_teal, __pyx_k_teal, sizeof(__pyx_k_teal), 0, 0, 1, 1},
    {&__pyx_n_s_tec, __pyx_k_tec, sizeof(__pyx_k_tec), 0, 0, 1, 1},
    {&__pyx_n_s_tensor_product, __pyx_k_tensor_product, sizeof(__pyx_k_tensor_product), 0, 0, 1, 1},
    {&__pyx_n_s_tep, __pyx_k_tep, sizeof(__pyx_k_tep), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_test_2, __pyx_k_test_2, sizeof(__pyx_k_test_2), 0, 0, 1, 1},
    {&__pyx_n_s_tetrahedron, __pyx_k_tetrahedron, sizeof(__pyx_k_tetrahedron), 0, 0, 1, 1},
    {&__pyx_n_s_tex, __pyx_k_tex, sizeof(__pyx_k_tex), 0, 0, 1, 1},
    {&__pyx_n_s_texpand, __pyx_k_texpand, sizeof(__pyx_k_texpand), 0, 0, 1, 1},
    {&__pyx_n_s_textinput, __pyx_k_textinput, sizeof(__pyx_k_textinput), 0, 0, 1, 1},
    {&__pyx_n_s_then, __pyx_k_then, sizeof(__pyx_k_then), 0, 0, 1, 1},
    {&__pyx_n_s_therm, __pyx_k_therm, sizeof(__pyx_k_therm), 0, 0, 1, 1},
    {&__pyx_n_s_thickness, __pyx_k_thickness, sizeof(__pyx_k_thickness), 0, 0, 1, 1},
    {&__pyx_n_s_thiele, __pyx_k_thiele, sizeof(__pyx_k_thiele), 0, 0, 1, 1},
    {&__pyx_n_s_threadeval, __pyx_k_threadeval, sizeof(__pyx_k_threadeval), 0, 0, 1, 1},
    {&__pyx_kp_s_threads_s, __pyx_k_threads_s, sizeof(__pyx_k_threads_s), 0, 0, 1, 0},
    {&__pyx_n_s_threshold, __pyx_k_threshold, sizeof(__pyx_k_threshold), 0, 0, 1, 1},
    {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
    {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
    {&__pyx_n_s_title, __pyx_k_title, sizeof(__pyx_k_title), 0, 0, 1, 1},
    {&__pyx_n_s_titre, __pyx_k_titre, sizeof(__pyx_k_titre), 0, 0, 1, 1},
    {&__pyx_n_s_tlin, __pyx_k_tlin, sizeof(__pyx_k_tlin), 0, 0, 1, 1},
    {&__pyx_n_s_tmp, __pyx_k_tmp, sizeof(__pyx_k_tmp), 0, 0, 1, 1},
    {&__pyx_n_s_to, __pyx_k_to, sizeof(__pyx_k_to), 0, 0, 1, 1},
    {&__pyx_n_s_ton, __pyx_k_ton, sizeof(__pyx_k_ton), 0, 0, 1, 1},
    {&__pyx_n_s_tonUK, __pyx_k_tonUK, sizeof(__pyx_k_tonUK), 0, 0, 1, 1},
    {&__pyx_n_s_tonnetz, __pyx_k_tonnetz, sizeof(__pyx_k_tonnetz), 0, 0, 1, 1},
    {&__pyx_n_s_topologic_sort, __pyx_k_topologic_sort, sizeof(__pyx_k_topologic_sort), 0, 0, 1, 1},
    {&__pyx_n_s_topological_sort, __pyx_k_topological_sort, sizeof(__pyx_k_topological_sort), 0, 0, 1, 1},
    {&__pyx_n_s_topology, __pyx_k_topology, sizeof(__pyx_k_topology), 0, 0, 1, 1},
    {&__pyx_n_s_toqcas, __pyx_k_toqcas, sizeof(__pyx_k_toqcas), 0, 0, 1, 1},
    {&__pyx_n_s_toremove, __pyx_k_toremove, sizeof(__pyx_k_toremove), 0, 0, 1, 1},
    {&__pyx_n_s_torr, __pyx_k_torr, sizeof(__pyx_k_torr), 0, 0, 1, 1},
    {&__pyx_n_s_torus_grid_graph, __pyx_k_torus_grid_graph, sizeof(__pyx_k_torus_grid_graph), 0, 0, 1, 1},
    {&__pyx_n_s_total_degree, __pyx_k_total_degree, sizeof(__pyx_k_total_degree), 0, 0, 1, 1},
    {&__pyx_n_s_tourne_droite, __pyx_k_tourne_droite, sizeof(__pyx_k_tourne_droite), 0, 0, 1, 1},
    {&__pyx_n_s_tourne_gauche, __pyx_k_tourne_gauche, sizeof(__pyx_k_tourne_gauche), 0, 0, 1, 1},
    {&__pyx_n_s_tpsolve, __pyx_k_tpsolve, sizeof(__pyx_k_tpsolve), 0, 0, 1, 1},
    {&__pyx_n_s_tr, __pyx_k_tr, sizeof(__pyx_k_tr), 0, 0, 1, 1},
    {&__pyx_kp_s_tr_min, __pyx_k_tr_min, sizeof(__pyx_k_tr_min), 0, 0, 1, 0},
    {&__pyx_kp_s_tr_s, __pyx_k_tr_s, sizeof(__pyx_k_tr_s), 0, 0, 1, 0},
    {&__pyx_n_s_trace, __pyx_k_trace, sizeof(__pyx_k_trace), 0, 0, 1, 1},
    {&__pyx_n_s_trail, __pyx_k_trail, sizeof(__pyx_k_trail), 0, 0, 1, 1},
    {&__pyx_n_s_trail2edges, __pyx_k_trail2edges, sizeof(__pyx_k_trail2edges), 0, 0, 1, 1},
    {&__pyx_n_s_train, __pyx_k_train, sizeof(__pyx_k_train), 0, 0, 1, 1},
    {&__pyx_n_s_trames, __pyx_k_trames, sizeof(__pyx_k_trames), 0, 0, 1, 1},
    {&__pyx_n_s_tran, __pyx_k_tran, sizeof(__pyx_k_tran), 0, 0, 1, 1},
    {&__pyx_n_s_transitive_closure, __pyx_k_transitive_closure, sizeof(__pyx_k_transitive_closure), 0, 0, 1, 1},
    {&__pyx_n_s_translation, __pyx_k_translation, sizeof(__pyx_k_translation), 0, 0, 1, 1},
    {&__pyx_n_s_transpose, __pyx_k_transpose, sizeof(__pyx_k_transpose), 0, 0, 1, 1},
    {&__pyx_n_s_trapeze, __pyx_k_trapeze, sizeof(__pyx_k_trapeze), 0, 0, 1, 1},
    {&__pyx_n_s_trapezoid, __pyx_k_trapezoid, sizeof(__pyx_k_trapezoid), 0, 0, 1, 1},
    {&__pyx_n_s_traveling_salesman, __pyx_k_traveling_salesman, sizeof(__pyx_k_traveling_salesman), 0, 0, 1, 1},
    {&__pyx_n_s_tree, __pyx_k_tree, sizeof(__pyx_k_tree), 0, 0, 1, 1},
    {&__pyx_n_s_tree_height, __pyx_k_tree_height, sizeof(__pyx_k_tree_height), 0, 0, 1, 1},
    {&__pyx_n_s_tri, __pyx_k_tri, sizeof(__pyx_k_tri), 0, 0, 1, 1},
    {&__pyx_n_s_triangle, __pyx_k_triangle, sizeof(__pyx_k_triangle), 0, 0, 1, 1},
    {&__pyx_n_s_triangle_paper, __pyx_k_triangle_paper, sizeof(__pyx_k_triangle_paper), 0, 0, 1, 1},
    {&__pyx_n_s_triangle_plein, __pyx_k_triangle_plein, sizeof(__pyx_k_triangle_plein), 0, 0, 1, 1},
    {&__pyx_n_s_triangle_point, __pyx_k_triangle_point, sizeof(__pyx_k_triangle_point), 0, 0, 1, 1},
    {&__pyx_n_s_triangle_window, __pyx_k_triangle_window, sizeof(__pyx_k_triangle_window), 0, 0, 1, 1},
    {&__pyx_n_s_trig2exp, __pyx_k_trig2exp, sizeof(__pyx_k_trig2exp), 0, 0, 1, 1},
    {&__pyx_n_s_trigcos, __pyx_k_trigcos, sizeof(__pyx_k_trigcos), 0, 0, 1, 1},
    {&__pyx_n_s_trigexpand, __pyx_k_trigexpand, sizeof(__pyx_k_trigexpand), 0, 0, 1, 1},
    {&__pyx_n_s_triginterp, __pyx_k_triginterp, sizeof(__pyx_k_triginterp), 0, 0, 1, 1},
    {&__pyx_n_s_trigsimplify, __pyx_k_trigsimplify, sizeof(__pyx_k_trigsimplify), 0, 0, 1, 1},
    {&__pyx_n_s_trigsin, __pyx_k_trigsin, sizeof(__pyx_k_trigsin), 0, 0, 1, 1},
    {&__pyx_n_s_trigtan, __pyx_k_trigtan, sizeof(__pyx_k_trigtan), 0, 0, 1, 1},
    {&__pyx_n_s_trim, __pyx_k_trim, sizeof(__pyx_k_trim), 0, 0, 1, 1},
    {&__pyx_n_s_trn, __pyx_k_trn, sizeof(__pyx_k_trn), 0, 0, 1, 1},
    {&__pyx_n_s_true, __pyx_k_true, sizeof(__pyx_k_true), 0, 0, 1, 1},
    {&__pyx_n_s_truediv, __pyx_k_truediv, sizeof(__pyx_k_truediv), 0, 0, 1, 1},
    {&__pyx_n_s_trunc, __pyx_k_trunc, sizeof(__pyx_k_trunc), 0, 0, 1, 1},
    {&__pyx_n_s_truncate, __pyx_k_truncate, sizeof(__pyx_k_truncate), 0, 0, 1, 1},
    {&__pyx_n_s_truncate_graph, __pyx_k_truncate_graph, sizeof(__pyx_k_truncate_graph), 0, 0, 1, 1},
    {&__pyx_n_s_try, __pyx_k_try, sizeof(__pyx_k_try), 0, 0, 1, 1},
    {&__pyx_kp_s_trying_soft_interruption_wait_2s, __pyx_k_trying_soft_interruption_wait_2s, sizeof(__pyx_k_trying_soft_interruption_wait_2s), 0, 0, 1, 0},
    {&__pyx_n_s_tsimplify, __pyx_k_tsimplify, sizeof(__pyx_k_tsimplify), 0, 0, 1, 1},
    {&__pyx_n_s_tsp, __pyx_k_tsp, sizeof(__pyx_k_tsp), 0, 0, 1, 1},
    {&__pyx_n_s_tstep, __pyx_k_tstep, sizeof(__pyx_k_tstep), 0, 0, 1, 1},
    {&__pyx_n_s_tuer, __pyx_k_tuer, sizeof(__pyx_k_tuer), 0, 0, 1, 1},
    {&__pyx_n_s_tukey_window, __pyx_k_tukey_window, sizeof(__pyx_k_tukey_window), 0, 0, 1, 1},
    {&__pyx_n_s_tutte_polynomial, __pyx_k_tutte_polynomial, sizeof(__pyx_k_tutte_polynomial), 0, 0, 1, 1},
    {&__pyx_n_s_two_edge_connected_components, __pyx_k_two_edge_connected_components, sizeof(__pyx_k_two_edge_connected_components), 0, 0, 1, 1},
    {&__pyx_n_s_twopi, __pyx_k_twopi, sizeof(__pyx_k_twopi), 0, 0, 1, 1},
    {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
    {&__pyx_n_s_type_2, __pyx_k_type_2, sizeof(__pyx_k_type_2), 0, 0, 1, 1},
    {&__pyx_n_s_u, __pyx_k_u, sizeof(__pyx_k_u), 0, 0, 1, 1},
    {&__pyx_n_s_ufactor, __pyx_k_ufactor, sizeof(__pyx_k_ufactor), 0, 0, 1, 1},
    {&__pyx_n_s_ugamma, __pyx_k_ugamma, sizeof(__pyx_k_ugamma), 0, 0, 1, 1},
    {&__pyx_n_s_unapply, __pyx_k_unapply, sizeof(__pyx_k_unapply), 0, 0, 1, 1},
    {&__pyx_n_s_unarchive, __pyx_k_unarchive, sizeof(__pyx_k_unarchive), 0, 0, 1, 1},
    {&__pyx_n_s_undef, __pyx_k_undef, sizeof(__pyx_k_undef), 0, 0, 1, 1},
    {&__pyx_n_s_underlying_graph, __pyx_k_underlying_graph, sizeof(__pyx_k_underlying_graph), 0, 0, 1, 1},
    {&__pyx_n_s_unfactored, __pyx_k_unfactored, sizeof(__pyx_k_unfactored), 0, 0, 1, 1},
    {&__pyx_n_s_uniform, __pyx_k_uniform, sizeof(__pyx_k_uniform), 0, 0, 1, 1},
    {&__pyx_n_s_uniform_cdf, __pyx_k_uniform_cdf, sizeof(__pyx_k_uniform_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_uniform_icdf, __pyx_k_uniform_icdf, sizeof(__pyx_k_uniform_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_uniformd, __pyx_k_uniformd, sizeof(__pyx_k_uniformd), 0, 0, 1, 1},
    {&__pyx_n_s_uniformd_cdf, __pyx_k_uniformd_cdf, sizeof(__pyx_k_uniformd_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_uniformd_icdf, __pyx_k_uniformd_icdf, sizeof(__pyx_k_uniformd_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_union, __pyx_k_union, sizeof(__pyx_k_union), 0, 0, 1, 1},
    {&__pyx_n_s_unitV, __pyx_k_unitV, sizeof(__pyx_k_unitV), 0, 0, 1, 1},
    {&__pyx_n_s_unquote, __pyx_k_unquote, sizeof(__pyx_k_unquote), 0, 0, 1, 1},
    {&__pyx_n_s_until, __pyx_k_until, sizeof(__pyx_k_until), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
    {&__pyx_n_s_url, __pyx_k_url, sizeof(__pyx_k_url), 0, 0, 1, 1},
    {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_user_operator, __pyx_k_user_operator, sizeof(__pyx_k_user_operator), 0, 0, 1, 1},
    {&__pyx_n_s_usimplify, __pyx_k_usimplify, sizeof(__pyx_k_usimplify), 0, 0, 1, 1},
    {&__pyx_kp_s_using_sendtext, __pyx_k_using_sendtext, sizeof(__pyx_k_using_sendtext), 0, 0, 1, 0},
    {&__pyx_n_s_ustep, __pyx_k_ustep, sizeof(__pyx_k_ustep), 0, 0, 1, 1},
    {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
    {&__pyx_n_s_valuation, __pyx_k_valuation, sizeof(__pyx_k_valuation), 0, 0, 1, 1},
    {&__pyx_n_s_vandermonde, __pyx_k_vandermonde, sizeof(__pyx_k_vandermonde), 0, 0, 1, 1},
    {&__pyx_n_s_var, __pyx_k_var, sizeof(__pyx_k_var), 0, 0, 1, 1},
    {&__pyx_n_s_variables_are_files, __pyx_k_variables_are_files, sizeof(__pyx_k_variables_are_files), 0, 0, 1, 1},
    {&__pyx_n_s_variance, __pyx_k_variance, sizeof(__pyx_k_variance), 0, 0, 1, 1},
    {&__pyx_n_s_vector, __pyx_k_vector, sizeof(__pyx_k_vector), 0, 0, 1, 1},
    {&__pyx_n_s_vers, __pyx_k_vers, sizeof(__pyx_k_vers), 0, 0, 1, 1},
    {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
    {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
    {&__pyx_n_s_vert, __pyx_k_vert, sizeof(__pyx_k_vert), 0, 0, 1, 1},
    {&__pyx_n_s_vertex_connectivity, __pyx_k_vertex_connectivity, sizeof(__pyx_k_vertex_connectivity), 0, 0, 1, 1},
    {&__pyx_n_s_vertex_cover_number, __pyx_k_vertex_cover_number, sizeof(__pyx_k_vertex_cover_number), 0, 0, 1, 1},
    {&__pyx_n_s_vertex_degree, __pyx_k_vertex_degree, sizeof(__pyx_k_vertex_degree), 0, 0, 1, 1},
    {&__pyx_n_s_vertex_distance, __pyx_k_vertex_distance, sizeof(__pyx_k_vertex_distance), 0, 0, 1, 1},
    {&__pyx_n_s_vertex_in_degree, __pyx_k_vertex_in_degree, sizeof(__pyx_k_vertex_in_degree), 0, 0, 1, 1},
    {&__pyx_n_s_vertex_out_degree, __pyx_k_vertex_out_degree, sizeof(__pyx_k_vertex_out_degree), 0, 0, 1, 1},
    {&__pyx_n_s_vertices, __pyx_k_vertices, sizeof(__pyx_k_vertices), 0, 0, 1, 1},
    {&__pyx_n_s_vertices_abc, __pyx_k_vertices_abc, sizeof(__pyx_k_vertices_abc), 0, 0, 1, 1},
    {&__pyx_n_s_vertices_abca, __pyx_k_vertices_abca, sizeof(__pyx_k_vertices_abca), 0, 0, 1, 1},
    {&__pyx_kp_u_vide_Pygen_giac_version_dpt_eit, __pyx_k_vide_Pygen_giac_version_dpt_eit, sizeof(__pyx_k_vide_Pygen_giac_version_dpt_eit), 0, 1, 0, 0},
    {&__pyx_n_s_violet, __pyx_k_violet, sizeof(__pyx_k_violet), 0, 0, 1, 1},
    {&__pyx_n_s_vpotential, __pyx_k_vpotential, sizeof(__pyx_k_vpotential), 0, 0, 1, 1},
    {&__pyx_n_s_vrai, __pyx_k_vrai, sizeof(__pyx_k_vrai), 0, 0, 1, 1},
    {&__pyx_n_s_vstep, __pyx_k_vstep, sizeof(__pyx_k_vstep), 0, 0, 1, 1},
    {&__pyx_kp_s_warning_Killing_thread, __pyx_k_warning_Killing_thread, sizeof(__pyx_k_warning_Killing_thread), 0, 0, 1, 0},
    {&__pyx_n_s_watch, __pyx_k_watch, sizeof(__pyx_k_watch), 0, 0, 1, 1},
    {&__pyx_n_s_web_graph, __pyx_k_web_graph, sizeof(__pyx_k_web_graph), 0, 0, 1, 1},
    {&__pyx_n_s_webbrowser, __pyx_k_webbrowser, sizeof(__pyx_k_webbrowser), 0, 0, 1, 1},
    {&__pyx_n_s_weibull, __pyx_k_weibull, sizeof(__pyx_k_weibull), 0, 0, 1, 1},
    {&__pyx_n_s_weibull_cdf, __pyx_k_weibull_cdf, sizeof(__pyx_k_weibull_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_weibull_icdf, __pyx_k_weibull_icdf, sizeof(__pyx_k_weibull_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_weibulld, __pyx_k_weibulld, sizeof(__pyx_k_weibulld), 0, 0, 1, 1},
    {&__pyx_n_s_weibulld_cdf, __pyx_k_weibulld_cdf, sizeof(__pyx_k_weibulld_cdf), 0, 0, 1, 1},
    {&__pyx_n_s_weibulld_icdf, __pyx_k_weibulld_icdf, sizeof(__pyx_k_weibulld_icdf), 0, 0, 1, 1},
    {&__pyx_n_s_weibullvariate, __pyx_k_weibullvariate, sizeof(__pyx_k_weibullvariate), 0, 0, 1, 1},
    {&__pyx_n_s_weight_decay, __pyx_k_weight_decay, sizeof(__pyx_k_weight_decay), 0, 0, 1, 1},
    {&__pyx_n_s_weight_matrix, __pyx_k_weight_matrix, sizeof(__pyx_k_weight_matrix), 0, 0, 1, 1},
    {&__pyx_n_s_weighted, __pyx_k_weighted, sizeof(__pyx_k_weighted), 0, 0, 1, 1},
    {&__pyx_n_s_weights, __pyx_k_weights, sizeof(__pyx_k_weights), 0, 0, 1, 1},
    {&__pyx_n_s_welch_window, __pyx_k_welch_window, sizeof(__pyx_k_welch_window), 0, 0, 1, 1},
    {&__pyx_n_s_wheel_graph, __pyx_k_wheel_graph, sizeof(__pyx_k_wheel_graph), 0, 0, 1, 1},
    {&__pyx_n_s_when, __pyx_k_when, sizeof(__pyx_k_when), 0, 0, 1, 1},
    {&__pyx_n_s_while, __pyx_k_while, sizeof(__pyx_k_while), 0, 0, 1, 1},
    {&__pyx_n_s_white, __pyx_k_white, sizeof(__pyx_k_white), 0, 0, 1, 1},
    {&__pyx_n_s_widget_size, __pyx_k_widget_size, sizeof(__pyx_k_widget_size), 0, 0, 1, 1},
    {&__pyx_n_s_wilcoxonp, __pyx_k_wilcoxonp, sizeof(__pyx_k_wilcoxonp), 0, 0, 1, 1},
    {&__pyx_n_s_wilcoxons, __pyx_k_wilcoxons, sizeof(__pyx_k_wilcoxons), 0, 0, 1, 1},
    {&__pyx_n_s_wilcoxont, __pyx_k_wilcoxont, sizeof(__pyx_k_wilcoxont), 0, 0, 1, 1},
    {&__pyx_n_s_with_sqrt, __pyx_k_with_sqrt, sizeof(__pyx_k_with_sqrt), 0, 0, 1, 1},
    {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
    {&__pyx_n_s_writergb, __pyx_k_writergb, sizeof(__pyx_k_writergb), 0, 0, 1, 1},
    {&__pyx_n_s_writewav, __pyx_k_writewav, sizeof(__pyx_k_writewav), 0, 0, 1, 1},
    {&__pyx_n_s_wwwbrowseropen, __pyx_k_wwwbrowseropen, sizeof(__pyx_k_wwwbrowseropen), 0, 0, 1, 1},
    {&__pyx_n_s_wz_certificate, __pyx_k_wz_certificate, sizeof(__pyx_k_wz_certificate), 0, 0, 1, 1},
    {&__pyx_n_s_xcas_mode, __pyx_k_xcas_mode, sizeof(__pyx_k_xcas_mode), 0, 0, 1, 1},
    {&__pyx_n_s_xml_print, __pyx_k_xml_print, sizeof(__pyx_k_xml_print), 0, 0, 1, 1},
    {&__pyx_n_s_xor, __pyx_k_xor, sizeof(__pyx_k_xor), 0, 0, 1, 1},
    {&__pyx_n_s_xstep, __pyx_k_xstep, sizeof(__pyx_k_xstep), 0, 0, 1, 1},
    {&__pyx_n_s_xyz2rgb, __pyx_k_xyz2rgb, sizeof(__pyx_k_xyz2rgb), 0, 0, 1, 1},
    {&__pyx_n_s_xyztrange, __pyx_k_xyztrange, sizeof(__pyx_k_xyztrange), 0, 0, 1, 1},
    {&__pyx_n_s_yd, __pyx_k_yd, sizeof(__pyx_k_yd), 0, 0, 1, 1},
    {&__pyx_kp_s_yd_2, __pyx_k_yd_2, sizeof(__pyx_k_yd_2), 0, 0, 1, 0},
    {&__pyx_kp_s_yd_3, __pyx_k_yd_3, sizeof(__pyx_k_yd_3), 0, 0, 1, 0},
    {&__pyx_n_s_yellow, __pyx_k_yellow, sizeof(__pyx_k_yellow), 0, 0, 1, 1},
    {&__pyx_n_s_yr, __pyx_k_yr, sizeof(__pyx_k_yr), 0, 0, 1, 1},
    {&__pyx_n_s_ystep, __pyx_k_ystep, sizeof(__pyx_k_ystep), 0, 0, 1, 1},
    {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
    {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
    {&__pyx_n_s_znorder, __pyx_k_znorder, sizeof(__pyx_k_znorder), 0, 0, 1, 1},
    {&__pyx_n_s_znprimroot, __pyx_k_znprimroot, sizeof(__pyx_k_znprimroot), 0, 0, 1, 1},
    {&__pyx_n_s_zstep, __pyx_k_zstep, sizeof(__pyx_k_zstep), 0, 0, 1, 1},
    {&__pyx_n_s_ztrans, __pyx_k_ztrans, sizeof(__pyx_k_ztrans), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 127, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(0, 890, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(0, 958, __pyx_L1_error)
  __pyx_builtin_KeyboardInterrupt = __Pyx_GetBuiltinName(__pyx_n_s_KeyboardInterrupt); if (!__pyx_builtin_KeyboardInterrupt) __PYX_ERR(0, 1056, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 1146, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "giacpy/giacpy.pyx":629
 * 
 *          def __set__(self,value):
 *            l=Pygen('cas_setup()').eval()             # <<<<<<<<<<<<<<
 *            pl=[ i for i in l ]
 *            pl[6]=value
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_s_cas_setup_2); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "giacpy/giacpy.pyx":972
 *                   return self[i[0]]
 *                else:
 *                   return self[i[0],i[1]][tuple(i[2:])]             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
  __pyx_slice__2 = PySlice_New(__pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_slice__2)) __PYX_ERR(0, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__2);
  __Pyx_GIVEREF(__pyx_slice__2);

  /* "giacpy/giacpy.pyx":1031
 *         v=(<Pygen>(Pygen(value).eval())).gptr[0]
 *         GIAC_sto(v,g,1,context_ptr)
 *         Pygen('purge(GIACPY_TMP_NAME050268070969290100291003):;').eval()             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_s_purge_GIACPY_TMP_NAME05026807096); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "giacpy/giacpy.pyx":1146
 *                          cont=False
 *                          if(CASmonitor(context_ptr) == 1):
 *                             print("killing thread")             # <<<<<<<<<<<<<<
 *                             CASkillthread(context_ptr)
 *                             raise KeyboardInterrupt
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_s_killing_thread); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "giacpy/giacpy.pyx":1165
 *         except:
 *            setctrl_c()
 *            print("trying soft interruption (wait 2s)")             # <<<<<<<<<<<<<<
 *            sleep(2)
 *            print("cas monitor status:",CASmonitor(context_ptr))
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_trying_soft_interruption_wait_2s); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 1165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "giacpy/giacpy.pyx":1169
 *            print("cas monitor status:",CASmonitor(context_ptr))
 *            if(CASmonitor(context_ptr) == 1):
 *               print("warning: Killing thread")             # <<<<<<<<<<<<<<
 *               CASkillthread(context_ptr)
 *               sleep(2)
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_s_warning_Killing_thread); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "giacpy/giacpy.pyx":1447
 *      # To be able to use the eval function before the GiacMethods initialisation
 *      def cas_setup(self,*args):
 *         return Pygen('cas_setup')(self,*args)             # <<<<<<<<<<<<<<
 * 
 *      # ipython pretty printing
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_n_s_cas_setup); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "giacpy/giacpy.pyx":1759
 *      aneg=True
 *      a=-a
 *    if Pyversioninfo >= (2,7):             # <<<<<<<<<<<<<<
 *       size=a.bit_length()  # bit_length python >= 2.7 required.
 *       shift=Pymaxint.bit_length()-1
 */
  __pyx_tuple__9 = PyTuple_Pack(2, __pyx_int_2, __pyx_int_7); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 1759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "giacpy/giacpy.pyx":1891
 *       return
 *    else:
 *       oldies=Pygen('"using sendtext"')             # <<<<<<<<<<<<<<
 *       ressetctrl_c()
 *       try:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_using_sendtext); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 1891, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  __pyx_tuple__13 = PyTuple_Pack(3, __pyx_int_238750788, __pyx_int_228825662, __pyx_int_222419149); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "giacpy/giacpy.pyx":112
 *    PythonVersion3 = False
 * 
 * def decstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return s.decode()
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_n_s_s); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_decstring23, 112, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(0, 112, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":119
 * 
 * 
 * def encstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return bytes(s,'UTF-8')
 */
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_encstring23, 119, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(0, 119, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":147
 * #
 * # Some global variables for optimisation
 * GIACNULL=Pygen('NULL')             # <<<<<<<<<<<<<<
 * #
 * 
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_n_s_NULL); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "giacpy/giacpy.pyx":163
 * # The wrapper to eval with giac
 * #######################################################
 * def giac(s):             # <<<<<<<<<<<<<<
 *   """
 *     This function evaluate a python object with the giac library.
 */
  __pyx_codeobj__19 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_giac, 163, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__19)) __PYX_ERR(0, 163, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);
  __pyx_codeobj__21 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__21)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_tuple__22 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);
  __pyx_codeobj__23 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__22, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__23)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12
 *      """
 * 
 *      def Airy_Ai(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Ai:
 */
  __pyx_tuple__24 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_args); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_codeobj__25 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Airy_Ai, 12, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__25)) __PYX_ERR(2, 12, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":24
 *         return GiacMethods['Airy_Ai'](self,*args)
 * 
 *      def Airy_Bi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Bi:
 */
  __pyx_codeobj__26 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Airy_Bi, 24, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__26)) __PYX_ERR(2, 24, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":36
 *         return GiacMethods['Airy_Bi'](self,*args)
 * 
 *      def Archive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Archive:
 */
  __pyx_codeobj__27 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Archive, 36, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__27)) __PYX_ERR(2, 36, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":47
 *         return GiacMethods['Archive'](self,*args)
 * 
 *      def BesselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselJ:
 */
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_BesselJ, 47, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(2, 47, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":59
 *         return GiacMethods['BesselJ'](self,*args)
 * 
 *      def BesselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselY:
 */
  __pyx_codeobj__29 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_BesselY, 59, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__29)) __PYX_ERR(2, 59, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":71
 *         return GiacMethods['BesselY'](self,*args)
 * 
 *      def Beta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Beta:
 */
  __pyx_codeobj__30 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Beta, 71, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__30)) __PYX_ERR(2, 71, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":85
 *         return GiacMethods['Beta'](self,*args)
 * 
 *      def BlockDiagonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BlockDiagonal:
 */
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_BlockDiagonal, 85, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(2, 85, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":97
 *         return GiacMethods['BlockDiagonal'](self,*args)
 * 
 *      def Ci(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ci:
 */
  __pyx_codeobj__32 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Ci, 97, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__32)) __PYX_ERR(2, 97, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":108
 *         return GiacMethods['Ci'](self,*args)
 * 
 *      def Circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Circle:
 */
  __pyx_codeobj__33 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Circle, 108, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__33)) __PYX_ERR(2, 108, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":121
 *         return GiacMethods['Circle'](self,*args)
 * 
 *      def Col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Col:
 */
  __pyx_codeobj__34 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Col, 121, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__34)) __PYX_ERR(2, 121, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":132
 *         return GiacMethods['Col'](self,*args)
 * 
 *      def CopyVar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for CopyVar:
 */
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_CopyVar, 132, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(2, 132, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":143
 *         return GiacMethods['CopyVar'](self,*args)
 * 
 *      def Dirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Dirac:
 */
  __pyx_codeobj__36 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Dirac, 143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__36)) __PYX_ERR(2, 143, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":156
 *         return GiacMethods['Dirac'](self,*args)
 * 
 *      def Ei(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ei:
 */
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Ei, 156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(2, 156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":167
 *         return GiacMethods['Ei'](self,*args)
 * 
 *      def Factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Factor:
 */
  __pyx_codeobj__38 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Factor, 167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__38)) __PYX_ERR(2, 167, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":179
 *         return GiacMethods['Factor'](self,*args)
 * 
 *      def Fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Fourier:
 */
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Fourier, 179, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(2, 179, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":190
 *         return GiacMethods['Fourier'](self,*args)
 * 
 *      def GF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for GF:
 */
  __pyx_codeobj__40 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_GF, 190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__40)) __PYX_ERR(2, 190, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":205
 *         return GiacMethods['GF'](self,*args)
 * 
 *      def Gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Gamma:
 */
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Gamma, 205, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(2, 205, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":219
 *         return GiacMethods['Gamma'](self,*args)
 * 
 *      def Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside:
 */
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Heaviside, 219, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) __PYX_ERR(2, 219, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":232
 *         return GiacMethods['Heaviside'](self,*args)
 * 
 *      def Heaviside2sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside2sign:
 */
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Heaviside2sign, 232, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) __PYX_ERR(2, 232, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":243
 *         return GiacMethods['Heaviside2sign'](self,*args)
 * 
 *      def Hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Hilbert:
 */
  __pyx_codeobj__44 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Hilbert, 243, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__44)) __PYX_ERR(2, 243, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":254
 *         return GiacMethods['Hilbert'](self,*args)
 * 
 *      def JordanBlock(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for JordanBlock:
 */
  __pyx_codeobj__45 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_JordanBlock, 254, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__45)) __PYX_ERR(2, 254, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":265
 *         return GiacMethods['JordanBlock'](self,*args)
 * 
 *      def LU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LU:
 */
  __pyx_codeobj__46 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_LU, 265, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__46)) __PYX_ERR(2, 265, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":277
 *         return GiacMethods['LU'](self,*args)
 * 
 *      def LambertW(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LambertW:
 */
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_LambertW, 277, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(2, 277, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":289
 *         return GiacMethods['LambertW'](self,*args)
 * 
 *      def Li(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Li:
 */
  __pyx_codeobj__48 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Li, 289, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__48)) __PYX_ERR(2, 289, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":300
 *         return GiacMethods['Li'](self,*args)
 * 
 *      def Line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Line:
 */
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Line, 300, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(2, 300, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":311
 *         return GiacMethods['Line'](self,*args)
 * 
 *      def LineHorz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineHorz:
 */
  __pyx_codeobj__50 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_LineHorz, 311, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__50)) __PYX_ERR(2, 311, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":322
 *         return GiacMethods['LineHorz'](self,*args)
 * 
 *      def LineTan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineTan:
 */
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_LineTan, 322, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(2, 322, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":337
 *         return GiacMethods['LineTan'](self,*args)
 * 
 *      def LineVert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineVert:
 */
  __pyx_codeobj__52 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_LineVert, 337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__52)) __PYX_ERR(2, 337, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":348
 *         return GiacMethods['LineVert'](self,*args)
 * 
 *      def MSE(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for MSE:
 */
  __pyx_codeobj__53 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_MSE, 348, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__53)) __PYX_ERR(2, 348, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":358
 *         return GiacMethods['MSE'](self,*args)
 * 
 *      def Phi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Phi:
 */
  __pyx_codeobj__54 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Phi, 358, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__54)) __PYX_ERR(2, 358, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":370
 *         return GiacMethods['Phi'](self,*args)
 * 
 *      def Pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Pi:
 */
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Pi, 370, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(2, 370, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":384
 *         return GiacMethods['Pi'](self,*args)
 * 
 *      def Psi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Psi:
 */
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Psi, 384, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) __PYX_ERR(2, 384, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":395
 *         return GiacMethods['Psi'](self,*args)
 * 
 *      def QR(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for QR:
 */
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_QR, 395, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(2, 395, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":406
 *         return GiacMethods['QR'](self,*args)
 * 
 *      def RandSeed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for RandSeed:
 */
  __pyx_codeobj__58 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_RandSeed, 406, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__58)) __PYX_ERR(2, 406, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":417
 *         return GiacMethods['RandSeed'](self,*args)
 * 
 *      def ReLU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ReLU:
 */
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ReLU, 417, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(2, 417, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":427
 *         return GiacMethods['ReLU'](self,*args)
 * 
 *      def Row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Row:
 */
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Row, 427, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) __PYX_ERR(2, 427, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":438
 *         return GiacMethods['Row'](self,*args)
 * 
 *      def SortA(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortA:
 */
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_SortA, 438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(2, 438, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":452
 *         return GiacMethods['SortA'](self,*args)
 * 
 *      def SortD(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortD:
 */
  __pyx_codeobj__62 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_SortD, 452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__62)) __PYX_ERR(2, 452, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":466
 *         return GiacMethods['SortD'](self,*args)
 * 
 *      def UTPC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPC:
 */
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_UTPC, 466, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(2, 466, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":478
 *         return GiacMethods['UTPC'](self,*args)
 * 
 *      def UTPF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPF:
 */
  __pyx_codeobj__64 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_UTPF, 478, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__64)) __PYX_ERR(2, 478, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":490
 *         return GiacMethods['UTPF'](self,*args)
 * 
 *      def UTPN(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPN:
 */
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_UTPN, 490, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(2, 490, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":502
 *         return GiacMethods['UTPN'](self,*args)
 * 
 *      def UTPT(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPT:
 */
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_UTPT, 502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(2, 502, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":514
 *         return GiacMethods['UTPT'](self,*args)
 * 
 *      def VARS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VARS:
 */
  __pyx_codeobj__67 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_VARS, 514, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__67)) __PYX_ERR(2, 514, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":525
 *         return GiacMethods['VARS'](self,*args)
 * 
 *      def VAS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS:
 */
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_VAS, 525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(2, 525, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":536
 *         return GiacMethods['VAS'](self,*args)
 * 
 *      def VAS_positive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS_positive:
 */
  __pyx_codeobj__69 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_VAS_positive, 536, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__69)) __PYX_ERR(2, 536, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":547
 *         return GiacMethods['VAS_positive'](self,*args)
 * 
 *      def Zeta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Zeta:
 */
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_Zeta, 547, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(2, 547, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":558
 *         return GiacMethods['Zeta'](self,*args)
 * 
 *      def a2q(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for a2q:
 */
  __pyx_codeobj__71 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_a2q, 558, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__71)) __PYX_ERR(2, 558, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":570
 *         return GiacMethods['a2q'](self,*args)
 * 
 *      def abcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abcuv:
 */
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_abcuv, 570, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(2, 570, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":585
 *         return GiacMethods['abcuv'](self,*args)
 * 
 *      def about(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for about:
 */
  __pyx_codeobj__73 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_about, 585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__73)) __PYX_ERR(2, 585, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":597
 *         return GiacMethods['about'](self,*args)
 * 
 *      def abs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abs:
 */
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_abs, 597, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(2, 597, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":611
 *         return GiacMethods['abs'](self,*args)
 * 
 *      def abscissa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abscissa:
 */
  __pyx_codeobj__75 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_abscissa, 611, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__75)) __PYX_ERR(2, 611, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":625
 *         return GiacMethods['abscissa'](self,*args)
 * 
 *      def accumulate_head_tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for accumulate_head_tail:
 */
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_accumulate_head_tail, 625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) __PYX_ERR(2, 625, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":636
 *         return GiacMethods['accumulate_head_tail'](self,*args)
 * 
 *      def acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos:
 */
  __pyx_codeobj__77 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acos, 636, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__77)) __PYX_ERR(2, 636, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":647
 *         return GiacMethods['acos'](self,*args)
 * 
 *      def acos2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2asin:
 */
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acos2asin, 647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) __PYX_ERR(2, 647, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":659
 *         return GiacMethods['acos2asin'](self,*args)
 * 
 *      def acos2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2atan:
 */
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acos2atan, 659, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(2, 659, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":671
 *         return GiacMethods['acos2atan'](self,*args)
 * 
 *      def acosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acosh:
 */
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acosh, 671, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) __PYX_ERR(2, 671, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":682
 *         return GiacMethods['acosh'](self,*args)
 * 
 *      def acot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acot:
 */
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acot, 682, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(2, 682, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":693
 *         return GiacMethods['acot'](self,*args)
 * 
 *      def acsc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acsc:
 */
  __pyx_codeobj__82 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acsc, 693, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__82)) __PYX_ERR(2, 693, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":705
 *         return GiacMethods['acsc'](self,*args)
 * 
 *      def acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acyclic:
 */
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_acyclic, 705, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(2, 705, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":715
 *         return GiacMethods['acyclic'](self,*args)
 * 
 *      def adaptive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adaptive:
 */
  __pyx_codeobj__84 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_adaptive, 715, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__84)) __PYX_ERR(2, 715, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":725
 *         return GiacMethods['adaptive'](self,*args)
 * 
 *      def add(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add:
 */
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_add, 725, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(2, 725, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":745
 *         return GiacMethods['add'](self,*args)
 * 
 *      def add_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_arc:
 */
  __pyx_codeobj__86 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_add_arc, 745, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__86)) __PYX_ERR(2, 745, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":756
 *         return GiacMethods['add_arc'](self,*args)
 * 
 *      def add_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_edge:
 */
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_add_edge, 756, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(2, 756, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":767
 *         return GiacMethods['add_edge'](self,*args)
 * 
 *      def add_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_vertex:
 */
  __pyx_codeobj__88 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_add_vertex, 767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__88)) __PYX_ERR(2, 767, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":778
 *         return GiacMethods['add_vertex'](self,*args)
 * 
 *      def additionally(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for additionally:
 */
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_additionally, 778, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(2, 778, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":790
 *         return GiacMethods['additionally'](self,*args)
 * 
 *      def addtable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for addtable:
 */
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_addtable, 790, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(2, 790, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":801
 *         return GiacMethods['addtable'](self,*args)
 * 
 *      def adjacency_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjacency_matrix:
 */
  __pyx_codeobj__91 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_adjacency_matrix, 801, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__91)) __PYX_ERR(2, 801, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":812
 *         return GiacMethods['adjacency_matrix'](self,*args)
 * 
 *      def adjoint_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjoint_matrix:
 */
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_adjoint_matrix, 812, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) __PYX_ERR(2, 812, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":823
 *         return GiacMethods['adjoint_matrix'](self,*args)
 * 
 *      def affix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for affix:
 */
  __pyx_codeobj__93 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_affix, 823, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__93)) __PYX_ERR(2, 823, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":836
 *         return GiacMethods['affix'](self,*args)
 * 
 *      def algsubs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algsubs:
 */
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_algsubs, 836, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(2, 836, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":849
 *         return GiacMethods['algsubs'](self,*args)
 * 
 *      def algvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algvar:
 */
  __pyx_codeobj__95 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_algvar, 849, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__95)) __PYX_ERR(2, 849, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":860
 *         return GiacMethods['algvar'](self,*args)
 * 
 *      def all_trig_solutions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for all_trig_solutions:
 */
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_all_trig_solutions, 860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(2, 860, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":872
 *         return GiacMethods['all_trig_solutions'](self,*args)
 * 
 *      def allpairs_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for allpairs_distance:
 */
  __pyx_codeobj__97 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_allpairs_distance, 872, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__97)) __PYX_ERR(2, 872, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":883
 *         return GiacMethods['allpairs_distance'](self,*args)
 * 
 *      def alog10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for alog10:
 */
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_alog10, 883, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(2, 883, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":894
 *         return GiacMethods['alog10'](self,*args)
 * 
 *      def altitude(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for altitude:
 */
  __pyx_codeobj__99 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_altitude, 894, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__99)) __PYX_ERR(2, 894, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":905
 *         return GiacMethods['altitude'](self,*args)
 * 
 *      def angle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle:
 */
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_angle, 905, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) __PYX_ERR(2, 905, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":920
 *         return GiacMethods['angle'](self,*args)
 * 
 *      def angle_radian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle_radian:
 */
  __pyx_codeobj__101 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_angle_radian, 920, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__101)) __PYX_ERR(2, 920, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":932
 *         return GiacMethods['angle_radian'](self,*args)
 * 
 *      def angleat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleat:
 */
  __pyx_codeobj__102 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_angleat, 932, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__102)) __PYX_ERR(2, 932, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":943
 *         return GiacMethods['angleat'](self,*args)
 * 
 *      def angleatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleatraw:
 */
  __pyx_codeobj__103 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_angleatraw, 943, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__103)) __PYX_ERR(2, 943, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":954
 *         return GiacMethods['angleatraw'](self,*args)
 * 
 *      def ans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ans:
 */
  __pyx_codeobj__104 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ans, 954, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__104)) __PYX_ERR(2, 954, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":967
 *         return GiacMethods['ans'](self,*args)
 * 
 *      def antiprism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for antiprism_graph:
 */
  __pyx_codeobj__105 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_antiprism_graph, 967, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__105)) __PYX_ERR(2, 967, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":978
 *         return GiacMethods['antiprism_graph'](self,*args)
 * 
 *      def append(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for append:
 */
  __pyx_codeobj__106 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_append, 978, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__106)) __PYX_ERR(2, 978, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":994
 *         return GiacMethods['append'](self,*args)
 * 
 *      def apply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for apply:
 */
  __pyx_codeobj__107 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_apply, 994, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__107)) __PYX_ERR(2, 994, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1006
 *         return GiacMethods['apply'](self,*args)
 * 
 *      def approx(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for approx:
 */
  __pyx_codeobj__108 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_approx, 1006, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__108)) __PYX_ERR(2, 1006, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1022
 *         return GiacMethods['approx'](self,*args)
 * 
 *      def arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arc:
 */
  __pyx_codeobj__109 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arc, 1022, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__109)) __PYX_ERR(2, 1022, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1036
 *         return GiacMethods['arc'](self,*args)
 * 
 *      def arcLen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcLen:
 */
  __pyx_codeobj__110 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arcLen, 1036, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__110)) __PYX_ERR(2, 1036, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1049
 *         return GiacMethods['arcLen'](self,*args)
 * 
 *      def arccos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccos:
 */
  __pyx_codeobj__111 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arccos, 1049, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__111)) __PYX_ERR(2, 1049, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1060
 *         return GiacMethods['arccos'](self,*args)
 * 
 *      def arccosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccosh:
 */
  __pyx_codeobj__112 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arccosh, 1060, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__112)) __PYX_ERR(2, 1060, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1071
 *         return GiacMethods['arccosh'](self,*args)
 * 
 *      def arclen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arclen:
 */
  __pyx_codeobj__113 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arclen, 1071, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__113)) __PYX_ERR(2, 1071, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1084
 *         return GiacMethods['arclen'](self,*args)
 * 
 *      def arcsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsin:
 */
  __pyx_codeobj__114 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arcsin, 1084, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__114)) __PYX_ERR(2, 1084, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1095
 *         return GiacMethods['arcsin'](self,*args)
 * 
 *      def arcsinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsinh:
 */
  __pyx_codeobj__115 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arcsinh, 1095, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__115)) __PYX_ERR(2, 1095, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1106
 *         return GiacMethods['arcsinh'](self,*args)
 * 
 *      def arctan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctan:
 */
  __pyx_codeobj__116 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arctan, 1106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__116)) __PYX_ERR(2, 1106, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1117
 *         return GiacMethods['arctan'](self,*args)
 * 
 *      def arctanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctanh:
 */
  __pyx_codeobj__117 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arctanh, 1117, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__117)) __PYX_ERR(2, 1117, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1128
 *         return GiacMethods['arctanh'](self,*args)
 * 
 *      def area(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for area:
 */
  __pyx_codeobj__118 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_area, 1128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__118)) __PYX_ERR(2, 1128, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1145
 *         return GiacMethods['area'](self,*args)
 * 
 *      def areaat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaat:
 */
  __pyx_codeobj__119 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_areaat, 1145, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__119)) __PYX_ERR(2, 1145, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1160
 *         return GiacMethods['areaat'](self,*args)
 * 
 *      def areaatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaatraw:
 */
  __pyx_codeobj__120 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_areaatraw, 1160, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__120)) __PYX_ERR(2, 1160, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1175
 *         return GiacMethods['areaatraw'](self,*args)
 * 
 *      def areaplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaplot:
 */
  __pyx_codeobj__121 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_areaplot, 1175, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__121)) __PYX_ERR(2, 1175, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1188
 *         return GiacMethods['areaplot'](self,*args)
 * 
 *      def arg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arg:
 */
  __pyx_codeobj__122 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arg, 1188, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__122)) __PYX_ERR(2, 1188, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1201
 *         return GiacMethods['arg'](self,*args)
 * 
 *      def array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for array:
 */
  __pyx_codeobj__123 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_array, 1201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__123)) __PYX_ERR(2, 1201, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1213
 *         return GiacMethods['array'](self,*args)
 * 
 *      def arrivals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arrivals:
 */
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_arrivals, 1213, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(2, 1213, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1224
 *         return GiacMethods['arrivals'](self,*args)
 * 
 *      def articulation_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for articulation_points:
 */
  __pyx_codeobj__125 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_articulation_points, 1224, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__125)) __PYX_ERR(2, 1224, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1236
 *         return GiacMethods['articulation_points'](self,*args)
 * 
 *      def asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin:
 */
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_asin, 1236, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(2, 1236, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1247
 *         return GiacMethods['asin'](self,*args)
 * 
 *      def asin2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2acos:
 */
  __pyx_codeobj__127 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_asin2acos, 1247, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__127)) __PYX_ERR(2, 1247, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1259
 *         return GiacMethods['asin2acos'](self,*args)
 * 
 *      def asin2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2atan:
 */
  __pyx_codeobj__128 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_asin2atan, 1259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__128)) __PYX_ERR(2, 1259, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1271
 *         return GiacMethods['asin2atan'](self,*args)
 * 
 *      def asinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asinh:
 */
  __pyx_codeobj__129 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_asinh, 1271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__129)) __PYX_ERR(2, 1271, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1282
 *         return GiacMethods['asinh'](self,*args)
 * 
 *      def assign_edge_weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assign_edge_weights:
 */
  __pyx_codeobj__130 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_assign_edge_weights, 1282, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__130)) __PYX_ERR(2, 1282, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1294
 *         return GiacMethods['assign_edge_weights'](self,*args)
 * 
 *      def assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assume:
 */
  __pyx_codeobj__131 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_assume, 1294, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__131)) __PYX_ERR(2, 1294, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1314
 *         return GiacMethods['assume'](self,*args)
 * 
 *      def at(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for at:
 */
  __pyx_codeobj__132 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_at, 1314, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__132)) __PYX_ERR(2, 1314, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1326
 *         return GiacMethods['at'](self,*args)
 * 
 *      def atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan:
 */
  __pyx_codeobj__133 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_atan, 1326, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__133)) __PYX_ERR(2, 1326, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1337
 *         return GiacMethods['atan'](self,*args)
 * 
 *      def atan2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2:
 */
  __pyx_codeobj__134 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_atan2, 1337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__134)) __PYX_ERR(2, 1337, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1348
 *         return GiacMethods['atan2'](self,*args)
 * 
 *      def atan2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2acos:
 */
  __pyx_codeobj__135 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_atan2acos, 1348, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__135)) __PYX_ERR(2, 1348, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1358
 *         return GiacMethods['atan2acos'](self,*args)
 * 
 *      def atan2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2asin:
 */
  __pyx_codeobj__136 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_atan2asin, 1358, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__136)) __PYX_ERR(2, 1358, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1368
 *         return GiacMethods['atan2asin'](self,*args)
 * 
 *      def atanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atanh:
 */
  __pyx_codeobj__137 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_atanh, 1368, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__137)) __PYX_ERR(2, 1368, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1379
 *         return GiacMethods['atanh'](self,*args)
 * 
 *      def atrig2ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atrig2ln:
 */
  __pyx_codeobj__138 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_atrig2ln, 1379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__138)) __PYX_ERR(2, 1379, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1392
 *         return GiacMethods['atrig2ln'](self,*args)
 * 
 *      def augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for augment:
 */
  __pyx_codeobj__139 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_augment, 1392, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__139)) __PYX_ERR(2, 1392, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1407
 *         return GiacMethods['augment'](self,*args)
 * 
 *      def auto_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for auto_correlation:
 */
  __pyx_codeobj__140 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_auto_correlation, 1407, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__140)) __PYX_ERR(2, 1407, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1418
 *         return GiacMethods['auto_correlation'](self,*args)
 * 
 *      def autosimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for autosimplify:
 */
  __pyx_codeobj__141 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_autosimplify, 1418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__141)) __PYX_ERR(2, 1418, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1434
 *         return GiacMethods['autosimplify'](self,*args)
 * 
 *      def avance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avance:
 */
  __pyx_codeobj__142 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_avance, 1434, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__142)) __PYX_ERR(2, 1434, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1446
 *         return GiacMethods['avance'](self,*args)
 * 
 *      def avgRC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avgRC:
 */
  __pyx_codeobj__143 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_avgRC, 1446, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__143)) __PYX_ERR(2, 1446, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1459
 *         return GiacMethods['avgRC'](self,*args)
 * 
 *      def axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axes:
 */
  __pyx_codeobj__144 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_axes, 1459, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__144)) __PYX_ERR(2, 1459, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1471
 *         return GiacMethods['axes'](self,*args)
 * 
 *      def axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axis:
 */
  __pyx_codeobj__145 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_axis, 1471, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__145)) __PYX_ERR(2, 1471, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1481
 *         return GiacMethods['axis'](self,*args)
 * 
 *      def back(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for back:
 */
  __pyx_codeobj__146 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_back, 1481, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__146)) __PYX_ERR(2, 1481, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1494
 *         return GiacMethods['back'](self,*args)
 * 
 *      def backward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for backward:
 */
  __pyx_codeobj__147 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_backward, 1494, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__147)) __PYX_ERR(2, 1494, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1506
 *         return GiacMethods['backward'](self,*args)
 * 
 *      def baisse_crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for baisse_crayon:
 */
  __pyx_codeobj__148 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_baisse_crayon, 1506, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__148)) __PYX_ERR(2, 1506, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1517
 *         return GiacMethods['baisse_crayon'](self,*args)
 * 
 *      def bandwidth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bandwidth:
 */
  __pyx_codeobj__149 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bandwidth, 1517, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__149)) __PYX_ERR(2, 1517, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1527
 *         return GiacMethods['bandwidth'](self,*args)
 * 
 *      def bar_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bar_plot:
 */
  __pyx_codeobj__150 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bar_plot, 1527, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__150)) __PYX_ERR(2, 1527, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1540
 *         return GiacMethods['bar_plot'](self,*args)
 * 
 *      def barplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barplot:
 */
  __pyx_codeobj__151 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_barplot, 1540, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__151)) __PYX_ERR(2, 1540, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1553
 *         return GiacMethods['barplot'](self,*args)
 * 
 *      def bartlett_hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bartlett_hann_window:
 */
  __pyx_codeobj__152 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bartlett_hann_window, 1553, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__152)) __PYX_ERR(2, 1553, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1564
 *         return GiacMethods['bartlett_hann_window'](self,*args)
 * 
 *      def barycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barycenter:
 */
  __pyx_codeobj__153 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_barycenter, 1564, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__153)) __PYX_ERR(2, 1564, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1577
 *         return GiacMethods['barycenter'](self,*args)
 * 
 *      def base(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for base:
 */
  __pyx_codeobj__154 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_base, 1577, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__154)) __PYX_ERR(2, 1577, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1590
 *         return GiacMethods['base'](self,*args)
 * 
 *      def basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for basis:
 */
  __pyx_codeobj__155 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_basis, 1590, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__155)) __PYX_ERR(2, 1590, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1601
 *         return GiacMethods['basis'](self,*args)
 * 
 *      def batons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for batons:
 */
  __pyx_codeobj__156 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_batons, 1601, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__156)) __PYX_ERR(2, 1601, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1614
 *         return GiacMethods['batons'](self,*args)
 * 
 *      def bellman_ford(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bellman_ford:
 */
  __pyx_codeobj__157 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bellman_ford, 1614, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__157)) __PYX_ERR(2, 1614, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1625
 *         return GiacMethods['bellman_ford'](self,*args)
 * 
 *      def berlekamp_massey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for berlekamp_massey:
 */
  __pyx_codeobj__158 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_berlekamp_massey, 1625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__158)) __PYX_ERR(2, 1625, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1636
 *         return GiacMethods['berlekamp_massey'](self,*args)
 * 
 *      def bernoulli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli:
 */
  __pyx_codeobj__159 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bernoulli, 1636, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__159)) __PYX_ERR(2, 1636, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1648
 *         return GiacMethods['bernoulli'](self,*args)
 * 
 *      def bernoulli_mod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli_mod:
 */
  __pyx_codeobj__160 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bernoulli_mod, 1648, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__160)) __PYX_ERR(2, 1648, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1658
 *         return GiacMethods['bernoulli_mod'](self,*args)
 * 
 *      def besselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselJ:
 */
  __pyx_codeobj__161 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_besselJ, 1658, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__161)) __PYX_ERR(2, 1658, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1670
 *         return GiacMethods['besselJ'](self,*args)
 * 
 *      def besselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselY:
 */
  __pyx_codeobj__162 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_besselY, 1670, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__162)) __PYX_ERR(2, 1670, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1682
 *         return GiacMethods['besselY'](self,*args)
 * 
 *      def betad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad:
 */
  __pyx_codeobj__163 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_betad, 1682, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__163)) __PYX_ERR(2, 1682, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1693
 *         return GiacMethods['betad'](self,*args)
 * 
 *      def betad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_cdf:
 */
  __pyx_codeobj__164 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_betad_cdf, 1693, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__164)) __PYX_ERR(2, 1693, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1705
 *         return GiacMethods['betad_cdf'](self,*args)
 * 
 *      def betad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_icdf:
 */
  __pyx_codeobj__165 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_betad_icdf, 1705, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__165)) __PYX_ERR(2, 1705, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1717
 *         return GiacMethods['betad_icdf'](self,*args)
 * 
 *      def betavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betavariate:
 */
  __pyx_codeobj__166 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_betavariate, 1717, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__166)) __PYX_ERR(2, 1717, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1729
 *         return GiacMethods['betavariate'](self,*args)
 * 
 *      def betweenness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betweenness_centrality:
 */
  __pyx_codeobj__167 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_betweenness_centrality, 1729, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__167)) __PYX_ERR(2, 1729, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1740
 *         return GiacMethods['betweenness_centrality'](self,*args)
 * 
 *      def bezier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezier:
 */
  __pyx_codeobj__168 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bezier, 1740, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__168)) __PYX_ERR(2, 1740, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1754
 *         return GiacMethods['bezier'](self,*args)
 * 
 *      def bezout_entiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezout_entiers:
 */
  __pyx_codeobj__169 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bezout_entiers, 1754, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__169)) __PYX_ERR(2, 1754, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1767
 *         return GiacMethods['bezout_entiers'](self,*args)
 * 
 *      def bezoutian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezoutian:
 */
  __pyx_codeobj__170 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bezoutian, 1767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__170)) __PYX_ERR(2, 1767, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1777
 *         return GiacMethods['bezoutian'](self,*args)
 * 
 *      def biconnected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for biconnected_components:
 */
  __pyx_codeobj__171 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_biconnected_components, 1777, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__171)) __PYX_ERR(2, 1777, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1788
 *         return GiacMethods['biconnected_components'](self,*args)
 * 
 *      def binomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial:
 */
  __pyx_codeobj__172 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_binomial, 1788, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__172)) __PYX_ERR(2, 1788, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1805
 *         return GiacMethods['binomial'](self,*args)
 * 
 *      def binomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_cdf:
 */
  __pyx_codeobj__173 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_binomial_cdf, 1805, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__173)) __PYX_ERR(2, 1805, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1818
 *         return GiacMethods['binomial_cdf'](self,*args)
 * 
 *      def binomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_icdf:
 */
  __pyx_codeobj__174 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_binomial_icdf, 1818, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__174)) __PYX_ERR(2, 1818, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1830
 *         return GiacMethods['binomial_icdf'](self,*args)
 * 
 *      def bins(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bins:
 */
  __pyx_codeobj__175 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bins, 1830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__175)) __PYX_ERR(2, 1830, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1840
 *         return GiacMethods['bins'](self,*args)
 * 
 *      def bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite:
 */
  __pyx_codeobj__176 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bipartite, 1840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__176)) __PYX_ERR(2, 1840, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1850
 *         return GiacMethods['bipartite'](self,*args)
 * 
 *      def bipartite_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite_matching:
 */
  __pyx_codeobj__177 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bipartite_matching, 1850, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__177)) __PYX_ERR(2, 1850, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1861
 *         return GiacMethods['bipartite_matching'](self,*args)
 * 
 *      def bisection_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisection_solver:
 */
  __pyx_codeobj__178 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bisection_solver, 1861, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__178)) __PYX_ERR(2, 1861, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1877
 *         return GiacMethods['bisection_solver'](self,*args)
 * 
 *      def bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisector:
 */
  __pyx_codeobj__179 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bisector, 1877, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__179)) __PYX_ERR(2, 1877, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1888
 *         return GiacMethods['bisector'](self,*args)
 * 
 *      def bit_depth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bit_depth:
 */
  __pyx_codeobj__180 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bit_depth, 1888, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__180)) __PYX_ERR(2, 1888, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1899
 *         return GiacMethods['bit_depth'](self,*args)
 * 
 *      def bitand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitand:
 */
  __pyx_codeobj__181 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bitand, 1899, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__181)) __PYX_ERR(2, 1899, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1910
 *         return GiacMethods['bitand'](self,*args)
 * 
 *      def bitor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitor:
 */
  __pyx_codeobj__182 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bitor, 1910, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__182)) __PYX_ERR(2, 1910, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1921
 *         return GiacMethods['bitor'](self,*args)
 * 
 *      def bitxor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitxor:
 */
  __pyx_codeobj__183 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bitxor, 1921, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__183)) __PYX_ERR(2, 1921, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1932
 *         return GiacMethods['bitxor'](self,*args)
 * 
 *      def blackman_harris_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_harris_window:
 */
  __pyx_codeobj__184 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_blackman_harris_window, 1932, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__184)) __PYX_ERR(2, 1932, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1943
 *         return GiacMethods['blackman_harris_window'](self,*args)
 * 
 *      def blackman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_window:
 */
  __pyx_codeobj__185 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_blackman_window, 1943, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__185)) __PYX_ERR(2, 1943, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1954
 *         return GiacMethods['blackman_window'](self,*args)
 * 
 *      def block_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for block_size:
 */
  __pyx_codeobj__186 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_block_size, 1954, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__186)) __PYX_ERR(2, 1954, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1964
 *         return GiacMethods['block_size'](self,*args)
 * 
 *      def blockmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blockmatrix:
 */
  __pyx_codeobj__187 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_blockmatrix, 1964, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__187)) __PYX_ERR(2, 1964, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1976
 *         return GiacMethods['blockmatrix'](self,*args)
 * 
 *      def bohman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bohman_window:
 */
  __pyx_codeobj__188 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bohman_window, 1976, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__188)) __PYX_ERR(2, 1976, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1987
 *         return GiacMethods['bohman_window'](self,*args)
 * 
 *      def border(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for border:
 */
  __pyx_codeobj__189 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_border, 1987, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__189)) __PYX_ERR(2, 1987, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":1999
 *         return GiacMethods['border'](self,*args)
 * 
 *      def box_constraints(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for box_constraints:
 */
  __pyx_codeobj__190 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_box_constraints, 1999, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__190)) __PYX_ERR(2, 1999, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2010
 *         return GiacMethods['box_constraints'](self,*args)
 * 
 *      def boxcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxcar:
 */
  __pyx_codeobj__191 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_boxcar, 2010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__191)) __PYX_ERR(2, 2010, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2021
 *         return GiacMethods['boxcar'](self,*args)
 * 
 *      def boxwhisker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxwhisker:
 */
  __pyx_codeobj__192 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_boxwhisker, 2021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__192)) __PYX_ERR(2, 2021, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2035
 *         return GiacMethods['boxwhisker'](self,*args)
 * 
 *      def brent_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brent_solver:
 */
  __pyx_codeobj__193 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_brent_solver, 2035, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__193)) __PYX_ERR(2, 2035, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2051
 *         return GiacMethods['brent_solver'](self,*args)
 * 
 *      def brown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brown:
 */
  __pyx_codeobj__194 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_brown, 2051, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__194)) __PYX_ERR(2, 2051, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2063
 *         return GiacMethods['brown'](self,*args)
 * 
 *      def bspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bspline:
 */
  __pyx_codeobj__195 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bspline, 2063, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__195)) __PYX_ERR(2, 2063, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2074
 *         return GiacMethods['bspline'](self,*args)
 * 
 *      def bvpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bvpsolve:
 */
  __pyx_codeobj__196 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_bvpsolve, 2074, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__196)) __PYX_ERR(2, 2074, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2086
 *         return GiacMethods['bvpsolve'](self,*args)
 * 
 *      def cFactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cFactor:
 */
  __pyx_codeobj__197 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cFactor, 2086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__197)) __PYX_ERR(2, 2086, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2099
 *         return GiacMethods['cFactor'](self,*args)
 * 
 *      def cSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cSolve:
 */
  __pyx_codeobj__198 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cSolve, 2099, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__198)) __PYX_ERR(2, 2099, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2113
 *         return GiacMethods['cSolve'](self,*args)
 * 
 *      def cZeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cZeros:
 */
  __pyx_codeobj__199 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cZeros, 2113, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__199)) __PYX_ERR(2, 2113, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2125
 *         return GiacMethods['cZeros'](self,*args)
 * 
 *      def camembert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for camembert:
 */
  __pyx_codeobj__200 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_camembert, 2125, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__200)) __PYX_ERR(2, 2125, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2138
 *         return GiacMethods['camembert'](self,*args)
 * 
 *      def canonical_form(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_form:
 */
  __pyx_codeobj__201 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_canonical_form, 2138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__201)) __PYX_ERR(2, 2138, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2150
 *         return GiacMethods['canonical_form'](self,*args)
 * 
 *      def canonical_labeling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_labeling:
 */
  __pyx_codeobj__202 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_canonical_labeling, 2150, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__202)) __PYX_ERR(2, 2150, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2161
 *         return GiacMethods['canonical_labeling'](self,*args)
 * 
 *      def cartesian_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cartesian_product:
 */
  __pyx_codeobj__203 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cartesian_product, 2161, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__203)) __PYX_ERR(2, 2161, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2172
 *         return GiacMethods['cartesian_product'](self,*args)
 * 
 *      def cauchy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy:
 */
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cauchy, 2172, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(2, 2172, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2183
 *         return GiacMethods['cauchy'](self,*args)
 * 
 *      def cauchy_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_cdf:
 */
  __pyx_codeobj__205 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cauchy_cdf, 2183, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__205)) __PYX_ERR(2, 2183, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2195
 *         return GiacMethods['cauchy_cdf'](self,*args)
 * 
 *      def cauchy_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_icdf:
 */
  __pyx_codeobj__206 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cauchy_icdf, 2195, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__206)) __PYX_ERR(2, 2195, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2206
 *         return GiacMethods['cauchy_icdf'](self,*args)
 * 
 *      def cauchyd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd:
 */
  __pyx_codeobj__207 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cauchyd, 2206, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__207)) __PYX_ERR(2, 2206, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2217
 *         return GiacMethods['cauchyd'](self,*args)
 * 
 *      def cauchyd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_cdf:
 */
  __pyx_codeobj__208 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cauchyd_cdf, 2217, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__208)) __PYX_ERR(2, 2217, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2229
 *         return GiacMethods['cauchyd_cdf'](self,*args)
 * 
 *      def cauchyd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_icdf:
 */
  __pyx_codeobj__209 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cauchyd_icdf, 2229, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__209)) __PYX_ERR(2, 2229, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2240
 *         return GiacMethods['cauchyd_icdf'](self,*args)
 * 
 *      def cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cdf:
 */
  __pyx_codeobj__210 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cdf, 2240, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__210)) __PYX_ERR(2, 2240, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2254
 *         return GiacMethods['cdf'](self,*args)
 * 
 *      def ceil(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceil:
 */
  __pyx_codeobj__211 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ceil, 2254, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__211)) __PYX_ERR(2, 2254, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2266
 *         return GiacMethods['ceil'](self,*args)
 * 
 *      def ceiling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceiling:
 */
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ceiling, 2266, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(2, 2266, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2278
 *         return GiacMethods['ceiling'](self,*args)
 * 
 *      def center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center:
 */
  __pyx_codeobj__213 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_center, 2278, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__213)) __PYX_ERR(2, 2278, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2290
 *         return GiacMethods['center'](self,*args)
 * 
 *      def center2interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center2interval:
 */
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_center2interval, 2290, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(2, 2290, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2302
 *         return GiacMethods['center2interval'](self,*args)
 * 
 *      def centered_cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_cube:
 */
  __pyx_codeobj__215 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_centered_cube, 2302, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__215)) __PYX_ERR(2, 2302, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2314
 *         return GiacMethods['centered_cube'](self,*args)
 * 
 *      def centered_tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_tetrahedron:
 */
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_centered_tetrahedron, 2314, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(2, 2314, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2326
 *         return GiacMethods['centered_tetrahedron'](self,*args)
 * 
 *      def cfactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfactor:
 */
  __pyx_codeobj__217 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cfactor, 2326, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__217)) __PYX_ERR(2, 2326, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2339
 *         return GiacMethods['cfactor'](self,*args)
 * 
 *      def cfsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfsolve:
 */
  __pyx_codeobj__218 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cfsolve, 2339, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__218)) __PYX_ERR(2, 2339, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2351
 *         return GiacMethods['cfsolve'](self,*args)
 * 
 *      def changebase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for changebase:
 */
  __pyx_codeobj__219 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_changebase, 2351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__219)) __PYX_ERR(2, 2351, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2363
 *         return GiacMethods['changebase'](self,*args)
 * 
 *      def channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channel_data:
 */
  __pyx_codeobj__220 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_channel_data, 2363, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__220)) __PYX_ERR(2, 2363, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2377
 *         return GiacMethods['channel_data'](self,*args)
 * 
 *      def channels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channels:
 */
  __pyx_codeobj__221 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_channels, 2377, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__221)) __PYX_ERR(2, 2377, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2388
 *         return GiacMethods['channels'](self,*args)
 * 
 *      def char(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for char:
 */
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_char, 2388, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(2, 2388, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2400
 *         return GiacMethods['char'](self,*args)
 * 
 *      def charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for charpoly:
 */
  __pyx_codeobj__223 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_charpoly, 2400, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__223)) __PYX_ERR(2, 2400, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2414
 *         return GiacMethods['charpoly'](self,*args)
 * 
 *      def chinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chinrem:
 */
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chinrem, 2414, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(2, 2414, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2426
 *         return GiacMethods['chinrem'](self,*args)
 * 
 *      def chisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare:
 */
  __pyx_codeobj__225 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquare, 2426, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__225)) __PYX_ERR(2, 2426, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2440
 *         return GiacMethods['chisquare'](self,*args)
 * 
 *      def chisquare_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_cdf:
 */
  __pyx_codeobj__226 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquare_cdf, 2440, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__226)) __PYX_ERR(2, 2440, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2452
 *         return GiacMethods['chisquare_cdf'](self,*args)
 * 
 *      def chisquare_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_icdf:
 */
  __pyx_codeobj__227 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquare_icdf, 2452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__227)) __PYX_ERR(2, 2452, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2464
 *         return GiacMethods['chisquare_icdf'](self,*args)
 * 
 *      def chisquared(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared:
 */
  __pyx_codeobj__228 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquared, 2464, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__228)) __PYX_ERR(2, 2464, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2478
 *         return GiacMethods['chisquared'](self,*args)
 * 
 *      def chisquared_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_cdf:
 */
  __pyx_codeobj__229 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquared_cdf, 2478, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__229)) __PYX_ERR(2, 2478, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2490
 *         return GiacMethods['chisquared_cdf'](self,*args)
 * 
 *      def chisquared_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_icdf:
 */
  __pyx_codeobj__230 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquared_icdf, 2490, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__230)) __PYX_ERR(2, 2490, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2502
 *         return GiacMethods['chisquared_icdf'](self,*args)
 * 
 *      def chisquaret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquaret:
 */
  __pyx_codeobj__231 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chisquaret, 2502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__231)) __PYX_ERR(2, 2502, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2521
 *         return GiacMethods['chisquaret'](self,*args)
 * 
 *      def choice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for choice:
 */
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_choice, 2521, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(2, 2521, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2535
 *         return GiacMethods['choice'](self,*args)
 * 
 *      def cholesky(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cholesky:
 */
  __pyx_codeobj__233 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cholesky, 2535, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__233)) __PYX_ERR(2, 2535, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2546
 *         return GiacMethods['cholesky'](self,*args)
 * 
 *      def chr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chr:
 */
  __pyx_codeobj__234 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chr, 2546, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__234)) __PYX_ERR(2, 2546, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2558
 *         return GiacMethods['chr'](self,*args)
 * 
 *      def chrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chrem:
 */
  __pyx_codeobj__235 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chrem, 2558, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__235)) __PYX_ERR(2, 2558, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2573
 *         return GiacMethods['chrem'](self,*args)
 * 
 *      def chromatic_index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_index:
 */
  __pyx_codeobj__236 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chromatic_index, 2573, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__236)) __PYX_ERR(2, 2573, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2584
 *         return GiacMethods['chromatic_index'](self,*args)
 * 
 *      def chromatic_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_number:
 */
  __pyx_codeobj__237 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chromatic_number, 2584, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__237)) __PYX_ERR(2, 2584, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2594
 *         return GiacMethods['chromatic_number'](self,*args)
 * 
 *      def chromatic_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_polynomial:
 */
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_chromatic_polynomial, 2594, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(2, 2594, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2606
 *         return GiacMethods['chromatic_polynomial'](self,*args)
 * 
 *      def circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circle:
 */
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_circle, 2606, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(2, 2606, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2624
 *         return GiacMethods['circle'](self,*args)
 * 
 *      def circumcircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circumcircle:
 */
  __pyx_codeobj__240 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_circumcircle, 2624, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__240)) __PYX_ERR(2, 2624, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2635
 *         return GiacMethods['circumcircle'](self,*args)
 * 
 *      def classes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for classes:
 */
  __pyx_codeobj__241 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_classes, 2635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__241)) __PYX_ERR(2, 2635, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2650
 *         return GiacMethods['classes'](self,*args)
 * 
 *      def clear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clear:
 */
  __pyx_codeobj__242 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_clear, 2650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__242)) __PYX_ERR(2, 2650, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2661
 *         return GiacMethods['clear'](self,*args)
 * 
 *      def clique_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover:
 */
  __pyx_codeobj__243 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_clique_cover, 2661, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__243)) __PYX_ERR(2, 2661, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2674
 *         return GiacMethods['clique_cover'](self,*args)
 * 
 *      def clique_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover_number:
 */
  __pyx_codeobj__244 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_clique_cover_number, 2674, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__244)) __PYX_ERR(2, 2674, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2687
 *         return GiacMethods['clique_cover_number'](self,*args)
 * 
 *      def clique_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_number:
 */
  __pyx_codeobj__245 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_clique_number, 2687, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__245)) __PYX_ERR(2, 2687, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2698
 *         return GiacMethods['clique_number'](self,*args)
 * 
 *      def closeness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for closeness_centrality:
 */
  __pyx_codeobj__246 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_closeness_centrality, 2698, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__246)) __PYX_ERR(2, 2698, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2709
 *         return GiacMethods['closeness_centrality'](self,*args)
 * 
 *      def cluster(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cluster:
 */
  __pyx_codeobj__247 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cluster, 2709, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__247)) __PYX_ERR(2, 2709, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2720
 *         return GiacMethods['cluster'](self,*args)
 * 
 *      def clustering_coefficient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clustering_coefficient:
 */
  __pyx_codeobj__248 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_clustering_coefficient, 2720, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__248)) __PYX_ERR(2, 2720, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2732
 *         return GiacMethods['clustering_coefficient'](self,*args)
 * 
 *      def coeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeff:
 */
  __pyx_codeobj__249 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_coeff, 2732, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__249)) __PYX_ERR(2, 2732, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2745
 *         return GiacMethods['coeff'](self,*args)
 * 
 *      def coeffs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeffs:
 */
  __pyx_codeobj__250 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_coeffs, 2745, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__250)) __PYX_ERR(2, 2745, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2758
 *         return GiacMethods['coeffs'](self,*args)
 * 
 *      def col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for col:
 */
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_col, 2758, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(2, 2758, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2771
 *         return GiacMethods['col'](self,*args)
 * 
 *      def colDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colDim:
 */
  __pyx_codeobj__252 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colDim, 2771, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__252)) __PYX_ERR(2, 2771, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2783
 *         return GiacMethods['colDim'](self,*args)
 * 
 *      def colNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colNorm:
 */
  __pyx_codeobj__253 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colNorm, 2783, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__253)) __PYX_ERR(2, 2783, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2795
 *         return GiacMethods['colNorm'](self,*args)
 * 
 *      def colSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colSwap:
 */
  __pyx_codeobj__254 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colSwap, 2795, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__254)) __PYX_ERR(2, 2795, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2806
 *         return GiacMethods['colSwap'](self,*args)
 * 
 *      def coldim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coldim:
 */
  __pyx_codeobj__255 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_coldim, 2806, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__255)) __PYX_ERR(2, 2806, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2818
 *         return GiacMethods['coldim'](self,*args)
 * 
 *      def collect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for collect:
 */
  __pyx_codeobj__256 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_collect, 2818, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__256)) __PYX_ERR(2, 2818, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2831
 *         return GiacMethods['collect'](self,*args)
 * 
 *      def colnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colnorm:
 */
  __pyx_codeobj__257 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colnorm, 2831, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__257)) __PYX_ERR(2, 2831, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2843
 *         return GiacMethods['colnorm'](self,*args)
 * 
 *      def color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for color:
 */
  __pyx_codeobj__258 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_color, 2843, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__258)) __PYX_ERR(2, 2843, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2863
 *         return GiacMethods['color'](self,*args)
 * 
 *      def colormap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colormap:
 */
  __pyx_codeobj__259 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colormap, 2863, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__259)) __PYX_ERR(2, 2863, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2878
 *         return GiacMethods['colormap'](self,*args)
 * 
 *      def colspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colspace:
 */
  __pyx_codeobj__260 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colspace, 2878, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__260)) __PYX_ERR(2, 2878, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2890
 *         return GiacMethods['colspace'](self,*args)
 * 
 *      def colswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colswap:
 */
  __pyx_codeobj__261 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_colswap, 2890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__261)) __PYX_ERR(2, 2890, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2901
 *         return GiacMethods['colswap'](self,*args)
 * 
 *      def comDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comDenom:
 */
  __pyx_codeobj__262 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_comDenom, 2901, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__262)) __PYX_ERR(2, 2901, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2914
 *         return GiacMethods['comDenom'](self,*args)
 * 
 *      def comb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comb:
 */
  __pyx_codeobj__263 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_comb, 2914, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__263)) __PYX_ERR(2, 2914, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2925
 *         return GiacMethods['comb'](self,*args)
 * 
 *      def combine(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for combine:
 */
  __pyx_codeobj__264 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_combine, 2925, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__264)) __PYX_ERR(2, 2925, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2938
 *         return GiacMethods['combine'](self,*args)
 * 
 *      def comment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comment:
 */
  __pyx_codeobj__265 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_comment, 2938, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__265)) __PYX_ERR(2, 2938, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2949
 *         return GiacMethods['comment'](self,*args)
 * 
 *      def common_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for common_perpendicular:
 */
  __pyx_codeobj__266 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_common_perpendicular, 2949, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__266)) __PYX_ERR(2, 2949, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2960
 *         return GiacMethods['common_perpendicular'](self,*args)
 * 
 *      def companion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for companion:
 */
  __pyx_codeobj__267 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_companion, 2960, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__267)) __PYX_ERR(2, 2960, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2972
 *         return GiacMethods['companion'](self,*args)
 * 
 *      def compare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for compare:
 */
  __pyx_codeobj__268 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_compare, 2972, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__268)) __PYX_ERR(2, 2972, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2985
 *         return GiacMethods['compare'](self,*args)
 * 
 *      def complete_binary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_binary_tree:
 */
  __pyx_codeobj__269 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_complete_binary_tree, 2985, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__269)) __PYX_ERR(2, 2985, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":2996
 *         return GiacMethods['complete_binary_tree'](self,*args)
 * 
 *      def complete_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_graph:
 */
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_complete_graph, 2996, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(2, 2996, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3009
 *         return GiacMethods['complete_graph'](self,*args)
 * 
 *      def complete_kary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_kary_tree:
 */
  __pyx_codeobj__271 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_complete_kary_tree, 3009, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__271)) __PYX_ERR(2, 3009, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3020
 *         return GiacMethods['complete_kary_tree'](self,*args)
 * 
 *      def complex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex:
 */
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_complex, 3020, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(2, 3020, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3033
 *         return GiacMethods['complex'](self,*args)
 * 
 *      def complex_variables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex_variables:
 */
  __pyx_codeobj__273 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_complex_variables, 3033, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__273)) __PYX_ERR(2, 3033, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3045
 *         return GiacMethods['complex_variables'](self,*args)
 * 
 *      def complexroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complexroot:
 */
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_complexroot, 3045, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(2, 3045, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3059
 *         return GiacMethods['complexroot'](self,*args)
 * 
 *      def concat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for concat:
 */
  __pyx_codeobj__275 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_concat, 3059, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__275)) __PYX_ERR(2, 3059, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3074
 *         return GiacMethods['concat'](self,*args)
 * 
 *      def cond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cond:
 */
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cond, 3074, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(2, 3074, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3088
 *         return GiacMethods['cond'](self,*args)
 * 
 *      def condensation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for condensation:
 */
  __pyx_codeobj__277 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_condensation, 3088, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__277)) __PYX_ERR(2, 3088, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3099
 *         return GiacMethods['condensation'](self,*args)
 * 
 *      def cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cone:
 */
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cone, 3099, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(2, 3099, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3111
 *         return GiacMethods['cone'](self,*args)
 * 
 *      def confrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for confrac:
 */
  __pyx_codeobj__279 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_confrac, 3111, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__279)) __PYX_ERR(2, 3111, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3122
 *         return GiacMethods['confrac'](self,*args)
 * 
 *      def conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conic:
 */
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_conic, 3122, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(2, 3122, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3136
 *         return GiacMethods['conic'](self,*args)
 * 
 *      def conj(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conj:
 */
  __pyx_codeobj__281 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_conj, 3136, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__281)) __PYX_ERR(2, 3136, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3150
 *         return GiacMethods['conj'](self,*args)
 * 
 *      def conjugate_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_equation:
 */
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_conjugate_equation, 3150, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(2, 3150, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3161
 *         return GiacMethods['conjugate_equation'](self,*args)
 * 
 *      def conjugate_gradient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_gradient:
 */
  __pyx_codeobj__283 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_conjugate_gradient, 3161, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__283)) __PYX_ERR(2, 3161, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3175
 *         return GiacMethods['conjugate_gradient'](self,*args)
 * 
 *      def connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected:
 */
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_connected, 3175, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(2, 3175, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3185
 *         return GiacMethods['connected'](self,*args)
 * 
 *      def connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected_components:
 */
  __pyx_codeobj__285 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_connected_components, 3185, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__285)) __PYX_ERR(2, 3185, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3196
 *         return GiacMethods['connected_components'](self,*args)
 * 
 *      def cont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cont:
 */
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cont, 3196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(2, 3196, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3207
 *         return GiacMethods['cont'](self,*args)
 * 
 *      def contains(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contains:
 */
  __pyx_codeobj__287 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_contains, 3207, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__287)) __PYX_ERR(2, 3207, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3220
 *         return GiacMethods['contains'](self,*args)
 * 
 *      def content(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for content:
 */
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_content, 3220, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(2, 3220, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3233
 *         return GiacMethods['content'](self,*args)
 * 
 *      def contourplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contourplot:
 */
  __pyx_codeobj__289 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_contourplot, 3233, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__289)) __PYX_ERR(2, 3233, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3247
 *         return GiacMethods['contourplot'](self,*args)
 * 
 *      def contract_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_edge:
 */
  __pyx_codeobj__290 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_contract_edge, 3247, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__290)) __PYX_ERR(2, 3247, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3258
 *         return GiacMethods['contract_edge'](self,*args)
 * 
 *      def contract_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_subgraph:
 */
  __pyx_codeobj__291 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_contract_subgraph, 3258, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__291)) __PYX_ERR(2, 3258, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3269
 *         return GiacMethods['contract_subgraph'](self,*args)
 * 
 *      def convert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convert:
 */
  __pyx_codeobj__292 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_convert, 3269, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__292)) __PYX_ERR(2, 3269, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3296
 *         return GiacMethods['convert'](self,*args)
 * 
 *      def convertir(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convertir:
 */
  __pyx_codeobj__293 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_convertir, 3296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__293)) __PYX_ERR(2, 3296, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3323
 *         return GiacMethods['convertir'](self,*args)
 * 
 *      def convex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convex:
 */
  __pyx_codeobj__294 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_convex, 3323, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__294)) __PYX_ERR(2, 3323, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3338
 *         return GiacMethods['convex'](self,*args)
 * 
 *      def convexhull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convexhull:
 */
  __pyx_codeobj__295 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_convexhull, 3338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__295)) __PYX_ERR(2, 3338, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3351
 *         return GiacMethods['convexhull'](self,*args)
 * 
 *      def convolution(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convolution:
 */
  __pyx_codeobj__296 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_convolution, 3351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__296)) __PYX_ERR(2, 3351, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3363
 *         return GiacMethods['convolution'](self,*args)
 * 
 *      def coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coordinates:
 */
  __pyx_codeobj__297 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_coordinates, 3363, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__297)) __PYX_ERR(2, 3363, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3381
 *         return GiacMethods['coordinates'](self,*args)
 * 
 *      def copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for copy:
 */
  __pyx_codeobj__298 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_copy, 3381, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__298)) __PYX_ERR(2, 3381, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3392
 *         return GiacMethods['copy'](self,*args)
 * 
 *      def correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for correlation:
 */
  __pyx_codeobj__299 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_correlation, 3392, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__299)) __PYX_ERR(2, 3392, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3403
 *         return GiacMethods['correlation'](self,*args)
 * 
 *      def cos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos:
 */
  __pyx_codeobj__300 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cos, 3403, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__300)) __PYX_ERR(2, 3403, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3415
 *         return GiacMethods['cos'](self,*args)
 * 
 *      def cos2sintan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos2sintan:
 */
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cos2sintan, 3415, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(2, 3415, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3426
 *         return GiacMethods['cos2sintan'](self,*args)
 * 
 *      def cosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosh:
 */
  __pyx_codeobj__302 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cosh, 3426, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__302)) __PYX_ERR(2, 3426, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3437
 *         return GiacMethods['cosh'](self,*args)
 * 
 *      def cosine_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosine_window:
 */
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cosine_window, 3437, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(2, 3437, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3448
 *         return GiacMethods['cosine_window'](self,*args)
 * 
 *      def cot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cot:
 */
  __pyx_codeobj__304 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cot, 3448, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__304)) __PYX_ERR(2, 3448, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3459
 *         return GiacMethods['cot'](self,*args)
 * 
 *      def cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cote:
 */
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cote, 3459, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(2, 3459, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3471
 *         return GiacMethods['cote'](self,*args)
 * 
 *      def count(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count:
 */
  __pyx_codeobj__306 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_count, 3471, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__306)) __PYX_ERR(2, 3471, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3491
 *         return GiacMethods['count'](self,*args)
 * 
 *      def count_eq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_eq:
 */
  __pyx_codeobj__307 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_count_eq, 3491, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__307)) __PYX_ERR(2, 3491, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3505
 *         return GiacMethods['count_eq'](self,*args)
 * 
 *      def count_inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_inf:
 */
  __pyx_codeobj__308 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_count_inf, 3505, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__308)) __PYX_ERR(2, 3505, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3519
 *         return GiacMethods['count_inf'](self,*args)
 * 
 *      def count_sup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_sup:
 */
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_count_sup, 3519, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(2, 3519, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3533
 *         return GiacMethods['count_sup'](self,*args)
 * 
 *      def courbe_parametrique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_parametrique:
 */
  __pyx_codeobj__310 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_courbe_parametrique, 3533, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__310)) __PYX_ERR(2, 3533, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3551
 *         return GiacMethods['courbe_parametrique'](self,*args)
 * 
 *      def courbe_polaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_polaire:
 */
  __pyx_codeobj__311 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_courbe_polaire, 3551, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__311)) __PYX_ERR(2, 3551, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3563
 *         return GiacMethods['courbe_polaire'](self,*args)
 * 
 *      def covariance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance:
 */
  __pyx_codeobj__312 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_covariance, 3563, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__312)) __PYX_ERR(2, 3563, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3574
 *         return GiacMethods['covariance'](self,*args)
 * 
 *      def covariance_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance_correlation:
 */
  __pyx_codeobj__313 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_covariance_correlation, 3574, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__313)) __PYX_ERR(2, 3574, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3585
 *         return GiacMethods['covariance_correlation'](self,*args)
 * 
 *      def cpartfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cpartfrac:
 */
  __pyx_codeobj__314 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cpartfrac, 3585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__314)) __PYX_ERR(2, 3585, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3598
 *         return GiacMethods['cpartfrac'](self,*args)
 * 
 *      def crationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crationalroot:
 */
  __pyx_codeobj__315 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_crationalroot, 3598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__315)) __PYX_ERR(2, 3598, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3609
 *         return GiacMethods['crationalroot'](self,*args)
 * 
 *      def crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crayon:
 */
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_crayon, 3609, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(2, 3609, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3623
 *         return GiacMethods['crayon'](self,*args)
 * 
 *      def createwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for createwav:
 */
  __pyx_codeobj__317 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_createwav, 3623, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__317)) __PYX_ERR(2, 3623, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3638
 *         return GiacMethods['createwav'](self,*args)
 * 
 *      def cross(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross:
 */
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cross, 3638, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(2, 3638, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3650
 *         return GiacMethods['cross'](self,*args)
 * 
 *      def crossP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossP:
 */
  __pyx_codeobj__319 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_crossP, 3650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__319)) __PYX_ERR(2, 3650, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3662
 *         return GiacMethods['crossP'](self,*args)
 * 
 *      def cross_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_correlation:
 */
  __pyx_codeobj__320 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cross_correlation, 3662, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__320)) __PYX_ERR(2, 3662, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3673
 *         return GiacMethods['cross_correlation'](self,*args)
 * 
 *      def cross_entropy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_entropy:
 */
  __pyx_codeobj__321 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cross_entropy, 3673, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__321)) __PYX_ERR(2, 3673, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3683
 *         return GiacMethods['cross_entropy'](self,*args)
 * 
 *      def cross_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_point:
 */
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cross_point, 3683, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(2, 3683, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3695
 *         return GiacMethods['cross_point'](self,*args)
 * 
 *      def cross_ratio(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_ratio:
 */
  __pyx_codeobj__323 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cross_ratio, 3695, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__323)) __PYX_ERR(2, 3695, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3708
 *         return GiacMethods['cross_ratio'](self,*args)
 * 
 *      def crossproduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossproduct:
 */
  __pyx_codeobj__324 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_crossproduct, 3708, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__324)) __PYX_ERR(2, 3708, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3720
 *         return GiacMethods['crossproduct'](self,*args)
 * 
 *      def csc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csc:
 */
  __pyx_codeobj__325 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_csc, 3720, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__325)) __PYX_ERR(2, 3720, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3731
 *         return GiacMethods['csc'](self,*args)
 * 
 *      def csolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csolve:
 */
  __pyx_codeobj__326 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_csolve, 3731, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__326)) __PYX_ERR(2, 3731, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3745
 *         return GiacMethods['csolve'](self,*args)
 * 
 *      def csv2gen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csv2gen:
 */
  __pyx_codeobj__327 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_csv2gen, 3745, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__327)) __PYX_ERR(2, 3745, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3756
 *         return GiacMethods['csv2gen'](self,*args)
 * 
 *      def cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cube:
 */
  __pyx_codeobj__328 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cube, 3756, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__328)) __PYX_ERR(2, 3756, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3771
 *         return GiacMethods['cube'](self,*args)
 * 
 *      def cumSum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumSum:
 */
  __pyx_codeobj__329 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cumSum, 3771, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__329)) __PYX_ERR(2, 3771, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3784
 *         return GiacMethods['cumSum'](self,*args)
 * 
 *      def cumsum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumsum:
 */
  __pyx_codeobj__330 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cumsum, 3784, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__330)) __PYX_ERR(2, 3784, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3797
 *         return GiacMethods['cumsum'](self,*args)
 * 
 *      def cumulated_frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumulated_frequencies:
 */
  __pyx_codeobj__331 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cumulated_frequencies, 3797, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__331)) __PYX_ERR(2, 3797, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3812
 *         return GiacMethods['cumulated_frequencies'](self,*args)
 * 
 *      def curl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curl:
 */
  __pyx_codeobj__332 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_curl, 3812, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__332)) __PYX_ERR(2, 3812, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3823
 *         return GiacMethods['curl'](self,*args)
 * 
 *      def current_sheet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for current_sheet:
 */
  __pyx_codeobj__333 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_current_sheet, 3823, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__333)) __PYX_ERR(2, 3823, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3834
 *         return GiacMethods['current_sheet'](self,*args)
 * 
 *      def curvature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curvature:
 */
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_curvature, 3834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(2, 3834, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3851
 *         return GiacMethods['curvature'](self,*args)
 * 
 *      def curve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curve:
 */
  __pyx_codeobj__335 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_curve, 3851, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__335)) __PYX_ERR(2, 3851, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3861
 *         return GiacMethods['curve'](self,*args)
 * 
 *      def cyan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyan:
 */
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cyan, 3861, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(2, 3861, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3873
 *         return GiacMethods['cyan'](self,*args)
 * 
 *      def cycle2perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle2perm:
 */
  __pyx_codeobj__337 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cycle2perm, 3873, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__337)) __PYX_ERR(2, 3873, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3884
 *         return GiacMethods['cycle2perm'](self,*args)
 * 
 *      def cycle_basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_basis:
 */
  __pyx_codeobj__338 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cycle_basis, 3884, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__338)) __PYX_ERR(2, 3884, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3895
 *         return GiacMethods['cycle_basis'](self,*args)
 * 
 *      def cycle_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_graph:
 */
  __pyx_codeobj__339 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cycle_graph, 3895, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__339)) __PYX_ERR(2, 3895, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3907
 *         return GiacMethods['cycle_graph'](self,*args)
 * 
 *      def cycleinv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycleinv:
 */
  __pyx_codeobj__340 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cycleinv, 3907, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__340)) __PYX_ERR(2, 3907, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3918
 *         return GiacMethods['cycleinv'](self,*args)
 * 
 *      def cycles2permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycles2permu:
 */
  __pyx_codeobj__341 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cycles2permu, 3918, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__341)) __PYX_ERR(2, 3918, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3929
 *         return GiacMethods['cycles2permu'](self,*args)
 * 
 *      def cyclotomic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyclotomic:
 */
  __pyx_codeobj__342 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cyclotomic, 3929, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__342)) __PYX_ERR(2, 3929, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3940
 *         return GiacMethods['cyclotomic'](self,*args)
 * 
 *      def cylinder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cylinder:
 */
  __pyx_codeobj__343 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_cylinder, 3940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__343)) __PYX_ERR(2, 3940, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3952
 *         return GiacMethods['cylinder'](self,*args)
 * 
 *      def dash_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dash_line:
 */
  __pyx_codeobj__344 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dash_line, 3952, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__344)) __PYX_ERR(2, 3952, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3964
 *         return GiacMethods['dash_line'](self,*args)
 * 
 *      def dashdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdot_line:
 */
  __pyx_codeobj__345 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dashdot_line, 3964, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__345)) __PYX_ERR(2, 3964, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3976
 *         return GiacMethods['dashdot_line'](self,*args)
 * 
 *      def dashdotdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdotdot_line:
 */
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dashdotdot_line, 3976, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(2, 3976, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3988
 *         return GiacMethods['dashdotdot_line'](self,*args)
 * 
 *      def dayofweek(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dayofweek:
 */
  __pyx_codeobj__347 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dayofweek, 3988, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__347)) __PYX_ERR(2, 3988, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":3999
 *         return GiacMethods['dayofweek'](self,*args)
 * 
 *      def deSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deSolve:
 */
  __pyx_codeobj__348 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_deSolve, 3999, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__348)) __PYX_ERR(2, 3999, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4025
 *         return GiacMethods['deSolve'](self,*args)
 * 
 *      def debut_enregistrement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for debut_enregistrement:
 */
  __pyx_codeobj__349 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_debut_enregistrement, 4025, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__349)) __PYX_ERR(2, 4025, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4037
 *         return GiacMethods['debut_enregistrement'](self,*args)
 * 
 *      def degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree:
 */
  __pyx_codeobj__350 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_degree, 4037, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__350)) __PYX_ERR(2, 4037, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4050
 *         return GiacMethods['degree'](self,*args)
 * 
 *      def degree_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_centrality:
 */
  __pyx_codeobj__351 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_degree_centrality, 4050, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__351)) __PYX_ERR(2, 4050, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4061
 *         return GiacMethods['degree_centrality'](self,*args)
 * 
 *      def degree_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_sequence:
 */
  __pyx_codeobj__352 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_degree_sequence, 4061, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__352)) __PYX_ERR(2, 4061, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4072
 *         return GiacMethods['degree_sequence'](self,*args)
 * 
 *      def degrees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degrees:
 */
  __pyx_codeobj__353 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_degrees, 4072, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__353)) __PYX_ERR(2, 4072, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4082
 *         return GiacMethods['degrees'](self,*args)
 * 
 *      def delcols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delcols:
 */
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_delcols, 4082, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(2, 4082, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4095
 *         return GiacMethods['delcols'](self,*args)
 * 
 *      def delete_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_arc:
 */
  __pyx_codeobj__355 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_delete_arc, 4095, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__355)) __PYX_ERR(2, 4095, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4106
 *         return GiacMethods['delete_arc'](self,*args)
 * 
 *      def delete_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_edge:
 */
  __pyx_codeobj__356 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_delete_edge, 4106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__356)) __PYX_ERR(2, 4106, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4117
 *         return GiacMethods['delete_edge'](self,*args)
 * 
 *      def delete_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_vertex:
 */
  __pyx_codeobj__357 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_delete_vertex, 4117, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__357)) __PYX_ERR(2, 4117, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4128
 *         return GiacMethods['delete_vertex'](self,*args)
 * 
 *      def delrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delrows:
 */
  __pyx_codeobj__358 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_delrows, 4128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__358)) __PYX_ERR(2, 4128, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4141
 *         return GiacMethods['delrows'](self,*args)
 * 
 *      def deltalist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deltalist:
 */
  __pyx_codeobj__359 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_deltalist, 4141, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__359)) __PYX_ERR(2, 4141, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4153
 *         return GiacMethods['deltalist'](self,*args)
 * 
 *      def denom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for denom:
 */
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_denom, 4153, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(2, 4153, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4166
 *         return GiacMethods['denom'](self,*args)
 * 
 *      def densityplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for densityplot:
 */
  __pyx_codeobj__361 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_densityplot, 4166, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__361)) __PYX_ERR(2, 4166, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4178
 *         return GiacMethods['densityplot'](self,*args)
 * 
 *      def departures(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for departures:
 */
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_departures, 4178, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(2, 4178, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4189
 *         return GiacMethods['departures'](self,*args)
 * 
 *      def derive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for derive:
 */
  __pyx_codeobj__363 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_derive, 4189, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__363)) __PYX_ERR(2, 4189, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4207
 *         return GiacMethods['derive'](self,*args)
 * 
 *      def deriver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deriver:
 */
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_deriver, 4207, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(2, 4207, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4225
 *         return GiacMethods['deriver'](self,*args)
 * 
 *      def desolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for desolve:
 */
  __pyx_codeobj__365 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_desolve, 4225, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__365)) __PYX_ERR(2, 4225, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4251
 *         return GiacMethods['desolve'](self,*args)
 * 
 *      def dessine_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dessine_tortue:
 */
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dessine_tortue, 4251, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(2, 4251, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4264
 *         return GiacMethods['dessine_tortue'](self,*args)
 * 
 *      def det(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det:
 */
  __pyx_codeobj__367 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_det, 4264, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__367)) __PYX_ERR(2, 4264, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4276
 *         return GiacMethods['det'](self,*args)
 * 
 *      def det_minor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det_minor:
 */
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_det_minor, 4276, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(2, 4276, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4287
 *         return GiacMethods['det_minor'](self,*args)
 * 
 *      def developper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper:
 */
  __pyx_codeobj__369 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_developper, 4287, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__369)) __PYX_ERR(2, 4287, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4302
 *         return GiacMethods['developper'](self,*args)
 * 
 *      def developper_transcendant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper_transcendant:
 */
  __pyx_codeobj__370 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_developper_transcendant, 4302, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__370)) __PYX_ERR(2, 4302, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4315
 *         return GiacMethods['developper_transcendant'](self,*args)
 * 
 *      def dfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc:
 */
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dfc, 4315, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(2, 4315, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4330
 *         return GiacMethods['dfc'](self,*args)
 * 
 *      def dfc2f(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc2f:
 */
  __pyx_codeobj__372 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dfc2f, 4330, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__372)) __PYX_ERR(2, 4330, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4342
 *         return GiacMethods['dfc2f'](self,*args)
 * 
 *      def diag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diag:
 */
  __pyx_codeobj__373 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_diag, 4342, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__373)) __PYX_ERR(2, 4342, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4358
 *         return GiacMethods['diag'](self,*args)
 * 
 *      def diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diff:
 */
  __pyx_codeobj__374 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_diff, 4358, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__374)) __PYX_ERR(2, 4358, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4376
 *         return GiacMethods['diff'](self,*args)
 * 
 *      def digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for digraph:
 */
  __pyx_codeobj__375 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_digraph, 4376, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__375)) __PYX_ERR(2, 4376, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4388
 *         return GiacMethods['digraph'](self,*args)
 * 
 *      def dijkstra(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dijkstra:
 */
  __pyx_codeobj__376 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dijkstra, 4388, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__376)) __PYX_ERR(2, 4388, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4399
 *         return GiacMethods['dijkstra'](self,*args)
 * 
 *      def dim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dim:
 */
  __pyx_codeobj__377 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dim, 4399, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__377)) __PYX_ERR(2, 4399, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4410
 *         return GiacMethods['dim'](self,*args)
 * 
 *      def directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for directed:
 */
  __pyx_codeobj__378 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_directed, 4410, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__378)) __PYX_ERR(2, 4410, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4420
 *         return GiacMethods['directed'](self,*args)
 * 
 *      def discard_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_edge_attribute:
 */
  __pyx_codeobj__379 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_discard_edge_attribute, 4420, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__379)) __PYX_ERR(2, 4420, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4431
 *         return GiacMethods['discard_edge_attribute'](self,*args)
 * 
 *      def discard_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_graph_attribute:
 */
  __pyx_codeobj__380 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_discard_graph_attribute, 4431, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__380)) __PYX_ERR(2, 4431, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4442
 *         return GiacMethods['discard_graph_attribute'](self,*args)
 * 
 *      def discard_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_vertex_attribute:
 */
  __pyx_codeobj__381 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_discard_vertex_attribute, 4442, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__381)) __PYX_ERR(2, 4442, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4453
 *         return GiacMethods['discard_vertex_attribute'](self,*args)
 * 
 *      def disjoint_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disjoint_union:
 */
  __pyx_codeobj__382 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_disjoint_union, 4453, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__382)) __PYX_ERR(2, 4453, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4464
 *         return GiacMethods['disjoint_union'](self,*args)
 * 
 *      def display(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for display:
 */
  __pyx_codeobj__383 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_display, 4464, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__383)) __PYX_ERR(2, 4464, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4484
 *         return GiacMethods['display'](self,*args)
 * 
 *      def disque(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque:
 */
  __pyx_codeobj__384 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_disque, 4484, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__384)) __PYX_ERR(2, 4484, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4498
 *         return GiacMethods['disque'](self,*args)
 * 
 *      def disque_centre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque_centre:
 */
  __pyx_codeobj__385 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_disque_centre, 4498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__385)) __PYX_ERR(2, 4498, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4512
 *         return GiacMethods['disque_centre'](self,*args)
 * 
 *      def distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance:
 */
  __pyx_codeobj__386 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_distance, 4512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__386)) __PYX_ERR(2, 4512, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4525
 *         return GiacMethods['distance'](self,*args)
 * 
 *      def distance2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance2:
 */
  __pyx_codeobj__387 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_distance2, 4525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__387)) __PYX_ERR(2, 4525, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4538
 *         return GiacMethods['distance2'](self,*args)
 * 
 *      def distanceat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceat:
 */
  __pyx_codeobj__388 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_distanceat, 4538, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__388)) __PYX_ERR(2, 4538, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4550
 *         return GiacMethods['distanceat'](self,*args)
 * 
 *      def distanceatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceatraw:
 */
  __pyx_codeobj__389 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_distanceatraw, 4550, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__389)) __PYX_ERR(2, 4550, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4562
 *         return GiacMethods['distanceatraw'](self,*args)
 * 
 *      def divergence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divergence:
 */
  __pyx_codeobj__390 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_divergence, 4562, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__390)) __PYX_ERR(2, 4562, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4573
 *         return GiacMethods['divergence'](self,*args)
 * 
 *      def divide(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divide:
 */
  __pyx_codeobj__391 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_divide, 4573, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__391)) __PYX_ERR(2, 4573, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4587
 *         return GiacMethods['divide'](self,*args)
 * 
 *      def divis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divis:
 */
  __pyx_codeobj__392 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_divis, 4587, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__392)) __PYX_ERR(2, 4587, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4603
 *         return GiacMethods['divis'](self,*args)
 * 
 *      def division_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for division_point:
 */
  __pyx_codeobj__393 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_division_point, 4603, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__393)) __PYX_ERR(2, 4603, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4615
 *         return GiacMethods['division_point'](self,*args)
 * 
 *      def divisors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divisors:
 */
  __pyx_codeobj__394 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_divisors, 4615, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__394)) __PYX_ERR(2, 4615, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4627
 *         return GiacMethods['divisors'](self,*args)
 * 
 *      def divmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divmod:
 */
  __pyx_codeobj__395 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_divmod, 4627, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__395)) __PYX_ERR(2, 4627, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4640
 *         return GiacMethods['divmod'](self,*args)
 * 
 *      def divpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divpc:
 */
  __pyx_codeobj__396 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_divpc, 4640, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__396)) __PYX_ERR(2, 4640, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4651
 *         return GiacMethods['divpc'](self,*args)
 * 
 *      def dnewton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dnewton_solver:
 */
  __pyx_codeobj__397 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dnewton_solver, 4651, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__397)) __PYX_ERR(2, 4651, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4667
 *         return GiacMethods['dnewton_solver'](self,*args)
 * 
 *      def dodecahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dodecahedron:
 */
  __pyx_codeobj__398 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dodecahedron, 4667, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__398)) __PYX_ERR(2, 4667, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4679
 *         return GiacMethods['dodecahedron'](self,*args)
 * 
 *      def domain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for domain:
 */
  __pyx_codeobj__399 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_domain, 4679, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__399)) __PYX_ERR(2, 4679, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4690
 *         return GiacMethods['domain'](self,*args)
 * 
 *      def dot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot:
 */
  __pyx_codeobj__400 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dot, 4690, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__400)) __PYX_ERR(2, 4690, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4703
 *         return GiacMethods['dot'](self,*args)
 * 
 *      def dotP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotP:
 */
  __pyx_codeobj__401 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dotP, 4703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__401)) __PYX_ERR(2, 4703, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4716
 *         return GiacMethods['dotP'](self,*args)
 * 
 *      def dot_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot_paper:
 */
  __pyx_codeobj__402 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dot_paper, 4716, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__402)) __PYX_ERR(2, 4716, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4728
 *         return GiacMethods['dot_paper'](self,*args)
 * 
 *      def dotprod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotprod:
 */
  __pyx_codeobj__403 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dotprod, 4728, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__403)) __PYX_ERR(2, 4728, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4741
 *         return GiacMethods['dotprod'](self,*args)
 * 
 *      def draw_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_arc:
 */
  __pyx_codeobj__404 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_arc, 4741, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__404)) __PYX_ERR(2, 4741, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4752
 *         return GiacMethods['draw_arc'](self,*args)
 * 
 *      def draw_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_circle:
 */
  __pyx_codeobj__405 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_circle, 4752, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__405)) __PYX_ERR(2, 4752, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4764
 *         return GiacMethods['draw_circle'](self,*args)
 * 
 *      def draw_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_graph:
 */
  __pyx_codeobj__406 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_graph, 4764, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__406)) __PYX_ERR(2, 4764, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4779
 *         return GiacMethods['draw_graph'](self,*args)
 * 
 *      def draw_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_line:
 */
  __pyx_codeobj__407 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_line, 4779, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__407)) __PYX_ERR(2, 4779, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4790
 *         return GiacMethods['draw_line'](self,*args)
 * 
 *      def draw_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_pixel:
 */
  __pyx_codeobj__408 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_pixel, 4790, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__408)) __PYX_ERR(2, 4790, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4801
 *         return GiacMethods['draw_pixel'](self,*args)
 * 
 *      def draw_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_polygon:
 */
  __pyx_codeobj__409 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_polygon, 4801, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__409)) __PYX_ERR(2, 4801, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4813
 *         return GiacMethods['draw_polygon'](self,*args)
 * 
 *      def draw_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_rectangle:
 */
  __pyx_codeobj__410 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_draw_rectangle, 4813, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__410)) __PYX_ERR(2, 4813, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4825
 *         return GiacMethods['draw_rectangle'](self,*args)
 * 
 *      def droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droit:
 */
  __pyx_codeobj__411 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_droit, 4825, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__411)) __PYX_ERR(2, 4825, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4839
 *         return GiacMethods['droit'](self,*args)
 * 
 *      def droite_tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droite_tangente:
 */
  __pyx_codeobj__412 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_droite_tangente, 4839, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__412)) __PYX_ERR(2, 4839, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4853
 *         return GiacMethods['droite_tangente'](self,*args)
 * 
 *      def dsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dsolve:
 */
  __pyx_codeobj__413 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dsolve, 4853, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__413)) __PYX_ERR(2, 4853, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4879
 *         return GiacMethods['dsolve'](self,*args)
 * 
 *      def duration(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for duration:
 */
  __pyx_codeobj__414 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_duration, 4879, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__414)) __PYX_ERR(2, 4879, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4890
 *         return GiacMethods['duration'](self,*args)
 * 
 *      def dwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dwt:
 */
  __pyx_codeobj__415 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_dwt, 4890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__415)) __PYX_ERR(2, 4890, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4902
 *         return GiacMethods['dwt'](self,*args)
 * 
 *      def e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e:
 */
  __pyx_codeobj__416 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_e, 4902, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__416)) __PYX_ERR(2, 4902, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4913
 *         return GiacMethods['e'](self,*args)
 * 
 *      def e2r(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e2r:
 */
  __pyx_codeobj__417 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_e2r, 4913, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__417)) __PYX_ERR(2, 4913, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4929
 *         return GiacMethods['e2r'](self,*args)
 * 
 *      def ecart_type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type:
 */
  __pyx_codeobj__418 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ecart_type, 4929, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__418)) __PYX_ERR(2, 4929, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4942
 *         return GiacMethods['ecart_type'](self,*args)
 * 
 *      def ecart_type_population(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type_population:
 */
  __pyx_codeobj__419 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ecart_type_population, 4942, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__419)) __PYX_ERR(2, 4942, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4955
 *         return GiacMethods['ecart_type_population'](self,*args)
 * 
 *      def ecef2geodetic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecef2geodetic:
 */
  __pyx_codeobj__420 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ecef2geodetic, 4955, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__420)) __PYX_ERR(2, 4955, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4966
 *         return GiacMethods['ecef2geodetic'](self,*args)
 * 
 *      def ecm_factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecm_factor:
 */
  __pyx_codeobj__421 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ecm_factor, 4966, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__421)) __PYX_ERR(2, 4966, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4976
 *         return GiacMethods['ecm_factor'](self,*args)
 * 
 *      def edge_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edge_connectivity:
 */
  __pyx_codeobj__422 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_edge_connectivity, 4976, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__422)) __PYX_ERR(2, 4976, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":4989
 *         return GiacMethods['edge_connectivity'](self,*args)
 * 
 *      def edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edges:
 */
  __pyx_codeobj__423 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_edges, 4989, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__423)) __PYX_ERR(2, 4989, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5000
 *         return GiacMethods['edges'](self,*args)
 * 
 *      def egcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egcd:
 */
  __pyx_codeobj__424 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_egcd, 5000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__424)) __PYX_ERR(2, 5000, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5014
 *         return GiacMethods['egcd'](self,*args)
 * 
 *      def egv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egv:
 */
  __pyx_codeobj__425 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_egv, 5014, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__425)) __PYX_ERR(2, 5014, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5026
 *         return GiacMethods['egv'](self,*args)
 * 
 *      def egvl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egvl:
 */
  __pyx_codeobj__426 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_egvl, 5026, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__426)) __PYX_ERR(2, 5026, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5039
 *         return GiacMethods['egvl'](self,*args)
 * 
 *      def eigVc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVc:
 */
  __pyx_codeobj__427 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eigVc, 5039, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__427)) __PYX_ERR(2, 5039, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5051
 *         return GiacMethods['eigVc'](self,*args)
 * 
 *      def eigVl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVl:
 */
  __pyx_codeobj__428 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eigVl, 5051, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__428)) __PYX_ERR(2, 5051, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5064
 *         return GiacMethods['eigVl'](self,*args)
 * 
 *      def eigenvals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvals:
 */
  __pyx_codeobj__429 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eigenvals, 5064, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__429)) __PYX_ERR(2, 5064, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5077
 *         return GiacMethods['eigenvals'](self,*args)
 * 
 *      def eigenvalues(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvalues:
 */
  __pyx_codeobj__430 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eigenvalues, 5077, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__430)) __PYX_ERR(2, 5077, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5090
 *         return GiacMethods['eigenvalues'](self,*args)
 * 
 *      def eigenvectors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvectors:
 */
  __pyx_codeobj__431 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eigenvectors, 5090, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__431)) __PYX_ERR(2, 5090, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5102
 *         return GiacMethods['eigenvectors'](self,*args)
 * 
 *      def eigenvects(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvects:
 */
  __pyx_codeobj__432 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eigenvects, 5102, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__432)) __PYX_ERR(2, 5102, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5114
 *         return GiacMethods['eigenvects'](self,*args)
 * 
 *      def element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for element:
 */
  __pyx_codeobj__433 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_element, 5114, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__433)) __PYX_ERR(2, 5114, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5130
 *         return GiacMethods['element'](self,*args)
 * 
 *      def eliminate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eliminate:
 */
  __pyx_codeobj__434 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eliminate, 5130, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__434)) __PYX_ERR(2, 5130, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5141
 *         return GiacMethods['eliminate'](self,*args)
 * 
 *      def ellipse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ellipse:
 */
  __pyx_codeobj__435 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ellipse, 5141, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__435)) __PYX_ERR(2, 5141, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5156
 *         return GiacMethods['ellipse'](self,*args)
 * 
 *      def emd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for emd:
 */
  __pyx_codeobj__436 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_emd, 5156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__436)) __PYX_ERR(2, 5156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5167
 *         return GiacMethods['emd'](self,*args)
 * 
 *      def entry(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for entry:
 */
  __pyx_codeobj__437 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_entry, 5167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__437)) __PYX_ERR(2, 5167, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5180
 *         return GiacMethods['entry'](self,*args)
 * 
 *      def envelope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for envelope:
 */
  __pyx_codeobj__438 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_envelope, 5180, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__438)) __PYX_ERR(2, 5180, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5192
 *         return GiacMethods['envelope'](self,*args)
 * 
 *      def epsilon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon:
 */
  __pyx_codeobj__439 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_epsilon, 5192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__439)) __PYX_ERR(2, 5192, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5203
 *         return GiacMethods['epsilon'](self,*args)
 * 
 *      def epsilon2zero(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon2zero:
 */
  __pyx_codeobj__440 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_epsilon2zero, 5203, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__440)) __PYX_ERR(2, 5203, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5214
 *         return GiacMethods['epsilon2zero'](self,*args)
 * 
 *      def equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal:
 */
  __pyx_codeobj__441 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_equal, 5214, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__441)) __PYX_ERR(2, 5214, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5227
 *         return GiacMethods['equal'](self,*args)
 * 
 *      def equal2diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2diff:
 */
  __pyx_codeobj__442 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_equal2diff, 5227, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__442)) __PYX_ERR(2, 5227, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5239
 *         return GiacMethods['equal2diff'](self,*args)
 * 
 *      def equal2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2list:
 */
  __pyx_codeobj__443 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_equal2list, 5239, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__443)) __PYX_ERR(2, 5239, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5251
 *         return GiacMethods['equal2list'](self,*args)
 * 
 *      def equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equation:
 */
  __pyx_codeobj__444 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_equation, 5251, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__444)) __PYX_ERR(2, 5251, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5262
 *         return GiacMethods['equation'](self,*args)
 * 
 *      def equilateral_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equilateral_triangle:
 */
  __pyx_codeobj__445 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_equilateral_triangle, 5262, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__445)) __PYX_ERR(2, 5262, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5276
 *         return GiacMethods['equilateral_triangle'](self,*args)
 * 
 *      def erf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erf:
 */
  __pyx_codeobj__446 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_erf, 5276, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__446)) __PYX_ERR(2, 5276, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5288
 *         return GiacMethods['erf'](self,*args)
 * 
 *      def erfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erfc:
 */
  __pyx_codeobj__447 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_erfc, 5288, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__447)) __PYX_ERR(2, 5288, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5300
 *         return GiacMethods['erfc'](self,*args)
 * 
 *      def error(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for error:
 */
  __pyx_codeobj__448 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_error, 5300, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__448)) __PYX_ERR(2, 5300, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5312
 *         return GiacMethods['error'](self,*args)
 * 
 *      def est_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for est_permu:
 */
  __pyx_codeobj__449 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_est_permu, 5312, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__449)) __PYX_ERR(2, 5312, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5324
 *         return GiacMethods['est_permu'](self,*args)
 * 
 *      def euler(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler:
 */
  __pyx_codeobj__450 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_euler, 5324, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__450)) __PYX_ERR(2, 5324, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5336
 *         return GiacMethods['euler'](self,*args)
 * 
 *      def euler_gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_gamma:
 */
  __pyx_codeobj__451 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_euler_gamma, 5336, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__451)) __PYX_ERR(2, 5336, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5346
 *         return GiacMethods['euler_gamma'](self,*args)
 * 
 *      def euler_lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_lagrange:
 */
  __pyx_codeobj__452 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_euler_lagrange, 5346, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__452)) __PYX_ERR(2, 5346, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5359
 *         return GiacMethods['euler_lagrange'](self,*args)
 * 
 *      def eval_level(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eval_level:
 */
  __pyx_codeobj__453 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_eval_level, 5359, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__453)) __PYX_ERR(2, 5359, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5373
 *         return GiacMethods['eval_level'](self,*args)
 * 
 *      def evala(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evala:
 */
  __pyx_codeobj__454 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_evala, 5373, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__454)) __PYX_ERR(2, 5373, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5386
 *         return GiacMethods['evala'](self,*args)
 * 
 *      def evalb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalb:
 */
  __pyx_codeobj__455 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_evalb, 5386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__455)) __PYX_ERR(2, 5386, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5398
 *         return GiacMethods['evalb'](self,*args)
 * 
 *      def evalc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalc:
 */
  __pyx_codeobj__456 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_evalc, 5398, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__456)) __PYX_ERR(2, 5398, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5410
 *         return GiacMethods['evalc'](self,*args)
 * 
 *      def evalf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalf:
 */
  __pyx_codeobj__457 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_evalf, 5410, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__457)) __PYX_ERR(2, 5410, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5426
 *         return GiacMethods['evalf'](self,*args)
 * 
 *      def evalm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalm:
 */
  __pyx_codeobj__458 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_evalm, 5426, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__458)) __PYX_ERR(2, 5426, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5437
 *         return GiacMethods['evalm'](self,*args)
 * 
 *      def even(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for even:
 */
  __pyx_codeobj__459 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_even, 5437, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__459)) __PYX_ERR(2, 5437, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5449
 *         return GiacMethods['even'](self,*args)
 * 
 *      def evolute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evolute:
 */
  __pyx_codeobj__460 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_evolute, 5449, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__460)) __PYX_ERR(2, 5449, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5462
 *         return GiacMethods['evolute'](self,*args)
 * 
 *      def exact(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exact:
 */
  __pyx_codeobj__461 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exact, 5462, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__461)) __PYX_ERR(2, 5462, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5476
 *         return GiacMethods['exact'](self,*args)
 * 
 *      def exbisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exbisector:
 */
  __pyx_codeobj__462 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exbisector, 5476, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__462)) __PYX_ERR(2, 5476, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5487
 *         return GiacMethods['exbisector'](self,*args)
 * 
 *      def excircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for excircle:
 */
  __pyx_codeobj__463 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_excircle, 5487, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__463)) __PYX_ERR(2, 5487, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5498
 *         return GiacMethods['excircle'](self,*args)
 * 
 *      def execute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for execute:
 */
  __pyx_codeobj__464 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_execute, 5498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__464)) __PYX_ERR(2, 5498, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5512
 *         return GiacMethods['execute'](self,*args)
 * 
 *      def exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp:
 */
  __pyx_codeobj__465 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exp, 5512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__465)) __PYX_ERR(2, 5512, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5524
 *         return GiacMethods['exp'](self,*args)
 * 
 *      def exp2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2list:
 */
  __pyx_codeobj__466 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exp2list, 5524, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__466)) __PYX_ERR(2, 5524, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5536
 *         return GiacMethods['exp2list'](self,*args)
 * 
 *      def exp2pow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2pow:
 */
  __pyx_codeobj__467 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exp2pow, 5536, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__467)) __PYX_ERR(2, 5536, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5548
 *         return GiacMethods['exp2pow'](self,*args)
 * 
 *      def exp2trig(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2trig:
 */
  __pyx_codeobj__468 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exp2trig, 5548, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__468)) __PYX_ERR(2, 5548, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5560
 *         return GiacMethods['exp2trig'](self,*args)
 * 
 *      def expand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expand:
 */
  __pyx_codeobj__469 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_expand, 5560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__469)) __PYX_ERR(2, 5560, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5575
 *         return GiacMethods['expand'](self,*args)
 * 
 *      def expexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expexpand:
 */
  __pyx_codeobj__470 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_expexpand, 5575, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__470)) __PYX_ERR(2, 5575, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5586
 *         return GiacMethods['expexpand'](self,*args)
 * 
 *      def expln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expln:
 */
  __pyx_codeobj__471 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_expln, 5586, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__471)) __PYX_ERR(2, 5586, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5597
 *         return GiacMethods['expln'](self,*args)
 * 
 *      def exponential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential:
 */
  __pyx_codeobj__472 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponential, 5597, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__472)) __PYX_ERR(2, 5597, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5611
 *         return GiacMethods['exponential'](self,*args)
 * 
 *      def exponential_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_cdf:
 */
  __pyx_codeobj__473 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponential_cdf, 5611, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__473)) __PYX_ERR(2, 5611, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5623
 *         return GiacMethods['exponential_cdf'](self,*args)
 * 
 *      def exponential_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_icdf:
 */
  __pyx_codeobj__474 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponential_icdf, 5623, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__474)) __PYX_ERR(2, 5623, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5635
 *         return GiacMethods['exponential_icdf'](self,*args)
 * 
 *      def exponential_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression:
 */
  __pyx_codeobj__475 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponential_regression, 5635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__475)) __PYX_ERR(2, 5635, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5647
 *         return GiacMethods['exponential_regression'](self,*args)
 * 
 *      def exponential_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression_plot:
 */
  __pyx_codeobj__476 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponential_regression_plot, 5647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__476)) __PYX_ERR(2, 5647, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5659
 *         return GiacMethods['exponential_regression_plot'](self,*args)
 * 
 *      def exponentiald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald:
 */
  __pyx_codeobj__477 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponentiald, 5659, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__477)) __PYX_ERR(2, 5659, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5673
 *         return GiacMethods['exponentiald'](self,*args)
 * 
 *      def exponentiald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_cdf:
 */
  __pyx_codeobj__478 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponentiald_cdf, 5673, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__478)) __PYX_ERR(2, 5673, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5685
 *         return GiacMethods['exponentiald_cdf'](self,*args)
 * 
 *      def exponentiald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_icdf:
 */
  __pyx_codeobj__479 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_exponentiald_icdf, 5685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__479)) __PYX_ERR(2, 5685, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5697
 *         return GiacMethods['exponentiald_icdf'](self,*args)
 * 
 *      def export_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_graph:
 */
  __pyx_codeobj__480 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_export_graph, 5697, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__480)) __PYX_ERR(2, 5697, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5708
 *         return GiacMethods['export_graph'](self,*args)
 * 
 *      def export_mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_mathml:
 */
  __pyx_codeobj__481 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_export_mathml, 5708, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__481)) __PYX_ERR(2, 5708, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5721
 *         return GiacMethods['export_mathml'](self,*args)
 * 
 *      def expovariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expovariate:
 */
  __pyx_codeobj__482 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_expovariate, 5721, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__482)) __PYX_ERR(2, 5721, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5733
 *         return GiacMethods['expovariate'](self,*args)
 * 
 *      def expr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expr:
 */
  __pyx_codeobj__483 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_expr, 5733, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__483)) __PYX_ERR(2, 5733, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5747
 *         return GiacMethods['expr'](self,*args)
 * 
 *      def extend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extend:
 */
  __pyx_codeobj__484 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_extend, 5747, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__484)) __PYX_ERR(2, 5747, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5762
 *         return GiacMethods['extend'](self,*args)
 * 
 *      def extract_measure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extract_measure:
 */
  __pyx_codeobj__485 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_extract_measure, 5762, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__485)) __PYX_ERR(2, 5762, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5775
 *         return GiacMethods['extract_measure'](self,*args)
 * 
 *      def extrema(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extrema:
 */
  __pyx_codeobj__486 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_extrema, 5775, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__486)) __PYX_ERR(2, 5775, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5791
 *         return GiacMethods['extrema'](self,*args)
 * 
 *      def ezgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ezgcd:
 */
  __pyx_codeobj__487 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ezgcd, 5791, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__487)) __PYX_ERR(2, 5791, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5804
 *         return GiacMethods['ezgcd'](self,*args)
 * 
 *      def f2nd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for f2nd:
 */
  __pyx_codeobj__488 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_f2nd, 5804, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__488)) __PYX_ERR(2, 5804, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5816
 *         return GiacMethods['f2nd'](self,*args)
 * 
 *      def fMax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMax:
 */
  __pyx_codeobj__489 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fMax, 5816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__489)) __PYX_ERR(2, 5816, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5828
 *         return GiacMethods['fMax'](self,*args)
 * 
 *      def fMin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMin:
 */
  __pyx_codeobj__490 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fMin, 5828, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__490)) __PYX_ERR(2, 5828, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5842
 *         return GiacMethods['fMin'](self,*args)
 * 
 *      def fPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fPart:
 */
  __pyx_codeobj__491 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fPart, 5842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__491)) __PYX_ERR(2, 5842, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5857
 *         return GiacMethods['fPart'](self,*args)
 * 
 *      def faces(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for faces:
 */
  __pyx_codeobj__492 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_faces, 5857, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__492)) __PYX_ERR(2, 5857, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5869
 *         return GiacMethods['faces'](self,*args)
 * 
 *      def facteurs_premiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for facteurs_premiers:
 */
  __pyx_codeobj__493 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_facteurs_premiers, 5869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__493)) __PYX_ERR(2, 5869, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5881
 *         return GiacMethods['facteurs_premiers'](self,*args)
 * 
 *      def factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor:
 */
  __pyx_codeobj__494 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factor, 5881, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__494)) __PYX_ERR(2, 5881, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5894
 *         return GiacMethods['factor'](self,*args)
 * 
 *      def factor_xn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor_xn:
 */
  __pyx_codeobj__495 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factor_xn, 5894, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__495)) __PYX_ERR(2, 5894, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5906
 *         return GiacMethods['factor_xn'](self,*args)
 * 
 *      def factorial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factorial:
 */
  __pyx_codeobj__496 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factorial, 5906, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__496)) __PYX_ERR(2, 5906, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5918
 *         return GiacMethods['factorial'](self,*args)
 * 
 *      def factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser:
 */
  __pyx_codeobj__497 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factoriser, 5918, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__497)) __PYX_ERR(2, 5918, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5931
 *         return GiacMethods['factoriser'](self,*args)
 * 
 *      def factoriser_entier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_entier:
 */
  __pyx_codeobj__498 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factoriser_entier, 5931, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__498)) __PYX_ERR(2, 5931, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5943
 *         return GiacMethods['factoriser_entier'](self,*args)
 * 
 *      def factoriser_sur_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_sur_C:
 */
  __pyx_codeobj__499 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factoriser_sur_C, 5943, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__499)) __PYX_ERR(2, 5943, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5956
 *         return GiacMethods['factoriser_sur_C'](self,*args)
 * 
 *      def factors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factors:
 */
  __pyx_codeobj__500 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_factors, 5956, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__500)) __PYX_ERR(2, 5956, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5968
 *         return GiacMethods['factors'](self,*args)
 * 
 *      def fadeev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fadeev:
 */
  __pyx_codeobj__501 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fadeev, 5968, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__501)) __PYX_ERR(2, 5968, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5979
 *         return GiacMethods['fadeev'](self,*args)
 * 
 *      def false(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for false:
 */
  __pyx_codeobj__502 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_false, 5979, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__502)) __PYX_ERR(2, 5979, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":5990
 *         return GiacMethods['false'](self,*args)
 * 
 *      def falsepos_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for falsepos_solver:
 */
  __pyx_codeobj__503 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_falsepos_solver, 5990, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__503)) __PYX_ERR(2, 5990, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6006
 *         return GiacMethods['falsepos_solver'](self,*args)
 * 
 *      def fclose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fclose:
 */
  __pyx_codeobj__504 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fclose, 6006, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__504)) __PYX_ERR(2, 6006, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6017
 *         return GiacMethods['fclose'](self,*args)
 * 
 *      def fcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fcoeff:
 */
  __pyx_codeobj__505 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fcoeff, 6017, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__505)) __PYX_ERR(2, 6017, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6028
 *         return GiacMethods['fcoeff'](self,*args)
 * 
 *      def fdistrib(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fdistrib:
 */
  __pyx_codeobj__506 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fdistrib, 6028, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__506)) __PYX_ERR(2, 6028, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6043
 *         return GiacMethods['fdistrib'](self,*args)
 * 
 *      def fft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fft:
 */
  __pyx_codeobj__507 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fft, 6043, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__507)) __PYX_ERR(2, 6043, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6055
 *         return GiacMethods['fft'](self,*args)
 * 
 *      def fieldplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fieldplot:
 */
  __pyx_codeobj__508 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fieldplot, 6055, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__508)) __PYX_ERR(2, 6055, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6070
 *         return GiacMethods['fieldplot'](self,*args)
 * 
 *      def find(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find:
 */
  __pyx_codeobj__509 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_find, 6070, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__509)) __PYX_ERR(2, 6070, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6085
 *         return GiacMethods['find'](self,*args)
 * 
 *      def find_cliques(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cliques:
 */
  __pyx_codeobj__510 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_find_cliques, 6085, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__510)) __PYX_ERR(2, 6085, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6098
 *         return GiacMethods['find_cliques'](self,*args)
 * 
 *      def find_cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cycles:
 */
  __pyx_codeobj__511 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_find_cycles, 6098, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__511)) __PYX_ERR(2, 6098, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6111
 *         return GiacMethods['find_cycles'](self,*args)
 * 
 *      def find_minimum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_minimum:
 */
  __pyx_codeobj__512 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_find_minimum, 6111, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__512)) __PYX_ERR(2, 6111, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6125
 *         return GiacMethods['find_minimum'](self,*args)
 * 
 *      def find_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_vertex_cover:
 */
  __pyx_codeobj__513 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_find_vertex_cover, 6125, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__513)) __PYX_ERR(2, 6125, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6137
 *         return GiacMethods['find_vertex_cover'](self,*args)
 * 
 *      def findhelp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for findhelp:
 */
  __pyx_codeobj__514 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_findhelp, 6137, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__514)) __PYX_ERR(2, 6137, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6148
 *         return GiacMethods['findhelp'](self,*args)
 * 
 *      def fisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher:
 */
  __pyx_codeobj__515 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fisher, 6148, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__515)) __PYX_ERR(2, 6148, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6162
 *         return GiacMethods['fisher'](self,*args)
 * 
 *      def fisher_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_cdf:
 */
  __pyx_codeobj__516 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fisher_cdf, 6162, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__516)) __PYX_ERR(2, 6162, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6174
 *         return GiacMethods['fisher_cdf'](self,*args)
 * 
 *      def fisher_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_icdf:
 */
  __pyx_codeobj__517 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fisher_icdf, 6174, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__517)) __PYX_ERR(2, 6174, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6186
 *         return GiacMethods['fisher_icdf'](self,*args)
 * 
 *      def fisherd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd:
 */
  __pyx_codeobj__518 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fisherd, 6186, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__518)) __PYX_ERR(2, 6186, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6200
 *         return GiacMethods['fisherd'](self,*args)
 * 
 *      def fisherd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_cdf:
 */
  __pyx_codeobj__519 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fisherd_cdf, 6200, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__519)) __PYX_ERR(2, 6200, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6212
 *         return GiacMethods['fisherd_cdf'](self,*args)
 * 
 *      def fisherd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_icdf:
 */
  __pyx_codeobj__520 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fisherd_icdf, 6212, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__520)) __PYX_ERR(2, 6212, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6224
 *         return GiacMethods['fisherd_icdf'](self,*args)
 * 
 *      def fitdistr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitdistr:
 */
  __pyx_codeobj__521 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fitdistr, 6224, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__521)) __PYX_ERR(2, 6224, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6237
 *         return GiacMethods['fitdistr'](self,*args)
 * 
 *      def fitpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitpoly:
 */
  __pyx_codeobj__522 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fitpoly, 6237, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__522)) __PYX_ERR(2, 6237, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6249
 *         return GiacMethods['fitpoly'](self,*args)
 * 
 *      def fitspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitspline:
 */
  __pyx_codeobj__523 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fitspline, 6249, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__523)) __PYX_ERR(2, 6249, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6260
 *         return GiacMethods['fitspline'](self,*args)
 * 
 *      def flatten(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flatten:
 */
  __pyx_codeobj__524 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_flatten, 6260, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__524)) __PYX_ERR(2, 6260, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6271
 *         return GiacMethods['flatten'](self,*args)
 * 
 *      def float2rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for float2rational:
 */
  __pyx_codeobj__525 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_float2rational, 6271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__525)) __PYX_ERR(2, 6271, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6285
 *         return GiacMethods['float2rational'](self,*args)
 * 
 *      def floor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for floor:
 */
  __pyx_codeobj__526 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_floor, 6285, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__526)) __PYX_ERR(2, 6285, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6297
 *         return GiacMethods['floor'](self,*args)
 * 
 *      def flow_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flow_polynomial:
 */
  __pyx_codeobj__527 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_flow_polynomial, 6297, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__527)) __PYX_ERR(2, 6297, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6309
 *         return GiacMethods['flow_polynomial'](self,*args)
 * 
 *      def flower_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flower_snark:
 */
  __pyx_codeobj__528 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_flower_snark, 6309, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__528)) __PYX_ERR(2, 6309, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6320
 *         return GiacMethods['flower_snark'](self,*args)
 * 
 *      def fmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fmod:
 */
  __pyx_codeobj__529 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fmod, 6320, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__529)) __PYX_ERR(2, 6320, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6331
 *         return GiacMethods['fmod'](self,*args)
 * 
 *      def foldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldl:
 */
  __pyx_codeobj__530 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_foldl, 6331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__530)) __PYX_ERR(2, 6331, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6342
 *         return GiacMethods['foldl'](self,*args)
 * 
 *      def foldr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldr:
 */
  __pyx_codeobj__531 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_foldr, 6342, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__531)) __PYX_ERR(2, 6342, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6353
 *         return GiacMethods['foldr'](self,*args)
 * 
 *      def fonction_derivee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fonction_derivee:
 */
  __pyx_codeobj__532 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fonction_derivee, 6353, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__532)) __PYX_ERR(2, 6353, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6368
 *         return GiacMethods['fonction_derivee'](self,*args)
 * 
 *      def forward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for forward:
 */
  __pyx_codeobj__533 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_forward, 6368, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__533)) __PYX_ERR(2, 6368, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6380
 *         return GiacMethods['forward'](self,*args)
 * 
 *      def fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier:
 */
  __pyx_codeobj__534 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fourier, 6380, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__534)) __PYX_ERR(2, 6380, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6397
 *         return GiacMethods['fourier'](self,*args)
 * 
 *      def fourier_an(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_an:
 */
  __pyx_codeobj__535 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fourier_an, 6397, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__535)) __PYX_ERR(2, 6397, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6409
 *         return GiacMethods['fourier_an'](self,*args)
 * 
 *      def fourier_bn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_bn:
 */
  __pyx_codeobj__536 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fourier_bn, 6409, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__536)) __PYX_ERR(2, 6409, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6421
 *         return GiacMethods['fourier_bn'](self,*args)
 * 
 *      def fourier_cn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_cn:
 */
  __pyx_codeobj__537 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fourier_cn, 6421, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__537)) __PYX_ERR(2, 6421, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6433
 *         return GiacMethods['fourier_cn'](self,*args)
 * 
 *      def fprint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fprint:
 */
  __pyx_codeobj__538 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fprint, 6433, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__538)) __PYX_ERR(2, 6433, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6446
 *         return GiacMethods['fprint'](self,*args)
 * 
 *      def frac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frac:
 */
  __pyx_codeobj__539 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_frac, 6446, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__539)) __PYX_ERR(2, 6446, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6461
 *         return GiacMethods['frac'](self,*args)
 * 
 *      def fracmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fracmod:
 */
  __pyx_codeobj__540 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fracmod, 6461, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__540)) __PYX_ERR(2, 6461, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6472
 *         return GiacMethods['fracmod'](self,*args)
 * 
 *      def frame_2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frame_2d:
 */
  __pyx_codeobj__541 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_frame_2d, 6472, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__541)) __PYX_ERR(2, 6472, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6483
 *         return GiacMethods['frame_2d'](self,*args)
 * 
 *      def frank_wolfe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frank_wolfe:
 */
  __pyx_codeobj__542 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_frank_wolfe, 6483, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__542)) __PYX_ERR(2, 6483, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6494
 *         return GiacMethods['frank_wolfe'](self,*args)
 * 
 *      def frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frequencies:
 */
  __pyx_codeobj__543 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_frequencies, 6494, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__543)) __PYX_ERR(2, 6494, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6506
 *         return GiacMethods['frequencies'](self,*args)
 * 
 *      def frobenius_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frobenius_norm:
 */
  __pyx_codeobj__544 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_frobenius_norm, 6506, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__544)) __PYX_ERR(2, 6506, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6517
 *         return GiacMethods['frobenius_norm'](self,*args)
 * 
 *      def froot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for froot:
 */
  __pyx_codeobj__545 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_froot, 6517, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__545)) __PYX_ERR(2, 6517, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6529
 *         return GiacMethods['froot'](self,*args)
 * 
 *      def fsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fsolve:
 */
  __pyx_codeobj__546 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fsolve, 6529, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__546)) __PYX_ERR(2, 6529, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6543
 *         return GiacMethods['fsolve'](self,*args)
 * 
 *      def fullparfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fullparfrac:
 */
  __pyx_codeobj__547 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fullparfrac, 6543, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__547)) __PYX_ERR(2, 6543, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6555
 *         return GiacMethods['fullparfrac'](self,*args)
 * 
 *      def funcplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for funcplot:
 */
  __pyx_codeobj__548 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_funcplot, 6555, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__548)) __PYX_ERR(2, 6555, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6570
 *         return GiacMethods['funcplot'](self,*args)
 * 
 *      def function_diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for function_diff:
 */
  __pyx_codeobj__549 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_function_diff, 6570, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__549)) __PYX_ERR(2, 6570, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6585
 *         return GiacMethods['function_diff'](self,*args)
 * 
 *      def fundamental_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fundamental_cycle:
 */
  __pyx_codeobj__550 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fundamental_cycle, 6585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__550)) __PYX_ERR(2, 6585, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6596
 *         return GiacMethods['fundamental_cycle'](self,*args)
 * 
 *      def fxnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fxnd:
 */
  __pyx_codeobj__551 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_fxnd, 6596, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__551)) __PYX_ERR(2, 6596, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6608
 *         return GiacMethods['fxnd'](self,*args)
 * 
 *      def gammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad:
 */
  __pyx_codeobj__552 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gammad, 6608, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__552)) __PYX_ERR(2, 6608, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6619
 *         return GiacMethods['gammad'](self,*args)
 * 
 *      def gammad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_cdf:
 */
  __pyx_codeobj__553 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gammad_cdf, 6619, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__553)) __PYX_ERR(2, 6619, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6631
 *         return GiacMethods['gammad_cdf'](self,*args)
 * 
 *      def gammad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_icdf:
 */
  __pyx_codeobj__554 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gammad_icdf, 6631, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__554)) __PYX_ERR(2, 6631, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6643
 *         return GiacMethods['gammad_icdf'](self,*args)
 * 
 *      def gammavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammavariate:
 */
  __pyx_codeobj__555 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gammavariate, 6643, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__555)) __PYX_ERR(2, 6643, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6655
 *         return GiacMethods['gammavariate'](self,*args)
 * 
 *      def gauss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss:
 */
  __pyx_codeobj__556 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gauss, 6655, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__556)) __PYX_ERR(2, 6655, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6666
 *         return GiacMethods['gauss'](self,*args)
 * 
 *      def gauss15(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss15:
 */
  __pyx_codeobj__557 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gauss15, 6666, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__557)) __PYX_ERR(2, 6666, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6680
 *         return GiacMethods['gauss15'](self,*args)
 * 
 *      def gauss_seidel_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss_seidel_linsolve:
 */
  __pyx_codeobj__558 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gauss_seidel_linsolve, 6680, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__558)) __PYX_ERR(2, 6680, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6694
 *         return GiacMethods['gauss_seidel_linsolve'](self,*args)
 * 
 *      def gaussian_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussian_window:
 */
  __pyx_codeobj__559 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gaussian_window, 6694, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__559)) __PYX_ERR(2, 6694, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6705
 *         return GiacMethods['gaussian_window'](self,*args)
 * 
 *      def gaussjord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussjord:
 */
  __pyx_codeobj__560 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gaussjord, 6705, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__560)) __PYX_ERR(2, 6705, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6719
 *         return GiacMethods['gaussjord'](self,*args)
 * 
 *      def gaussquad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussquad:
 */
  __pyx_codeobj__561 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gaussquad, 6719, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__561)) __PYX_ERR(2, 6719, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6732
 *         return GiacMethods['gaussquad'](self,*args)
 * 
 *      def gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis:
 */
  __pyx_codeobj__562 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gbasis, 6732, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__562)) __PYX_ERR(2, 6732, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6748
 *         return GiacMethods['gbasis'](self,*args)
 * 
 *      def gbasis_max_pairs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_max_pairs:
 */
  __pyx_codeobj__563 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gbasis_max_pairs, 6748, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__563)) __PYX_ERR(2, 6748, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6760
 *         return GiacMethods['gbasis_max_pairs'](self,*args)
 * 
 *      def gbasis_reinject(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_reinject:
 */
  __pyx_codeobj__564 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gbasis_reinject, 6760, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__564)) __PYX_ERR(2, 6760, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6772
 *         return GiacMethods['gbasis_reinject'](self,*args)
 * 
 *      def gbasis_simult_primes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_simult_primes:
 */
  __pyx_codeobj__565 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gbasis_simult_primes, 6772, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__565)) __PYX_ERR(2, 6772, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6783
 *         return GiacMethods['gbasis_simult_primes'](self,*args)
 * 
 *      def gcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcd:
 */
  __pyx_codeobj__566 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gcd, 6783, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__566)) __PYX_ERR(2, 6783, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6798
 *         return GiacMethods['gcd'](self,*args)
 * 
 *      def gcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcdex:
 */
  __pyx_codeobj__567 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gcdex, 6798, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__567)) __PYX_ERR(2, 6798, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6812
 *         return GiacMethods['gcdex'](self,*args)
 * 
 *      def genpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for genpoly:
 */
  __pyx_codeobj__568 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_genpoly, 6812, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__568)) __PYX_ERR(2, 6812, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6825
 *         return GiacMethods['genpoly'](self,*args)
 * 
 *      def geodetic2ecef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geodetic2ecef:
 */
  __pyx_codeobj__569 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_geodetic2ecef, 6825, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__569)) __PYX_ERR(2, 6825, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6836
 *         return GiacMethods['geodetic2ecef'](self,*args)
 * 
 *      def geometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric:
 */
  __pyx_codeobj__570 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_geometric, 6836, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__570)) __PYX_ERR(2, 6836, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6850
 *         return GiacMethods['geometric'](self,*args)
 * 
 *      def geometric_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_cdf:
 */
  __pyx_codeobj__571 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_geometric_cdf, 6850, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__571)) __PYX_ERR(2, 6850, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6862
 *         return GiacMethods['geometric_cdf'](self,*args)
 * 
 *      def geometric_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_icdf:
 */
  __pyx_codeobj__572 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_geometric_icdf, 6862, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__572)) __PYX_ERR(2, 6862, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6873
 *         return GiacMethods['geometric_icdf'](self,*args)
 * 
 *      def getDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getDenom:
 */
  __pyx_codeobj__573 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_getDenom, 6873, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__573)) __PYX_ERR(2, 6873, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6886
 *         return GiacMethods['getDenom'](self,*args)
 * 
 *      def getKey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getKey:
 */
  __pyx_codeobj__574 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_getKey, 6886, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__574)) __PYX_ERR(2, 6886, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6897
 *         return GiacMethods['getKey'](self,*args)
 * 
 *      def getNum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getNum:
 */
  __pyx_codeobj__575 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_getNum, 6897, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__575)) __PYX_ERR(2, 6897, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6910
 *         return GiacMethods['getNum'](self,*args)
 * 
 *      def getType(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getType:
 */
  __pyx_codeobj__576 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_getType, 6910, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__576)) __PYX_ERR(2, 6910, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6924
 *         return GiacMethods['getType'](self,*args)
 * 
 *      def get_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_attribute:
 */
  __pyx_codeobj__577 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_get_edge_attribute, 6924, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__577)) __PYX_ERR(2, 6924, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6935
 *         return GiacMethods['get_edge_attribute'](self,*args)
 * 
 *      def get_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_weight:
 */
  __pyx_codeobj__578 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_get_edge_weight, 6935, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__578)) __PYX_ERR(2, 6935, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6946
 *         return GiacMethods['get_edge_weight'](self,*args)
 * 
 *      def get_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_graph_attribute:
 */
  __pyx_codeobj__579 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_get_graph_attribute, 6946, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__579)) __PYX_ERR(2, 6946, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6957
 *         return GiacMethods['get_graph_attribute'](self,*args)
 * 
 *      def get_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_vertex_attribute:
 */
  __pyx_codeobj__580 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_get_vertex_attribute, 6957, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__580)) __PYX_ERR(2, 6957, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6968
 *         return GiacMethods['get_vertex_attribute'](self,*args)
 * 
 *      def girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for girth:
 */
  __pyx_codeobj__581 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_girth, 6968, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__581)) __PYX_ERR(2, 6968, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6980
 *         return GiacMethods['girth'](self,*args)
 * 
 *      def gl_showaxes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gl_showaxes:
 */
  __pyx_codeobj__582 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gl_showaxes, 6980, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__582)) __PYX_ERR(2, 6980, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":6992
 *         return GiacMethods['gl_showaxes'](self,*args)
 * 
 *      def gold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gold:
 */
  __pyx_codeobj__583 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gold, 6992, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__583)) __PYX_ERR(2, 6992, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7004
 *         return GiacMethods['gold'](self,*args)
 * 
 *      def goldberg_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for goldberg_snark:
 */
  __pyx_codeobj__584 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_goldberg_snark, 7004, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__584)) __PYX_ERR(2, 7004, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7015
 *         return GiacMethods['goldberg_snark'](self,*args)
 * 
 *      def grad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grad:
 */
  __pyx_codeobj__585 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_grad, 7015, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__585)) __PYX_ERR(2, 7015, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7026
 *         return GiacMethods['grad'](self,*args)
 * 
 *      def gramschmidt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gramschmidt:
 */
  __pyx_codeobj__586 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_gramschmidt, 7026, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__586)) __PYX_ERR(2, 7026, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7038
 *         return GiacMethods['gramschmidt'](self,*args)
 * 
 *      def graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph:
 */
  __pyx_codeobj__587 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph, 7038, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__587)) __PYX_ERR(2, 7038, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7055
 *         return GiacMethods['graph'](self,*args)
 * 
 *      def graph_automorphisms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_automorphisms:
 */
  __pyx_codeobj__588 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_automorphisms, 7055, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__588)) __PYX_ERR(2, 7055, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7066
 *         return GiacMethods['graph_automorphisms'](self,*args)
 * 
 *      def graph_charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_charpoly:
 */
  __pyx_codeobj__589 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_charpoly, 7066, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__589)) __PYX_ERR(2, 7066, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7078
 *         return GiacMethods['graph_charpoly'](self,*args)
 * 
 *      def graph_complement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_complement:
 */
  __pyx_codeobj__590 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_complement, 7078, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__590)) __PYX_ERR(2, 7078, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7089
 *         return GiacMethods['graph_complement'](self,*args)
 * 
 *      def graph_diameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_diameter:
 */
  __pyx_codeobj__591 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_diameter, 7089, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__591)) __PYX_ERR(2, 7089, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7100
 *         return GiacMethods['graph_diameter'](self,*args)
 * 
 *      def graph_equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_equal:
 */
  __pyx_codeobj__592 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_equal, 7100, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__592)) __PYX_ERR(2, 7100, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7111
 *         return GiacMethods['graph_equal'](self,*args)
 * 
 *      def graph_join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_join:
 */
  __pyx_codeobj__593 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_join, 7111, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__593)) __PYX_ERR(2, 7111, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7122
 *         return GiacMethods['graph_join'](self,*args)
 * 
 *      def graph_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_power:
 */
  __pyx_codeobj__594 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_power, 7122, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__594)) __PYX_ERR(2, 7122, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7133
 *         return GiacMethods['graph_power'](self,*args)
 * 
 *      def graph_rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_rank:
 */
  __pyx_codeobj__595 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_rank, 7133, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__595)) __PYX_ERR(2, 7133, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7145
 *         return GiacMethods['graph_rank'](self,*args)
 * 
 *      def graph_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_spectrum:
 */
  __pyx_codeobj__596 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_spectrum, 7145, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__596)) __PYX_ERR(2, 7145, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7156
 *         return GiacMethods['graph_spectrum'](self,*args)
 * 
 *      def graph_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_union:
 */
  __pyx_codeobj__597 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_union, 7156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__597)) __PYX_ERR(2, 7156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7167
 *         return GiacMethods['graph_union'](self,*args)
 * 
 *      def graph_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_vertices:
 */
  __pyx_codeobj__598 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_graph_vertices, 7167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__598)) __PYX_ERR(2, 7167, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7178
 *         return GiacMethods['graph_vertices'](self,*args)
 * 
 *      def greduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greduce:
 */
  __pyx_codeobj__599 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_greduce, 7178, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__599)) __PYX_ERR(2, 7178, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7192
 *         return GiacMethods['greduce'](self,*args)
 * 
 *      def greedy_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_clique:
 */
  __pyx_codeobj__600 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_greedy_clique, 7192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__600)) __PYX_ERR(2, 7192, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7203
 *         return GiacMethods['greedy_clique'](self,*args)
 * 
 *      def greedy_color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_color:
 */
  __pyx_codeobj__601 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_greedy_color, 7203, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__601)) __PYX_ERR(2, 7203, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7214
 *         return GiacMethods['greedy_color'](self,*args)
 * 
 *      def greedy_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_independent_set:
 */
  __pyx_codeobj__602 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_greedy_independent_set, 7214, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__602)) __PYX_ERR(2, 7214, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7225
 *         return GiacMethods['greedy_independent_set'](self,*args)
 * 
 *      def grey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grey:
 */
  __pyx_codeobj__603 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_grey, 7225, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__603)) __PYX_ERR(2, 7225, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7237
 *         return GiacMethods['grey'](self,*args)
 * 
 *      def grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grid_graph:
 */
  __pyx_codeobj__604 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_grid_graph, 7237, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__604)) __PYX_ERR(2, 7237, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7248
 *         return GiacMethods['grid_graph'](self,*args)
 * 
 *      def groupermu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for groupermu:
 */
  __pyx_codeobj__605 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_groupermu, 7248, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__605)) __PYX_ERR(2, 7248, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7259
 *         return GiacMethods['groupermu'](self,*args)
 * 
 *      def haar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for haar_graph:
 */
  __pyx_codeobj__606 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_haar_graph, 7259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__606)) __PYX_ERR(2, 7259, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7271
 *         return GiacMethods['haar_graph'](self,*args)
 * 
 *      def hadamard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hadamard:
 */
  __pyx_codeobj__607 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hadamard, 7271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__607)) __PYX_ERR(2, 7271, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7283
 *         return GiacMethods['hadamard'](self,*args)
 * 
 *      def half_cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_cone:
 */
  __pyx_codeobj__608 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_half_cone, 7283, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__608)) __PYX_ERR(2, 7283, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7295
 *         return GiacMethods['half_cone'](self,*args)
 * 
 *      def half_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_line:
 */
  __pyx_codeobj__609 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_half_line, 7295, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__609)) __PYX_ERR(2, 7295, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7307
 *         return GiacMethods['half_line'](self,*args)
 * 
 *      def halftan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan:
 */
  __pyx_codeobj__610 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_halftan, 7307, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__610)) __PYX_ERR(2, 7307, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7319
 *         return GiacMethods['halftan'](self,*args)
 * 
 *      def halftan_hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan_hyp2exp:
 */
  __pyx_codeobj__611 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_halftan_hyp2exp, 7319, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__611)) __PYX_ERR(2, 7319, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7330
 *         return GiacMethods['halftan_hyp2exp'](self,*args)
 * 
 *      def halt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halt:
 */
  __pyx_codeobj__612 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_halt, 7330, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__612)) __PYX_ERR(2, 7330, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7341
 *         return GiacMethods['halt'](self,*args)
 * 
 *      def hamdist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamdist:
 */
  __pyx_codeobj__613 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hamdist, 7341, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__613)) __PYX_ERR(2, 7341, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7351
 *         return GiacMethods['hamdist'](self,*args)
 * 
 *      def hamming(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming:
 */
  __pyx_codeobj__614 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hamming, 7351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__614)) __PYX_ERR(2, 7351, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7362
 *         return GiacMethods['hamming'](self,*args)
 * 
 *      def hamming_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming_window:
 */
  __pyx_codeobj__615 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hamming_window, 7362, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__615)) __PYX_ERR(2, 7362, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7373
 *         return GiacMethods['hamming_window'](self,*args)
 * 
 *      def hann_poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_poisson_window:
 */
  __pyx_codeobj__616 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hann_poisson_window, 7373, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__616)) __PYX_ERR(2, 7373, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7384
 *         return GiacMethods['hann_poisson_window'](self,*args)
 * 
 *      def hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_window:
 */
  __pyx_codeobj__617 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hann_window, 7384, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__617)) __PYX_ERR(2, 7384, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7395
 *         return GiacMethods['hann_window'](self,*args)
 * 
 *      def harmonic_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_centrality:
 */
  __pyx_codeobj__618 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_harmonic_centrality, 7395, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__618)) __PYX_ERR(2, 7395, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7406
 *         return GiacMethods['harmonic_centrality'](self,*args)
 * 
 *      def harmonic_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_conjugate:
 */
  __pyx_codeobj__619 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_harmonic_conjugate, 7406, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__619)) __PYX_ERR(2, 7406, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7420
 *         return GiacMethods['harmonic_conjugate'](self,*args)
 * 
 *      def harmonic_division(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_division:
 */
  __pyx_codeobj__620 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_harmonic_division, 7420, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__620)) __PYX_ERR(2, 7420, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7434
 *         return GiacMethods['harmonic_division'](self,*args)
 * 
 *      def has(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has:
 */
  __pyx_codeobj__621 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_has, 7434, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__621)) __PYX_ERR(2, 7434, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7446
 *         return GiacMethods['has'](self,*args)
 * 
 *      def has_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_arc:
 */
  __pyx_codeobj__622 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_has_arc, 7446, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__622)) __PYX_ERR(2, 7446, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7458
 *         return GiacMethods['has_arc'](self,*args)
 * 
 *      def has_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_edge:
 */
  __pyx_codeobj__623 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_has_edge, 7458, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__623)) __PYX_ERR(2, 7458, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7469
 *         return GiacMethods['has_edge'](self,*args)
 * 
 *      def hasard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hasard:
 */
  __pyx_codeobj__624 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hasard, 7469, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__624)) __PYX_ERR(2, 7469, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7486
 *         return GiacMethods['hasard'](self,*args)
 * 
 *      def head(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for head:
 */
  __pyx_codeobj__625 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_head, 7486, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__625)) __PYX_ERR(2, 7486, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7499
 *         return GiacMethods['head'](self,*args)
 * 
 *      def heading(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heading:
 */
  __pyx_codeobj__626 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_heading, 7499, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__626)) __PYX_ERR(2, 7499, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7512
 *         return GiacMethods['heading'](self,*args)
 * 
 *      def heapify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heapify:
 */
  __pyx_codeobj__627 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_heapify, 7512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__627)) __PYX_ERR(2, 7512, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7522
 *         return GiacMethods['heapify'](self,*args)
 * 
 *      def heappop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappop:
 */
  __pyx_codeobj__628 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_heappop, 7522, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__628)) __PYX_ERR(2, 7522, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7532
 *         return GiacMethods['heappop'](self,*args)
 * 
 *      def heappush(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappush:
 */
  __pyx_codeobj__629 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_heappush, 7532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__629)) __PYX_ERR(2, 7532, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7542
 *         return GiacMethods['heappush'](self,*args)
 * 
 *      def hermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hermite:
 */
  __pyx_codeobj__630 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hermite, 7542, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__630)) __PYX_ERR(2, 7542, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7554
 *         return GiacMethods['hermite'](self,*args)
 * 
 *      def hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessenberg:
 */
  __pyx_codeobj__631 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hessenberg, 7554, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__631)) __PYX_ERR(2, 7554, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7569
 *         return GiacMethods['hessenberg'](self,*args)
 * 
 *      def hessian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessian:
 */
  __pyx_codeobj__632 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hessian, 7569, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__632)) __PYX_ERR(2, 7569, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7580
 *         return GiacMethods['hessian'](self,*args)
 * 
 *      def heugcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heugcd:
 */
  __pyx_codeobj__633 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_heugcd, 7580, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__633)) __PYX_ERR(2, 7580, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7591
 *         return GiacMethods['heugcd'](self,*args)
 * 
 *      def hexagon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hexagon:
 */
  __pyx_codeobj__634 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hexagon, 7591, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__634)) __PYX_ERR(2, 7591, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7605
 *         return GiacMethods['hexagon'](self,*args)
 * 
 *      def hht(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hht:
 */
  __pyx_codeobj__635 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hht, 7605, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__635)) __PYX_ERR(2, 7605, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7616
 *         return GiacMethods['hht'](self,*args)
 * 
 *      def highlight_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_edges:
 */
  __pyx_codeobj__636 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_highlight_edges, 7616, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__636)) __PYX_ERR(2, 7616, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7627
 *         return GiacMethods['highlight_edges'](self,*args)
 * 
 *      def highlight_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_subgraph:
 */
  __pyx_codeobj__637 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_highlight_subgraph, 7627, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__637)) __PYX_ERR(2, 7627, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7638
 *         return GiacMethods['highlight_subgraph'](self,*args)
 * 
 *      def highlight_trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_trail:
 */
  __pyx_codeobj__638 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_highlight_trail, 7638, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__638)) __PYX_ERR(2, 7638, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7649
 *         return GiacMethods['highlight_trail'](self,*args)
 * 
 *      def highlight_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_vertex:
 */
  __pyx_codeobj__639 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_highlight_vertex, 7649, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__639)) __PYX_ERR(2, 7649, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7660
 *         return GiacMethods['highlight_vertex'](self,*args)
 * 
 *      def highpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highpass:
 */
  __pyx_codeobj__640 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_highpass, 7660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__640)) __PYX_ERR(2, 7660, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7671
 *         return GiacMethods['highpass'](self,*args)
 * 
 *      def hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hilbert:
 */
  __pyx_codeobj__641 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hilbert, 7671, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__641)) __PYX_ERR(2, 7671, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7685
 *         return GiacMethods['hilbert'](self,*args)
 * 
 *      def histogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for histogram:
 */
  __pyx_codeobj__642 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_histogram, 7685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__642)) __PYX_ERR(2, 7685, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7703
 *         return GiacMethods['histogram'](self,*args)
 * 
 *      def hold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hold:
 */
  __pyx_codeobj__643 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hold, 7703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__643)) __PYX_ERR(2, 7703, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7716
 *         return GiacMethods['hold'](self,*args)
 * 
 *      def homogeneize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homogeneize:
 */
  __pyx_codeobj__644 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_homogeneize, 7716, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__644)) __PYX_ERR(2, 7716, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7727
 *         return GiacMethods['homogeneize'](self,*args)
 * 
 *      def homothety(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homothety:
 */
  __pyx_codeobj__645 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_homothety, 7727, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__645)) __PYX_ERR(2, 7727, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7741
 *         return GiacMethods['homothety'](self,*args)
 * 
 *      def horner(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for horner:
 */
  __pyx_codeobj__646 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_horner, 7741, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__646)) __PYX_ERR(2, 7741, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7755
 *         return GiacMethods['horner'](self,*args)
 * 
 *      def hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv:
 */
  __pyx_codeobj__647 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hsv, 7755, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__647)) __PYX_ERR(2, 7755, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7768
 *         return GiacMethods['hsv'](self,*args)
 * 
 *      def hsv2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv2rgb:
 */
  __pyx_codeobj__648 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hsv2rgb, 7768, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__648)) __PYX_ERR(2, 7768, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7781
 *         return GiacMethods['hsv2rgb'](self,*args)
 * 
 *      def hybrid_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrid_solver:
 */
  __pyx_codeobj__649 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hybrid_solver, 7781, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__649)) __PYX_ERR(2, 7781, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7797
 *         return GiacMethods['hybrid_solver'](self,*args)
 * 
 *      def hybridj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridj_solver:
 */
  __pyx_codeobj__650 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hybridj_solver, 7797, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__650)) __PYX_ERR(2, 7797, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7813
 *         return GiacMethods['hybridj_solver'](self,*args)
 * 
 *      def hybrids_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrids_solver:
 */
  __pyx_codeobj__651 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hybrids_solver, 7813, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__651)) __PYX_ERR(2, 7813, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7829
 *         return GiacMethods['hybrids_solver'](self,*args)
 * 
 *      def hybridsj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridsj_solver:
 */
  __pyx_codeobj__652 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hybridsj_solver, 7829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__652)) __PYX_ERR(2, 7829, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7845
 *         return GiacMethods['hybridsj_solver'](self,*args)
 * 
 *      def hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyp2exp:
 */
  __pyx_codeobj__653 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hyp2exp, 7845, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__653)) __PYX_ERR(2, 7845, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7856
 *         return GiacMethods['hyp2exp'](self,*args)
 * 
 *      def hyperbola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyperbola:
 */
  __pyx_codeobj__654 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hyperbola, 7856, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__654)) __PYX_ERR(2, 7856, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7870
 *         return GiacMethods['hyperbola'](self,*args)
 * 
 *      def hypercube_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hypercube_graph:
 */
  __pyx_codeobj__655 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_hypercube_graph, 7870, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__655)) __PYX_ERR(2, 7870, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7881
 *         return GiacMethods['hypercube_graph'](self,*args)
 * 
 *      def iPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iPart:
 */
  __pyx_codeobj__656 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_iPart, 7881, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__656)) __PYX_ERR(2, 7881, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7894
 *         return GiacMethods['iPart'](self,*args)
 * 
 *      def iabcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iabcuv:
 */
  __pyx_codeobj__657 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_iabcuv, 7894, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__657)) __PYX_ERR(2, 7894, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7907
 *         return GiacMethods['iabcuv'](self,*args)
 * 
 *      def ibasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibasis:
 */
  __pyx_codeobj__658 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ibasis, 7907, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__658)) __PYX_ERR(2, 7907, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7918
 *         return GiacMethods['ibasis'](self,*args)
 * 
 *      def ibpdv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpdv:
 */
  __pyx_codeobj__659 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ibpdv, 7918, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__659)) __PYX_ERR(2, 7918, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7933
 *         return GiacMethods['ibpdv'](self,*args)
 * 
 *      def ibpu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpu:
 */
  __pyx_codeobj__660 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ibpu, 7933, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__660)) __PYX_ERR(2, 7933, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7948
 *         return GiacMethods['ibpu'](self,*args)
 * 
 *      def icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icdf:
 */
  __pyx_codeobj__661 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_icdf, 7948, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__661)) __PYX_ERR(2, 7948, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7960
 *         return GiacMethods['icdf'](self,*args)
 * 
 *      def ichinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichinrem:
 */
  __pyx_codeobj__662 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ichinrem, 7960, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__662)) __PYX_ERR(2, 7960, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7974
 *         return GiacMethods['ichinrem'](self,*args)
 * 
 *      def ichrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichrem:
 */
  __pyx_codeobj__663 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ichrem, 7974, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__663)) __PYX_ERR(2, 7974, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":7988
 *         return GiacMethods['ichrem'](self,*args)
 * 
 *      def icomp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icomp:
 */
  __pyx_codeobj__664 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_icomp, 7988, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__664)) __PYX_ERR(2, 7988, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8000
 *         return GiacMethods['icomp'](self,*args)
 * 
 *      def icontent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icontent:
 */
  __pyx_codeobj__665 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_icontent, 8000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__665)) __PYX_ERR(2, 8000, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8012
 *         return GiacMethods['icontent'](self,*args)
 * 
 *      def icosahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icosahedron:
 */
  __pyx_codeobj__666 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_icosahedron, 8012, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__666)) __PYX_ERR(2, 8012, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8024
 *         return GiacMethods['icosahedron'](self,*args)
 * 
 *      def id(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for id:
 */
  __pyx_codeobj__667 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_id, 8024, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__667)) __PYX_ERR(2, 8024, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8035
 *         return GiacMethods['id'](self,*args)
 * 
 *      def identify_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identify_graph:
 */
  __pyx_codeobj__668 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_identify_graph, 8035, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__668)) __PYX_ERR(2, 8035, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8046
 *         return GiacMethods['identify_graph'](self,*args)
 * 
 *      def identity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identity:
 */
  __pyx_codeobj__669 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_identity, 8046, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__669)) __PYX_ERR(2, 8046, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8058
 *         return GiacMethods['identity'](self,*args)
 * 
 *      def idivis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idivis:
 */
  __pyx_codeobj__670 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_idivis, 8058, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__670)) __PYX_ERR(2, 8058, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8070
 *         return GiacMethods['idivis'](self,*args)
 * 
 *      def idn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idn:
 */
  __pyx_codeobj__671 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_idn, 8070, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__671)) __PYX_ERR(2, 8070, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8082
 *         return GiacMethods['idn'](self,*args)
 * 
 *      def idwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idwt:
 */
  __pyx_codeobj__672 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_idwt, 8082, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__672)) __PYX_ERR(2, 8082, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8094
 *         return GiacMethods['idwt'](self,*args)
 * 
 *      def iegcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iegcd:
 */
  __pyx_codeobj__673 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_iegcd, 8094, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__673)) __PYX_ERR(2, 8094, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8107
 *         return GiacMethods['iegcd'](self,*args)
 * 
 *      def ifactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactor:
 */
  __pyx_codeobj__674 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ifactor, 8107, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__674)) __PYX_ERR(2, 8107, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8119
 *         return GiacMethods['ifactor'](self,*args)
 * 
 *      def ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactors:
 */
  __pyx_codeobj__675 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ifactors, 8119, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__675)) __PYX_ERR(2, 8119, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8131
 *         return GiacMethods['ifactors'](self,*args)
 * 
 *      def ifourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifourier:
 */
  __pyx_codeobj__676 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ifourier, 8131, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__676)) __PYX_ERR(2, 8131, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8148
 *         return GiacMethods['ifourier'](self,*args)
 * 
 *      def igamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igamma:
 */
  __pyx_codeobj__677 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_igamma, 8148, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__677)) __PYX_ERR(2, 8148, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8161
 *         return GiacMethods['igamma'](self,*args)
 * 
 *      def igcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcd:
 */
  __pyx_codeobj__678 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_igcd, 8161, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__678)) __PYX_ERR(2, 8161, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8176
 *         return GiacMethods['igcd'](self,*args)
 * 
 *      def igcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcdex:
 */
  __pyx_codeobj__679 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_igcdex, 8176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__679)) __PYX_ERR(2, 8176, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8189
 *         return GiacMethods['igcdex'](self,*args)
 * 
 *      def ihermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ihermite:
 */
  __pyx_codeobj__680 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ihermite, 8189, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__680)) __PYX_ERR(2, 8189, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8201
 *         return GiacMethods['ihermite'](self,*args)
 * 
 *      def ilaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ilaplace:
 */
  __pyx_codeobj__681 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ilaplace, 8201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__681)) __PYX_ERR(2, 8201, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8214
 *         return GiacMethods['ilaplace'](self,*args)
 * 
 *      def im(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for im:
 */
  __pyx_codeobj__682 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_im, 8214, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__682)) __PYX_ERR(2, 8214, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8227
 *         return GiacMethods['im'](self,*args)
 * 
 *      def imag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imag:
 */
  __pyx_codeobj__683 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_imag, 8227, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__683)) __PYX_ERR(2, 8227, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8240
 *         return GiacMethods['imag'](self,*args)
 * 
 *      def image(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for image:
 */
  __pyx_codeobj__684 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_image, 8240, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__684)) __PYX_ERR(2, 8240, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8252
 *         return GiacMethods['image'](self,*args)
 * 
 *      def imfplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imfplot:
 */
  __pyx_codeobj__685 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_imfplot, 8252, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__685)) __PYX_ERR(2, 8252, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8263
 *         return GiacMethods['imfplot'](self,*args)
 * 
 *      def implicitdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitdiff:
 */
  __pyx_codeobj__686 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_implicitdiff, 8263, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__686)) __PYX_ERR(2, 8263, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8281
 *         return GiacMethods['implicitdiff'](self,*args)
 * 
 *      def implicitplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitplot:
 */
  __pyx_codeobj__687 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_implicitplot, 8281, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__687)) __PYX_ERR(2, 8281, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8300
 *         return GiacMethods['implicitplot'](self,*args)
 * 
 *      def import_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for import_graph:
 */
  __pyx_codeobj__688 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_import_graph, 8300, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__688)) __PYX_ERR(2, 8300, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8310
 *         return GiacMethods['import_graph'](self,*args)
 * 
 *      def inString(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inString:
 */
  __pyx_codeobj__689 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inString, 8310, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__689)) __PYX_ERR(2, 8310, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8322
 *         return GiacMethods['inString'](self,*args)
 * 
 *      def in_ideal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for in_ideal:
 */
  __pyx_codeobj__690 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_in_ideal, 8322, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__690)) __PYX_ERR(2, 8322, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8334
 *         return GiacMethods['in_ideal'](self,*args)
 * 
 *      def incidence_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incidence_matrix:
 */
  __pyx_codeobj__691 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_incidence_matrix, 8334, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__691)) __PYX_ERR(2, 8334, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8345
 *         return GiacMethods['incidence_matrix'](self,*args)
 * 
 *      def incident_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incident_edges:
 */
  __pyx_codeobj__692 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_incident_edges, 8345, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__692)) __PYX_ERR(2, 8345, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8356
 *         return GiacMethods['incident_edges'](self,*args)
 * 
 *      def incircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incircle:
 */
  __pyx_codeobj__693 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_incircle, 8356, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__693)) __PYX_ERR(2, 8356, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8367
 *         return GiacMethods['incircle'](self,*args)
 * 
 *      def increasing_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for increasing_power:
 */
  __pyx_codeobj__694 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_increasing_power, 8367, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__694)) __PYX_ERR(2, 8367, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8379
 *         return GiacMethods['increasing_power'](self,*args)
 * 
 *      def independence_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for independence_number:
 */
  __pyx_codeobj__695 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_independence_number, 8379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__695)) __PYX_ERR(2, 8379, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8390
 *         return GiacMethods['independence_number'](self,*args)
 * 
 *      def indets(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for indets:
 */
  __pyx_codeobj__696 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_indets, 8390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__696)) __PYX_ERR(2, 8390, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8401
 *         return GiacMethods['indets'](self,*args)
 * 
 *      def index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for index:
 */
  __pyx_codeobj__697 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_index, 8401, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__697)) __PYX_ERR(2, 8401, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8415
 *         return GiacMethods['index'](self,*args)
 * 
 *      def induced_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for induced_subgraph:
 */
  __pyx_codeobj__698 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_induced_subgraph, 8415, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__698)) __PYX_ERR(2, 8415, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8426
 *         return GiacMethods['induced_subgraph'](self,*args)
 * 
 *      def inequationplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inequationplot:
 */
  __pyx_codeobj__699 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inequationplot, 8426, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__699)) __PYX_ERR(2, 8426, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8440
 *         return GiacMethods['inequationplot'](self,*args)
 * 
 *      def inertia(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inertia:
 */
  __pyx_codeobj__700 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inertia, 8440, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__700)) __PYX_ERR(2, 8440, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8455
 *         return GiacMethods['inertia'](self,*args)
 * 
 *      def inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inf:
 */
  __pyx_codeobj__701 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inf, 8455, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__701)) __PYX_ERR(2, 8455, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8465
 *         return GiacMethods['inf'](self,*args)
 * 
 *      def infinity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for infinity:
 */
  __pyx_codeobj__702 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_infinity, 8465, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__702)) __PYX_ERR(2, 8465, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8475
 *         return GiacMethods['infinity'](self,*args)
 * 
 *      def information_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for information_centrality:
 */
  __pyx_codeobj__703 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_information_centrality, 8475, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__703)) __PYX_ERR(2, 8475, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8486
 *         return GiacMethods['information_centrality'](self,*args)
 * 
 *      def insert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insert:
 */
  __pyx_codeobj__704 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_insert, 8486, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__704)) __PYX_ERR(2, 8486, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8498
 *         return GiacMethods['insert'](self,*args)
 * 
 *      def insmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insmod:
 */
  __pyx_codeobj__705 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_insmod, 8498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__705)) __PYX_ERR(2, 8498, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8509
 *         return GiacMethods['insmod'](self,*args)
 * 
 *      def instfreq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instfreq:
 */
  __pyx_codeobj__706 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_instfreq, 8509, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__706)) __PYX_ERR(2, 8509, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8521
 *         return GiacMethods['instfreq'](self,*args)
 * 
 *      def instphase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instphase:
 */
  __pyx_codeobj__707 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_instphase, 8521, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__707)) __PYX_ERR(2, 8521, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8533
 *         return GiacMethods['instphase'](self,*args)
 * 
 *      def int(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for int:
 */
  __pyx_codeobj__708 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_int, 8533, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__708)) __PYX_ERR(2, 8533, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8546
 *         return GiacMethods['int'](self,*args)
 * 
 *      def intDiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for intDiv:
 */
  __pyx_codeobj__709 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_intDiv, 8546, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__709)) __PYX_ERR(2, 8546, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8560
 *         return GiacMethods['intDiv'](self,*args)
 * 
 *      def integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integer:
 */
  __pyx_codeobj__710 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_integer, 8560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__710)) __PYX_ERR(2, 8560, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8575
 *         return GiacMethods['integer'](self,*args)
 * 
 *      def integrate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrate:
 */
  __pyx_codeobj__711 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_integrate, 8575, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__711)) __PYX_ERR(2, 8575, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8588
 *         return GiacMethods['integrate'](self,*args)
 * 
 *      def integrer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrer:
 */
  __pyx_codeobj__712 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_integrer, 8588, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__712)) __PYX_ERR(2, 8588, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8601
 *         return GiacMethods['integrer'](self,*args)
 * 
 *      def inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inter:
 */
  __pyx_codeobj__713 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inter, 8601, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__713)) __PYX_ERR(2, 8601, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8616
 *         return GiacMethods['inter'](self,*args)
 * 
 *      def interactive_odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_odeplot:
 */
  __pyx_codeobj__714 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_interactive_odeplot, 8616, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__714)) __PYX_ERR(2, 8616, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8628
 *         return GiacMethods['interactive_odeplot'](self,*args)
 * 
 *      def interactive_plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_plotode:
 */
  __pyx_codeobj__715 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_interactive_plotode, 8628, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__715)) __PYX_ERR(2, 8628, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8640
 *         return GiacMethods['interactive_plotode'](self,*args)
 * 
 *      def interp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interp:
 */
  __pyx_codeobj__716 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_interp, 8640, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__716)) __PYX_ERR(2, 8640, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8653
 *         return GiacMethods['interp'](self,*args)
 * 
 *      def interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval:
 */
  __pyx_codeobj__717 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_interval, 8653, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__717)) __PYX_ERR(2, 8653, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8666
 *         return GiacMethods['interval'](self,*args)
 * 
 *      def interval2center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval2center:
 */
  __pyx_codeobj__718 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_interval2center, 8666, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__718)) __PYX_ERR(2, 8666, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8678
 *         return GiacMethods['interval2center'](self,*args)
 * 
 *      def interval_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval_graph:
 */
  __pyx_codeobj__719 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_interval_graph, 8678, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__719)) __PYX_ERR(2, 8678, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8689
 *         return GiacMethods['interval_graph'](self,*args)
 * 
 *      def inv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inv:
 */
  __pyx_codeobj__720 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inv, 8689, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__720)) __PYX_ERR(2, 8689, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8701
 *         return GiacMethods['inv'](self,*args)
 * 
 *      def inverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inverse:
 */
  __pyx_codeobj__721 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inverse, 8701, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__721)) __PYX_ERR(2, 8701, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8713
 *         return GiacMethods['inverse'](self,*args)
 * 
 *      def inversion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inversion:
 */
  __pyx_codeobj__722 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_inversion, 8713, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__722)) __PYX_ERR(2, 8713, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8727
 *         return GiacMethods['inversion'](self,*args)
 * 
 *      def invisible_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invisible_point:
 */
  __pyx_codeobj__723 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_invisible_point, 8727, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__723)) __PYX_ERR(2, 8727, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8739
 *         return GiacMethods['invisible_point'](self,*args)
 * 
 *      def invlaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invlaplace:
 */
  __pyx_codeobj__724 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_invlaplace, 8739, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__724)) __PYX_ERR(2, 8739, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8752
 *         return GiacMethods['invlaplace'](self,*args)
 * 
 *      def invztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invztrans:
 */
  __pyx_codeobj__725 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_invztrans, 8752, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__725)) __PYX_ERR(2, 8752, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8764
 *         return GiacMethods['invztrans'](self,*args)
 * 
 *      def iquo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquo:
 */
  __pyx_codeobj__726 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_iquo, 8764, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__726)) __PYX_ERR(2, 8764, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8778
 *         return GiacMethods['iquo'](self,*args)
 * 
 *      def iquorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquorem:
 */
  __pyx_codeobj__727 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_iquorem, 8778, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__727)) __PYX_ERR(2, 8778, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8791
 *         return GiacMethods['iquorem'](self,*args)
 * 
 *      def iratrecon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iratrecon:
 */
  __pyx_codeobj__728 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_iratrecon, 8791, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__728)) __PYX_ERR(2, 8791, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8802
 *         return GiacMethods['iratrecon'](self,*args)
 * 
 *      def irem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for irem:
 */
  __pyx_codeobj__729 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_irem, 8802, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__729)) __PYX_ERR(2, 8802, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8816
 *         return GiacMethods['irem'](self,*args)
 * 
 *      def isPrime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isPrime:
 */
  __pyx_codeobj__730 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isPrime, 8816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__730)) __PYX_ERR(2, 8816, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8829
 *         return GiacMethods['isPrime'](self,*args)
 * 
 *      def is_acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_acyclic:
 */
  __pyx_codeobj__731 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_acyclic, 8829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__731)) __PYX_ERR(2, 8829, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8840
 *         return GiacMethods['is_acyclic'](self,*args)
 * 
 *      def is_arborescence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_arborescence:
 */
  __pyx_codeobj__732 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_arborescence, 8840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__732)) __PYX_ERR(2, 8840, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8852
 *         return GiacMethods['is_arborescence'](self,*args)
 * 
 *      def is_biconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_biconnected:
 */
  __pyx_codeobj__733 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_biconnected, 8852, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__733)) __PYX_ERR(2, 8852, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8865
 *         return GiacMethods['is_biconnected'](self,*args)
 * 
 *      def is_bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_bipartite:
 */
  __pyx_codeobj__734 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_bipartite, 8865, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__734)) __PYX_ERR(2, 8865, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8876
 *         return GiacMethods['is_bipartite'](self,*args)
 * 
 *      def is_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_clique:
 */
  __pyx_codeobj__735 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_clique, 8876, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__735)) __PYX_ERR(2, 8876, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8887
 *         return GiacMethods['is_clique'](self,*args)
 * 
 *      def is_collinear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_collinear:
 */
  __pyx_codeobj__736 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_collinear, 8887, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__736)) __PYX_ERR(2, 8887, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8900
 *         return GiacMethods['is_collinear'](self,*args)
 * 
 *      def is_concyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_concyclic:
 */
  __pyx_codeobj__737 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_concyclic, 8900, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__737)) __PYX_ERR(2, 8900, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8912
 *         return GiacMethods['is_concyclic'](self,*args)
 * 
 *      def is_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_conjugate:
 */
  __pyx_codeobj__738 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_conjugate, 8912, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__738)) __PYX_ERR(2, 8912, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8932
 *         return GiacMethods['is_conjugate'](self,*args)
 * 
 *      def is_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_connected:
 */
  __pyx_codeobj__739 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_connected, 8932, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__739)) __PYX_ERR(2, 8932, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8945
 *         return GiacMethods['is_connected'](self,*args)
 * 
 *      def is_coplanar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_coplanar:
 */
  __pyx_codeobj__740 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_coplanar, 8945, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__740)) __PYX_ERR(2, 8945, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8955
 *         return GiacMethods['is_coplanar'](self,*args)
 * 
 *      def is_cospherical(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cospherical:
 */
  __pyx_codeobj__741 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_cospherical, 8955, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__741)) __PYX_ERR(2, 8955, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8965
 *         return GiacMethods['is_cospherical'](self,*args)
 * 
 *      def is_cut_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cut_set:
 */
  __pyx_codeobj__742 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_cut_set, 8965, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__742)) __PYX_ERR(2, 8965, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8976
 *         return GiacMethods['is_cut_set'](self,*args)
 * 
 *      def is_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cycle:
 */
  __pyx_codeobj__743 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_cycle, 8976, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__743)) __PYX_ERR(2, 8976, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8988
 *         return GiacMethods['is_cycle'](self,*args)
 * 
 *      def is_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_directed:
 */
  __pyx_codeobj__744 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_directed, 8988, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__744)) __PYX_ERR(2, 8988, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":8999
 *         return GiacMethods['is_directed'](self,*args)
 * 
 *      def is_element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_element:
 */
  __pyx_codeobj__745 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_element, 8999, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__745)) __PYX_ERR(2, 8999, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9011
 *         return GiacMethods['is_element'](self,*args)
 * 
 *      def is_equilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_equilateral:
 */
  __pyx_codeobj__746 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_equilateral, 9011, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__746)) __PYX_ERR(2, 9011, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9024
 *         return GiacMethods['is_equilateral'](self,*args)
 * 
 *      def is_eulerian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_eulerian:
 */
  __pyx_codeobj__747 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_eulerian, 9024, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__747)) __PYX_ERR(2, 9024, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9038
 *         return GiacMethods['is_eulerian'](self,*args)
 * 
 *      def is_forest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_forest:
 */
  __pyx_codeobj__748 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_forest, 9038, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__748)) __PYX_ERR(2, 9038, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9049
 *         return GiacMethods['is_forest'](self,*args)
 * 
 *      def is_graphic_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_graphic_sequence:
 */
  __pyx_codeobj__749 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_graphic_sequence, 9049, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__749)) __PYX_ERR(2, 9049, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9060
 *         return GiacMethods['is_graphic_sequence'](self,*args)
 * 
 *      def is_hamiltonian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_hamiltonian:
 */
  __pyx_codeobj__750 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_hamiltonian, 9060, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__750)) __PYX_ERR(2, 9060, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9073
 *         return GiacMethods['is_hamiltonian'](self,*args)
 * 
 *      def is_harmonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic:
 */
  __pyx_codeobj__751 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_harmonic, 9073, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__751)) __PYX_ERR(2, 9073, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9085
 *         return GiacMethods['is_harmonic'](self,*args)
 * 
 *      def is_harmonic_circle_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_circle_bundle:
 */
  __pyx_codeobj__752 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_harmonic_circle_bundle, 9085, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__752)) __PYX_ERR(2, 9085, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9097
 *         return GiacMethods['is_harmonic_circle_bundle'](self,*args)
 * 
 *      def is_harmonic_line_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_line_bundle:
 */
  __pyx_codeobj__753 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_harmonic_line_bundle, 9097, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__753)) __PYX_ERR(2, 9097, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9109
 *         return GiacMethods['is_harmonic_line_bundle'](self,*args)
 * 
 *      def is_inside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_inside:
 */
  __pyx_codeobj__754 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_inside, 9109, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__754)) __PYX_ERR(2, 9109, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9121
 *         return GiacMethods['is_inside'](self,*args)
 * 
 *      def is_integer_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_integer_graph:
 */
  __pyx_codeobj__755 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_integer_graph, 9121, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__755)) __PYX_ERR(2, 9121, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9132
 *         return GiacMethods['is_integer_graph'](self,*args)
 * 
 *      def is_irreducible(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_irreducible:
 */
  __pyx_codeobj__756 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_irreducible, 9132, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__756)) __PYX_ERR(2, 9132, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9145
 *         return GiacMethods['is_irreducible'](self,*args)
 * 
 *      def is_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isomorphic:
 */
  __pyx_codeobj__757 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_isomorphic, 9145, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__757)) __PYX_ERR(2, 9145, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9156
 *         return GiacMethods['is_isomorphic'](self,*args)
 * 
 *      def is_isosceles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isosceles:
 */
  __pyx_codeobj__758 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_isosceles, 9156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__758)) __PYX_ERR(2, 9156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9169
 *         return GiacMethods['is_isosceles'](self,*args)
 * 
 *      def is_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_network:
 */
  __pyx_codeobj__759 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_network, 9169, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__759)) __PYX_ERR(2, 9169, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9182
 *         return GiacMethods['is_network'](self,*args)
 * 
 *      def is_orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_orthogonal:
 */
  __pyx_codeobj__760 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_orthogonal, 9182, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__760)) __PYX_ERR(2, 9182, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9195
 *         return GiacMethods['is_orthogonal'](self,*args)
 * 
 *      def is_parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallel:
 */
  __pyx_codeobj__761 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_parallel, 9195, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__761)) __PYX_ERR(2, 9195, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9208
 *         return GiacMethods['is_parallel'](self,*args)
 * 
 *      def is_parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallelogram:
 */
  __pyx_codeobj__762 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_parallelogram, 9208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__762)) __PYX_ERR(2, 9208, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9221
 *         return GiacMethods['is_parallelogram'](self,*args)
 * 
 *      def is_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_permu:
 */
  __pyx_codeobj__763 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_permu, 9221, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__763)) __PYX_ERR(2, 9221, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9233
 *         return GiacMethods['is_permu'](self,*args)
 * 
 *      def is_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_perpendicular:
 */
  __pyx_codeobj__764 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_perpendicular, 9233, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__764)) __PYX_ERR(2, 9233, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9247
 *         return GiacMethods['is_perpendicular'](self,*args)
 * 
 *      def is_planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_planar:
 */
  __pyx_codeobj__765 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_planar, 9247, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__765)) __PYX_ERR(2, 9247, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9259
 *         return GiacMethods['is_planar'](self,*args)
 * 
 *      def is_prime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_prime:
 */
  __pyx_codeobj__766 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_prime, 9259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__766)) __PYX_ERR(2, 9259, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9273
 *         return GiacMethods['is_prime'](self,*args)
 * 
 *      def is_pseudoprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_pseudoprime:
 */
  __pyx_codeobj__767 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_pseudoprime, 9273, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__767)) __PYX_ERR(2, 9273, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9286
 *         return GiacMethods['is_pseudoprime'](self,*args)
 * 
 *      def is_reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_reachable:
 */
  __pyx_codeobj__768 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_reachable, 9286, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__768)) __PYX_ERR(2, 9286, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9298
 *         return GiacMethods['is_reachable'](self,*args)
 * 
 *      def is_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rectangle:
 */
  __pyx_codeobj__769 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_rectangle, 9298, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__769)) __PYX_ERR(2, 9298, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9314
 *         return GiacMethods['is_rectangle'](self,*args)
 * 
 *      def is_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_regular:
 */
  __pyx_codeobj__770 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_regular, 9314, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__770)) __PYX_ERR(2, 9314, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9325
 *         return GiacMethods['is_regular'](self,*args)
 * 
 *      def is_rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rhombus:
 */
  __pyx_codeobj__771 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_rhombus, 9325, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__771)) __PYX_ERR(2, 9325, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9338
 *         return GiacMethods['is_rhombus'](self,*args)
 * 
 *      def is_split_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_split_graph:
 */
  __pyx_codeobj__772 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_split_graph, 9338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__772)) __PYX_ERR(2, 9338, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9349
 *         return GiacMethods['is_split_graph'](self,*args)
 * 
 *      def is_square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_square:
 */
  __pyx_codeobj__773 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_square, 9349, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__773)) __PYX_ERR(2, 9349, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9362
 *         return GiacMethods['is_square'](self,*args)
 * 
 *      def is_strongly_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_connected:
 */
  __pyx_codeobj__774 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_strongly_connected, 9362, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__774)) __PYX_ERR(2, 9362, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9373
 *         return GiacMethods['is_strongly_connected'](self,*args)
 * 
 *      def is_strongly_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_regular:
 */
  __pyx_codeobj__775 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_strongly_regular, 9373, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__775)) __PYX_ERR(2, 9373, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9385
 *         return GiacMethods['is_strongly_regular'](self,*args)
 * 
 *      def is_subgraph_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_subgraph_isomorphic:
 */
  __pyx_codeobj__776 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_subgraph_isomorphic, 9385, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__776)) __PYX_ERR(2, 9385, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9396
 *         return GiacMethods['is_subgraph_isomorphic'](self,*args)
 * 
 *      def is_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tournament:
 */
  __pyx_codeobj__777 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_tournament, 9396, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__777)) __PYX_ERR(2, 9396, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9407
 *         return GiacMethods['is_tournament'](self,*args)
 * 
 *      def is_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tree:
 */
  __pyx_codeobj__778 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_tree, 9407, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__778)) __PYX_ERR(2, 9407, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9420
 *         return GiacMethods['is_tree'](self,*args)
 * 
 *      def is_triconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_triconnected:
 */
  __pyx_codeobj__779 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_triconnected, 9420, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__779)) __PYX_ERR(2, 9420, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9433
 *         return GiacMethods['is_triconnected'](self,*args)
 * 
 *      def is_two_edge_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_two_edge_connected:
 */
  __pyx_codeobj__780 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_two_edge_connected, 9433, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__780)) __PYX_ERR(2, 9433, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9445
 *         return GiacMethods['is_two_edge_connected'](self,*args)
 * 
 *      def is_vertex_colorable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_vertex_colorable:
 */
  __pyx_codeobj__781 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_vertex_colorable, 9445, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__781)) __PYX_ERR(2, 9445, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9457
 *         return GiacMethods['is_vertex_colorable'](self,*args)
 * 
 *      def is_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_weighted:
 */
  __pyx_codeobj__782 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_is_weighted, 9457, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__782)) __PYX_ERR(2, 9457, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9469
 *         return GiacMethods['is_weighted'](self,*args)
 * 
 *      def isinf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isinf:
 */
  __pyx_codeobj__783 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isinf, 9469, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__783)) __PYX_ERR(2, 9469, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9479
 *         return GiacMethods['isinf'](self,*args)
 * 
 *      def ismith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ismith:
 */
  __pyx_codeobj__784 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ismith, 9479, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__784)) __PYX_ERR(2, 9479, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9491
 *         return GiacMethods['ismith'](self,*args)
 * 
 *      def isnan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isnan:
 */
  __pyx_codeobj__785 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isnan, 9491, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__785)) __PYX_ERR(2, 9491, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9501
 *         return GiacMethods['isnan'](self,*args)
 * 
 *      def isobarycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isobarycenter:
 */
  __pyx_codeobj__786 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isobarycenter, 9501, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__786)) __PYX_ERR(2, 9501, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9512
 *         return GiacMethods['isobarycenter'](self,*args)
 * 
 *      def isolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isolve:
 */
  __pyx_codeobj__787 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isolve, 9512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__787)) __PYX_ERR(2, 9512, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9528
 *         return GiacMethods['isolve'](self,*args)
 * 
 *      def isom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isom:
 */
  __pyx_codeobj__788 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isom, 9528, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__788)) __PYX_ERR(2, 9528, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9539
 *         return GiacMethods['isom'](self,*args)
 * 
 *      def isomorphic_copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isomorphic_copy:
 */
  __pyx_codeobj__789 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isomorphic_copy, 9539, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__789)) __PYX_ERR(2, 9539, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9550
 *         return GiacMethods['isomorphic_copy'](self,*args)
 * 
 *      def isopolygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isopolygon:
 */
  __pyx_codeobj__790 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isopolygon, 9550, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__790)) __PYX_ERR(2, 9550, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9564
 *         return GiacMethods['isopolygon'](self,*args)
 * 
 *      def isosceles_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isosceles_triangle:
 */
  __pyx_codeobj__791 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isosceles_triangle, 9564, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__791)) __PYX_ERR(2, 9564, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9578
 *         return GiacMethods['isosceles_triangle'](self,*args)
 * 
 *      def isposdef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isposdef:
 */
  __pyx_codeobj__792 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isposdef, 9578, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__792)) __PYX_ERR(2, 9578, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9589
 *         return GiacMethods['isposdef'](self,*args)
 * 
 *      def isprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isprime:
 */
  __pyx_codeobj__793 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_isprime, 9589, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__793)) __PYX_ERR(2, 9589, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9602
 *         return GiacMethods['isprime'](self,*args)
 * 
 *      def istft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for istft:
 */
  __pyx_codeobj__794 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_istft, 9602, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__794)) __PYX_ERR(2, 9602, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9613
 *         return GiacMethods['istft'](self,*args)
 * 
 *      def ithprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ithprime:
 */
  __pyx_codeobj__795 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ithprime, 9613, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__795)) __PYX_ERR(2, 9613, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9625
 *         return GiacMethods['ithprime'](self,*args)
 * 
 *      def jacobi_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_equation:
 */
  __pyx_codeobj__796 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_jacobi_equation, 9625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__796)) __PYX_ERR(2, 9625, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9636
 *         return GiacMethods['jacobi_equation'](self,*args)
 * 
 *      def jacobi_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_linsolve:
 */
  __pyx_codeobj__797 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_jacobi_linsolve, 9636, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__797)) __PYX_ERR(2, 9636, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9648
 *         return GiacMethods['jacobi_linsolve'](self,*args)
 * 
 *      def jacobi_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_symbol:
 */
  __pyx_codeobj__798 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_jacobi_symbol, 9648, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__798)) __PYX_ERR(2, 9648, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9660
 *         return GiacMethods['jacobi_symbol'](self,*args)
 * 
 *      def johnson_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for johnson_graph:
 */
  __pyx_codeobj__799 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_johnson_graph, 9660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__799)) __PYX_ERR(2, 9660, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9671
 *         return GiacMethods['johnson_graph'](self,*args)
 * 
 *      def join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for join:
 */
  __pyx_codeobj__800 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_join, 9671, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__800)) __PYX_ERR(2, 9671, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9682
 *         return GiacMethods['join'](self,*args)
 * 
 *      def jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jordan:
 */
  __pyx_codeobj__801 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_jordan, 9682, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__801)) __PYX_ERR(2, 9682, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9695
 *         return GiacMethods['jordan'](self,*args)
 * 
 *      def katz_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for katz_centrality:
 */
  __pyx_codeobj__802 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_katz_centrality, 9695, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__802)) __PYX_ERR(2, 9695, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9706
 *         return GiacMethods['katz_centrality'](self,*args)
 * 
 *      def kde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kde:
 */
  __pyx_codeobj__803 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kde, 9706, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__803)) __PYX_ERR(2, 9706, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9719
 *         return GiacMethods['kde'](self,*args)
 * 
 *      def keep_pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for keep_pivot:
 */
  __pyx_codeobj__804 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_keep_pivot, 9719, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__804)) __PYX_ERR(2, 9719, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9730
 *         return GiacMethods['keep_pivot'](self,*args)
 * 
 *      def ker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ker:
 */
  __pyx_codeobj__805 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ker, 9730, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__805)) __PYX_ERR(2, 9730, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9742
 *         return GiacMethods['ker'](self,*args)
 * 
 *      def kernel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel:
 */
  __pyx_codeobj__806 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kernel, 9742, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__806)) __PYX_ERR(2, 9742, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9754
 *         return GiacMethods['kernel'](self,*args)
 * 
 *      def kernel_density(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel_density:
 */
  __pyx_codeobj__807 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kernel_density, 9754, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__807)) __PYX_ERR(2, 9754, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9767
 *         return GiacMethods['kernel_density'](self,*args)
 * 
 *      def kmeans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kmeans:
 */
  __pyx_codeobj__808 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kmeans, 9767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__808)) __PYX_ERR(2, 9767, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9778
 *         return GiacMethods['kmeans'](self,*args)
 * 
 *      def kneser_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kneser_graph:
 */
  __pyx_codeobj__809 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kneser_graph, 9778, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__809)) __PYX_ERR(2, 9778, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9789
 *         return GiacMethods['kneser_graph'](self,*args)
 * 
 *      def kolmogorovd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovd:
 */
  __pyx_codeobj__810 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kolmogorovd, 9789, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__810)) __PYX_ERR(2, 9789, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9799
 *         return GiacMethods['kolmogorovd'](self,*args)
 * 
 *      def kolmogorovt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovt:
 */
  __pyx_codeobj__811 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kolmogorovt, 9799, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__811)) __PYX_ERR(2, 9799, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9813
 *         return GiacMethods['kolmogorovt'](self,*args)
 * 
 *      def kovacicsols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kovacicsols:
 */
  __pyx_codeobj__812 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kovacicsols, 9813, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__812)) __PYX_ERR(2, 9813, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9830
 *         return GiacMethods['kovacicsols'](self,*args)
 * 
 *      def kspaths(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kspaths:
 */
  __pyx_codeobj__813 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_kspaths, 9830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__813)) __PYX_ERR(2, 9830, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9842
 *         return GiacMethods['kspaths'](self,*args)
 * 
 *      def l1norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l1norm:
 */
  __pyx_codeobj__814 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_l1norm, 9842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__814)) __PYX_ERR(2, 9842, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9855
 *         return GiacMethods['l1norm'](self,*args)
 * 
 *      def l2norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l2norm:
 */
  __pyx_codeobj__815 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_l2norm, 9855, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__815)) __PYX_ERR(2, 9855, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9869
 *         return GiacMethods['l2norm'](self,*args)
 * 
 *      def lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lagrange:
 */
  __pyx_codeobj__816 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lagrange, 9869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__816)) __PYX_ERR(2, 9869, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9890
 *         return GiacMethods['lagrange'](self,*args)
 * 
 *      def laguerre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laguerre:
 */
  __pyx_codeobj__817 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_laguerre, 9890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__817)) __PYX_ERR(2, 9890, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9901
 *         return GiacMethods['laguerre'](self,*args)
 * 
 *      def laplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplace:
 */
  __pyx_codeobj__818 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_laplace, 9901, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__818)) __PYX_ERR(2, 9901, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9914
 *         return GiacMethods['laplace'](self,*args)
 * 
 *      def laplacian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian:
 */
  __pyx_codeobj__819 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_laplacian, 9914, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__819)) __PYX_ERR(2, 9914, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9928
 *         return GiacMethods['laplacian'](self,*args)
 * 
 *      def laplacian_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian_matrix:
 */
  __pyx_codeobj__820 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_laplacian_matrix, 9928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__820)) __PYX_ERR(2, 9928, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9940
 *         return GiacMethods['laplacian_matrix'](self,*args)
 * 
 *      def latex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for latex:
 */
  __pyx_codeobj__821 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_latex, 9940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__821)) __PYX_ERR(2, 9940, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9952
 *         return GiacMethods['latex'](self,*args)
 * 
 *      def lcf_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcf_graph:
 */
  __pyx_codeobj__822 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lcf_graph, 9952, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__822)) __PYX_ERR(2, 9952, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9963
 *         return GiacMethods['lcf_graph'](self,*args)
 * 
 *      def lcm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcm:
 */
  __pyx_codeobj__823 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lcm, 9963, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__823)) __PYX_ERR(2, 9963, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9979
 *         return GiacMethods['lcm'](self,*args)
 * 
 *      def lcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcoeff:
 */
  __pyx_codeobj__824 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lcoeff, 9979, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__824)) __PYX_ERR(2, 9979, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":9991
 *         return GiacMethods['lcoeff'](self,*args)
 * 
 *      def ldegree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldegree:
 */
  __pyx_codeobj__825 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ldegree, 9991, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__825)) __PYX_ERR(2, 9991, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10006
 *         return GiacMethods['ldegree'](self,*args)
 * 
 *      def ldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldl:
 */
  __pyx_codeobj__826 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ldl, 10006, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__826)) __PYX_ERR(2, 10006, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10019
 *         return GiacMethods['ldl'](self,*args)
 * 
 *      def learning_rate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for learning_rate:
 */
  __pyx_codeobj__827 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_learning_rate, 10019, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__827)) __PYX_ERR(2, 10019, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10029
 *         return GiacMethods['learning_rate'](self,*args)
 * 
 *      def left(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left:
 */
  __pyx_codeobj__828 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_left, 10029, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__828)) __PYX_ERR(2, 10029, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10043
 *         return GiacMethods['left'](self,*args)
 * 
 *      def left_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left_rectangle:
 */
  __pyx_codeobj__829 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_left_rectangle, 10043, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__829)) __PYX_ERR(2, 10043, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10059
 *         return GiacMethods['left_rectangle'](self,*args)
 * 
 *      def legend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legend:
 */
  __pyx_codeobj__830 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_legend, 10059, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__830)) __PYX_ERR(2, 10059, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10082
 *         return GiacMethods['legend'](self,*args)
 * 
 *      def legendre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre:
 */
  __pyx_codeobj__831 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_legendre, 10082, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__831)) __PYX_ERR(2, 10082, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10093
 *         return GiacMethods['legendre'](self,*args)
 * 
 *      def legendre_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre_symbol:
 */
  __pyx_codeobj__832 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_legendre_symbol, 10093, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__832)) __PYX_ERR(2, 10093, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10105
 *         return GiacMethods['legendre_symbol'](self,*args)
 * 
 *      def length(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for length:
 */
  __pyx_codeobj__833 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_length, 10105, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__833)) __PYX_ERR(2, 10105, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10118
 *         return GiacMethods['length'](self,*args)
 * 
 *      def levenshtein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for levenshtein:
 */
  __pyx_codeobj__834 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_levenshtein, 10118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__834)) __PYX_ERR(2, 10118, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10129
 *         return GiacMethods['levenshtein'](self,*args)
 * 
 *      def lgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lgcd:
 */
  __pyx_codeobj__835 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lgcd, 10129, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__835)) __PYX_ERR(2, 10129, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10142
 *         return GiacMethods['lgcd'](self,*args)
 * 
 *      def lhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lhs:
 */
  __pyx_codeobj__836 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lhs, 10142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__836)) __PYX_ERR(2, 10142, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10156
 *         return GiacMethods['lhs'](self,*args)
 * 
 *      def ligne_chapeau_carre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_carre:
 */
  __pyx_codeobj__837 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_chapeau_carre, 10156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__837)) __PYX_ERR(2, 10156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10168
 *         return GiacMethods['ligne_chapeau_carre'](self,*args)
 * 
 *      def ligne_chapeau_plat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_plat:
 */
  __pyx_codeobj__838 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_chapeau_plat, 10168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__838)) __PYX_ERR(2, 10168, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10180
 *         return GiacMethods['ligne_chapeau_plat'](self,*args)
 * 
 *      def ligne_chapeau_rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_rond:
 */
  __pyx_codeobj__839 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_chapeau_rond, 10180, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__839)) __PYX_ERR(2, 10180, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10192
 *         return GiacMethods['ligne_chapeau_rond'](self,*args)
 * 
 *      def ligne_polygonale(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale:
 */
  __pyx_codeobj__840 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_polygonale, 10192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__840)) __PYX_ERR(2, 10192, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10203
 *         return GiacMethods['ligne_polygonale'](self,*args)
 * 
 *      def ligne_polygonale_pointee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale_pointee:
 */
  __pyx_codeobj__841 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_polygonale_pointee, 10203, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__841)) __PYX_ERR(2, 10203, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10214
 *         return GiacMethods['ligne_polygonale_pointee'](self,*args)
 * 
 *      def ligne_tiret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret:
 */
  __pyx_codeobj__842 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_tiret, 10214, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__842)) __PYX_ERR(2, 10214, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10226
 *         return GiacMethods['ligne_tiret'](self,*args)
 * 
 *      def ligne_tiret_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_point:
 */
  __pyx_codeobj__843 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_tiret_point, 10226, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__843)) __PYX_ERR(2, 10226, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10238
 *         return GiacMethods['ligne_tiret_point'](self,*args)
 * 
 *      def ligne_tiret_pointpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_pointpoint:
 */
  __pyx_codeobj__844 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_tiret_pointpoint, 10238, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__844)) __PYX_ERR(2, 10238, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10250
 *         return GiacMethods['ligne_tiret_pointpoint'](self,*args)
 * 
 *      def ligne_trait_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_trait_plein:
 */
  __pyx_codeobj__845 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ligne_trait_plein, 10250, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__845)) __PYX_ERR(2, 10250, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10262
 *         return GiacMethods['ligne_trait_plein'](self,*args)
 * 
 *      def limit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limit:
 */
  __pyx_codeobj__846 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_limit, 10262, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__846)) __PYX_ERR(2, 10262, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10278
 *         return GiacMethods['limit'](self,*args)
 * 
 *      def limite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limite:
 */
  __pyx_codeobj__847 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_limite, 10278, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__847)) __PYX_ERR(2, 10278, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10294
 *         return GiacMethods['limite'](self,*args)
 * 
 *      def lin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lin:
 */
  __pyx_codeobj__848 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lin, 10294, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__848)) __PYX_ERR(2, 10294, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10306
 *         return GiacMethods['lin'](self,*args)
 * 
 *      def linabs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linabs:
 */
  __pyx_codeobj__849 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linabs, 10306, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__849)) __PYX_ERR(2, 10306, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10319
 *         return GiacMethods['linabs'](self,*args)
 * 
 *      def line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line:
 */
  __pyx_codeobj__850 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_line, 10319, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__850)) __PYX_ERR(2, 10319, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10338
 *         return GiacMethods['line'](self,*args)
 * 
 *      def line_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_graph:
 */
  __pyx_codeobj__851 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_line_graph, 10338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__851)) __PYX_ERR(2, 10338, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10349
 *         return GiacMethods['line_graph'](self,*args)
 * 
 *      def line_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_inter:
 */
  __pyx_codeobj__852 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_line_inter, 10349, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__852)) __PYX_ERR(2, 10349, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10366
 *         return GiacMethods['line_inter'](self,*args)
 * 
 *      def line_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_paper:
 */
  __pyx_codeobj__853 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_line_paper, 10366, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__853)) __PYX_ERR(2, 10366, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10378
 *         return GiacMethods['line_paper'](self,*args)
 * 
 *      def line_segments(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_segments:
 */
  __pyx_codeobj__854 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_line_segments, 10378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__854)) __PYX_ERR(2, 10378, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10390
 *         return GiacMethods['line_segments'](self,*args)
 * 
 *      def linear_interpolate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_interpolate:
 */
  __pyx_codeobj__855 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linear_interpolate, 10390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__855)) __PYX_ERR(2, 10390, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10401
 *         return GiacMethods['linear_interpolate'](self,*args)
 * 
 *      def linear_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression:
 */
  __pyx_codeobj__856 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linear_regression, 10401, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__856)) __PYX_ERR(2, 10401, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10413
 *         return GiacMethods['linear_regression'](self,*args)
 * 
 *      def linear_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression_plot:
 */
  __pyx_codeobj__857 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linear_regression_plot, 10413, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__857)) __PYX_ERR(2, 10413, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10425
 *         return GiacMethods['linear_regression_plot'](self,*args)
 * 
 *      def lineariser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser:
 */
  __pyx_codeobj__858 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lineariser, 10425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__858)) __PYX_ERR(2, 10425, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10437
 *         return GiacMethods['lineariser'](self,*args)
 * 
 *      def lineariser_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser_trigo:
 */
  __pyx_codeobj__859 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lineariser_trigo, 10437, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__859)) __PYX_ERR(2, 10437, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10449
 *         return GiacMethods['lineariser_trigo'](self,*args)
 * 
 *      def linfnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linfnorm:
 */
  __pyx_codeobj__860 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linfnorm, 10449, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__860)) __PYX_ERR(2, 10449, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10460
 *         return GiacMethods['linfnorm'](self,*args)
 * 
 *      def linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linsolve:
 */
  __pyx_codeobj__861 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linsolve, 10460, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__861)) __PYX_ERR(2, 10460, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10479
 *         return GiacMethods['linsolve'](self,*args)
 * 
 *      def linspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linspace:
 */
  __pyx_codeobj__862 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linspace, 10479, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__862)) __PYX_ERR(2, 10479, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10489
 *         return GiacMethods['linspace'](self,*args)
 * 
 *      def linstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linstep:
 */
  __pyx_codeobj__863 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_linstep, 10489, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__863)) __PYX_ERR(2, 10489, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10502
 *         return GiacMethods['linstep'](self,*args)
 * 
 *      def lis_phrase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lis_phrase:
 */
  __pyx_codeobj__864 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lis_phrase, 10502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__864)) __PYX_ERR(2, 10502, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10513
 *         return GiacMethods['lis_phrase'](self,*args)
 * 
 *      def list2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2exp:
 */
  __pyx_codeobj__865 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_list2exp, 10513, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__865)) __PYX_ERR(2, 10513, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10525
 *         return GiacMethods['list2exp'](self,*args)
 * 
 *      def list2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2mat:
 */
  __pyx_codeobj__866 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_list2mat, 10525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__866)) __PYX_ERR(2, 10525, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10537
 *         return GiacMethods['list2mat'](self,*args)
 * 
 *      def list_edge_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_edge_attributes:
 */
  __pyx_codeobj__867 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_list_edge_attributes, 10537, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__867)) __PYX_ERR(2, 10537, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10547
 *         return GiacMethods['list_edge_attributes'](self,*args)
 * 
 *      def list_graph_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_graph_attributes:
 */
  __pyx_codeobj__868 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_list_graph_attributes, 10547, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__868)) __PYX_ERR(2, 10547, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10557
 *         return GiacMethods['list_graph_attributes'](self,*args)
 * 
 *      def list_vertex_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_vertex_attributes:
 */
  __pyx_codeobj__869 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_list_vertex_attributes, 10557, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__869)) __PYX_ERR(2, 10557, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10567
 *         return GiacMethods['list_vertex_attributes'](self,*args)
 * 
 *      def listplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for listplot:
 */
  __pyx_codeobj__870 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_listplot, 10567, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__870)) __PYX_ERR(2, 10567, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10580
 *         return GiacMethods['listplot'](self,*args)
 * 
 *      def lll(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lll:
 */
  __pyx_codeobj__871 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lll, 10580, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__871)) __PYX_ERR(2, 10580, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10590
 *         return GiacMethods['lll'](self,*args)
 * 
 *      def ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ln:
 */
  __pyx_codeobj__872 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ln, 10590, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__872)) __PYX_ERR(2, 10590, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10603
 *         return GiacMethods['ln'](self,*args)
 * 
 *      def lname(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lname:
 */
  __pyx_codeobj__873 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lname, 10603, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__873)) __PYX_ERR(2, 10603, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10614
 *         return GiacMethods['lname'](self,*args)
 * 
 *      def lncollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lncollect:
 */
  __pyx_codeobj__874 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lncollect, 10614, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__874)) __PYX_ERR(2, 10614, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10625
 *         return GiacMethods['lncollect'](self,*args)
 * 
 *      def lnexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lnexpand:
 */
  __pyx_codeobj__875 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lnexpand, 10625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__875)) __PYX_ERR(2, 10625, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10636
 *         return GiacMethods['lnexpand'](self,*args)
 * 
 *      def locus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for locus:
 */
  __pyx_codeobj__876 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_locus, 10636, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__876)) __PYX_ERR(2, 10636, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10648
 *         return GiacMethods['locus'](self,*args)
 * 
 *      def log(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log:
 */
  __pyx_codeobj__877 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_log, 10648, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__877)) __PYX_ERR(2, 10648, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10661
 *         return GiacMethods['log'](self,*args)
 * 
 *      def log10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log10:
 */
  __pyx_codeobj__878 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_log10, 10661, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__878)) __PYX_ERR(2, 10661, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10672
 *         return GiacMethods['log10'](self,*args)
 * 
 *      def log2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log2:
 */
  __pyx_codeobj__879 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_log2, 10672, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__879)) __PYX_ERR(2, 10672, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10683
 *         return GiacMethods['log2'](self,*args)
 * 
 *      def log_loss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log_loss:
 */
  __pyx_codeobj__880 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_log_loss, 10683, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__880)) __PYX_ERR(2, 10683, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10693
 *         return GiacMethods['log_loss'](self,*args)
 * 
 *      def logarithmic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression:
 */
  __pyx_codeobj__881 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_logarithmic_regression, 10693, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__881)) __PYX_ERR(2, 10693, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10705
 *         return GiacMethods['logarithmic_regression'](self,*args)
 * 
 *      def logarithmic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression_plot:
 */
  __pyx_codeobj__882 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_logarithmic_regression_plot, 10705, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__882)) __PYX_ERR(2, 10705, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10717
 *         return GiacMethods['logarithmic_regression_plot'](self,*args)
 * 
 *      def logb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logb:
 */
  __pyx_codeobj__883 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_logb, 10717, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__883)) __PYX_ERR(2, 10717, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10729
 *         return GiacMethods['logb'](self,*args)
 * 
 *      def logistic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic:
 */
  __pyx_codeobj__884 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_logistic, 10729, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__884)) __PYX_ERR(2, 10729, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10741
 *         return GiacMethods['logistic'](self,*args)
 * 
 *      def logistic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression:
 */
  __pyx_codeobj__885 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_logistic_regression, 10741, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__885)) __PYX_ERR(2, 10741, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10753
 *         return GiacMethods['logistic_regression'](self,*args)
 * 
 *      def logistic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression_plot:
 */
  __pyx_codeobj__886 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_logistic_regression_plot, 10753, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__886)) __PYX_ERR(2, 10753, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10765
 *         return GiacMethods['logistic_regression_plot'](self,*args)
 * 
 *      def lower(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lower:
 */
  __pyx_codeobj__887 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lower, 10765, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__887)) __PYX_ERR(2, 10765, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10777
 *         return GiacMethods['lower'](self,*args)
 * 
 *      def lowest_common_ancestor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowest_common_ancestor:
 */
  __pyx_codeobj__888 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lowest_common_ancestor, 10777, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__888)) __PYX_ERR(2, 10777, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10789
 *         return GiacMethods['lowest_common_ancestor'](self,*args)
 * 
 *      def lowpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowpass:
 */
  __pyx_codeobj__889 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lowpass, 10789, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__889)) __PYX_ERR(2, 10789, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10800
 *         return GiacMethods['lowpass'](self,*args)
 * 
 *      def lp_assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_assume:
 */
  __pyx_codeobj__890 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_assume, 10800, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__890)) __PYX_ERR(2, 10800, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10810
 *         return GiacMethods['lp_assume'](self,*args)
 * 
 *      def lp_bestlocalbound(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestlocalbound:
 */
  __pyx_codeobj__891 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_bestlocalbound, 10810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__891)) __PYX_ERR(2, 10810, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10820
 *         return GiacMethods['lp_bestlocalbound'](self,*args)
 * 
 *      def lp_bestprojection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestprojection:
 */
  __pyx_codeobj__892 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_bestprojection, 10820, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__892)) __PYX_ERR(2, 10820, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10830
 *         return GiacMethods['lp_bestprojection'](self,*args)
 * 
 *      def lp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binary:
 */
  __pyx_codeobj__893 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_binary, 10830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__893)) __PYX_ERR(2, 10830, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10840
 *         return GiacMethods['lp_binary'](self,*args)
 * 
 *      def lp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binaryvariables:
 */
  __pyx_codeobj__894 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_binaryvariables, 10840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__894)) __PYX_ERR(2, 10840, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10850
 *         return GiacMethods['lp_binaryvariables'](self,*args)
 * 
 *      def lp_breadthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_breadthfirst:
 */
  __pyx_codeobj__895 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_breadthfirst, 10850, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__895)) __PYX_ERR(2, 10850, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10860
 *         return GiacMethods['lp_breadthfirst'](self,*args)
 * 
 *      def lp_depthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthfirst:
 */
  __pyx_codeobj__896 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_depthfirst, 10860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__896)) __PYX_ERR(2, 10860, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10870
 *         return GiacMethods['lp_depthfirst'](self,*args)
 * 
 *      def lp_depthlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthlimit:
 */
  __pyx_codeobj__897 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_depthlimit, 10870, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__897)) __PYX_ERR(2, 10870, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10880
 *         return GiacMethods['lp_depthlimit'](self,*args)
 * 
 *      def lp_firstfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_firstfractional:
 */
  __pyx_codeobj__898 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_firstfractional, 10880, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__898)) __PYX_ERR(2, 10880, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10890
 *         return GiacMethods['lp_firstfractional'](self,*args)
 * 
 *      def lp_gaptolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_gaptolerance:
 */
  __pyx_codeobj__899 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_gaptolerance, 10890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__899)) __PYX_ERR(2, 10890, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10900
 *         return GiacMethods['lp_gaptolerance'](self,*args)
 * 
 *      def lp_heuristic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_heuristic:
 */
  __pyx_codeobj__900 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_heuristic, 10900, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__900)) __PYX_ERR(2, 10900, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10910
 *         return GiacMethods['lp_heuristic'](self,*args)
 * 
 *      def lp_hybrid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_hybrid:
 */
  __pyx_codeobj__901 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_hybrid, 10910, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__901)) __PYX_ERR(2, 10910, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10920
 *         return GiacMethods['lp_hybrid'](self,*args)
 * 
 *      def lp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integer:
 */
  __pyx_codeobj__902 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_integer, 10920, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__902)) __PYX_ERR(2, 10920, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10930
 *         return GiacMethods['lp_integer'](self,*args)
 * 
 *      def lp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integervariables:
 */
  __pyx_codeobj__903 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_integervariables, 10930, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__903)) __PYX_ERR(2, 10930, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10940
 *         return GiacMethods['lp_integervariables'](self,*args)
 * 
 *      def lp_interiorpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_interiorpoint:
 */
  __pyx_codeobj__904 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_interiorpoint, 10940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__904)) __PYX_ERR(2, 10940, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10950
 *         return GiacMethods['lp_interiorpoint'](self,*args)
 * 
 *      def lp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_iterationlimit:
 */
  __pyx_codeobj__905 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_iterationlimit, 10950, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__905)) __PYX_ERR(2, 10950, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10960
 *         return GiacMethods['lp_iterationlimit'](self,*args)
 * 
 *      def lp_lastfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_lastfractional:
 */
  __pyx_codeobj__906 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_lastfractional, 10960, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__906)) __PYX_ERR(2, 10960, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10970
 *         return GiacMethods['lp_lastfractional'](self,*args)
 * 
 *      def lp_maxcuts(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maxcuts:
 */
  __pyx_codeobj__907 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_maxcuts, 10970, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__907)) __PYX_ERR(2, 10970, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10980
 *         return GiacMethods['lp_maxcuts'](self,*args)
 * 
 *      def lp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maximize:
 */
  __pyx_codeobj__908 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_maximize, 10980, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__908)) __PYX_ERR(2, 10980, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":10990
 *         return GiacMethods['lp_maximize'](self,*args)
 * 
 *      def lp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_method:
 */
  __pyx_codeobj__909 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_method, 10990, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__909)) __PYX_ERR(2, 10990, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11000
 *         return GiacMethods['lp_method'](self,*args)
 * 
 *      def lp_mostfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_mostfractional:
 */
  __pyx_codeobj__910 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_mostfractional, 11000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__910)) __PYX_ERR(2, 11000, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11010
 *         return GiacMethods['lp_mostfractional'](self,*args)
 * 
 *      def lp_nodelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodelimit:
 */
  __pyx_codeobj__911 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_nodelimit, 11010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__911)) __PYX_ERR(2, 11010, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11020
 *         return GiacMethods['lp_nodelimit'](self,*args)
 * 
 *      def lp_nodeselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodeselect:
 */
  __pyx_codeobj__912 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_nodeselect, 11020, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__912)) __PYX_ERR(2, 11020, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11030
 *         return GiacMethods['lp_nodeselect'](self,*args)
 * 
 *      def lp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegative:
 */
  __pyx_codeobj__913 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_nonnegative, 11030, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__913)) __PYX_ERR(2, 11030, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11040
 *         return GiacMethods['lp_nonnegative'](self,*args)
 * 
 *      def lp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegint:
 */
  __pyx_codeobj__914 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_nonnegint, 11040, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__914)) __PYX_ERR(2, 11040, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11050
 *         return GiacMethods['lp_nonnegint'](self,*args)
 * 
 *      def lp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_presolve:
 */
  __pyx_codeobj__915 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_presolve, 11050, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__915)) __PYX_ERR(2, 11050, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11060
 *         return GiacMethods['lp_presolve'](self,*args)
 * 
 *      def lp_pseudocost(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_pseudocost:
 */
  __pyx_codeobj__916 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_pseudocost, 11060, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__916)) __PYX_ERR(2, 11060, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11070
 *         return GiacMethods['lp_pseudocost'](self,*args)
 * 
 *      def lp_simplex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_simplex:
 */
  __pyx_codeobj__917 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_simplex, 11070, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__917)) __PYX_ERR(2, 11070, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11080
 *         return GiacMethods['lp_simplex'](self,*args)
 * 
 *      def lp_timelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_timelimit:
 */
  __pyx_codeobj__918 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_timelimit, 11080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__918)) __PYX_ERR(2, 11080, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11090
 *         return GiacMethods['lp_timelimit'](self,*args)
 * 
 *      def lp_varselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_varselect:
 */
  __pyx_codeobj__919 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_varselect, 11090, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__919)) __PYX_ERR(2, 11090, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11100
 *         return GiacMethods['lp_varselect'](self,*args)
 * 
 *      def lp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_verbose:
 */
  __pyx_codeobj__920 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lp_verbose, 11100, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__920)) __PYX_ERR(2, 11100, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11110
 *         return GiacMethods['lp_verbose'](self,*args)
 * 
 *      def lpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lpsolve:
 */
  __pyx_codeobj__921 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lpsolve, 11110, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__921)) __PYX_ERR(2, 11110, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11127
 *         return GiacMethods['lpsolve'](self,*args)
 * 
 *      def lsmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsmod:
 */
  __pyx_codeobj__922 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lsmod, 11127, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__922)) __PYX_ERR(2, 11127, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11138
 *         return GiacMethods['lsmod'](self,*args)
 * 
 *      def lsq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsq:
 */
  __pyx_codeobj__923 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lsq, 11138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__923)) __PYX_ERR(2, 11138, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11150
 *         return GiacMethods['lsq'](self,*args)
 * 
 *      def lu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lu:
 */
  __pyx_codeobj__924 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lu, 11150, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__924)) __PYX_ERR(2, 11150, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11162
 *         return GiacMethods['lu'](self,*args)
 * 
 *      def lvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lvar:
 */
  __pyx_codeobj__925 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_lvar, 11162, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__925)) __PYX_ERR(2, 11162, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11174
 *         return GiacMethods['lvar'](self,*args)
 * 
 *      def mRow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRow:
 */
  __pyx_codeobj__926 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mRow, 11174, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__926)) __PYX_ERR(2, 11174, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11185
 *         return GiacMethods['mRow'](self,*args)
 * 
 *      def mRowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRowAdd:
 */
  __pyx_codeobj__927 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mRowAdd, 11185, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__927)) __PYX_ERR(2, 11185, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11196
 *         return GiacMethods['mRowAdd'](self,*args)
 * 
 *      def magenta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for magenta:
 */
  __pyx_codeobj__928 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_magenta, 11196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__928)) __PYX_ERR(2, 11196, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11208
 *         return GiacMethods['magenta'](self,*args)
 * 
 *      def make_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_directed:
 */
  __pyx_codeobj__929 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_make_directed, 11208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__929)) __PYX_ERR(2, 11208, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11219
 *         return GiacMethods['make_directed'](self,*args)
 * 
 *      def make_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_symbol:
 */
  __pyx_codeobj__930 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_make_symbol, 11219, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__930)) __PYX_ERR(2, 11219, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11230
 *         return GiacMethods['make_symbol'](self,*args)
 * 
 *      def make_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_weighted:
 */
  __pyx_codeobj__931 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_make_weighted, 11230, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__931)) __PYX_ERR(2, 11230, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11241
 *         return GiacMethods['make_weighted'](self,*args)
 * 
 *      def makelist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makelist:
 */
  __pyx_codeobj__932 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_makelist, 11241, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__932)) __PYX_ERR(2, 11241, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11255
 *         return GiacMethods['makelist'](self,*args)
 * 
 *      def makemat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makemat:
 */
  __pyx_codeobj__933 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_makemat, 11255, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__933)) __PYX_ERR(2, 11255, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11268
 *         return GiacMethods['makemat'](self,*args)
 * 
 *      def makesuite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makesuite:
 */
  __pyx_codeobj__934 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_makesuite, 11268, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__934)) __PYX_ERR(2, 11268, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11279
 *         return GiacMethods['makesuite'](self,*args)
 * 
 *      def makevector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makevector:
 */
  __pyx_codeobj__935 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_makevector, 11279, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__935)) __PYX_ERR(2, 11279, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11290
 *         return GiacMethods['makevector'](self,*args)
 * 
 *      def map(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for map:
 */
  __pyx_codeobj__936 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_map, 11290, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__936)) __PYX_ERR(2, 11290, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11303
 *         return GiacMethods['map'](self,*args)
 * 
 *      def maple2mupad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2mupad:
 */
  __pyx_codeobj__937 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maple2mupad, 11303, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__937)) __PYX_ERR(2, 11303, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11313
 *         return GiacMethods['maple2mupad'](self,*args)
 * 
 *      def maple2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2xcas:
 */
  __pyx_codeobj__938 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maple2xcas, 11313, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__938)) __PYX_ERR(2, 11313, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11323
 *         return GiacMethods['maple2xcas'](self,*args)
 * 
 *      def maple_ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_ifactors:
 */
  __pyx_codeobj__939 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maple_ifactors, 11323, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__939)) __PYX_ERR(2, 11323, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11334
 *         return GiacMethods['maple_ifactors'](self,*args)
 * 
 *      def maple_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_mode:
 */
  __pyx_codeobj__940 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maple_mode, 11334, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__940)) __PYX_ERR(2, 11334, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11346
 *         return GiacMethods['maple_mode'](self,*args)
 * 
 *      def markov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for markov:
 */
  __pyx_codeobj__941 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_markov, 11346, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__941)) __PYX_ERR(2, 11346, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11357
 *         return GiacMethods['markov'](self,*args)
 * 
 *      def mat2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mat2list:
 */
  __pyx_codeobj__942 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mat2list, 11357, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__942)) __PYX_ERR(2, 11357, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11368
 *         return GiacMethods['mat2list'](self,*args)
 * 
 *      def mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mathml:
 */
  __pyx_codeobj__943 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mathml, 11368, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__943)) __PYX_ERR(2, 11368, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11379
 *         return GiacMethods['mathml'](self,*args)
 * 
 *      def matpow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matpow:
 */
  __pyx_codeobj__944 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_matpow, 11379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__944)) __PYX_ERR(2, 11379, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11390
 *         return GiacMethods['matpow'](self,*args)
 * 
 *      def matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix:
 */
  __pyx_codeobj__945 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_matrix, 11390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__945)) __PYX_ERR(2, 11390, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11404
 *         return GiacMethods['matrix'](self,*args)
 * 
 *      def matrix_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix_norm:
 */
  __pyx_codeobj__946 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_matrix_norm, 11404, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__946)) __PYX_ERR(2, 11404, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11418
 *         return GiacMethods['matrix_norm'](self,*args)
 * 
 *      def max(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for max:
 */
  __pyx_codeobj__947 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_max, 11418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__947)) __PYX_ERR(2, 11418, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11429
 *         return GiacMethods['max'](self,*args)
 * 
 *      def maxflow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxflow:
 */
  __pyx_codeobj__948 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maxflow, 11429, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__948)) __PYX_ERR(2, 11429, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11440
 *         return GiacMethods['maxflow'](self,*args)
 * 
 *      def maximal_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximal_independent_set:
 */
  __pyx_codeobj__949 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maximal_independent_set, 11440, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__949)) __PYX_ERR(2, 11440, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11451
 *         return GiacMethods['maximal_independent_set'](self,*args)
 * 
 *      def maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximize:
 */
  __pyx_codeobj__950 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maximize, 11451, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__950)) __PYX_ERR(2, 11451, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11468
 *         return GiacMethods['maximize'](self,*args)
 * 
 *      def maximum_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_clique:
 */
  __pyx_codeobj__951 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maximum_clique, 11468, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__951)) __PYX_ERR(2, 11468, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11479
 *         return GiacMethods['maximum_clique'](self,*args)
 * 
 *      def maximum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_degree:
 */
  __pyx_codeobj__952 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maximum_degree, 11479, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__952)) __PYX_ERR(2, 11479, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11490
 *         return GiacMethods['maximum_degree'](self,*args)
 * 
 *      def maximum_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_independent_set:
 */
  __pyx_codeobj__953 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maximum_independent_set, 11490, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__953)) __PYX_ERR(2, 11490, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11501
 *         return GiacMethods['maximum_independent_set'](self,*args)
 * 
 *      def maximum_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_matching:
 */
  __pyx_codeobj__954 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maximum_matching, 11501, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__954)) __PYX_ERR(2, 11501, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11512
 *         return GiacMethods['maximum_matching'](self,*args)
 * 
 *      def maxnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxnorm:
 */
  __pyx_codeobj__955 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_maxnorm, 11512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__955)) __PYX_ERR(2, 11512, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11525
 *         return GiacMethods['maxnorm'](self,*args)
 * 
 *      def mean(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mean:
 */
  __pyx_codeobj__956 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mean, 11525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__956)) __PYX_ERR(2, 11525, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11538
 *         return GiacMethods['mean'](self,*args)
 * 
 *      def median(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median:
 */
  __pyx_codeobj__957 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_median, 11538, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__957)) __PYX_ERR(2, 11538, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11550
 *         return GiacMethods['median'](self,*args)
 * 
 *      def median_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median_line:
 */
  __pyx_codeobj__958 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_median_line, 11550, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__958)) __PYX_ERR(2, 11550, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11561
 *         return GiacMethods['median_line'](self,*args)
 * 
 *      def member(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for member:
 */
  __pyx_codeobj__959 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_member, 11561, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__959)) __PYX_ERR(2, 11561, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11573
 *         return GiacMethods['member'](self,*args)
 * 
 *      def mgf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mgf:
 */
  __pyx_codeobj__960 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mgf, 11573, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__960)) __PYX_ERR(2, 11573, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11585
 *         return GiacMethods['mgf'](self,*args)
 * 
 *      def mid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mid:
 */
  __pyx_codeobj__961 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mid, 11585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__961)) __PYX_ERR(2, 11585, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11600
 *         return GiacMethods['mid'](self,*args)
 * 
 *      def middle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for middle_point:
 */
  __pyx_codeobj__962 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_middle_point, 11600, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__962)) __PYX_ERR(2, 11600, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11616
 *         return GiacMethods['middle_point'](self,*args)
 * 
 *      def midpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for midpoint:
 */
  __pyx_codeobj__963 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_midpoint, 11616, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__963)) __PYX_ERR(2, 11616, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11627
 *         return GiacMethods['midpoint'](self,*args)
 * 
 *      def min(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for min:
 */
  __pyx_codeobj__964 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_min, 11627, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__964)) __PYX_ERR(2, 11627, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11638
 *         return GiacMethods['min'](self,*args)
 * 
 *      def minimal_edge_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_edge_coloring:
 */
  __pyx_codeobj__965 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimal_edge_coloring, 11638, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__965)) __PYX_ERR(2, 11638, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11650
 *         return GiacMethods['minimal_edge_coloring'](self,*args)
 * 
 *      def minimal_spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_spanning_tree:
 */
  __pyx_codeobj__966 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimal_spanning_tree, 11650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__966)) __PYX_ERR(2, 11650, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11661
 *         return GiacMethods['minimal_spanning_tree'](self,*args)
 * 
 *      def minimal_vertex_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_vertex_coloring:
 */
  __pyx_codeobj__967 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimal_vertex_coloring, 11661, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__967)) __PYX_ERR(2, 11661, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11673
 *         return GiacMethods['minimal_vertex_coloring'](self,*args)
 * 
 *      def minimax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimax:
 */
  __pyx_codeobj__968 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimax, 11673, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__968)) __PYX_ERR(2, 11673, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11686
 *         return GiacMethods['minimax'](self,*args)
 * 
 *      def minimize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimize:
 */
  __pyx_codeobj__969 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimize, 11686, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__969)) __PYX_ERR(2, 11686, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11703
 *         return GiacMethods['minimize'](self,*args)
 * 
 *      def minimum_cut(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_cut:
 */
  __pyx_codeobj__970 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimum_cut, 11703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__970)) __PYX_ERR(2, 11703, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11714
 *         return GiacMethods['minimum_cut'](self,*args)
 * 
 *      def minimum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_degree:
 */
  __pyx_codeobj__971 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimum_degree, 11714, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__971)) __PYX_ERR(2, 11714, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11725
 *         return GiacMethods['minimum_degree'](self,*args)
 * 
 *      def minimum_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_vertex_cover:
 */
  __pyx_codeobj__972 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_minimum_vertex_cover, 11725, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__972)) __PYX_ERR(2, 11725, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11736
 *         return GiacMethods['minimum_vertex_cover'](self,*args)
 * 
 *      def mixdown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mixdown:
 */
  __pyx_codeobj__973 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mixdown, 11736, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__973)) __PYX_ERR(2, 11736, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11746
 *         return GiacMethods['mixdown'](self,*args)
 * 
 *      def mkisom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mkisom:
 */
  __pyx_codeobj__974 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mkisom, 11746, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__974)) __PYX_ERR(2, 11746, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11759
 *         return GiacMethods['mkisom'](self,*args)
 * 
 *      def mksa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mksa:
 */
  __pyx_codeobj__975 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mksa, 11759, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__975)) __PYX_ERR(2, 11759, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11770
 *         return GiacMethods['mksa'](self,*args)
 * 
 *      def modf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modf:
 */
  __pyx_codeobj__976 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_modf, 11770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__976)) __PYX_ERR(2, 11770, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11782
 *         return GiacMethods['modf'](self,*args)
 * 
 *      def modgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modgcd:
 */
  __pyx_codeobj__977 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_modgcd, 11782, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__977)) __PYX_ERR(2, 11782, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11793
 *         return GiacMethods['modgcd'](self,*args)
 * 
 *      def mods(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mods:
 */
  __pyx_codeobj__978 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mods, 11793, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__978)) __PYX_ERR(2, 11793, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11806
 *         return GiacMethods['mods'](self,*args)
 * 
 *      def momentum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for momentum:
 */
  __pyx_codeobj__979 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_momentum, 11806, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__979)) __PYX_ERR(2, 11806, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11816
 *         return GiacMethods['momentum'](self,*args)
 * 
 *      def monotonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for monotonic:
 */
  __pyx_codeobj__980 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_monotonic, 11816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__980)) __PYX_ERR(2, 11816, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11826
 *         return GiacMethods['monotonic'](self,*args)
 * 
 *      def montre_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for montre_tortue:
 */
  __pyx_codeobj__981 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_montre_tortue, 11826, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__981)) __PYX_ERR(2, 11826, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11837
 *         return GiacMethods['montre_tortue'](self,*args)
 * 
 *      def moustache(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moustache:
 */
  __pyx_codeobj__982 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_moustache, 11837, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__982)) __PYX_ERR(2, 11837, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11851
 *         return GiacMethods['moustache'](self,*args)
 * 
 *      def moving_average(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moving_average:
 */
  __pyx_codeobj__983 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_moving_average, 11851, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__983)) __PYX_ERR(2, 11851, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11862
 *         return GiacMethods['moving_average'](self,*args)
 * 
 *      def moyal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyal:
 */
  __pyx_codeobj__984 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_moyal, 11862, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__984)) __PYX_ERR(2, 11862, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11873
 *         return GiacMethods['moyal'](self,*args)
 * 
 *      def moyenne(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyenne:
 */
  __pyx_codeobj__985 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_moyenne, 11873, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__985)) __PYX_ERR(2, 11873, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11886
 *         return GiacMethods['moyenne'](self,*args)
 * 
 *      def mul(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mul:
 */
  __pyx_codeobj__986 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mul, 11886, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__986)) __PYX_ERR(2, 11886, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11903
 *         return GiacMethods['mul'](self,*args)
 * 
 *      def mult_c_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_c_conjugate:
 */
  __pyx_codeobj__987 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mult_c_conjugate, 11903, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__987)) __PYX_ERR(2, 11903, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11915
 *         return GiacMethods['mult_c_conjugate'](self,*args)
 * 
 *      def mult_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_conjugate:
 */
  __pyx_codeobj__988 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mult_conjugate, 11915, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__988)) __PYX_ERR(2, 11915, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11927
 *         return GiacMethods['mult_conjugate'](self,*args)
 * 
 *      def multinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multinomial:
 */
  __pyx_codeobj__989 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_multinomial, 11927, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__989)) __PYX_ERR(2, 11927, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11941
 *         return GiacMethods['multinomial'](self,*args)
 * 
 *      def multiplier_conjugue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue:
 */
  __pyx_codeobj__990 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_multiplier_conjugue, 11941, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__990)) __PYX_ERR(2, 11941, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11953
 *         return GiacMethods['multiplier_conjugue'](self,*args)
 * 
 *      def multiplier_conjugue_complexe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue_complexe:
 */
  __pyx_codeobj__991 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_multiplier_conjugue_complexe, 11953, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__991)) __PYX_ERR(2, 11953, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11965
 *         return GiacMethods['multiplier_conjugue_complexe'](self,*args)
 * 
 *      def multiply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiply:
 */
  __pyx_codeobj__992 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_multiply, 11965, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__992)) __PYX_ERR(2, 11965, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11978
 *         return GiacMethods['multiply'](self,*args)
 * 
 *      def mupad2maple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2maple:
 */
  __pyx_codeobj__993 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mupad2maple, 11978, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__993)) __PYX_ERR(2, 11978, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11988
 *         return GiacMethods['mupad2maple'](self,*args)
 * 
 *      def mupad2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2xcas:
 */
  __pyx_codeobj__994 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mupad2xcas, 11988, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__994)) __PYX_ERR(2, 11988, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":11998
 *         return GiacMethods['mupad2xcas'](self,*args)
 * 
 *      def mycielski(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mycielski:
 */
  __pyx_codeobj__995 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_mycielski, 11998, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__995)) __PYX_ERR(2, 11998, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12010
 *         return GiacMethods['mycielski'](self,*args)
 * 
 *      def nCr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nCr:
 */
  __pyx_codeobj__996 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nCr, 12010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__996)) __PYX_ERR(2, 12010, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12021
 *         return GiacMethods['nCr'](self,*args)
 * 
 *      def nDeriv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nDeriv:
 */
  __pyx_codeobj__997 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nDeriv, 12021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__997)) __PYX_ERR(2, 12021, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12034
 *         return GiacMethods['nDeriv'](self,*args)
 * 
 *      def nInt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nInt:
 */
  __pyx_codeobj__998 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nInt, 12034, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__998)) __PYX_ERR(2, 12034, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12047
 *         return GiacMethods['nInt'](self,*args)
 * 
 *      def nPr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nPr:
 */
  __pyx_codeobj__999 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nPr, 12047, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__999)) __PYX_ERR(2, 12047, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12058
 *         return GiacMethods['nPr'](self,*args)
 * 
 *      def nSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nSolve:
 */
  __pyx_codeobj__1000 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nSolve, 12058, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1000)) __PYX_ERR(2, 12058, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12070
 *         return GiacMethods['nSolve'](self,*args)
 * 
 *      def navy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for navy:
 */
  __pyx_codeobj__1001 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_navy, 12070, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1001)) __PYX_ERR(2, 12070, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12082
 *         return GiacMethods['navy'](self,*args)
 * 
 *      def ncols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ncols:
 */
  __pyx_codeobj__1002 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ncols, 12082, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1002)) __PYX_ERR(2, 12082, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12094
 *         return GiacMethods['ncols'](self,*args)
 * 
 *      def negbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial:
 */
  __pyx_codeobj__1003 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_negbinomial, 12094, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1003)) __PYX_ERR(2, 12094, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12107
 *         return GiacMethods['negbinomial'](self,*args)
 * 
 *      def negbinomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_cdf:
 */
  __pyx_codeobj__1004 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_negbinomial_cdf, 12107, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1004)) __PYX_ERR(2, 12107, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12120
 *         return GiacMethods['negbinomial_cdf'](self,*args)
 * 
 *      def negbinomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_icdf:
 */
  __pyx_codeobj__1005 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_negbinomial_icdf, 12120, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1005)) __PYX_ERR(2, 12120, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12132
 *         return GiacMethods['negbinomial_icdf'](self,*args)
 * 
 *      def neighbors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neighbors:
 */
  __pyx_codeobj__1006 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_neighbors, 12132, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1006)) __PYX_ERR(2, 12132, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12143
 *         return GiacMethods['neighbors'](self,*args)
 * 
 *      def network_transitivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for network_transitivity:
 */
  __pyx_codeobj__1007 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_network_transitivity, 12143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1007)) __PYX_ERR(2, 12143, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12154
 *         return GiacMethods['network_transitivity'](self,*args)
 * 
 *      def neural_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neural_network:
 */
  __pyx_codeobj__1008 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_neural_network, 12154, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1008)) __PYX_ERR(2, 12154, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12166
 *         return GiacMethods['neural_network'](self,*args)
 * 
 *      def newList(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newList:
 */
  __pyx_codeobj__1009 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_newList, 12166, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1009)) __PYX_ERR(2, 12166, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12177
 *         return GiacMethods['newList'](self,*args)
 * 
 *      def newMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newMat:
 */
  __pyx_codeobj__1010 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_newMat, 12177, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1010)) __PYX_ERR(2, 12177, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12188
 *         return GiacMethods['newMat'](self,*args)
 * 
 *      def newton(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton:
 */
  __pyx_codeobj__1011 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_newton, 12188, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1011)) __PYX_ERR(2, 12188, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12202
 *         return GiacMethods['newton'](self,*args)
 * 
 *      def newton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton_solver:
 */
  __pyx_codeobj__1012 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_newton_solver, 12202, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1012)) __PYX_ERR(2, 12202, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12218
 *         return GiacMethods['newton_solver'](self,*args)
 * 
 *      def newtonj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newtonj_solver:
 */
  __pyx_codeobj__1013 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_newtonj_solver, 12218, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1013)) __PYX_ERR(2, 12218, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12234
 *         return GiacMethods['newtonj_solver'](self,*args)
 * 
 *      def nextperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextperm:
 */
  __pyx_codeobj__1014 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nextperm, 12234, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1014)) __PYX_ERR(2, 12234, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12246
 *         return GiacMethods['nextperm'](self,*args)
 * 
 *      def nextprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextprime:
 */
  __pyx_codeobj__1015 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nextprime, 12246, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1015)) __PYX_ERR(2, 12246, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12258
 *         return GiacMethods['nextprime'](self,*args)
 * 
 *      def nlp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binary:
 */
  __pyx_codeobj__1016 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_binary, 12258, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1016)) __PYX_ERR(2, 12258, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12268
 *         return GiacMethods['nlp_binary'](self,*args)
 * 
 *      def nlp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binaryvariables:
 */
  __pyx_codeobj__1017 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_binaryvariables, 12268, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1017)) __PYX_ERR(2, 12268, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12278
 *         return GiacMethods['nlp_binaryvariables'](self,*args)
 * 
 *      def nlp_initialpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_initialpoint:
 */
  __pyx_codeobj__1018 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_initialpoint, 12278, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1018)) __PYX_ERR(2, 12278, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12288
 *         return GiacMethods['nlp_initialpoint'](self,*args)
 * 
 *      def nlp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integer:
 */
  __pyx_codeobj__1019 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_integer, 12288, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1019)) __PYX_ERR(2, 12288, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12298
 *         return GiacMethods['nlp_integer'](self,*args)
 * 
 *      def nlp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integervariables:
 */
  __pyx_codeobj__1020 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_integervariables, 12298, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1020)) __PYX_ERR(2, 12298, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12308
 *         return GiacMethods['nlp_integervariables'](self,*args)
 * 
 *      def nlp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_iterationlimit:
 */
  __pyx_codeobj__1021 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_iterationlimit, 12308, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1021)) __PYX_ERR(2, 12308, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12318
 *         return GiacMethods['nlp_iterationlimit'](self,*args)
 * 
 *      def nlp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_maximize:
 */
  __pyx_codeobj__1022 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_maximize, 12318, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1022)) __PYX_ERR(2, 12318, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12328
 *         return GiacMethods['nlp_maximize'](self,*args)
 * 
 *      def nlp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_method:
 */
  __pyx_codeobj__1023 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_method, 12328, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1023)) __PYX_ERR(2, 12328, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12338
 *         return GiacMethods['nlp_method'](self,*args)
 * 
 *      def nlp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegative:
 */
  __pyx_codeobj__1024 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_nonnegative, 12338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1024)) __PYX_ERR(2, 12338, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12348
 *         return GiacMethods['nlp_nonnegative'](self,*args)
 * 
 *      def nlp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegint:
 */
  __pyx_codeobj__1025 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_nonnegint, 12348, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1025)) __PYX_ERR(2, 12348, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12358
 *         return GiacMethods['nlp_nonnegint'](self,*args)
 * 
 *      def nlp_precision(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_precision:
 */
  __pyx_codeobj__1026 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_precision, 12358, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1026)) __PYX_ERR(2, 12358, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12368
 *         return GiacMethods['nlp_precision'](self,*args)
 * 
 *      def nlp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_presolve:
 */
  __pyx_codeobj__1027 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_presolve, 12368, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1027)) __PYX_ERR(2, 12368, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12378
 *         return GiacMethods['nlp_presolve'](self,*args)
 * 
 *      def nlp_tolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_tolerance:
 */
  __pyx_codeobj__1028 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_tolerance, 12378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1028)) __PYX_ERR(2, 12378, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12388
 *         return GiacMethods['nlp_tolerance'](self,*args)
 * 
 *      def nlp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_verbose:
 */
  __pyx_codeobj__1029 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlp_verbose, 12388, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1029)) __PYX_ERR(2, 12388, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12398
 *         return GiacMethods['nlp_verbose'](self,*args)
 * 
 *      def nlpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlpsolve:
 */
  __pyx_codeobj__1030 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nlpsolve, 12398, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1030)) __PYX_ERR(2, 12398, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12413
 *         return GiacMethods['nlpsolve'](self,*args)
 * 
 *      def nodisp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nodisp:
 */
  __pyx_codeobj__1031 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nodisp, 12413, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1031)) __PYX_ERR(2, 12413, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12423
 *         return GiacMethods['nodisp'](self,*args)
 * 
 *      def non_recursive_normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for non_recursive_normal:
 */
  __pyx_codeobj__1032 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_non_recursive_normal, 12423, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1032)) __PYX_ERR(2, 12423, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12435
 *         return GiacMethods['non_recursive_normal'](self,*args)
 * 
 *      def nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nonnegint:
 */
  __pyx_codeobj__1033 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nonnegint, 12435, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1033)) __PYX_ERR(2, 12435, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12445
 *         return GiacMethods['nonnegint'](self,*args)
 * 
 *      def nop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nop:
 */
  __pyx_codeobj__1034 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nop, 12445, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1034)) __PYX_ERR(2, 12445, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12456
 *         return GiacMethods['nop'](self,*args)
 * 
 *      def nops(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nops:
 */
  __pyx_codeobj__1035 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nops, 12456, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1035)) __PYX_ERR(2, 12456, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12469
 *         return GiacMethods['nops'](self,*args)
 * 
 *      def norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for norm:
 */
  __pyx_codeobj__1036 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_norm, 12469, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1036)) __PYX_ERR(2, 12469, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12483
 *         return GiacMethods['norm'](self,*args)
 * 
 *      def normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal:
 */
  __pyx_codeobj__1037 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normal, 12483, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1037)) __PYX_ERR(2, 12483, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12496
 *         return GiacMethods['normal'](self,*args)
 * 
 *      def normal_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_cdf:
 */
  __pyx_codeobj__1038 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normal_cdf, 12496, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1038)) __PYX_ERR(2, 12496, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12509
 *         return GiacMethods['normal_cdf'](self,*args)
 * 
 *      def normal_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_icdf:
 */
  __pyx_codeobj__1039 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normal_icdf, 12509, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1039)) __PYX_ERR(2, 12509, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12521
 *         return GiacMethods['normal_icdf'](self,*args)
 * 
 *      def normald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald:
 */
  __pyx_codeobj__1040 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normald, 12521, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1040)) __PYX_ERR(2, 12521, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12535
 *         return GiacMethods['normald'](self,*args)
 * 
 *      def normald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_cdf:
 */
  __pyx_codeobj__1041 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normald_cdf, 12535, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1041)) __PYX_ERR(2, 12535, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12548
 *         return GiacMethods['normald_cdf'](self,*args)
 * 
 *      def normald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_icdf:
 */
  __pyx_codeobj__1042 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normald_icdf, 12548, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1042)) __PYX_ERR(2, 12548, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12560
 *         return GiacMethods['normald_icdf'](self,*args)
 * 
 *      def normalize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalize:
 */
  __pyx_codeobj__1043 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normalize, 12560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1043)) __PYX_ERR(2, 12560, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12574
 *         return GiacMethods['normalize'](self,*args)
 * 
 *      def normalt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalt:
 */
  __pyx_codeobj__1044 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normalt, 12574, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1044)) __PYX_ERR(2, 12574, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12586
 *         return GiacMethods['normalt'](self,*args)
 * 
 *      def normalvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalvariate:
 */
  __pyx_codeobj__1045 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_normalvariate, 12586, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1045)) __PYX_ERR(2, 12586, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12598
 *         return GiacMethods['normalvariate'](self,*args)
 * 
 *      def nprimes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nprimes:
 */
  __pyx_codeobj__1046 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nprimes, 12598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1046)) __PYX_ERR(2, 12598, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12609
 *         return GiacMethods['nprimes'](self,*args)
 * 
 *      def nrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nrows:
 */
  __pyx_codeobj__1047 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nrows, 12609, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1047)) __PYX_ERR(2, 12609, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12621
 *         return GiacMethods['nrows'](self,*args)
 * 
 *      def nstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nstep:
 */
  __pyx_codeobj__1048 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nstep, 12621, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1048)) __PYX_ERR(2, 12621, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12630
 *         return GiacMethods['nstep'](self,*args)
 * 
 *      def nuage_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nuage_points:
 */
  __pyx_codeobj__1049 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nuage_points, 12630, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1049)) __PYX_ERR(2, 12630, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12641
 *         return GiacMethods['nuage_points'](self,*args)
 * 
 *      def nullspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nullspace:
 */
  __pyx_codeobj__1050 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_nullspace, 12641, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1050)) __PYX_ERR(2, 12641, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12653
 *         return GiacMethods['nullspace'](self,*args)
 * 
 *      def number_of_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_edges:
 */
  __pyx_codeobj__1051 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_number_of_edges, 12653, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1051)) __PYX_ERR(2, 12653, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12664
 *         return GiacMethods['number_of_edges'](self,*args)
 * 
 *      def number_of_spanning_trees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_spanning_trees:
 */
  __pyx_codeobj__1052 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_number_of_spanning_trees, 12664, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1052)) __PYX_ERR(2, 12664, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12676
 *         return GiacMethods['number_of_spanning_trees'](self,*args)
 * 
 *      def number_of_triangles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_triangles:
 */
  __pyx_codeobj__1053 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_number_of_triangles, 12676, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1053)) __PYX_ERR(2, 12676, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12687
 *         return GiacMethods['number_of_triangles'](self,*args)
 * 
 *      def number_of_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_vertices:
 */
  __pyx_codeobj__1054 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_number_of_vertices, 12687, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1054)) __PYX_ERR(2, 12687, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12698
 *         return GiacMethods['number_of_vertices'](self,*args)
 * 
 *      def numdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numdiff:
 */
  __pyx_codeobj__1055 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_numdiff, 12698, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1055)) __PYX_ERR(2, 12698, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12710
 *         return GiacMethods['numdiff'](self,*args)
 * 
 *      def numer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numer:
 */
  __pyx_codeobj__1056 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_numer, 12710, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1056)) __PYX_ERR(2, 12710, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12723
 *         return GiacMethods['numer'](self,*args)
 * 
 *      def octahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for octahedron:
 */
  __pyx_codeobj__1057 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_octahedron, 12723, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1057)) __PYX_ERR(2, 12723, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12735
 *         return GiacMethods['octahedron'](self,*args)
 * 
 *      def odd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd:
 */
  __pyx_codeobj__1058 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_odd, 12735, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1058)) __PYX_ERR(2, 12735, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12747
 *         return GiacMethods['odd'](self,*args)
 * 
 *      def odd_girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_girth:
 */
  __pyx_codeobj__1059 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_odd_girth, 12747, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1059)) __PYX_ERR(2, 12747, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12759
 *         return GiacMethods['odd_girth'](self,*args)
 * 
 *      def odd_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_graph:
 */
  __pyx_codeobj__1060 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_odd_graph, 12759, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1060)) __PYX_ERR(2, 12759, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12770
 *         return GiacMethods['odd_graph'](self,*args)
 * 
 *      def odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odeplot:
 */
  __pyx_codeobj__1061 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_odeplot, 12770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1061)) __PYX_ERR(2, 12770, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12787
 *         return GiacMethods['odeplot'](self,*args)
 * 
 *      def odesolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odesolve:
 */
  __pyx_codeobj__1062 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_odesolve, 12787, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1062)) __PYX_ERR(2, 12787, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12802
 *         return GiacMethods['odesolve'](self,*args)
 * 
 *      def olive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for olive:
 */
  __pyx_codeobj__1063 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_olive, 12802, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1063)) __PYX_ERR(2, 12802, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12814
 *         return GiacMethods['olive'](self,*args)
 * 
 *      def op(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for op:
 */
  __pyx_codeobj__1064 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_op, 12814, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1064)) __PYX_ERR(2, 12814, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12829
 *         return GiacMethods['op'](self,*args)
 * 
 *      def open_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for open_polygon:
 */
  __pyx_codeobj__1065 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_open_polygon, 12829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1065)) __PYX_ERR(2, 12829, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12841
 *         return GiacMethods['open_polygon'](self,*args)
 * 
 *      def orange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orange:
 */
  __pyx_codeobj__1066 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_orange, 12841, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1066)) __PYX_ERR(2, 12841, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12853
 *         return GiacMethods['orange'](self,*args)
 * 
 *      def ord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ord:
 */
  __pyx_codeobj__1067 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ord, 12853, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1067)) __PYX_ERR(2, 12853, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12866
 *         return GiacMethods['ord'](self,*args)
 * 
 *      def order(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order:
 */
  __pyx_codeobj__1068 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_order, 12866, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1068)) __PYX_ERR(2, 12866, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12877
 *         return GiacMethods['order'](self,*args)
 * 
 *      def order_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order_size:
 */
  __pyx_codeobj__1069 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_order_size, 12877, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1069)) __PYX_ERR(2, 12877, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12889
 *         return GiacMethods['order_size'](self,*args)
 * 
 *      def ordinate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ordinate:
 */
  __pyx_codeobj__1070 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ordinate, 12889, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1070)) __PYX_ERR(2, 12889, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12903
 *         return GiacMethods['ordinate'](self,*args)
 * 
 *      def orthocenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthocenter:
 */
  __pyx_codeobj__1071 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_orthocenter, 12903, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1071)) __PYX_ERR(2, 12903, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12916
 *         return GiacMethods['orthocenter'](self,*args)
 * 
 *      def orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthogonal:
 */
  __pyx_codeobj__1072 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_orthogonal, 12916, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1072)) __PYX_ERR(2, 12916, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12928
 *         return GiacMethods['orthogonal'](self,*args)
 * 
 *      def osculating_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for osculating_circle:
 */
  __pyx_codeobj__1073 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_osculating_circle, 12928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1073)) __PYX_ERR(2, 12928, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12944
 *         return GiacMethods['osculating_circle'](self,*args)
 * 
 *      def p1oc2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1oc2:
 */
  __pyx_codeobj__1074 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_p1oc2, 12944, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1074)) __PYX_ERR(2, 12944, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12955
 *         return GiacMethods['p1oc2'](self,*args)
 * 
 *      def p1op2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1op2:
 */
  __pyx_codeobj__1075 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_p1op2, 12955, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1075)) __PYX_ERR(2, 12955, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12966
 *         return GiacMethods['p1op2'](self,*args)
 * 
 *      def pa2b2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pa2b2:
 */
  __pyx_codeobj__1076 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pa2b2, 12966, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1076)) __PYX_ERR(2, 12966, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12978
 *         return GiacMethods['pa2b2'](self,*args)
 * 
 *      def pade(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pade:
 */
  __pyx_codeobj__1077 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pade, 12978, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1077)) __PYX_ERR(2, 12978, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":12989
 *         return GiacMethods['pade'](self,*args)
 * 
 *      def paley_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paley_graph:
 */
  __pyx_codeobj__1078 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_paley_graph, 12989, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1078)) __PYX_ERR(2, 12989, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13001
 *         return GiacMethods['paley_graph'](self,*args)
 * 
 *      def parabola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parabola:
 */
  __pyx_codeobj__1079 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parabola, 13001, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1079)) __PYX_ERR(2, 13001, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13015
 *         return GiacMethods['parabola'](self,*args)
 * 
 *      def parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallel:
 */
  __pyx_codeobj__1080 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parallel, 13015, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1080)) __PYX_ERR(2, 13015, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13032
 *         return GiacMethods['parallel'](self,*args)
 * 
 *      def parallelepiped(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelepiped:
 */
  __pyx_codeobj__1081 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parallelepiped, 13032, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1081)) __PYX_ERR(2, 13032, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13044
 *         return GiacMethods['parallelepiped'](self,*args)
 * 
 *      def parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelogram:
 */
  __pyx_codeobj__1082 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parallelogram, 13044, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1082)) __PYX_ERR(2, 13044, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13058
 *         return GiacMethods['parallelogram'](self,*args)
 * 
 *      def parameq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameq:
 */
  __pyx_codeobj__1083 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parameq, 13058, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1083)) __PYX_ERR(2, 13058, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13070
 *         return GiacMethods['parameq'](self,*args)
 * 
 *      def parameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameter:
 */
  __pyx_codeobj__1084 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parameter, 13070, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1084)) __PYX_ERR(2, 13070, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13080
 *         return GiacMethods['parameter'](self,*args)
 * 
 *      def paramplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paramplot:
 */
  __pyx_codeobj__1085 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_paramplot, 13080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1085)) __PYX_ERR(2, 13080, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13098
 *         return GiacMethods['paramplot'](self,*args)
 * 
 *      def parfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parfrac:
 */
  __pyx_codeobj__1086 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parfrac, 13098, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1086)) __PYX_ERR(2, 13098, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13110
 *         return GiacMethods['parfrac'](self,*args)
 * 
 *      def pari(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pari:
 */
  __pyx_codeobj__1087 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pari, 13110, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1087)) __PYX_ERR(2, 13110, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13128
 *         return GiacMethods['pari'](self,*args)
 * 
 *      def part(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for part:
 */
  __pyx_codeobj__1088 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_part, 13128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1088)) __PYX_ERR(2, 13128, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13142
 *         return GiacMethods['part'](self,*args)
 * 
 *      def partfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for partfrac:
 */
  __pyx_codeobj__1089 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_partfrac, 13142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1089)) __PYX_ERR(2, 13142, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13156
 *         return GiacMethods['partfrac'](self,*args)
 * 
 *      def parzen_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parzen_window:
 */
  __pyx_codeobj__1090 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_parzen_window, 13156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1090)) __PYX_ERR(2, 13156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13167
 *         return GiacMethods['parzen_window'](self,*args)
 * 
 *      def pas_de_cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pas_de_cote:
 */
  __pyx_codeobj__1091 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pas_de_cote, 13167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1091)) __PYX_ERR(2, 13167, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13179
 *         return GiacMethods['pas_de_cote'](self,*args)
 * 
 *      def path_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for path_graph:
 */
  __pyx_codeobj__1092 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_path_graph, 13179, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1092)) __PYX_ERR(2, 13179, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13190
 *         return GiacMethods['path_graph'](self,*args)
 * 
 *      def pcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar:
 */
  __pyx_codeobj__1093 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pcar, 13190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1093)) __PYX_ERR(2, 13190, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13204
 *         return GiacMethods['pcar'](self,*args)
 * 
 *      def pcar_hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar_hessenberg:
 */
  __pyx_codeobj__1094 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pcar_hessenberg, 13204, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1094)) __PYX_ERR(2, 13204, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13217
 *         return GiacMethods['pcar_hessenberg'](self,*args)
 * 
 *      def pcoef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoef:
 */
  __pyx_codeobj__1095 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pcoef, 13217, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1095)) __PYX_ERR(2, 13217, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13229
 *         return GiacMethods['pcoef'](self,*args)
 * 
 *      def pcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoeff:
 */
  __pyx_codeobj__1096 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pcoeff, 13229, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1096)) __PYX_ERR(2, 13229, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13241
 *         return GiacMethods['pcoeff'](self,*args)
 * 
 *      def pencolor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pencolor:
 */
  __pyx_codeobj__1097 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pencolor, 13241, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1097)) __PYX_ERR(2, 13241, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13255
 *         return GiacMethods['pencolor'](self,*args)
 * 
 *      def pendown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pendown:
 */
  __pyx_codeobj__1098 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pendown, 13255, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1098)) __PYX_ERR(2, 13255, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13266
 *         return GiacMethods['pendown'](self,*args)
 * 
 *      def penup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for penup:
 */
  __pyx_codeobj__1099 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_penup, 13266, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1099)) __PYX_ERR(2, 13266, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13277
 *         return GiacMethods['penup'](self,*args)
 * 
 *      def perimeter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeter:
 */
  __pyx_codeobj__1100 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perimeter, 13277, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1100)) __PYX_ERR(2, 13277, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13291
 *         return GiacMethods['perimeter'](self,*args)
 * 
 *      def perimeterat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeterat:
 */
  __pyx_codeobj__1101 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perimeterat, 13291, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1101)) __PYX_ERR(2, 13291, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13306
 *         return GiacMethods['perimeterat'](self,*args)
 * 
 *      def perimeteratraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeteratraw:
 */
  __pyx_codeobj__1102 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perimeteratraw, 13306, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1102)) __PYX_ERR(2, 13306, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13321
 *         return GiacMethods['perimeteratraw'](self,*args)
 * 
 *      def period(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for period:
 */
  __pyx_codeobj__1103 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_period, 13321, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1103)) __PYX_ERR(2, 13321, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13334
 *         return GiacMethods['period'](self,*args)
 * 
 *      def periodic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for periodic:
 */
  __pyx_codeobj__1104 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_periodic, 13334, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1104)) __PYX_ERR(2, 13334, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13346
 *         return GiacMethods['periodic'](self,*args)
 * 
 *      def perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perm:
 */
  __pyx_codeobj__1105 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perm, 13346, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1105)) __PYX_ERR(2, 13346, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13357
 *         return GiacMethods['perm'](self,*args)
 * 
 *      def perminv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perminv:
 */
  __pyx_codeobj__1106 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perminv, 13357, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1106)) __PYX_ERR(2, 13357, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13368
 *         return GiacMethods['perminv'](self,*args)
 * 
 *      def permu2cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2cycles:
 */
  __pyx_codeobj__1107 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_permu2cycles, 13368, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1107)) __PYX_ERR(2, 13368, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13380
 *         return GiacMethods['permu2cycles'](self,*args)
 * 
 *      def permu2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2mat:
 */
  __pyx_codeobj__1108 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_permu2mat, 13380, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1108)) __PYX_ERR(2, 13380, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13391
 *         return GiacMethods['permu2mat'](self,*args)
 * 
 *      def permuorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permuorder:
 */
  __pyx_codeobj__1109 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_permuorder, 13391, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1109)) __PYX_ERR(2, 13391, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13402
 *         return GiacMethods['permuorder'](self,*args)
 * 
 *      def permute_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permute_vertices:
 */
  __pyx_codeobj__1110 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_permute_vertices, 13402, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1110)) __PYX_ERR(2, 13402, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13413
 *         return GiacMethods['permute_vertices'](self,*args)
 * 
 *      def perpen_bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpen_bisector:
 */
  __pyx_codeobj__1111 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perpen_bisector, 13413, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1111)) __PYX_ERR(2, 13413, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13425
 *         return GiacMethods['perpen_bisector'](self,*args)
 * 
 *      def perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpendicular:
 */
  __pyx_codeobj__1112 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_perpendicular, 13425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1112)) __PYX_ERR(2, 13425, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13439
 *         return GiacMethods['perpendicular'](self,*args)
 * 
 *      def petersen_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for petersen_graph:
 */
  __pyx_codeobj__1113 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_petersen_graph, 13439, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1113)) __PYX_ERR(2, 13439, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13452
 *         return GiacMethods['petersen_graph'](self,*args)
 * 
 *      def peval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for peval:
 */
  __pyx_codeobj__1114 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_peval, 13452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1114)) __PYX_ERR(2, 13452, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13464
 *         return GiacMethods['peval'](self,*args)
 * 
 *      def pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pi:
 */
  __pyx_codeobj__1115 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pi, 13464, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1115)) __PYX_ERR(2, 13464, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13478
 *         return GiacMethods['pi'](self,*args)
 * 
 *      def pie(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pie:
 */
  __pyx_codeobj__1116 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pie, 13478, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1116)) __PYX_ERR(2, 13478, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13491
 *         return GiacMethods['pie'](self,*args)
 * 
 *      def piecewise(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for piecewise:
 */
  __pyx_codeobj__1117 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_piecewise, 13491, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1117)) __PYX_ERR(2, 13491, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13503
 *         return GiacMethods['piecewise'](self,*args)
 * 
 *      def pink(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pink:
 */
  __pyx_codeobj__1118 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pink, 13503, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1118)) __PYX_ERR(2, 13503, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13515
 *         return GiacMethods['pink'](self,*args)
 * 
 *      def pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pivot:
 */
  __pyx_codeobj__1119 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pivot, 13515, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1119)) __PYX_ERR(2, 13515, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13527
 *         return GiacMethods['pivot'](self,*args)
 * 
 *      def pixoff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixoff:
 */
  __pyx_codeobj__1120 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pixoff, 13527, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1120)) __PYX_ERR(2, 13527, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13538
 *         return GiacMethods['pixoff'](self,*args)
 * 
 *      def pixon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixon:
 */
  __pyx_codeobj__1121 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pixon, 13538, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1121)) __PYX_ERR(2, 13538, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13549
 *         return GiacMethods['pixon'](self,*args)
 * 
 *      def planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for planar:
 */
  __pyx_codeobj__1122 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_planar, 13549, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1122)) __PYX_ERR(2, 13549, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13559
 *         return GiacMethods['planar'](self,*args)
 * 
 *      def plane(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane:
 */
  __pyx_codeobj__1123 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plane, 13559, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1123)) __PYX_ERR(2, 13559, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13573
 *         return GiacMethods['plane'](self,*args)
 * 
 *      def plane_dual(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane_dual:
 */
  __pyx_codeobj__1124 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plane_dual, 13573, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1124)) __PYX_ERR(2, 13573, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13584
 *         return GiacMethods['plane_dual'](self,*args)
 * 
 *      def playsnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for playsnd:
 */
  __pyx_codeobj__1125 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_playsnd, 13584, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1125)) __PYX_ERR(2, 13584, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13595
 *         return GiacMethods['playsnd'](self,*args)
 * 
 *      def plex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plex:
 */
  __pyx_codeobj__1126 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plex, 13595, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1126)) __PYX_ERR(2, 13595, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13605
 *         return GiacMethods['plex'](self,*args)
 * 
 *      def plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot:
 */
  __pyx_codeobj__1127 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plot, 13605, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1127)) __PYX_ERR(2, 13605, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13622
 *         return GiacMethods['plot'](self,*args)
 * 
 *      def plot3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot3d:
 */
  __pyx_codeobj__1128 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plot3d, 13622, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1128)) __PYX_ERR(2, 13622, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13637
 *         return GiacMethods['plot3d'](self,*args)
 * 
 *      def plotarea(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotarea:
 */
  __pyx_codeobj__1129 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotarea, 13637, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1129)) __PYX_ERR(2, 13637, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13650
 *         return GiacMethods['plotarea'](self,*args)
 * 
 *      def plotcdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcdf:
 */
  __pyx_codeobj__1130 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotcdf, 13650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1130)) __PYX_ERR(2, 13650, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13663
 *         return GiacMethods['plotcdf'](self,*args)
 * 
 *      def plotcontour(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcontour:
 */
  __pyx_codeobj__1131 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotcontour, 13663, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1131)) __PYX_ERR(2, 13663, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13677
 *         return GiacMethods['plotcontour'](self,*args)
 * 
 *      def plotdensity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotdensity:
 */
  __pyx_codeobj__1132 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotdensity, 13677, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1132)) __PYX_ERR(2, 13677, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13689
 *         return GiacMethods['plotdensity'](self,*args)
 * 
 *      def plotfield(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfield:
 */
  __pyx_codeobj__1133 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotfield, 13689, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1133)) __PYX_ERR(2, 13689, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13704
 *         return GiacMethods['plotfield'](self,*args)
 * 
 *      def plotfunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfunc:
 */
  __pyx_codeobj__1134 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotfunc, 13704, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1134)) __PYX_ERR(2, 13704, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13719
 *         return GiacMethods['plotfunc'](self,*args)
 * 
 *      def plotimf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimf:
 */
  __pyx_codeobj__1135 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotimf, 13719, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1135)) __PYX_ERR(2, 13719, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13730
 *         return GiacMethods['plotimf'](self,*args)
 * 
 *      def plotimplicit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimplicit:
 */
  __pyx_codeobj__1136 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotimplicit, 13730, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1136)) __PYX_ERR(2, 13730, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13749
 *         return GiacMethods['plotimplicit'](self,*args)
 * 
 *      def plotinequation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotinequation:
 */
  __pyx_codeobj__1137 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotinequation, 13749, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1137)) __PYX_ERR(2, 13749, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13763
 *         return GiacMethods['plotinequation'](self,*args)
 * 
 *      def plotlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotlist:
 */
  __pyx_codeobj__1138 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotlist, 13763, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1138)) __PYX_ERR(2, 13763, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13776
 *         return GiacMethods['plotlist'](self,*args)
 * 
 *      def plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotode:
 */
  __pyx_codeobj__1139 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotode, 13776, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1139)) __PYX_ERR(2, 13776, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13793
 *         return GiacMethods['plotode'](self,*args)
 * 
 *      def plotparam(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotparam:
 */
  __pyx_codeobj__1140 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotparam, 13793, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1140)) __PYX_ERR(2, 13793, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13811
 *         return GiacMethods['plotparam'](self,*args)
 * 
 *      def plotpolar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotpolar:
 */
  __pyx_codeobj__1141 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotpolar, 13811, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1141)) __PYX_ERR(2, 13811, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13823
 *         return GiacMethods['plotpolar'](self,*args)
 * 
 *      def plotproba(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotproba:
 */
  __pyx_codeobj__1142 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotproba, 13823, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1142)) __PYX_ERR(2, 13823, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13836
 *         return GiacMethods['plotproba'](self,*args)
 * 
 *      def plotseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotseq:
 */
  __pyx_codeobj__1143 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotseq, 13836, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1143)) __PYX_ERR(2, 13836, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13849
 *         return GiacMethods['plotseq'](self,*args)
 * 
 *      def plotspectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotspectrum:
 */
  __pyx_codeobj__1144 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotspectrum, 13849, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1144)) __PYX_ERR(2, 13849, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13861
 *         return GiacMethods['plotspectrum'](self,*args)
 * 
 *      def plotwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotwav:
 */
  __pyx_codeobj__1145 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plotwav, 13861, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1145)) __PYX_ERR(2, 13861, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13874
 *         return GiacMethods['plotwav'](self,*args)
 * 
 *      def plus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plus_point:
 */
  __pyx_codeobj__1146 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_plus_point, 13874, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1146)) __PYX_ERR(2, 13874, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13886
 *         return GiacMethods['plus_point'](self,*args)
 * 
 *      def pmin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pmin:
 */
  __pyx_codeobj__1147 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pmin, 13886, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1147)) __PYX_ERR(2, 13886, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13901
 *         return GiacMethods['pmin'](self,*args)
 * 
 *      def point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point:
 */
  __pyx_codeobj__1148 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_point, 13901, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1148)) __PYX_ERR(2, 13901, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13919
 *         return GiacMethods['point'](self,*args)
 * 
 *      def point2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point2d:
 */
  __pyx_codeobj__1149 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_point2d, 13919, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1149)) __PYX_ERR(2, 13919, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13930
 *         return GiacMethods['point2d'](self,*args)
 * 
 *      def point3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point3d:
 */
  __pyx_codeobj__1150 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_point3d, 13930, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1150)) __PYX_ERR(2, 13930, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13941
 *         return GiacMethods['point3d'](self,*args)
 * 
 *      def poisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson:
 */
  __pyx_codeobj__1151 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_poisson, 13941, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1151)) __PYX_ERR(2, 13941, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13955
 *         return GiacMethods['poisson'](self,*args)
 * 
 *      def poisson_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_cdf:
 */
  __pyx_codeobj__1152 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_poisson_cdf, 13955, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1152)) __PYX_ERR(2, 13955, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13967
 *         return GiacMethods['poisson_cdf'](self,*args)
 * 
 *      def poisson_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_icdf:
 */
  __pyx_codeobj__1153 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_poisson_icdf, 13967, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1153)) __PYX_ERR(2, 13967, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13979
 *         return GiacMethods['poisson_icdf'](self,*args)
 * 
 *      def poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_window:
 */
  __pyx_codeobj__1154 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_poisson_window, 13979, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1154)) __PYX_ERR(2, 13979, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":13990
 *         return GiacMethods['poisson_window'](self,*args)
 * 
 *      def polar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar:
 */
  __pyx_codeobj__1155 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polar, 13990, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1155)) __PYX_ERR(2, 13990, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14002
 *         return GiacMethods['polar'](self,*args)
 * 
 *      def polar_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_coordinates:
 */
  __pyx_codeobj__1156 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polar_coordinates, 14002, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1156)) __PYX_ERR(2, 14002, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14016
 *         return GiacMethods['polar_coordinates'](self,*args)
 * 
 *      def polar_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_point:
 */
  __pyx_codeobj__1157 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polar_point, 14016, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1157)) __PYX_ERR(2, 14016, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14028
 *         return GiacMethods['polar_point'](self,*args)
 * 
 *      def polarplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polarplot:
 */
  __pyx_codeobj__1158 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polarplot, 14028, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1158)) __PYX_ERR(2, 14028, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14040
 *         return GiacMethods['polarplot'](self,*args)
 * 
 *      def pole(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pole:
 */
  __pyx_codeobj__1159 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pole, 14040, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1159)) __PYX_ERR(2, 14040, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14052
 *         return GiacMethods['pole'](self,*args)
 * 
 *      def poly2symb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poly2symb:
 */
  __pyx_codeobj__1160 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_poly2symb, 14052, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1160)) __PYX_ERR(2, 14052, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14066
 *         return GiacMethods['poly2symb'](self,*args)
 * 
 *      def polyEval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyEval:
 */
  __pyx_codeobj__1161 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polyEval, 14066, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1161)) __PYX_ERR(2, 14066, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14078
 *         return GiacMethods['polyEval'](self,*args)
 * 
 *      def polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygon:
 */
  __pyx_codeobj__1162 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polygon, 14078, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1162)) __PYX_ERR(2, 14078, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14090
 *         return GiacMethods['polygon'](self,*args)
 * 
 *      def polygone_rempli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygone_rempli:
 */
  __pyx_codeobj__1163 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polygone_rempli, 14090, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1163)) __PYX_ERR(2, 14090, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14103
 *         return GiacMethods['polygone_rempli'](self,*args)
 * 
 *      def polygonplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonplot:
 */
  __pyx_codeobj__1164 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polygonplot, 14103, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1164)) __PYX_ERR(2, 14103, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14114
 *         return GiacMethods['polygonplot'](self,*args)
 * 
 *      def polygonscatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonscatterplot:
 */
  __pyx_codeobj__1165 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polygonscatterplot, 14114, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1165)) __PYX_ERR(2, 14114, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14125
 *         return GiacMethods['polygonscatterplot'](self,*args)
 * 
 *      def polyhedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyhedron:
 */
  __pyx_codeobj__1166 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polyhedron, 14125, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1166)) __PYX_ERR(2, 14125, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14136
 *         return GiacMethods['polyhedron'](self,*args)
 * 
 *      def polynom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynom:
 */
  __pyx_codeobj__1167 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polynom, 14136, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1167)) __PYX_ERR(2, 14136, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14151
 *         return GiacMethods['polynom'](self,*args)
 * 
 *      def polynomial_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression:
 */
  __pyx_codeobj__1168 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polynomial_regression, 14151, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1168)) __PYX_ERR(2, 14151, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14164
 *         return GiacMethods['polynomial_regression'](self,*args)
 * 
 *      def polynomial_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression_plot:
 */
  __pyx_codeobj__1169 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_polynomial_regression_plot, 14164, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1169)) __PYX_ERR(2, 14164, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14177
 *         return GiacMethods['polynomial_regression_plot'](self,*args)
 * 
 *      def position(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for position:
 */
  __pyx_codeobj__1170 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_position, 14177, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1170)) __PYX_ERR(2, 14177, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14190
 *         return GiacMethods['position'](self,*args)
 * 
 *      def poslbdLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poslbdLMQ:
 */
  __pyx_codeobj__1171 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_poslbdLMQ, 14190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1171)) __PYX_ERR(2, 14190, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14201
 *         return GiacMethods['poslbdLMQ'](self,*args)
 * 
 *      def posubLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for posubLMQ:
 */
  __pyx_codeobj__1172 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_posubLMQ, 14201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1172)) __PYX_ERR(2, 14201, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14212
 *         return GiacMethods['posubLMQ'](self,*args)
 * 
 *      def potential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for potential:
 */
  __pyx_codeobj__1173 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_potential, 14212, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1173)) __PYX_ERR(2, 14212, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14223
 *         return GiacMethods['potential'](self,*args)
 * 
 *      def pow2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pow2exp:
 */
  __pyx_codeobj__1174 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pow2exp, 14223, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1174)) __PYX_ERR(2, 14223, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14234
 *         return GiacMethods['pow2exp'](self,*args)
 * 
 *      def power_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression:
 */
  __pyx_codeobj__1175 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_power_regression, 14234, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1175)) __PYX_ERR(2, 14234, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14247
 *         return GiacMethods['power_regression'](self,*args)
 * 
 *      def power_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression_plot:
 */
  __pyx_codeobj__1176 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_power_regression_plot, 14247, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1176)) __PYX_ERR(2, 14247, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14260
 *         return GiacMethods['power_regression_plot'](self,*args)
 * 
 *      def powermod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powermod:
 */
  __pyx_codeobj__1177 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_powermod, 14260, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1177)) __PYX_ERR(2, 14260, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14272
 *         return GiacMethods['powermod'](self,*args)
 * 
 *      def powerpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powerpc:
 */
  __pyx_codeobj__1178 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_powerpc, 14272, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1178)) __PYX_ERR(2, 14272, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14284
 *         return GiacMethods['powerpc'](self,*args)
 * 
 *      def powexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powexpand:
 */
  __pyx_codeobj__1179 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_powexpand, 14284, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1179)) __PYX_ERR(2, 14284, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14296
 *         return GiacMethods['powexpand'](self,*args)
 * 
 *      def powmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powmod:
 */
  __pyx_codeobj__1180 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_powmod, 14296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1180)) __PYX_ERR(2, 14296, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14308
 *         return GiacMethods['powmod'](self,*args)
 * 
 *      def prepend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prepend:
 */
  __pyx_codeobj__1181 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_prepend, 14308, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1181)) __PYX_ERR(2, 14308, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14324
 *         return GiacMethods['prepend'](self,*args)
 * 
 *      def preval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for preval:
 */
  __pyx_codeobj__1182 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_preval, 14324, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1182)) __PYX_ERR(2, 14324, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14338
 *         return GiacMethods['preval'](self,*args)
 * 
 *      def prevperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevperm:
 */
  __pyx_codeobj__1183 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_prevperm, 14338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1183)) __PYX_ERR(2, 14338, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14350
 *         return GiacMethods['prevperm'](self,*args)
 * 
 *      def prevprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevprime:
 */
  __pyx_codeobj__1184 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_prevprime, 14350, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1184)) __PYX_ERR(2, 14350, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14362
 *         return GiacMethods['prevprime'](self,*args)
 * 
 *      def primpart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for primpart:
 */
  __pyx_codeobj__1185 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_primpart, 14362, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1185)) __PYX_ERR(2, 14362, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14374
 *         return GiacMethods['primpart'](self,*args)
 * 
 *      def printf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for printf:
 */
  __pyx_codeobj__1186 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_printf, 14374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1186)) __PYX_ERR(2, 14374, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14386
 *         return GiacMethods['printf'](self,*args)
 * 
 *      def prism(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism:
 */
  __pyx_codeobj__1187 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_prism, 14386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1187)) __PYX_ERR(2, 14386, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14397
 *         return GiacMethods['prism'](self,*args)
 * 
 *      def prism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism_graph:
 */
  __pyx_codeobj__1188 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_prism_graph, 14397, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1188)) __PYX_ERR(2, 14397, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14408
 *         return GiacMethods['prism_graph'](self,*args)
 * 
 *      def product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for product:
 */
  __pyx_codeobj__1189 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_product, 14408, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1189)) __PYX_ERR(2, 14408, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14425
 *         return GiacMethods['product'](self,*args)
 * 
 *      def projection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for projection:
 */
  __pyx_codeobj__1190 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_projection, 14425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1190)) __PYX_ERR(2, 14425, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14438
 *         return GiacMethods['projection'](self,*args)
 * 
 *      def proot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for proot:
 */
  __pyx_codeobj__1191 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_proot, 14438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1191)) __PYX_ERR(2, 14438, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14452
 *         return GiacMethods['proot'](self,*args)
 * 
 *      def propFrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propFrac:
 */
  __pyx_codeobj__1192 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_propFrac, 14452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1192)) __PYX_ERR(2, 14452, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14464
 *         return GiacMethods['propFrac'](self,*args)
 * 
 *      def propfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propfrac:
 */
  __pyx_codeobj__1193 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_propfrac, 14464, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1193)) __PYX_ERR(2, 14464, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14476
 *         return GiacMethods['propfrac'](self,*args)
 * 
 *      def pruefer_code(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pruefer_code:
 */
  __pyx_codeobj__1194 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pruefer_code, 14476, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1194)) __PYX_ERR(2, 14476, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14488
 *         return GiacMethods['pruefer_code'](self,*args)
 * 
 *      def psrgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for psrgcd:
 */
  __pyx_codeobj__1195 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_psrgcd, 14488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1195)) __PYX_ERR(2, 14488, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14499
 *         return GiacMethods['psrgcd'](self,*args)
 * 
 *      def ptayl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ptayl:
 */
  __pyx_codeobj__1196 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ptayl, 14499, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1196)) __PYX_ERR(2, 14499, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14515
 *         return GiacMethods['ptayl'](self,*args)
 * 
 *      def purge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purge:
 */
  __pyx_codeobj__1197 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_purge, 14515, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1197)) __PYX_ERR(2, 14515, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14527
 *         return GiacMethods['purge'](self,*args)
 * 
 *      def purple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purple:
 */
  __pyx_codeobj__1198 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_purple, 14527, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1198)) __PYX_ERR(2, 14527, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14539
 *         return GiacMethods['purple'](self,*args)
 * 
 *      def pwd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pwd:
 */
  __pyx_codeobj__1199 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pwd, 14539, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1199)) __PYX_ERR(2, 14539, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14550
 *         return GiacMethods['pwd'](self,*args)
 * 
 *      def pyramid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pyramid:
 */
  __pyx_codeobj__1200 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_pyramid, 14550, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1200)) __PYX_ERR(2, 14550, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14562
 *         return GiacMethods['pyramid'](self,*args)
 * 
 *      def python_compat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for python_compat:
 */
  __pyx_codeobj__1201 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_python_compat, 14562, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1201)) __PYX_ERR(2, 14562, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14574
 *         return GiacMethods['python_compat'](self,*args)
 * 
 *      def q2a(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for q2a:
 */
  __pyx_codeobj__1202 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_q2a, 14574, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1202)) __PYX_ERR(2, 14574, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14585
 *         return GiacMethods['q2a'](self,*args)
 * 
 *      def qr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for qr:
 */
  __pyx_codeobj__1203 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_qr, 14585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1203)) __PYX_ERR(2, 14585, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14596
 *         return GiacMethods['qr'](self,*args)
 * 
 *      def quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadric:
 */
  __pyx_codeobj__1204 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quadric, 14596, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1204)) __PYX_ERR(2, 14596, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14610
 *         return GiacMethods['quadric'](self,*args)
 * 
 *      def quadrilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadrilateral:
 */
  __pyx_codeobj__1205 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quadrilateral, 14610, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1205)) __PYX_ERR(2, 14610, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14622
 *         return GiacMethods['quadrilateral'](self,*args)
 * 
 *      def quantile(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quantile:
 */
  __pyx_codeobj__1206 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quantile, 14622, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1206)) __PYX_ERR(2, 14622, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14634
 *         return GiacMethods['quantile'](self,*args)
 * 
 *      def quartile1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile1:
 */
  __pyx_codeobj__1207 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quartile1, 14634, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1207)) __PYX_ERR(2, 14634, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14647
 *         return GiacMethods['quartile1'](self,*args)
 * 
 *      def quartile3(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile3:
 */
  __pyx_codeobj__1208 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quartile3, 14647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1208)) __PYX_ERR(2, 14647, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14660
 *         return GiacMethods['quartile3'](self,*args)
 * 
 *      def quartiles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartiles:
 */
  __pyx_codeobj__1209 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quartiles, 14660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1209)) __PYX_ERR(2, 14660, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14673
 *         return GiacMethods['quartiles'](self,*args)
 * 
 *      def quest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quest:
 */
  __pyx_codeobj__1210 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quest, 14673, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1210)) __PYX_ERR(2, 14673, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14686
 *         return GiacMethods['quest'](self,*args)
 * 
 *      def quo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quo:
 */
  __pyx_codeobj__1211 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quo, 14686, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1211)) __PYX_ERR(2, 14686, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14699
 *         return GiacMethods['quo'](self,*args)
 * 
 *      def quorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quorem:
 */
  __pyx_codeobj__1212 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quorem, 14699, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1212)) __PYX_ERR(2, 14699, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14713
 *         return GiacMethods['quorem'](self,*args)
 * 
 *      def quote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quote:
 */
  __pyx_codeobj__1213 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_quote, 14713, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1213)) __PYX_ERR(2, 14713, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14726
 *         return GiacMethods['quote'](self,*args)
 * 
 *      def r2e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for r2e:
 */
  __pyx_codeobj__1214 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_r2e, 14726, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1214)) __PYX_ERR(2, 14726, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14740
 *         return GiacMethods['r2e'](self,*args)
 * 
 *      def radians(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radians:
 */
  __pyx_codeobj__1215 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_radians, 14740, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1215)) __PYX_ERR(2, 14740, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14750
 *         return GiacMethods['radians'](self,*args)
 * 
 *      def radical_axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radical_axis:
 */
  __pyx_codeobj__1216 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_radical_axis, 14750, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1216)) __PYX_ERR(2, 14750, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14762
 *         return GiacMethods['radical_axis'](self,*args)
 * 
 *      def radius(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radius:
 */
  __pyx_codeobj__1217 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_radius, 14762, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1217)) __PYX_ERR(2, 14762, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14773
 *         return GiacMethods['radius'](self,*args)
 * 
 *      def ramene(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ramene:
 */
  __pyx_codeobj__1218 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ramene, 14773, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1218)) __PYX_ERR(2, 14773, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14784
 *         return GiacMethods['ramene'](self,*args)
 * 
 *      def rand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rand:
 */
  __pyx_codeobj__1219 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rand, 14784, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1219)) __PYX_ERR(2, 14784, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14805
 *         return GiacMethods['rand'](self,*args)
 * 
 *      def randMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randMat:
 */
  __pyx_codeobj__1220 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randMat, 14805, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1220)) __PYX_ERR(2, 14805, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14828
 *         return GiacMethods['randMat'](self,*args)
 * 
 *      def randNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randNorm:
 */
  __pyx_codeobj__1221 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randNorm, 14828, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1221)) __PYX_ERR(2, 14828, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14840
 *         return GiacMethods['randNorm'](self,*args)
 * 
 *      def randPoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randPoly:
 */
  __pyx_codeobj__1222 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randPoly, 14840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1222)) __PYX_ERR(2, 14840, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14856
 *         return GiacMethods['randPoly'](self,*args)
 * 
 *      def randbetad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbetad:
 */
  __pyx_codeobj__1223 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randbetad, 14856, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1223)) __PYX_ERR(2, 14856, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14868
 *         return GiacMethods['randbetad'](self,*args)
 * 
 *      def randbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbinomial:
 */
  __pyx_codeobj__1224 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randbinomial, 14868, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1224)) __PYX_ERR(2, 14868, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14880
 *         return GiacMethods['randbinomial'](self,*args)
 * 
 *      def randchisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randchisquare:
 */
  __pyx_codeobj__1225 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randchisquare, 14880, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1225)) __PYX_ERR(2, 14880, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14892
 *         return GiacMethods['randchisquare'](self,*args)
 * 
 *      def randexp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randexp:
 */
  __pyx_codeobj__1226 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randexp, 14892, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1226)) __PYX_ERR(2, 14892, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14904
 *         return GiacMethods['randexp'](self,*args)
 * 
 *      def randfisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randfisher:
 */
  __pyx_codeobj__1227 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randfisher, 14904, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1227)) __PYX_ERR(2, 14904, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14916
 *         return GiacMethods['randfisher'](self,*args)
 * 
 *      def randgammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgammad:
 */
  __pyx_codeobj__1228 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randgammad, 14916, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1228)) __PYX_ERR(2, 14916, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14928
 *         return GiacMethods['randgammad'](self,*args)
 * 
 *      def randgeometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgeometric:
 */
  __pyx_codeobj__1229 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randgeometric, 14928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1229)) __PYX_ERR(2, 14928, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14939
 *         return GiacMethods['randgeometric'](self,*args)
 * 
 *      def randint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randint:
 */
  __pyx_codeobj__1230 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randint, 14939, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1230)) __PYX_ERR(2, 14939, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14951
 *         return GiacMethods['randint'](self,*args)
 * 
 *      def randmarkov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmarkov:
 */
  __pyx_codeobj__1231 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randmarkov, 14951, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1231)) __PYX_ERR(2, 14951, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14963
 *         return GiacMethods['randmarkov'](self,*args)
 * 
 *      def randmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmatrix:
 */
  __pyx_codeobj__1232 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randmatrix, 14963, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1232)) __PYX_ERR(2, 14963, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14986
 *         return GiacMethods['randmatrix'](self,*args)
 * 
 *      def randmultinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmultinomial:
 */
  __pyx_codeobj__1233 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randmultinomial, 14986, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1233)) __PYX_ERR(2, 14986, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":14998
 *         return GiacMethods['randmultinomial'](self,*args)
 * 
 *      def randnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randnorm:
 */
  __pyx_codeobj__1234 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randnorm, 14998, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1234)) __PYX_ERR(2, 14998, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15010
 *         return GiacMethods['randnorm'](self,*args)
 * 
 *      def random(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random:
 */
  __pyx_codeobj__1235 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random, 15010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1235)) __PYX_ERR(2, 15010, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15031
 *         return GiacMethods['random'](self,*args)
 * 
 *      def random_bipartite_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_bipartite_graph:
 */
  __pyx_codeobj__1236 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_bipartite_graph, 15031, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1236)) __PYX_ERR(2, 15031, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15043
 *         return GiacMethods['random_bipartite_graph'](self,*args)
 * 
 *      def random_digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_digraph:
 */
  __pyx_codeobj__1237 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_digraph, 15043, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1237)) __PYX_ERR(2, 15043, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15055
 *         return GiacMethods['random_digraph'](self,*args)
 * 
 *      def random_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_graph:
 */
  __pyx_codeobj__1238 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_graph, 15055, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1238)) __PYX_ERR(2, 15055, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15067
 *         return GiacMethods['random_graph'](self,*args)
 * 
 *      def random_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_network:
 */
  __pyx_codeobj__1239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_network, 15067, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1239)) __PYX_ERR(2, 15067, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15080
 *         return GiacMethods['random_network'](self,*args)
 * 
 *      def random_planar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_planar_graph:
 */
  __pyx_codeobj__1240 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_planar_graph, 15080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1240)) __PYX_ERR(2, 15080, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15090
 *         return GiacMethods['random_planar_graph'](self,*args)
 * 
 *      def random_regular_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_regular_graph:
 */
  __pyx_codeobj__1241 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_regular_graph, 15090, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1241)) __PYX_ERR(2, 15090, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15101
 *         return GiacMethods['random_regular_graph'](self,*args)
 * 
 *      def random_sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_sequence_graph:
 */
  __pyx_codeobj__1242 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_sequence_graph, 15101, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1242)) __PYX_ERR(2, 15101, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15112
 *         return GiacMethods['random_sequence_graph'](self,*args)
 * 
 *      def random_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tournament:
 */
  __pyx_codeobj__1243 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_tournament, 15112, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1243)) __PYX_ERR(2, 15112, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15123
 *         return GiacMethods['random_tournament'](self,*args)
 * 
 *      def random_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tree:
 */
  __pyx_codeobj__1244 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_tree, 15123, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1244)) __PYX_ERR(2, 15123, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15133
 *         return GiacMethods['random_tree'](self,*args)
 * 
 *      def random_variable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_variable:
 */
  __pyx_codeobj__1245 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_random_variable, 15133, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1245)) __PYX_ERR(2, 15133, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15153
 *         return GiacMethods['random_variable'](self,*args)
 * 
 *      def randperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randperm:
 */
  __pyx_codeobj__1246 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randperm, 15153, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1246)) __PYX_ERR(2, 15153, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15168
 *         return GiacMethods['randperm'](self,*args)
 * 
 *      def randpoisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoisson:
 */
  __pyx_codeobj__1247 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randpoisson, 15168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1247)) __PYX_ERR(2, 15168, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15180
 *         return GiacMethods['randpoisson'](self,*args)
 * 
 *      def randpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoly:
 */
  __pyx_codeobj__1248 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randpoly, 15180, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1248)) __PYX_ERR(2, 15180, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15196
 *         return GiacMethods['randpoly'](self,*args)
 * 
 *      def randseed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randseed:
 */
  __pyx_codeobj__1249 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randseed, 15196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1249)) __PYX_ERR(2, 15196, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15208
 *         return GiacMethods['randseed'](self,*args)
 * 
 *      def randstudent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randstudent:
 */
  __pyx_codeobj__1250 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randstudent, 15208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1250)) __PYX_ERR(2, 15208, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15220
 *         return GiacMethods['randstudent'](self,*args)
 * 
 *      def randvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvar:
 */
  __pyx_codeobj__1251 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randvar, 15220, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1251)) __PYX_ERR(2, 15220, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15240
 *         return GiacMethods['randvar'](self,*args)
 * 
 *      def randvector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvector:
 */
  __pyx_codeobj__1252 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randvector, 15240, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1252)) __PYX_ERR(2, 15240, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15260
 *         return GiacMethods['randvector'](self,*args)
 * 
 *      def randweibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randweibulld:
 */
  __pyx_codeobj__1253 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_randweibulld, 15260, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1253)) __PYX_ERR(2, 15260, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15272
 *         return GiacMethods['randweibulld'](self,*args)
 * 
 *      def rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rank:
 */
  __pyx_codeobj__1254 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rank, 15272, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1254)) __PYX_ERR(2, 15272, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15284
 *         return GiacMethods['rank'](self,*args)
 * 
 *      def ranm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranm:
 */
  __pyx_codeobj__1255 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ranm, 15284, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1255)) __PYX_ERR(2, 15284, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15307
 *         return GiacMethods['ranm'](self,*args)
 * 
 *      def ranv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranv:
 */
  __pyx_codeobj__1256 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ranv, 15307, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1256)) __PYX_ERR(2, 15307, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15327
 *         return GiacMethods['ranv'](self,*args)
 * 
 *      def rassembler_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rassembler_trigo:
 */
  __pyx_codeobj__1257 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rassembler_trigo, 15327, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1257)) __PYX_ERR(2, 15327, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15338
 *         return GiacMethods['rassembler_trigo'](self,*args)
 * 
 *      def rat_jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rat_jordan:
 */
  __pyx_codeobj__1258 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rat_jordan, 15338, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1258)) __PYX_ERR(2, 15338, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15351
 *         return GiacMethods['rat_jordan'](self,*args)
 * 
 *      def ratinterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratinterp:
 */
  __pyx_codeobj__1259 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ratinterp, 15351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1259)) __PYX_ERR(2, 15351, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15362
 *         return GiacMethods['ratinterp'](self,*args)
 * 
 *      def rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rational:
 */
  __pyx_codeobj__1260 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rational, 15362, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1260)) __PYX_ERR(2, 15362, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15375
 *         return GiacMethods['rational'](self,*args)
 * 
 *      def rationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rationalroot:
 */
  __pyx_codeobj__1261 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rationalroot, 15375, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1261)) __PYX_ERR(2, 15375, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15386
 *         return GiacMethods['rationalroot'](self,*args)
 * 
 *      def ratnormal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratnormal:
 */
  __pyx_codeobj__1262 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ratnormal, 15386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1262)) __PYX_ERR(2, 15386, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15399
 *         return GiacMethods['ratnormal'](self,*args)
 * 
 *      def rdiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rdiv:
 */
  __pyx_codeobj__1263 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rdiv, 15399, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1263)) __PYX_ERR(2, 15399, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15411
 *         return GiacMethods['rdiv'](self,*args)
 * 
 *      def re(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for re:
 */
  __pyx_codeobj__1264 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_re, 15411, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1264)) __PYX_ERR(2, 15411, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15424
 *         return GiacMethods['re'](self,*args)
 * 
 *      def reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reachable:
 */
  __pyx_codeobj__1265 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reachable, 15424, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1265)) __PYX_ERR(2, 15424, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15435
 *         return GiacMethods['reachable'](self,*args)
 * 
 *      def read(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for read:
 */
  __pyx_codeobj__1266 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_read, 15435, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1266)) __PYX_ERR(2, 15435, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15446
 *         return GiacMethods['read'](self,*args)
 * 
 *      def readrgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readrgb:
 */
  __pyx_codeobj__1267 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_readrgb, 15446, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1267)) __PYX_ERR(2, 15446, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15458
 *         return GiacMethods['readrgb'](self,*args)
 * 
 *      def readwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readwav:
 */
  __pyx_codeobj__1268 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_readwav, 15458, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1268)) __PYX_ERR(2, 15458, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15469
 *         return GiacMethods['readwav'](self,*args)
 * 
 *      def real(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for real:
 */
  __pyx_codeobj__1269 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_real, 15469, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1269)) __PYX_ERR(2, 15469, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15482
 *         return GiacMethods['real'](self,*args)
 * 
 *      def realroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for realroot:
 */
  __pyx_codeobj__1270 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_realroot, 15482, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1270)) __PYX_ERR(2, 15482, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15498
 *         return GiacMethods['realroot'](self,*args)
 * 
 *      def reciprocation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reciprocation:
 */
  __pyx_codeobj__1271 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reciprocation, 15498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1271)) __PYX_ERR(2, 15498, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15510
 *         return GiacMethods['reciprocation'](self,*args)
 * 
 *      def rect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rect:
 */
  __pyx_codeobj__1272 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rect, 15510, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1272)) __PYX_ERR(2, 15510, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15521
 *         return GiacMethods['rect'](self,*args)
 * 
 *      def rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle:
 */
  __pyx_codeobj__1273 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rectangle, 15521, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1273)) __PYX_ERR(2, 15521, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15535
 *         return GiacMethods['rectangle'](self,*args)
 * 
 *      def rectangle_droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_droit:
 */
  __pyx_codeobj__1274 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rectangle_droit, 15535, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1274)) __PYX_ERR(2, 15535, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15551
 *         return GiacMethods['rectangle_droit'](self,*args)
 * 
 *      def rectangle_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_gauche:
 */
  __pyx_codeobj__1275 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rectangle_gauche, 15551, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1275)) __PYX_ERR(2, 15551, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15567
 *         return GiacMethods['rectangle_gauche'](self,*args)
 * 
 *      def rectangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_plein:
 */
  __pyx_codeobj__1276 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rectangle_plein, 15567, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1276)) __PYX_ERR(2, 15567, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15580
 *         return GiacMethods['rectangle_plein'](self,*args)
 * 
 *      def rectangular_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangular_coordinates:
 */
  __pyx_codeobj__1277 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rectangular_coordinates, 15580, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1277)) __PYX_ERR(2, 15580, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15592
 *         return GiacMethods['rectangular_coordinates'](self,*args)
 * 
 *      def recule(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for recule:
 */
  __pyx_codeobj__1278 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_recule, 15592, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1278)) __PYX_ERR(2, 15592, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15604
 *         return GiacMethods['recule'](self,*args)
 * 
 *      def red(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for red:
 */
  __pyx_codeobj__1279 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_red, 15604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1279)) __PYX_ERR(2, 15604, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15616
 *         return GiacMethods['red'](self,*args)
 * 
 *      def reduced_conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_conic:
 */
  __pyx_codeobj__1280 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reduced_conic, 15616, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1280)) __PYX_ERR(2, 15616, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15630
 *         return GiacMethods['reduced_conic'](self,*args)
 * 
 *      def reduced_quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_quadric:
 */
  __pyx_codeobj__1281 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reduced_quadric, 15630, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1281)) __PYX_ERR(2, 15630, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15644
 *         return GiacMethods['reduced_quadric'](self,*args)
 * 
 *      def ref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ref:
 */
  __pyx_codeobj__1282 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ref, 15644, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1282)) __PYX_ERR(2, 15644, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15656
 *         return GiacMethods['ref'](self,*args)
 * 
 *      def reflection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reflection:
 */
  __pyx_codeobj__1283 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reflection, 15656, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1283)) __PYX_ERR(2, 15656, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15669
 *         return GiacMethods['reflection'](self,*args)
 * 
 *      def regroup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for regroup:
 */
  __pyx_codeobj__1284 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_regroup, 15669, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1284)) __PYX_ERR(2, 15669, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15680
 *         return GiacMethods['regroup'](self,*args)
 * 
 *      def relabel_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for relabel_vertices:
 */
  __pyx_codeobj__1285 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_relabel_vertices, 15680, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1285)) __PYX_ERR(2, 15680, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15691
 *         return GiacMethods['relabel_vertices'](self,*args)
 * 
 *      def reliability_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reliability_polynomial:
 */
  __pyx_codeobj__1286 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reliability_polynomial, 15691, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1286)) __PYX_ERR(2, 15691, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15703
 *         return GiacMethods['reliability_polynomial'](self,*args)
 * 
 *      def rem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rem:
 */
  __pyx_codeobj__1287 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rem, 15703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1287)) __PYX_ERR(2, 15703, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15716
 *         return GiacMethods['rem'](self,*args)
 * 
 *      def remain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remain:
 */
  __pyx_codeobj__1288 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_remain, 15716, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1288)) __PYX_ERR(2, 15716, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15730
 *         return GiacMethods['remain'](self,*args)
 * 
 *      def remove(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remove:
 */
  __pyx_codeobj__1289 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_remove, 15730, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1289)) __PYX_ERR(2, 15730, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15742
 *         return GiacMethods['remove'](self,*args)
 * 
 *      def reorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reorder:
 */
  __pyx_codeobj__1290 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reorder, 15742, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1290)) __PYX_ERR(2, 15742, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15754
 *         return GiacMethods['reorder'](self,*args)
 * 
 *      def resample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resample:
 */
  __pyx_codeobj__1291 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_resample, 15754, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1291)) __PYX_ERR(2, 15754, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15766
 *         return GiacMethods['resample'](self,*args)
 * 
 *      def residue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for residue:
 */
  __pyx_codeobj__1292 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_residue, 15766, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1292)) __PYX_ERR(2, 15766, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15780
 *         return GiacMethods['residue'](self,*args)
 * 
 *      def resoudre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre:
 */
  __pyx_codeobj__1293 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_resoudre, 15780, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1293)) __PYX_ERR(2, 15780, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15794
 *         return GiacMethods['resoudre'](self,*args)
 * 
 *      def resoudre_dans_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_dans_C:
 */
  __pyx_codeobj__1294 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_resoudre_dans_C, 15794, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1294)) __PYX_ERR(2, 15794, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15808
 *         return GiacMethods['resoudre_dans_C'](self,*args)
 * 
 *      def resoudre_systeme_lineaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_systeme_lineaire:
 */
  __pyx_codeobj__1295 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_resoudre_systeme_lineaire, 15808, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1295)) __PYX_ERR(2, 15808, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15827
 *         return GiacMethods['resoudre_systeme_lineaire'](self,*args)
 * 
 *      def resultant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resultant:
 */
  __pyx_codeobj__1296 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_resultant, 15827, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1296)) __PYX_ERR(2, 15827, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15839
 *         return GiacMethods['resultant'](self,*args)
 * 
 *      def reverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse:
 */
  __pyx_codeobj__1297 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reverse, 15839, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1297)) __PYX_ERR(2, 15839, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15852
 *         return GiacMethods['reverse'](self,*args)
 * 
 *      def reverse_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_graph:
 */
  __pyx_codeobj__1298 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reverse_graph, 15852, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1298)) __PYX_ERR(2, 15852, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15863
 *         return GiacMethods['reverse_graph'](self,*args)
 * 
 *      def reverse_rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_rsolve:
 */
  __pyx_codeobj__1299 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_reverse_rsolve, 15863, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1299)) __PYX_ERR(2, 15863, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15874
 *         return GiacMethods['reverse_rsolve'](self,*args)
 * 
 *      def revert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revert:
 */
  __pyx_codeobj__1300 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_revert, 15874, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1300)) __PYX_ERR(2, 15874, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15885
 *         return GiacMethods['revert'](self,*args)
 * 
 *      def revlex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlex:
 */
  __pyx_codeobj__1301 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_revlex, 15885, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1301)) __PYX_ERR(2, 15885, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15895
 *         return GiacMethods['revlex'](self,*args)
 * 
 *      def revlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlist:
 */
  __pyx_codeobj__1302 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_revlist, 15895, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1302)) __PYX_ERR(2, 15895, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15908
 *         return GiacMethods['revlist'](self,*args)
 * 
 *      def rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb:
 */
  __pyx_codeobj__1303 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rgb, 15908, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1303)) __PYX_ERR(2, 15908, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15927
 *         return GiacMethods['rgb'](self,*args)
 * 
 *      def rgb2hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2hsv:
 */
  __pyx_codeobj__1304 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rgb2hsv, 15927, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1304)) __PYX_ERR(2, 15927, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15940
 *         return GiacMethods['rgb2hsv'](self,*args)
 * 
 *      def rgb2xyz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2xyz:
 */
  __pyx_codeobj__1305 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rgb2xyz, 15940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1305)) __PYX_ERR(2, 15940, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15953
 *         return GiacMethods['rgb2xyz'](self,*args)
 * 
 *      def rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus:
 */
  __pyx_codeobj__1306 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rhombus, 15953, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1306)) __PYX_ERR(2, 15953, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15968
 *         return GiacMethods['rhombus'](self,*args)
 * 
 *      def rhombus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus_point:
 */
  __pyx_codeobj__1307 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rhombus_point, 15968, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1307)) __PYX_ERR(2, 15968, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15980
 *         return GiacMethods['rhombus_point'](self,*args)
 * 
 *      def rhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhs:
 */
  __pyx_codeobj__1308 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rhs, 15980, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1308)) __PYX_ERR(2, 15980, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":15994
 *         return GiacMethods['rhs'](self,*args)
 * 
 *      def riemann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for riemann_window:
 */
  __pyx_codeobj__1309 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_riemann_window, 15994, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1309)) __PYX_ERR(2, 15994, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16005
 *         return GiacMethods['riemann_window'](self,*args)
 * 
 *      def right(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right:
 */
  __pyx_codeobj__1310 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_right, 16005, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1310)) __PYX_ERR(2, 16005, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16019
 *         return GiacMethods['right'](self,*args)
 * 
 *      def right_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_rectangle:
 */
  __pyx_codeobj__1311 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_right_rectangle, 16019, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1311)) __PYX_ERR(2, 16019, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16035
 *         return GiacMethods['right_rectangle'](self,*args)
 * 
 *      def right_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_triangle:
 */
  __pyx_codeobj__1312 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_right_triangle, 16035, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1312)) __PYX_ERR(2, 16035, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16050
 *         return GiacMethods['right_triangle'](self,*args)
 * 
 *      def risch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for risch:
 */
  __pyx_codeobj__1313 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_risch, 16050, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1313)) __PYX_ERR(2, 16050, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16063
 *         return GiacMethods['risch'](self,*args)
 * 
 *      def rm_a_z(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_a_z:
 */
  __pyx_codeobj__1314 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rm_a_z, 16063, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1314)) __PYX_ERR(2, 16063, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16074
 *         return GiacMethods['rm_a_z'](self,*args)
 * 
 *      def rm_all_vars(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_all_vars:
 */
  __pyx_codeobj__1315 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rm_all_vars, 16074, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1315)) __PYX_ERR(2, 16074, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16085
 *         return GiacMethods['rm_all_vars'](self,*args)
 * 
 *      def rmbreakpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmbreakpoint:
 */
  __pyx_codeobj__1316 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rmbreakpoint, 16085, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1316)) __PYX_ERR(2, 16085, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16096
 *         return GiacMethods['rmbreakpoint'](self,*args)
 * 
 *      def rmmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmmod:
 */
  __pyx_codeobj__1317 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rmmod, 16096, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1317)) __PYX_ERR(2, 16096, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16107
 *         return GiacMethods['rmmod'](self,*args)
 * 
 *      def rms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rms:
 */
  __pyx_codeobj__1318 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rms, 16107, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1318)) __PYX_ERR(2, 16107, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16118
 *         return GiacMethods['rms'](self,*args)
 * 
 *      def rmwatch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmwatch:
 */
  __pyx_codeobj__1319 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rmwatch, 16118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1319)) __PYX_ERR(2, 16118, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16129
 *         return GiacMethods['rmwatch'](self,*args)
 * 
 *      def romberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for romberg:
 */
  __pyx_codeobj__1320 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_romberg, 16129, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1320)) __PYX_ERR(2, 16129, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16142
 *         return GiacMethods['romberg'](self,*args)
 * 
 *      def rombergm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergm:
 */
  __pyx_codeobj__1321 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rombergm, 16142, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1321)) __PYX_ERR(2, 16142, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16156
 *         return GiacMethods['rombergm'](self,*args)
 * 
 *      def rombergt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergt:
 */
  __pyx_codeobj__1322 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rombergt, 16156, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1322)) __PYX_ERR(2, 16156, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16170
 *         return GiacMethods['rombergt'](self,*args)
 * 
 *      def rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rond:
 */
  __pyx_codeobj__1323 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rond, 16170, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1323)) __PYX_ERR(2, 16170, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16184
 *         return GiacMethods['rond'](self,*args)
 * 
 *      def root(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for root:
 */
  __pyx_codeobj__1324 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_root, 16184, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1324)) __PYX_ERR(2, 16184, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16198
 *         return GiacMethods['root'](self,*args)
 * 
 *      def rootof(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rootof:
 */
  __pyx_codeobj__1325 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rootof, 16198, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1325)) __PYX_ERR(2, 16198, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16211
 *         return GiacMethods['rootof'](self,*args)
 * 
 *      def roots(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for roots:
 */
  __pyx_codeobj__1326 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_roots, 16211, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1326)) __PYX_ERR(2, 16211, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16223
 *         return GiacMethods['roots'](self,*args)
 * 
 *      def rotate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotate:
 */
  __pyx_codeobj__1327 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rotate, 16223, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1327)) __PYX_ERR(2, 16223, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16241
 *         return GiacMethods['rotate'](self,*args)
 * 
 *      def rotation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotation:
 */
  __pyx_codeobj__1328 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rotation, 16241, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1328)) __PYX_ERR(2, 16241, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16256
 *         return GiacMethods['rotation'](self,*args)
 * 
 *      def round(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for round:
 */
  __pyx_codeobj__1329 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_round, 16256, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1329)) __PYX_ERR(2, 16256, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16271
 *         return GiacMethods['round'](self,*args)
 * 
 *      def row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for row:
 */
  __pyx_codeobj__1330 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_row, 16271, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1330)) __PYX_ERR(2, 16271, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16284
 *         return GiacMethods['row'](self,*args)
 * 
 *      def rowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowAdd:
 */
  __pyx_codeobj__1331 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowAdd, 16284, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1331)) __PYX_ERR(2, 16284, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16295
 *         return GiacMethods['rowAdd'](self,*args)
 * 
 *      def rowDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowDim:
 */
  __pyx_codeobj__1332 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowDim, 16295, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1332)) __PYX_ERR(2, 16295, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16307
 *         return GiacMethods['rowDim'](self,*args)
 * 
 *      def rowNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowNorm:
 */
  __pyx_codeobj__1333 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowNorm, 16307, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1333)) __PYX_ERR(2, 16307, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16319
 *         return GiacMethods['rowNorm'](self,*args)
 * 
 *      def rowSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowSwap:
 */
  __pyx_codeobj__1334 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowSwap, 16319, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1334)) __PYX_ERR(2, 16319, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16330
 *         return GiacMethods['rowSwap'](self,*args)
 * 
 *      def rowdim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowdim:
 */
  __pyx_codeobj__1335 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowdim, 16330, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1335)) __PYX_ERR(2, 16330, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16342
 *         return GiacMethods['rowdim'](self,*args)
 * 
 *      def rownorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rownorm:
 */
  __pyx_codeobj__1336 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rownorm, 16342, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1336)) __PYX_ERR(2, 16342, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16354
 *         return GiacMethods['rownorm'](self,*args)
 * 
 *      def rowspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowspace:
 */
  __pyx_codeobj__1337 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowspace, 16354, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1337)) __PYX_ERR(2, 16354, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16366
 *         return GiacMethods['rowspace'](self,*args)
 * 
 *      def rowswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowswap:
 */
  __pyx_codeobj__1338 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rowswap, 16366, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1338)) __PYX_ERR(2, 16366, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16377
 *         return GiacMethods['rowswap'](self,*args)
 * 
 *      def rref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rref:
 */
  __pyx_codeobj__1339 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rref, 16377, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1339)) __PYX_ERR(2, 16377, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16391
 *         return GiacMethods['rref'](self,*args)
 * 
 *      def rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rsolve:
 */
  __pyx_codeobj__1340 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rsolve, 16391, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1340)) __PYX_ERR(2, 16391, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16406
 *         return GiacMethods['rsolve'](self,*args)
 * 
 *      def rur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur:
 */
  __pyx_codeobj__1341 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rur, 16406, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1341)) __PYX_ERR(2, 16406, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16418
 *         return GiacMethods['rur'](self,*args)
 * 
 *      def rur_certify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_certify:
 */
  __pyx_codeobj__1342 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rur_certify, 16418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1342)) __PYX_ERR(2, 16418, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16429
 *         return GiacMethods['rur_certify'](self,*args)
 * 
 *      def rur_gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_gbasis:
 */
  __pyx_codeobj__1343 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_rur_gbasis, 16429, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1343)) __PYX_ERR(2, 16429, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16440
 *         return GiacMethods['rur_gbasis'](self,*args)
 * 
 *      def same(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for same:
 */
  __pyx_codeobj__1344 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_same, 16440, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1344)) __PYX_ERR(2, 16440, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16452
 *         return GiacMethods['same'](self,*args)
 * 
 *      def sample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sample:
 */
  __pyx_codeobj__1345 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sample, 16452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1345)) __PYX_ERR(2, 16452, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16468
 *         return GiacMethods['sample'](self,*args)
 * 
 *      def samplerate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for samplerate:
 */
  __pyx_codeobj__1346 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_samplerate, 16468, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1346)) __PYX_ERR(2, 16468, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16479
 *         return GiacMethods['samplerate'](self,*args)
 * 
 *      def sans_factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sans_factoriser:
 */
  __pyx_codeobj__1347 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sans_factoriser, 16479, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1347)) __PYX_ERR(2, 16479, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16494
 *         return GiacMethods['sans_factoriser'](self,*args)
 * 
 *      def saute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for saute:
 */
  __pyx_codeobj__1348 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_saute, 16494, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1348)) __PYX_ERR(2, 16494, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16506
 *         return GiacMethods['saute'](self,*args)
 * 
 *      def scalarProduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalarProduct:
 */
  __pyx_codeobj__1349 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_scalarProduct, 16506, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1349)) __PYX_ERR(2, 16506, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16519
 *         return GiacMethods['scalarProduct'](self,*args)
 * 
 *      def scalar_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalar_product:
 */
  __pyx_codeobj__1350 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_scalar_product, 16519, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1350)) __PYX_ERR(2, 16519, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16532
 *         return GiacMethods['scalar_product'](self,*args)
 * 
 *      def scatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scatterplot:
 */
  __pyx_codeobj__1351 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_scatterplot, 16532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1351)) __PYX_ERR(2, 16532, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16543
 *         return GiacMethods['scatterplot'](self,*args)
 * 
 *      def schur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for schur:
 */
  __pyx_codeobj__1352 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_schur, 16543, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1352)) __PYX_ERR(2, 16543, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16555
 *         return GiacMethods['schur'](self,*args)
 * 
 *      def sec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sec:
 */
  __pyx_codeobj__1353 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sec, 16555, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1353)) __PYX_ERR(2, 16555, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16566
 *         return GiacMethods['sec'](self,*args)
 * 
 *      def secant_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for secant_solver:
 */
  __pyx_codeobj__1354 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_secant_solver, 16566, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1354)) __PYX_ERR(2, 16566, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16582
 *         return GiacMethods['secant_solver'](self,*args)
 * 
 *      def segment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for segment:
 */
  __pyx_codeobj__1355 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_segment, 16582, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1355)) __PYX_ERR(2, 16582, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16599
 *         return GiacMethods['segment'](self,*args)
 * 
 *      def seidel_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_spectrum:
 */
  __pyx_codeobj__1356 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_seidel_spectrum, 16599, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1356)) __PYX_ERR(2, 16599, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16610
 *         return GiacMethods['seidel_spectrum'](self,*args)
 * 
 *      def seidel_switch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_switch:
 */
  __pyx_codeobj__1357 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_seidel_switch, 16610, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1357)) __PYX_ERR(2, 16610, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16621
 *         return GiacMethods['seidel_switch'](self,*args)
 * 
 *      def select(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for select:
 */
  __pyx_codeobj__1358 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_select, 16621, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1358)) __PYX_ERR(2, 16621, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16633
 *         return GiacMethods['select'](self,*args)
 * 
 *      def semi_augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for semi_augment:
 */
  __pyx_codeobj__1359 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_semi_augment, 16633, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1359)) __PYX_ERR(2, 16633, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16644
 *         return GiacMethods['semi_augment'](self,*args)
 * 
 *      def seq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seq:
 */
  __pyx_codeobj__1360 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_seq, 16644, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1360)) __PYX_ERR(2, 16644, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16665
 *         return GiacMethods['seq'](self,*args)
 * 
 *      def seqplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqplot:
 */
  __pyx_codeobj__1361 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_seqplot, 16665, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1361)) __PYX_ERR(2, 16665, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16678
 *         return GiacMethods['seqplot'](self,*args)
 * 
 *      def seqsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqsolve:
 */
  __pyx_codeobj__1362 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_seqsolve, 16678, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1362)) __PYX_ERR(2, 16678, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16694
 *         return GiacMethods['seqsolve'](self,*args)
 * 
 *      def sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sequence_graph:
 */
  __pyx_codeobj__1363 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sequence_graph, 16694, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1363)) __PYX_ERR(2, 16694, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16705
 *         return GiacMethods['sequence_graph'](self,*args)
 * 
 *      def series(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for series:
 */
  __pyx_codeobj__1364 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_series, 16705, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1364)) __PYX_ERR(2, 16705, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16728
 *         return GiacMethods['series'](self,*args)
 * 
 *      def set_channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_channel_data:
 */
  __pyx_codeobj__1365 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_channel_data, 16728, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1365)) __PYX_ERR(2, 16728, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16740
 *         return GiacMethods['set_channel_data'](self,*args)
 * 
 *      def set_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_attribute:
 */
  __pyx_codeobj__1366 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_edge_attribute, 16740, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1366)) __PYX_ERR(2, 16740, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16751
 *         return GiacMethods['set_edge_attribute'](self,*args)
 * 
 *      def set_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_weight:
 */
  __pyx_codeobj__1367 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_edge_weight, 16751, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1367)) __PYX_ERR(2, 16751, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16762
 *         return GiacMethods['set_edge_weight'](self,*args)
 * 
 *      def set_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_graph_attribute:
 */
  __pyx_codeobj__1368 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_graph_attribute, 16762, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1368)) __PYX_ERR(2, 16762, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16773
 *         return GiacMethods['set_graph_attribute'](self,*args)
 * 
 *      def set_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_pixel:
 */
  __pyx_codeobj__1369 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_pixel, 16773, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1369)) __PYX_ERR(2, 16773, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16784
 *         return GiacMethods['set_pixel'](self,*args)
 * 
 *      def set_screen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_screen:
 */
  __pyx_codeobj__1370 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_screen, 16784, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1370)) __PYX_ERR(2, 16784, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16794
 *         return GiacMethods['set_screen'](self,*args)
 * 
 *      def set_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_attribute:
 */
  __pyx_codeobj__1371 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_vertex_attribute, 16794, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1371)) __PYX_ERR(2, 16794, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16805
 *         return GiacMethods['set_vertex_attribute'](self,*args)
 * 
 *      def set_vertex_positions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_positions:
 */
  __pyx_codeobj__1372 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_set_vertex_positions, 16805, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1372)) __PYX_ERR(2, 16805, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16816
 *         return GiacMethods['set_vertex_positions'](self,*args)
 * 
 *      def shift(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift:
 */
  __pyx_codeobj__1373 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_shift, 16816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1373)) __PYX_ERR(2, 16816, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16831
 *         return GiacMethods['shift'](self,*args)
 * 
 *      def shift_phase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift_phase:
 */
  __pyx_codeobj__1374 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_shift_phase, 16831, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1374)) __PYX_ERR(2, 16831, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16847
 *         return GiacMethods['shift_phase'](self,*args)
 * 
 *      def shortest_path(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shortest_path:
 */
  __pyx_codeobj__1375 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_shortest_path, 16847, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1375)) __PYX_ERR(2, 16847, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16858
 *         return GiacMethods['shortest_path'](self,*args)
 * 
 *      def show_pixels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for show_pixels:
 */
  __pyx_codeobj__1376 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_show_pixels, 16858, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1376)) __PYX_ERR(2, 16858, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16869
 *         return GiacMethods['show_pixels'](self,*args)
 * 
 *      def shuffle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shuffle:
 */
  __pyx_codeobj__1377 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_shuffle, 16869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1377)) __PYX_ERR(2, 16869, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16884
 *         return GiacMethods['shuffle'](self,*args)
 * 
 *      def sierpinski_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sierpinski_graph:
 */
  __pyx_codeobj__1378 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sierpinski_graph, 16884, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1378)) __PYX_ERR(2, 16884, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16899
 *         return GiacMethods['sierpinski_graph'](self,*args)
 * 
 *      def sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign:
 */
  __pyx_codeobj__1379 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sign, 16899, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1379)) __PYX_ERR(2, 16899, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16911
 *         return GiacMethods['sign'](self,*args)
 * 
 *      def sign2Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign2Heaviside:
 */
  __pyx_codeobj__1380 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sign2Heaviside, 16911, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1380)) __PYX_ERR(2, 16911, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16922
 *         return GiacMethods['sign2Heaviside'](self,*args)
 * 
 *      def signature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signature:
 */
  __pyx_codeobj__1381 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_signature, 16922, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1381)) __PYX_ERR(2, 16922, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16933
 *         return GiacMethods['signature'](self,*args)
 * 
 *      def signe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signe:
 */
  __pyx_codeobj__1382 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_signe, 16933, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1382)) __PYX_ERR(2, 16933, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16945
 *         return GiacMethods['signe'](self,*args)
 * 
 *      def similarity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for similarity:
 */
  __pyx_codeobj__1383 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_similarity, 16945, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1383)) __PYX_ERR(2, 16945, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16959
 *         return GiacMethods['similarity'](self,*args)
 * 
 *      def simp2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simp2:
 */
  __pyx_codeobj__1384 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simp2, 16959, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1384)) __PYX_ERR(2, 16959, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16971
 *         return GiacMethods['simp2'](self,*args)
 * 
 *      def simplex_reduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplex_reduce:
 */
  __pyx_codeobj__1385 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simplex_reduce, 16971, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1385)) __PYX_ERR(2, 16971, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16985
 *         return GiacMethods['simplex_reduce'](self,*args)
 * 
 *      def simplicial_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplicial_vertices:
 */
  __pyx_codeobj__1386 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simplicial_vertices, 16985, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1386)) __PYX_ERR(2, 16985, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":16996
 *         return GiacMethods['simplicial_vertices'](self,*args)
 * 
 *      def simplifier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifier:
 */
  __pyx_codeobj__1387 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simplifier, 16996, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1387)) __PYX_ERR(2, 16996, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17009
 *         return GiacMethods['simplifier'](self,*args)
 * 
 *      def simplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplify:
 */
  __pyx_codeobj__1388 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simplify, 17009, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1388)) __PYX_ERR(2, 17009, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17022
 *         return GiacMethods['simplify'](self,*args)
 * 
 *      def simplifyDirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifyDirac:
 */
  __pyx_codeobj__1389 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simplifyDirac, 17022, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1389)) __PYX_ERR(2, 17022, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17035
 *         return GiacMethods['simplifyDirac'](self,*args)
 * 
 *      def simpson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simpson:
 */
  __pyx_codeobj__1390 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simpson, 17035, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1390)) __PYX_ERR(2, 17035, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17049
 *         return GiacMethods['simpson'](self,*args)
 * 
 *      def simulated_annealing(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simulated_annealing:
 */
  __pyx_codeobj__1391 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simulated_annealing, 17049, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1391)) __PYX_ERR(2, 17049, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17060
 *         return GiacMethods['simulated_annealing'](self,*args)
 * 
 *      def simult(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simult:
 */
  __pyx_codeobj__1392 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_simult, 17060, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1392)) __PYX_ERR(2, 17060, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17072
 *         return GiacMethods['simult'](self,*args)
 * 
 *      def sin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin:
 */
  __pyx_codeobj__1393 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sin, 17072, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1393)) __PYX_ERR(2, 17072, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17084
 *         return GiacMethods['sin'](self,*args)
 * 
 *      def sin2costan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin2costan:
 */
  __pyx_codeobj__1394 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sin2costan, 17084, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1394)) __PYX_ERR(2, 17084, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17095
 *         return GiacMethods['sin2costan'](self,*args)
 * 
 *      def sinc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinc:
 */
  __pyx_codeobj__1395 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sinc, 17095, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1395)) __PYX_ERR(2, 17095, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17106
 *         return GiacMethods['sinc'](self,*args)
 * 
 *      def sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sincos:
 */
  __pyx_codeobj__1396 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sincos, 17106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1396)) __PYX_ERR(2, 17106, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17119
 *         return GiacMethods['sincos'](self,*args)
 * 
 *      def single_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for single_inter:
 */
  __pyx_codeobj__1397 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_single_inter, 17119, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1397)) __PYX_ERR(2, 17119, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17136
 *         return GiacMethods['single_inter'](self,*args)
 * 
 *      def sinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinh:
 */
  __pyx_codeobj__1398 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sinh, 17136, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1398)) __PYX_ERR(2, 17136, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17147
 *         return GiacMethods['sinh'](self,*args)
 * 
 *      def sizes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sizes:
 */
  __pyx_codeobj__1399 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sizes, 17147, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1399)) __PYX_ERR(2, 17147, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17158
 *         return GiacMethods['sizes'](self,*args)
 * 
 *      def slope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slope:
 */
  __pyx_codeobj__1400 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_slope, 17158, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1400)) __PYX_ERR(2, 17158, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17176
 *         return GiacMethods['slope'](self,*args)
 * 
 *      def slopeat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeat:
 */
  __pyx_codeobj__1401 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_slopeat, 17176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1401)) __PYX_ERR(2, 17176, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17189
 *         return GiacMethods['slopeat'](self,*args)
 * 
 *      def slopeatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeatraw:
 */
  __pyx_codeobj__1402 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_slopeatraw, 17189, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1402)) __PYX_ERR(2, 17189, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17203
 *         return GiacMethods['slopeatraw'](self,*args)
 * 
 *      def smith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smith:
 */
  __pyx_codeobj__1403 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_smith, 17203, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1403)) __PYX_ERR(2, 17203, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17215
 *         return GiacMethods['smith'](self,*args)
 * 
 *      def smod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smod:
 */
  __pyx_codeobj__1404 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_smod, 17215, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1404)) __PYX_ERR(2, 17215, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17228
 *         return GiacMethods['smod'](self,*args)
 * 
 *      def snedecor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor:
 */
  __pyx_codeobj__1405 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_snedecor, 17228, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1405)) __PYX_ERR(2, 17228, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17242
 *         return GiacMethods['snedecor'](self,*args)
 * 
 *      def snedecor_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_cdf:
 */
  __pyx_codeobj__1406 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_snedecor_cdf, 17242, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1406)) __PYX_ERR(2, 17242, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17254
 *         return GiacMethods['snedecor_cdf'](self,*args)
 * 
 *      def snedecor_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_icdf:
 */
  __pyx_codeobj__1407 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_snedecor_icdf, 17254, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1407)) __PYX_ERR(2, 17254, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17266
 *         return GiacMethods['snedecor_icdf'](self,*args)
 * 
 *      def snedecord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord:
 */
  __pyx_codeobj__1408 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_snedecord, 17266, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1408)) __PYX_ERR(2, 17266, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17280
 *         return GiacMethods['snedecord'](self,*args)
 * 
 *      def snedecord_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_cdf:
 */
  __pyx_codeobj__1409 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_snedecord_cdf, 17280, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1409)) __PYX_ERR(2, 17280, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17292
 *         return GiacMethods['snedecord_cdf'](self,*args)
 * 
 *      def snedecord_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_icdf:
 */
  __pyx_codeobj__1410 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_snedecord_icdf, 17292, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1410)) __PYX_ERR(2, 17292, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17304
 *         return GiacMethods['snedecord_icdf'](self,*args)
 * 
 *      def solid_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solid_line:
 */
  __pyx_codeobj__1411 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_solid_line, 17304, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1411)) __PYX_ERR(2, 17304, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17316
 *         return GiacMethods['solid_line'](self,*args)
 * 
 *      def solve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solve:
 */
  __pyx_codeobj__1412 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_solve, 17316, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1412)) __PYX_ERR(2, 17316, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17330
 *         return GiacMethods['solve'](self,*args)
 * 
 *      def somme(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for somme:
 */
  __pyx_codeobj__1413 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_somme, 17330, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1413)) __PYX_ERR(2, 17330, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17350
 *         return GiacMethods['somme'](self,*args)
 * 
 *      def sommet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sommet:
 */
  __pyx_codeobj__1414 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sommet, 17350, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1414)) __PYX_ERR(2, 17350, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17362
 *         return GiacMethods['sommet'](self,*args)
 * 
 *      def sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sort:
 */
  __pyx_codeobj__1415 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sort, 17362, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1415)) __PYX_ERR(2, 17362, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17377
 *         return GiacMethods['sort'](self,*args)
 * 
 *      def sorta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorta:
 */
  __pyx_codeobj__1416 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sorta, 17377, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1416)) __PYX_ERR(2, 17377, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17390
 *         return GiacMethods['sorta'](self,*args)
 * 
 *      def sortd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortd:
 */
  __pyx_codeobj__1417 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sortd, 17390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1417)) __PYX_ERR(2, 17390, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17403
 *         return GiacMethods['sortd'](self,*args)
 * 
 *      def sorted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorted:
 */
  __pyx_codeobj__1418 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sorted, 17403, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1418)) __PYX_ERR(2, 17403, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17418
 *         return GiacMethods['sorted'](self,*args)
 * 
 *      def sortperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortperm:
 */
  __pyx_codeobj__1419 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sortperm, 17418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1419)) __PYX_ERR(2, 17418, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17430
 *         return GiacMethods['sortperm'](self,*args)
 * 
 *      def soundsec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for soundsec:
 */
  __pyx_codeobj__1420 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_soundsec, 17430, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1420)) __PYX_ERR(2, 17430, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17442
 *         return GiacMethods['soundsec'](self,*args)
 * 
 *      def spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spanning_tree:
 */
  __pyx_codeobj__1421 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_spanning_tree, 17442, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1421)) __PYX_ERR(2, 17442, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17454
 *         return GiacMethods['spanning_tree'](self,*args)
 * 
 *      def sphere(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sphere:
 */
  __pyx_codeobj__1422 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sphere, 17454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1422)) __PYX_ERR(2, 17454, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17466
 *         return GiacMethods['sphere'](self,*args)
 * 
 *      def splice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for splice:
 */
  __pyx_codeobj__1423 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_splice, 17466, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1423)) __PYX_ERR(2, 17466, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17477
 *         return GiacMethods['splice'](self,*args)
 * 
 *      def spline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spline:
 */
  __pyx_codeobj__1424 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_spline, 17477, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1424)) __PYX_ERR(2, 17477, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17488
 *         return GiacMethods['spline'](self,*args)
 * 
 *      def split(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for split:
 */
  __pyx_codeobj__1425 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_split, 17488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1425)) __PYX_ERR(2, 17488, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17501
 *         return GiacMethods['split'](self,*args)
 * 
 *      def spring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spring:
 */
  __pyx_codeobj__1426 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_spring, 17501, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1426)) __PYX_ERR(2, 17501, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17511
 *         return GiacMethods['spring'](self,*args)
 * 
 *      def sq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sq:
 */
  __pyx_codeobj__1427 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sq, 17511, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1427)) __PYX_ERR(2, 17511, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17523
 *         return GiacMethods['sq'](self,*args)
 * 
 *      def sqrfree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrfree:
 */
  __pyx_codeobj__1428 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sqrfree, 17523, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1428)) __PYX_ERR(2, 17523, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17535
 *         return GiacMethods['sqrfree'](self,*args)
 * 
 *      def sqrt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrt:
 */
  __pyx_codeobj__1429 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sqrt, 17535, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1429)) __PYX_ERR(2, 17535, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17547
 *         return GiacMethods['sqrt'](self,*args)
 * 
 *      def square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square:
 */
  __pyx_codeobj__1430 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_square, 17547, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1430)) __PYX_ERR(2, 17547, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17561
 *         return GiacMethods['square'](self,*args)
 * 
 *      def square_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square_point:
 */
  __pyx_codeobj__1431 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_square_point, 17561, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1431)) __PYX_ERR(2, 17561, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17573
 *         return GiacMethods['square_point'](self,*args)
 * 
 *      def srand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for srand:
 */
  __pyx_codeobj__1432 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_srand, 17573, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1432)) __PYX_ERR(2, 17573, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17585
 *         return GiacMethods['srand'](self,*args)
 * 
 *      def sst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst:
 */
  __pyx_codeobj__1433 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sst, 17585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1433)) __PYX_ERR(2, 17585, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17596
 *         return GiacMethods['sst'](self,*args)
 * 
 *      def sst_in(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst_in:
 */
  __pyx_codeobj__1434 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sst_in, 17596, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1434)) __PYX_ERR(2, 17596, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17607
 *         return GiacMethods['sst_in'](self,*args)
 * 
 *      def st_ordering(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for st_ordering:
 */
  __pyx_codeobj__1435 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_st_ordering, 17607, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1435)) __PYX_ERR(2, 17607, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17618
 *         return GiacMethods['st_ordering'](self,*args)
 * 
 *      def star_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_graph:
 */
  __pyx_codeobj__1436 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_star_graph, 17618, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1436)) __PYX_ERR(2, 17618, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17629
 *         return GiacMethods['star_graph'](self,*args)
 * 
 *      def star_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_point:
 */
  __pyx_codeobj__1437 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_star_point, 17629, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1437)) __PYX_ERR(2, 17629, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17641
 *         return GiacMethods['star_point'](self,*args)
 * 
 *      def stdDev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stdDev:
 */
  __pyx_codeobj__1438 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_stdDev, 17641, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1438)) __PYX_ERR(2, 17641, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17654
 *         return GiacMethods['stdDev'](self,*args)
 * 
 *      def stddev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddev:
 */
  __pyx_codeobj__1439 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_stddev, 17654, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1439)) __PYX_ERR(2, 17654, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17667
 *         return GiacMethods['stddev'](self,*args)
 * 
 *      def stddevp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddevp:
 */
  __pyx_codeobj__1440 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_stddevp, 17667, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1440)) __PYX_ERR(2, 17667, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17680
 *         return GiacMethods['stddevp'](self,*args)
 * 
 *      def steffenson_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for steffenson_solver:
 */
  __pyx_codeobj__1441 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_steffenson_solver, 17680, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1441)) __PYX_ERR(2, 17680, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17696
 *         return GiacMethods['steffenson_solver'](self,*args)
 * 
 *      def stereo2mono(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stereo2mono:
 */
  __pyx_codeobj__1442 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_stereo2mono, 17696, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1442)) __PYX_ERR(2, 17696, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17707
 *         return GiacMethods['stereo2mono'](self,*args)
 * 
 *      def stft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stft:
 */
  __pyx_codeobj__1443 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_stft, 17707, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1443)) __PYX_ERR(2, 17707, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17719
 *         return GiacMethods['stft'](self,*args)
 * 
 *      def str(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for str:
 */
  __pyx_codeobj__1444 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_str, 17719, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1444)) __PYX_ERR(2, 17719, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17733
 *         return GiacMethods['str'](self,*args)
 * 
 *      def strip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strip:
 */
  __pyx_codeobj__1445 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_strip, 17733, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1445)) __PYX_ERR(2, 17733, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17744
 *         return GiacMethods['strip'](self,*args)
 * 
 *      def strongly_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strongly_connected_components:
 */
  __pyx_codeobj__1446 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_strongly_connected_components, 17744, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1446)) __PYX_ERR(2, 17744, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17755
 *         return GiacMethods['strongly_connected_components'](self,*args)
 * 
 *      def student(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student:
 */
  __pyx_codeobj__1447 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_student, 17755, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1447)) __PYX_ERR(2, 17755, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17767
 *         return GiacMethods['student'](self,*args)
 * 
 *      def student_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_cdf:
 */
  __pyx_codeobj__1448 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_student_cdf, 17767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1448)) __PYX_ERR(2, 17767, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17779
 *         return GiacMethods['student_cdf'](self,*args)
 * 
 *      def student_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_icdf:
 */
  __pyx_codeobj__1449 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_student_icdf, 17779, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1449)) __PYX_ERR(2, 17779, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17791
 *         return GiacMethods['student_icdf'](self,*args)
 * 
 *      def studentd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentd:
 */
  __pyx_codeobj__1450 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_studentd, 17791, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1450)) __PYX_ERR(2, 17791, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17803
 *         return GiacMethods['studentd'](self,*args)
 * 
 *      def studentt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentt:
 */
  __pyx_codeobj__1451 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_studentt, 17803, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1451)) __PYX_ERR(2, 17803, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17815
 *         return GiacMethods['studentt'](self,*args)
 * 
 *      def sturm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturm:
 */
  __pyx_codeobj__1452 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sturm, 17815, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1452)) __PYX_ERR(2, 17815, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17830
 *         return GiacMethods['sturm'](self,*args)
 * 
 *      def sturmab(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmab:
 */
  __pyx_codeobj__1453 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sturmab, 17830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1453)) __PYX_ERR(2, 17830, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17842
 *         return GiacMethods['sturmab'](self,*args)
 * 
 *      def sturmseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmseq:
 */
  __pyx_codeobj__1454 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sturmseq, 17842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1454)) __PYX_ERR(2, 17842, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17855
 *         return GiacMethods['sturmseq'](self,*args)
 * 
 *      def style(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for style:
 */
  __pyx_codeobj__1455 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_style, 17855, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1455)) __PYX_ERR(2, 17855, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17867
 *         return GiacMethods['style'](self,*args)
 * 
 *      def subMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subMat:
 */
  __pyx_codeobj__1456 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subMat, 17867, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1456)) __PYX_ERR(2, 17867, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17878
 *         return GiacMethods['subMat'](self,*args)
 * 
 *      def subdivide_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subdivide_edges:
 */
  __pyx_codeobj__1457 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subdivide_edges, 17878, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1457)) __PYX_ERR(2, 17878, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17889
 *         return GiacMethods['subdivide_edges'](self,*args)
 * 
 *      def subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subgraph:
 */
  __pyx_codeobj__1458 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subgraph, 17889, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1458)) __PYX_ERR(2, 17889, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17900
 *         return GiacMethods['subgraph'](self,*args)
 * 
 *      def subs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subs:
 */
  __pyx_codeobj__1459 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subs, 17900, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1459)) __PYX_ERR(2, 17900, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17913
 *         return GiacMethods['subs'](self,*args)
 * 
 *      def subsop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subsop:
 */
  __pyx_codeobj__1460 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subsop, 17913, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1460)) __PYX_ERR(2, 17913, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17926
 *         return GiacMethods['subsop'](self,*args)
 * 
 *      def subst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subst:
 */
  __pyx_codeobj__1461 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subst, 17926, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1461)) __PYX_ERR(2, 17926, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17943
 *         return GiacMethods['subst'](self,*args)
 * 
 *      def substituer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for substituer:
 */
  __pyx_codeobj__1462 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_substituer, 17943, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1462)) __PYX_ERR(2, 17943, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17960
 *         return GiacMethods['substituer'](self,*args)
 * 
 *      def subtype(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subtype:
 */
  __pyx_codeobj__1463 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_subtype, 17960, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1463)) __PYX_ERR(2, 17960, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17974
 *         return GiacMethods['subtype'](self,*args)
 * 
 *      def sum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum:
 */
  __pyx_codeobj__1464 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sum, 17974, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1464)) __PYX_ERR(2, 17974, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":17994
 *         return GiacMethods['sum'](self,*args)
 * 
 *      def sum_riemann(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum_riemann:
 */
  __pyx_codeobj__1465 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sum_riemann, 17994, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1465)) __PYX_ERR(2, 17994, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18007
 *         return GiacMethods['sum_riemann'](self,*args)
 * 
 *      def suppress(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for suppress:
 */
  __pyx_codeobj__1466 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_suppress, 18007, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1466)) __PYX_ERR(2, 18007, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18021
 *         return GiacMethods['suppress'](self,*args)
 * 
 *      def surd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for surd:
 */
  __pyx_codeobj__1467 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_surd, 18021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1467)) __PYX_ERR(2, 18021, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18033
 *         return GiacMethods['surd'](self,*args)
 * 
 *      def svd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for svd:
 */
  __pyx_codeobj__1468 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_svd, 18033, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1468)) __PYX_ERR(2, 18033, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18043
 *         return GiacMethods['svd'](self,*args)
 * 
 *      def swapcol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swapcol:
 */
  __pyx_codeobj__1469 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_swapcol, 18043, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1469)) __PYX_ERR(2, 18043, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18054
 *         return GiacMethods['swapcol'](self,*args)
 * 
 *      def swaprow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swaprow:
 */
  __pyx_codeobj__1470 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_swaprow, 18054, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1470)) __PYX_ERR(2, 18054, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18065
 *         return GiacMethods['swaprow'](self,*args)
 * 
 *      def switch_axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for switch_axes:
 */
  __pyx_codeobj__1471 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_switch_axes, 18065, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1471)) __PYX_ERR(2, 18065, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18078
 *         return GiacMethods['switch_axes'](self,*args)
 * 
 *      def sylvester(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sylvester:
 */
  __pyx_codeobj__1472 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_sylvester, 18078, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1472)) __PYX_ERR(2, 18078, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18090
 *         return GiacMethods['sylvester'](self,*args)
 * 
 *      def symb2poly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symb2poly:
 */
  __pyx_codeobj__1473 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_symb2poly, 18090, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1473)) __PYX_ERR(2, 18090, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18106
 *         return GiacMethods['symb2poly'](self,*args)
 * 
 *      def symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol:
 */
  __pyx_codeobj__1474 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_symbol, 18106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1474)) __PYX_ERR(2, 18106, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18120
 *         return GiacMethods['symbol'](self,*args)
 * 
 *      def symbol_array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol_array:
 */
  __pyx_codeobj__1475 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_symbol_array, 18120, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1475)) __PYX_ERR(2, 18120, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18133
 *         return GiacMethods['symbol_array'](self,*args)
 * 
 *      def syst2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for syst2mat:
 */
  __pyx_codeobj__1476 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_syst2mat, 18133, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1476)) __PYX_ERR(2, 18133, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18144
 *         return GiacMethods['syst2mat'](self,*args)
 * 
 *      def tCollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tCollect:
 */
  __pyx_codeobj__1477 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tCollect, 18144, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1477)) __PYX_ERR(2, 18144, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18155
 *         return GiacMethods['tCollect'](self,*args)
 * 
 *      def tExpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tExpand:
 */
  __pyx_codeobj__1478 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tExpand, 18155, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1478)) __PYX_ERR(2, 18155, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18168
 *         return GiacMethods['tExpand'](self,*args)
 * 
 *      def table(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for table:
 */
  __pyx_codeobj__1479 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_table, 18168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1479)) __PYX_ERR(2, 18168, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18181
 *         return GiacMethods['table'](self,*args)
 * 
 *      def tablefunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tablefunc:
 */
  __pyx_codeobj__1480 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tablefunc, 18181, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1480)) __PYX_ERR(2, 18181, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18193
 *         return GiacMethods['tablefunc'](self,*args)
 * 
 *      def tableseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tableseq:
 */
  __pyx_codeobj__1481 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tableseq, 18193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1481)) __PYX_ERR(2, 18193, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18205
 *         return GiacMethods['tableseq'](self,*args)
 * 
 *      def tabsign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabsign:
 */
  __pyx_codeobj__1482 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tabsign, 18205, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1482)) __PYX_ERR(2, 18205, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18218
 *         return GiacMethods['tabsign'](self,*args)
 * 
 *      def tabvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabvar:
 */
  __pyx_codeobj__1483 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tabvar, 18218, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1483)) __PYX_ERR(2, 18218, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18233
 *         return GiacMethods['tabvar'](self,*args)
 * 
 *      def tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tail:
 */
  __pyx_codeobj__1484 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tail, 18233, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1484)) __PYX_ERR(2, 18233, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18246
 *         return GiacMethods['tail'](self,*args)
 * 
 *      def tan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan:
 */
  __pyx_codeobj__1485 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tan, 18246, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1485)) __PYX_ERR(2, 18246, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18259
 *         return GiacMethods['tan'](self,*args)
 * 
 *      def tan2cossin2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2cossin2:
 */
  __pyx_codeobj__1486 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tan2cossin2, 18259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1486)) __PYX_ERR(2, 18259, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18270
 *         return GiacMethods['tan2cossin2'](self,*args)
 * 
 *      def tan2sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos:
 */
  __pyx_codeobj__1487 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tan2sincos, 18270, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1487)) __PYX_ERR(2, 18270, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18281
 *         return GiacMethods['tan2sincos'](self,*args)
 * 
 *      def tan2sincos2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos2:
 */
  __pyx_codeobj__1488 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tan2sincos2, 18281, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1488)) __PYX_ERR(2, 18281, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18292
 *         return GiacMethods['tan2sincos2'](self,*args)
 * 
 *      def tangent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangent:
 */
  __pyx_codeobj__1489 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tangent, 18292, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1489)) __PYX_ERR(2, 18292, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18310
 *         return GiacMethods['tangent'](self,*args)
 * 
 *      def tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangente:
 */
  __pyx_codeobj__1490 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tangente, 18310, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1490)) __PYX_ERR(2, 18310, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18328
 *         return GiacMethods['tangente'](self,*args)
 * 
 *      def tanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tanh:
 */
  __pyx_codeobj__1491 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tanh, 18328, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1491)) __PYX_ERR(2, 18328, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18340
 *         return GiacMethods['tanh'](self,*args)
 * 
 *      def tar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tar:
 */
  __pyx_codeobj__1492 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tar, 18340, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1492)) __PYX_ERR(2, 18340, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18356
 *         return GiacMethods['tar'](self,*args)
 * 
 *      def taux_accroissement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taux_accroissement:
 */
  __pyx_codeobj__1493 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_taux_accroissement, 18356, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1493)) __PYX_ERR(2, 18356, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18369
 *         return GiacMethods['taux_accroissement'](self,*args)
 * 
 *      def taylor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taylor:
 */
  __pyx_codeobj__1494 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_taylor, 18369, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1494)) __PYX_ERR(2, 18369, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18389
 *         return GiacMethods['taylor'](self,*args)
 * 
 *      def tchebyshev1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev1:
 */
  __pyx_codeobj__1495 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tchebyshev1, 18389, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1495)) __PYX_ERR(2, 18389, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18400
 *         return GiacMethods['tchebyshev1'](self,*args)
 * 
 *      def tchebyshev2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev2:
 */
  __pyx_codeobj__1496 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tchebyshev2, 18400, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1496)) __PYX_ERR(2, 18400, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18411
 *         return GiacMethods['tchebyshev2'](self,*args)
 * 
 *      def tcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcoeff:
 */
  __pyx_codeobj__1497 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tcoeff, 18411, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1497)) __PYX_ERR(2, 18411, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18423
 *         return GiacMethods['tcoeff'](self,*args)
 * 
 *      def tcollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcollect:
 */
  __pyx_codeobj__1498 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tcollect, 18423, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1498)) __PYX_ERR(2, 18423, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18434
 *         return GiacMethods['tcollect'](self,*args)
 * 
 *      def tdeg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tdeg:
 */
  __pyx_codeobj__1499 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tdeg, 18434, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1499)) __PYX_ERR(2, 18434, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18444
 *         return GiacMethods['tdeg'](self,*args)
 * 
 *      def teal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for teal:
 */
  __pyx_codeobj__1500 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_teal, 18444, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1500)) __PYX_ERR(2, 18444, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18456
 *         return GiacMethods['teal'](self,*args)
 * 
 *      def tensor_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tensor_product:
 */
  __pyx_codeobj__1501 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tensor_product, 18456, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1501)) __PYX_ERR(2, 18456, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18467
 *         return GiacMethods['tensor_product'](self,*args)
 * 
 *      def tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tetrahedron:
 */
  __pyx_codeobj__1502 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tetrahedron, 18467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1502)) __PYX_ERR(2, 18467, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18479
 *         return GiacMethods['tetrahedron'](self,*args)
 * 
 *      def texpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for texpand:
 */
  __pyx_codeobj__1503 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_texpand, 18479, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1503)) __PYX_ERR(2, 18479, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18492
 *         return GiacMethods['texpand'](self,*args)
 * 
 *      def thickness(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for thickness:
 */
  __pyx_codeobj__1504 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_thickness, 18492, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1504)) __PYX_ERR(2, 18492, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18504
 *         return GiacMethods['thickness'](self,*args)
 * 
 *      def threshold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for threshold:
 */
  __pyx_codeobj__1505 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_threshold, 18504, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1505)) __PYX_ERR(2, 18504, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18516
 *         return GiacMethods['threshold'](self,*args)
 * 
 *      def throw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for throw:
 */
  __pyx_codeobj__1506 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_throw, 18516, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1506)) __PYX_ERR(2, 18516, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18528
 *         return GiacMethods['throw'](self,*args)
 * 
 *      def title(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for title:
 */
  __pyx_codeobj__1507 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_title, 18528, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1507)) __PYX_ERR(2, 18528, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18540
 *         return GiacMethods['title'](self,*args)
 * 
 *      def titre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for titre:
 */
  __pyx_codeobj__1508 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_titre, 18540, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1508)) __PYX_ERR(2, 18540, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18552
 *         return GiacMethods['titre'](self,*args)
 * 
 *      def tlin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tlin:
 */
  __pyx_codeobj__1509 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tlin, 18552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1509)) __PYX_ERR(2, 18552, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18564
 *         return GiacMethods['tlin'](self,*args)
 * 
 *      def tonnetz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tonnetz:
 */
  __pyx_codeobj__1510 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tonnetz, 18564, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1510)) __PYX_ERR(2, 18564, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18576
 *         return GiacMethods['tonnetz'](self,*args)
 * 
 *      def topologic_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topologic_sort:
 */
  __pyx_codeobj__1511 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_topologic_sort, 18576, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1511)) __PYX_ERR(2, 18576, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18587
 *         return GiacMethods['topologic_sort'](self,*args)
 * 
 *      def topological_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topological_sort:
 */
  __pyx_codeobj__1512 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_topological_sort, 18587, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1512)) __PYX_ERR(2, 18587, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18598
 *         return GiacMethods['topological_sort'](self,*args)
 * 
 *      def topology(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topology:
 */
  __pyx_codeobj__1513 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_topology, 18598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1513)) __PYX_ERR(2, 18598, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18608
 *         return GiacMethods['topology'](self,*args)
 * 
 *      def torus_grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for torus_grid_graph:
 */
  __pyx_codeobj__1514 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_torus_grid_graph, 18608, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1514)) __PYX_ERR(2, 18608, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18619
 *         return GiacMethods['torus_grid_graph'](self,*args)
 * 
 *      def total_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for total_degree:
 */
  __pyx_codeobj__1515 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_total_degree, 18619, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1515)) __PYX_ERR(2, 18619, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18630
 *         return GiacMethods['total_degree'](self,*args)
 * 
 *      def tourne_droite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_droite:
 */
  __pyx_codeobj__1516 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tourne_droite, 18630, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1516)) __PYX_ERR(2, 18630, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18642
 *         return GiacMethods['tourne_droite'](self,*args)
 * 
 *      def tourne_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_gauche:
 */
  __pyx_codeobj__1517 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tourne_gauche, 18642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1517)) __PYX_ERR(2, 18642, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18654
 *         return GiacMethods['tourne_gauche'](self,*args)
 * 
 *      def tpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tpsolve:
 */
  __pyx_codeobj__1518 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tpsolve, 18654, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1518)) __PYX_ERR(2, 18654, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18666
 *         return GiacMethods['tpsolve'](self,*args)
 * 
 *      def trace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trace:
 */
  __pyx_codeobj__1519 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trace, 18666, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1519)) __PYX_ERR(2, 18666, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18680
 *         return GiacMethods['trace'](self,*args)
 * 
 *      def trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail:
 */
  __pyx_codeobj__1520 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trail, 18680, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1520)) __PYX_ERR(2, 18680, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18691
 *         return GiacMethods['trail'](self,*args)
 * 
 *      def trail2edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail2edges:
 */
  __pyx_codeobj__1521 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trail2edges, 18691, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1521)) __PYX_ERR(2, 18691, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18703
 *         return GiacMethods['trail2edges'](self,*args)
 * 
 *      def train(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for train:
 */
  __pyx_codeobj__1522 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_train, 18703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1522)) __PYX_ERR(2, 18703, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18714
 *         return GiacMethods['train'](self,*args)
 * 
 *      def trames(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trames:
 */
  __pyx_codeobj__1523 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trames, 18714, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1523)) __PYX_ERR(2, 18714, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18726
 *         return GiacMethods['trames'](self,*args)
 * 
 *      def tran(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tran:
 */
  __pyx_codeobj__1524 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tran, 18726, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1524)) __PYX_ERR(2, 18726, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18739
 *         return GiacMethods['tran'](self,*args)
 * 
 *      def transitive_closure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transitive_closure:
 */
  __pyx_codeobj__1525 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_transitive_closure, 18739, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1525)) __PYX_ERR(2, 18739, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18750
 *         return GiacMethods['transitive_closure'](self,*args)
 * 
 *      def translation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for translation:
 */
  __pyx_codeobj__1526 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_translation, 18750, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1526)) __PYX_ERR(2, 18750, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18764
 *         return GiacMethods['translation'](self,*args)
 * 
 *      def transpose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transpose:
 */
  __pyx_codeobj__1527 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_transpose, 18764, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1527)) __PYX_ERR(2, 18764, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18777
 *         return GiacMethods['transpose'](self,*args)
 * 
 *      def trapeze(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapeze:
 */
  __pyx_codeobj__1528 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trapeze, 18777, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1528)) __PYX_ERR(2, 18777, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18793
 *         return GiacMethods['trapeze'](self,*args)
 * 
 *      def trapezoid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapezoid:
 */
  __pyx_codeobj__1529 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trapezoid, 18793, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1529)) __PYX_ERR(2, 18793, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18809
 *         return GiacMethods['trapezoid'](self,*args)
 * 
 *      def traveling_salesman(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for traveling_salesman:
 */
  __pyx_codeobj__1530 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_traveling_salesman, 18809, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1530)) __PYX_ERR(2, 18809, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18824
 *         return GiacMethods['traveling_salesman'](self,*args)
 * 
 *      def tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree:
 */
  __pyx_codeobj__1531 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tree, 18824, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1531)) __PYX_ERR(2, 18824, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18834
 *         return GiacMethods['tree'](self,*args)
 * 
 *      def tree_height(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree_height:
 */
  __pyx_codeobj__1532 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tree_height, 18834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1532)) __PYX_ERR(2, 18834, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18845
 *         return GiacMethods['tree_height'](self,*args)
 * 
 *      def tri(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tri:
 */
  __pyx_codeobj__1533 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tri, 18845, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1533)) __PYX_ERR(2, 18845, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18856
 *         return GiacMethods['tri'](self,*args)
 * 
 *      def triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle:
 */
  __pyx_codeobj__1534 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_triangle, 18856, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1534)) __PYX_ERR(2, 18856, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18869
 *         return GiacMethods['triangle'](self,*args)
 * 
 *      def triangle_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_paper:
 */
  __pyx_codeobj__1535 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_triangle_paper, 18869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1535)) __PYX_ERR(2, 18869, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18882
 *         return GiacMethods['triangle_paper'](self,*args)
 * 
 *      def triangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_plein:
 */
  __pyx_codeobj__1536 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_triangle_plein, 18882, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1536)) __PYX_ERR(2, 18882, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18896
 *         return GiacMethods['triangle_plein'](self,*args)
 * 
 *      def triangle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_point:
 */
  __pyx_codeobj__1537 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_triangle_point, 18896, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1537)) __PYX_ERR(2, 18896, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18908
 *         return GiacMethods['triangle_point'](self,*args)
 * 
 *      def triangle_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_window:
 */
  __pyx_codeobj__1538 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_triangle_window, 18908, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1538)) __PYX_ERR(2, 18908, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18919
 *         return GiacMethods['triangle_window'](self,*args)
 * 
 *      def trig2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trig2exp:
 */
  __pyx_codeobj__1539 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trig2exp, 18919, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1539)) __PYX_ERR(2, 18919, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18930
 *         return GiacMethods['trig2exp'](self,*args)
 * 
 *      def trigcos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigcos:
 */
  __pyx_codeobj__1540 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trigcos, 18930, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1540)) __PYX_ERR(2, 18930, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18941
 *         return GiacMethods['trigcos'](self,*args)
 * 
 *      def trigexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigexpand:
 */
  __pyx_codeobj__1541 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trigexpand, 18941, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1541)) __PYX_ERR(2, 18941, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18952
 *         return GiacMethods['trigexpand'](self,*args)
 * 
 *      def triginterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triginterp:
 */
  __pyx_codeobj__1542 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_triginterp, 18952, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1542)) __PYX_ERR(2, 18952, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18964
 *         return GiacMethods['triginterp'](self,*args)
 * 
 *      def trigsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsimplify:
 */
  __pyx_codeobj__1543 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trigsimplify, 18964, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1543)) __PYX_ERR(2, 18964, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18975
 *         return GiacMethods['trigsimplify'](self,*args)
 * 
 *      def trigsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsin:
 */
  __pyx_codeobj__1544 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trigsin, 18975, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1544)) __PYX_ERR(2, 18975, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18986
 *         return GiacMethods['trigsin'](self,*args)
 * 
 *      def trigtan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigtan:
 */
  __pyx_codeobj__1545 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trigtan, 18986, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1545)) __PYX_ERR(2, 18986, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":18997
 *         return GiacMethods['trigtan'](self,*args)
 * 
 *      def trim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trim:
 */
  __pyx_codeobj__1546 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trim, 18997, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1546)) __PYX_ERR(2, 18997, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19010
 *         return GiacMethods['trim'](self,*args)
 * 
 *      def trn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trn:
 */
  __pyx_codeobj__1547 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trn, 19010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1547)) __PYX_ERR(2, 19010, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19021
 *         return GiacMethods['trn'](self,*args)
 * 
 *      def true(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for true:
 */
  __pyx_codeobj__1548 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_true, 19021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1548)) __PYX_ERR(2, 19021, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19032
 *         return GiacMethods['true'](self,*args)
 * 
 *      def trunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trunc:
 */
  __pyx_codeobj__1549 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_trunc, 19032, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1549)) __PYX_ERR(2, 19032, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19047
 *         return GiacMethods['trunc'](self,*args)
 * 
 *      def truncate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate:
 */
  __pyx_codeobj__1550 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_truncate, 19047, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1550)) __PYX_ERR(2, 19047, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19058
 *         return GiacMethods['truncate'](self,*args)
 * 
 *      def truncate_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate_graph:
 */
  __pyx_codeobj__1551 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_truncate_graph, 19058, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1551)) __PYX_ERR(2, 19058, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19069
 *         return GiacMethods['truncate_graph'](self,*args)
 * 
 *      def tsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tsimplify:
 */
  __pyx_codeobj__1552 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tsimplify, 19069, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1552)) __PYX_ERR(2, 19069, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19080
 *         return GiacMethods['tsimplify'](self,*args)
 * 
 *      def tstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tstep:
 */
  __pyx_codeobj__1553 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tstep, 19080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1553)) __PYX_ERR(2, 19080, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19089
 *         return GiacMethods['tstep'](self,*args)
 * 
 *      def tuer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tuer:
 */
  __pyx_codeobj__1554 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tuer, 19089, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1554)) __PYX_ERR(2, 19089, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19100
 *         return GiacMethods['tuer'](self,*args)
 * 
 *      def tukey_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tukey_window:
 */
  __pyx_codeobj__1555 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tukey_window, 19100, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1555)) __PYX_ERR(2, 19100, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19111
 *         return GiacMethods['tukey_window'](self,*args)
 * 
 *      def tutte_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tutte_polynomial:
 */
  __pyx_codeobj__1556 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_tutte_polynomial, 19111, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1556)) __PYX_ERR(2, 19111, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19123
 *         return GiacMethods['tutte_polynomial'](self,*args)
 * 
 *      def two_edge_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for two_edge_connected_components:
 */
  __pyx_codeobj__1557 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_two_edge_connected_components, 19123, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1557)) __PYX_ERR(2, 19123, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19134
 *         return GiacMethods['two_edge_connected_components'](self,*args)
 * 
 *      def ufactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ufactor:
 */
  __pyx_codeobj__1558 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ufactor, 19134, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1558)) __PYX_ERR(2, 19134, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19145
 *         return GiacMethods['ufactor'](self,*args)
 * 
 *      def ugamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ugamma:
 */
  __pyx_codeobj__1559 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ugamma, 19145, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1559)) __PYX_ERR(2, 19145, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19157
 *         return GiacMethods['ugamma'](self,*args)
 * 
 *      def unapply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unapply:
 */
  __pyx_codeobj__1560 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_unapply, 19157, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1560)) __PYX_ERR(2, 19157, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19169
 *         return GiacMethods['unapply'](self,*args)
 * 
 *      def unarchive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unarchive:
 */
  __pyx_codeobj__1561 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_unarchive, 19169, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1561)) __PYX_ERR(2, 19169, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19181
 *         return GiacMethods['unarchive'](self,*args)
 * 
 *      def undef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for undef:
 */
  __pyx_codeobj__1562 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_undef, 19181, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1562)) __PYX_ERR(2, 19181, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19192
 *         return GiacMethods['undef'](self,*args)
 * 
 *      def underlying_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for underlying_graph:
 */
  __pyx_codeobj__1563 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_underlying_graph, 19192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1563)) __PYX_ERR(2, 19192, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19203
 *         return GiacMethods['underlying_graph'](self,*args)
 * 
 *      def unfactored(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unfactored:
 */
  __pyx_codeobj__1564 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_unfactored, 19203, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1564)) __PYX_ERR(2, 19203, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19218
 *         return GiacMethods['unfactored'](self,*args)
 * 
 *      def uniform(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform:
 */
  __pyx_codeobj__1565 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_uniform, 19218, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1565)) __PYX_ERR(2, 19218, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19232
 *         return GiacMethods['uniform'](self,*args)
 * 
 *      def uniform_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_cdf:
 */
  __pyx_codeobj__1566 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_uniform_cdf, 19232, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1566)) __PYX_ERR(2, 19232, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19244
 *         return GiacMethods['uniform_cdf'](self,*args)
 * 
 *      def uniform_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_icdf:
 */
  __pyx_codeobj__1567 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_uniform_icdf, 19244, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1567)) __PYX_ERR(2, 19244, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19256
 *         return GiacMethods['uniform_icdf'](self,*args)
 * 
 *      def uniformd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd:
 */
  __pyx_codeobj__1568 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_uniformd, 19256, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1568)) __PYX_ERR(2, 19256, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19270
 *         return GiacMethods['uniformd'](self,*args)
 * 
 *      def uniformd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_cdf:
 */
  __pyx_codeobj__1569 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_uniformd_cdf, 19270, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1569)) __PYX_ERR(2, 19270, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19282
 *         return GiacMethods['uniformd_cdf'](self,*args)
 * 
 *      def uniformd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_icdf:
 */
  __pyx_codeobj__1570 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_uniformd_icdf, 19282, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1570)) __PYX_ERR(2, 19282, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19294
 *         return GiacMethods['uniformd_icdf'](self,*args)
 * 
 *      def unitV(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unitV:
 */
  __pyx_codeobj__1571 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_unitV, 19294, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1571)) __PYX_ERR(2, 19294, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19308
 *         return GiacMethods['unitV'](self,*args)
 * 
 *      def unquote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unquote:
 */
  __pyx_codeobj__1572 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_unquote, 19308, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1572)) __PYX_ERR(2, 19308, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19319
 *         return GiacMethods['unquote'](self,*args)
 * 
 *      def upper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for upper:
 */
  __pyx_codeobj__1573 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_upper, 19319, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1573)) __PYX_ERR(2, 19319, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19331
 *         return GiacMethods['upper'](self,*args)
 * 
 *      def user_operator(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for user_operator:
 */
  __pyx_codeobj__1574 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_user_operator, 19331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1574)) __PYX_ERR(2, 19331, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19343
 *         return GiacMethods['user_operator'](self,*args)
 * 
 *      def usimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for usimplify:
 */
  __pyx_codeobj__1575 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_usimplify, 19343, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1575)) __PYX_ERR(2, 19343, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19354
 *         return GiacMethods['usimplify'](self,*args)
 * 
 *      def ustep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ustep:
 */
  __pyx_codeobj__1576 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ustep, 19354, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1576)) __PYX_ERR(2, 19354, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19363
 *         return GiacMethods['ustep'](self,*args)
 * 
 *      def valuation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for valuation:
 */
  __pyx_codeobj__1577 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_valuation, 19363, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1577)) __PYX_ERR(2, 19363, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19378
 *         return GiacMethods['valuation'](self,*args)
 * 
 *      def vandermonde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vandermonde:
 */
  __pyx_codeobj__1578 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vandermonde, 19378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1578)) __PYX_ERR(2, 19378, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19389
 *         return GiacMethods['vandermonde'](self,*args)
 * 
 *      def variables_are_files(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variables_are_files:
 */
  __pyx_codeobj__1579 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_variables_are_files, 19389, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1579)) __PYX_ERR(2, 19389, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19401
 *         return GiacMethods['variables_are_files'](self,*args)
 * 
 *      def variance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variance:
 */
  __pyx_codeobj__1580 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_variance, 19401, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1580)) __PYX_ERR(2, 19401, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19414
 *         return GiacMethods['variance'](self,*args)
 * 
 *      def version(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for version:
 */
  __pyx_codeobj__1581 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_version, 19414, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1581)) __PYX_ERR(2, 19414, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19425
 *         return GiacMethods['version'](self,*args)
 * 
 *      def vertex_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_connectivity:
 */
  __pyx_codeobj__1582 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertex_connectivity, 19425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1582)) __PYX_ERR(2, 19425, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19438
 *         return GiacMethods['vertex_connectivity'](self,*args)
 * 
 *      def vertex_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_cover_number:
 */
  __pyx_codeobj__1583 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertex_cover_number, 19438, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1583)) __PYX_ERR(2, 19438, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19449
 *         return GiacMethods['vertex_cover_number'](self,*args)
 * 
 *      def vertex_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_degree:
 */
  __pyx_codeobj__1584 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertex_degree, 19449, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1584)) __PYX_ERR(2, 19449, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19460
 *         return GiacMethods['vertex_degree'](self,*args)
 * 
 *      def vertex_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_distance:
 */
  __pyx_codeobj__1585 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertex_distance, 19460, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1585)) __PYX_ERR(2, 19460, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19472
 *         return GiacMethods['vertex_distance'](self,*args)
 * 
 *      def vertex_in_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_in_degree:
 */
  __pyx_codeobj__1586 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertex_in_degree, 19472, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1586)) __PYX_ERR(2, 19472, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19483
 *         return GiacMethods['vertex_in_degree'](self,*args)
 * 
 *      def vertex_out_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_out_degree:
 */
  __pyx_codeobj__1587 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertex_out_degree, 19483, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1587)) __PYX_ERR(2, 19483, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19494
 *         return GiacMethods['vertex_out_degree'](self,*args)
 * 
 *      def vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices:
 */
  __pyx_codeobj__1588 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertices, 19494, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1588)) __PYX_ERR(2, 19494, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19507
 *         return GiacMethods['vertices'](self,*args)
 * 
 *      def vertices_abc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abc:
 */
  __pyx_codeobj__1589 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertices_abc, 19507, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1589)) __PYX_ERR(2, 19507, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19520
 *         return GiacMethods['vertices_abc'](self,*args)
 * 
 *      def vertices_abca(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abca:
 */
  __pyx_codeobj__1590 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vertices_abca, 19520, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1590)) __PYX_ERR(2, 19520, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19533
 *         return GiacMethods['vertices_abca'](self,*args)
 * 
 *      def violet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for violet:
 */
  __pyx_codeobj__1591 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_violet, 19533, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1591)) __PYX_ERR(2, 19533, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19545
 *         return GiacMethods['violet'](self,*args)
 * 
 *      def vpotential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vpotential:
 */
  __pyx_codeobj__1592 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vpotential, 19545, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1592)) __PYX_ERR(2, 19545, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19556
 *         return GiacMethods['vpotential'](self,*args)
 * 
 *      def vstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vstep:
 */
  __pyx_codeobj__1593 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_vstep, 19556, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1593)) __PYX_ERR(2, 19556, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19565
 *         return GiacMethods['vstep'](self,*args)
 * 
 *      def web_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for web_graph:
 */
  __pyx_codeobj__1594 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_web_graph, 19565, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1594)) __PYX_ERR(2, 19565, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19576
 *         return GiacMethods['web_graph'](self,*args)
 * 
 *      def weibull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull:
 */
  __pyx_codeobj__1595 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibull, 19576, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1595)) __PYX_ERR(2, 19576, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19589
 *         return GiacMethods['weibull'](self,*args)
 * 
 *      def weibull_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_cdf:
 */
  __pyx_codeobj__1596 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibull_cdf, 19589, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1596)) __PYX_ERR(2, 19589, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19604
 *         return GiacMethods['weibull_cdf'](self,*args)
 * 
 *      def weibull_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_icdf:
 */
  __pyx_codeobj__1597 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibull_icdf, 19604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1597)) __PYX_ERR(2, 19604, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19616
 *         return GiacMethods['weibull_icdf'](self,*args)
 * 
 *      def weibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld:
 */
  __pyx_codeobj__1598 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibulld, 19616, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1598)) __PYX_ERR(2, 19616, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19629
 *         return GiacMethods['weibulld'](self,*args)
 * 
 *      def weibulld_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_cdf:
 */
  __pyx_codeobj__1599 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibulld_cdf, 19629, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1599)) __PYX_ERR(2, 19629, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19644
 *         return GiacMethods['weibulld_cdf'](self,*args)
 * 
 *      def weibulld_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_icdf:
 */
  __pyx_codeobj__1600 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibulld_icdf, 19644, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1600)) __PYX_ERR(2, 19644, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19656
 *         return GiacMethods['weibulld_icdf'](self,*args)
 * 
 *      def weibullvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibullvariate:
 */
  __pyx_codeobj__1601 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weibullvariate, 19656, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1601)) __PYX_ERR(2, 19656, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19668
 *         return GiacMethods['weibullvariate'](self,*args)
 * 
 *      def weight_decay(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_decay:
 */
  __pyx_codeobj__1602 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weight_decay, 19668, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1602)) __PYX_ERR(2, 19668, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19678
 *         return GiacMethods['weight_decay'](self,*args)
 * 
 *      def weight_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_matrix:
 */
  __pyx_codeobj__1603 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weight_matrix, 19678, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1603)) __PYX_ERR(2, 19678, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19689
 *         return GiacMethods['weight_matrix'](self,*args)
 * 
 *      def weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weighted:
 */
  __pyx_codeobj__1604 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weighted, 19689, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1604)) __PYX_ERR(2, 19689, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19699
 *         return GiacMethods['weighted'](self,*args)
 * 
 *      def weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weights:
 */
  __pyx_codeobj__1605 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_weights, 19699, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1605)) __PYX_ERR(2, 19699, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19709
 *         return GiacMethods['weights'](self,*args)
 * 
 *      def welch_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for welch_window:
 */
  __pyx_codeobj__1606 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_welch_window, 19709, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1606)) __PYX_ERR(2, 19709, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19720
 *         return GiacMethods['welch_window'](self,*args)
 * 
 *      def wheel_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wheel_graph:
 */
  __pyx_codeobj__1607 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_wheel_graph, 19720, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1607)) __PYX_ERR(2, 19720, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19731
 *         return GiacMethods['wheel_graph'](self,*args)
 * 
 *      def widget_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for widget_size:
 */
  __pyx_codeobj__1608 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_widget_size, 19731, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1608)) __PYX_ERR(2, 19731, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19744
 *         return GiacMethods['widget_size'](self,*args)
 * 
 *      def wilcoxonp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxonp:
 */
  __pyx_codeobj__1609 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_wilcoxonp, 19744, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1609)) __PYX_ERR(2, 19744, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19756
 *         return GiacMethods['wilcoxonp'](self,*args)
 * 
 *      def wilcoxons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxons:
 */
  __pyx_codeobj__1610 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_wilcoxons, 19756, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1610)) __PYX_ERR(2, 19756, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19768
 *         return GiacMethods['wilcoxons'](self,*args)
 * 
 *      def wilcoxont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxont:
 */
  __pyx_codeobj__1611 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_wilcoxont, 19768, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1611)) __PYX_ERR(2, 19768, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19782
 *         return GiacMethods['wilcoxont'](self,*args)
 * 
 *      def writergb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writergb:
 */
  __pyx_codeobj__1612 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_writergb, 19782, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1612)) __PYX_ERR(2, 19782, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19795
 *         return GiacMethods['writergb'](self,*args)
 * 
 *      def writewav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writewav:
 */
  __pyx_codeobj__1613 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_writewav, 19795, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1613)) __PYX_ERR(2, 19795, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19807
 *         return GiacMethods['writewav'](self,*args)
 * 
 *      def xcas_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xcas_mode:
 */
  __pyx_codeobj__1614 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_xcas_mode, 19807, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1614)) __PYX_ERR(2, 19807, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19819
 *         return GiacMethods['xcas_mode'](self,*args)
 * 
 *      def xml_print(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xml_print:
 */
  __pyx_codeobj__1615 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_xml_print, 19819, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1615)) __PYX_ERR(2, 19819, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19830
 *         return GiacMethods['xml_print'](self,*args)
 * 
 *      def xstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xstep:
 */
  __pyx_codeobj__1616 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_xstep, 19830, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1616)) __PYX_ERR(2, 19830, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19839
 *         return GiacMethods['xstep'](self,*args)
 * 
 *      def xyz2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyz2rgb:
 */
  __pyx_codeobj__1617 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_xyz2rgb, 19839, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1617)) __PYX_ERR(2, 19839, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19850
 *         return GiacMethods['xyz2rgb'](self,*args)
 * 
 *      def xyztrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyztrange:
 */
  __pyx_codeobj__1618 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_xyztrange, 19850, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1618)) __PYX_ERR(2, 19850, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19860
 *         return GiacMethods['xyztrange'](self,*args)
 * 
 *      def ystep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ystep:
 */
  __pyx_codeobj__1619 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ystep, 19860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1619)) __PYX_ERR(2, 19860, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19869
 *         return GiacMethods['ystep'](self,*args)
 * 
 *      def zeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zeros:
 */
  __pyx_codeobj__1620 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_zeros, 19869, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1620)) __PYX_ERR(2, 19869, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19883
 *         return GiacMethods['zeros'](self,*args)
 * 
 *      def znorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znorder:
 */
  __pyx_codeobj__1621 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_znorder, 19883, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1621)) __PYX_ERR(2, 19883, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19896
 *         return GiacMethods['znorder'](self,*args)
 * 
 *      def znprimroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znprimroot:
 */
  __pyx_codeobj__1622 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_znprimroot, 19896, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1622)) __PYX_ERR(2, 19896, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19907
 *         return GiacMethods['znprimroot'](self,*args)
 * 
 *      def zstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zstep:
 */
  __pyx_codeobj__1623 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_zstep, 19907, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1623)) __PYX_ERR(2, 19907, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19916
 *         return GiacMethods['zstep'](self,*args)
 * 
 *      def ztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ztrans:
 */
  __pyx_codeobj__1624 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_ztrans, 19916, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1624)) __PYX_ERR(2, 19916, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19928
 *         return GiacMethods['ztrans'](self,*args)
 * 
 *      def type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for type:
 */
  __pyx_codeobj__1625 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_type, 19928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1625)) __PYX_ERR(2, 19928, __pyx_L1_error)

  /* "giacpy/auto-methods.pxi":19940
 *         return GiacMethods['type'](self,*args)
 * 
 *      def zip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zip:
 */
  __pyx_codeobj__1626 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_auto_methods_pxi, __pyx_n_s_zip, 19940, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1626)) __PYX_ERR(2, 19940, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__1627 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__1627)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1627);
  __Pyx_GIVEREF(__pyx_tuple__1627);
  __pyx_codeobj__1628 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1627, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1628)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_GiacMethods_base__set_state(self, __pyx_state)
 */
  __pyx_codeobj__1629 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__22, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1629)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1101
 *            raise TypeError,"self is not a giac real"
 * 
 *      def eval(self):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         ressetctrl_c()
 */
  __pyx_tuple__1630 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_result); if (unlikely(!__pyx_tuple__1630)) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1630);
  __Pyx_GIVEREF(__pyx_tuple__1630);
  __pyx_codeobj__1631 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1630, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_eval, 1101, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1631)) __PYX_ERR(0, 1101, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1110
 *            raise RuntimeError
 * 
 *      def threadeval(self,*args):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         cdef gen * param
 */
  __pyx_tuple__1632 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_args, __pyx_n_s_result, __pyx_n_s_param, __pyx_n_s_count, __pyx_n_s_maxcount, __pyx_n_s_n, __pyx_n_s_right, __pyx_n_s_condi, __pyx_n_s_cont); if (unlikely(!__pyx_tuple__1632)) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1632);
  __Pyx_GIVEREF(__pyx_tuple__1632);
  __pyx_codeobj__1633 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1632, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_threadeval, 1110, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1633)) __PYX_ERR(0, 1110, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1446
 * 
 *      # To be able to use the eval function before the GiacMethods initialisation
 *      def cas_setup(self,*args):             # <<<<<<<<<<<<<<
 *         return Pygen('cas_setup')(self,*args)
 * 
 */
  __pyx_codeobj__1634 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_cas_setup, 1446, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1634)) __PYX_ERR(0, 1446, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1450
 * 
 *      # ipython pretty printing
 *      def _repr_latex_(self):             # <<<<<<<<<<<<<<
 *         # remove quotes
 *         #return str(self.latex())[1:-1]
 */
  __pyx_codeobj__1635 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_repr_latex, 1450, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1635)) __PYX_ERR(0, 1450, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1456
 *         return decstring23(GIAC_gen2tex(self.gptr[0], context_ptr).c_str()) #python3
 * 
 *      def _repr_html_(self):             # <<<<<<<<<<<<<<
 *         if self._type == 8:
 *            if self.sommet() == 'pnt':
 */
  __pyx_codeobj__1636 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_repr_html, 1456, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1636)) __PYX_ERR(0, 1456, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1469
 * 
 *      #
 *      def save(self, str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Archive a Pygen element to a file in giac compressed format.
 */
  __pyx_tuple__1637 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_filename); if (unlikely(!__pyx_tuple__1637)) __PYX_ERR(0, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1637);
  __Pyx_GIVEREF(__pyx_tuple__1637);
  __pyx_codeobj__1638 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1637, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_save, 1469, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1638)) __PYX_ERR(0, 1469, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1498
 * 
 * 
 *      def htmlhelp(self, str lang='en'):             # <<<<<<<<<<<<<<
 *          """
 *          Open the giac  html  detailled help about self in an external  browser
 */
  __pyx_tuple__1639 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_lang, __pyx_n_s_l, __pyx_n_s_url, __pyx_n_s_giacbasedir); if (unlikely(!__pyx_tuple__1639)) __PYX_ERR(0, 1498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1639);
  __Pyx_GIVEREF(__pyx_tuple__1639);
  __pyx_codeobj__1640 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1639, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_htmlhelp, 1498, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1640)) __PYX_ERR(0, 1498, __pyx_L1_error)
  __pyx_tuple__1641 = PyTuple_Pack(1, __pyx_n_s_en); if (unlikely(!__pyx_tuple__1641)) __PYX_ERR(0, 1498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1641);
  __Pyx_GIVEREF(__pyx_tuple__1641);

  /* "giacpy/giacpy.pyx":1523
 * 
 * 
 *      def help(self):             # <<<<<<<<<<<<<<
 *         return self.findhelp()
 * 
 */
  __pyx_codeobj__1642 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_help, 1523, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1642)) __PYX_ERR(0, 1523, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1526
 *         return self.findhelp()
 * 
 *      def redim(self,a,b=None):             # <<<<<<<<<<<<<<
 *         """
 *         * Increase the size of a matrix when possible, otherwise return self.
 */
  __pyx_tuple__1643 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_a, __pyx_n_s_b, __pyx_n_s_d, __pyx_n_s_A); if (unlikely(!__pyx_tuple__1643)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1643);
  __Pyx_GIVEREF(__pyx_tuple__1643);
  __pyx_codeobj__1644 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1643, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_redim, 1526, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1644)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __pyx_tuple__1645 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__1645)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1645);
  __Pyx_GIVEREF(__pyx_tuple__1645);

  /* "giacpy/giacpy.pyx":1552
 * 
 * 
 *      def qcas(self,s=None):             # <<<<<<<<<<<<<<
 *        """
 *        * Send a giac graphic to qcas. (3D is currently not supported in qcas)
 */
  __pyx_tuple__1646 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_s, __pyx_n_s_toqcas); if (unlikely(!__pyx_tuple__1646)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1646);
  __Pyx_GIVEREF(__pyx_tuple__1646);
  __pyx_codeobj__1647 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1646, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_qcas, 1552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1647)) __PYX_ERR(0, 1552, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__1648 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1648)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__1649 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__22, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1649)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1846
 * #############################################
 * 
 * I=Pygen('i')  # The complex number sqrt(-1)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__1650 = PyTuple_Pack(1, __pyx_n_s_i); if (unlikely(!__pyx_tuple__1650)) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1650);
  __Pyx_GIVEREF(__pyx_tuple__1650);

  /* "giacpy/giacpy.pyx":1849
 * 
 * 
 * def htmlhelp(s='en'):             # <<<<<<<<<<<<<<
 *    """
 *    Open the giac html detailled help in an external  browser
 */
  __pyx_tuple__1651 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_giacbasedir, __pyx_n_s_url); if (unlikely(!__pyx_tuple__1651)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1651);
  __Pyx_GIVEREF(__pyx_tuple__1651);
  __pyx_codeobj__1652 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1651, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_htmlhelp, 1849, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1652)) __PYX_ERR(0, 1849, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1879
 * #  Qcas string interactive 2D geometry; string input
 * #############################################################
 * def qcas(str s):             # <<<<<<<<<<<<<<
 *    """
 *    * EXPERIMENTAL: Send a giac command to an  interactive 2D geometry display in qcas.
 */
  __pyx_tuple__1653 = PyTuple_Pack(3, __pyx_n_s_s, __pyx_n_s_oldies, __pyx_n_s_toqcas); if (unlikely(!__pyx_tuple__1653)) __PYX_ERR(0, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1653);
  __Pyx_GIVEREF(__pyx_tuple__1653);
  __pyx_codeobj__1654 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1653, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_qcas, 1879, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1654)) __PYX_ERR(0, 1879, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1927
 *    This class is used by GiacFunction
 *    """
 *    def __call__(self, *args):             # <<<<<<<<<<<<<<
 *       return self.threadeval(*args)
 * 
 */
  __pyx_codeobj__1701 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_call, 1927, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1701)) __PYX_ERR(0, 1927, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1934
 *    # docstring removed to show  self.__doc__  under IEP.
 * 
 *    def __init__(self,str s):             # <<<<<<<<<<<<<<
 * 
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']
 */
  __pyx_tuple__1702 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_s, __pyx_n_s_directevalued); if (unlikely(!__pyx_tuple__1702)) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1702);
  __Pyx_GIVEREF(__pyx_tuple__1702);
  __pyx_codeobj__1703 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1702, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_init, 1934, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1703)) __PYX_ERR(0, 1934, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1949
 * 
 * 
 *    def __call__(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen(*args)
 * 
 */
  __pyx_codeobj__1704 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_call, 1949, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1704)) __PYX_ERR(0, 1949, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1953
 * 
 * 
 *    def __repr__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__repr__()
 * 
 */
  __pyx_codeobj__1705 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_repr, 1953, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1705)) __PYX_ERR(0, 1953, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1957
 * 
 * 
 *    def __str__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__str__()
 * 
 */
  __pyx_codeobj__1706 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_str_2, 1957, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1706)) __PYX_ERR(0, 1957, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1961
 * 
 * 
 *    def __add__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_tuple__1707 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_right); if (unlikely(!__pyx_tuple__1707)) __PYX_ERR(0, 1961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1707);
  __Pyx_GIVEREF(__pyx_tuple__1707);
  __pyx_codeobj__1708 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1707, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_add_2, 1961, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1708)) __PYX_ERR(0, 1961, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1969
 * 
 * 
 *    def __sub__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_codeobj__1709 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1707, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_sub, 1969, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1709)) __PYX_ERR(0, 1969, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1977
 * 
 * 
 *    def __mul__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_codeobj__1710 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1707, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_mul_2, 1977, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1710)) __PYX_ERR(0, 1977, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1985
 * 
 * 
 *    def __div__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_codeobj__1711 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1707, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_div_2, 1985, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1711)) __PYX_ERR(0, 1985, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":1993
 * 
 * 
 *    def __truediv__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_codeobj__1712 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1707, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_truediv, 1993, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1712)) __PYX_ERR(0, 1993, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2001
 * 
 * 
 *    def __pow__(self,right,ignored):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_tuple__1713 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_right, __pyx_n_s_ignored); if (unlikely(!__pyx_tuple__1713)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1713);
  __Pyx_GIVEREF(__pyx_tuple__1713);
  __pyx_codeobj__1714 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1713, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_pow_2, 2001, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1714)) __PYX_ERR(0, 2001, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2009
 * 
 * 
 *    def __neg__(self):             # <<<<<<<<<<<<<<
 *       return -self.Pygen
 * 
 */
  __pyx_codeobj__1715 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__20, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_neg, 2009, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1715)) __PYX_ERR(0, 2009, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2013
 * 
 * 
 *    def diff(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.diff(args)
 * 
 */
  __pyx_codeobj__1716 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_diff, 2013, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1716)) __PYX_ERR(0, 2013, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2017
 * 
 * 
 *    def int(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.int(args)
 * 
 */
  __pyx_codeobj__1717 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_int, 2017, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1717)) __PYX_ERR(0, 2017, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2021
 * 
 * 
 *    def plot(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.plot(args)
 * 
 */
  __pyx_codeobj__1718 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_plot, 2021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1718)) __PYX_ERR(0, 2021, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2025
 * 
 * 
 *    def htmlhelp(self,str lang='en'):             # <<<<<<<<<<<<<<
 *       return self.Pygen.htmlhelp(lang)
 * 
 */
  __pyx_tuple__1719 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_lang); if (unlikely(!__pyx_tuple__1719)) __PYX_ERR(0, 2025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1719);
  __Pyx_GIVEREF(__pyx_tuple__1719);
  __pyx_codeobj__1720 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1719, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_htmlhelp, 2025, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1720)) __PYX_ERR(0, 2025, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2034
 * # Some convenient settings
 * #############################################################
 * Pygen('printpow(-1)').eval() ; # default power is ** instead of ^             # <<<<<<<<<<<<<<
 * Pygen('add_language(1)').eval() ; # Add the french keywords in the giac library language.
 * # FIXME: print I for sqrt(-1) instead of i
 */
  __pyx_tuple__1721 = PyTuple_Pack(1, __pyx_kp_s_printpow_1); if (unlikely(!__pyx_tuple__1721)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1721);
  __Pyx_GIVEREF(__pyx_tuple__1721);

  /* "giacpy/giacpy.pyx":2035
 * #############################################################
 * Pygen('printpow(-1)').eval() ; # default power is ** instead of ^
 * Pygen('add_language(1)').eval() ; # Add the french keywords in the giac library language.             # <<<<<<<<<<<<<<
 * # FIXME: print I for sqrt(-1) instead of i
 * #GIAC_try_parse_i(False,context_ptr);
 */
  __pyx_tuple__1722 = PyTuple_Pack(1, __pyx_kp_s_add_language_1); if (unlikely(!__pyx_tuple__1722)) __PYX_ERR(0, 2035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1722);
  __Pyx_GIVEREF(__pyx_tuple__1722);

  /* "giacpy/giacpy.pyx":2061
 *    GiacMethods[i]=tmp
 * ##
 * def moretests():             # <<<<<<<<<<<<<<
 *    """
 *      >>> from giacpy import giac
 */
  __pyx_codeobj__1723 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_moretests, 2061, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1723)) __PYX_ERR(0, 2061, __pyx_L1_error)

  /* "giacpy/giacpy.pyx":2106
 * 
 * 
 * def loadgiacgen(str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Open a file in giac compressed format to create a Pygen element.
 */
  __pyx_tuple__1724 = PyTuple_Pack(2, __pyx_n_s_filename, __pyx_n_s_result); if (unlikely(!__pyx_tuple__1724)) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1724);
  __Pyx_GIVEREF(__pyx_tuple__1724);
  __pyx_codeobj__1725 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1724, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_giacpy_giacpy_pyx, __pyx_n_s_loadgiacgen, 2106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1725)) __PYX_ERR(0, 2106, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_GiacMethods_base(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__1726 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__1726)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__1726);
  __Pyx_GIVEREF(__pyx_tuple__1726);
  __pyx_codeobj__1727 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__1726, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_GiacMethods_base, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__1727)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PySlice_Type_indices.type = (PyObject*)&PySlice_Type;
  __pyx_umethod_PySlice_Type_indices.method_name = &__pyx_n_s_indices;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_float_0_05 = PyFloat_FromDouble(0.05); if (unlikely(!__pyx_float_0_05)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_001 = PyFloat_FromDouble(0.001); if (unlikely(!__pyx_float_0_001)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_14 = PyInt_FromLong(14); if (unlikely(!__pyx_int_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000000 = PyInt_FromLong(1000000L); if (unlikely(!__pyx_int_1000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_228825662 = PyInt_FromLong(228825662L); if (unlikely(!__pyx_int_228825662)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_238750788 = PyInt_FromLong(238750788L); if (unlikely(!__pyx_int_238750788)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s_context_ptr, (void *)&__pyx_v_6giacpy_6giacpy_context_ptr, "giac::context *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6giacpy_6giacpy_GiacMethods_base = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6giacpy_6giacpy_GiacMethods_base_spec, NULL); if (unlikely(!__pyx_ptype_6giacpy_6giacpy_GiacMethods_base)) __PYX_ERR(2, 2, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6giacpy_6giacpy_GiacMethods_base_spec, __pyx_ptype_6giacpy_6giacpy_GiacMethods_base) < 0) __PYX_ERR(2, 2, __pyx_L1_error)
  #else
  __pyx_ptype_6giacpy_6giacpy_GiacMethods_base = &__pyx_type_6giacpy_6giacpy_GiacMethods_base;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base) < 0) __PYX_ERR(2, 2, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_dictoffset && __pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6giacpy_6giacpy_GiacMethods_base->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_GiacMethods_base, (PyObject *) __pyx_ptype_6giacpy_6giacpy_GiacMethods_base) < 0) __PYX_ERR(2, 2, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6giacpy_6giacpy_GiacMethods_base) < 0) __PYX_ERR(2, 2, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6giacpy_6giacpy_Pygen = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6giacpy_6giacpy_Pygen_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6giacpy_6giacpy_Pygen)) __PYX_ERR(0, 788, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6giacpy_6giacpy_Pygen_spec, __pyx_ptype_6giacpy_6giacpy_Pygen) < 0) __PYX_ERR(0, 788, __pyx_L1_error)
  #else
  __pyx_ptype_6giacpy_6giacpy_Pygen = &__pyx_type_6giacpy_6giacpy_Pygen;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6giacpy_6giacpy_Pygen->tp_base = __pyx_ptype_6giacpy_6giacpy_GiacMethods_base;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6giacpy_6giacpy_Pygen) < 0) __PYX_ERR(0, 788, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6giacpy_6giacpy_Pygen->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6giacpy_6giacpy_Pygen->tp_dictoffset && __pyx_ptype_6giacpy_6giacpy_Pygen->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6giacpy_6giacpy_Pygen->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__repr__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_4__repr__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_4__repr__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_4__repr__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_4__repr__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__getitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_10__getitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_10__getitem__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_10__getitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_10__getitem__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__setitem__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_12__setitem__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_12__setitem__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_12__setitem__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_12__setitem__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__iter__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_14__iter__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_14__iter__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_14__iter__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_14__iter__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__int__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_17__int__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_17__int__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_17__int__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_17__int__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__float__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_19__float__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_19__float__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_19__float__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_19__float__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__radd__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_27__radd__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_27__radd__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_27__radd__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_27__radd__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__rsub__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_33__rsub__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_33__rsub__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_33__rsub__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_33__rsub__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__rmul__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_37__rmul__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_37__rmul__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_37__rmul__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_37__rmul__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__rtruediv__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_43__rtruediv__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_43__rtruediv__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_43__rtruediv__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_43__rtruediv__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__rpow__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_47__rpow__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_47__rpow__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_47__rpow__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_47__rpow__;
    }
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, "__rmod__"); if (unlikely(!wrapper)) __PYX_ERR(0, 788, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_51__rmod__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6giacpy_6giacpy_5Pygen_51__rmod__.doc = __pyx_doc_6giacpy_6giacpy_5Pygen_51__rmod__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6giacpy_6giacpy_5Pygen_51__rmod__;
    }
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Pygen, (PyObject *) __pyx_ptype_6giacpy_6giacpy_Pygen) < 0) __PYX_ERR(0, 788, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6giacpy_6giacpy_Pygen) < 0) __PYX_ERR(0, 788, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6giacpy_6giacpy_GiacSetting = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6giacpy_6giacpy_GiacSetting_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6giacpy_6giacpy_GiacSetting)) __PYX_ERR(0, 508, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6giacpy_6giacpy_GiacSetting_spec, __pyx_ptype_6giacpy_6giacpy_GiacSetting) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  #else
  __pyx_ptype_6giacpy_6giacpy_GiacSetting = &__pyx_type_6giacpy_6giacpy_GiacSetting;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6giacpy_6giacpy_GiacSetting->tp_base = __pyx_ptype_6giacpy_6giacpy_Pygen;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6giacpy_6giacpy_GiacSetting) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6giacpy_6giacpy_GiacSetting->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6giacpy_6giacpy_GiacSetting->tp_dictoffset && __pyx_ptype_6giacpy_6giacpy_GiacSetting->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6giacpy_6giacpy_GiacSetting->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_GiacSetting, (PyObject *) __pyx_ptype_6giacpy_6giacpy_GiacSetting) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6giacpy_6giacpy_GiacSetting) < 0) __PYX_ERR(0, 508, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter___spec, NULL); if (unlikely(!__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__)) __PYX_ERR(0, 1035, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter___spec, __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__) < 0) __PYX_ERR(0, 1035, __pyx_L1_error)
  #else
  __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__ = &__pyx_type_6giacpy_6giacpy___pyx_scope_struct____iter__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__) < 0) __PYX_ERR(0, 1035, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__->tp_dictoffset && __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6giacpy_6giacpy___pyx_scope_struct____iter__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_0_11(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_giacpy(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_giacpy},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "giacpy",
      __pyx_k_giacpy_Interface_to_the_C_libra, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initgiacpy(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initgiacpy(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_giacpy(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_giacpy(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_giacpy(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  unsigned int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'giacpy' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("giacpy", __pyx_methods, __pyx_k_giacpy_Interface_to_the_C_libra, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "giacpy" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_giacpy(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_giacpy__giacpy) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "giacpy.giacpy")) {
      if (unlikely((PyDict_SetItemString(modules, "giacpy.giacpy", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  if (unlikely((__Pyx_modinit_variable_export_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "giacpy/giacpy.pyx":97
 * cimport giacpy
 * 
 * from webbrowser import open as wwwbrowseropen             # <<<<<<<<<<<<<<
 * from sys import maxsize as Pymaxint
 * import os
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_open);
  __Pyx_GIVEREF(__pyx_n_s_open);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_open)) __PYX_ERR(0, 97, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_webbrowser, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_open); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wwwbrowseropen, __pyx_t_2) < 0) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "giacpy/giacpy.pyx":98
 * 
 * from webbrowser import open as wwwbrowseropen
 * from sys import maxsize as Pymaxint             # <<<<<<<<<<<<<<
 * import os
 * import math
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_maxsize);
  __Pyx_GIVEREF(__pyx_n_s_maxsize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_maxsize)) __PYX_ERR(0, 98, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_sys, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_maxsize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Pymaxint, __pyx_t_3) < 0) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":99
 * from webbrowser import open as wwwbrowseropen
 * from sys import maxsize as Pymaxint
 * import os             # <<<<<<<<<<<<<<
 * import math
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_os, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_2) < 0) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":100
 * from sys import maxsize as Pymaxint
 * import os
 * import math             # <<<<<<<<<<<<<<
 * 
 * from time import sleep
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_math, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_math, __pyx_t_2) < 0) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":102
 * import math
 * 
 * from time import sleep             # <<<<<<<<<<<<<<
 * from cpython.exc cimport PyErr_CheckSignals
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_sleep);
  __Pyx_GIVEREF(__pyx_n_s_sleep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_sleep)) __PYX_ERR(0, 102, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_time, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_sleep); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sleep, __pyx_t_2) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "giacpy/giacpy.pyx":106
 * 
 * #### Python3 compatibility  #############################
 * from sys import version_info as Pyversioninfo             # <<<<<<<<<<<<<<
 * if Pyversioninfo[0]>2 :
 *    PythonVersion3 = True
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_version_info);
  __Pyx_GIVEREF(__pyx_n_s_version_info);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_version_info)) __PYX_ERR(0, 106, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_sys, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_version_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Pyversioninfo, __pyx_t_3) < 0) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":107
 * #### Python3 compatibility  #############################
 * from sys import version_info as Pyversioninfo
 * if Pyversioninfo[0]>2 :             # <<<<<<<<<<<<<<
 *    PythonVersion3 = True
 * else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Pyversioninfo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_int_2, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "giacpy/giacpy.pyx":108
 * from sys import version_info as Pyversioninfo
 * if Pyversioninfo[0]>2 :
 *    PythonVersion3 = True             # <<<<<<<<<<<<<<
 * else:
 *    PythonVersion3 = False
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_PythonVersion3, Py_True) < 0) __PYX_ERR(0, 108, __pyx_L1_error)

    /* "giacpy/giacpy.pyx":107
 * #### Python3 compatibility  #############################
 * from sys import version_info as Pyversioninfo
 * if Pyversioninfo[0]>2 :             # <<<<<<<<<<<<<<
 *    PythonVersion3 = True
 * else:
 */
    goto __pyx_L2;
  }

  /* "giacpy/giacpy.pyx":110
 *    PythonVersion3 = True
 * else:
 *    PythonVersion3 = False             # <<<<<<<<<<<<<<
 * 
 * def decstring23(s):
 */
  /*else*/ {
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_PythonVersion3, Py_False) < 0) __PYX_ERR(0, 110, __pyx_L1_error)
  }
  __pyx_L2:;

  /* "giacpy/giacpy.pyx":112
 *    PythonVersion3 = False
 * 
 * def decstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return s.decode()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_1decstring23, 0, __pyx_n_s_decstring23, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_decstring23, __pyx_t_2) < 0) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":119
 * 
 * 
 * def encstring23(s):             # <<<<<<<<<<<<<<
 *   if PythonVersion3 :
 *       return bytes(s,'UTF-8')
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_3encstring23, 0, __pyx_n_s_encstring23, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__17)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_encstring23, __pyx_t_2) < 0) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":126
 * 
 * 
 * if PythonVersion3:             # <<<<<<<<<<<<<<
 *     listrange=list,range
 * else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_PythonVersion3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "giacpy/giacpy.pyx":127
 * 
 * if PythonVersion3:
 *     listrange=list,range             # <<<<<<<<<<<<<<
 * else:
 *     listrange=list
 */
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF((PyObject *)(&PyList_Type));
    __Pyx_GIVEREF((PyObject *)(&PyList_Type));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)(&PyList_Type)))) __PYX_ERR(0, 127, __pyx_L1_error);
    __Pyx_INCREF(__pyx_builtin_range);
    __Pyx_GIVEREF(__pyx_builtin_range);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_builtin_range)) __PYX_ERR(0, 127, __pyx_L1_error);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_listrange, __pyx_t_2) < 0) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":126
 * 
 * 
 * if PythonVersion3:             # <<<<<<<<<<<<<<
 *     listrange=list,range
 * else:
 */
    goto __pyx_L3;
  }

  /* "giacpy/giacpy.pyx":129
 *     listrange=list,range
 * else:
 *     listrange=list             # <<<<<<<<<<<<<<
 * 
 * ####End of Python3 compatibility########################
 */
  /*else*/ {
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_listrange, ((PyObject *)(&PyList_Type))) < 0) __PYX_ERR(0, 129, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "giacpy/interrupt.pxi":17
 * 
 * 
 * signal(SIGINT,GIAC_ctrl_c_signal_handler)             # <<<<<<<<<<<<<<
 * 
 * ressetctrl_c() #NB: I failed to do this with a cython variable. How to improve?
 */
  (void)(signal(SIGINT, giac::ctrl_c_signal_handler));

  /* "giacpy/interrupt.pxi":19
 * signal(SIGINT,GIAC_ctrl_c_signal_handler)
 * 
 * ressetctrl_c() #NB: I failed to do this with a cython variable. How to improve?             # <<<<<<<<<<<<<<
 * 
 * ###########################################################################
 */
  try {
    ressetctrl_c();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(4, 19, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":144
 * # A global context pointer. One by giac session.
 * ########################################################
 * context_ptr=new context()             # <<<<<<<<<<<<<<
 * #
 * # Some global variables for optimisation
 */
  __pyx_v_6giacpy_6giacpy_context_ptr = new giac::context();

  /* "giacpy/giacpy.pyx":147
 * #
 * # Some global variables for optimisation
 * GIACNULL=Pygen('NULL')             # <<<<<<<<<<<<<<
 * #
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GIACNULL, __pyx_t_2) < 0) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":153
 * 
 * # Create a giac setting instance
 * giacsettings=GiacSetting()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacSetting)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_giacsettings, __pyx_t_2) < 0) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":157
 * 
 * # remove lock to enable write access from giac
 * unsetsecure_run()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  try {
    unsetsecure_run();
  } catch(...) {
    __Pyx_CppExn2PyErr();
    __PYX_ERR(0, 157, __pyx_L1_error)
  }

  /* "giacpy/giacpy.pyx":163
 * # The wrapper to eval with giac
 * #######################################################
 * def giac(s):             # <<<<<<<<<<<<<<
 *   """
 *     This function evaluate a python object with the giac library.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5giac, 0, __pyx_n_s_giac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__19)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_giac, __pyx_t_2) < 0) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_11GiacSetting_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacSetting___reduce_cython, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__21)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_11GiacSetting_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacSetting___setstate_cython, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__23)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/auto-methods.pxi":12
 *      """
 * 
 *      def Airy_Ai(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Ai:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1Airy_Ai, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Airy_Ai, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__25)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Airy_Ai, __pyx_t_2) < 0) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":24
 *         return GiacMethods['Airy_Ai'](self,*args)
 * 
 *      def Airy_Bi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Airy_Bi:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3Airy_Bi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Airy_Bi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__26)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Airy_Bi, __pyx_t_2) < 0) __PYX_ERR(2, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":36
 *         return GiacMethods['Airy_Bi'](self,*args)
 * 
 *      def Archive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Archive:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_5Archive, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Archive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__27)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Archive, __pyx_t_2) < 0) __PYX_ERR(2, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":47
 *         return GiacMethods['Archive'](self,*args)
 * 
 *      def BesselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselJ:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_7BesselJ, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_BesselJ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_BesselJ, __pyx_t_2) < 0) __PYX_ERR(2, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":59
 *         return GiacMethods['BesselJ'](self,*args)
 * 
 *      def BesselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BesselY:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_9BesselY, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_BesselY, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__29)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_BesselY, __pyx_t_2) < 0) __PYX_ERR(2, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":71
 *         return GiacMethods['BesselY'](self,*args)
 * 
 *      def Beta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Beta:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_11Beta, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Beta, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__30)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Beta, __pyx_t_2) < 0) __PYX_ERR(2, 71, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":85
 *         return GiacMethods['Beta'](self,*args)
 * 
 *      def BlockDiagonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for BlockDiagonal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_13BlockDiagonal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_BlockDiagonal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__31)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_BlockDiagonal, __pyx_t_2) < 0) __PYX_ERR(2, 85, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":97
 *         return GiacMethods['BlockDiagonal'](self,*args)
 * 
 *      def Ci(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ci:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_15Ci, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Ci, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__32)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Ci, __pyx_t_2) < 0) __PYX_ERR(2, 97, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":108
 *         return GiacMethods['Ci'](self,*args)
 * 
 *      def Circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Circle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_17Circle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Circle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__33)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Circle, __pyx_t_2) < 0) __PYX_ERR(2, 108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":121
 *         return GiacMethods['Circle'](self,*args)
 * 
 *      def Col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Col:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_19Col, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Col, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__34)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Col, __pyx_t_2) < 0) __PYX_ERR(2, 121, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":132
 *         return GiacMethods['Col'](self,*args)
 * 
 *      def CopyVar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for CopyVar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_21CopyVar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_CopyVar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__35)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_CopyVar, __pyx_t_2) < 0) __PYX_ERR(2, 132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":143
 *         return GiacMethods['CopyVar'](self,*args)
 * 
 *      def Dirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Dirac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_23Dirac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Dirac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__36)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Dirac, __pyx_t_2) < 0) __PYX_ERR(2, 143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":156
 *         return GiacMethods['Dirac'](self,*args)
 * 
 *      def Ei(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Ei:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_25Ei, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Ei, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__37)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Ei, __pyx_t_2) < 0) __PYX_ERR(2, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":167
 *         return GiacMethods['Ei'](self,*args)
 * 
 *      def Factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Factor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_27Factor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Factor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__38)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Factor, __pyx_t_2) < 0) __PYX_ERR(2, 167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":179
 *         return GiacMethods['Factor'](self,*args)
 * 
 *      def Fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Fourier:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_29Fourier, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Fourier, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Fourier, __pyx_t_2) < 0) __PYX_ERR(2, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":190
 *         return GiacMethods['Fourier'](self,*args)
 * 
 *      def GF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for GF:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_31GF, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_GF, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__40)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_GF, __pyx_t_2) < 0) __PYX_ERR(2, 190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":205
 *         return GiacMethods['GF'](self,*args)
 * 
 *      def Gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Gamma:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_33Gamma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Gamma, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Gamma, __pyx_t_2) < 0) __PYX_ERR(2, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":219
 *         return GiacMethods['Gamma'](self,*args)
 * 
 *      def Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_35Heaviside, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Heaviside, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__42)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Heaviside, __pyx_t_2) < 0) __PYX_ERR(2, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":232
 *         return GiacMethods['Heaviside'](self,*args)
 * 
 *      def Heaviside2sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Heaviside2sign:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_37Heaviside2sign, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Heaviside2sign, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Heaviside2sign, __pyx_t_2) < 0) __PYX_ERR(2, 232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":243
 *         return GiacMethods['Heaviside2sign'](self,*args)
 * 
 *      def Hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Hilbert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_39Hilbert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Hilbert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__44)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Hilbert, __pyx_t_2) < 0) __PYX_ERR(2, 243, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":254
 *         return GiacMethods['Hilbert'](self,*args)
 * 
 *      def JordanBlock(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for JordanBlock:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_41JordanBlock, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_JordanBlock, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__45)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_JordanBlock, __pyx_t_2) < 0) __PYX_ERR(2, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":265
 *         return GiacMethods['JordanBlock'](self,*args)
 * 
 *      def LU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LU:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_43LU, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_LU, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__46)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_LU, __pyx_t_2) < 0) __PYX_ERR(2, 265, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":277
 *         return GiacMethods['LU'](self,*args)
 * 
 *      def LambertW(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LambertW:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_45LambertW, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_LambertW, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_LambertW, __pyx_t_2) < 0) __PYX_ERR(2, 277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":289
 *         return GiacMethods['LambertW'](self,*args)
 * 
 *      def Li(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Li:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_47Li, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Li, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__48)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Li, __pyx_t_2) < 0) __PYX_ERR(2, 289, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":300
 *         return GiacMethods['Li'](self,*args)
 * 
 *      def Line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_49Line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Line, __pyx_t_2) < 0) __PYX_ERR(2, 300, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":311
 *         return GiacMethods['Line'](self,*args)
 * 
 *      def LineHorz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineHorz:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_51LineHorz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_LineHorz, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__50)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_LineHorz, __pyx_t_2) < 0) __PYX_ERR(2, 311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":322
 *         return GiacMethods['LineHorz'](self,*args)
 * 
 *      def LineTan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineTan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_53LineTan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_LineTan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_LineTan, __pyx_t_2) < 0) __PYX_ERR(2, 322, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":337
 *         return GiacMethods['LineTan'](self,*args)
 * 
 *      def LineVert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for LineVert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_55LineVert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_LineVert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__52)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_LineVert, __pyx_t_2) < 0) __PYX_ERR(2, 337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":348
 *         return GiacMethods['LineVert'](self,*args)
 * 
 *      def MSE(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for MSE:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_57MSE, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_MSE, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__53)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_MSE, __pyx_t_2) < 0) __PYX_ERR(2, 348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":358
 *         return GiacMethods['MSE'](self,*args)
 * 
 *      def Phi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Phi:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_59Phi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Phi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__54)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Phi, __pyx_t_2) < 0) __PYX_ERR(2, 358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":370
 *         return GiacMethods['Phi'](self,*args)
 * 
 *      def Pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Pi:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_61Pi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Pi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Pi, __pyx_t_2) < 0) __PYX_ERR(2, 370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":384
 *         return GiacMethods['Pi'](self,*args)
 * 
 *      def Psi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Psi:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_63Psi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Psi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__56)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Psi, __pyx_t_2) < 0) __PYX_ERR(2, 384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":395
 *         return GiacMethods['Psi'](self,*args)
 * 
 *      def QR(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for QR:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_65QR, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_QR, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_QR, __pyx_t_2) < 0) __PYX_ERR(2, 395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":406
 *         return GiacMethods['QR'](self,*args)
 * 
 *      def RandSeed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for RandSeed:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_67RandSeed, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_RandSeed, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__58)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_RandSeed, __pyx_t_2) < 0) __PYX_ERR(2, 406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":417
 *         return GiacMethods['RandSeed'](self,*args)
 * 
 *      def ReLU(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ReLU:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_69ReLU, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ReLU, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ReLU, __pyx_t_2) < 0) __PYX_ERR(2, 417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":427
 *         return GiacMethods['ReLU'](self,*args)
 * 
 *      def Row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Row:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_71Row, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Row, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__60)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Row, __pyx_t_2) < 0) __PYX_ERR(2, 427, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":438
 *         return GiacMethods['Row'](self,*args)
 * 
 *      def SortA(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortA:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_73SortA, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_SortA, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__61)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_SortA, __pyx_t_2) < 0) __PYX_ERR(2, 438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":452
 *         return GiacMethods['SortA'](self,*args)
 * 
 *      def SortD(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for SortD:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_75SortD, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_SortD, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__62)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_SortD, __pyx_t_2) < 0) __PYX_ERR(2, 452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":466
 *         return GiacMethods['SortD'](self,*args)
 * 
 *      def UTPC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPC:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_77UTPC, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_UTPC, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_UTPC, __pyx_t_2) < 0) __PYX_ERR(2, 466, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":478
 *         return GiacMethods['UTPC'](self,*args)
 * 
 *      def UTPF(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPF:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_79UTPF, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_UTPF, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__64)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_UTPF, __pyx_t_2) < 0) __PYX_ERR(2, 478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":490
 *         return GiacMethods['UTPF'](self,*args)
 * 
 *      def UTPN(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPN:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_81UTPN, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_UTPN, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_UTPN, __pyx_t_2) < 0) __PYX_ERR(2, 490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":502
 *         return GiacMethods['UTPN'](self,*args)
 * 
 *      def UTPT(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for UTPT:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_83UTPT, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_UTPT, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__66)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_UTPT, __pyx_t_2) < 0) __PYX_ERR(2, 502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":514
 *         return GiacMethods['UTPT'](self,*args)
 * 
 *      def VARS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VARS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_85VARS, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_VARS, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__67)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_VARS, __pyx_t_2) < 0) __PYX_ERR(2, 514, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":525
 *         return GiacMethods['VARS'](self,*args)
 * 
 *      def VAS(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_87VAS, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_VAS, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_VAS, __pyx_t_2) < 0) __PYX_ERR(2, 525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":536
 *         return GiacMethods['VAS'](self,*args)
 * 
 *      def VAS_positive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for VAS_positive:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_89VAS_positive, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_VAS_positive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__69)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_VAS_positive, __pyx_t_2) < 0) __PYX_ERR(2, 536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":547
 *         return GiacMethods['VAS_positive'](self,*args)
 * 
 *      def Zeta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for Zeta:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_91Zeta, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_Zeta, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_Zeta, __pyx_t_2) < 0) __PYX_ERR(2, 547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":558
 *         return GiacMethods['Zeta'](self,*args)
 * 
 *      def a2q(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for a2q:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_93a2q, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_a2q, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__71)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_a2q, __pyx_t_2) < 0) __PYX_ERR(2, 558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":570
 *         return GiacMethods['a2q'](self,*args)
 * 
 *      def abcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abcuv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_95abcuv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_abcuv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_abcuv, __pyx_t_2) < 0) __PYX_ERR(2, 570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":585
 *         return GiacMethods['abcuv'](self,*args)
 * 
 *      def about(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for about:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_97about, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_about, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__73)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_about, __pyx_t_2) < 0) __PYX_ERR(2, 585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":597
 *         return GiacMethods['about'](self,*args)
 * 
 *      def abs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_99abs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_abs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__74)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_abs, __pyx_t_2) < 0) __PYX_ERR(2, 597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":611
 *         return GiacMethods['abs'](self,*args)
 * 
 *      def abscissa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for abscissa:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_101abscissa, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_abscissa, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__75)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_abscissa, __pyx_t_2) < 0) __PYX_ERR(2, 611, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":625
 *         return GiacMethods['abscissa'](self,*args)
 * 
 *      def accumulate_head_tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for accumulate_head_tail:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_103accumulate_head_tail, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_accumulate_head, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__76)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_accumulate_head_tail, __pyx_t_2) < 0) __PYX_ERR(2, 625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":636
 *         return GiacMethods['accumulate_head_tail'](self,*args)
 * 
 *      def acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_105acos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__77)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acos, __pyx_t_2) < 0) __PYX_ERR(2, 636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":647
 *         return GiacMethods['acos'](self,*args)
 * 
 *      def acos2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2asin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_107acos2asin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acos2asin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__78)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acos2asin, __pyx_t_2) < 0) __PYX_ERR(2, 647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":659
 *         return GiacMethods['acos2asin'](self,*args)
 * 
 *      def acos2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acos2atan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_109acos2atan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acos2atan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__79)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acos2atan, __pyx_t_2) < 0) __PYX_ERR(2, 659, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":671
 *         return GiacMethods['acos2atan'](self,*args)
 * 
 *      def acosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acosh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_111acosh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acosh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__80)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acosh, __pyx_t_2) < 0) __PYX_ERR(2, 671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":682
 *         return GiacMethods['acosh'](self,*args)
 * 
 *      def acot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_113acot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__81)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acot, __pyx_t_2) < 0) __PYX_ERR(2, 682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":693
 *         return GiacMethods['acot'](self,*args)
 * 
 *      def acsc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acsc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_115acsc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acsc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__82)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acsc, __pyx_t_2) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":705
 *         return GiacMethods['acsc'](self,*args)
 * 
 *      def acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for acyclic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_117acyclic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_acyclic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_acyclic, __pyx_t_2) < 0) __PYX_ERR(2, 705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":715
 *         return GiacMethods['acyclic'](self,*args)
 * 
 *      def adaptive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adaptive:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_119adaptive, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_adaptive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__84)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_adaptive, __pyx_t_2) < 0) __PYX_ERR(2, 715, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":725
 *         return GiacMethods['adaptive'](self,*args)
 * 
 *      def add(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_121add, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_add, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__85)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_add, __pyx_t_2) < 0) __PYX_ERR(2, 725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":745
 *         return GiacMethods['add'](self,*args)
 * 
 *      def add_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_arc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_123add_arc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_add_arc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__86)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_add_arc, __pyx_t_2) < 0) __PYX_ERR(2, 745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":756
 *         return GiacMethods['add_arc'](self,*args)
 * 
 *      def add_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_edge:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_125add_edge, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_add_edge, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__87)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_add_edge, __pyx_t_2) < 0) __PYX_ERR(2, 756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":767
 *         return GiacMethods['add_edge'](self,*args)
 * 
 *      def add_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for add_vertex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_127add_vertex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_add_vertex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__88)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_add_vertex, __pyx_t_2) < 0) __PYX_ERR(2, 767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":778
 *         return GiacMethods['add_vertex'](self,*args)
 * 
 *      def additionally(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for additionally:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_129additionally, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_additionally, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__89)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_additionally, __pyx_t_2) < 0) __PYX_ERR(2, 778, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":790
 *         return GiacMethods['additionally'](self,*args)
 * 
 *      def addtable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for addtable:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_131addtable, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_addtable, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_addtable, __pyx_t_2) < 0) __PYX_ERR(2, 790, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":801
 *         return GiacMethods['addtable'](self,*args)
 * 
 *      def adjacency_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjacency_matrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_133adjacency_matrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_adjacency_matri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__91)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_adjacency_matrix, __pyx_t_2) < 0) __PYX_ERR(2, 801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":812
 *         return GiacMethods['adjacency_matrix'](self,*args)
 * 
 *      def adjoint_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for adjoint_matrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_135adjoint_matrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_adjoint_matrix, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__92)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_adjoint_matrix, __pyx_t_2) < 0) __PYX_ERR(2, 812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":823
 *         return GiacMethods['adjoint_matrix'](self,*args)
 * 
 *      def affix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for affix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_137affix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_affix, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__93)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_affix, __pyx_t_2) < 0) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":836
 *         return GiacMethods['affix'](self,*args)
 * 
 *      def algsubs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algsubs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_139algsubs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_algsubs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_algsubs, __pyx_t_2) < 0) __PYX_ERR(2, 836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":849
 *         return GiacMethods['algsubs'](self,*args)
 * 
 *      def algvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for algvar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_141algvar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_algvar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__95)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_algvar, __pyx_t_2) < 0) __PYX_ERR(2, 849, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":860
 *         return GiacMethods['algvar'](self,*args)
 * 
 *      def all_trig_solutions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for all_trig_solutions:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_143all_trig_solutions, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_all_trig_soluti, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_all_trig_solutions, __pyx_t_2) < 0) __PYX_ERR(2, 860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":872
 *         return GiacMethods['all_trig_solutions'](self,*args)
 * 
 *      def allpairs_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for allpairs_distance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_145allpairs_distance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_allpairs_distan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__97)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_allpairs_distance, __pyx_t_2) < 0) __PYX_ERR(2, 872, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":883
 *         return GiacMethods['allpairs_distance'](self,*args)
 * 
 *      def alog10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for alog10:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_147alog10, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_alog10, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_alog10, __pyx_t_2) < 0) __PYX_ERR(2, 883, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":894
 *         return GiacMethods['alog10'](self,*args)
 * 
 *      def altitude(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for altitude:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_149altitude, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_altitude, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__99)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_altitude, __pyx_t_2) < 0) __PYX_ERR(2, 894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":905
 *         return GiacMethods['altitude'](self,*args)
 * 
 *      def angle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_151angle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_angle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__100)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_angle, __pyx_t_2) < 0) __PYX_ERR(2, 905, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":920
 *         return GiacMethods['angle'](self,*args)
 * 
 *      def angle_radian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angle_radian:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_153angle_radian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_angle_radian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__101)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_angle_radian, __pyx_t_2) < 0) __PYX_ERR(2, 920, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":932
 *         return GiacMethods['angle_radian'](self,*args)
 * 
 *      def angleat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_155angleat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_angleat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__102)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_angleat, __pyx_t_2) < 0) __PYX_ERR(2, 932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":943
 *         return GiacMethods['angleat'](self,*args)
 * 
 *      def angleatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for angleatraw:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_157angleatraw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_angleatraw, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__103)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_angleatraw, __pyx_t_2) < 0) __PYX_ERR(2, 943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":954
 *         return GiacMethods['angleatraw'](self,*args)
 * 
 *      def ans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ans:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_159ans, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ans, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__104)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ans, __pyx_t_2) < 0) __PYX_ERR(2, 954, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":967
 *         return GiacMethods['ans'](self,*args)
 * 
 *      def antiprism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for antiprism_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_161antiprism_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_antiprism_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__105)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_antiprism_graph, __pyx_t_2) < 0) __PYX_ERR(2, 967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":978
 *         return GiacMethods['antiprism_graph'](self,*args)
 * 
 *      def append(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for append:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_163append, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_append, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__106)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_append, __pyx_t_2) < 0) __PYX_ERR(2, 978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":994
 *         return GiacMethods['append'](self,*args)
 * 
 *      def apply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for apply:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_165apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_apply, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__107)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(2, 994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1006
 *         return GiacMethods['apply'](self,*args)
 * 
 *      def approx(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for approx:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_167approx, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_approx, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__108)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_approx, __pyx_t_2) < 0) __PYX_ERR(2, 1006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1022
 *         return GiacMethods['approx'](self,*args)
 * 
 *      def arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_169arc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__109)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arc, __pyx_t_2) < 0) __PYX_ERR(2, 1022, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1036
 *         return GiacMethods['arc'](self,*args)
 * 
 *      def arcLen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcLen:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_171arcLen, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arcLen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__110)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arcLen, __pyx_t_2) < 0) __PYX_ERR(2, 1036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1049
 *         return GiacMethods['arcLen'](self,*args)
 * 
 *      def arccos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_173arccos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arccos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__111)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arccos, __pyx_t_2) < 0) __PYX_ERR(2, 1049, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1060
 *         return GiacMethods['arccos'](self,*args)
 * 
 *      def arccosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arccosh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_175arccosh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arccosh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__112)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arccosh, __pyx_t_2) < 0) __PYX_ERR(2, 1060, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1071
 *         return GiacMethods['arccosh'](self,*args)
 * 
 *      def arclen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arclen:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_177arclen, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arclen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__113)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arclen, __pyx_t_2) < 0) __PYX_ERR(2, 1071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1084
 *         return GiacMethods['arclen'](self,*args)
 * 
 *      def arcsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_179arcsin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arcsin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__114)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arcsin, __pyx_t_2) < 0) __PYX_ERR(2, 1084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1095
 *         return GiacMethods['arcsin'](self,*args)
 * 
 *      def arcsinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arcsinh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_181arcsinh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arcsinh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__115)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arcsinh, __pyx_t_2) < 0) __PYX_ERR(2, 1095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1106
 *         return GiacMethods['arcsinh'](self,*args)
 * 
 *      def arctan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_183arctan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arctan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__116)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arctan, __pyx_t_2) < 0) __PYX_ERR(2, 1106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1117
 *         return GiacMethods['arctan'](self,*args)
 * 
 *      def arctanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arctanh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_185arctanh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arctanh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__117)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arctanh, __pyx_t_2) < 0) __PYX_ERR(2, 1117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1128
 *         return GiacMethods['arctanh'](self,*args)
 * 
 *      def area(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for area:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_187area, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_area, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__118)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_area, __pyx_t_2) < 0) __PYX_ERR(2, 1128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1145
 *         return GiacMethods['area'](self,*args)
 * 
 *      def areaat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_189areaat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_areaat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__119)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_areaat, __pyx_t_2) < 0) __PYX_ERR(2, 1145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1160
 *         return GiacMethods['areaat'](self,*args)
 * 
 *      def areaatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaatraw:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_191areaatraw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_areaatraw, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__120)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_areaatraw, __pyx_t_2) < 0) __PYX_ERR(2, 1160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1175
 *         return GiacMethods['areaatraw'](self,*args)
 * 
 *      def areaplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for areaplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_193areaplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_areaplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__121)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_areaplot, __pyx_t_2) < 0) __PYX_ERR(2, 1175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1188
 *         return GiacMethods['areaplot'](self,*args)
 * 
 *      def arg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arg:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_195arg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__122)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arg, __pyx_t_2) < 0) __PYX_ERR(2, 1188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1201
 *         return GiacMethods['arg'](self,*args)
 * 
 *      def array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for array:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_197array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_array, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__123)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_array, __pyx_t_2) < 0) __PYX_ERR(2, 1201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1213
 *         return GiacMethods['array'](self,*args)
 * 
 *      def arrivals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for arrivals:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_199arrivals, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_arrivals, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__124)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_arrivals, __pyx_t_2) < 0) __PYX_ERR(2, 1213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1224
 *         return GiacMethods['arrivals'](self,*args)
 * 
 *      def articulation_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for articulation_points:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_201articulation_points, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_articulation_po, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__125)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_articulation_points, __pyx_t_2) < 0) __PYX_ERR(2, 1224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1236
 *         return GiacMethods['articulation_points'](self,*args)
 * 
 *      def asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_203asin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_asin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__126)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_asin, __pyx_t_2) < 0) __PYX_ERR(2, 1236, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1247
 *         return GiacMethods['asin'](self,*args)
 * 
 *      def asin2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2acos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_205asin2acos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_asin2acos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__127)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_asin2acos, __pyx_t_2) < 0) __PYX_ERR(2, 1247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1259
 *         return GiacMethods['asin2acos'](self,*args)
 * 
 *      def asin2atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asin2atan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_207asin2atan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_asin2atan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__128)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_asin2atan, __pyx_t_2) < 0) __PYX_ERR(2, 1259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1271
 *         return GiacMethods['asin2atan'](self,*args)
 * 
 *      def asinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for asinh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_209asinh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_asinh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__129)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_asinh, __pyx_t_2) < 0) __PYX_ERR(2, 1271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1282
 *         return GiacMethods['asinh'](self,*args)
 * 
 *      def assign_edge_weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assign_edge_weights:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_211assign_edge_weights, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_assign_edge_wei, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__130)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_assign_edge_weights, __pyx_t_2) < 0) __PYX_ERR(2, 1282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1294
 *         return GiacMethods['assign_edge_weights'](self,*args)
 * 
 *      def assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for assume:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_213assume, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_assume, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__131)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_assume, __pyx_t_2) < 0) __PYX_ERR(2, 1294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1314
 *         return GiacMethods['assume'](self,*args)
 * 
 *      def at(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for at:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_215at, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_at, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__132)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_at, __pyx_t_2) < 0) __PYX_ERR(2, 1314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1326
 *         return GiacMethods['at'](self,*args)
 * 
 *      def atan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_217atan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_atan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__133)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_atan, __pyx_t_2) < 0) __PYX_ERR(2, 1326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1337
 *         return GiacMethods['atan'](self,*args)
 * 
 *      def atan2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_219atan2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_atan2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__134)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_atan2, __pyx_t_2) < 0) __PYX_ERR(2, 1337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1348
 *         return GiacMethods['atan2'](self,*args)
 * 
 *      def atan2acos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2acos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_221atan2acos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_atan2acos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__135)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_atan2acos, __pyx_t_2) < 0) __PYX_ERR(2, 1348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1358
 *         return GiacMethods['atan2acos'](self,*args)
 * 
 *      def atan2asin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atan2asin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_223atan2asin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_atan2asin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__136)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_atan2asin, __pyx_t_2) < 0) __PYX_ERR(2, 1358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1368
 *         return GiacMethods['atan2asin'](self,*args)
 * 
 *      def atanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atanh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_225atanh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_atanh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__137)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_atanh, __pyx_t_2) < 0) __PYX_ERR(2, 1368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1379
 *         return GiacMethods['atanh'](self,*args)
 * 
 *      def atrig2ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for atrig2ln:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_227atrig2ln, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_atrig2ln, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__138)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_atrig2ln, __pyx_t_2) < 0) __PYX_ERR(2, 1379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1392
 *         return GiacMethods['atrig2ln'](self,*args)
 * 
 *      def augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for augment:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_229augment, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_augment, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__139)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_augment, __pyx_t_2) < 0) __PYX_ERR(2, 1392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1407
 *         return GiacMethods['augment'](self,*args)
 * 
 *      def auto_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for auto_correlation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_231auto_correlation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_auto_correlatio, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__140)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_auto_correlation, __pyx_t_2) < 0) __PYX_ERR(2, 1407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1418
 *         return GiacMethods['auto_correlation'](self,*args)
 * 
 *      def autosimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for autosimplify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_233autosimplify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_autosimplify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__141)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_autosimplify, __pyx_t_2) < 0) __PYX_ERR(2, 1418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1434
 *         return GiacMethods['autosimplify'](self,*args)
 * 
 *      def avance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_235avance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_avance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__142)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_avance, __pyx_t_2) < 0) __PYX_ERR(2, 1434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1446
 *         return GiacMethods['avance'](self,*args)
 * 
 *      def avgRC(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for avgRC:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_237avgRC, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_avgRC, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__143)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_avgRC, __pyx_t_2) < 0) __PYX_ERR(2, 1446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1459
 *         return GiacMethods['avgRC'](self,*args)
 * 
 *      def axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_239axes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_axes, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__144)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_axes, __pyx_t_2) < 0) __PYX_ERR(2, 1459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1471
 *         return GiacMethods['axes'](self,*args)
 * 
 *      def axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for axis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_241axis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_axis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__145)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_axis, __pyx_t_2) < 0) __PYX_ERR(2, 1471, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1481
 *         return GiacMethods['axis'](self,*args)
 * 
 *      def back(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for back:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_243back, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_back, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__146)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_back, __pyx_t_2) < 0) __PYX_ERR(2, 1481, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1494
 *         return GiacMethods['back'](self,*args)
 * 
 *      def backward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for backward:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_245backward, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_backward, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__147)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_backward, __pyx_t_2) < 0) __PYX_ERR(2, 1494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1506
 *         return GiacMethods['backward'](self,*args)
 * 
 *      def baisse_crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for baisse_crayon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_247baisse_crayon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_baisse_crayon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__148)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_baisse_crayon, __pyx_t_2) < 0) __PYX_ERR(2, 1506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1517
 *         return GiacMethods['baisse_crayon'](self,*args)
 * 
 *      def bandwidth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bandwidth:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_249bandwidth, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bandwidth, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__149)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bandwidth, __pyx_t_2) < 0) __PYX_ERR(2, 1517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1527
 *         return GiacMethods['bandwidth'](self,*args)
 * 
 *      def bar_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bar_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_251bar_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bar_plot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__150)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bar_plot, __pyx_t_2) < 0) __PYX_ERR(2, 1527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1540
 *         return GiacMethods['bar_plot'](self,*args)
 * 
 *      def barplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_253barplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_barplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__151)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_barplot, __pyx_t_2) < 0) __PYX_ERR(2, 1540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1553
 *         return GiacMethods['barplot'](self,*args)
 * 
 *      def bartlett_hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bartlett_hann_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_255bartlett_hann_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bartlett_hann_w, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__152)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bartlett_hann_window, __pyx_t_2) < 0) __PYX_ERR(2, 1553, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1564
 *         return GiacMethods['bartlett_hann_window'](self,*args)
 * 
 *      def barycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for barycenter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_257barycenter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_barycenter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__153)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_barycenter, __pyx_t_2) < 0) __PYX_ERR(2, 1564, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1577
 *         return GiacMethods['barycenter'](self,*args)
 * 
 *      def base(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for base:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_259base, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_base, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__154)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_base, __pyx_t_2) < 0) __PYX_ERR(2, 1577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1590
 *         return GiacMethods['base'](self,*args)
 * 
 *      def basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for basis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_261basis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_basis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__155)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_basis, __pyx_t_2) < 0) __PYX_ERR(2, 1590, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1601
 *         return GiacMethods['basis'](self,*args)
 * 
 *      def batons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for batons:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_263batons, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_batons, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__156)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_batons, __pyx_t_2) < 0) __PYX_ERR(2, 1601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1614
 *         return GiacMethods['batons'](self,*args)
 * 
 *      def bellman_ford(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bellman_ford:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_265bellman_ford, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bellman_ford, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__157)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bellman_ford, __pyx_t_2) < 0) __PYX_ERR(2, 1614, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1625
 *         return GiacMethods['bellman_ford'](self,*args)
 * 
 *      def berlekamp_massey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for berlekamp_massey:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_267berlekamp_massey, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_berlekamp_masse, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__158)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_berlekamp_massey, __pyx_t_2) < 0) __PYX_ERR(2, 1625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1636
 *         return GiacMethods['berlekamp_massey'](self,*args)
 * 
 *      def bernoulli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_269bernoulli, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bernoulli, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__159)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bernoulli, __pyx_t_2) < 0) __PYX_ERR(2, 1636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1648
 *         return GiacMethods['bernoulli'](self,*args)
 * 
 *      def bernoulli_mod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bernoulli_mod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_271bernoulli_mod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bernoulli_mod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__160)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bernoulli_mod, __pyx_t_2) < 0) __PYX_ERR(2, 1648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1658
 *         return GiacMethods['bernoulli_mod'](self,*args)
 * 
 *      def besselJ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselJ:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_273besselJ, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_besselJ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__161)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_besselJ, __pyx_t_2) < 0) __PYX_ERR(2, 1658, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1670
 *         return GiacMethods['besselJ'](self,*args)
 * 
 *      def besselY(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for besselY:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_275besselY, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_besselY, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__162)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_besselY, __pyx_t_2) < 0) __PYX_ERR(2, 1670, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1682
 *         return GiacMethods['besselY'](self,*args)
 * 
 *      def betad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_277betad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_betad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__163)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_betad, __pyx_t_2) < 0) __PYX_ERR(2, 1682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1693
 *         return GiacMethods['betad'](self,*args)
 * 
 *      def betad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_279betad_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_betad_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__164)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_betad_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 1693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1705
 *         return GiacMethods['betad_cdf'](self,*args)
 * 
 *      def betad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betad_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_281betad_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_betad_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__165)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_betad_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 1705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1717
 *         return GiacMethods['betad_icdf'](self,*args)
 * 
 *      def betavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betavariate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_283betavariate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_betavariate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__166)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_betavariate, __pyx_t_2) < 0) __PYX_ERR(2, 1717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1729
 *         return GiacMethods['betavariate'](self,*args)
 * 
 *      def betweenness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for betweenness_centrality:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_285betweenness_centrality, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_betweenness_cen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__167)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_betweenness_centrality, __pyx_t_2) < 0) __PYX_ERR(2, 1729, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1740
 *         return GiacMethods['betweenness_centrality'](self,*args)
 * 
 *      def bezier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezier:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_287bezier, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bezier, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__168)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bezier, __pyx_t_2) < 0) __PYX_ERR(2, 1740, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1754
 *         return GiacMethods['bezier'](self,*args)
 * 
 *      def bezout_entiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezout_entiers:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_289bezout_entiers, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bezout_entiers, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__169)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bezout_entiers, __pyx_t_2) < 0) __PYX_ERR(2, 1754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1767
 *         return GiacMethods['bezout_entiers'](self,*args)
 * 
 *      def bezoutian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bezoutian:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_291bezoutian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bezoutian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__170)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bezoutian, __pyx_t_2) < 0) __PYX_ERR(2, 1767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1777
 *         return GiacMethods['bezoutian'](self,*args)
 * 
 *      def biconnected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for biconnected_components:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_293biconnected_components, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_biconnected_com, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__171)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_biconnected_components, __pyx_t_2) < 0) __PYX_ERR(2, 1777, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1788
 *         return GiacMethods['biconnected_components'](self,*args)
 * 
 *      def binomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_295binomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_binomial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__172)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_binomial, __pyx_t_2) < 0) __PYX_ERR(2, 1788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1805
 *         return GiacMethods['binomial'](self,*args)
 * 
 *      def binomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_297binomial_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_binomial_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__173)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_binomial_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1818
 *         return GiacMethods['binomial_cdf'](self,*args)
 * 
 *      def binomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for binomial_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_299binomial_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_binomial_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__174)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_binomial_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 1818, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1830
 *         return GiacMethods['binomial_icdf'](self,*args)
 * 
 *      def bins(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bins:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_301bins, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bins, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__175)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bins, __pyx_t_2) < 0) __PYX_ERR(2, 1830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1840
 *         return GiacMethods['bins'](self,*args)
 * 
 *      def bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_303bipartite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bipartite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__176)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bipartite, __pyx_t_2) < 0) __PYX_ERR(2, 1840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1850
 *         return GiacMethods['bipartite'](self,*args)
 * 
 *      def bipartite_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bipartite_matching:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_305bipartite_matching, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bipartite_match, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__177)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bipartite_matching, __pyx_t_2) < 0) __PYX_ERR(2, 1850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1861
 *         return GiacMethods['bipartite_matching'](self,*args)
 * 
 *      def bisection_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisection_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_307bisection_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bisection_solve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__178)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bisection_solver, __pyx_t_2) < 0) __PYX_ERR(2, 1861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1877
 *         return GiacMethods['bisection_solver'](self,*args)
 * 
 *      def bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bisector:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_309bisector, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bisector, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__179)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bisector, __pyx_t_2) < 0) __PYX_ERR(2, 1877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1888
 *         return GiacMethods['bisector'](self,*args)
 * 
 *      def bit_depth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bit_depth:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_311bit_depth, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bit_depth, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__180)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bit_depth, __pyx_t_2) < 0) __PYX_ERR(2, 1888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1899
 *         return GiacMethods['bit_depth'](self,*args)
 * 
 *      def bitand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_313bitand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bitand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__181)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bitand, __pyx_t_2) < 0) __PYX_ERR(2, 1899, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1910
 *         return GiacMethods['bitand'](self,*args)
 * 
 *      def bitor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_315bitor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bitor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__182)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bitor, __pyx_t_2) < 0) __PYX_ERR(2, 1910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1921
 *         return GiacMethods['bitor'](self,*args)
 * 
 *      def bitxor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bitxor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_317bitxor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bitxor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__183)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bitxor, __pyx_t_2) < 0) __PYX_ERR(2, 1921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1932
 *         return GiacMethods['bitxor'](self,*args)
 * 
 *      def blackman_harris_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_harris_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_319blackman_harris_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_blackman_harris, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__184)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_blackman_harris_window, __pyx_t_2) < 0) __PYX_ERR(2, 1932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1943
 *         return GiacMethods['blackman_harris_window'](self,*args)
 * 
 *      def blackman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blackman_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_321blackman_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_blackman_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__185)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_blackman_window, __pyx_t_2) < 0) __PYX_ERR(2, 1943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1954
 *         return GiacMethods['blackman_window'](self,*args)
 * 
 *      def block_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for block_size:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_323block_size, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_block_size, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__186)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_block_size, __pyx_t_2) < 0) __PYX_ERR(2, 1954, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1964
 *         return GiacMethods['block_size'](self,*args)
 * 
 *      def blockmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for blockmatrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_325blockmatrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_blockmatrix, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__187)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_blockmatrix, __pyx_t_2) < 0) __PYX_ERR(2, 1964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1976
 *         return GiacMethods['blockmatrix'](self,*args)
 * 
 *      def bohman_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bohman_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_327bohman_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bohman_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__188)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bohman_window, __pyx_t_2) < 0) __PYX_ERR(2, 1976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1987
 *         return GiacMethods['bohman_window'](self,*args)
 * 
 *      def border(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for border:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_329border, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_border, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__189)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_border, __pyx_t_2) < 0) __PYX_ERR(2, 1987, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":1999
 *         return GiacMethods['border'](self,*args)
 * 
 *      def box_constraints(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for box_constraints:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_331box_constraints, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_box_constraints, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__190)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_box_constraints, __pyx_t_2) < 0) __PYX_ERR(2, 1999, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2010
 *         return GiacMethods['box_constraints'](self,*args)
 * 
 *      def boxcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxcar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_333boxcar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_boxcar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__191)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_boxcar, __pyx_t_2) < 0) __PYX_ERR(2, 2010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2021
 *         return GiacMethods['boxcar'](self,*args)
 * 
 *      def boxwhisker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for boxwhisker:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_335boxwhisker, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_boxwhisker, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__192)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_boxwhisker, __pyx_t_2) < 0) __PYX_ERR(2, 2021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2035
 *         return GiacMethods['boxwhisker'](self,*args)
 * 
 *      def brent_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brent_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_337brent_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_brent_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__193)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_brent_solver, __pyx_t_2) < 0) __PYX_ERR(2, 2035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2051
 *         return GiacMethods['brent_solver'](self,*args)
 * 
 *      def brown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for brown:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_339brown, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_brown, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__194)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_brown, __pyx_t_2) < 0) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2063
 *         return GiacMethods['brown'](self,*args)
 * 
 *      def bspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bspline:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_341bspline, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bspline, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__195)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bspline, __pyx_t_2) < 0) __PYX_ERR(2, 2063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2074
 *         return GiacMethods['bspline'](self,*args)
 * 
 *      def bvpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for bvpsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_343bvpsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_bvpsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__196)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_bvpsolve, __pyx_t_2) < 0) __PYX_ERR(2, 2074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2086
 *         return GiacMethods['bvpsolve'](self,*args)
 * 
 *      def cFactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cFactor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_345cFactor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cFactor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__197)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cFactor, __pyx_t_2) < 0) __PYX_ERR(2, 2086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2099
 *         return GiacMethods['cFactor'](self,*args)
 * 
 *      def cSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cSolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_347cSolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cSolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__198)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cSolve, __pyx_t_2) < 0) __PYX_ERR(2, 2099, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2113
 *         return GiacMethods['cSolve'](self,*args)
 * 
 *      def cZeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cZeros:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_349cZeros, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cZeros, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__199)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cZeros, __pyx_t_2) < 0) __PYX_ERR(2, 2113, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2125
 *         return GiacMethods['cZeros'](self,*args)
 * 
 *      def camembert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for camembert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_351camembert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_camembert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__200)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_camembert, __pyx_t_2) < 0) __PYX_ERR(2, 2125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2138
 *         return GiacMethods['camembert'](self,*args)
 * 
 *      def canonical_form(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_form:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_353canonical_form, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_canonical_form, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__201)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_canonical_form, __pyx_t_2) < 0) __PYX_ERR(2, 2138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2150
 *         return GiacMethods['canonical_form'](self,*args)
 * 
 *      def canonical_labeling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for canonical_labeling:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_355canonical_labeling, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_canonical_label, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__202)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_canonical_labeling, __pyx_t_2) < 0) __PYX_ERR(2, 2150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2161
 *         return GiacMethods['canonical_labeling'](self,*args)
 * 
 *      def cartesian_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cartesian_product:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_357cartesian_product, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cartesian_produ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__203)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cartesian_product, __pyx_t_2) < 0) __PYX_ERR(2, 2161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2172
 *         return GiacMethods['cartesian_product'](self,*args)
 * 
 *      def cauchy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_359cauchy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cauchy, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__204)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cauchy, __pyx_t_2) < 0) __PYX_ERR(2, 2172, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2183
 *         return GiacMethods['cauchy'](self,*args)
 * 
 *      def cauchy_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_361cauchy_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cauchy_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__205)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cauchy_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 2183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2195
 *         return GiacMethods['cauchy_cdf'](self,*args)
 * 
 *      def cauchy_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchy_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_363cauchy_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cauchy_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__206)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cauchy_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 2195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2206
 *         return GiacMethods['cauchy_icdf'](self,*args)
 * 
 *      def cauchyd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_365cauchyd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cauchyd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__207)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cauchyd, __pyx_t_2) < 0) __PYX_ERR(2, 2206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2217
 *         return GiacMethods['cauchyd'](self,*args)
 * 
 *      def cauchyd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_367cauchyd_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cauchyd_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__208)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cauchyd_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 2217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2229
 *         return GiacMethods['cauchyd_cdf'](self,*args)
 * 
 *      def cauchyd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cauchyd_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_369cauchyd_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cauchyd_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__209)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cauchyd_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 2229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2240
 *         return GiacMethods['cauchyd_icdf'](self,*args)
 * 
 *      def cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_371cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__210)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 2240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2254
 *         return GiacMethods['cdf'](self,*args)
 * 
 *      def ceil(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceil:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_373ceil, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ceil, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__211)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ceil, __pyx_t_2) < 0) __PYX_ERR(2, 2254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2266
 *         return GiacMethods['ceil'](self,*args)
 * 
 *      def ceiling(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ceiling:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_375ceiling, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ceiling, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__212)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ceiling, __pyx_t_2) < 0) __PYX_ERR(2, 2266, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2278
 *         return GiacMethods['ceiling'](self,*args)
 * 
 *      def center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_377center, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_center, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__213)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_center, __pyx_t_2) < 0) __PYX_ERR(2, 2278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2290
 *         return GiacMethods['center'](self,*args)
 * 
 *      def center2interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for center2interval:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_379center2interval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_center2interval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__214)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_center2interval, __pyx_t_2) < 0) __PYX_ERR(2, 2290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2302
 *         return GiacMethods['center2interval'](self,*args)
 * 
 *      def centered_cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_cube:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_381centered_cube, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_centered_cube, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__215)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_centered_cube, __pyx_t_2) < 0) __PYX_ERR(2, 2302, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2314
 *         return GiacMethods['centered_cube'](self,*args)
 * 
 *      def centered_tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for centered_tetrahedron:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_383centered_tetrahedron, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_centered_tetrah, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__216)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_centered_tetrahedron, __pyx_t_2) < 0) __PYX_ERR(2, 2314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2326
 *         return GiacMethods['centered_tetrahedron'](self,*args)
 * 
 *      def cfactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfactor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_385cfactor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cfactor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__217)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cfactor, __pyx_t_2) < 0) __PYX_ERR(2, 2326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2339
 *         return GiacMethods['cfactor'](self,*args)
 * 
 *      def cfsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cfsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_387cfsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cfsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__218)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cfsolve, __pyx_t_2) < 0) __PYX_ERR(2, 2339, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2351
 *         return GiacMethods['cfsolve'](self,*args)
 * 
 *      def changebase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for changebase:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_389changebase, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_changebase, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__219)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_changebase, __pyx_t_2) < 0) __PYX_ERR(2, 2351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2363
 *         return GiacMethods['changebase'](self,*args)
 * 
 *      def channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channel_data:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_391channel_data, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_channel_data, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__220)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_channel_data, __pyx_t_2) < 0) __PYX_ERR(2, 2363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2377
 *         return GiacMethods['channel_data'](self,*args)
 * 
 *      def channels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for channels:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_393channels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_channels, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__221)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_channels, __pyx_t_2) < 0) __PYX_ERR(2, 2377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2388
 *         return GiacMethods['channels'](self,*args)
 * 
 *      def char(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for char:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_395char, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_char, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__222)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_char, __pyx_t_2) < 0) __PYX_ERR(2, 2388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2400
 *         return GiacMethods['char'](self,*args)
 * 
 *      def charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for charpoly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_397charpoly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_charpoly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__223)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_charpoly, __pyx_t_2) < 0) __PYX_ERR(2, 2400, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2414
 *         return GiacMethods['charpoly'](self,*args)
 * 
 *      def chinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chinrem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_399chinrem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chinrem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__224)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chinrem, __pyx_t_2) < 0) __PYX_ERR(2, 2414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2426
 *         return GiacMethods['chinrem'](self,*args)
 * 
 *      def chisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_401chisquare, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquare, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__225)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquare, __pyx_t_2) < 0) __PYX_ERR(2, 2426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2440
 *         return GiacMethods['chisquare'](self,*args)
 * 
 *      def chisquare_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_403chisquare_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquare_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__226)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquare_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 2440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2452
 *         return GiacMethods['chisquare_cdf'](self,*args)
 * 
 *      def chisquare_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquare_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_405chisquare_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquare_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__227)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquare_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 2452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2464
 *         return GiacMethods['chisquare_icdf'](self,*args)
 * 
 *      def chisquared(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_407chisquared, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquared, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__228)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquared, __pyx_t_2) < 0) __PYX_ERR(2, 2464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2478
 *         return GiacMethods['chisquared'](self,*args)
 * 
 *      def chisquared_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_409chisquared_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquared_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__229)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquared_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 2478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2490
 *         return GiacMethods['chisquared_cdf'](self,*args)
 * 
 *      def chisquared_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquared_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_411chisquared_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquared_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__230)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquared_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 2490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2502
 *         return GiacMethods['chisquared_icdf'](self,*args)
 * 
 *      def chisquaret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chisquaret:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_413chisquaret, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chisquaret, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__231)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chisquaret, __pyx_t_2) < 0) __PYX_ERR(2, 2502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2521
 *         return GiacMethods['chisquaret'](self,*args)
 * 
 *      def choice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for choice:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_415choice, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_choice, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__232)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_choice, __pyx_t_2) < 0) __PYX_ERR(2, 2521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2535
 *         return GiacMethods['choice'](self,*args)
 * 
 *      def cholesky(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cholesky:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_417cholesky, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cholesky, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__233)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cholesky, __pyx_t_2) < 0) __PYX_ERR(2, 2535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2546
 *         return GiacMethods['cholesky'](self,*args)
 * 
 *      def chr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_419chr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__234)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chr, __pyx_t_2) < 0) __PYX_ERR(2, 2546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2558
 *         return GiacMethods['chr'](self,*args)
 * 
 *      def chrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chrem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_421chrem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chrem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__235)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chrem, __pyx_t_2) < 0) __PYX_ERR(2, 2558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2573
 *         return GiacMethods['chrem'](self,*args)
 * 
 *      def chromatic_index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_index:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_423chromatic_index, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chromatic_index, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__236)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chromatic_index, __pyx_t_2) < 0) __PYX_ERR(2, 2573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2584
 *         return GiacMethods['chromatic_index'](self,*args)
 * 
 *      def chromatic_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_number:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_425chromatic_number, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chromatic_numbe, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__237)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chromatic_number, __pyx_t_2) < 0) __PYX_ERR(2, 2584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2594
 *         return GiacMethods['chromatic_number'](self,*args)
 * 
 *      def chromatic_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for chromatic_polynomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_427chromatic_polynomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_chromatic_polyn, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__238)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_chromatic_polynomial, __pyx_t_2) < 0) __PYX_ERR(2, 2594, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2606
 *         return GiacMethods['chromatic_polynomial'](self,*args)
 * 
 *      def circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_429circle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_circle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_circle, __pyx_t_2) < 0) __PYX_ERR(2, 2606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2624
 *         return GiacMethods['circle'](self,*args)
 * 
 *      def circumcircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for circumcircle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_431circumcircle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_circumcircle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__240)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_circumcircle, __pyx_t_2) < 0) __PYX_ERR(2, 2624, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2635
 *         return GiacMethods['circumcircle'](self,*args)
 * 
 *      def classes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for classes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_433classes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_classes, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__241)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_classes, __pyx_t_2) < 0) __PYX_ERR(2, 2635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2650
 *         return GiacMethods['classes'](self,*args)
 * 
 *      def clear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clear:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_435clear, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_clear, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__242)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_clear, __pyx_t_2) < 0) __PYX_ERR(2, 2650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2661
 *         return GiacMethods['clear'](self,*args)
 * 
 *      def clique_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_437clique_cover, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_clique_cover, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__243)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_clique_cover, __pyx_t_2) < 0) __PYX_ERR(2, 2661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2674
 *         return GiacMethods['clique_cover'](self,*args)
 * 
 *      def clique_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_cover_number:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_439clique_cover_number, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_clique_cover_nu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__244)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_clique_cover_number, __pyx_t_2) < 0) __PYX_ERR(2, 2674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2687
 *         return GiacMethods['clique_cover_number'](self,*args)
 * 
 *      def clique_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clique_number:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_441clique_number, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_clique_number, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__245)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_clique_number, __pyx_t_2) < 0) __PYX_ERR(2, 2687, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2698
 *         return GiacMethods['clique_number'](self,*args)
 * 
 *      def closeness_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for closeness_centrality:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_443closeness_centrality, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_closeness_centr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__246)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_closeness_centrality, __pyx_t_2) < 0) __PYX_ERR(2, 2698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2709
 *         return GiacMethods['closeness_centrality'](self,*args)
 * 
 *      def cluster(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cluster:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_445cluster, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cluster, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__247)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cluster, __pyx_t_2) < 0) __PYX_ERR(2, 2709, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2720
 *         return GiacMethods['cluster'](self,*args)
 * 
 *      def clustering_coefficient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for clustering_coefficient:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_447clustering_coefficient, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_clustering_coef, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__248)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_clustering_coefficient, __pyx_t_2) < 0) __PYX_ERR(2, 2720, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2732
 *         return GiacMethods['clustering_coefficient'](self,*args)
 * 
 *      def coeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_449coeff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_coeff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__249)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_coeff, __pyx_t_2) < 0) __PYX_ERR(2, 2732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2745
 *         return GiacMethods['coeff'](self,*args)
 * 
 *      def coeffs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coeffs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_451coeffs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_coeffs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__250)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_coeffs, __pyx_t_2) < 0) __PYX_ERR(2, 2745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2758
 *         return GiacMethods['coeffs'](self,*args)
 * 
 *      def col(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for col:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_453col, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_col, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_col, __pyx_t_2) < 0) __PYX_ERR(2, 2758, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2771
 *         return GiacMethods['col'](self,*args)
 * 
 *      def colDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colDim:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_455colDim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colDim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__252)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colDim, __pyx_t_2) < 0) __PYX_ERR(2, 2771, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2783
 *         return GiacMethods['colDim'](self,*args)
 * 
 *      def colNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colNorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_457colNorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colNorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__253)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colNorm, __pyx_t_2) < 0) __PYX_ERR(2, 2783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2795
 *         return GiacMethods['colNorm'](self,*args)
 * 
 *      def colSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colSwap:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_459colSwap, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colSwap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__254)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colSwap, __pyx_t_2) < 0) __PYX_ERR(2, 2795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2806
 *         return GiacMethods['colSwap'](self,*args)
 * 
 *      def coldim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coldim:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_461coldim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_coldim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__255)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_coldim, __pyx_t_2) < 0) __PYX_ERR(2, 2806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2818
 *         return GiacMethods['coldim'](self,*args)
 * 
 *      def collect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for collect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_463collect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_collect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__256)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_collect, __pyx_t_2) < 0) __PYX_ERR(2, 2818, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2831
 *         return GiacMethods['collect'](self,*args)
 * 
 *      def colnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colnorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_465colnorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colnorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__257)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colnorm, __pyx_t_2) < 0) __PYX_ERR(2, 2831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2843
 *         return GiacMethods['colnorm'](self,*args)
 * 
 *      def color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for color:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_467color, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_color, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__258)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_color, __pyx_t_2) < 0) __PYX_ERR(2, 2843, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2863
 *         return GiacMethods['color'](self,*args)
 * 
 *      def colormap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colormap:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_469colormap, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colormap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__259)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colormap, __pyx_t_2) < 0) __PYX_ERR(2, 2863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2878
 *         return GiacMethods['colormap'](self,*args)
 * 
 *      def colspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colspace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_471colspace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colspace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__260)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colspace, __pyx_t_2) < 0) __PYX_ERR(2, 2878, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2890
 *         return GiacMethods['colspace'](self,*args)
 * 
 *      def colswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for colswap:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_473colswap, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_colswap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__261)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_colswap, __pyx_t_2) < 0) __PYX_ERR(2, 2890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2901
 *         return GiacMethods['colswap'](self,*args)
 * 
 *      def comDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comDenom:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_475comDenom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_comDenom, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__262)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_comDenom, __pyx_t_2) < 0) __PYX_ERR(2, 2901, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2914
 *         return GiacMethods['comDenom'](self,*args)
 * 
 *      def comb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_477comb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_comb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__263)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_comb, __pyx_t_2) < 0) __PYX_ERR(2, 2914, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2925
 *         return GiacMethods['comb'](self,*args)
 * 
 *      def combine(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for combine:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_479combine, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_combine, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__264)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_combine, __pyx_t_2) < 0) __PYX_ERR(2, 2925, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2938
 *         return GiacMethods['combine'](self,*args)
 * 
 *      def comment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for comment:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_481comment, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_comment, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__265)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_comment, __pyx_t_2) < 0) __PYX_ERR(2, 2938, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2949
 *         return GiacMethods['comment'](self,*args)
 * 
 *      def common_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for common_perpendicular:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_483common_perpendicular, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_common_perpendi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__266)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_common_perpendicular, __pyx_t_2) < 0) __PYX_ERR(2, 2949, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2960
 *         return GiacMethods['common_perpendicular'](self,*args)
 * 
 *      def companion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for companion:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_485companion, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_companion, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__267)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_companion, __pyx_t_2) < 0) __PYX_ERR(2, 2960, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2972
 *         return GiacMethods['companion'](self,*args)
 * 
 *      def compare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for compare:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_487compare, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_compare, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__268)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_compare, __pyx_t_2) < 0) __PYX_ERR(2, 2972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2985
 *         return GiacMethods['compare'](self,*args)
 * 
 *      def complete_binary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_binary_tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_489complete_binary_tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_complete_binary, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__269)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_complete_binary_tree, __pyx_t_2) < 0) __PYX_ERR(2, 2985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":2996
 *         return GiacMethods['complete_binary_tree'](self,*args)
 * 
 *      def complete_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_491complete_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_complete_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_complete_graph, __pyx_t_2) < 0) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3009
 *         return GiacMethods['complete_graph'](self,*args)
 * 
 *      def complete_kary_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complete_kary_tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_493complete_kary_tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_complete_kary_t, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__271)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_complete_kary_tree, __pyx_t_2) < 0) __PYX_ERR(2, 3009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3020
 *         return GiacMethods['complete_kary_tree'](self,*args)
 * 
 *      def complex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_495complex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_complex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_complex, __pyx_t_2) < 0) __PYX_ERR(2, 3020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3033
 *         return GiacMethods['complex'](self,*args)
 * 
 *      def complex_variables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complex_variables:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_497complex_variables, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_complex_variabl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__273)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_complex_variables, __pyx_t_2) < 0) __PYX_ERR(2, 3033, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3045
 *         return GiacMethods['complex_variables'](self,*args)
 * 
 *      def complexroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for complexroot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_499complexroot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_complexroot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__274)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_complexroot, __pyx_t_2) < 0) __PYX_ERR(2, 3045, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3059
 *         return GiacMethods['complexroot'](self,*args)
 * 
 *      def concat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for concat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_501concat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_concat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__275)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_concat, __pyx_t_2) < 0) __PYX_ERR(2, 3059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3074
 *         return GiacMethods['concat'](self,*args)
 * 
 *      def cond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cond:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_503cond, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cond, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cond, __pyx_t_2) < 0) __PYX_ERR(2, 3074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3088
 *         return GiacMethods['cond'](self,*args)
 * 
 *      def condensation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for condensation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_505condensation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_condensation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__277)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_condensation, __pyx_t_2) < 0) __PYX_ERR(2, 3088, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3099
 *         return GiacMethods['condensation'](self,*args)
 * 
 *      def cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cone:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_507cone, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cone, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cone, __pyx_t_2) < 0) __PYX_ERR(2, 3099, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3111
 *         return GiacMethods['cone'](self,*args)
 * 
 *      def confrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for confrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_509confrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_confrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__279)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_confrac, __pyx_t_2) < 0) __PYX_ERR(2, 3111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3122
 *         return GiacMethods['confrac'](self,*args)
 * 
 *      def conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_511conic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_conic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_conic, __pyx_t_2) < 0) __PYX_ERR(2, 3122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3136
 *         return GiacMethods['conic'](self,*args)
 * 
 *      def conj(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conj:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_513conj, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_conj, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__281)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_conj, __pyx_t_2) < 0) __PYX_ERR(2, 3136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3150
 *         return GiacMethods['conj'](self,*args)
 * 
 *      def conjugate_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_equation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_515conjugate_equation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_conjugate_equat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_conjugate_equation, __pyx_t_2) < 0) __PYX_ERR(2, 3150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3161
 *         return GiacMethods['conjugate_equation'](self,*args)
 * 
 *      def conjugate_gradient(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for conjugate_gradient:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_517conjugate_gradient, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_conjugate_gradi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__283)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_conjugate_gradient, __pyx_t_2) < 0) __PYX_ERR(2, 3161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3175
 *         return GiacMethods['conjugate_gradient'](self,*args)
 * 
 *      def connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_519connected, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_connected, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__284)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_connected, __pyx_t_2) < 0) __PYX_ERR(2, 3175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3185
 *         return GiacMethods['connected'](self,*args)
 * 
 *      def connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for connected_components:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_521connected_components, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_connected_compo, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__285)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_connected_components, __pyx_t_2) < 0) __PYX_ERR(2, 3185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3196
 *         return GiacMethods['connected_components'](self,*args)
 * 
 *      def cont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cont:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_523cont, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cont, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cont, __pyx_t_2) < 0) __PYX_ERR(2, 3196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3207
 *         return GiacMethods['cont'](self,*args)
 * 
 *      def contains(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contains:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_525contains, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_contains, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__287)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_contains, __pyx_t_2) < 0) __PYX_ERR(2, 3207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3220
 *         return GiacMethods['contains'](self,*args)
 * 
 *      def content(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for content:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_527content, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_content, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__288)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_content, __pyx_t_2) < 0) __PYX_ERR(2, 3220, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3233
 *         return GiacMethods['content'](self,*args)
 * 
 *      def contourplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contourplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_529contourplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_contourplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__289)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_contourplot, __pyx_t_2) < 0) __PYX_ERR(2, 3233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3247
 *         return GiacMethods['contourplot'](self,*args)
 * 
 *      def contract_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_edge:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_531contract_edge, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_contract_edge, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__290)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_contract_edge, __pyx_t_2) < 0) __PYX_ERR(2, 3247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3258
 *         return GiacMethods['contract_edge'](self,*args)
 * 
 *      def contract_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for contract_subgraph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_533contract_subgraph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_contract_subgra, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__291)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_contract_subgraph, __pyx_t_2) < 0) __PYX_ERR(2, 3258, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3269
 *         return GiacMethods['contract_subgraph'](self,*args)
 * 
 *      def convert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_535convert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_convert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__292)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_convert, __pyx_t_2) < 0) __PYX_ERR(2, 3269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3296
 *         return GiacMethods['convert'](self,*args)
 * 
 *      def convertir(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convertir:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_537convertir, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_convertir, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__293)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_convertir, __pyx_t_2) < 0) __PYX_ERR(2, 3296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3323
 *         return GiacMethods['convertir'](self,*args)
 * 
 *      def convex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_539convex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_convex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__294)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_convex, __pyx_t_2) < 0) __PYX_ERR(2, 3323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3338
 *         return GiacMethods['convex'](self,*args)
 * 
 *      def convexhull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convexhull:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_541convexhull, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_convexhull, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__295)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_convexhull, __pyx_t_2) < 0) __PYX_ERR(2, 3338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3351
 *         return GiacMethods['convexhull'](self,*args)
 * 
 *      def convolution(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for convolution:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_543convolution, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_convolution, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__296)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_convolution, __pyx_t_2) < 0) __PYX_ERR(2, 3351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3363
 *         return GiacMethods['convolution'](self,*args)
 * 
 *      def coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for coordinates:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_545coordinates, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_coordinates, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__297)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_coordinates, __pyx_t_2) < 0) __PYX_ERR(2, 3363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3381
 *         return GiacMethods['coordinates'](self,*args)
 * 
 *      def copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for copy:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_547copy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_copy, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__298)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_copy, __pyx_t_2) < 0) __PYX_ERR(2, 3381, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3392
 *         return GiacMethods['copy'](self,*args)
 * 
 *      def correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for correlation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_549correlation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_correlation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__299)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_correlation, __pyx_t_2) < 0) __PYX_ERR(2, 3392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3403
 *         return GiacMethods['correlation'](self,*args)
 * 
 *      def cos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_551cos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__300)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cos, __pyx_t_2) < 0) __PYX_ERR(2, 3403, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3415
 *         return GiacMethods['cos'](self,*args)
 * 
 *      def cos2sintan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cos2sintan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_553cos2sintan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cos2sintan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cos2sintan, __pyx_t_2) < 0) __PYX_ERR(2, 3415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3426
 *         return GiacMethods['cos2sintan'](self,*args)
 * 
 *      def cosh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_555cosh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cosh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__302)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cosh, __pyx_t_2) < 0) __PYX_ERR(2, 3426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3437
 *         return GiacMethods['cosh'](self,*args)
 * 
 *      def cosine_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cosine_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_557cosine_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cosine_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cosine_window, __pyx_t_2) < 0) __PYX_ERR(2, 3437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3448
 *         return GiacMethods['cosine_window'](self,*args)
 * 
 *      def cot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_559cot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__304)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cot, __pyx_t_2) < 0) __PYX_ERR(2, 3448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3459
 *         return GiacMethods['cot'](self,*args)
 * 
 *      def cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cote:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_561cote, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cote, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cote, __pyx_t_2) < 0) __PYX_ERR(2, 3459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3471
 *         return GiacMethods['cote'](self,*args)
 * 
 *      def count(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_563count, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_count, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__306)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_count, __pyx_t_2) < 0) __PYX_ERR(2, 3471, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3491
 *         return GiacMethods['count'](self,*args)
 * 
 *      def count_eq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_eq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_565count_eq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_count_eq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__307)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_count_eq, __pyx_t_2) < 0) __PYX_ERR(2, 3491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3505
 *         return GiacMethods['count_eq'](self,*args)
 * 
 *      def count_inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_inf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_567count_inf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_count_inf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__308)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_count_inf, __pyx_t_2) < 0) __PYX_ERR(2, 3505, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3519
 *         return GiacMethods['count_inf'](self,*args)
 * 
 *      def count_sup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for count_sup:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_569count_sup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_count_sup, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_count_sup, __pyx_t_2) < 0) __PYX_ERR(2, 3519, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3533
 *         return GiacMethods['count_sup'](self,*args)
 * 
 *      def courbe_parametrique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_parametrique:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_571courbe_parametrique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_courbe_parametr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__310)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_courbe_parametrique, __pyx_t_2) < 0) __PYX_ERR(2, 3533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3551
 *         return GiacMethods['courbe_parametrique'](self,*args)
 * 
 *      def courbe_polaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for courbe_polaire:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_573courbe_polaire, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_courbe_polaire, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__311)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_courbe_polaire, __pyx_t_2) < 0) __PYX_ERR(2, 3551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3563
 *         return GiacMethods['courbe_polaire'](self,*args)
 * 
 *      def covariance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_575covariance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_covariance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__312)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_covariance, __pyx_t_2) < 0) __PYX_ERR(2, 3563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3574
 *         return GiacMethods['covariance'](self,*args)
 * 
 *      def covariance_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for covariance_correlation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_577covariance_correlation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_covariance_corr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__313)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_covariance_correlation, __pyx_t_2) < 0) __PYX_ERR(2, 3574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3585
 *         return GiacMethods['covariance_correlation'](self,*args)
 * 
 *      def cpartfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cpartfrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_579cpartfrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cpartfrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__314)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cpartfrac, __pyx_t_2) < 0) __PYX_ERR(2, 3585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3598
 *         return GiacMethods['cpartfrac'](self,*args)
 * 
 *      def crationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crationalroot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_581crationalroot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_crationalroot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__315)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_crationalroot, __pyx_t_2) < 0) __PYX_ERR(2, 3598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3609
 *         return GiacMethods['crationalroot'](self,*args)
 * 
 *      def crayon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crayon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_583crayon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_crayon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__316)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_crayon, __pyx_t_2) < 0) __PYX_ERR(2, 3609, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3623
 *         return GiacMethods['crayon'](self,*args)
 * 
 *      def createwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for createwav:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_585createwav, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_createwav, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__317)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_createwav, __pyx_t_2) < 0) __PYX_ERR(2, 3623, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3638
 *         return GiacMethods['createwav'](self,*args)
 * 
 *      def cross(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_587cross, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cross, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__318)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cross, __pyx_t_2) < 0) __PYX_ERR(2, 3638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3650
 *         return GiacMethods['cross'](self,*args)
 * 
 *      def crossP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossP:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_589crossP, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_crossP, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__319)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_crossP, __pyx_t_2) < 0) __PYX_ERR(2, 3650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3662
 *         return GiacMethods['crossP'](self,*args)
 * 
 *      def cross_correlation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_correlation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_591cross_correlation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cross_correlati, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__320)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cross_correlation, __pyx_t_2) < 0) __PYX_ERR(2, 3662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3673
 *         return GiacMethods['cross_correlation'](self,*args)
 * 
 *      def cross_entropy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_entropy:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_593cross_entropy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cross_entropy, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__321)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cross_entropy, __pyx_t_2) < 0) __PYX_ERR(2, 3673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3683
 *         return GiacMethods['cross_entropy'](self,*args)
 * 
 *      def cross_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_595cross_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cross_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__322)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cross_point, __pyx_t_2) < 0) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3695
 *         return GiacMethods['cross_point'](self,*args)
 * 
 *      def cross_ratio(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cross_ratio:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_597cross_ratio, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cross_ratio, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__323)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cross_ratio, __pyx_t_2) < 0) __PYX_ERR(2, 3695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3708
 *         return GiacMethods['cross_ratio'](self,*args)
 * 
 *      def crossproduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for crossproduct:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_599crossproduct, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_crossproduct, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__324)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_crossproduct, __pyx_t_2) < 0) __PYX_ERR(2, 3708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3720
 *         return GiacMethods['crossproduct'](self,*args)
 * 
 *      def csc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_601csc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_csc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__325)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_csc, __pyx_t_2) < 0) __PYX_ERR(2, 3720, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3731
 *         return GiacMethods['csc'](self,*args)
 * 
 *      def csolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_603csolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_csolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__326)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_csolve, __pyx_t_2) < 0) __PYX_ERR(2, 3731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3745
 *         return GiacMethods['csolve'](self,*args)
 * 
 *      def csv2gen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for csv2gen:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_605csv2gen, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_csv2gen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__327)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_csv2gen, __pyx_t_2) < 0) __PYX_ERR(2, 3745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3756
 *         return GiacMethods['csv2gen'](self,*args)
 * 
 *      def cube(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cube:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_607cube, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cube, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__328)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cube, __pyx_t_2) < 0) __PYX_ERR(2, 3756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3771
 *         return GiacMethods['cube'](self,*args)
 * 
 *      def cumSum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumSum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_609cumSum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cumSum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__329)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cumSum, __pyx_t_2) < 0) __PYX_ERR(2, 3771, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3784
 *         return GiacMethods['cumSum'](self,*args)
 * 
 *      def cumsum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumsum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_611cumsum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cumsum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__330)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cumsum, __pyx_t_2) < 0) __PYX_ERR(2, 3784, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3797
 *         return GiacMethods['cumsum'](self,*args)
 * 
 *      def cumulated_frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cumulated_frequencies:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_613cumulated_frequencies, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cumulated_frequ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__331)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cumulated_frequencies, __pyx_t_2) < 0) __PYX_ERR(2, 3797, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3812
 *         return GiacMethods['cumulated_frequencies'](self,*args)
 * 
 *      def curl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curl:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_615curl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_curl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__332)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_curl, __pyx_t_2) < 0) __PYX_ERR(2, 3812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3823
 *         return GiacMethods['curl'](self,*args)
 * 
 *      def current_sheet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for current_sheet:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_617current_sheet, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_current_sheet, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__333)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_current_sheet, __pyx_t_2) < 0) __PYX_ERR(2, 3823, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3834
 *         return GiacMethods['current_sheet'](self,*args)
 * 
 *      def curvature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curvature:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_619curvature, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_curvature, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_curvature, __pyx_t_2) < 0) __PYX_ERR(2, 3834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3851
 *         return GiacMethods['curvature'](self,*args)
 * 
 *      def curve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for curve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_621curve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_curve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__335)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_curve, __pyx_t_2) < 0) __PYX_ERR(2, 3851, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3861
 *         return GiacMethods['curve'](self,*args)
 * 
 *      def cyan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_623cyan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cyan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cyan, __pyx_t_2) < 0) __PYX_ERR(2, 3861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3873
 *         return GiacMethods['cyan'](self,*args)
 * 
 *      def cycle2perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle2perm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_625cycle2perm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cycle2perm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__337)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cycle2perm, __pyx_t_2) < 0) __PYX_ERR(2, 3873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3884
 *         return GiacMethods['cycle2perm'](self,*args)
 * 
 *      def cycle_basis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_basis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_627cycle_basis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cycle_basis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__338)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cycle_basis, __pyx_t_2) < 0) __PYX_ERR(2, 3884, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3895
 *         return GiacMethods['cycle_basis'](self,*args)
 * 
 *      def cycle_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycle_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_629cycle_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cycle_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__339)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cycle_graph, __pyx_t_2) < 0) __PYX_ERR(2, 3895, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3907
 *         return GiacMethods['cycle_graph'](self,*args)
 * 
 *      def cycleinv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycleinv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_631cycleinv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cycleinv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__340)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cycleinv, __pyx_t_2) < 0) __PYX_ERR(2, 3907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3918
 *         return GiacMethods['cycleinv'](self,*args)
 * 
 *      def cycles2permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cycles2permu:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_633cycles2permu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cycles2permu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__341)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cycles2permu, __pyx_t_2) < 0) __PYX_ERR(2, 3918, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3929
 *         return GiacMethods['cycles2permu'](self,*args)
 * 
 *      def cyclotomic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cyclotomic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_635cyclotomic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cyclotomic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__342)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cyclotomic, __pyx_t_2) < 0) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3940
 *         return GiacMethods['cyclotomic'](self,*args)
 * 
 *      def cylinder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for cylinder:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_637cylinder, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_cylinder, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__343)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_cylinder, __pyx_t_2) < 0) __PYX_ERR(2, 3940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3952
 *         return GiacMethods['cylinder'](self,*args)
 * 
 *      def dash_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dash_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_639dash_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dash_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__344)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dash_line, __pyx_t_2) < 0) __PYX_ERR(2, 3952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3964
 *         return GiacMethods['dash_line'](self,*args)
 * 
 *      def dashdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdot_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_641dashdot_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dashdot_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__345)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dashdot_line, __pyx_t_2) < 0) __PYX_ERR(2, 3964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3976
 *         return GiacMethods['dashdot_line'](self,*args)
 * 
 *      def dashdotdot_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dashdotdot_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_643dashdotdot_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dashdotdot_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__346)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dashdotdot_line, __pyx_t_2) < 0) __PYX_ERR(2, 3976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3988
 *         return GiacMethods['dashdotdot_line'](self,*args)
 * 
 *      def dayofweek(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dayofweek:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_645dayofweek, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dayofweek, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__347)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dayofweek, __pyx_t_2) < 0) __PYX_ERR(2, 3988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":3999
 *         return GiacMethods['dayofweek'](self,*args)
 * 
 *      def deSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deSolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_647deSolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_deSolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__348)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_deSolve, __pyx_t_2) < 0) __PYX_ERR(2, 3999, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4025
 *         return GiacMethods['deSolve'](self,*args)
 * 
 *      def debut_enregistrement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for debut_enregistrement:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_649debut_enregistrement, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_debut_enregistr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__349)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_debut_enregistrement, __pyx_t_2) < 0) __PYX_ERR(2, 4025, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4037
 *         return GiacMethods['debut_enregistrement'](self,*args)
 * 
 *      def degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_651degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_degree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__350)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_degree, __pyx_t_2) < 0) __PYX_ERR(2, 4037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4050
 *         return GiacMethods['degree'](self,*args)
 * 
 *      def degree_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_centrality:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_653degree_centrality, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_degree_centrali, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__351)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_degree_centrality, __pyx_t_2) < 0) __PYX_ERR(2, 4050, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4061
 *         return GiacMethods['degree_centrality'](self,*args)
 * 
 *      def degree_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degree_sequence:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_655degree_sequence, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_degree_sequence, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__352)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_degree_sequence, __pyx_t_2) < 0) __PYX_ERR(2, 4061, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4072
 *         return GiacMethods['degree_sequence'](self,*args)
 * 
 *      def degrees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for degrees:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_657degrees, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_degrees, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__353)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_degrees, __pyx_t_2) < 0) __PYX_ERR(2, 4072, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4082
 *         return GiacMethods['degrees'](self,*args)
 * 
 *      def delcols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delcols:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_659delcols, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_delcols, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__354)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_delcols, __pyx_t_2) < 0) __PYX_ERR(2, 4082, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4095
 *         return GiacMethods['delcols'](self,*args)
 * 
 *      def delete_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_arc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_661delete_arc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_delete_arc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__355)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_delete_arc, __pyx_t_2) < 0) __PYX_ERR(2, 4095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4106
 *         return GiacMethods['delete_arc'](self,*args)
 * 
 *      def delete_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_edge:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_663delete_edge, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_delete_edge, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__356)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_delete_edge, __pyx_t_2) < 0) __PYX_ERR(2, 4106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4117
 *         return GiacMethods['delete_edge'](self,*args)
 * 
 *      def delete_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delete_vertex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_665delete_vertex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_delete_vertex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__357)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_delete_vertex, __pyx_t_2) < 0) __PYX_ERR(2, 4117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4128
 *         return GiacMethods['delete_vertex'](self,*args)
 * 
 *      def delrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for delrows:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_667delrows, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_delrows, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__358)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_delrows, __pyx_t_2) < 0) __PYX_ERR(2, 4128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4141
 *         return GiacMethods['delrows'](self,*args)
 * 
 *      def deltalist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deltalist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_669deltalist, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_deltalist, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__359)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_deltalist, __pyx_t_2) < 0) __PYX_ERR(2, 4141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4153
 *         return GiacMethods['deltalist'](self,*args)
 * 
 *      def denom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for denom:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_671denom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_denom, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__360)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_denom, __pyx_t_2) < 0) __PYX_ERR(2, 4153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4166
 *         return GiacMethods['denom'](self,*args)
 * 
 *      def densityplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for densityplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_673densityplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_densityplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__361)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_densityplot, __pyx_t_2) < 0) __PYX_ERR(2, 4166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4178
 *         return GiacMethods['densityplot'](self,*args)
 * 
 *      def departures(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for departures:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_675departures, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_departures, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__362)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_departures, __pyx_t_2) < 0) __PYX_ERR(2, 4178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4189
 *         return GiacMethods['departures'](self,*args)
 * 
 *      def derive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for derive:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_677derive, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_derive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__363)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_derive, __pyx_t_2) < 0) __PYX_ERR(2, 4189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4207
 *         return GiacMethods['derive'](self,*args)
 * 
 *      def deriver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for deriver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_679deriver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_deriver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_deriver, __pyx_t_2) < 0) __PYX_ERR(2, 4207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4225
 *         return GiacMethods['deriver'](self,*args)
 * 
 *      def desolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for desolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_681desolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_desolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__365)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_desolve, __pyx_t_2) < 0) __PYX_ERR(2, 4225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4251
 *         return GiacMethods['desolve'](self,*args)
 * 
 *      def dessine_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dessine_tortue:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_683dessine_tortue, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dessine_tortue, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dessine_tortue, __pyx_t_2) < 0) __PYX_ERR(2, 4251, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4264
 *         return GiacMethods['dessine_tortue'](self,*args)
 * 
 *      def det(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_685det, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_det, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__367)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_det, __pyx_t_2) < 0) __PYX_ERR(2, 4264, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4276
 *         return GiacMethods['det'](self,*args)
 * 
 *      def det_minor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for det_minor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_687det_minor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_det_minor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_det_minor, __pyx_t_2) < 0) __PYX_ERR(2, 4276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4287
 *         return GiacMethods['det_minor'](self,*args)
 * 
 *      def developper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_689developper, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_developper, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__369)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_developper, __pyx_t_2) < 0) __PYX_ERR(2, 4287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4302
 *         return GiacMethods['developper'](self,*args)
 * 
 *      def developper_transcendant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for developper_transcendant:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_691developper_transcendant, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_developper_tran, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__370)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_developper_transcendant, __pyx_t_2) < 0) __PYX_ERR(2, 4302, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4315
 *         return GiacMethods['developper_transcendant'](self,*args)
 * 
 *      def dfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_693dfc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dfc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dfc, __pyx_t_2) < 0) __PYX_ERR(2, 4315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4330
 *         return GiacMethods['dfc'](self,*args)
 * 
 *      def dfc2f(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dfc2f:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_695dfc2f, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dfc2f, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__372)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dfc2f, __pyx_t_2) < 0) __PYX_ERR(2, 4330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4342
 *         return GiacMethods['dfc2f'](self,*args)
 * 
 *      def diag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diag:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_697diag, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_diag, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__373)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_diag, __pyx_t_2) < 0) __PYX_ERR(2, 4342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4358
 *         return GiacMethods['diag'](self,*args)
 * 
 *      def diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for diff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_699diff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_diff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__374)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_diff, __pyx_t_2) < 0) __PYX_ERR(2, 4358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4376
 *         return GiacMethods['diff'](self,*args)
 * 
 *      def digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for digraph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_701digraph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_digraph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__375)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_digraph, __pyx_t_2) < 0) __PYX_ERR(2, 4376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4388
 *         return GiacMethods['digraph'](self,*args)
 * 
 *      def dijkstra(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dijkstra:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_703dijkstra, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dijkstra, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__376)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dijkstra, __pyx_t_2) < 0) __PYX_ERR(2, 4388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4399
 *         return GiacMethods['dijkstra'](self,*args)
 * 
 *      def dim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dim:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_705dim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__377)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dim, __pyx_t_2) < 0) __PYX_ERR(2, 4399, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4410
 *         return GiacMethods['dim'](self,*args)
 * 
 *      def directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for directed:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_707directed, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_directed, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__378)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_directed, __pyx_t_2) < 0) __PYX_ERR(2, 4410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4420
 *         return GiacMethods['directed'](self,*args)
 * 
 *      def discard_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_edge_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_709discard_edge_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_discard_edge_at, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__379)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_discard_edge_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 4420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4431
 *         return GiacMethods['discard_edge_attribute'](self,*args)
 * 
 *      def discard_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_graph_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_711discard_graph_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_discard_graph_a, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__380)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_discard_graph_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 4431, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4442
 *         return GiacMethods['discard_graph_attribute'](self,*args)
 * 
 *      def discard_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for discard_vertex_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_713discard_vertex_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_discard_vertex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__381)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_discard_vertex_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 4442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4453
 *         return GiacMethods['discard_vertex_attribute'](self,*args)
 * 
 *      def disjoint_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disjoint_union:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_715disjoint_union, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_disjoint_union, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__382)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_disjoint_union, __pyx_t_2) < 0) __PYX_ERR(2, 4453, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4464
 *         return GiacMethods['disjoint_union'](self,*args)
 * 
 *      def display(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for display:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_717display, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_display, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__383)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_display, __pyx_t_2) < 0) __PYX_ERR(2, 4464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4484
 *         return GiacMethods['display'](self,*args)
 * 
 *      def disque(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_719disque, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_disque, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__384)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_disque, __pyx_t_2) < 0) __PYX_ERR(2, 4484, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4498
 *         return GiacMethods['disque'](self,*args)
 * 
 *      def disque_centre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for disque_centre:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_721disque_centre, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_disque_centre, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__385)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_disque_centre, __pyx_t_2) < 0) __PYX_ERR(2, 4498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4512
 *         return GiacMethods['disque_centre'](self,*args)
 * 
 *      def distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_723distance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_distance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__386)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_distance, __pyx_t_2) < 0) __PYX_ERR(2, 4512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4525
 *         return GiacMethods['distance'](self,*args)
 * 
 *      def distance2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distance2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_725distance2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_distance2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__387)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_distance2, __pyx_t_2) < 0) __PYX_ERR(2, 4525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4538
 *         return GiacMethods['distance2'](self,*args)
 * 
 *      def distanceat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_727distanceat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_distanceat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__388)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_distanceat, __pyx_t_2) < 0) __PYX_ERR(2, 4538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4550
 *         return GiacMethods['distanceat'](self,*args)
 * 
 *      def distanceatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for distanceatraw:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_729distanceatraw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_distanceatraw, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__389)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_distanceatraw, __pyx_t_2) < 0) __PYX_ERR(2, 4550, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4562
 *         return GiacMethods['distanceatraw'](self,*args)
 * 
 *      def divergence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divergence:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_731divergence, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_divergence, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__390)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_divergence, __pyx_t_2) < 0) __PYX_ERR(2, 4562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4573
 *         return GiacMethods['divergence'](self,*args)
 * 
 *      def divide(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divide:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_733divide, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_divide, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__391)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_divide, __pyx_t_2) < 0) __PYX_ERR(2, 4573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4587
 *         return GiacMethods['divide'](self,*args)
 * 
 *      def divis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_735divis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_divis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__392)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_divis, __pyx_t_2) < 0) __PYX_ERR(2, 4587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4603
 *         return GiacMethods['divis'](self,*args)
 * 
 *      def division_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for division_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_737division_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_division_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__393)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_division_point, __pyx_t_2) < 0) __PYX_ERR(2, 4603, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4615
 *         return GiacMethods['division_point'](self,*args)
 * 
 *      def divisors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divisors:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_739divisors, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_divisors, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__394)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_divisors, __pyx_t_2) < 0) __PYX_ERR(2, 4615, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4627
 *         return GiacMethods['divisors'](self,*args)
 * 
 *      def divmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_741divmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_divmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__395)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_divmod, __pyx_t_2) < 0) __PYX_ERR(2, 4627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4640
 *         return GiacMethods['divmod'](self,*args)
 * 
 *      def divpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for divpc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_743divpc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_divpc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__396)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_divpc, __pyx_t_2) < 0) __PYX_ERR(2, 4640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4651
 *         return GiacMethods['divpc'](self,*args)
 * 
 *      def dnewton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dnewton_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_745dnewton_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dnewton_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__397)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dnewton_solver, __pyx_t_2) < 0) __PYX_ERR(2, 4651, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4667
 *         return GiacMethods['dnewton_solver'](self,*args)
 * 
 *      def dodecahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dodecahedron:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_747dodecahedron, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dodecahedron, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__398)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dodecahedron, __pyx_t_2) < 0) __PYX_ERR(2, 4667, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4679
 *         return GiacMethods['dodecahedron'](self,*args)
 * 
 *      def domain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for domain:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_749domain, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_domain, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__399)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_domain, __pyx_t_2) < 0) __PYX_ERR(2, 4679, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4690
 *         return GiacMethods['domain'](self,*args)
 * 
 *      def dot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_751dot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__400)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dot, __pyx_t_2) < 0) __PYX_ERR(2, 4690, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4703
 *         return GiacMethods['dot'](self,*args)
 * 
 *      def dotP(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotP:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_753dotP, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dotP, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__401)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dotP, __pyx_t_2) < 0) __PYX_ERR(2, 4703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4716
 *         return GiacMethods['dotP'](self,*args)
 * 
 *      def dot_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dot_paper:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_755dot_paper, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dot_paper, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__402)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dot_paper, __pyx_t_2) < 0) __PYX_ERR(2, 4716, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4728
 *         return GiacMethods['dot_paper'](self,*args)
 * 
 *      def dotprod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dotprod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_757dotprod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dotprod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__403)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dotprod, __pyx_t_2) < 0) __PYX_ERR(2, 4728, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4741
 *         return GiacMethods['dotprod'](self,*args)
 * 
 *      def draw_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_arc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_759draw_arc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_arc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__404)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_arc, __pyx_t_2) < 0) __PYX_ERR(2, 4741, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4752
 *         return GiacMethods['draw_arc'](self,*args)
 * 
 *      def draw_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_circle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_761draw_circle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_circle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__405)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_circle, __pyx_t_2) < 0) __PYX_ERR(2, 4752, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4764
 *         return GiacMethods['draw_circle'](self,*args)
 * 
 *      def draw_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_763draw_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__406)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_graph, __pyx_t_2) < 0) __PYX_ERR(2, 4764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4779
 *         return GiacMethods['draw_graph'](self,*args)
 * 
 *      def draw_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_765draw_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__407)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_line, __pyx_t_2) < 0) __PYX_ERR(2, 4779, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4790
 *         return GiacMethods['draw_line'](self,*args)
 * 
 *      def draw_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_pixel:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_767draw_pixel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_pixel, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__408)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_pixel, __pyx_t_2) < 0) __PYX_ERR(2, 4790, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4801
 *         return GiacMethods['draw_pixel'](self,*args)
 * 
 *      def draw_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_polygon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_769draw_polygon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_polygon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__409)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_polygon, __pyx_t_2) < 0) __PYX_ERR(2, 4801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4813
 *         return GiacMethods['draw_polygon'](self,*args)
 * 
 *      def draw_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for draw_rectangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_771draw_rectangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_draw_rectangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__410)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_draw_rectangle, __pyx_t_2) < 0) __PYX_ERR(2, 4813, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4825
 *         return GiacMethods['draw_rectangle'](self,*args)
 * 
 *      def droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_773droit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_droit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__411)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_droit, __pyx_t_2) < 0) __PYX_ERR(2, 4825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4839
 *         return GiacMethods['droit'](self,*args)
 * 
 *      def droite_tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for droite_tangente:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_775droite_tangente, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_droite_tangente, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__412)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_droite_tangente, __pyx_t_2) < 0) __PYX_ERR(2, 4839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4853
 *         return GiacMethods['droite_tangente'](self,*args)
 * 
 *      def dsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_777dsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__413)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dsolve, __pyx_t_2) < 0) __PYX_ERR(2, 4853, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4879
 *         return GiacMethods['dsolve'](self,*args)
 * 
 *      def duration(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for duration:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_779duration, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_duration, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__414)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_duration, __pyx_t_2) < 0) __PYX_ERR(2, 4879, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4890
 *         return GiacMethods['duration'](self,*args)
 * 
 *      def dwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for dwt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_781dwt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_dwt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__415)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_dwt, __pyx_t_2) < 0) __PYX_ERR(2, 4890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4902
 *         return GiacMethods['dwt'](self,*args)
 * 
 *      def e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_783e, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_e, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__416)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_e, __pyx_t_2) < 0) __PYX_ERR(2, 4902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4913
 *         return GiacMethods['e'](self,*args)
 * 
 *      def e2r(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for e2r:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_785e2r, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_e2r, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__417)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_e2r, __pyx_t_2) < 0) __PYX_ERR(2, 4913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4929
 *         return GiacMethods['e2r'](self,*args)
 * 
 *      def ecart_type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_787ecart_type, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ecart_type, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__418)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ecart_type, __pyx_t_2) < 0) __PYX_ERR(2, 4929, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4942
 *         return GiacMethods['ecart_type'](self,*args)
 * 
 *      def ecart_type_population(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecart_type_population:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_789ecart_type_population, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ecart_type_popu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__419)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ecart_type_population, __pyx_t_2) < 0) __PYX_ERR(2, 4942, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4955
 *         return GiacMethods['ecart_type_population'](self,*args)
 * 
 *      def ecef2geodetic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecef2geodetic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_791ecef2geodetic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ecef2geodetic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__420)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ecef2geodetic, __pyx_t_2) < 0) __PYX_ERR(2, 4955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4966
 *         return GiacMethods['ecef2geodetic'](self,*args)
 * 
 *      def ecm_factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ecm_factor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_793ecm_factor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ecm_factor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__421)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ecm_factor, __pyx_t_2) < 0) __PYX_ERR(2, 4966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4976
 *         return GiacMethods['ecm_factor'](self,*args)
 * 
 *      def edge_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edge_connectivity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_795edge_connectivity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_edge_connectivi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__422)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_edge_connectivity, __pyx_t_2) < 0) __PYX_ERR(2, 4976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":4989
 *         return GiacMethods['edge_connectivity'](self,*args)
 * 
 *      def edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for edges:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_797edges, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_edges, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__423)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_edges, __pyx_t_2) < 0) __PYX_ERR(2, 4989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5000
 *         return GiacMethods['edges'](self,*args)
 * 
 *      def egcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_799egcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_egcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__424)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_egcd, __pyx_t_2) < 0) __PYX_ERR(2, 5000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5014
 *         return GiacMethods['egcd'](self,*args)
 * 
 *      def egv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_801egv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_egv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__425)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_egv, __pyx_t_2) < 0) __PYX_ERR(2, 5014, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5026
 *         return GiacMethods['egv'](self,*args)
 * 
 *      def egvl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for egvl:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_803egvl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_egvl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__426)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_egvl, __pyx_t_2) < 0) __PYX_ERR(2, 5026, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5039
 *         return GiacMethods['egvl'](self,*args)
 * 
 *      def eigVc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_805eigVc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eigVc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__427)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eigVc, __pyx_t_2) < 0) __PYX_ERR(2, 5039, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5051
 *         return GiacMethods['eigVc'](self,*args)
 * 
 *      def eigVl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigVl:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_807eigVl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eigVl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__428)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eigVl, __pyx_t_2) < 0) __PYX_ERR(2, 5051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5064
 *         return GiacMethods['eigVl'](self,*args)
 * 
 *      def eigenvals(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvals:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_809eigenvals, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eigenvals, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__429)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eigenvals, __pyx_t_2) < 0) __PYX_ERR(2, 5064, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5077
 *         return GiacMethods['eigenvals'](self,*args)
 * 
 *      def eigenvalues(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvalues:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_811eigenvalues, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eigenvalues, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__430)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eigenvalues, __pyx_t_2) < 0) __PYX_ERR(2, 5077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5090
 *         return GiacMethods['eigenvalues'](self,*args)
 * 
 *      def eigenvectors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvectors:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_813eigenvectors, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eigenvectors, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eigenvectors, __pyx_t_2) < 0) __PYX_ERR(2, 5090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5102
 *         return GiacMethods['eigenvectors'](self,*args)
 * 
 *      def eigenvects(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eigenvects:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_815eigenvects, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eigenvects, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__432)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eigenvects, __pyx_t_2) < 0) __PYX_ERR(2, 5102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5114
 *         return GiacMethods['eigenvects'](self,*args)
 * 
 *      def element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for element:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_817element, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_element, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__433)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_element, __pyx_t_2) < 0) __PYX_ERR(2, 5114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5130
 *         return GiacMethods['element'](self,*args)
 * 
 *      def eliminate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eliminate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_819eliminate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eliminate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__434)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eliminate, __pyx_t_2) < 0) __PYX_ERR(2, 5130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5141
 *         return GiacMethods['eliminate'](self,*args)
 * 
 *      def ellipse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ellipse:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_821ellipse, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ellipse, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__435)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ellipse, __pyx_t_2) < 0) __PYX_ERR(2, 5141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5156
 *         return GiacMethods['ellipse'](self,*args)
 * 
 *      def emd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for emd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_823emd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_emd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__436)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_emd, __pyx_t_2) < 0) __PYX_ERR(2, 5156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5167
 *         return GiacMethods['emd'](self,*args)
 * 
 *      def entry(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for entry:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_825entry, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_entry, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__437)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_entry, __pyx_t_2) < 0) __PYX_ERR(2, 5167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5180
 *         return GiacMethods['entry'](self,*args)
 * 
 *      def envelope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for envelope:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_827envelope, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_envelope, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__438)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_envelope, __pyx_t_2) < 0) __PYX_ERR(2, 5180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5192
 *         return GiacMethods['envelope'](self,*args)
 * 
 *      def epsilon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_829epsilon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_epsilon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__439)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_epsilon, __pyx_t_2) < 0) __PYX_ERR(2, 5192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5203
 *         return GiacMethods['epsilon'](self,*args)
 * 
 *      def epsilon2zero(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for epsilon2zero:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_831epsilon2zero, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_epsilon2zero, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__440)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_epsilon2zero, __pyx_t_2) < 0) __PYX_ERR(2, 5203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5214
 *         return GiacMethods['epsilon2zero'](self,*args)
 * 
 *      def equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_833equal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_equal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__441)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_equal, __pyx_t_2) < 0) __PYX_ERR(2, 5214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5227
 *         return GiacMethods['equal'](self,*args)
 * 
 *      def equal2diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2diff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_835equal2diff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_equal2diff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__442)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_equal2diff, __pyx_t_2) < 0) __PYX_ERR(2, 5227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5239
 *         return GiacMethods['equal2diff'](self,*args)
 * 
 *      def equal2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equal2list:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_837equal2list, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_equal2list, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__443)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_equal2list, __pyx_t_2) < 0) __PYX_ERR(2, 5239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5251
 *         return GiacMethods['equal2list'](self,*args)
 * 
 *      def equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_839equation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_equation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__444)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_equation, __pyx_t_2) < 0) __PYX_ERR(2, 5251, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5262
 *         return GiacMethods['equation'](self,*args)
 * 
 *      def equilateral_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for equilateral_triangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_841equilateral_triangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_equilateral_tri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__445)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_equilateral_triangle, __pyx_t_2) < 0) __PYX_ERR(2, 5262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5276
 *         return GiacMethods['equilateral_triangle'](self,*args)
 * 
 *      def erf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_843erf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_erf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__446)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_erf, __pyx_t_2) < 0) __PYX_ERR(2, 5276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5288
 *         return GiacMethods['erf'](self,*args)
 * 
 *      def erfc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for erfc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_845erfc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_erfc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_erfc, __pyx_t_2) < 0) __PYX_ERR(2, 5288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5300
 *         return GiacMethods['erfc'](self,*args)
 * 
 *      def error(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for error:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_847error, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_error, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__448)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_error, __pyx_t_2) < 0) __PYX_ERR(2, 5300, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5312
 *         return GiacMethods['error'](self,*args)
 * 
 *      def est_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for est_permu:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_849est_permu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_est_permu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__449)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_est_permu, __pyx_t_2) < 0) __PYX_ERR(2, 5312, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5324
 *         return GiacMethods['est_permu'](self,*args)
 * 
 *      def euler(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_851euler, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_euler, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__450)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_euler, __pyx_t_2) < 0) __PYX_ERR(2, 5324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5336
 *         return GiacMethods['euler'](self,*args)
 * 
 *      def euler_gamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_gamma:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_853euler_gamma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_euler_gamma, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__451)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_euler_gamma, __pyx_t_2) < 0) __PYX_ERR(2, 5336, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5346
 *         return GiacMethods['euler_gamma'](self,*args)
 * 
 *      def euler_lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for euler_lagrange:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_855euler_lagrange, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_euler_lagrange, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__452)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_euler_lagrange, __pyx_t_2) < 0) __PYX_ERR(2, 5346, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5359
 *         return GiacMethods['euler_lagrange'](self,*args)
 * 
 *      def eval_level(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for eval_level:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_857eval_level, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_eval_level, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__453)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_eval_level, __pyx_t_2) < 0) __PYX_ERR(2, 5359, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5373
 *         return GiacMethods['eval_level'](self,*args)
 * 
 *      def evala(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evala:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_859evala, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_evala, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__454)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_evala, __pyx_t_2) < 0) __PYX_ERR(2, 5373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5386
 *         return GiacMethods['evala'](self,*args)
 * 
 *      def evalb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_861evalb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_evalb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__455)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_evalb, __pyx_t_2) < 0) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5398
 *         return GiacMethods['evalb'](self,*args)
 * 
 *      def evalc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_863evalc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_evalc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__456)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_evalc, __pyx_t_2) < 0) __PYX_ERR(2, 5398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5410
 *         return GiacMethods['evalc'](self,*args)
 * 
 *      def evalf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_865evalf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_evalf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__457)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_evalf, __pyx_t_2) < 0) __PYX_ERR(2, 5410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5426
 *         return GiacMethods['evalf'](self,*args)
 * 
 *      def evalm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evalm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_867evalm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_evalm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__458)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_evalm, __pyx_t_2) < 0) __PYX_ERR(2, 5426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5437
 *         return GiacMethods['evalm'](self,*args)
 * 
 *      def even(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for even:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_869even, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_even, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__459)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_even, __pyx_t_2) < 0) __PYX_ERR(2, 5437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5449
 *         return GiacMethods['even'](self,*args)
 * 
 *      def evolute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for evolute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_871evolute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_evolute, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__460)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_evolute, __pyx_t_2) < 0) __PYX_ERR(2, 5449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5462
 *         return GiacMethods['evolute'](self,*args)
 * 
 *      def exact(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exact:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_873exact, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exact, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__461)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exact, __pyx_t_2) < 0) __PYX_ERR(2, 5462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5476
 *         return GiacMethods['exact'](self,*args)
 * 
 *      def exbisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exbisector:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_875exbisector, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exbisector, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exbisector, __pyx_t_2) < 0) __PYX_ERR(2, 5476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5487
 *         return GiacMethods['exbisector'](self,*args)
 * 
 *      def excircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for excircle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_877excircle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_excircle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__463)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_excircle, __pyx_t_2) < 0) __PYX_ERR(2, 5487, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5498
 *         return GiacMethods['excircle'](self,*args)
 * 
 *      def execute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for execute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_879execute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_execute, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__464)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_execute, __pyx_t_2) < 0) __PYX_ERR(2, 5498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5512
 *         return GiacMethods['execute'](self,*args)
 * 
 *      def exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_881exp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__465)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exp, __pyx_t_2) < 0) __PYX_ERR(2, 5512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5524
 *         return GiacMethods['exp'](self,*args)
 * 
 *      def exp2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2list:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_883exp2list, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exp2list, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__466)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exp2list, __pyx_t_2) < 0) __PYX_ERR(2, 5524, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5536
 *         return GiacMethods['exp2list'](self,*args)
 * 
 *      def exp2pow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2pow:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_885exp2pow, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exp2pow, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__467)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exp2pow, __pyx_t_2) < 0) __PYX_ERR(2, 5536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5548
 *         return GiacMethods['exp2pow'](self,*args)
 * 
 *      def exp2trig(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exp2trig:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_887exp2trig, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exp2trig, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__468)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exp2trig, __pyx_t_2) < 0) __PYX_ERR(2, 5548, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5560
 *         return GiacMethods['exp2trig'](self,*args)
 * 
 *      def expand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_889expand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_expand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__469)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_expand, __pyx_t_2) < 0) __PYX_ERR(2, 5560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5575
 *         return GiacMethods['expand'](self,*args)
 * 
 *      def expexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expexpand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_891expexpand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_expexpand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__470)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_expexpand, __pyx_t_2) < 0) __PYX_ERR(2, 5575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5586
 *         return GiacMethods['expexpand'](self,*args)
 * 
 *      def expln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expln:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_893expln, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_expln, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__471)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_expln, __pyx_t_2) < 0) __PYX_ERR(2, 5586, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5597
 *         return GiacMethods['expln'](self,*args)
 * 
 *      def exponential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_895exponential, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponential, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__472)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponential, __pyx_t_2) < 0) __PYX_ERR(2, 5597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5611
 *         return GiacMethods['exponential'](self,*args)
 * 
 *      def exponential_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_897exponential_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponential_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__473)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponential_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 5611, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5623
 *         return GiacMethods['exponential_cdf'](self,*args)
 * 
 *      def exponential_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_899exponential_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponential_icd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__474)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponential_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 5623, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5635
 *         return GiacMethods['exponential_icdf'](self,*args)
 * 
 *      def exponential_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_901exponential_regression, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponential_reg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__475)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponential_regression, __pyx_t_2) < 0) __PYX_ERR(2, 5635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5647
 *         return GiacMethods['exponential_regression'](self,*args)
 * 
 *      def exponential_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponential_regression_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_903exponential_regression_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponential_reg_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__476)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponential_regression_plot, __pyx_t_2) < 0) __PYX_ERR(2, 5647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5659
 *         return GiacMethods['exponential_regression_plot'](self,*args)
 * 
 *      def exponentiald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_905exponentiald, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponentiald, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponentiald, __pyx_t_2) < 0) __PYX_ERR(2, 5659, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5673
 *         return GiacMethods['exponentiald'](self,*args)
 * 
 *      def exponentiald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_907exponentiald_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponentiald_cd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__478)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponentiald_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 5673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5685
 *         return GiacMethods['exponentiald_cdf'](self,*args)
 * 
 *      def exponentiald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for exponentiald_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_909exponentiald_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_exponentiald_ic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__479)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_exponentiald_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 5685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5697
 *         return GiacMethods['exponentiald_icdf'](self,*args)
 * 
 *      def export_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_911export_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_export_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__480)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_export_graph, __pyx_t_2) < 0) __PYX_ERR(2, 5697, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5708
 *         return GiacMethods['export_graph'](self,*args)
 * 
 *      def export_mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for export_mathml:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_913export_mathml, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_export_mathml, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__481)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_export_mathml, __pyx_t_2) < 0) __PYX_ERR(2, 5708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5721
 *         return GiacMethods['export_mathml'](self,*args)
 * 
 *      def expovariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expovariate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_915expovariate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_expovariate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__482)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_expovariate, __pyx_t_2) < 0) __PYX_ERR(2, 5721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5733
 *         return GiacMethods['expovariate'](self,*args)
 * 
 *      def expr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for expr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_917expr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_expr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__483)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_expr, __pyx_t_2) < 0) __PYX_ERR(2, 5733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5747
 *         return GiacMethods['expr'](self,*args)
 * 
 *      def extend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extend:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_919extend, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_extend, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__484)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_extend, __pyx_t_2) < 0) __PYX_ERR(2, 5747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5762
 *         return GiacMethods['extend'](self,*args)
 * 
 *      def extract_measure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extract_measure:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_921extract_measure, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_extract_measure, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__485)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_extract_measure, __pyx_t_2) < 0) __PYX_ERR(2, 5762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5775
 *         return GiacMethods['extract_measure'](self,*args)
 * 
 *      def extrema(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for extrema:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_923extrema, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_extrema, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__486)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_extrema, __pyx_t_2) < 0) __PYX_ERR(2, 5775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5791
 *         return GiacMethods['extrema'](self,*args)
 * 
 *      def ezgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ezgcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_925ezgcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ezgcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__487)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ezgcd, __pyx_t_2) < 0) __PYX_ERR(2, 5791, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5804
 *         return GiacMethods['ezgcd'](self,*args)
 * 
 *      def f2nd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for f2nd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_927f2nd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_f2nd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__488)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_f2nd, __pyx_t_2) < 0) __PYX_ERR(2, 5804, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5816
 *         return GiacMethods['f2nd'](self,*args)
 * 
 *      def fMax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMax:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_929fMax, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fMax, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__489)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fMax, __pyx_t_2) < 0) __PYX_ERR(2, 5816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5828
 *         return GiacMethods['fMax'](self,*args)
 * 
 *      def fMin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fMin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_931fMin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fMin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__490)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fMin, __pyx_t_2) < 0) __PYX_ERR(2, 5828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5842
 *         return GiacMethods['fMin'](self,*args)
 * 
 *      def fPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fPart:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_933fPart, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fPart, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__491)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fPart, __pyx_t_2) < 0) __PYX_ERR(2, 5842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5857
 *         return GiacMethods['fPart'](self,*args)
 * 
 *      def faces(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for faces:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_935faces, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_faces, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__492)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_faces, __pyx_t_2) < 0) __PYX_ERR(2, 5857, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5869
 *         return GiacMethods['faces'](self,*args)
 * 
 *      def facteurs_premiers(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for facteurs_premiers:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_937facteurs_premiers, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_facteurs_premie, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__493)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_facteurs_premiers, __pyx_t_2) < 0) __PYX_ERR(2, 5869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5881
 *         return GiacMethods['facteurs_premiers'](self,*args)
 * 
 *      def factor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_939factor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__494)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factor, __pyx_t_2) < 0) __PYX_ERR(2, 5881, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5894
 *         return GiacMethods['factor'](self,*args)
 * 
 *      def factor_xn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factor_xn:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_941factor_xn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factor_xn, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__495)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factor_xn, __pyx_t_2) < 0) __PYX_ERR(2, 5894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5906
 *         return GiacMethods['factor_xn'](self,*args)
 * 
 *      def factorial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factorial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_943factorial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factorial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__496)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factorial, __pyx_t_2) < 0) __PYX_ERR(2, 5906, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5918
 *         return GiacMethods['factorial'](self,*args)
 * 
 *      def factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_945factoriser, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factoriser, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__497)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factoriser, __pyx_t_2) < 0) __PYX_ERR(2, 5918, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5931
 *         return GiacMethods['factoriser'](self,*args)
 * 
 *      def factoriser_entier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_entier:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_947factoriser_entier, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factoriser_enti, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__498)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factoriser_entier, __pyx_t_2) < 0) __PYX_ERR(2, 5931, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5943
 *         return GiacMethods['factoriser_entier'](self,*args)
 * 
 *      def factoriser_sur_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factoriser_sur_C:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_949factoriser_sur_C, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factoriser_sur, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__499)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factoriser_sur_C, __pyx_t_2) < 0) __PYX_ERR(2, 5943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5956
 *         return GiacMethods['factoriser_sur_C'](self,*args)
 * 
 *      def factors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for factors:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_951factors, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_factors, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__500)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_factors, __pyx_t_2) < 0) __PYX_ERR(2, 5956, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5968
 *         return GiacMethods['factors'](self,*args)
 * 
 *      def fadeev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fadeev:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_953fadeev, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fadeev, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__501)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fadeev, __pyx_t_2) < 0) __PYX_ERR(2, 5968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5979
 *         return GiacMethods['fadeev'](self,*args)
 * 
 *      def false(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for false:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_955false, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_false, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__502)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_false, __pyx_t_2) < 0) __PYX_ERR(2, 5979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":5990
 *         return GiacMethods['false'](self,*args)
 * 
 *      def falsepos_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for falsepos_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_957falsepos_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_falsepos_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__503)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_falsepos_solver, __pyx_t_2) < 0) __PYX_ERR(2, 5990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6006
 *         return GiacMethods['falsepos_solver'](self,*args)
 * 
 *      def fclose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fclose:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_959fclose, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fclose, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__504)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fclose, __pyx_t_2) < 0) __PYX_ERR(2, 6006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6017
 *         return GiacMethods['fclose'](self,*args)
 * 
 *      def fcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fcoeff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_961fcoeff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fcoeff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__505)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fcoeff, __pyx_t_2) < 0) __PYX_ERR(2, 6017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6028
 *         return GiacMethods['fcoeff'](self,*args)
 * 
 *      def fdistrib(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fdistrib:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_963fdistrib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fdistrib, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__506)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fdistrib, __pyx_t_2) < 0) __PYX_ERR(2, 6028, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6043
 *         return GiacMethods['fdistrib'](self,*args)
 * 
 *      def fft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fft:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_965fft, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fft, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__507)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fft, __pyx_t_2) < 0) __PYX_ERR(2, 6043, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6055
 *         return GiacMethods['fft'](self,*args)
 * 
 *      def fieldplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fieldplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_967fieldplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fieldplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__508)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fieldplot, __pyx_t_2) < 0) __PYX_ERR(2, 6055, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6070
 *         return GiacMethods['fieldplot'](self,*args)
 * 
 *      def find(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_969find, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_find, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__509)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_find, __pyx_t_2) < 0) __PYX_ERR(2, 6070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6085
 *         return GiacMethods['find'](self,*args)
 * 
 *      def find_cliques(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cliques:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_971find_cliques, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_find_cliques, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__510)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_find_cliques, __pyx_t_2) < 0) __PYX_ERR(2, 6085, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6098
 *         return GiacMethods['find_cliques'](self,*args)
 * 
 *      def find_cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_cycles:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_973find_cycles, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_find_cycles, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__511)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_find_cycles, __pyx_t_2) < 0) __PYX_ERR(2, 6098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6111
 *         return GiacMethods['find_cycles'](self,*args)
 * 
 *      def find_minimum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_minimum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_975find_minimum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_find_minimum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__512)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_find_minimum, __pyx_t_2) < 0) __PYX_ERR(2, 6111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6125
 *         return GiacMethods['find_minimum'](self,*args)
 * 
 *      def find_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for find_vertex_cover:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_977find_vertex_cover, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_find_vertex_cov, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__513)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_find_vertex_cover, __pyx_t_2) < 0) __PYX_ERR(2, 6125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6137
 *         return GiacMethods['find_vertex_cover'](self,*args)
 * 
 *      def findhelp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for findhelp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_979findhelp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_findhelp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__514)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_findhelp, __pyx_t_2) < 0) __PYX_ERR(2, 6137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6148
 *         return GiacMethods['findhelp'](self,*args)
 * 
 *      def fisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_981fisher, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fisher, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__515)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fisher, __pyx_t_2) < 0) __PYX_ERR(2, 6148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6162
 *         return GiacMethods['fisher'](self,*args)
 * 
 *      def fisher_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_983fisher_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fisher_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__516)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fisher_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 6162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6174
 *         return GiacMethods['fisher_cdf'](self,*args)
 * 
 *      def fisher_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisher_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_985fisher_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fisher_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__517)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fisher_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 6174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6186
 *         return GiacMethods['fisher_icdf'](self,*args)
 * 
 *      def fisherd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_987fisherd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fisherd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__518)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fisherd, __pyx_t_2) < 0) __PYX_ERR(2, 6186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6200
 *         return GiacMethods['fisherd'](self,*args)
 * 
 *      def fisherd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_989fisherd_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fisherd_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__519)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fisherd_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 6200, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6212
 *         return GiacMethods['fisherd_cdf'](self,*args)
 * 
 *      def fisherd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fisherd_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_991fisherd_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fisherd_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__520)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fisherd_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 6212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6224
 *         return GiacMethods['fisherd_icdf'](self,*args)
 * 
 *      def fitdistr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitdistr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_993fitdistr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fitdistr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__521)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fitdistr, __pyx_t_2) < 0) __PYX_ERR(2, 6224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6237
 *         return GiacMethods['fitdistr'](self,*args)
 * 
 *      def fitpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitpoly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_995fitpoly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fitpoly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__522)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fitpoly, __pyx_t_2) < 0) __PYX_ERR(2, 6237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6249
 *         return GiacMethods['fitpoly'](self,*args)
 * 
 *      def fitspline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fitspline:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_997fitspline, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fitspline, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__523)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fitspline, __pyx_t_2) < 0) __PYX_ERR(2, 6249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6260
 *         return GiacMethods['fitspline'](self,*args)
 * 
 *      def flatten(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flatten:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_999flatten, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_flatten, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__524)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_flatten, __pyx_t_2) < 0) __PYX_ERR(2, 6260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6271
 *         return GiacMethods['flatten'](self,*args)
 * 
 *      def float2rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for float2rational:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1001float2rational, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_float2rational, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__525)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_float2rational, __pyx_t_2) < 0) __PYX_ERR(2, 6271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6285
 *         return GiacMethods['float2rational'](self,*args)
 * 
 *      def floor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for floor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1003floor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_floor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__526)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_floor, __pyx_t_2) < 0) __PYX_ERR(2, 6285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6297
 *         return GiacMethods['floor'](self,*args)
 * 
 *      def flow_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flow_polynomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1005flow_polynomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_flow_polynomial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__527)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_flow_polynomial, __pyx_t_2) < 0) __PYX_ERR(2, 6297, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6309
 *         return GiacMethods['flow_polynomial'](self,*args)
 * 
 *      def flower_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for flower_snark:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1007flower_snark, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_flower_snark, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__528)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_flower_snark, __pyx_t_2) < 0) __PYX_ERR(2, 6309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6320
 *         return GiacMethods['flower_snark'](self,*args)
 * 
 *      def fmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1009fmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__529)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fmod, __pyx_t_2) < 0) __PYX_ERR(2, 6320, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6331
 *         return GiacMethods['fmod'](self,*args)
 * 
 *      def foldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldl:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1011foldl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_foldl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__530)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_foldl, __pyx_t_2) < 0) __PYX_ERR(2, 6331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6342
 *         return GiacMethods['foldl'](self,*args)
 * 
 *      def foldr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for foldr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1013foldr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_foldr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__531)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_foldr, __pyx_t_2) < 0) __PYX_ERR(2, 6342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6353
 *         return GiacMethods['foldr'](self,*args)
 * 
 *      def fonction_derivee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fonction_derivee:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1015fonction_derivee, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fonction_derive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__532)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fonction_derivee, __pyx_t_2) < 0) __PYX_ERR(2, 6353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6368
 *         return GiacMethods['fonction_derivee'](self,*args)
 * 
 *      def forward(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for forward:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1017forward, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_forward, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__533)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_forward, __pyx_t_2) < 0) __PYX_ERR(2, 6368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6380
 *         return GiacMethods['forward'](self,*args)
 * 
 *      def fourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1019fourier, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fourier, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__534)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fourier, __pyx_t_2) < 0) __PYX_ERR(2, 6380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6397
 *         return GiacMethods['fourier'](self,*args)
 * 
 *      def fourier_an(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_an:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1021fourier_an, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fourier_an, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__535)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fourier_an, __pyx_t_2) < 0) __PYX_ERR(2, 6397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6409
 *         return GiacMethods['fourier_an'](self,*args)
 * 
 *      def fourier_bn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_bn:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1023fourier_bn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fourier_bn, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__536)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fourier_bn, __pyx_t_2) < 0) __PYX_ERR(2, 6409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6421
 *         return GiacMethods['fourier_bn'](self,*args)
 * 
 *      def fourier_cn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fourier_cn:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1025fourier_cn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fourier_cn, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__537)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fourier_cn, __pyx_t_2) < 0) __PYX_ERR(2, 6421, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6433
 *         return GiacMethods['fourier_cn'](self,*args)
 * 
 *      def fprint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fprint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1027fprint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fprint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__538)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fprint, __pyx_t_2) < 0) __PYX_ERR(2, 6433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6446
 *         return GiacMethods['fprint'](self,*args)
 * 
 *      def frac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1029frac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_frac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__539)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_frac, __pyx_t_2) < 0) __PYX_ERR(2, 6446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6461
 *         return GiacMethods['frac'](self,*args)
 * 
 *      def fracmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fracmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1031fracmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fracmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__540)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fracmod, __pyx_t_2) < 0) __PYX_ERR(2, 6461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6472
 *         return GiacMethods['fracmod'](self,*args)
 * 
 *      def frame_2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frame_2d:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1033frame_2d, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_frame_2d, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__541)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_frame_2d, __pyx_t_2) < 0) __PYX_ERR(2, 6472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6483
 *         return GiacMethods['frame_2d'](self,*args)
 * 
 *      def frank_wolfe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frank_wolfe:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1035frank_wolfe, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_frank_wolfe, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__542)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_frank_wolfe, __pyx_t_2) < 0) __PYX_ERR(2, 6483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6494
 *         return GiacMethods['frank_wolfe'](self,*args)
 * 
 *      def frequencies(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frequencies:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1037frequencies, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_frequencies, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__543)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_frequencies, __pyx_t_2) < 0) __PYX_ERR(2, 6494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6506
 *         return GiacMethods['frequencies'](self,*args)
 * 
 *      def frobenius_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for frobenius_norm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1039frobenius_norm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_frobenius_norm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__544)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_frobenius_norm, __pyx_t_2) < 0) __PYX_ERR(2, 6506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6517
 *         return GiacMethods['frobenius_norm'](self,*args)
 * 
 *      def froot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for froot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1041froot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_froot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__545)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_froot, __pyx_t_2) < 0) __PYX_ERR(2, 6517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6529
 *         return GiacMethods['froot'](self,*args)
 * 
 *      def fsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1043fsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__546)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fsolve, __pyx_t_2) < 0) __PYX_ERR(2, 6529, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6543
 *         return GiacMethods['fsolve'](self,*args)
 * 
 *      def fullparfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fullparfrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1045fullparfrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fullparfrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__547)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fullparfrac, __pyx_t_2) < 0) __PYX_ERR(2, 6543, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6555
 *         return GiacMethods['fullparfrac'](self,*args)
 * 
 *      def funcplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for funcplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1047funcplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_funcplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__548)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_funcplot, __pyx_t_2) < 0) __PYX_ERR(2, 6555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6570
 *         return GiacMethods['funcplot'](self,*args)
 * 
 *      def function_diff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for function_diff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1049function_diff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_function_diff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__549)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_function_diff, __pyx_t_2) < 0) __PYX_ERR(2, 6570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6585
 *         return GiacMethods['function_diff'](self,*args)
 * 
 *      def fundamental_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fundamental_cycle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1051fundamental_cycle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fundamental_cyc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__550)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fundamental_cycle, __pyx_t_2) < 0) __PYX_ERR(2, 6585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6596
 *         return GiacMethods['fundamental_cycle'](self,*args)
 * 
 *      def fxnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for fxnd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1053fxnd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_fxnd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__551)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_fxnd, __pyx_t_2) < 0) __PYX_ERR(2, 6596, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6608
 *         return GiacMethods['fxnd'](self,*args)
 * 
 *      def gammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1055gammad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gammad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__552)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gammad, __pyx_t_2) < 0) __PYX_ERR(2, 6608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6619
 *         return GiacMethods['gammad'](self,*args)
 * 
 *      def gammad_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1057gammad_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gammad_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__553)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gammad_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 6619, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6631
 *         return GiacMethods['gammad_cdf'](self,*args)
 * 
 *      def gammad_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammad_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1059gammad_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gammad_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__554)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gammad_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 6631, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6643
 *         return GiacMethods['gammad_icdf'](self,*args)
 * 
 *      def gammavariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gammavariate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1061gammavariate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gammavariate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__555)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gammavariate, __pyx_t_2) < 0) __PYX_ERR(2, 6643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6655
 *         return GiacMethods['gammavariate'](self,*args)
 * 
 *      def gauss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1063gauss, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gauss, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__556)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gauss, __pyx_t_2) < 0) __PYX_ERR(2, 6655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6666
 *         return GiacMethods['gauss'](self,*args)
 * 
 *      def gauss15(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss15:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1065gauss15, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gauss15, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__557)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gauss15, __pyx_t_2) < 0) __PYX_ERR(2, 6666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6680
 *         return GiacMethods['gauss15'](self,*args)
 * 
 *      def gauss_seidel_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gauss_seidel_linsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1067gauss_seidel_linsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gauss_seidel_li, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__558)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gauss_seidel_linsolve, __pyx_t_2) < 0) __PYX_ERR(2, 6680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6694
 *         return GiacMethods['gauss_seidel_linsolve'](self,*args)
 * 
 *      def gaussian_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussian_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1069gaussian_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gaussian_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__559)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gaussian_window, __pyx_t_2) < 0) __PYX_ERR(2, 6694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6705
 *         return GiacMethods['gaussian_window'](self,*args)
 * 
 *      def gaussjord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussjord:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1071gaussjord, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gaussjord, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__560)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gaussjord, __pyx_t_2) < 0) __PYX_ERR(2, 6705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6719
 *         return GiacMethods['gaussjord'](self,*args)
 * 
 *      def gaussquad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gaussquad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1073gaussquad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gaussquad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__561)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gaussquad, __pyx_t_2) < 0) __PYX_ERR(2, 6719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6732
 *         return GiacMethods['gaussquad'](self,*args)
 * 
 *      def gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1075gbasis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gbasis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__562)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gbasis, __pyx_t_2) < 0) __PYX_ERR(2, 6732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6748
 *         return GiacMethods['gbasis'](self,*args)
 * 
 *      def gbasis_max_pairs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_max_pairs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1077gbasis_max_pairs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gbasis_max_pair, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__563)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gbasis_max_pairs, __pyx_t_2) < 0) __PYX_ERR(2, 6748, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6760
 *         return GiacMethods['gbasis_max_pairs'](self,*args)
 * 
 *      def gbasis_reinject(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_reinject:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1079gbasis_reinject, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gbasis_reinject, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__564)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gbasis_reinject, __pyx_t_2) < 0) __PYX_ERR(2, 6760, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6772
 *         return GiacMethods['gbasis_reinject'](self,*args)
 * 
 *      def gbasis_simult_primes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gbasis_simult_primes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1081gbasis_simult_primes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gbasis_simult_p, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__565)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gbasis_simult_primes, __pyx_t_2) < 0) __PYX_ERR(2, 6772, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6783
 *         return GiacMethods['gbasis_simult_primes'](self,*args)
 * 
 *      def gcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1083gcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__566)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gcd, __pyx_t_2) < 0) __PYX_ERR(2, 6783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6798
 *         return GiacMethods['gcd'](self,*args)
 * 
 *      def gcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gcdex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1085gcdex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gcdex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__567)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gcdex, __pyx_t_2) < 0) __PYX_ERR(2, 6798, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6812
 *         return GiacMethods['gcdex'](self,*args)
 * 
 *      def genpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for genpoly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1087genpoly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_genpoly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__568)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_genpoly, __pyx_t_2) < 0) __PYX_ERR(2, 6812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6825
 *         return GiacMethods['genpoly'](self,*args)
 * 
 *      def geodetic2ecef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geodetic2ecef:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1089geodetic2ecef, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_geodetic2ecef, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__569)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_geodetic2ecef, __pyx_t_2) < 0) __PYX_ERR(2, 6825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6836
 *         return GiacMethods['geodetic2ecef'](self,*args)
 * 
 *      def geometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1091geometric, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_geometric, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__570)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_geometric, __pyx_t_2) < 0) __PYX_ERR(2, 6836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6850
 *         return GiacMethods['geometric'](self,*args)
 * 
 *      def geometric_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1093geometric_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_geometric_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__571)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_geometric_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 6850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6862
 *         return GiacMethods['geometric_cdf'](self,*args)
 * 
 *      def geometric_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for geometric_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1095geometric_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_geometric_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__572)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_geometric_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 6862, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6873
 *         return GiacMethods['geometric_icdf'](self,*args)
 * 
 *      def getDenom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getDenom:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1097getDenom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_getDenom, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__573)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_getDenom, __pyx_t_2) < 0) __PYX_ERR(2, 6873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6886
 *         return GiacMethods['getDenom'](self,*args)
 * 
 *      def getKey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getKey:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1099getKey, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_getKey, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__574)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_getKey, __pyx_t_2) < 0) __PYX_ERR(2, 6886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6897
 *         return GiacMethods['getKey'](self,*args)
 * 
 *      def getNum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getNum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1101getNum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_getNum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__575)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_getNum, __pyx_t_2) < 0) __PYX_ERR(2, 6897, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6910
 *         return GiacMethods['getNum'](self,*args)
 * 
 *      def getType(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for getType:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1103getType, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_getType, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__576)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_getType, __pyx_t_2) < 0) __PYX_ERR(2, 6910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6924
 *         return GiacMethods['getType'](self,*args)
 * 
 *      def get_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1105get_edge_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_get_edge_attrib, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__577)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_get_edge_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 6924, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6935
 *         return GiacMethods['get_edge_attribute'](self,*args)
 * 
 *      def get_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_edge_weight:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1107get_edge_weight, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_get_edge_weight, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__578)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_get_edge_weight, __pyx_t_2) < 0) __PYX_ERR(2, 6935, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6946
 *         return GiacMethods['get_edge_weight'](self,*args)
 * 
 *      def get_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_graph_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1109get_graph_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_get_graph_attri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__579)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_get_graph_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 6946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6957
 *         return GiacMethods['get_graph_attribute'](self,*args)
 * 
 *      def get_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for get_vertex_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1111get_vertex_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_get_vertex_attr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__580)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_get_vertex_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 6957, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6968
 *         return GiacMethods['get_vertex_attribute'](self,*args)
 * 
 *      def girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for girth:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1113girth, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_girth, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__581)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_girth, __pyx_t_2) < 0) __PYX_ERR(2, 6968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6980
 *         return GiacMethods['girth'](self,*args)
 * 
 *      def gl_showaxes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gl_showaxes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1115gl_showaxes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gl_showaxes, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__582)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gl_showaxes, __pyx_t_2) < 0) __PYX_ERR(2, 6980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":6992
 *         return GiacMethods['gl_showaxes'](self,*args)
 * 
 *      def gold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gold:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1117gold, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gold, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__583)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gold, __pyx_t_2) < 0) __PYX_ERR(2, 6992, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7004
 *         return GiacMethods['gold'](self,*args)
 * 
 *      def goldberg_snark(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for goldberg_snark:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1119goldberg_snark, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_goldberg_snark, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__584)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_goldberg_snark, __pyx_t_2) < 0) __PYX_ERR(2, 7004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7015
 *         return GiacMethods['goldberg_snark'](self,*args)
 * 
 *      def grad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1121grad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_grad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__585)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_grad, __pyx_t_2) < 0) __PYX_ERR(2, 7015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7026
 *         return GiacMethods['grad'](self,*args)
 * 
 *      def gramschmidt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for gramschmidt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1123gramschmidt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_gramschmidt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__586)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_gramschmidt, __pyx_t_2) < 0) __PYX_ERR(2, 7026, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7038
 *         return GiacMethods['gramschmidt'](self,*args)
 * 
 *      def graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1125graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__587)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph, __pyx_t_2) < 0) __PYX_ERR(2, 7038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7055
 *         return GiacMethods['graph'](self,*args)
 * 
 *      def graph_automorphisms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_automorphisms:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1127graph_automorphisms, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_automorph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__588)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_automorphisms, __pyx_t_2) < 0) __PYX_ERR(2, 7055, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7066
 *         return GiacMethods['graph_automorphisms'](self,*args)
 * 
 *      def graph_charpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_charpoly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1129graph_charpoly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_charpoly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__589)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_charpoly, __pyx_t_2) < 0) __PYX_ERR(2, 7066, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7078
 *         return GiacMethods['graph_charpoly'](self,*args)
 * 
 *      def graph_complement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_complement:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1131graph_complement, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_complemen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__590)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_complement, __pyx_t_2) < 0) __PYX_ERR(2, 7078, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7089
 *         return GiacMethods['graph_complement'](self,*args)
 * 
 *      def graph_diameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_diameter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1133graph_diameter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_diameter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__591)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_diameter, __pyx_t_2) < 0) __PYX_ERR(2, 7089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7100
 *         return GiacMethods['graph_diameter'](self,*args)
 * 
 *      def graph_equal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_equal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1135graph_equal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_equal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__592)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_equal, __pyx_t_2) < 0) __PYX_ERR(2, 7100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7111
 *         return GiacMethods['graph_equal'](self,*args)
 * 
 *      def graph_join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_join:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1137graph_join, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_join, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__593)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_join, __pyx_t_2) < 0) __PYX_ERR(2, 7111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7122
 *         return GiacMethods['graph_join'](self,*args)
 * 
 *      def graph_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_power:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1139graph_power, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_power, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__594)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_power, __pyx_t_2) < 0) __PYX_ERR(2, 7122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7133
 *         return GiacMethods['graph_power'](self,*args)
 * 
 *      def graph_rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_rank:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1141graph_rank, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_rank, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__595)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_rank, __pyx_t_2) < 0) __PYX_ERR(2, 7133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7145
 *         return GiacMethods['graph_rank'](self,*args)
 * 
 *      def graph_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_spectrum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1143graph_spectrum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_spectrum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__596)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_spectrum, __pyx_t_2) < 0) __PYX_ERR(2, 7145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7156
 *         return GiacMethods['graph_spectrum'](self,*args)
 * 
 *      def graph_union(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_union:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1145graph_union, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_union, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__597)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_union, __pyx_t_2) < 0) __PYX_ERR(2, 7156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7167
 *         return GiacMethods['graph_union'](self,*args)
 * 
 *      def graph_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for graph_vertices:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1147graph_vertices, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_graph_vertices, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__598)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_graph_vertices, __pyx_t_2) < 0) __PYX_ERR(2, 7167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7178
 *         return GiacMethods['graph_vertices'](self,*args)
 * 
 *      def greduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greduce:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1149greduce, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_greduce, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__599)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_greduce, __pyx_t_2) < 0) __PYX_ERR(2, 7178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7192
 *         return GiacMethods['greduce'](self,*args)
 * 
 *      def greedy_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_clique:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1151greedy_clique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_greedy_clique, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__600)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_greedy_clique, __pyx_t_2) < 0) __PYX_ERR(2, 7192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7203
 *         return GiacMethods['greedy_clique'](self,*args)
 * 
 *      def greedy_color(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_color:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1153greedy_color, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_greedy_color, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__601)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_greedy_color, __pyx_t_2) < 0) __PYX_ERR(2, 7203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7214
 *         return GiacMethods['greedy_color'](self,*args)
 * 
 *      def greedy_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for greedy_independent_set:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1155greedy_independent_set, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_greedy_independ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__602)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_greedy_independent_set, __pyx_t_2) < 0) __PYX_ERR(2, 7214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7225
 *         return GiacMethods['greedy_independent_set'](self,*args)
 * 
 *      def grey(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grey:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1157grey, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_grey, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__603)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_grey, __pyx_t_2) < 0) __PYX_ERR(2, 7225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7237
 *         return GiacMethods['grey'](self,*args)
 * 
 *      def grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for grid_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1159grid_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_grid_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__604)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_grid_graph, __pyx_t_2) < 0) __PYX_ERR(2, 7237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7248
 *         return GiacMethods['grid_graph'](self,*args)
 * 
 *      def groupermu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for groupermu:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1161groupermu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_groupermu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__605)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_groupermu, __pyx_t_2) < 0) __PYX_ERR(2, 7248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7259
 *         return GiacMethods['groupermu'](self,*args)
 * 
 *      def haar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for haar_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1163haar_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_haar_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__606)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_haar_graph, __pyx_t_2) < 0) __PYX_ERR(2, 7259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7271
 *         return GiacMethods['haar_graph'](self,*args)
 * 
 *      def hadamard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hadamard:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1165hadamard, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hadamard, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__607)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hadamard, __pyx_t_2) < 0) __PYX_ERR(2, 7271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7283
 *         return GiacMethods['hadamard'](self,*args)
 * 
 *      def half_cone(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_cone:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1167half_cone, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_half_cone, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__608)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_half_cone, __pyx_t_2) < 0) __PYX_ERR(2, 7283, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7295
 *         return GiacMethods['half_cone'](self,*args)
 * 
 *      def half_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for half_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1169half_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_half_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__609)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_half_line, __pyx_t_2) < 0) __PYX_ERR(2, 7295, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7307
 *         return GiacMethods['half_line'](self,*args)
 * 
 *      def halftan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1171halftan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_halftan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__610)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_halftan, __pyx_t_2) < 0) __PYX_ERR(2, 7307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7319
 *         return GiacMethods['halftan'](self,*args)
 * 
 *      def halftan_hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halftan_hyp2exp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1173halftan_hyp2exp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_halftan_hyp2exp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__611)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_halftan_hyp2exp, __pyx_t_2) < 0) __PYX_ERR(2, 7319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7330
 *         return GiacMethods['halftan_hyp2exp'](self,*args)
 * 
 *      def halt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for halt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1175halt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_halt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__612)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_halt, __pyx_t_2) < 0) __PYX_ERR(2, 7330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7341
 *         return GiacMethods['halt'](self,*args)
 * 
 *      def hamdist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamdist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1177hamdist, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hamdist, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__613)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hamdist, __pyx_t_2) < 0) __PYX_ERR(2, 7341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7351
 *         return GiacMethods['hamdist'](self,*args)
 * 
 *      def hamming(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1179hamming, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hamming, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__614)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hamming, __pyx_t_2) < 0) __PYX_ERR(2, 7351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7362
 *         return GiacMethods['hamming'](self,*args)
 * 
 *      def hamming_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hamming_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1181hamming_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hamming_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__615)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hamming_window, __pyx_t_2) < 0) __PYX_ERR(2, 7362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7373
 *         return GiacMethods['hamming_window'](self,*args)
 * 
 *      def hann_poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_poisson_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1183hann_poisson_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hann_poisson_wi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__616)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hann_poisson_window, __pyx_t_2) < 0) __PYX_ERR(2, 7373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7384
 *         return GiacMethods['hann_poisson_window'](self,*args)
 * 
 *      def hann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hann_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1185hann_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hann_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__617)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hann_window, __pyx_t_2) < 0) __PYX_ERR(2, 7384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7395
 *         return GiacMethods['hann_window'](self,*args)
 * 
 *      def harmonic_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_centrality:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1187harmonic_centrality, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_harmonic_centra, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__618)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_harmonic_centrality, __pyx_t_2) < 0) __PYX_ERR(2, 7395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7406
 *         return GiacMethods['harmonic_centrality'](self,*args)
 * 
 *      def harmonic_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_conjugate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1189harmonic_conjugate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_harmonic_conjug, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__619)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_harmonic_conjugate, __pyx_t_2) < 0) __PYX_ERR(2, 7406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7420
 *         return GiacMethods['harmonic_conjugate'](self,*args)
 * 
 *      def harmonic_division(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for harmonic_division:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1191harmonic_division, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_harmonic_divisi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__620)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_harmonic_division, __pyx_t_2) < 0) __PYX_ERR(2, 7420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7434
 *         return GiacMethods['harmonic_division'](self,*args)
 * 
 *      def has(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1193has, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_has, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__621)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_has, __pyx_t_2) < 0) __PYX_ERR(2, 7434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7446
 *         return GiacMethods['has'](self,*args)
 * 
 *      def has_arc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_arc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1195has_arc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_has_arc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__622)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_has_arc, __pyx_t_2) < 0) __PYX_ERR(2, 7446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7458
 *         return GiacMethods['has_arc'](self,*args)
 * 
 *      def has_edge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for has_edge:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1197has_edge, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_has_edge, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__623)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_has_edge, __pyx_t_2) < 0) __PYX_ERR(2, 7458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7469
 *         return GiacMethods['has_edge'](self,*args)
 * 
 *      def hasard(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hasard:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1199hasard, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hasard, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__624)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hasard, __pyx_t_2) < 0) __PYX_ERR(2, 7469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7486
 *         return GiacMethods['hasard'](self,*args)
 * 
 *      def head(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for head:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1201head, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_head, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__625)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_head, __pyx_t_2) < 0) __PYX_ERR(2, 7486, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7499
 *         return GiacMethods['head'](self,*args)
 * 
 *      def heading(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heading:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1203heading, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_heading, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__626)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_heading, __pyx_t_2) < 0) __PYX_ERR(2, 7499, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7512
 *         return GiacMethods['heading'](self,*args)
 * 
 *      def heapify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heapify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1205heapify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_heapify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__627)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_heapify, __pyx_t_2) < 0) __PYX_ERR(2, 7512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7522
 *         return GiacMethods['heapify'](self,*args)
 * 
 *      def heappop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappop:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1207heappop, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_heappop, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__628)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_heappop, __pyx_t_2) < 0) __PYX_ERR(2, 7522, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7532
 *         return GiacMethods['heappop'](self,*args)
 * 
 *      def heappush(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heappush:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1209heappush, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_heappush, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__629)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_heappush, __pyx_t_2) < 0) __PYX_ERR(2, 7532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7542
 *         return GiacMethods['heappush'](self,*args)
 * 
 *      def hermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hermite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1211hermite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hermite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__630)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hermite, __pyx_t_2) < 0) __PYX_ERR(2, 7542, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7554
 *         return GiacMethods['hermite'](self,*args)
 * 
 *      def hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessenberg:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1213hessenberg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hessenberg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__631)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hessenberg, __pyx_t_2) < 0) __PYX_ERR(2, 7554, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7569
 *         return GiacMethods['hessenberg'](self,*args)
 * 
 *      def hessian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hessian:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1215hessian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hessian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__632)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hessian, __pyx_t_2) < 0) __PYX_ERR(2, 7569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7580
 *         return GiacMethods['hessian'](self,*args)
 * 
 *      def heugcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for heugcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1217heugcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_heugcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__633)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_heugcd, __pyx_t_2) < 0) __PYX_ERR(2, 7580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7591
 *         return GiacMethods['heugcd'](self,*args)
 * 
 *      def hexagon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hexagon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1219hexagon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hexagon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__634)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hexagon, __pyx_t_2) < 0) __PYX_ERR(2, 7591, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7605
 *         return GiacMethods['hexagon'](self,*args)
 * 
 *      def hht(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hht:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1221hht, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hht, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__635)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hht, __pyx_t_2) < 0) __PYX_ERR(2, 7605, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7616
 *         return GiacMethods['hht'](self,*args)
 * 
 *      def highlight_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_edges:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1223highlight_edges, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_highlight_edges, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__636)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_highlight_edges, __pyx_t_2) < 0) __PYX_ERR(2, 7616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7627
 *         return GiacMethods['highlight_edges'](self,*args)
 * 
 *      def highlight_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_subgraph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1225highlight_subgraph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_highlight_subgr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__637)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_highlight_subgraph, __pyx_t_2) < 0) __PYX_ERR(2, 7627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7638
 *         return GiacMethods['highlight_subgraph'](self,*args)
 * 
 *      def highlight_trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_trail:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1227highlight_trail, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_highlight_trail, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__638)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_highlight_trail, __pyx_t_2) < 0) __PYX_ERR(2, 7638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7649
 *         return GiacMethods['highlight_trail'](self,*args)
 * 
 *      def highlight_vertex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highlight_vertex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1229highlight_vertex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_highlight_verte, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__639)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_highlight_vertex, __pyx_t_2) < 0) __PYX_ERR(2, 7649, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7660
 *         return GiacMethods['highlight_vertex'](self,*args)
 * 
 *      def highpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for highpass:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1231highpass, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_highpass, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__640)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_highpass, __pyx_t_2) < 0) __PYX_ERR(2, 7660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7671
 *         return GiacMethods['highpass'](self,*args)
 * 
 *      def hilbert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hilbert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1233hilbert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hilbert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__641)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hilbert, __pyx_t_2) < 0) __PYX_ERR(2, 7671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7685
 *         return GiacMethods['hilbert'](self,*args)
 * 
 *      def histogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for histogram:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1235histogram, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_histogram, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__642)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_histogram, __pyx_t_2) < 0) __PYX_ERR(2, 7685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7703
 *         return GiacMethods['histogram'](self,*args)
 * 
 *      def hold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hold:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1237hold, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hold, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__643)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hold, __pyx_t_2) < 0) __PYX_ERR(2, 7703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7716
 *         return GiacMethods['hold'](self,*args)
 * 
 *      def homogeneize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homogeneize:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1239homogeneize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_homogeneize, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__644)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_homogeneize, __pyx_t_2) < 0) __PYX_ERR(2, 7716, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7727
 *         return GiacMethods['homogeneize'](self,*args)
 * 
 *      def homothety(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for homothety:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1241homothety, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_homothety, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__645)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_homothety, __pyx_t_2) < 0) __PYX_ERR(2, 7727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7741
 *         return GiacMethods['homothety'](self,*args)
 * 
 *      def horner(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for horner:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1243horner, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_horner, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__646)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_horner, __pyx_t_2) < 0) __PYX_ERR(2, 7741, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7755
 *         return GiacMethods['horner'](self,*args)
 * 
 *      def hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1245hsv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hsv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__647)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hsv, __pyx_t_2) < 0) __PYX_ERR(2, 7755, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7768
 *         return GiacMethods['hsv'](self,*args)
 * 
 *      def hsv2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hsv2rgb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1247hsv2rgb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hsv2rgb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__648)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hsv2rgb, __pyx_t_2) < 0) __PYX_ERR(2, 7768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7781
 *         return GiacMethods['hsv2rgb'](self,*args)
 * 
 *      def hybrid_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrid_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1249hybrid_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hybrid_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__649)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hybrid_solver, __pyx_t_2) < 0) __PYX_ERR(2, 7781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7797
 *         return GiacMethods['hybrid_solver'](self,*args)
 * 
 *      def hybridj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridj_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1251hybridj_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hybridj_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__650)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hybridj_solver, __pyx_t_2) < 0) __PYX_ERR(2, 7797, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7813
 *         return GiacMethods['hybridj_solver'](self,*args)
 * 
 *      def hybrids_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybrids_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1253hybrids_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hybrids_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__651)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hybrids_solver, __pyx_t_2) < 0) __PYX_ERR(2, 7813, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7829
 *         return GiacMethods['hybrids_solver'](self,*args)
 * 
 *      def hybridsj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hybridsj_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1255hybridsj_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hybridsj_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__652)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hybridsj_solver, __pyx_t_2) < 0) __PYX_ERR(2, 7829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7845
 *         return GiacMethods['hybridsj_solver'](self,*args)
 * 
 *      def hyp2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyp2exp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1257hyp2exp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hyp2exp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__653)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hyp2exp, __pyx_t_2) < 0) __PYX_ERR(2, 7845, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7856
 *         return GiacMethods['hyp2exp'](self,*args)
 * 
 *      def hyperbola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hyperbola:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1259hyperbola, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hyperbola, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__654)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hyperbola, __pyx_t_2) < 0) __PYX_ERR(2, 7856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7870
 *         return GiacMethods['hyperbola'](self,*args)
 * 
 *      def hypercube_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for hypercube_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1261hypercube_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_hypercube_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__655)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_hypercube_graph, __pyx_t_2) < 0) __PYX_ERR(2, 7870, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7881
 *         return GiacMethods['hypercube_graph'](self,*args)
 * 
 *      def iPart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iPart:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1263iPart, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_iPart, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__656)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_iPart, __pyx_t_2) < 0) __PYX_ERR(2, 7881, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7894
 *         return GiacMethods['iPart'](self,*args)
 * 
 *      def iabcuv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iabcuv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1265iabcuv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_iabcuv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__657)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_iabcuv, __pyx_t_2) < 0) __PYX_ERR(2, 7894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7907
 *         return GiacMethods['iabcuv'](self,*args)
 * 
 *      def ibasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibasis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1267ibasis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ibasis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__658)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ibasis, __pyx_t_2) < 0) __PYX_ERR(2, 7907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7918
 *         return GiacMethods['ibasis'](self,*args)
 * 
 *      def ibpdv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpdv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1269ibpdv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ibpdv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__659)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ibpdv, __pyx_t_2) < 0) __PYX_ERR(2, 7918, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7933
 *         return GiacMethods['ibpdv'](self,*args)
 * 
 *      def ibpu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ibpu:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1271ibpu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ibpu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__660)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ibpu, __pyx_t_2) < 0) __PYX_ERR(2, 7933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7948
 *         return GiacMethods['ibpu'](self,*args)
 * 
 *      def icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1273icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__661)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 7948, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7960
 *         return GiacMethods['icdf'](self,*args)
 * 
 *      def ichinrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichinrem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1275ichinrem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ichinrem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__662)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ichinrem, __pyx_t_2) < 0) __PYX_ERR(2, 7960, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7974
 *         return GiacMethods['ichinrem'](self,*args)
 * 
 *      def ichrem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ichrem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1277ichrem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ichrem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__663)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ichrem, __pyx_t_2) < 0) __PYX_ERR(2, 7974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":7988
 *         return GiacMethods['ichrem'](self,*args)
 * 
 *      def icomp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icomp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1279icomp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_icomp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__664)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_icomp, __pyx_t_2) < 0) __PYX_ERR(2, 7988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8000
 *         return GiacMethods['icomp'](self,*args)
 * 
 *      def icontent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icontent:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1281icontent, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_icontent, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__665)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_icontent, __pyx_t_2) < 0) __PYX_ERR(2, 8000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8012
 *         return GiacMethods['icontent'](self,*args)
 * 
 *      def icosahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for icosahedron:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1283icosahedron, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_icosahedron, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__666)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_icosahedron, __pyx_t_2) < 0) __PYX_ERR(2, 8012, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8024
 *         return GiacMethods['icosahedron'](self,*args)
 * 
 *      def id(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for id:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1285id, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_id, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__667)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_id, __pyx_t_2) < 0) __PYX_ERR(2, 8024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8035
 *         return GiacMethods['id'](self,*args)
 * 
 *      def identify_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identify_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1287identify_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_identify_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__668)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_identify_graph, __pyx_t_2) < 0) __PYX_ERR(2, 8035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8046
 *         return GiacMethods['identify_graph'](self,*args)
 * 
 *      def identity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for identity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1289identity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_identity, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__669)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_identity, __pyx_t_2) < 0) __PYX_ERR(2, 8046, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8058
 *         return GiacMethods['identity'](self,*args)
 * 
 *      def idivis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idivis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1291idivis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_idivis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__670)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_idivis, __pyx_t_2) < 0) __PYX_ERR(2, 8058, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8070
 *         return GiacMethods['idivis'](self,*args)
 * 
 *      def idn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idn:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1293idn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_idn, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__671)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_idn, __pyx_t_2) < 0) __PYX_ERR(2, 8070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8082
 *         return GiacMethods['idn'](self,*args)
 * 
 *      def idwt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for idwt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1295idwt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_idwt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__672)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_idwt, __pyx_t_2) < 0) __PYX_ERR(2, 8082, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8094
 *         return GiacMethods['idwt'](self,*args)
 * 
 *      def iegcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iegcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1297iegcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_iegcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__673)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_iegcd, __pyx_t_2) < 0) __PYX_ERR(2, 8094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8107
 *         return GiacMethods['iegcd'](self,*args)
 * 
 *      def ifactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1299ifactor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ifactor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__674)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ifactor, __pyx_t_2) < 0) __PYX_ERR(2, 8107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8119
 *         return GiacMethods['ifactor'](self,*args)
 * 
 *      def ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifactors:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1301ifactors, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ifactors, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__675)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ifactors, __pyx_t_2) < 0) __PYX_ERR(2, 8119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8131
 *         return GiacMethods['ifactors'](self,*args)
 * 
 *      def ifourier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ifourier:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1303ifourier, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ifourier, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__676)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ifourier, __pyx_t_2) < 0) __PYX_ERR(2, 8131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8148
 *         return GiacMethods['ifourier'](self,*args)
 * 
 *      def igamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igamma:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1305igamma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_igamma, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__677)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_igamma, __pyx_t_2) < 0) __PYX_ERR(2, 8148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8161
 *         return GiacMethods['igamma'](self,*args)
 * 
 *      def igcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1307igcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_igcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__678)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_igcd, __pyx_t_2) < 0) __PYX_ERR(2, 8161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8176
 *         return GiacMethods['igcd'](self,*args)
 * 
 *      def igcdex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for igcdex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1309igcdex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_igcdex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__679)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_igcdex, __pyx_t_2) < 0) __PYX_ERR(2, 8176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8189
 *         return GiacMethods['igcdex'](self,*args)
 * 
 *      def ihermite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ihermite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1311ihermite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ihermite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__680)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ihermite, __pyx_t_2) < 0) __PYX_ERR(2, 8189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8201
 *         return GiacMethods['ihermite'](self,*args)
 * 
 *      def ilaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ilaplace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1313ilaplace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ilaplace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__681)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ilaplace, __pyx_t_2) < 0) __PYX_ERR(2, 8201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8214
 *         return GiacMethods['ilaplace'](self,*args)
 * 
 *      def im(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for im:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1315im, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_im, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__682)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_im, __pyx_t_2) < 0) __PYX_ERR(2, 8214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8227
 *         return GiacMethods['im'](self,*args)
 * 
 *      def imag(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imag:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1317imag, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_imag, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__683)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_imag, __pyx_t_2) < 0) __PYX_ERR(2, 8227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8240
 *         return GiacMethods['imag'](self,*args)
 * 
 *      def image(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for image:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1319image, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_image, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__684)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_image, __pyx_t_2) < 0) __PYX_ERR(2, 8240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8252
 *         return GiacMethods['image'](self,*args)
 * 
 *      def imfplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for imfplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1321imfplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_imfplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__685)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_imfplot, __pyx_t_2) < 0) __PYX_ERR(2, 8252, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8263
 *         return GiacMethods['imfplot'](self,*args)
 * 
 *      def implicitdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitdiff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1323implicitdiff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_implicitdiff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__686)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_implicitdiff, __pyx_t_2) < 0) __PYX_ERR(2, 8263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8281
 *         return GiacMethods['implicitdiff'](self,*args)
 * 
 *      def implicitplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for implicitplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1325implicitplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_implicitplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__687)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_implicitplot, __pyx_t_2) < 0) __PYX_ERR(2, 8281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8300
 *         return GiacMethods['implicitplot'](self,*args)
 * 
 *      def import_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for import_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1327import_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_import_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__688)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_import_graph, __pyx_t_2) < 0) __PYX_ERR(2, 8300, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8310
 *         return GiacMethods['import_graph'](self,*args)
 * 
 *      def inString(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inString:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1329inString, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inString, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__689)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inString, __pyx_t_2) < 0) __PYX_ERR(2, 8310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8322
 *         return GiacMethods['inString'](self,*args)
 * 
 *      def in_ideal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for in_ideal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1331in_ideal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_in_ideal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__690)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_in_ideal, __pyx_t_2) < 0) __PYX_ERR(2, 8322, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8334
 *         return GiacMethods['in_ideal'](self,*args)
 * 
 *      def incidence_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incidence_matrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1333incidence_matrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_incidence_matri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__691)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_incidence_matrix, __pyx_t_2) < 0) __PYX_ERR(2, 8334, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8345
 *         return GiacMethods['incidence_matrix'](self,*args)
 * 
 *      def incident_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incident_edges:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1335incident_edges, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_incident_edges, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__692)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_incident_edges, __pyx_t_2) < 0) __PYX_ERR(2, 8345, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8356
 *         return GiacMethods['incident_edges'](self,*args)
 * 
 *      def incircle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for incircle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1337incircle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_incircle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__693)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_incircle, __pyx_t_2) < 0) __PYX_ERR(2, 8356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8367
 *         return GiacMethods['incircle'](self,*args)
 * 
 *      def increasing_power(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for increasing_power:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1339increasing_power, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_increasing_powe, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__694)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_increasing_power, __pyx_t_2) < 0) __PYX_ERR(2, 8367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8379
 *         return GiacMethods['increasing_power'](self,*args)
 * 
 *      def independence_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for independence_number:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1341independence_number, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_independence_nu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__695)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_independence_number, __pyx_t_2) < 0) __PYX_ERR(2, 8379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8390
 *         return GiacMethods['independence_number'](self,*args)
 * 
 *      def indets(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for indets:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1343indets, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_indets, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__696)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_indets, __pyx_t_2) < 0) __PYX_ERR(2, 8390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8401
 *         return GiacMethods['indets'](self,*args)
 * 
 *      def index(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for index:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1345index, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_index, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__697)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_index, __pyx_t_2) < 0) __PYX_ERR(2, 8401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8415
 *         return GiacMethods['index'](self,*args)
 * 
 *      def induced_subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for induced_subgraph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1347induced_subgraph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_induced_subgrap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__698)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_induced_subgraph, __pyx_t_2) < 0) __PYX_ERR(2, 8415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8426
 *         return GiacMethods['induced_subgraph'](self,*args)
 * 
 *      def inequationplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inequationplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1349inequationplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inequationplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__699)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inequationplot, __pyx_t_2) < 0) __PYX_ERR(2, 8426, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8440
 *         return GiacMethods['inequationplot'](self,*args)
 * 
 *      def inertia(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inertia:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1351inertia, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inertia, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__700)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inertia, __pyx_t_2) < 0) __PYX_ERR(2, 8440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8455
 *         return GiacMethods['inertia'](self,*args)
 * 
 *      def inf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1353inf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__701)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inf, __pyx_t_2) < 0) __PYX_ERR(2, 8455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8465
 *         return GiacMethods['inf'](self,*args)
 * 
 *      def infinity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for infinity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1355infinity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_infinity, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__702)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_infinity, __pyx_t_2) < 0) __PYX_ERR(2, 8465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8475
 *         return GiacMethods['infinity'](self,*args)
 * 
 *      def information_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for information_centrality:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1357information_centrality, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_information_cen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__703)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_information_centrality, __pyx_t_2) < 0) __PYX_ERR(2, 8475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8486
 *         return GiacMethods['information_centrality'](self,*args)
 * 
 *      def insert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1359insert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_insert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__704)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_insert, __pyx_t_2) < 0) __PYX_ERR(2, 8486, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8498
 *         return GiacMethods['insert'](self,*args)
 * 
 *      def insmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for insmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1361insmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_insmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__705)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_insmod, __pyx_t_2) < 0) __PYX_ERR(2, 8498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8509
 *         return GiacMethods['insmod'](self,*args)
 * 
 *      def instfreq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instfreq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1363instfreq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_instfreq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__706)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_instfreq, __pyx_t_2) < 0) __PYX_ERR(2, 8509, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8521
 *         return GiacMethods['instfreq'](self,*args)
 * 
 *      def instphase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for instphase:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1365instphase, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_instphase, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__707)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_instphase, __pyx_t_2) < 0) __PYX_ERR(2, 8521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8533
 *         return GiacMethods['instphase'](self,*args)
 * 
 *      def int(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for int:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1367int, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_int, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__708)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_int, __pyx_t_2) < 0) __PYX_ERR(2, 8533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8546
 *         return GiacMethods['int'](self,*args)
 * 
 *      def intDiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for intDiv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1369intDiv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_intDiv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__709)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_intDiv, __pyx_t_2) < 0) __PYX_ERR(2, 8546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8560
 *         return GiacMethods['intDiv'](self,*args)
 * 
 *      def integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1371integer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_integer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__710)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_integer, __pyx_t_2) < 0) __PYX_ERR(2, 8560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8575
 *         return GiacMethods['integer'](self,*args)
 * 
 *      def integrate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1373integrate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_integrate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__711)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_integrate, __pyx_t_2) < 0) __PYX_ERR(2, 8575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8588
 *         return GiacMethods['integrate'](self,*args)
 * 
 *      def integrer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for integrer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1375integrer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_integrer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__712)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_integrer, __pyx_t_2) < 0) __PYX_ERR(2, 8588, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8601
 *         return GiacMethods['integrer'](self,*args)
 * 
 *      def inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1377inter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__713)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inter, __pyx_t_2) < 0) __PYX_ERR(2, 8601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8616
 *         return GiacMethods['inter'](self,*args)
 * 
 *      def interactive_odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_odeplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1379interactive_odeplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_interactive_ode, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__714)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_interactive_odeplot, __pyx_t_2) < 0) __PYX_ERR(2, 8616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8628
 *         return GiacMethods['interactive_odeplot'](self,*args)
 * 
 *      def interactive_plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interactive_plotode:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1381interactive_plotode, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_interactive_plo, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__715)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_interactive_plotode, __pyx_t_2) < 0) __PYX_ERR(2, 8628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8640
 *         return GiacMethods['interactive_plotode'](self,*args)
 * 
 *      def interp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1383interp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_interp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__716)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_interp, __pyx_t_2) < 0) __PYX_ERR(2, 8640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8653
 *         return GiacMethods['interp'](self,*args)
 * 
 *      def interval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1385interval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_interval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__717)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_interval, __pyx_t_2) < 0) __PYX_ERR(2, 8653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8666
 *         return GiacMethods['interval'](self,*args)
 * 
 *      def interval2center(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval2center:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1387interval2center, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_interval2center, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__718)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_interval2center, __pyx_t_2) < 0) __PYX_ERR(2, 8666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8678
 *         return GiacMethods['interval2center'](self,*args)
 * 
 *      def interval_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for interval_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1389interval_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_interval_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__719)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_interval_graph, __pyx_t_2) < 0) __PYX_ERR(2, 8678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8689
 *         return GiacMethods['interval_graph'](self,*args)
 * 
 *      def inv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1391inv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__720)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inv, __pyx_t_2) < 0) __PYX_ERR(2, 8689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8701
 *         return GiacMethods['inv'](self,*args)
 * 
 *      def inverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inverse:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1393inverse, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inverse, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__721)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inverse, __pyx_t_2) < 0) __PYX_ERR(2, 8701, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8713
 *         return GiacMethods['inverse'](self,*args)
 * 
 *      def inversion(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for inversion:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1395inversion, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_inversion, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__722)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_inversion, __pyx_t_2) < 0) __PYX_ERR(2, 8713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8727
 *         return GiacMethods['inversion'](self,*args)
 * 
 *      def invisible_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invisible_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1397invisible_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_invisible_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__723)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_invisible_point, __pyx_t_2) < 0) __PYX_ERR(2, 8727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8739
 *         return GiacMethods['invisible_point'](self,*args)
 * 
 *      def invlaplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invlaplace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1399invlaplace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_invlaplace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__724)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_invlaplace, __pyx_t_2) < 0) __PYX_ERR(2, 8739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8752
 *         return GiacMethods['invlaplace'](self,*args)
 * 
 *      def invztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for invztrans:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1401invztrans, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_invztrans, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__725)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_invztrans, __pyx_t_2) < 0) __PYX_ERR(2, 8752, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8764
 *         return GiacMethods['invztrans'](self,*args)
 * 
 *      def iquo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquo:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1403iquo, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_iquo, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__726)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_iquo, __pyx_t_2) < 0) __PYX_ERR(2, 8764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8778
 *         return GiacMethods['iquo'](self,*args)
 * 
 *      def iquorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iquorem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1405iquorem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_iquorem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__727)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_iquorem, __pyx_t_2) < 0) __PYX_ERR(2, 8778, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8791
 *         return GiacMethods['iquorem'](self,*args)
 * 
 *      def iratrecon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for iratrecon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1407iratrecon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_iratrecon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__728)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_iratrecon, __pyx_t_2) < 0) __PYX_ERR(2, 8791, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8802
 *         return GiacMethods['iratrecon'](self,*args)
 * 
 *      def irem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for irem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1409irem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_irem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__729)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_irem, __pyx_t_2) < 0) __PYX_ERR(2, 8802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8816
 *         return GiacMethods['irem'](self,*args)
 * 
 *      def isPrime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isPrime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1411isPrime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isPrime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__730)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isPrime, __pyx_t_2) < 0) __PYX_ERR(2, 8816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8829
 *         return GiacMethods['isPrime'](self,*args)
 * 
 *      def is_acyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_acyclic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1413is_acyclic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_acyclic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__731)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_acyclic, __pyx_t_2) < 0) __PYX_ERR(2, 8829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8840
 *         return GiacMethods['is_acyclic'](self,*args)
 * 
 *      def is_arborescence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_arborescence:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1415is_arborescence, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_arborescence, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__732)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_arborescence, __pyx_t_2) < 0) __PYX_ERR(2, 8840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8852
 *         return GiacMethods['is_arborescence'](self,*args)
 * 
 *      def is_biconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_biconnected:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1417is_biconnected, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_biconnected, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__733)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_biconnected, __pyx_t_2) < 0) __PYX_ERR(2, 8852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8865
 *         return GiacMethods['is_biconnected'](self,*args)
 * 
 *      def is_bipartite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_bipartite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1419is_bipartite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_bipartite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__734)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_bipartite, __pyx_t_2) < 0) __PYX_ERR(2, 8865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8876
 *         return GiacMethods['is_bipartite'](self,*args)
 * 
 *      def is_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_clique:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1421is_clique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_clique, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__735)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_clique, __pyx_t_2) < 0) __PYX_ERR(2, 8876, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8887
 *         return GiacMethods['is_clique'](self,*args)
 * 
 *      def is_collinear(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_collinear:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1423is_collinear, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_collinear, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__736)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_collinear, __pyx_t_2) < 0) __PYX_ERR(2, 8887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8900
 *         return GiacMethods['is_collinear'](self,*args)
 * 
 *      def is_concyclic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_concyclic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1425is_concyclic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_concyclic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__737)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_concyclic, __pyx_t_2) < 0) __PYX_ERR(2, 8900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8912
 *         return GiacMethods['is_concyclic'](self,*args)
 * 
 *      def is_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_conjugate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1427is_conjugate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_conjugate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__738)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_conjugate, __pyx_t_2) < 0) __PYX_ERR(2, 8912, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8932
 *         return GiacMethods['is_conjugate'](self,*args)
 * 
 *      def is_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_connected:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1429is_connected, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_connected, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__739)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_connected, __pyx_t_2) < 0) __PYX_ERR(2, 8932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8945
 *         return GiacMethods['is_connected'](self,*args)
 * 
 *      def is_coplanar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_coplanar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1431is_coplanar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_coplanar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__740)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_coplanar, __pyx_t_2) < 0) __PYX_ERR(2, 8945, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8955
 *         return GiacMethods['is_coplanar'](self,*args)
 * 
 *      def is_cospherical(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cospherical:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1433is_cospherical, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_cospherical, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__741)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_cospherical, __pyx_t_2) < 0) __PYX_ERR(2, 8955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8965
 *         return GiacMethods['is_cospherical'](self,*args)
 * 
 *      def is_cut_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cut_set:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1435is_cut_set, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_cut_set, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__742)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_cut_set, __pyx_t_2) < 0) __PYX_ERR(2, 8965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8976
 *         return GiacMethods['is_cut_set'](self,*args)
 * 
 *      def is_cycle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_cycle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1437is_cycle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_cycle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__743)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_cycle, __pyx_t_2) < 0) __PYX_ERR(2, 8976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8988
 *         return GiacMethods['is_cycle'](self,*args)
 * 
 *      def is_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_directed:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1439is_directed, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_directed, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__744)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_directed, __pyx_t_2) < 0) __PYX_ERR(2, 8988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":8999
 *         return GiacMethods['is_directed'](self,*args)
 * 
 *      def is_element(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_element:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1441is_element, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_element, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__745)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_element, __pyx_t_2) < 0) __PYX_ERR(2, 8999, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9011
 *         return GiacMethods['is_element'](self,*args)
 * 
 *      def is_equilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_equilateral:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1443is_equilateral, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_equilateral, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__746)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_equilateral, __pyx_t_2) < 0) __PYX_ERR(2, 9011, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9024
 *         return GiacMethods['is_equilateral'](self,*args)
 * 
 *      def is_eulerian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_eulerian:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1445is_eulerian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_eulerian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__747)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_eulerian, __pyx_t_2) < 0) __PYX_ERR(2, 9024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9038
 *         return GiacMethods['is_eulerian'](self,*args)
 * 
 *      def is_forest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_forest:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1447is_forest, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_forest, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__748)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_forest, __pyx_t_2) < 0) __PYX_ERR(2, 9038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9049
 *         return GiacMethods['is_forest'](self,*args)
 * 
 *      def is_graphic_sequence(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_graphic_sequence:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1449is_graphic_sequence, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_graphic_sequ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__749)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_graphic_sequence, __pyx_t_2) < 0) __PYX_ERR(2, 9049, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9060
 *         return GiacMethods['is_graphic_sequence'](self,*args)
 * 
 *      def is_hamiltonian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_hamiltonian:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1451is_hamiltonian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_hamiltonian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__750)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_hamiltonian, __pyx_t_2) < 0) __PYX_ERR(2, 9060, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9073
 *         return GiacMethods['is_hamiltonian'](self,*args)
 * 
 *      def is_harmonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1453is_harmonic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_harmonic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__751)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_harmonic, __pyx_t_2) < 0) __PYX_ERR(2, 9073, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9085
 *         return GiacMethods['is_harmonic'](self,*args)
 * 
 *      def is_harmonic_circle_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_circle_bundle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1455is_harmonic_circle_bundle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_harmonic_cir, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__752)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_harmonic_circle_bundle, __pyx_t_2) < 0) __PYX_ERR(2, 9085, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9097
 *         return GiacMethods['is_harmonic_circle_bundle'](self,*args)
 * 
 *      def is_harmonic_line_bundle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_harmonic_line_bundle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1457is_harmonic_line_bundle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_harmonic_lin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__753)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_harmonic_line_bundle, __pyx_t_2) < 0) __PYX_ERR(2, 9097, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9109
 *         return GiacMethods['is_harmonic_line_bundle'](self,*args)
 * 
 *      def is_inside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_inside:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1459is_inside, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_inside, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__754)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_inside, __pyx_t_2) < 0) __PYX_ERR(2, 9109, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9121
 *         return GiacMethods['is_inside'](self,*args)
 * 
 *      def is_integer_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_integer_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1461is_integer_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_integer_grap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__755)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_integer_graph, __pyx_t_2) < 0) __PYX_ERR(2, 9121, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9132
 *         return GiacMethods['is_integer_graph'](self,*args)
 * 
 *      def is_irreducible(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_irreducible:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1463is_irreducible, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_irreducible, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__756)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_irreducible, __pyx_t_2) < 0) __PYX_ERR(2, 9132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9145
 *         return GiacMethods['is_irreducible'](self,*args)
 * 
 *      def is_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isomorphic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1465is_isomorphic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_isomorphic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__757)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_isomorphic, __pyx_t_2) < 0) __PYX_ERR(2, 9145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9156
 *         return GiacMethods['is_isomorphic'](self,*args)
 * 
 *      def is_isosceles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_isosceles:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1467is_isosceles, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_isosceles, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__758)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_isosceles, __pyx_t_2) < 0) __PYX_ERR(2, 9156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9169
 *         return GiacMethods['is_isosceles'](self,*args)
 * 
 *      def is_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_network:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1469is_network, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_network, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__759)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_network, __pyx_t_2) < 0) __PYX_ERR(2, 9169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9182
 *         return GiacMethods['is_network'](self,*args)
 * 
 *      def is_orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_orthogonal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1471is_orthogonal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_orthogonal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__760)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_orthogonal, __pyx_t_2) < 0) __PYX_ERR(2, 9182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9195
 *         return GiacMethods['is_orthogonal'](self,*args)
 * 
 *      def is_parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallel:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1473is_parallel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_parallel, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__761)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_parallel, __pyx_t_2) < 0) __PYX_ERR(2, 9195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9208
 *         return GiacMethods['is_parallel'](self,*args)
 * 
 *      def is_parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_parallelogram:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1475is_parallelogram, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_parallelogra, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__762)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_parallelogram, __pyx_t_2) < 0) __PYX_ERR(2, 9208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9221
 *         return GiacMethods['is_parallelogram'](self,*args)
 * 
 *      def is_permu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_permu:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1477is_permu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_permu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__763)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_permu, __pyx_t_2) < 0) __PYX_ERR(2, 9221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9233
 *         return GiacMethods['is_permu'](self,*args)
 * 
 *      def is_perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_perpendicular:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1479is_perpendicular, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_perpendicula, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__764)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_perpendicular, __pyx_t_2) < 0) __PYX_ERR(2, 9233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9247
 *         return GiacMethods['is_perpendicular'](self,*args)
 * 
 *      def is_planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_planar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1481is_planar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_planar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__765)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_planar, __pyx_t_2) < 0) __PYX_ERR(2, 9247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9259
 *         return GiacMethods['is_planar'](self,*args)
 * 
 *      def is_prime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_prime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1483is_prime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_prime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__766)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_prime, __pyx_t_2) < 0) __PYX_ERR(2, 9259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9273
 *         return GiacMethods['is_prime'](self,*args)
 * 
 *      def is_pseudoprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_pseudoprime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1485is_pseudoprime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_pseudoprime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__767)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_pseudoprime, __pyx_t_2) < 0) __PYX_ERR(2, 9273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9286
 *         return GiacMethods['is_pseudoprime'](self,*args)
 * 
 *      def is_reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_reachable:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1487is_reachable, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_reachable, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__768)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_reachable, __pyx_t_2) < 0) __PYX_ERR(2, 9286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9298
 *         return GiacMethods['is_reachable'](self,*args)
 * 
 *      def is_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rectangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1489is_rectangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_rectangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__769)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_rectangle, __pyx_t_2) < 0) __PYX_ERR(2, 9298, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9314
 *         return GiacMethods['is_rectangle'](self,*args)
 * 
 *      def is_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_regular:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1491is_regular, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_regular, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__770)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_regular, __pyx_t_2) < 0) __PYX_ERR(2, 9314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9325
 *         return GiacMethods['is_regular'](self,*args)
 * 
 *      def is_rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_rhombus:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1493is_rhombus, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_rhombus, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__771)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_rhombus, __pyx_t_2) < 0) __PYX_ERR(2, 9325, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9338
 *         return GiacMethods['is_rhombus'](self,*args)
 * 
 *      def is_split_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_split_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1495is_split_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_split_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__772)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_split_graph, __pyx_t_2) < 0) __PYX_ERR(2, 9338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9349
 *         return GiacMethods['is_split_graph'](self,*args)
 * 
 *      def is_square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_square:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1497is_square, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_square, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__773)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_square, __pyx_t_2) < 0) __PYX_ERR(2, 9349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9362
 *         return GiacMethods['is_square'](self,*args)
 * 
 *      def is_strongly_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_connected:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1499is_strongly_connected, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_strongly_con, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__774)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_strongly_connected, __pyx_t_2) < 0) __PYX_ERR(2, 9362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9373
 *         return GiacMethods['is_strongly_connected'](self,*args)
 * 
 *      def is_strongly_regular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_strongly_regular:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1501is_strongly_regular, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_strongly_reg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__775)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_strongly_regular, __pyx_t_2) < 0) __PYX_ERR(2, 9373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9385
 *         return GiacMethods['is_strongly_regular'](self,*args)
 * 
 *      def is_subgraph_isomorphic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_subgraph_isomorphic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1503is_subgraph_isomorphic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_subgraph_iso, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__776)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_subgraph_isomorphic, __pyx_t_2) < 0) __PYX_ERR(2, 9385, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9396
 *         return GiacMethods['is_subgraph_isomorphic'](self,*args)
 * 
 *      def is_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tournament:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1505is_tournament, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_tournament, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__777)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_tournament, __pyx_t_2) < 0) __PYX_ERR(2, 9396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9407
 *         return GiacMethods['is_tournament'](self,*args)
 * 
 *      def is_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1507is_tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_tree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__778)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_tree, __pyx_t_2) < 0) __PYX_ERR(2, 9407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9420
 *         return GiacMethods['is_tree'](self,*args)
 * 
 *      def is_triconnected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_triconnected:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1509is_triconnected, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_triconnected, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__779)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_triconnected, __pyx_t_2) < 0) __PYX_ERR(2, 9420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9433
 *         return GiacMethods['is_triconnected'](self,*args)
 * 
 *      def is_two_edge_connected(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_two_edge_connected:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1511is_two_edge_connected, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_two_edge_con, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__780)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_two_edge_connected, __pyx_t_2) < 0) __PYX_ERR(2, 9433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9445
 *         return GiacMethods['is_two_edge_connected'](self,*args)
 * 
 *      def is_vertex_colorable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_vertex_colorable:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1513is_vertex_colorable, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_vertex_color, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__781)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_vertex_colorable, __pyx_t_2) < 0) __PYX_ERR(2, 9445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9457
 *         return GiacMethods['is_vertex_colorable'](self,*args)
 * 
 *      def is_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for is_weighted:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1515is_weighted, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_is_weighted, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__782)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_is_weighted, __pyx_t_2) < 0) __PYX_ERR(2, 9457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9469
 *         return GiacMethods['is_weighted'](self,*args)
 * 
 *      def isinf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isinf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1517isinf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isinf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__783)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isinf, __pyx_t_2) < 0) __PYX_ERR(2, 9469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9479
 *         return GiacMethods['isinf'](self,*args)
 * 
 *      def ismith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ismith:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1519ismith, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ismith, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__784)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ismith, __pyx_t_2) < 0) __PYX_ERR(2, 9479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9491
 *         return GiacMethods['ismith'](self,*args)
 * 
 *      def isnan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isnan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1521isnan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isnan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__785)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isnan, __pyx_t_2) < 0) __PYX_ERR(2, 9491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9501
 *         return GiacMethods['isnan'](self,*args)
 * 
 *      def isobarycenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isobarycenter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1523isobarycenter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isobarycenter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__786)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isobarycenter, __pyx_t_2) < 0) __PYX_ERR(2, 9501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9512
 *         return GiacMethods['isobarycenter'](self,*args)
 * 
 *      def isolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1525isolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__787)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isolve, __pyx_t_2) < 0) __PYX_ERR(2, 9512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9528
 *         return GiacMethods['isolve'](self,*args)
 * 
 *      def isom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isom:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1527isom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isom, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__788)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isom, __pyx_t_2) < 0) __PYX_ERR(2, 9528, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9539
 *         return GiacMethods['isom'](self,*args)
 * 
 *      def isomorphic_copy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isomorphic_copy:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1529isomorphic_copy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isomorphic_copy, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__789)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isomorphic_copy, __pyx_t_2) < 0) __PYX_ERR(2, 9539, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9550
 *         return GiacMethods['isomorphic_copy'](self,*args)
 * 
 *      def isopolygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isopolygon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1531isopolygon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isopolygon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__790)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isopolygon, __pyx_t_2) < 0) __PYX_ERR(2, 9550, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9564
 *         return GiacMethods['isopolygon'](self,*args)
 * 
 *      def isosceles_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isosceles_triangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1533isosceles_triangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isosceles_trian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__791)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isosceles_triangle, __pyx_t_2) < 0) __PYX_ERR(2, 9564, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9578
 *         return GiacMethods['isosceles_triangle'](self,*args)
 * 
 *      def isposdef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isposdef:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1535isposdef, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isposdef, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__792)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isposdef, __pyx_t_2) < 0) __PYX_ERR(2, 9578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9589
 *         return GiacMethods['isposdef'](self,*args)
 * 
 *      def isprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for isprime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1537isprime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_isprime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__793)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_isprime, __pyx_t_2) < 0) __PYX_ERR(2, 9589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9602
 *         return GiacMethods['isprime'](self,*args)
 * 
 *      def istft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for istft:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1539istft, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_istft, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__794)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_istft, __pyx_t_2) < 0) __PYX_ERR(2, 9602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9613
 *         return GiacMethods['istft'](self,*args)
 * 
 *      def ithprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ithprime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1541ithprime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ithprime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__795)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ithprime, __pyx_t_2) < 0) __PYX_ERR(2, 9613, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9625
 *         return GiacMethods['ithprime'](self,*args)
 * 
 *      def jacobi_equation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_equation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1543jacobi_equation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_jacobi_equation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__796)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_jacobi_equation, __pyx_t_2) < 0) __PYX_ERR(2, 9625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9636
 *         return GiacMethods['jacobi_equation'](self,*args)
 * 
 *      def jacobi_linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_linsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1545jacobi_linsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_jacobi_linsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__797)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_jacobi_linsolve, __pyx_t_2) < 0) __PYX_ERR(2, 9636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9648
 *         return GiacMethods['jacobi_linsolve'](self,*args)
 * 
 *      def jacobi_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jacobi_symbol:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1547jacobi_symbol, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_jacobi_symbol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__798)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_jacobi_symbol, __pyx_t_2) < 0) __PYX_ERR(2, 9648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9660
 *         return GiacMethods['jacobi_symbol'](self,*args)
 * 
 *      def johnson_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for johnson_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1549johnson_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_johnson_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__799)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_johnson_graph, __pyx_t_2) < 0) __PYX_ERR(2, 9660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9671
 *         return GiacMethods['johnson_graph'](self,*args)
 * 
 *      def join(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for join:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1551join, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_join, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__800)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_join, __pyx_t_2) < 0) __PYX_ERR(2, 9671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9682
 *         return GiacMethods['join'](self,*args)
 * 
 *      def jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for jordan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1553jordan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_jordan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__801)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_jordan, __pyx_t_2) < 0) __PYX_ERR(2, 9682, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9695
 *         return GiacMethods['jordan'](self,*args)
 * 
 *      def katz_centrality(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for katz_centrality:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1555katz_centrality, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_katz_centrality, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__802)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_katz_centrality, __pyx_t_2) < 0) __PYX_ERR(2, 9695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9706
 *         return GiacMethods['katz_centrality'](self,*args)
 * 
 *      def kde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kde:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1557kde, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kde, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__803)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kde, __pyx_t_2) < 0) __PYX_ERR(2, 9706, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9719
 *         return GiacMethods['kde'](self,*args)
 * 
 *      def keep_pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for keep_pivot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1559keep_pivot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_keep_pivot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__804)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_keep_pivot, __pyx_t_2) < 0) __PYX_ERR(2, 9719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9730
 *         return GiacMethods['keep_pivot'](self,*args)
 * 
 *      def ker(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ker:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1561ker, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ker, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__805)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ker, __pyx_t_2) < 0) __PYX_ERR(2, 9730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9742
 *         return GiacMethods['ker'](self,*args)
 * 
 *      def kernel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1563kernel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kernel, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__806)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kernel, __pyx_t_2) < 0) __PYX_ERR(2, 9742, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9754
 *         return GiacMethods['kernel'](self,*args)
 * 
 *      def kernel_density(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kernel_density:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1565kernel_density, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kernel_density, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__807)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kernel_density, __pyx_t_2) < 0) __PYX_ERR(2, 9754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9767
 *         return GiacMethods['kernel_density'](self,*args)
 * 
 *      def kmeans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kmeans:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1567kmeans, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kmeans, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__808)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kmeans, __pyx_t_2) < 0) __PYX_ERR(2, 9767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9778
 *         return GiacMethods['kmeans'](self,*args)
 * 
 *      def kneser_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kneser_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1569kneser_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kneser_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__809)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kneser_graph, __pyx_t_2) < 0) __PYX_ERR(2, 9778, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9789
 *         return GiacMethods['kneser_graph'](self,*args)
 * 
 *      def kolmogorovd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1571kolmogorovd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kolmogorovd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__810)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kolmogorovd, __pyx_t_2) < 0) __PYX_ERR(2, 9789, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9799
 *         return GiacMethods['kolmogorovd'](self,*args)
 * 
 *      def kolmogorovt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kolmogorovt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1573kolmogorovt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kolmogorovt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__811)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kolmogorovt, __pyx_t_2) < 0) __PYX_ERR(2, 9799, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9813
 *         return GiacMethods['kolmogorovt'](self,*args)
 * 
 *      def kovacicsols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kovacicsols:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1575kovacicsols, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kovacicsols, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__812)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kovacicsols, __pyx_t_2) < 0) __PYX_ERR(2, 9813, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9830
 *         return GiacMethods['kovacicsols'](self,*args)
 * 
 *      def kspaths(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for kspaths:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1577kspaths, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_kspaths, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__813)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_kspaths, __pyx_t_2) < 0) __PYX_ERR(2, 9830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9842
 *         return GiacMethods['kspaths'](self,*args)
 * 
 *      def l1norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l1norm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1579l1norm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_l1norm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__814)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_l1norm, __pyx_t_2) < 0) __PYX_ERR(2, 9842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9855
 *         return GiacMethods['l1norm'](self,*args)
 * 
 *      def l2norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for l2norm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1581l2norm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_l2norm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__815)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_l2norm, __pyx_t_2) < 0) __PYX_ERR(2, 9855, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9869
 *         return GiacMethods['l2norm'](self,*args)
 * 
 *      def lagrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lagrange:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1583lagrange, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lagrange, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__816)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lagrange, __pyx_t_2) < 0) __PYX_ERR(2, 9869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9890
 *         return GiacMethods['lagrange'](self,*args)
 * 
 *      def laguerre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laguerre:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1585laguerre, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_laguerre, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__817)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_laguerre, __pyx_t_2) < 0) __PYX_ERR(2, 9890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9901
 *         return GiacMethods['laguerre'](self,*args)
 * 
 *      def laplace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1587laplace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_laplace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__818)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_laplace, __pyx_t_2) < 0) __PYX_ERR(2, 9901, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9914
 *         return GiacMethods['laplace'](self,*args)
 * 
 *      def laplacian(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1589laplacian, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_laplacian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__819)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_laplacian, __pyx_t_2) < 0) __PYX_ERR(2, 9914, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9928
 *         return GiacMethods['laplacian'](self,*args)
 * 
 *      def laplacian_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for laplacian_matrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1591laplacian_matrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_laplacian_matri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__820)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_laplacian_matrix, __pyx_t_2) < 0) __PYX_ERR(2, 9928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9940
 *         return GiacMethods['laplacian_matrix'](self,*args)
 * 
 *      def latex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for latex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1593latex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_latex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__821)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_latex, __pyx_t_2) < 0) __PYX_ERR(2, 9940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9952
 *         return GiacMethods['latex'](self,*args)
 * 
 *      def lcf_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcf_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1595lcf_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lcf_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__822)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lcf_graph, __pyx_t_2) < 0) __PYX_ERR(2, 9952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9963
 *         return GiacMethods['lcf_graph'](self,*args)
 * 
 *      def lcm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1597lcm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lcm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__823)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lcm, __pyx_t_2) < 0) __PYX_ERR(2, 9963, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9979
 *         return GiacMethods['lcm'](self,*args)
 * 
 *      def lcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lcoeff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1599lcoeff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lcoeff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__824)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lcoeff, __pyx_t_2) < 0) __PYX_ERR(2, 9979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":9991
 *         return GiacMethods['lcoeff'](self,*args)
 * 
 *      def ldegree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldegree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1601ldegree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ldegree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__825)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ldegree, __pyx_t_2) < 0) __PYX_ERR(2, 9991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10006
 *         return GiacMethods['ldegree'](self,*args)
 * 
 *      def ldl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ldl:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1603ldl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ldl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__826)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ldl, __pyx_t_2) < 0) __PYX_ERR(2, 10006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10019
 *         return GiacMethods['ldl'](self,*args)
 * 
 *      def learning_rate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for learning_rate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1605learning_rate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_learning_rate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__827)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_learning_rate, __pyx_t_2) < 0) __PYX_ERR(2, 10019, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10029
 *         return GiacMethods['learning_rate'](self,*args)
 * 
 *      def left(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1607left, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_left, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__828)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_left, __pyx_t_2) < 0) __PYX_ERR(2, 10029, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10043
 *         return GiacMethods['left'](self,*args)
 * 
 *      def left_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for left_rectangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1609left_rectangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_left_rectangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__829)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_left_rectangle, __pyx_t_2) < 0) __PYX_ERR(2, 10043, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10059
 *         return GiacMethods['left_rectangle'](self,*args)
 * 
 *      def legend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legend:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1611legend, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_legend, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__830)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_legend, __pyx_t_2) < 0) __PYX_ERR(2, 10059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10082
 *         return GiacMethods['legend'](self,*args)
 * 
 *      def legendre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1613legendre, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_legendre, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__831)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_legendre, __pyx_t_2) < 0) __PYX_ERR(2, 10082, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10093
 *         return GiacMethods['legendre'](self,*args)
 * 
 *      def legendre_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for legendre_symbol:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1615legendre_symbol, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_legendre_symbol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__832)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_legendre_symbol, __pyx_t_2) < 0) __PYX_ERR(2, 10093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10105
 *         return GiacMethods['legendre_symbol'](self,*args)
 * 
 *      def length(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for length:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1617length, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_length, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__833)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_length, __pyx_t_2) < 0) __PYX_ERR(2, 10105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10118
 *         return GiacMethods['length'](self,*args)
 * 
 *      def levenshtein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for levenshtein:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1619levenshtein, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_levenshtein, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__834)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_levenshtein, __pyx_t_2) < 0) __PYX_ERR(2, 10118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10129
 *         return GiacMethods['levenshtein'](self,*args)
 * 
 *      def lgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lgcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1621lgcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lgcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__835)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lgcd, __pyx_t_2) < 0) __PYX_ERR(2, 10129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10142
 *         return GiacMethods['lgcd'](self,*args)
 * 
 *      def lhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lhs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1623lhs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lhs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__836)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lhs, __pyx_t_2) < 0) __PYX_ERR(2, 10142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10156
 *         return GiacMethods['lhs'](self,*args)
 * 
 *      def ligne_chapeau_carre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_carre:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1625ligne_chapeau_carre, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_chapeau_c, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__837)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_chapeau_carre, __pyx_t_2) < 0) __PYX_ERR(2, 10156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10168
 *         return GiacMethods['ligne_chapeau_carre'](self,*args)
 * 
 *      def ligne_chapeau_plat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_plat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1627ligne_chapeau_plat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_chapeau_p, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__838)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_chapeau_plat, __pyx_t_2) < 0) __PYX_ERR(2, 10168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10180
 *         return GiacMethods['ligne_chapeau_plat'](self,*args)
 * 
 *      def ligne_chapeau_rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_chapeau_rond:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1629ligne_chapeau_rond, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_chapeau_r, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__839)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_chapeau_rond, __pyx_t_2) < 0) __PYX_ERR(2, 10180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10192
 *         return GiacMethods['ligne_chapeau_rond'](self,*args)
 * 
 *      def ligne_polygonale(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1631ligne_polygonale, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_polygonal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__840)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_polygonale, __pyx_t_2) < 0) __PYX_ERR(2, 10192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10203
 *         return GiacMethods['ligne_polygonale'](self,*args)
 * 
 *      def ligne_polygonale_pointee(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_polygonale_pointee:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1633ligne_polygonale_pointee, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_polygonal_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__841)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_polygonale_pointee, __pyx_t_2) < 0) __PYX_ERR(2, 10203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10214
 *         return GiacMethods['ligne_polygonale_pointee'](self,*args)
 * 
 *      def ligne_tiret(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1635ligne_tiret, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_tiret, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__842)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_tiret, __pyx_t_2) < 0) __PYX_ERR(2, 10214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10226
 *         return GiacMethods['ligne_tiret'](self,*args)
 * 
 *      def ligne_tiret_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1637ligne_tiret_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_tiret_poi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__843)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_tiret_point, __pyx_t_2) < 0) __PYX_ERR(2, 10226, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10238
 *         return GiacMethods['ligne_tiret_point'](self,*args)
 * 
 *      def ligne_tiret_pointpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_tiret_pointpoint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1639ligne_tiret_pointpoint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_tiret_poi_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__844)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_tiret_pointpoint, __pyx_t_2) < 0) __PYX_ERR(2, 10238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10250
 *         return GiacMethods['ligne_tiret_pointpoint'](self,*args)
 * 
 *      def ligne_trait_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ligne_trait_plein:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1641ligne_trait_plein, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ligne_trait_ple, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__845)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ligne_trait_plein, __pyx_t_2) < 0) __PYX_ERR(2, 10250, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10262
 *         return GiacMethods['ligne_trait_plein'](self,*args)
 * 
 *      def limit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1643limit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_limit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__846)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_limit, __pyx_t_2) < 0) __PYX_ERR(2, 10262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10278
 *         return GiacMethods['limit'](self,*args)
 * 
 *      def limite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for limite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1645limite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_limite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__847)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_limite, __pyx_t_2) < 0) __PYX_ERR(2, 10278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10294
 *         return GiacMethods['limite'](self,*args)
 * 
 *      def lin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1647lin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__848)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lin, __pyx_t_2) < 0) __PYX_ERR(2, 10294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10306
 *         return GiacMethods['lin'](self,*args)
 * 
 *      def linabs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linabs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1649linabs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linabs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__849)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linabs, __pyx_t_2) < 0) __PYX_ERR(2, 10306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10319
 *         return GiacMethods['linabs'](self,*args)
 * 
 *      def line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1651line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__850)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_line, __pyx_t_2) < 0) __PYX_ERR(2, 10319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10338
 *         return GiacMethods['line'](self,*args)
 * 
 *      def line_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1653line_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_line_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__851)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_line_graph, __pyx_t_2) < 0) __PYX_ERR(2, 10338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10349
 *         return GiacMethods['line_graph'](self,*args)
 * 
 *      def line_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_inter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1655line_inter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_line_inter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__852)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_line_inter, __pyx_t_2) < 0) __PYX_ERR(2, 10349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10366
 *         return GiacMethods['line_inter'](self,*args)
 * 
 *      def line_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_paper:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1657line_paper, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_line_paper, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__853)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_line_paper, __pyx_t_2) < 0) __PYX_ERR(2, 10366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10378
 *         return GiacMethods['line_paper'](self,*args)
 * 
 *      def line_segments(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for line_segments:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1659line_segments, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_line_segments, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__854)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_line_segments, __pyx_t_2) < 0) __PYX_ERR(2, 10378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10390
 *         return GiacMethods['line_segments'](self,*args)
 * 
 *      def linear_interpolate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_interpolate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1661linear_interpolate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linear_interpol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__855)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linear_interpolate, __pyx_t_2) < 0) __PYX_ERR(2, 10390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10401
 *         return GiacMethods['linear_interpolate'](self,*args)
 * 
 *      def linear_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1663linear_regression, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linear_regressi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__856)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linear_regression, __pyx_t_2) < 0) __PYX_ERR(2, 10401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10413
 *         return GiacMethods['linear_regression'](self,*args)
 * 
 *      def linear_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linear_regression_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1665linear_regression_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linear_regressi_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__857)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linear_regression_plot, __pyx_t_2) < 0) __PYX_ERR(2, 10413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10425
 *         return GiacMethods['linear_regression_plot'](self,*args)
 * 
 *      def lineariser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1667lineariser, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lineariser, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__858)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lineariser, __pyx_t_2) < 0) __PYX_ERR(2, 10425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10437
 *         return GiacMethods['lineariser'](self,*args)
 * 
 *      def lineariser_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lineariser_trigo:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1669lineariser_trigo, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lineariser_trig, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__859)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lineariser_trigo, __pyx_t_2) < 0) __PYX_ERR(2, 10437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10449
 *         return GiacMethods['lineariser_trigo'](self,*args)
 * 
 *      def linfnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linfnorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1671linfnorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linfnorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__860)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linfnorm, __pyx_t_2) < 0) __PYX_ERR(2, 10449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10460
 *         return GiacMethods['linfnorm'](self,*args)
 * 
 *      def linsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1673linsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__861)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linsolve, __pyx_t_2) < 0) __PYX_ERR(2, 10460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10479
 *         return GiacMethods['linsolve'](self,*args)
 * 
 *      def linspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linspace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1675linspace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linspace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__862)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linspace, __pyx_t_2) < 0) __PYX_ERR(2, 10479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10489
 *         return GiacMethods['linspace'](self,*args)
 * 
 *      def linstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for linstep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1677linstep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_linstep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__863)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_linstep, __pyx_t_2) < 0) __PYX_ERR(2, 10489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10502
 *         return GiacMethods['linstep'](self,*args)
 * 
 *      def lis_phrase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lis_phrase:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1679lis_phrase, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lis_phrase, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__864)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lis_phrase, __pyx_t_2) < 0) __PYX_ERR(2, 10502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10513
 *         return GiacMethods['lis_phrase'](self,*args)
 * 
 *      def list2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2exp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1681list2exp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_list2exp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__865)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_list2exp, __pyx_t_2) < 0) __PYX_ERR(2, 10513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10525
 *         return GiacMethods['list2exp'](self,*args)
 * 
 *      def list2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list2mat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1683list2mat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_list2mat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__866)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_list2mat, __pyx_t_2) < 0) __PYX_ERR(2, 10525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10537
 *         return GiacMethods['list2mat'](self,*args)
 * 
 *      def list_edge_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_edge_attributes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1685list_edge_attributes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_list_edge_attri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__867)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_list_edge_attributes, __pyx_t_2) < 0) __PYX_ERR(2, 10537, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10547
 *         return GiacMethods['list_edge_attributes'](self,*args)
 * 
 *      def list_graph_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_graph_attributes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1687list_graph_attributes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_list_graph_attr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__868)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_list_graph_attributes, __pyx_t_2) < 0) __PYX_ERR(2, 10547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10557
 *         return GiacMethods['list_graph_attributes'](self,*args)
 * 
 *      def list_vertex_attributes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for list_vertex_attributes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1689list_vertex_attributes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_list_vertex_att, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__869)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_list_vertex_attributes, __pyx_t_2) < 0) __PYX_ERR(2, 10557, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10567
 *         return GiacMethods['list_vertex_attributes'](self,*args)
 * 
 *      def listplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for listplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1691listplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_listplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__870)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_listplot, __pyx_t_2) < 0) __PYX_ERR(2, 10567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10580
 *         return GiacMethods['listplot'](self,*args)
 * 
 *      def lll(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lll:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1693lll, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lll, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__871)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lll, __pyx_t_2) < 0) __PYX_ERR(2, 10580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10590
 *         return GiacMethods['lll'](self,*args)
 * 
 *      def ln(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ln:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1695ln, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ln, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__872)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ln, __pyx_t_2) < 0) __PYX_ERR(2, 10590, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10603
 *         return GiacMethods['ln'](self,*args)
 * 
 *      def lname(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lname:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1697lname, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lname, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__873)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lname, __pyx_t_2) < 0) __PYX_ERR(2, 10603, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10614
 *         return GiacMethods['lname'](self,*args)
 * 
 *      def lncollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lncollect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1699lncollect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lncollect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__874)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lncollect, __pyx_t_2) < 0) __PYX_ERR(2, 10614, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10625
 *         return GiacMethods['lncollect'](self,*args)
 * 
 *      def lnexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lnexpand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1701lnexpand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lnexpand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__875)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lnexpand, __pyx_t_2) < 0) __PYX_ERR(2, 10625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10636
 *         return GiacMethods['lnexpand'](self,*args)
 * 
 *      def locus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for locus:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1703locus, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_locus, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__876)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_locus, __pyx_t_2) < 0) __PYX_ERR(2, 10636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10648
 *         return GiacMethods['locus'](self,*args)
 * 
 *      def log(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1705log, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_log, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__877)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_log, __pyx_t_2) < 0) __PYX_ERR(2, 10648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10661
 *         return GiacMethods['log'](self,*args)
 * 
 *      def log10(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log10:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1707log10, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_log10, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__878)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_log10, __pyx_t_2) < 0) __PYX_ERR(2, 10661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10672
 *         return GiacMethods['log10'](self,*args)
 * 
 *      def log2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1709log2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_log2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__879)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_log2, __pyx_t_2) < 0) __PYX_ERR(2, 10672, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10683
 *         return GiacMethods['log2'](self,*args)
 * 
 *      def log_loss(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for log_loss:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1711log_loss, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_log_loss, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__880)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_log_loss, __pyx_t_2) < 0) __PYX_ERR(2, 10683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10693
 *         return GiacMethods['log_loss'](self,*args)
 * 
 *      def logarithmic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1713logarithmic_regression, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_logarithmic_reg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__881)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_logarithmic_regression, __pyx_t_2) < 0) __PYX_ERR(2, 10693, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10705
 *         return GiacMethods['logarithmic_regression'](self,*args)
 * 
 *      def logarithmic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logarithmic_regression_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1715logarithmic_regression_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_logarithmic_reg_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__882)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_logarithmic_regression_plot, __pyx_t_2) < 0) __PYX_ERR(2, 10705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10717
 *         return GiacMethods['logarithmic_regression_plot'](self,*args)
 * 
 *      def logb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1717logb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_logb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__883)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_logb, __pyx_t_2) < 0) __PYX_ERR(2, 10717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10729
 *         return GiacMethods['logb'](self,*args)
 * 
 *      def logistic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1719logistic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_logistic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__884)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_logistic, __pyx_t_2) < 0) __PYX_ERR(2, 10729, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10741
 *         return GiacMethods['logistic'](self,*args)
 * 
 *      def logistic_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1721logistic_regression, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_logistic_regres, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__885)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_logistic_regression, __pyx_t_2) < 0) __PYX_ERR(2, 10741, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10753
 *         return GiacMethods['logistic_regression'](self,*args)
 * 
 *      def logistic_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for logistic_regression_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1723logistic_regression_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_logistic_regres_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__886)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_logistic_regression_plot, __pyx_t_2) < 0) __PYX_ERR(2, 10753, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10765
 *         return GiacMethods['logistic_regression_plot'](self,*args)
 * 
 *      def lower(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lower:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1725lower, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lower, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__887)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lower, __pyx_t_2) < 0) __PYX_ERR(2, 10765, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10777
 *         return GiacMethods['lower'](self,*args)
 * 
 *      def lowest_common_ancestor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowest_common_ancestor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1727lowest_common_ancestor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lowest_common_a, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__888)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lowest_common_ancestor, __pyx_t_2) < 0) __PYX_ERR(2, 10777, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10789
 *         return GiacMethods['lowest_common_ancestor'](self,*args)
 * 
 *      def lowpass(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lowpass:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1729lowpass, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lowpass, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__889)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lowpass, __pyx_t_2) < 0) __PYX_ERR(2, 10789, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10800
 *         return GiacMethods['lowpass'](self,*args)
 * 
 *      def lp_assume(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_assume:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1731lp_assume, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_assume, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__890)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_assume, __pyx_t_2) < 0) __PYX_ERR(2, 10800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10810
 *         return GiacMethods['lp_assume'](self,*args)
 * 
 *      def lp_bestlocalbound(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestlocalbound:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1733lp_bestlocalbound, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_bestlocalbou, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__891)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_bestlocalbound, __pyx_t_2) < 0) __PYX_ERR(2, 10810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10820
 *         return GiacMethods['lp_bestlocalbound'](self,*args)
 * 
 *      def lp_bestprojection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_bestprojection:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1735lp_bestprojection, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_bestprojecti, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__892)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_bestprojection, __pyx_t_2) < 0) __PYX_ERR(2, 10820, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10830
 *         return GiacMethods['lp_bestprojection'](self,*args)
 * 
 *      def lp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binary:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1737lp_binary, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_binary, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__893)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_binary, __pyx_t_2) < 0) __PYX_ERR(2, 10830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10840
 *         return GiacMethods['lp_binary'](self,*args)
 * 
 *      def lp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_binaryvariables:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1739lp_binaryvariables, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_binaryvariab, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__894)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_binaryvariables, __pyx_t_2) < 0) __PYX_ERR(2, 10840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10850
 *         return GiacMethods['lp_binaryvariables'](self,*args)
 * 
 *      def lp_breadthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_breadthfirst:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1741lp_breadthfirst, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_breadthfirst, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__895)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_breadthfirst, __pyx_t_2) < 0) __PYX_ERR(2, 10850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10860
 *         return GiacMethods['lp_breadthfirst'](self,*args)
 * 
 *      def lp_depthfirst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthfirst:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1743lp_depthfirst, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_depthfirst, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__896)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_depthfirst, __pyx_t_2) < 0) __PYX_ERR(2, 10860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10870
 *         return GiacMethods['lp_depthfirst'](self,*args)
 * 
 *      def lp_depthlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_depthlimit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1745lp_depthlimit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_depthlimit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__897)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_depthlimit, __pyx_t_2) < 0) __PYX_ERR(2, 10870, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10880
 *         return GiacMethods['lp_depthlimit'](self,*args)
 * 
 *      def lp_firstfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_firstfractional:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1747lp_firstfractional, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_firstfractio, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__898)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_firstfractional, __pyx_t_2) < 0) __PYX_ERR(2, 10880, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10890
 *         return GiacMethods['lp_firstfractional'](self,*args)
 * 
 *      def lp_gaptolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_gaptolerance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1749lp_gaptolerance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_gaptolerance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__899)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_gaptolerance, __pyx_t_2) < 0) __PYX_ERR(2, 10890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10900
 *         return GiacMethods['lp_gaptolerance'](self,*args)
 * 
 *      def lp_heuristic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_heuristic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1751lp_heuristic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_heuristic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__900)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_heuristic, __pyx_t_2) < 0) __PYX_ERR(2, 10900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10910
 *         return GiacMethods['lp_heuristic'](self,*args)
 * 
 *      def lp_hybrid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_hybrid:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1753lp_hybrid, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_hybrid, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__901)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_hybrid, __pyx_t_2) < 0) __PYX_ERR(2, 10910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10920
 *         return GiacMethods['lp_hybrid'](self,*args)
 * 
 *      def lp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1755lp_integer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_integer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__902)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_integer, __pyx_t_2) < 0) __PYX_ERR(2, 10920, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10930
 *         return GiacMethods['lp_integer'](self,*args)
 * 
 *      def lp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_integervariables:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1757lp_integervariables, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_integervaria, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__903)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_integervariables, __pyx_t_2) < 0) __PYX_ERR(2, 10930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10940
 *         return GiacMethods['lp_integervariables'](self,*args)
 * 
 *      def lp_interiorpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_interiorpoint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1759lp_interiorpoint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_interiorpoin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__904)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_interiorpoint, __pyx_t_2) < 0) __PYX_ERR(2, 10940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10950
 *         return GiacMethods['lp_interiorpoint'](self,*args)
 * 
 *      def lp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_iterationlimit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1761lp_iterationlimit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_iterationlim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__905)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_iterationlimit, __pyx_t_2) < 0) __PYX_ERR(2, 10950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10960
 *         return GiacMethods['lp_iterationlimit'](self,*args)
 * 
 *      def lp_lastfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_lastfractional:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1763lp_lastfractional, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_lastfraction, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__906)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_lastfractional, __pyx_t_2) < 0) __PYX_ERR(2, 10960, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10970
 *         return GiacMethods['lp_lastfractional'](self,*args)
 * 
 *      def lp_maxcuts(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maxcuts:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1765lp_maxcuts, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_maxcuts, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__907)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_maxcuts, __pyx_t_2) < 0) __PYX_ERR(2, 10970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10980
 *         return GiacMethods['lp_maxcuts'](self,*args)
 * 
 *      def lp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_maximize:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1767lp_maximize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_maximize, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__908)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_maximize, __pyx_t_2) < 0) __PYX_ERR(2, 10980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":10990
 *         return GiacMethods['lp_maximize'](self,*args)
 * 
 *      def lp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_method:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1769lp_method, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_method, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__909)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 10990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_method, __pyx_t_2) < 0) __PYX_ERR(2, 10990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11000
 *         return GiacMethods['lp_method'](self,*args)
 * 
 *      def lp_mostfractional(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_mostfractional:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1771lp_mostfractional, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_mostfraction, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__910)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_mostfractional, __pyx_t_2) < 0) __PYX_ERR(2, 11000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11010
 *         return GiacMethods['lp_mostfractional'](self,*args)
 * 
 *      def lp_nodelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodelimit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1773lp_nodelimit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_nodelimit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__911)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_nodelimit, __pyx_t_2) < 0) __PYX_ERR(2, 11010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11020
 *         return GiacMethods['lp_nodelimit'](self,*args)
 * 
 *      def lp_nodeselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nodeselect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1775lp_nodeselect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_nodeselect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__912)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_nodeselect, __pyx_t_2) < 0) __PYX_ERR(2, 11020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11030
 *         return GiacMethods['lp_nodeselect'](self,*args)
 * 
 *      def lp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegative:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1777lp_nonnegative, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_nonnegative, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__913)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_nonnegative, __pyx_t_2) < 0) __PYX_ERR(2, 11030, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11040
 *         return GiacMethods['lp_nonnegative'](self,*args)
 * 
 *      def lp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_nonnegint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1779lp_nonnegint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_nonnegint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__914)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_nonnegint, __pyx_t_2) < 0) __PYX_ERR(2, 11040, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11050
 *         return GiacMethods['lp_nonnegint'](self,*args)
 * 
 *      def lp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_presolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1781lp_presolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_presolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__915)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_presolve, __pyx_t_2) < 0) __PYX_ERR(2, 11050, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11060
 *         return GiacMethods['lp_presolve'](self,*args)
 * 
 *      def lp_pseudocost(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_pseudocost:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1783lp_pseudocost, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_pseudocost, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__916)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_pseudocost, __pyx_t_2) < 0) __PYX_ERR(2, 11060, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11070
 *         return GiacMethods['lp_pseudocost'](self,*args)
 * 
 *      def lp_simplex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_simplex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1785lp_simplex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_simplex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__917)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_simplex, __pyx_t_2) < 0) __PYX_ERR(2, 11070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11080
 *         return GiacMethods['lp_simplex'](self,*args)
 * 
 *      def lp_timelimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_timelimit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1787lp_timelimit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_timelimit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__918)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_timelimit, __pyx_t_2) < 0) __PYX_ERR(2, 11080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11090
 *         return GiacMethods['lp_timelimit'](self,*args)
 * 
 *      def lp_varselect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_varselect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1789lp_varselect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_varselect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__919)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_varselect, __pyx_t_2) < 0) __PYX_ERR(2, 11090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11100
 *         return GiacMethods['lp_varselect'](self,*args)
 * 
 *      def lp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lp_verbose:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1791lp_verbose, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lp_verbose, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__920)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lp_verbose, __pyx_t_2) < 0) __PYX_ERR(2, 11100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11110
 *         return GiacMethods['lp_verbose'](self,*args)
 * 
 *      def lpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lpsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1793lpsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lpsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__921)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lpsolve, __pyx_t_2) < 0) __PYX_ERR(2, 11110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11127
 *         return GiacMethods['lpsolve'](self,*args)
 * 
 *      def lsmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1795lsmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lsmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__922)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lsmod, __pyx_t_2) < 0) __PYX_ERR(2, 11127, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11138
 *         return GiacMethods['lsmod'](self,*args)
 * 
 *      def lsq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lsq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1797lsq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lsq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__923)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lsq, __pyx_t_2) < 0) __PYX_ERR(2, 11138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11150
 *         return GiacMethods['lsq'](self,*args)
 * 
 *      def lu(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lu:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1799lu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__924)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lu, __pyx_t_2) < 0) __PYX_ERR(2, 11150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11162
 *         return GiacMethods['lu'](self,*args)
 * 
 *      def lvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for lvar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1801lvar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_lvar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__925)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_lvar, __pyx_t_2) < 0) __PYX_ERR(2, 11162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11174
 *         return GiacMethods['lvar'](self,*args)
 * 
 *      def mRow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRow:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1803mRow, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mRow, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__926)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mRow, __pyx_t_2) < 0) __PYX_ERR(2, 11174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11185
 *         return GiacMethods['mRow'](self,*args)
 * 
 *      def mRowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mRowAdd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1805mRowAdd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mRowAdd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__927)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mRowAdd, __pyx_t_2) < 0) __PYX_ERR(2, 11185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11196
 *         return GiacMethods['mRowAdd'](self,*args)
 * 
 *      def magenta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for magenta:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1807magenta, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_magenta, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__928)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_magenta, __pyx_t_2) < 0) __PYX_ERR(2, 11196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11208
 *         return GiacMethods['magenta'](self,*args)
 * 
 *      def make_directed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_directed:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1809make_directed, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_make_directed, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__929)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_make_directed, __pyx_t_2) < 0) __PYX_ERR(2, 11208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11219
 *         return GiacMethods['make_directed'](self,*args)
 * 
 *      def make_symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_symbol:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1811make_symbol, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_make_symbol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__930)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_make_symbol, __pyx_t_2) < 0) __PYX_ERR(2, 11219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11230
 *         return GiacMethods['make_symbol'](self,*args)
 * 
 *      def make_weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for make_weighted:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1813make_weighted, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_make_weighted, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__931)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_make_weighted, __pyx_t_2) < 0) __PYX_ERR(2, 11230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11241
 *         return GiacMethods['make_weighted'](self,*args)
 * 
 *      def makelist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makelist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1815makelist, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_makelist, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__932)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_makelist, __pyx_t_2) < 0) __PYX_ERR(2, 11241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11255
 *         return GiacMethods['makelist'](self,*args)
 * 
 *      def makemat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makemat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1817makemat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_makemat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__933)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_makemat, __pyx_t_2) < 0) __PYX_ERR(2, 11255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11268
 *         return GiacMethods['makemat'](self,*args)
 * 
 *      def makesuite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makesuite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1819makesuite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_makesuite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__934)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_makesuite, __pyx_t_2) < 0) __PYX_ERR(2, 11268, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11279
 *         return GiacMethods['makesuite'](self,*args)
 * 
 *      def makevector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for makevector:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1821makevector, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_makevector, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__935)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_makevector, __pyx_t_2) < 0) __PYX_ERR(2, 11279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11290
 *         return GiacMethods['makevector'](self,*args)
 * 
 *      def map(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for map:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1823map, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_map, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__936)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_map, __pyx_t_2) < 0) __PYX_ERR(2, 11290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11303
 *         return GiacMethods['map'](self,*args)
 * 
 *      def maple2mupad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2mupad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1825maple2mupad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maple2mupad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__937)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maple2mupad, __pyx_t_2) < 0) __PYX_ERR(2, 11303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11313
 *         return GiacMethods['maple2mupad'](self,*args)
 * 
 *      def maple2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple2xcas:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1827maple2xcas, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maple2xcas, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__938)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maple2xcas, __pyx_t_2) < 0) __PYX_ERR(2, 11313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11323
 *         return GiacMethods['maple2xcas'](self,*args)
 * 
 *      def maple_ifactors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_ifactors:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1829maple_ifactors, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maple_ifactors, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__939)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maple_ifactors, __pyx_t_2) < 0) __PYX_ERR(2, 11323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11334
 *         return GiacMethods['maple_ifactors'](self,*args)
 * 
 *      def maple_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maple_mode:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1831maple_mode, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maple_mode, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__940)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maple_mode, __pyx_t_2) < 0) __PYX_ERR(2, 11334, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11346
 *         return GiacMethods['maple_mode'](self,*args)
 * 
 *      def markov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for markov:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1833markov, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_markov, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__941)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_markov, __pyx_t_2) < 0) __PYX_ERR(2, 11346, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11357
 *         return GiacMethods['markov'](self,*args)
 * 
 *      def mat2list(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mat2list:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1835mat2list, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mat2list, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__942)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mat2list, __pyx_t_2) < 0) __PYX_ERR(2, 11357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11368
 *         return GiacMethods['mat2list'](self,*args)
 * 
 *      def mathml(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mathml:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1837mathml, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mathml, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__943)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mathml, __pyx_t_2) < 0) __PYX_ERR(2, 11368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11379
 *         return GiacMethods['mathml'](self,*args)
 * 
 *      def matpow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matpow:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1839matpow, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_matpow, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__944)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_matpow, __pyx_t_2) < 0) __PYX_ERR(2, 11379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11390
 *         return GiacMethods['matpow'](self,*args)
 * 
 *      def matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1841matrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_matrix, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__945)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_matrix, __pyx_t_2) < 0) __PYX_ERR(2, 11390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11404
 *         return GiacMethods['matrix'](self,*args)
 * 
 *      def matrix_norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for matrix_norm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1843matrix_norm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_matrix_norm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__946)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_matrix_norm, __pyx_t_2) < 0) __PYX_ERR(2, 11404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11418
 *         return GiacMethods['matrix_norm'](self,*args)
 * 
 *      def max(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for max:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1845max, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_max, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__947)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_max, __pyx_t_2) < 0) __PYX_ERR(2, 11418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11429
 *         return GiacMethods['max'](self,*args)
 * 
 *      def maxflow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxflow:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1847maxflow, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maxflow, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__948)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maxflow, __pyx_t_2) < 0) __PYX_ERR(2, 11429, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11440
 *         return GiacMethods['maxflow'](self,*args)
 * 
 *      def maximal_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximal_independent_set:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1849maximal_independent_set, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maximal_indepen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__949)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maximal_independent_set, __pyx_t_2) < 0) __PYX_ERR(2, 11440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11451
 *         return GiacMethods['maximal_independent_set'](self,*args)
 * 
 *      def maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximize:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1851maximize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maximize, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__950)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maximize, __pyx_t_2) < 0) __PYX_ERR(2, 11451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11468
 *         return GiacMethods['maximize'](self,*args)
 * 
 *      def maximum_clique(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_clique:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1853maximum_clique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maximum_clique, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__951)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maximum_clique, __pyx_t_2) < 0) __PYX_ERR(2, 11468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11479
 *         return GiacMethods['maximum_clique'](self,*args)
 * 
 *      def maximum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1855maximum_degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maximum_degree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__952)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maximum_degree, __pyx_t_2) < 0) __PYX_ERR(2, 11479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11490
 *         return GiacMethods['maximum_degree'](self,*args)
 * 
 *      def maximum_independent_set(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_independent_set:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1857maximum_independent_set, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maximum_indepen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__953)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maximum_independent_set, __pyx_t_2) < 0) __PYX_ERR(2, 11490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11501
 *         return GiacMethods['maximum_independent_set'](self,*args)
 * 
 *      def maximum_matching(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maximum_matching:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1859maximum_matching, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maximum_matchin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__954)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maximum_matching, __pyx_t_2) < 0) __PYX_ERR(2, 11501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11512
 *         return GiacMethods['maximum_matching'](self,*args)
 * 
 *      def maxnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for maxnorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1861maxnorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_maxnorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__955)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_maxnorm, __pyx_t_2) < 0) __PYX_ERR(2, 11512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11525
 *         return GiacMethods['maxnorm'](self,*args)
 * 
 *      def mean(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mean:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1863mean, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mean, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__956)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mean, __pyx_t_2) < 0) __PYX_ERR(2, 11525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11538
 *         return GiacMethods['mean'](self,*args)
 * 
 *      def median(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1865median, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_median, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__957)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_median, __pyx_t_2) < 0) __PYX_ERR(2, 11538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11550
 *         return GiacMethods['median'](self,*args)
 * 
 *      def median_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for median_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1867median_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_median_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__958)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_median_line, __pyx_t_2) < 0) __PYX_ERR(2, 11550, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11561
 *         return GiacMethods['median_line'](self,*args)
 * 
 *      def member(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for member:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1869member, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_member, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__959)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_member, __pyx_t_2) < 0) __PYX_ERR(2, 11561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11573
 *         return GiacMethods['member'](self,*args)
 * 
 *      def mgf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mgf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1871mgf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mgf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__960)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mgf, __pyx_t_2) < 0) __PYX_ERR(2, 11573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11585
 *         return GiacMethods['mgf'](self,*args)
 * 
 *      def mid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mid:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1873mid, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mid, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__961)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mid, __pyx_t_2) < 0) __PYX_ERR(2, 11585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11600
 *         return GiacMethods['mid'](self,*args)
 * 
 *      def middle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for middle_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1875middle_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_middle_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__962)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_middle_point, __pyx_t_2) < 0) __PYX_ERR(2, 11600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11616
 *         return GiacMethods['middle_point'](self,*args)
 * 
 *      def midpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for midpoint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1877midpoint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_midpoint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__963)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_midpoint, __pyx_t_2) < 0) __PYX_ERR(2, 11616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11627
 *         return GiacMethods['midpoint'](self,*args)
 * 
 *      def min(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for min:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1879min, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_min, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__964)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_min, __pyx_t_2) < 0) __PYX_ERR(2, 11627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11638
 *         return GiacMethods['min'](self,*args)
 * 
 *      def minimal_edge_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_edge_coloring:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1881minimal_edge_coloring, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimal_edge_co, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__965)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimal_edge_coloring, __pyx_t_2) < 0) __PYX_ERR(2, 11638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11650
 *         return GiacMethods['minimal_edge_coloring'](self,*args)
 * 
 *      def minimal_spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_spanning_tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1883minimal_spanning_tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimal_spannin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__966)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimal_spanning_tree, __pyx_t_2) < 0) __PYX_ERR(2, 11650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11661
 *         return GiacMethods['minimal_spanning_tree'](self,*args)
 * 
 *      def minimal_vertex_coloring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimal_vertex_coloring:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1885minimal_vertex_coloring, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimal_vertex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__967)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimal_vertex_coloring, __pyx_t_2) < 0) __PYX_ERR(2, 11661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11673
 *         return GiacMethods['minimal_vertex_coloring'](self,*args)
 * 
 *      def minimax(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimax:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1887minimax, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimax, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__968)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimax, __pyx_t_2) < 0) __PYX_ERR(2, 11673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11686
 *         return GiacMethods['minimax'](self,*args)
 * 
 *      def minimize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimize:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1889minimize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimize, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__969)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimize, __pyx_t_2) < 0) __PYX_ERR(2, 11686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11703
 *         return GiacMethods['minimize'](self,*args)
 * 
 *      def minimum_cut(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_cut:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1891minimum_cut, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimum_cut, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__970)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimum_cut, __pyx_t_2) < 0) __PYX_ERR(2, 11703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11714
 *         return GiacMethods['minimum_cut'](self,*args)
 * 
 *      def minimum_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1893minimum_degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimum_degree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__971)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimum_degree, __pyx_t_2) < 0) __PYX_ERR(2, 11714, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11725
 *         return GiacMethods['minimum_degree'](self,*args)
 * 
 *      def minimum_vertex_cover(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for minimum_vertex_cover:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1895minimum_vertex_cover, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_minimum_vertex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__972)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_minimum_vertex_cover, __pyx_t_2) < 0) __PYX_ERR(2, 11725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11736
 *         return GiacMethods['minimum_vertex_cover'](self,*args)
 * 
 *      def mixdown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mixdown:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1897mixdown, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mixdown, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__973)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mixdown, __pyx_t_2) < 0) __PYX_ERR(2, 11736, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11746
 *         return GiacMethods['mixdown'](self,*args)
 * 
 *      def mkisom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mkisom:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1899mkisom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mkisom, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__974)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mkisom, __pyx_t_2) < 0) __PYX_ERR(2, 11746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11759
 *         return GiacMethods['mkisom'](self,*args)
 * 
 *      def mksa(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mksa:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1901mksa, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mksa, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__975)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mksa, __pyx_t_2) < 0) __PYX_ERR(2, 11759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11770
 *         return GiacMethods['mksa'](self,*args)
 * 
 *      def modf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1903modf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_modf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__976)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_modf, __pyx_t_2) < 0) __PYX_ERR(2, 11770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11782
 *         return GiacMethods['modf'](self,*args)
 * 
 *      def modgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for modgcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1905modgcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_modgcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__977)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_modgcd, __pyx_t_2) < 0) __PYX_ERR(2, 11782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11793
 *         return GiacMethods['modgcd'](self,*args)
 * 
 *      def mods(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mods:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1907mods, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mods, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__978)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mods, __pyx_t_2) < 0) __PYX_ERR(2, 11793, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11806
 *         return GiacMethods['mods'](self,*args)
 * 
 *      def momentum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for momentum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1909momentum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_momentum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__979)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_momentum, __pyx_t_2) < 0) __PYX_ERR(2, 11806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11816
 *         return GiacMethods['momentum'](self,*args)
 * 
 *      def monotonic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for monotonic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1911monotonic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_monotonic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__980)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_monotonic, __pyx_t_2) < 0) __PYX_ERR(2, 11816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11826
 *         return GiacMethods['monotonic'](self,*args)
 * 
 *      def montre_tortue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for montre_tortue:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1913montre_tortue, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_montre_tortue, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__981)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_montre_tortue, __pyx_t_2) < 0) __PYX_ERR(2, 11826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11837
 *         return GiacMethods['montre_tortue'](self,*args)
 * 
 *      def moustache(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moustache:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1915moustache, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_moustache, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__982)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_moustache, __pyx_t_2) < 0) __PYX_ERR(2, 11837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11851
 *         return GiacMethods['moustache'](self,*args)
 * 
 *      def moving_average(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moving_average:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1917moving_average, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_moving_average, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__983)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_moving_average, __pyx_t_2) < 0) __PYX_ERR(2, 11851, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11862
 *         return GiacMethods['moving_average'](self,*args)
 * 
 *      def moyal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1919moyal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_moyal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__984)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_moyal, __pyx_t_2) < 0) __PYX_ERR(2, 11862, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11873
 *         return GiacMethods['moyal'](self,*args)
 * 
 *      def moyenne(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for moyenne:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1921moyenne, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_moyenne, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__985)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_moyenne, __pyx_t_2) < 0) __PYX_ERR(2, 11873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11886
 *         return GiacMethods['moyenne'](self,*args)
 * 
 *      def mul(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mul:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1923mul, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mul, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__986)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mul, __pyx_t_2) < 0) __PYX_ERR(2, 11886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11903
 *         return GiacMethods['mul'](self,*args)
 * 
 *      def mult_c_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_c_conjugate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1925mult_c_conjugate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mult_c_conjugat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__987)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mult_c_conjugate, __pyx_t_2) < 0) __PYX_ERR(2, 11903, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11915
 *         return GiacMethods['mult_c_conjugate'](self,*args)
 * 
 *      def mult_conjugate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mult_conjugate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1927mult_conjugate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mult_conjugate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__988)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mult_conjugate, __pyx_t_2) < 0) __PYX_ERR(2, 11915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11927
 *         return GiacMethods['mult_conjugate'](self,*args)
 * 
 *      def multinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multinomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1929multinomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_multinomial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__989)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_multinomial, __pyx_t_2) < 0) __PYX_ERR(2, 11927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11941
 *         return GiacMethods['multinomial'](self,*args)
 * 
 *      def multiplier_conjugue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1931multiplier_conjugue, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_multiplier_conj, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__990)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_multiplier_conjugue, __pyx_t_2) < 0) __PYX_ERR(2, 11941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11953
 *         return GiacMethods['multiplier_conjugue'](self,*args)
 * 
 *      def multiplier_conjugue_complexe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiplier_conjugue_complexe:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1933multiplier_conjugue_complexe, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_multiplier_conj_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__991)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_multiplier_conjugue_complexe, __pyx_t_2) < 0) __PYX_ERR(2, 11953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11965
 *         return GiacMethods['multiplier_conjugue_complexe'](self,*args)
 * 
 *      def multiply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for multiply:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1935multiply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_multiply, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__992)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_multiply, __pyx_t_2) < 0) __PYX_ERR(2, 11965, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11978
 *         return GiacMethods['multiply'](self,*args)
 * 
 *      def mupad2maple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2maple:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1937mupad2maple, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mupad2maple, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__993)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mupad2maple, __pyx_t_2) < 0) __PYX_ERR(2, 11978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11988
 *         return GiacMethods['mupad2maple'](self,*args)
 * 
 *      def mupad2xcas(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mupad2xcas:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1939mupad2xcas, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mupad2xcas, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__994)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mupad2xcas, __pyx_t_2) < 0) __PYX_ERR(2, 11988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":11998
 *         return GiacMethods['mupad2xcas'](self,*args)
 * 
 *      def mycielski(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for mycielski:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1941mycielski, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_mycielski, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__995)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 11998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_mycielski, __pyx_t_2) < 0) __PYX_ERR(2, 11998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12010
 *         return GiacMethods['mycielski'](self,*args)
 * 
 *      def nCr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nCr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1943nCr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nCr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__996)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nCr, __pyx_t_2) < 0) __PYX_ERR(2, 12010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12021
 *         return GiacMethods['nCr'](self,*args)
 * 
 *      def nDeriv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nDeriv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1945nDeriv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nDeriv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__997)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nDeriv, __pyx_t_2) < 0) __PYX_ERR(2, 12021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12034
 *         return GiacMethods['nDeriv'](self,*args)
 * 
 *      def nInt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nInt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1947nInt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nInt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__998)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nInt, __pyx_t_2) < 0) __PYX_ERR(2, 12034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12047
 *         return GiacMethods['nInt'](self,*args)
 * 
 *      def nPr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nPr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1949nPr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nPr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__999)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nPr, __pyx_t_2) < 0) __PYX_ERR(2, 12047, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12058
 *         return GiacMethods['nPr'](self,*args)
 * 
 *      def nSolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nSolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1951nSolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nSolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1000)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nSolve, __pyx_t_2) < 0) __PYX_ERR(2, 12058, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12070
 *         return GiacMethods['nSolve'](self,*args)
 * 
 *      def navy(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for navy:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1953navy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_navy, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1001)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_navy, __pyx_t_2) < 0) __PYX_ERR(2, 12070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12082
 *         return GiacMethods['navy'](self,*args)
 * 
 *      def ncols(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ncols:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1955ncols, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ncols, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1002)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ncols, __pyx_t_2) < 0) __PYX_ERR(2, 12082, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12094
 *         return GiacMethods['ncols'](self,*args)
 * 
 *      def negbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1957negbinomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_negbinomial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1003)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_negbinomial, __pyx_t_2) < 0) __PYX_ERR(2, 12094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12107
 *         return GiacMethods['negbinomial'](self,*args)
 * 
 *      def negbinomial_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1959negbinomial_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_negbinomial_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1004)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_negbinomial_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 12107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12120
 *         return GiacMethods['negbinomial_cdf'](self,*args)
 * 
 *      def negbinomial_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for negbinomial_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1961negbinomial_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_negbinomial_icd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1005)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_negbinomial_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 12120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12132
 *         return GiacMethods['negbinomial_icdf'](self,*args)
 * 
 *      def neighbors(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neighbors:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1963neighbors, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_neighbors, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1006)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_neighbors, __pyx_t_2) < 0) __PYX_ERR(2, 12132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12143
 *         return GiacMethods['neighbors'](self,*args)
 * 
 *      def network_transitivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for network_transitivity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1965network_transitivity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_network_transit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1007)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_network_transitivity, __pyx_t_2) < 0) __PYX_ERR(2, 12143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12154
 *         return GiacMethods['network_transitivity'](self,*args)
 * 
 *      def neural_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for neural_network:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1967neural_network, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_neural_network, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1008)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_neural_network, __pyx_t_2) < 0) __PYX_ERR(2, 12154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12166
 *         return GiacMethods['neural_network'](self,*args)
 * 
 *      def newList(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newList:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1969newList, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_newList, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1009)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_newList, __pyx_t_2) < 0) __PYX_ERR(2, 12166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12177
 *         return GiacMethods['newList'](self,*args)
 * 
 *      def newMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newMat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1971newMat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_newMat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1010)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_newMat, __pyx_t_2) < 0) __PYX_ERR(2, 12177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12188
 *         return GiacMethods['newMat'](self,*args)
 * 
 *      def newton(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1973newton, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_newton, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1011)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_newton, __pyx_t_2) < 0) __PYX_ERR(2, 12188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12202
 *         return GiacMethods['newton'](self,*args)
 * 
 *      def newton_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newton_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1975newton_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_newton_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1012)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_newton_solver, __pyx_t_2) < 0) __PYX_ERR(2, 12202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12218
 *         return GiacMethods['newton_solver'](self,*args)
 * 
 *      def newtonj_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for newtonj_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1977newtonj_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_newtonj_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1013)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_newtonj_solver, __pyx_t_2) < 0) __PYX_ERR(2, 12218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12234
 *         return GiacMethods['newtonj_solver'](self,*args)
 * 
 *      def nextperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextperm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1979nextperm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nextperm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1014)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nextperm, __pyx_t_2) < 0) __PYX_ERR(2, 12234, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12246
 *         return GiacMethods['nextperm'](self,*args)
 * 
 *      def nextprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nextprime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1981nextprime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nextprime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1015)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nextprime, __pyx_t_2) < 0) __PYX_ERR(2, 12246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12258
 *         return GiacMethods['nextprime'](self,*args)
 * 
 *      def nlp_binary(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binary:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1983nlp_binary, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_binary, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1016)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_binary, __pyx_t_2) < 0) __PYX_ERR(2, 12258, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12268
 *         return GiacMethods['nlp_binary'](self,*args)
 * 
 *      def nlp_binaryvariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_binaryvariables:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1985nlp_binaryvariables, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_binaryvaria, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1017)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_binaryvariables, __pyx_t_2) < 0) __PYX_ERR(2, 12268, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12278
 *         return GiacMethods['nlp_binaryvariables'](self,*args)
 * 
 *      def nlp_initialpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_initialpoint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1987nlp_initialpoint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_initialpoin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1018)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_initialpoint, __pyx_t_2) < 0) __PYX_ERR(2, 12278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12288
 *         return GiacMethods['nlp_initialpoint'](self,*args)
 * 
 *      def nlp_integer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1989nlp_integer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_integer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1019)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_integer, __pyx_t_2) < 0) __PYX_ERR(2, 12288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12298
 *         return GiacMethods['nlp_integer'](self,*args)
 * 
 *      def nlp_integervariables(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_integervariables:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1991nlp_integervariables, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_integervari, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1020)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_integervariables, __pyx_t_2) < 0) __PYX_ERR(2, 12298, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12308
 *         return GiacMethods['nlp_integervariables'](self,*args)
 * 
 *      def nlp_iterationlimit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_iterationlimit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1993nlp_iterationlimit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_iterationli, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1021)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_iterationlimit, __pyx_t_2) < 0) __PYX_ERR(2, 12308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12318
 *         return GiacMethods['nlp_iterationlimit'](self,*args)
 * 
 *      def nlp_maximize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_maximize:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1995nlp_maximize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_maximize, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1022)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_maximize, __pyx_t_2) < 0) __PYX_ERR(2, 12318, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12328
 *         return GiacMethods['nlp_maximize'](self,*args)
 * 
 *      def nlp_method(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_method:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1997nlp_method, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_method, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1023)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_method, __pyx_t_2) < 0) __PYX_ERR(2, 12328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12338
 *         return GiacMethods['nlp_method'](self,*args)
 * 
 *      def nlp_nonnegative(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegative:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_1999nlp_nonnegative, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_nonnegative, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1024)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_nonnegative, __pyx_t_2) < 0) __PYX_ERR(2, 12338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12348
 *         return GiacMethods['nlp_nonnegative'](self,*args)
 * 
 *      def nlp_nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_nonnegint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2001nlp_nonnegint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_nonnegint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1025)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_nonnegint, __pyx_t_2) < 0) __PYX_ERR(2, 12348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12358
 *         return GiacMethods['nlp_nonnegint'](self,*args)
 * 
 *      def nlp_precision(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_precision:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2003nlp_precision, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_precision, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1026)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_precision, __pyx_t_2) < 0) __PYX_ERR(2, 12358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12368
 *         return GiacMethods['nlp_precision'](self,*args)
 * 
 *      def nlp_presolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_presolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2005nlp_presolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_presolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1027)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_presolve, __pyx_t_2) < 0) __PYX_ERR(2, 12368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12378
 *         return GiacMethods['nlp_presolve'](self,*args)
 * 
 *      def nlp_tolerance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_tolerance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2007nlp_tolerance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_tolerance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1028)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_tolerance, __pyx_t_2) < 0) __PYX_ERR(2, 12378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12388
 *         return GiacMethods['nlp_tolerance'](self,*args)
 * 
 *      def nlp_verbose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlp_verbose:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2009nlp_verbose, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlp_verbose, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1029)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlp_verbose, __pyx_t_2) < 0) __PYX_ERR(2, 12388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12398
 *         return GiacMethods['nlp_verbose'](self,*args)
 * 
 *      def nlpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nlpsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2011nlpsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nlpsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1030)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nlpsolve, __pyx_t_2) < 0) __PYX_ERR(2, 12398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12413
 *         return GiacMethods['nlpsolve'](self,*args)
 * 
 *      def nodisp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nodisp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2013nodisp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nodisp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1031)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nodisp, __pyx_t_2) < 0) __PYX_ERR(2, 12413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12423
 *         return GiacMethods['nodisp'](self,*args)
 * 
 *      def non_recursive_normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for non_recursive_normal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2015non_recursive_normal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_non_recursive_n, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1032)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_non_recursive_normal, __pyx_t_2) < 0) __PYX_ERR(2, 12423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12435
 *         return GiacMethods['non_recursive_normal'](self,*args)
 * 
 *      def nonnegint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nonnegint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2017nonnegint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nonnegint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1033)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nonnegint, __pyx_t_2) < 0) __PYX_ERR(2, 12435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12445
 *         return GiacMethods['nonnegint'](self,*args)
 * 
 *      def nop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nop:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2019nop, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nop, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1034)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nop, __pyx_t_2) < 0) __PYX_ERR(2, 12445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12456
 *         return GiacMethods['nop'](self,*args)
 * 
 *      def nops(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nops:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2021nops, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nops, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1035)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nops, __pyx_t_2) < 0) __PYX_ERR(2, 12456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12469
 *         return GiacMethods['nops'](self,*args)
 * 
 *      def norm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for norm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2023norm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_norm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1036)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_norm, __pyx_t_2) < 0) __PYX_ERR(2, 12469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12483
 *         return GiacMethods['norm'](self,*args)
 * 
 *      def normal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2025normal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1037)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normal, __pyx_t_2) < 0) __PYX_ERR(2, 12483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12496
 *         return GiacMethods['normal'](self,*args)
 * 
 *      def normal_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2027normal_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normal_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1038)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normal_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 12496, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12509
 *         return GiacMethods['normal_cdf'](self,*args)
 * 
 *      def normal_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normal_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2029normal_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normal_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1039)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normal_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 12509, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12521
 *         return GiacMethods['normal_icdf'](self,*args)
 * 
 *      def normald(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2031normald, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normald, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1040)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normald, __pyx_t_2) < 0) __PYX_ERR(2, 12521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12535
 *         return GiacMethods['normald'](self,*args)
 * 
 *      def normald_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2033normald_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normald_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1041)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normald_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 12535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12548
 *         return GiacMethods['normald_cdf'](self,*args)
 * 
 *      def normald_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normald_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2035normald_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normald_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1042)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normald_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 12548, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12560
 *         return GiacMethods['normald_icdf'](self,*args)
 * 
 *      def normalize(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalize:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2037normalize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normalize, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1043)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normalize, __pyx_t_2) < 0) __PYX_ERR(2, 12560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12574
 *         return GiacMethods['normalize'](self,*args)
 * 
 *      def normalt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2039normalt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normalt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1044)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normalt, __pyx_t_2) < 0) __PYX_ERR(2, 12574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12586
 *         return GiacMethods['normalt'](self,*args)
 * 
 *      def normalvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for normalvariate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2041normalvariate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_normalvariate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1045)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_normalvariate, __pyx_t_2) < 0) __PYX_ERR(2, 12586, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12598
 *         return GiacMethods['normalvariate'](self,*args)
 * 
 *      def nprimes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nprimes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2043nprimes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nprimes, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1046)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nprimes, __pyx_t_2) < 0) __PYX_ERR(2, 12598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12609
 *         return GiacMethods['nprimes'](self,*args)
 * 
 *      def nrows(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nrows:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2045nrows, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nrows, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1047)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nrows, __pyx_t_2) < 0) __PYX_ERR(2, 12609, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12621
 *         return GiacMethods['nrows'](self,*args)
 * 
 *      def nstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nstep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2047nstep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nstep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1048)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nstep, __pyx_t_2) < 0) __PYX_ERR(2, 12621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12630
 *         return GiacMethods['nstep'](self,*args)
 * 
 *      def nuage_points(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nuage_points:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2049nuage_points, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nuage_points, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1049)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nuage_points, __pyx_t_2) < 0) __PYX_ERR(2, 12630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12641
 *         return GiacMethods['nuage_points'](self,*args)
 * 
 *      def nullspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for nullspace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2051nullspace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_nullspace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1050)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_nullspace, __pyx_t_2) < 0) __PYX_ERR(2, 12641, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12653
 *         return GiacMethods['nullspace'](self,*args)
 * 
 *      def number_of_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_edges:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2053number_of_edges, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_number_of_edges, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1051)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_number_of_edges, __pyx_t_2) < 0) __PYX_ERR(2, 12653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12664
 *         return GiacMethods['number_of_edges'](self,*args)
 * 
 *      def number_of_spanning_trees(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_spanning_trees:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2055number_of_spanning_trees, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_number_of_spann, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1052)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_number_of_spanning_trees, __pyx_t_2) < 0) __PYX_ERR(2, 12664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12676
 *         return GiacMethods['number_of_spanning_trees'](self,*args)
 * 
 *      def number_of_triangles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_triangles:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2057number_of_triangles, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_number_of_trian, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1053)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_number_of_triangles, __pyx_t_2) < 0) __PYX_ERR(2, 12676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12687
 *         return GiacMethods['number_of_triangles'](self,*args)
 * 
 *      def number_of_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for number_of_vertices:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2059number_of_vertices, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_number_of_verti, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1054)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_number_of_vertices, __pyx_t_2) < 0) __PYX_ERR(2, 12687, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12698
 *         return GiacMethods['number_of_vertices'](self,*args)
 * 
 *      def numdiff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numdiff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2061numdiff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_numdiff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1055)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_numdiff, __pyx_t_2) < 0) __PYX_ERR(2, 12698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12710
 *         return GiacMethods['numdiff'](self,*args)
 * 
 *      def numer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for numer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2063numer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_numer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1056)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_numer, __pyx_t_2) < 0) __PYX_ERR(2, 12710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12723
 *         return GiacMethods['numer'](self,*args)
 * 
 *      def octahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for octahedron:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2065octahedron, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_octahedron, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1057)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_octahedron, __pyx_t_2) < 0) __PYX_ERR(2, 12723, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12735
 *         return GiacMethods['octahedron'](self,*args)
 * 
 *      def odd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2067odd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_odd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1058)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_odd, __pyx_t_2) < 0) __PYX_ERR(2, 12735, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12747
 *         return GiacMethods['odd'](self,*args)
 * 
 *      def odd_girth(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_girth:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2069odd_girth, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_odd_girth, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1059)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_odd_girth, __pyx_t_2) < 0) __PYX_ERR(2, 12747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12759
 *         return GiacMethods['odd_girth'](self,*args)
 * 
 *      def odd_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odd_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2071odd_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_odd_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1060)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_odd_graph, __pyx_t_2) < 0) __PYX_ERR(2, 12759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12770
 *         return GiacMethods['odd_graph'](self,*args)
 * 
 *      def odeplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odeplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2073odeplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_odeplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1061)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_odeplot, __pyx_t_2) < 0) __PYX_ERR(2, 12770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12787
 *         return GiacMethods['odeplot'](self,*args)
 * 
 *      def odesolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for odesolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2075odesolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_odesolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1062)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_odesolve, __pyx_t_2) < 0) __PYX_ERR(2, 12787, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12802
 *         return GiacMethods['odesolve'](self,*args)
 * 
 *      def olive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for olive:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2077olive, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_olive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1063)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_olive, __pyx_t_2) < 0) __PYX_ERR(2, 12802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12814
 *         return GiacMethods['olive'](self,*args)
 * 
 *      def op(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for op:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2079op, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_op, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1064)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_op, __pyx_t_2) < 0) __PYX_ERR(2, 12814, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12829
 *         return GiacMethods['op'](self,*args)
 * 
 *      def open_polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for open_polygon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2081open_polygon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_open_polygon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1065)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_open_polygon, __pyx_t_2) < 0) __PYX_ERR(2, 12829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12841
 *         return GiacMethods['open_polygon'](self,*args)
 * 
 *      def orange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orange:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2083orange, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_orange, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1066)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_orange, __pyx_t_2) < 0) __PYX_ERR(2, 12841, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12853
 *         return GiacMethods['orange'](self,*args)
 * 
 *      def ord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ord:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2085ord, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ord, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1067)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ord, __pyx_t_2) < 0) __PYX_ERR(2, 12853, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12866
 *         return GiacMethods['ord'](self,*args)
 * 
 *      def order(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2087order, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_order, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1068)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_order, __pyx_t_2) < 0) __PYX_ERR(2, 12866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12877
 *         return GiacMethods['order'](self,*args)
 * 
 *      def order_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for order_size:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2089order_size, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_order_size, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1069)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_order_size, __pyx_t_2) < 0) __PYX_ERR(2, 12877, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12889
 *         return GiacMethods['order_size'](self,*args)
 * 
 *      def ordinate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ordinate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2091ordinate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ordinate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1070)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ordinate, __pyx_t_2) < 0) __PYX_ERR(2, 12889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12903
 *         return GiacMethods['ordinate'](self,*args)
 * 
 *      def orthocenter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthocenter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2093orthocenter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_orthocenter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1071)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_orthocenter, __pyx_t_2) < 0) __PYX_ERR(2, 12903, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12916
 *         return GiacMethods['orthocenter'](self,*args)
 * 
 *      def orthogonal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for orthogonal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2095orthogonal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_orthogonal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1072)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_orthogonal, __pyx_t_2) < 0) __PYX_ERR(2, 12916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12928
 *         return GiacMethods['orthogonal'](self,*args)
 * 
 *      def osculating_circle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for osculating_circle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2097osculating_circle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_osculating_circ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1073)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_osculating_circle, __pyx_t_2) < 0) __PYX_ERR(2, 12928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12944
 *         return GiacMethods['osculating_circle'](self,*args)
 * 
 *      def p1oc2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1oc2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2099p1oc2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_p1oc2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1074)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_p1oc2, __pyx_t_2) < 0) __PYX_ERR(2, 12944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12955
 *         return GiacMethods['p1oc2'](self,*args)
 * 
 *      def p1op2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for p1op2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2101p1op2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_p1op2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1075)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_p1op2, __pyx_t_2) < 0) __PYX_ERR(2, 12955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12966
 *         return GiacMethods['p1op2'](self,*args)
 * 
 *      def pa2b2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pa2b2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2103pa2b2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pa2b2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1076)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pa2b2, __pyx_t_2) < 0) __PYX_ERR(2, 12966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12978
 *         return GiacMethods['pa2b2'](self,*args)
 * 
 *      def pade(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pade:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2105pade, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pade, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1077)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pade, __pyx_t_2) < 0) __PYX_ERR(2, 12978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":12989
 *         return GiacMethods['pade'](self,*args)
 * 
 *      def paley_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paley_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2107paley_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_paley_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1078)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 12989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_paley_graph, __pyx_t_2) < 0) __PYX_ERR(2, 12989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13001
 *         return GiacMethods['paley_graph'](self,*args)
 * 
 *      def parabola(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parabola:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2109parabola, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parabola, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1079)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parabola, __pyx_t_2) < 0) __PYX_ERR(2, 13001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13015
 *         return GiacMethods['parabola'](self,*args)
 * 
 *      def parallel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallel:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2111parallel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parallel, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1080)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parallel, __pyx_t_2) < 0) __PYX_ERR(2, 13015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13032
 *         return GiacMethods['parallel'](self,*args)
 * 
 *      def parallelepiped(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelepiped:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2113parallelepiped, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parallelepiped, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1081)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parallelepiped, __pyx_t_2) < 0) __PYX_ERR(2, 13032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13044
 *         return GiacMethods['parallelepiped'](self,*args)
 * 
 *      def parallelogram(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parallelogram:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2115parallelogram, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parallelogram, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1082)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parallelogram, __pyx_t_2) < 0) __PYX_ERR(2, 13044, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13058
 *         return GiacMethods['parallelogram'](self,*args)
 * 
 *      def parameq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2117parameq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parameq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1083)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parameq, __pyx_t_2) < 0) __PYX_ERR(2, 13058, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13070
 *         return GiacMethods['parameq'](self,*args)
 * 
 *      def parameter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parameter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2119parameter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parameter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1084)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parameter, __pyx_t_2) < 0) __PYX_ERR(2, 13070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13080
 *         return GiacMethods['parameter'](self,*args)
 * 
 *      def paramplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for paramplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2121paramplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_paramplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1085)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_paramplot, __pyx_t_2) < 0) __PYX_ERR(2, 13080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13098
 *         return GiacMethods['paramplot'](self,*args)
 * 
 *      def parfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parfrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2123parfrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parfrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1086)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parfrac, __pyx_t_2) < 0) __PYX_ERR(2, 13098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13110
 *         return GiacMethods['parfrac'](self,*args)
 * 
 *      def pari(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pari:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2125pari, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pari, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1087)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pari, __pyx_t_2) < 0) __PYX_ERR(2, 13110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13128
 *         return GiacMethods['pari'](self,*args)
 * 
 *      def part(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for part:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2127part, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_part, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1088)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_part, __pyx_t_2) < 0) __PYX_ERR(2, 13128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13142
 *         return GiacMethods['part'](self,*args)
 * 
 *      def partfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for partfrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2129partfrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_partfrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1089)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_partfrac, __pyx_t_2) < 0) __PYX_ERR(2, 13142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13156
 *         return GiacMethods['partfrac'](self,*args)
 * 
 *      def parzen_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for parzen_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2131parzen_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_parzen_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1090)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_parzen_window, __pyx_t_2) < 0) __PYX_ERR(2, 13156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13167
 *         return GiacMethods['parzen_window'](self,*args)
 * 
 *      def pas_de_cote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pas_de_cote:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2133pas_de_cote, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pas_de_cote, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1091)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pas_de_cote, __pyx_t_2) < 0) __PYX_ERR(2, 13167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13179
 *         return GiacMethods['pas_de_cote'](self,*args)
 * 
 *      def path_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for path_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2135path_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_path_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1092)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_path_graph, __pyx_t_2) < 0) __PYX_ERR(2, 13179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13190
 *         return GiacMethods['path_graph'](self,*args)
 * 
 *      def pcar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2137pcar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pcar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1093)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pcar, __pyx_t_2) < 0) __PYX_ERR(2, 13190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13204
 *         return GiacMethods['pcar'](self,*args)
 * 
 *      def pcar_hessenberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcar_hessenberg:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2139pcar_hessenberg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pcar_hessenberg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1094)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pcar_hessenberg, __pyx_t_2) < 0) __PYX_ERR(2, 13204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13217
 *         return GiacMethods['pcar_hessenberg'](self,*args)
 * 
 *      def pcoef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoef:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2141pcoef, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pcoef, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1095)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pcoef, __pyx_t_2) < 0) __PYX_ERR(2, 13217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13229
 *         return GiacMethods['pcoef'](self,*args)
 * 
 *      def pcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pcoeff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2143pcoeff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pcoeff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1096)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pcoeff, __pyx_t_2) < 0) __PYX_ERR(2, 13229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13241
 *         return GiacMethods['pcoeff'](self,*args)
 * 
 *      def pencolor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pencolor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2145pencolor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pencolor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1097)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pencolor, __pyx_t_2) < 0) __PYX_ERR(2, 13241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13255
 *         return GiacMethods['pencolor'](self,*args)
 * 
 *      def pendown(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pendown:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2147pendown, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pendown, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1098)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pendown, __pyx_t_2) < 0) __PYX_ERR(2, 13255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13266
 *         return GiacMethods['pendown'](self,*args)
 * 
 *      def penup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for penup:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2149penup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_penup, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1099)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_penup, __pyx_t_2) < 0) __PYX_ERR(2, 13266, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13277
 *         return GiacMethods['penup'](self,*args)
 * 
 *      def perimeter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2151perimeter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perimeter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1100)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perimeter, __pyx_t_2) < 0) __PYX_ERR(2, 13277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13291
 *         return GiacMethods['perimeter'](self,*args)
 * 
 *      def perimeterat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeterat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2153perimeterat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perimeterat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1101)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perimeterat, __pyx_t_2) < 0) __PYX_ERR(2, 13291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13306
 *         return GiacMethods['perimeterat'](self,*args)
 * 
 *      def perimeteratraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perimeteratraw:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2155perimeteratraw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perimeteratraw, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1102)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perimeteratraw, __pyx_t_2) < 0) __PYX_ERR(2, 13306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13321
 *         return GiacMethods['perimeteratraw'](self,*args)
 * 
 *      def period(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for period:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2157period, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_period, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1103)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_period, __pyx_t_2) < 0) __PYX_ERR(2, 13321, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13334
 *         return GiacMethods['period'](self,*args)
 * 
 *      def periodic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for periodic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2159periodic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_periodic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1104)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_periodic, __pyx_t_2) < 0) __PYX_ERR(2, 13334, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13346
 *         return GiacMethods['periodic'](self,*args)
 * 
 *      def perm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2161perm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1105)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perm, __pyx_t_2) < 0) __PYX_ERR(2, 13346, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13357
 *         return GiacMethods['perm'](self,*args)
 * 
 *      def perminv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perminv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2163perminv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perminv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1106)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perminv, __pyx_t_2) < 0) __PYX_ERR(2, 13357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13368
 *         return GiacMethods['perminv'](self,*args)
 * 
 *      def permu2cycles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2cycles:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2165permu2cycles, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_permu2cycles, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1107)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_permu2cycles, __pyx_t_2) < 0) __PYX_ERR(2, 13368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13380
 *         return GiacMethods['permu2cycles'](self,*args)
 * 
 *      def permu2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permu2mat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2167permu2mat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_permu2mat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1108)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_permu2mat, __pyx_t_2) < 0) __PYX_ERR(2, 13380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13391
 *         return GiacMethods['permu2mat'](self,*args)
 * 
 *      def permuorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permuorder:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2169permuorder, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_permuorder, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1109)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_permuorder, __pyx_t_2) < 0) __PYX_ERR(2, 13391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13402
 *         return GiacMethods['permuorder'](self,*args)
 * 
 *      def permute_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for permute_vertices:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2171permute_vertices, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_permute_vertice, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1110)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_permute_vertices, __pyx_t_2) < 0) __PYX_ERR(2, 13402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13413
 *         return GiacMethods['permute_vertices'](self,*args)
 * 
 *      def perpen_bisector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpen_bisector:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2173perpen_bisector, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perpen_bisector, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1111)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perpen_bisector, __pyx_t_2) < 0) __PYX_ERR(2, 13413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13425
 *         return GiacMethods['perpen_bisector'](self,*args)
 * 
 *      def perpendicular(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for perpendicular:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2175perpendicular, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_perpendicular, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1112)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_perpendicular, __pyx_t_2) < 0) __PYX_ERR(2, 13425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13439
 *         return GiacMethods['perpendicular'](self,*args)
 * 
 *      def petersen_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for petersen_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2177petersen_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_petersen_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1113)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_petersen_graph, __pyx_t_2) < 0) __PYX_ERR(2, 13439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13452
 *         return GiacMethods['petersen_graph'](self,*args)
 * 
 *      def peval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for peval:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2179peval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_peval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1114)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_peval, __pyx_t_2) < 0) __PYX_ERR(2, 13452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13464
 *         return GiacMethods['peval'](self,*args)
 * 
 *      def pi(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pi:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2181pi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1115)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pi, __pyx_t_2) < 0) __PYX_ERR(2, 13464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13478
 *         return GiacMethods['pi'](self,*args)
 * 
 *      def pie(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pie:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2183pie, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pie, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1116)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pie, __pyx_t_2) < 0) __PYX_ERR(2, 13478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13491
 *         return GiacMethods['pie'](self,*args)
 * 
 *      def piecewise(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for piecewise:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2185piecewise, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_piecewise, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1117)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_piecewise, __pyx_t_2) < 0) __PYX_ERR(2, 13491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13503
 *         return GiacMethods['piecewise'](self,*args)
 * 
 *      def pink(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pink:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2187pink, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pink, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1118)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pink, __pyx_t_2) < 0) __PYX_ERR(2, 13503, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13515
 *         return GiacMethods['pink'](self,*args)
 * 
 *      def pivot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pivot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2189pivot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pivot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1119)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pivot, __pyx_t_2) < 0) __PYX_ERR(2, 13515, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13527
 *         return GiacMethods['pivot'](self,*args)
 * 
 *      def pixoff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixoff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2191pixoff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pixoff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1120)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pixoff, __pyx_t_2) < 0) __PYX_ERR(2, 13527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13538
 *         return GiacMethods['pixoff'](self,*args)
 * 
 *      def pixon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pixon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2193pixon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pixon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1121)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pixon, __pyx_t_2) < 0) __PYX_ERR(2, 13538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13549
 *         return GiacMethods['pixon'](self,*args)
 * 
 *      def planar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for planar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2195planar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_planar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1122)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_planar, __pyx_t_2) < 0) __PYX_ERR(2, 13549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13559
 *         return GiacMethods['planar'](self,*args)
 * 
 *      def plane(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2197plane, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plane, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1123)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plane, __pyx_t_2) < 0) __PYX_ERR(2, 13559, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13573
 *         return GiacMethods['plane'](self,*args)
 * 
 *      def plane_dual(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plane_dual:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2199plane_dual, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plane_dual, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1124)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plane_dual, __pyx_t_2) < 0) __PYX_ERR(2, 13573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13584
 *         return GiacMethods['plane_dual'](self,*args)
 * 
 *      def playsnd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for playsnd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2201playsnd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_playsnd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1125)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_playsnd, __pyx_t_2) < 0) __PYX_ERR(2, 13584, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13595
 *         return GiacMethods['playsnd'](self,*args)
 * 
 *      def plex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2203plex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1126)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plex, __pyx_t_2) < 0) __PYX_ERR(2, 13595, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13605
 *         return GiacMethods['plex'](self,*args)
 * 
 *      def plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2205plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1127)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plot, __pyx_t_2) < 0) __PYX_ERR(2, 13605, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13622
 *         return GiacMethods['plot'](self,*args)
 * 
 *      def plot3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plot3d:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2207plot3d, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plot3d, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1128)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plot3d, __pyx_t_2) < 0) __PYX_ERR(2, 13622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13637
 *         return GiacMethods['plot3d'](self,*args)
 * 
 *      def plotarea(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotarea:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2209plotarea, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotarea, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1129)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotarea, __pyx_t_2) < 0) __PYX_ERR(2, 13637, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13650
 *         return GiacMethods['plotarea'](self,*args)
 * 
 *      def plotcdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2211plotcdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotcdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1130)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotcdf, __pyx_t_2) < 0) __PYX_ERR(2, 13650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13663
 *         return GiacMethods['plotcdf'](self,*args)
 * 
 *      def plotcontour(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotcontour:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2213plotcontour, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotcontour, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1131)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotcontour, __pyx_t_2) < 0) __PYX_ERR(2, 13663, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13677
 *         return GiacMethods['plotcontour'](self,*args)
 * 
 *      def plotdensity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotdensity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2215plotdensity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotdensity, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1132)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotdensity, __pyx_t_2) < 0) __PYX_ERR(2, 13677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13689
 *         return GiacMethods['plotdensity'](self,*args)
 * 
 *      def plotfield(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfield:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2217plotfield, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotfield, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1133)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotfield, __pyx_t_2) < 0) __PYX_ERR(2, 13689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13704
 *         return GiacMethods['plotfield'](self,*args)
 * 
 *      def plotfunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotfunc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2219plotfunc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotfunc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1134)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotfunc, __pyx_t_2) < 0) __PYX_ERR(2, 13704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13719
 *         return GiacMethods['plotfunc'](self,*args)
 * 
 *      def plotimf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2221plotimf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotimf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1135)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotimf, __pyx_t_2) < 0) __PYX_ERR(2, 13719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13730
 *         return GiacMethods['plotimf'](self,*args)
 * 
 *      def plotimplicit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotimplicit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2223plotimplicit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotimplicit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1136)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotimplicit, __pyx_t_2) < 0) __PYX_ERR(2, 13730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13749
 *         return GiacMethods['plotimplicit'](self,*args)
 * 
 *      def plotinequation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotinequation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2225plotinequation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotinequation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1137)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotinequation, __pyx_t_2) < 0) __PYX_ERR(2, 13749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13763
 *         return GiacMethods['plotinequation'](self,*args)
 * 
 *      def plotlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotlist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2227plotlist, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotlist, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1138)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotlist, __pyx_t_2) < 0) __PYX_ERR(2, 13763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13776
 *         return GiacMethods['plotlist'](self,*args)
 * 
 *      def plotode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotode:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2229plotode, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotode, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1139)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotode, __pyx_t_2) < 0) __PYX_ERR(2, 13776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13793
 *         return GiacMethods['plotode'](self,*args)
 * 
 *      def plotparam(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotparam:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2231plotparam, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotparam, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1140)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotparam, __pyx_t_2) < 0) __PYX_ERR(2, 13793, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13811
 *         return GiacMethods['plotparam'](self,*args)
 * 
 *      def plotpolar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotpolar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2233plotpolar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotpolar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1141)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotpolar, __pyx_t_2) < 0) __PYX_ERR(2, 13811, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13823
 *         return GiacMethods['plotpolar'](self,*args)
 * 
 *      def plotproba(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotproba:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2235plotproba, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotproba, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1142)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotproba, __pyx_t_2) < 0) __PYX_ERR(2, 13823, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13836
 *         return GiacMethods['plotproba'](self,*args)
 * 
 *      def plotseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotseq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2237plotseq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotseq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1143)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotseq, __pyx_t_2) < 0) __PYX_ERR(2, 13836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13849
 *         return GiacMethods['plotseq'](self,*args)
 * 
 *      def plotspectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotspectrum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2239plotspectrum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotspectrum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1144)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotspectrum, __pyx_t_2) < 0) __PYX_ERR(2, 13849, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13861
 *         return GiacMethods['plotspectrum'](self,*args)
 * 
 *      def plotwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plotwav:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2241plotwav, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plotwav, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1145)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plotwav, __pyx_t_2) < 0) __PYX_ERR(2, 13861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13874
 *         return GiacMethods['plotwav'](self,*args)
 * 
 *      def plus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for plus_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2243plus_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_plus_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1146)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_plus_point, __pyx_t_2) < 0) __PYX_ERR(2, 13874, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13886
 *         return GiacMethods['plus_point'](self,*args)
 * 
 *      def pmin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pmin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2245pmin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pmin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1147)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pmin, __pyx_t_2) < 0) __PYX_ERR(2, 13886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13901
 *         return GiacMethods['pmin'](self,*args)
 * 
 *      def point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2247point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1148)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_point, __pyx_t_2) < 0) __PYX_ERR(2, 13901, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13919
 *         return GiacMethods['point'](self,*args)
 * 
 *      def point2d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point2d:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2249point2d, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_point2d, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1149)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_point2d, __pyx_t_2) < 0) __PYX_ERR(2, 13919, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13930
 *         return GiacMethods['point2d'](self,*args)
 * 
 *      def point3d(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for point3d:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2251point3d, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_point3d, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1150)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_point3d, __pyx_t_2) < 0) __PYX_ERR(2, 13930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13941
 *         return GiacMethods['point3d'](self,*args)
 * 
 *      def poisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2253poisson, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_poisson, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1151)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_poisson, __pyx_t_2) < 0) __PYX_ERR(2, 13941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13955
 *         return GiacMethods['poisson'](self,*args)
 * 
 *      def poisson_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2255poisson_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_poisson_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1152)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_poisson_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 13955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13967
 *         return GiacMethods['poisson_cdf'](self,*args)
 * 
 *      def poisson_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2257poisson_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_poisson_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1153)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_poisson_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 13967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13979
 *         return GiacMethods['poisson_icdf'](self,*args)
 * 
 *      def poisson_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poisson_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2259poisson_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_poisson_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1154)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_poisson_window, __pyx_t_2) < 0) __PYX_ERR(2, 13979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":13990
 *         return GiacMethods['poisson_window'](self,*args)
 * 
 *      def polar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2261polar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1155)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polar, __pyx_t_2) < 0) __PYX_ERR(2, 13990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14002
 *         return GiacMethods['polar'](self,*args)
 * 
 *      def polar_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_coordinates:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2263polar_coordinates, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polar_coordinat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1156)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polar_coordinates, __pyx_t_2) < 0) __PYX_ERR(2, 14002, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14016
 *         return GiacMethods['polar_coordinates'](self,*args)
 * 
 *      def polar_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polar_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2265polar_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polar_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1157)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polar_point, __pyx_t_2) < 0) __PYX_ERR(2, 14016, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14028
 *         return GiacMethods['polar_point'](self,*args)
 * 
 *      def polarplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polarplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2267polarplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polarplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1158)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polarplot, __pyx_t_2) < 0) __PYX_ERR(2, 14028, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14040
 *         return GiacMethods['polarplot'](self,*args)
 * 
 *      def pole(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pole:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2269pole, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pole, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1159)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pole, __pyx_t_2) < 0) __PYX_ERR(2, 14040, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14052
 *         return GiacMethods['pole'](self,*args)
 * 
 *      def poly2symb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poly2symb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2271poly2symb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_poly2symb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1160)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_poly2symb, __pyx_t_2) < 0) __PYX_ERR(2, 14052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14066
 *         return GiacMethods['poly2symb'](self,*args)
 * 
 *      def polyEval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyEval:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2273polyEval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polyEval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1161)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polyEval, __pyx_t_2) < 0) __PYX_ERR(2, 14066, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14078
 *         return GiacMethods['polyEval'](self,*args)
 * 
 *      def polygon(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygon:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2275polygon, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polygon, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1162)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polygon, __pyx_t_2) < 0) __PYX_ERR(2, 14078, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14090
 *         return GiacMethods['polygon'](self,*args)
 * 
 *      def polygone_rempli(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygone_rempli:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2277polygone_rempli, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polygone_rempli, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1163)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polygone_rempli, __pyx_t_2) < 0) __PYX_ERR(2, 14090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14103
 *         return GiacMethods['polygone_rempli'](self,*args)
 * 
 *      def polygonplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2279polygonplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polygonplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1164)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polygonplot, __pyx_t_2) < 0) __PYX_ERR(2, 14103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14114
 *         return GiacMethods['polygonplot'](self,*args)
 * 
 *      def polygonscatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polygonscatterplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2281polygonscatterplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polygonscatterp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1165)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polygonscatterplot, __pyx_t_2) < 0) __PYX_ERR(2, 14114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14125
 *         return GiacMethods['polygonscatterplot'](self,*args)
 * 
 *      def polyhedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polyhedron:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2283polyhedron, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polyhedron, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1166)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polyhedron, __pyx_t_2) < 0) __PYX_ERR(2, 14125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14136
 *         return GiacMethods['polyhedron'](self,*args)
 * 
 *      def polynom(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynom:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2285polynom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polynom, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1167)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polynom, __pyx_t_2) < 0) __PYX_ERR(2, 14136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14151
 *         return GiacMethods['polynom'](self,*args)
 * 
 *      def polynomial_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2287polynomial_regression, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polynomial_regr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1168)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polynomial_regression, __pyx_t_2) < 0) __PYX_ERR(2, 14151, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14164
 *         return GiacMethods['polynomial_regression'](self,*args)
 * 
 *      def polynomial_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for polynomial_regression_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2289polynomial_regression_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_polynomial_regr_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1169)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_polynomial_regression_plot, __pyx_t_2) < 0) __PYX_ERR(2, 14164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14177
 *         return GiacMethods['polynomial_regression_plot'](self,*args)
 * 
 *      def position(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for position:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2291position, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_position, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1170)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_position, __pyx_t_2) < 0) __PYX_ERR(2, 14177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14190
 *         return GiacMethods['position'](self,*args)
 * 
 *      def poslbdLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for poslbdLMQ:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2293poslbdLMQ, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_poslbdLMQ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1171)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_poslbdLMQ, __pyx_t_2) < 0) __PYX_ERR(2, 14190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14201
 *         return GiacMethods['poslbdLMQ'](self,*args)
 * 
 *      def posubLMQ(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for posubLMQ:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2295posubLMQ, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_posubLMQ, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1172)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_posubLMQ, __pyx_t_2) < 0) __PYX_ERR(2, 14201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14212
 *         return GiacMethods['posubLMQ'](self,*args)
 * 
 *      def potential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for potential:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2297potential, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_potential, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1173)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_potential, __pyx_t_2) < 0) __PYX_ERR(2, 14212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14223
 *         return GiacMethods['potential'](self,*args)
 * 
 *      def pow2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pow2exp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2299pow2exp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pow2exp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1174)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pow2exp, __pyx_t_2) < 0) __PYX_ERR(2, 14223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14234
 *         return GiacMethods['pow2exp'](self,*args)
 * 
 *      def power_regression(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2301power_regression, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_power_regressio, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1175)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_power_regression, __pyx_t_2) < 0) __PYX_ERR(2, 14234, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14247
 *         return GiacMethods['power_regression'](self,*args)
 * 
 *      def power_regression_plot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for power_regression_plot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2303power_regression_plot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_power_regressio_2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1176)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_power_regression_plot, __pyx_t_2) < 0) __PYX_ERR(2, 14247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14260
 *         return GiacMethods['power_regression_plot'](self,*args)
 * 
 *      def powermod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powermod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2305powermod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_powermod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1177)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_powermod, __pyx_t_2) < 0) __PYX_ERR(2, 14260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14272
 *         return GiacMethods['powermod'](self,*args)
 * 
 *      def powerpc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powerpc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2307powerpc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_powerpc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1178)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_powerpc, __pyx_t_2) < 0) __PYX_ERR(2, 14272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14284
 *         return GiacMethods['powerpc'](self,*args)
 * 
 *      def powexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powexpand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2309powexpand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_powexpand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1179)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_powexpand, __pyx_t_2) < 0) __PYX_ERR(2, 14284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14296
 *         return GiacMethods['powexpand'](self,*args)
 * 
 *      def powmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for powmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2311powmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_powmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1180)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_powmod, __pyx_t_2) < 0) __PYX_ERR(2, 14296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14308
 *         return GiacMethods['powmod'](self,*args)
 * 
 *      def prepend(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prepend:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2313prepend, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_prepend, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1181)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_prepend, __pyx_t_2) < 0) __PYX_ERR(2, 14308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14324
 *         return GiacMethods['prepend'](self,*args)
 * 
 *      def preval(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for preval:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2315preval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_preval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1182)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_preval, __pyx_t_2) < 0) __PYX_ERR(2, 14324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14338
 *         return GiacMethods['preval'](self,*args)
 * 
 *      def prevperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevperm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2317prevperm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_prevperm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1183)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_prevperm, __pyx_t_2) < 0) __PYX_ERR(2, 14338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14350
 *         return GiacMethods['prevperm'](self,*args)
 * 
 *      def prevprime(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prevprime:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2319prevprime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_prevprime, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1184)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_prevprime, __pyx_t_2) < 0) __PYX_ERR(2, 14350, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14362
 *         return GiacMethods['prevprime'](self,*args)
 * 
 *      def primpart(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for primpart:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2321primpart, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_primpart, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1185)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_primpart, __pyx_t_2) < 0) __PYX_ERR(2, 14362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14374
 *         return GiacMethods['primpart'](self,*args)
 * 
 *      def printf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for printf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2323printf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_printf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1186)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_printf, __pyx_t_2) < 0) __PYX_ERR(2, 14374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14386
 *         return GiacMethods['printf'](self,*args)
 * 
 *      def prism(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2325prism, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_prism, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1187)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_prism, __pyx_t_2) < 0) __PYX_ERR(2, 14386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14397
 *         return GiacMethods['prism'](self,*args)
 * 
 *      def prism_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for prism_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2327prism_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_prism_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1188)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_prism_graph, __pyx_t_2) < 0) __PYX_ERR(2, 14397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14408
 *         return GiacMethods['prism_graph'](self,*args)
 * 
 *      def product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for product:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2329product, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_product, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1189)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_product, __pyx_t_2) < 0) __PYX_ERR(2, 14408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14425
 *         return GiacMethods['product'](self,*args)
 * 
 *      def projection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for projection:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2331projection, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_projection, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1190)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_projection, __pyx_t_2) < 0) __PYX_ERR(2, 14425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14438
 *         return GiacMethods['projection'](self,*args)
 * 
 *      def proot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for proot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2333proot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_proot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1191)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_proot, __pyx_t_2) < 0) __PYX_ERR(2, 14438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14452
 *         return GiacMethods['proot'](self,*args)
 * 
 *      def propFrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propFrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2335propFrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_propFrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1192)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_propFrac, __pyx_t_2) < 0) __PYX_ERR(2, 14452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14464
 *         return GiacMethods['propFrac'](self,*args)
 * 
 *      def propfrac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for propfrac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2337propfrac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_propfrac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1193)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_propfrac, __pyx_t_2) < 0) __PYX_ERR(2, 14464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14476
 *         return GiacMethods['propfrac'](self,*args)
 * 
 *      def pruefer_code(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pruefer_code:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2339pruefer_code, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pruefer_code, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1194)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pruefer_code, __pyx_t_2) < 0) __PYX_ERR(2, 14476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14488
 *         return GiacMethods['pruefer_code'](self,*args)
 * 
 *      def psrgcd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for psrgcd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2341psrgcd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_psrgcd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1195)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_psrgcd, __pyx_t_2) < 0) __PYX_ERR(2, 14488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14499
 *         return GiacMethods['psrgcd'](self,*args)
 * 
 *      def ptayl(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ptayl:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2343ptayl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ptayl, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1196)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ptayl, __pyx_t_2) < 0) __PYX_ERR(2, 14499, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14515
 *         return GiacMethods['ptayl'](self,*args)
 * 
 *      def purge(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purge:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2345purge, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_purge, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1197)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_purge, __pyx_t_2) < 0) __PYX_ERR(2, 14515, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14527
 *         return GiacMethods['purge'](self,*args)
 * 
 *      def purple(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for purple:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2347purple, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_purple, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1198)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_purple, __pyx_t_2) < 0) __PYX_ERR(2, 14527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14539
 *         return GiacMethods['purple'](self,*args)
 * 
 *      def pwd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pwd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2349pwd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pwd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1199)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pwd, __pyx_t_2) < 0) __PYX_ERR(2, 14539, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14550
 *         return GiacMethods['pwd'](self,*args)
 * 
 *      def pyramid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for pyramid:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2351pyramid, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_pyramid, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1200)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_pyramid, __pyx_t_2) < 0) __PYX_ERR(2, 14550, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14562
 *         return GiacMethods['pyramid'](self,*args)
 * 
 *      def python_compat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for python_compat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2353python_compat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_python_compat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1201)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_python_compat, __pyx_t_2) < 0) __PYX_ERR(2, 14562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14574
 *         return GiacMethods['python_compat'](self,*args)
 * 
 *      def q2a(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for q2a:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2355q2a, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_q2a, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1202)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_q2a, __pyx_t_2) < 0) __PYX_ERR(2, 14574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14585
 *         return GiacMethods['q2a'](self,*args)
 * 
 *      def qr(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for qr:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2357qr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_qr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1203)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_qr, __pyx_t_2) < 0) __PYX_ERR(2, 14585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14596
 *         return GiacMethods['qr'](self,*args)
 * 
 *      def quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadric:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2359quadric, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quadric, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1204)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quadric, __pyx_t_2) < 0) __PYX_ERR(2, 14596, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14610
 *         return GiacMethods['quadric'](self,*args)
 * 
 *      def quadrilateral(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quadrilateral:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2361quadrilateral, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quadrilateral, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1205)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quadrilateral, __pyx_t_2) < 0) __PYX_ERR(2, 14610, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14622
 *         return GiacMethods['quadrilateral'](self,*args)
 * 
 *      def quantile(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quantile:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2363quantile, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quantile, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1206)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quantile, __pyx_t_2) < 0) __PYX_ERR(2, 14622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14634
 *         return GiacMethods['quantile'](self,*args)
 * 
 *      def quartile1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile1:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2365quartile1, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quartile1, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1207)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quartile1, __pyx_t_2) < 0) __PYX_ERR(2, 14634, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14647
 *         return GiacMethods['quartile1'](self,*args)
 * 
 *      def quartile3(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartile3:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2367quartile3, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quartile3, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1208)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quartile3, __pyx_t_2) < 0) __PYX_ERR(2, 14647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14660
 *         return GiacMethods['quartile3'](self,*args)
 * 
 *      def quartiles(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quartiles:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2369quartiles, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quartiles, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1209)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quartiles, __pyx_t_2) < 0) __PYX_ERR(2, 14660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14673
 *         return GiacMethods['quartiles'](self,*args)
 * 
 *      def quest(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quest:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2371quest, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quest, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1210)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quest, __pyx_t_2) < 0) __PYX_ERR(2, 14673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14686
 *         return GiacMethods['quest'](self,*args)
 * 
 *      def quo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quo:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2373quo, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quo, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1211)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quo, __pyx_t_2) < 0) __PYX_ERR(2, 14686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14699
 *         return GiacMethods['quo'](self,*args)
 * 
 *      def quorem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quorem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2375quorem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quorem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1212)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quorem, __pyx_t_2) < 0) __PYX_ERR(2, 14699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14713
 *         return GiacMethods['quorem'](self,*args)
 * 
 *      def quote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for quote:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2377quote, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_quote, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1213)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_quote, __pyx_t_2) < 0) __PYX_ERR(2, 14713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14726
 *         return GiacMethods['quote'](self,*args)
 * 
 *      def r2e(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for r2e:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2379r2e, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_r2e, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1214)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_r2e, __pyx_t_2) < 0) __PYX_ERR(2, 14726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14740
 *         return GiacMethods['r2e'](self,*args)
 * 
 *      def radians(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radians:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2381radians, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_radians, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1215)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_radians, __pyx_t_2) < 0) __PYX_ERR(2, 14740, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14750
 *         return GiacMethods['radians'](self,*args)
 * 
 *      def radical_axis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radical_axis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2383radical_axis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_radical_axis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1216)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_radical_axis, __pyx_t_2) < 0) __PYX_ERR(2, 14750, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14762
 *         return GiacMethods['radical_axis'](self,*args)
 * 
 *      def radius(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for radius:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2385radius, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_radius, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1217)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_radius, __pyx_t_2) < 0) __PYX_ERR(2, 14762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14773
 *         return GiacMethods['radius'](self,*args)
 * 
 *      def ramene(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ramene:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2387ramene, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ramene, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1218)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ramene, __pyx_t_2) < 0) __PYX_ERR(2, 14773, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14784
 *         return GiacMethods['ramene'](self,*args)
 * 
 *      def rand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2389rand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1219)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rand, __pyx_t_2) < 0) __PYX_ERR(2, 14784, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14805
 *         return GiacMethods['rand'](self,*args)
 * 
 *      def randMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randMat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2391randMat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randMat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1220)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randMat, __pyx_t_2) < 0) __PYX_ERR(2, 14805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14828
 *         return GiacMethods['randMat'](self,*args)
 * 
 *      def randNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randNorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2393randNorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randNorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1221)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randNorm, __pyx_t_2) < 0) __PYX_ERR(2, 14828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14840
 *         return GiacMethods['randNorm'](self,*args)
 * 
 *      def randPoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randPoly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2395randPoly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randPoly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1222)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randPoly, __pyx_t_2) < 0) __PYX_ERR(2, 14840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14856
 *         return GiacMethods['randPoly'](self,*args)
 * 
 *      def randbetad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbetad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2397randbetad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randbetad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1223)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randbetad, __pyx_t_2) < 0) __PYX_ERR(2, 14856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14868
 *         return GiacMethods['randbetad'](self,*args)
 * 
 *      def randbinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randbinomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2399randbinomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randbinomial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1224)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randbinomial, __pyx_t_2) < 0) __PYX_ERR(2, 14868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14880
 *         return GiacMethods['randbinomial'](self,*args)
 * 
 *      def randchisquare(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randchisquare:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2401randchisquare, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randchisquare, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1225)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randchisquare, __pyx_t_2) < 0) __PYX_ERR(2, 14880, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14892
 *         return GiacMethods['randchisquare'](self,*args)
 * 
 *      def randexp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randexp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2403randexp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randexp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1226)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randexp, __pyx_t_2) < 0) __PYX_ERR(2, 14892, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14904
 *         return GiacMethods['randexp'](self,*args)
 * 
 *      def randfisher(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randfisher:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2405randfisher, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randfisher, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1227)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randfisher, __pyx_t_2) < 0) __PYX_ERR(2, 14904, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14916
 *         return GiacMethods['randfisher'](self,*args)
 * 
 *      def randgammad(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgammad:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2407randgammad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randgammad, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1228)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randgammad, __pyx_t_2) < 0) __PYX_ERR(2, 14916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14928
 *         return GiacMethods['randgammad'](self,*args)
 * 
 *      def randgeometric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randgeometric:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2409randgeometric, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randgeometric, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1229)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randgeometric, __pyx_t_2) < 0) __PYX_ERR(2, 14928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14939
 *         return GiacMethods['randgeometric'](self,*args)
 * 
 *      def randint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2411randint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1230)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randint, __pyx_t_2) < 0) __PYX_ERR(2, 14939, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14951
 *         return GiacMethods['randint'](self,*args)
 * 
 *      def randmarkov(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmarkov:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2413randmarkov, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randmarkov, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1231)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randmarkov, __pyx_t_2) < 0) __PYX_ERR(2, 14951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14963
 *         return GiacMethods['randmarkov'](self,*args)
 * 
 *      def randmatrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmatrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2415randmatrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randmatrix, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1232)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randmatrix, __pyx_t_2) < 0) __PYX_ERR(2, 14963, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14986
 *         return GiacMethods['randmatrix'](self,*args)
 * 
 *      def randmultinomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randmultinomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2417randmultinomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randmultinomial, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1233)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randmultinomial, __pyx_t_2) < 0) __PYX_ERR(2, 14986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":14998
 *         return GiacMethods['randmultinomial'](self,*args)
 * 
 *      def randnorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randnorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2419randnorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randnorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1234)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 14998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randnorm, __pyx_t_2) < 0) __PYX_ERR(2, 14998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15010
 *         return GiacMethods['randnorm'](self,*args)
 * 
 *      def random(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2421random, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1235)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random, __pyx_t_2) < 0) __PYX_ERR(2, 15010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15031
 *         return GiacMethods['random'](self,*args)
 * 
 *      def random_bipartite_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_bipartite_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2423random_bipartite_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_bipartit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1236)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_bipartite_graph, __pyx_t_2) < 0) __PYX_ERR(2, 15031, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15043
 *         return GiacMethods['random_bipartite_graph'](self,*args)
 * 
 *      def random_digraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_digraph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2425random_digraph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_digraph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1237)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_digraph, __pyx_t_2) < 0) __PYX_ERR(2, 15043, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15055
 *         return GiacMethods['random_digraph'](self,*args)
 * 
 *      def random_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2427random_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1238)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_graph, __pyx_t_2) < 0) __PYX_ERR(2, 15055, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15067
 *         return GiacMethods['random_graph'](self,*args)
 * 
 *      def random_network(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_network:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2429random_network, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_network, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1239)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_network, __pyx_t_2) < 0) __PYX_ERR(2, 15067, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15080
 *         return GiacMethods['random_network'](self,*args)
 * 
 *      def random_planar_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_planar_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2431random_planar_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_planar_g, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1240)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_planar_graph, __pyx_t_2) < 0) __PYX_ERR(2, 15080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15090
 *         return GiacMethods['random_planar_graph'](self,*args)
 * 
 *      def random_regular_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_regular_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2433random_regular_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_regular, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1241)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_regular_graph, __pyx_t_2) < 0) __PYX_ERR(2, 15090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15101
 *         return GiacMethods['random_regular_graph'](self,*args)
 * 
 *      def random_sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_sequence_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2435random_sequence_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_sequence, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1242)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_sequence_graph, __pyx_t_2) < 0) __PYX_ERR(2, 15101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15112
 *         return GiacMethods['random_sequence_graph'](self,*args)
 * 
 *      def random_tournament(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tournament:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2437random_tournament, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_tourname, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1243)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_tournament, __pyx_t_2) < 0) __PYX_ERR(2, 15112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15123
 *         return GiacMethods['random_tournament'](self,*args)
 * 
 *      def random_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2439random_tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_tree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1244)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_tree, __pyx_t_2) < 0) __PYX_ERR(2, 15123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15133
 *         return GiacMethods['random_tree'](self,*args)
 * 
 *      def random_variable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for random_variable:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2441random_variable, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_random_variable, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1245)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_random_variable, __pyx_t_2) < 0) __PYX_ERR(2, 15133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15153
 *         return GiacMethods['random_variable'](self,*args)
 * 
 *      def randperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randperm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2443randperm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randperm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1246)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randperm, __pyx_t_2) < 0) __PYX_ERR(2, 15153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15168
 *         return GiacMethods['randperm'](self,*args)
 * 
 *      def randpoisson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoisson:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2445randpoisson, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randpoisson, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1247)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randpoisson, __pyx_t_2) < 0) __PYX_ERR(2, 15168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15180
 *         return GiacMethods['randpoisson'](self,*args)
 * 
 *      def randpoly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randpoly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2447randpoly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randpoly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1248)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randpoly, __pyx_t_2) < 0) __PYX_ERR(2, 15180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15196
 *         return GiacMethods['randpoly'](self,*args)
 * 
 *      def randseed(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randseed:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2449randseed, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randseed, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1249)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randseed, __pyx_t_2) < 0) __PYX_ERR(2, 15196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15208
 *         return GiacMethods['randseed'](self,*args)
 * 
 *      def randstudent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randstudent:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2451randstudent, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randstudent, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1250)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randstudent, __pyx_t_2) < 0) __PYX_ERR(2, 15208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15220
 *         return GiacMethods['randstudent'](self,*args)
 * 
 *      def randvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2453randvar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randvar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1251)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randvar, __pyx_t_2) < 0) __PYX_ERR(2, 15220, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15240
 *         return GiacMethods['randvar'](self,*args)
 * 
 *      def randvector(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randvector:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2455randvector, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randvector, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1252)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randvector, __pyx_t_2) < 0) __PYX_ERR(2, 15240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15260
 *         return GiacMethods['randvector'](self,*args)
 * 
 *      def randweibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for randweibulld:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2457randweibulld, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_randweibulld, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1253)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_randweibulld, __pyx_t_2) < 0) __PYX_ERR(2, 15260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15272
 *         return GiacMethods['randweibulld'](self,*args)
 * 
 *      def rank(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rank:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2459rank, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rank, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1254)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rank, __pyx_t_2) < 0) __PYX_ERR(2, 15272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15284
 *         return GiacMethods['rank'](self,*args)
 * 
 *      def ranm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2461ranm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ranm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1255)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ranm, __pyx_t_2) < 0) __PYX_ERR(2, 15284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15307
 *         return GiacMethods['ranm'](self,*args)
 * 
 *      def ranv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ranv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2463ranv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ranv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1256)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ranv, __pyx_t_2) < 0) __PYX_ERR(2, 15307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15327
 *         return GiacMethods['ranv'](self,*args)
 * 
 *      def rassembler_trigo(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rassembler_trigo:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2465rassembler_trigo, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rassembler_trig, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1257)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rassembler_trigo, __pyx_t_2) < 0) __PYX_ERR(2, 15327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15338
 *         return GiacMethods['rassembler_trigo'](self,*args)
 * 
 *      def rat_jordan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rat_jordan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2467rat_jordan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rat_jordan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1258)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rat_jordan, __pyx_t_2) < 0) __PYX_ERR(2, 15338, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15351
 *         return GiacMethods['rat_jordan'](self,*args)
 * 
 *      def ratinterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratinterp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2469ratinterp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ratinterp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1259)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ratinterp, __pyx_t_2) < 0) __PYX_ERR(2, 15351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15362
 *         return GiacMethods['ratinterp'](self,*args)
 * 
 *      def rational(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rational:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2471rational, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rational, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1260)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rational, __pyx_t_2) < 0) __PYX_ERR(2, 15362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15375
 *         return GiacMethods['rational'](self,*args)
 * 
 *      def rationalroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rationalroot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2473rationalroot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rationalroot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1261)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rationalroot, __pyx_t_2) < 0) __PYX_ERR(2, 15375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15386
 *         return GiacMethods['rationalroot'](self,*args)
 * 
 *      def ratnormal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ratnormal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2475ratnormal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ratnormal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1262)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ratnormal, __pyx_t_2) < 0) __PYX_ERR(2, 15386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15399
 *         return GiacMethods['ratnormal'](self,*args)
 * 
 *      def rdiv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rdiv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2477rdiv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rdiv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1263)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rdiv, __pyx_t_2) < 0) __PYX_ERR(2, 15399, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15411
 *         return GiacMethods['rdiv'](self,*args)
 * 
 *      def re(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for re:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2479re, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_re, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1264)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(2, 15411, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15424
 *         return GiacMethods['re'](self,*args)
 * 
 *      def reachable(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reachable:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2481reachable, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reachable, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1265)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reachable, __pyx_t_2) < 0) __PYX_ERR(2, 15424, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15435
 *         return GiacMethods['reachable'](self,*args)
 * 
 *      def read(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for read:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2483read, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_read, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1266)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_read, __pyx_t_2) < 0) __PYX_ERR(2, 15435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15446
 *         return GiacMethods['read'](self,*args)
 * 
 *      def readrgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readrgb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2485readrgb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_readrgb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1267)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_readrgb, __pyx_t_2) < 0) __PYX_ERR(2, 15446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15458
 *         return GiacMethods['readrgb'](self,*args)
 * 
 *      def readwav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for readwav:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2487readwav, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_readwav, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1268)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_readwav, __pyx_t_2) < 0) __PYX_ERR(2, 15458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15469
 *         return GiacMethods['readwav'](self,*args)
 * 
 *      def real(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for real:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2489real, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_real, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1269)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_real, __pyx_t_2) < 0) __PYX_ERR(2, 15469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15482
 *         return GiacMethods['real'](self,*args)
 * 
 *      def realroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for realroot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2491realroot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_realroot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1270)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_realroot, __pyx_t_2) < 0) __PYX_ERR(2, 15482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15498
 *         return GiacMethods['realroot'](self,*args)
 * 
 *      def reciprocation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reciprocation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2493reciprocation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reciprocation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1271)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reciprocation, __pyx_t_2) < 0) __PYX_ERR(2, 15498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15510
 *         return GiacMethods['reciprocation'](self,*args)
 * 
 *      def rect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2495rect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1272)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rect, __pyx_t_2) < 0) __PYX_ERR(2, 15510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15521
 *         return GiacMethods['rect'](self,*args)
 * 
 *      def rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2497rectangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rectangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1273)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rectangle, __pyx_t_2) < 0) __PYX_ERR(2, 15521, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15535
 *         return GiacMethods['rectangle'](self,*args)
 * 
 *      def rectangle_droit(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_droit:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2499rectangle_droit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rectangle_droit, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1274)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rectangle_droit, __pyx_t_2) < 0) __PYX_ERR(2, 15535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15551
 *         return GiacMethods['rectangle_droit'](self,*args)
 * 
 *      def rectangle_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_gauche:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2501rectangle_gauche, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rectangle_gauch, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1275)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rectangle_gauche, __pyx_t_2) < 0) __PYX_ERR(2, 15551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15567
 *         return GiacMethods['rectangle_gauche'](self,*args)
 * 
 *      def rectangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangle_plein:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2503rectangle_plein, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rectangle_plein, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1276)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rectangle_plein, __pyx_t_2) < 0) __PYX_ERR(2, 15567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15580
 *         return GiacMethods['rectangle_plein'](self,*args)
 * 
 *      def rectangular_coordinates(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rectangular_coordinates:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2505rectangular_coordinates, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rectangular_coo, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1277)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rectangular_coordinates, __pyx_t_2) < 0) __PYX_ERR(2, 15580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15592
 *         return GiacMethods['rectangular_coordinates'](self,*args)
 * 
 *      def recule(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for recule:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2507recule, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_recule, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1278)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_recule, __pyx_t_2) < 0) __PYX_ERR(2, 15592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15604
 *         return GiacMethods['recule'](self,*args)
 * 
 *      def red(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for red:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2509red, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_red, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1279)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_red, __pyx_t_2) < 0) __PYX_ERR(2, 15604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15616
 *         return GiacMethods['red'](self,*args)
 * 
 *      def reduced_conic(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_conic:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2511reduced_conic, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reduced_conic, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1280)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reduced_conic, __pyx_t_2) < 0) __PYX_ERR(2, 15616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15630
 *         return GiacMethods['reduced_conic'](self,*args)
 * 
 *      def reduced_quadric(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reduced_quadric:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2513reduced_quadric, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reduced_quadric, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1281)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reduced_quadric, __pyx_t_2) < 0) __PYX_ERR(2, 15630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15644
 *         return GiacMethods['reduced_quadric'](self,*args)
 * 
 *      def ref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ref:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2515ref, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ref, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1282)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ref, __pyx_t_2) < 0) __PYX_ERR(2, 15644, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15656
 *         return GiacMethods['ref'](self,*args)
 * 
 *      def reflection(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reflection:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2517reflection, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reflection, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1283)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reflection, __pyx_t_2) < 0) __PYX_ERR(2, 15656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15669
 *         return GiacMethods['reflection'](self,*args)
 * 
 *      def regroup(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for regroup:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2519regroup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_regroup, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1284)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_regroup, __pyx_t_2) < 0) __PYX_ERR(2, 15669, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15680
 *         return GiacMethods['regroup'](self,*args)
 * 
 *      def relabel_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for relabel_vertices:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2521relabel_vertices, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_relabel_vertice, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1285)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_relabel_vertices, __pyx_t_2) < 0) __PYX_ERR(2, 15680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15691
 *         return GiacMethods['relabel_vertices'](self,*args)
 * 
 *      def reliability_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reliability_polynomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2523reliability_polynomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reliability_pol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1286)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reliability_polynomial, __pyx_t_2) < 0) __PYX_ERR(2, 15691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15703
 *         return GiacMethods['reliability_polynomial'](self,*args)
 * 
 *      def rem(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rem:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2525rem, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1287)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rem, __pyx_t_2) < 0) __PYX_ERR(2, 15703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15716
 *         return GiacMethods['rem'](self,*args)
 * 
 *      def remain(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remain:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2527remain, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_remain, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1288)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15716, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_remain, __pyx_t_2) < 0) __PYX_ERR(2, 15716, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15730
 *         return GiacMethods['remain'](self,*args)
 * 
 *      def remove(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for remove:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2529remove, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_remove, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1289)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_remove, __pyx_t_2) < 0) __PYX_ERR(2, 15730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15742
 *         return GiacMethods['remove'](self,*args)
 * 
 *      def reorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reorder:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2531reorder, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reorder, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1290)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reorder, __pyx_t_2) < 0) __PYX_ERR(2, 15742, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15754
 *         return GiacMethods['reorder'](self,*args)
 * 
 *      def resample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resample:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2533resample, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_resample, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1291)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_resample, __pyx_t_2) < 0) __PYX_ERR(2, 15754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15766
 *         return GiacMethods['resample'](self,*args)
 * 
 *      def residue(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for residue:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2535residue, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_residue, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1292)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_residue, __pyx_t_2) < 0) __PYX_ERR(2, 15766, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15780
 *         return GiacMethods['residue'](self,*args)
 * 
 *      def resoudre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2537resoudre, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_resoudre, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1293)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_resoudre, __pyx_t_2) < 0) __PYX_ERR(2, 15780, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15794
 *         return GiacMethods['resoudre'](self,*args)
 * 
 *      def resoudre_dans_C(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_dans_C:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2539resoudre_dans_C, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_resoudre_dans_C, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1294)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_resoudre_dans_C, __pyx_t_2) < 0) __PYX_ERR(2, 15794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15808
 *         return GiacMethods['resoudre_dans_C'](self,*args)
 * 
 *      def resoudre_systeme_lineaire(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resoudre_systeme_lineaire:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2541resoudre_systeme_lineaire, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_resoudre_system, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1295)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_resoudre_systeme_lineaire, __pyx_t_2) < 0) __PYX_ERR(2, 15808, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15827
 *         return GiacMethods['resoudre_systeme_lineaire'](self,*args)
 * 
 *      def resultant(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for resultant:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2543resultant, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_resultant, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1296)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_resultant, __pyx_t_2) < 0) __PYX_ERR(2, 15827, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15839
 *         return GiacMethods['resultant'](self,*args)
 * 
 *      def reverse(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2545reverse, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reverse, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1297)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reverse, __pyx_t_2) < 0) __PYX_ERR(2, 15839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15852
 *         return GiacMethods['reverse'](self,*args)
 * 
 *      def reverse_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2547reverse_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reverse_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1298)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reverse_graph, __pyx_t_2) < 0) __PYX_ERR(2, 15852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15863
 *         return GiacMethods['reverse_graph'](self,*args)
 * 
 *      def reverse_rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for reverse_rsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2549reverse_rsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_reverse_rsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1299)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reverse_rsolve, __pyx_t_2) < 0) __PYX_ERR(2, 15863, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15874
 *         return GiacMethods['reverse_rsolve'](self,*args)
 * 
 *      def revert(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revert:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2551revert, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_revert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1300)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_revert, __pyx_t_2) < 0) __PYX_ERR(2, 15874, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15885
 *         return GiacMethods['revert'](self,*args)
 * 
 *      def revlex(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlex:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2553revlex, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_revlex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1301)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_revlex, __pyx_t_2) < 0) __PYX_ERR(2, 15885, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15895
 *         return GiacMethods['revlex'](self,*args)
 * 
 *      def revlist(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for revlist:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2555revlist, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_revlist, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1302)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_revlist, __pyx_t_2) < 0) __PYX_ERR(2, 15895, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15908
 *         return GiacMethods['revlist'](self,*args)
 * 
 *      def rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2557rgb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rgb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1303)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rgb, __pyx_t_2) < 0) __PYX_ERR(2, 15908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15927
 *         return GiacMethods['rgb'](self,*args)
 * 
 *      def rgb2hsv(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2hsv:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2559rgb2hsv, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rgb2hsv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1304)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rgb2hsv, __pyx_t_2) < 0) __PYX_ERR(2, 15927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15940
 *         return GiacMethods['rgb2hsv'](self,*args)
 * 
 *      def rgb2xyz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rgb2xyz:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2561rgb2xyz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rgb2xyz, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1305)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rgb2xyz, __pyx_t_2) < 0) __PYX_ERR(2, 15940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15953
 *         return GiacMethods['rgb2xyz'](self,*args)
 * 
 *      def rhombus(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2563rhombus, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rhombus, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1306)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rhombus, __pyx_t_2) < 0) __PYX_ERR(2, 15953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15968
 *         return GiacMethods['rhombus'](self,*args)
 * 
 *      def rhombus_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhombus_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2565rhombus_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rhombus_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1307)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rhombus_point, __pyx_t_2) < 0) __PYX_ERR(2, 15968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15980
 *         return GiacMethods['rhombus_point'](self,*args)
 * 
 *      def rhs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rhs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2567rhs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rhs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1308)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rhs, __pyx_t_2) < 0) __PYX_ERR(2, 15980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":15994
 *         return GiacMethods['rhs'](self,*args)
 * 
 *      def riemann_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for riemann_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2569riemann_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_riemann_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1309)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_riemann_window, __pyx_t_2) < 0) __PYX_ERR(2, 15994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16005
 *         return GiacMethods['riemann_window'](self,*args)
 * 
 *      def right(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2571right, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_right, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1310)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_right, __pyx_t_2) < 0) __PYX_ERR(2, 16005, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16019
 *         return GiacMethods['right'](self,*args)
 * 
 *      def right_rectangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_rectangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2573right_rectangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_right_rectangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1311)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_right_rectangle, __pyx_t_2) < 0) __PYX_ERR(2, 16019, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16035
 *         return GiacMethods['right_rectangle'](self,*args)
 * 
 *      def right_triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for right_triangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2575right_triangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_right_triangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1312)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_right_triangle, __pyx_t_2) < 0) __PYX_ERR(2, 16035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16050
 *         return GiacMethods['right_triangle'](self,*args)
 * 
 *      def risch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for risch:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2577risch, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_risch, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1313)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_risch, __pyx_t_2) < 0) __PYX_ERR(2, 16050, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16063
 *         return GiacMethods['risch'](self,*args)
 * 
 *      def rm_a_z(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_a_z:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2579rm_a_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rm_a_z, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1314)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rm_a_z, __pyx_t_2) < 0) __PYX_ERR(2, 16063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16074
 *         return GiacMethods['rm_a_z'](self,*args)
 * 
 *      def rm_all_vars(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rm_all_vars:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2581rm_all_vars, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rm_all_vars, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1315)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rm_all_vars, __pyx_t_2) < 0) __PYX_ERR(2, 16074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16085
 *         return GiacMethods['rm_all_vars'](self,*args)
 * 
 *      def rmbreakpoint(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmbreakpoint:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2583rmbreakpoint, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rmbreakpoint, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1316)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rmbreakpoint, __pyx_t_2) < 0) __PYX_ERR(2, 16085, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16096
 *         return GiacMethods['rmbreakpoint'](self,*args)
 * 
 *      def rmmod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmmod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2585rmmod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rmmod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1317)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rmmod, __pyx_t_2) < 0) __PYX_ERR(2, 16096, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16107
 *         return GiacMethods['rmmod'](self,*args)
 * 
 *      def rms(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rms:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2587rms, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rms, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1318)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rms, __pyx_t_2) < 0) __PYX_ERR(2, 16107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16118
 *         return GiacMethods['rms'](self,*args)
 * 
 *      def rmwatch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rmwatch:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2589rmwatch, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rmwatch, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1319)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rmwatch, __pyx_t_2) < 0) __PYX_ERR(2, 16118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16129
 *         return GiacMethods['rmwatch'](self,*args)
 * 
 *      def romberg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for romberg:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2591romberg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_romberg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1320)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_romberg, __pyx_t_2) < 0) __PYX_ERR(2, 16129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16142
 *         return GiacMethods['romberg'](self,*args)
 * 
 *      def rombergm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2593rombergm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rombergm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1321)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rombergm, __pyx_t_2) < 0) __PYX_ERR(2, 16142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16156
 *         return GiacMethods['rombergm'](self,*args)
 * 
 *      def rombergt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rombergt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2595rombergt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rombergt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1322)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rombergt, __pyx_t_2) < 0) __PYX_ERR(2, 16156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16170
 *         return GiacMethods['rombergt'](self,*args)
 * 
 *      def rond(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rond:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2597rond, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rond, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1323)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rond, __pyx_t_2) < 0) __PYX_ERR(2, 16170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16184
 *         return GiacMethods['rond'](self,*args)
 * 
 *      def root(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for root:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2599root, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_root, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1324)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_root, __pyx_t_2) < 0) __PYX_ERR(2, 16184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16198
 *         return GiacMethods['root'](self,*args)
 * 
 *      def rootof(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rootof:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2601rootof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rootof, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1325)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rootof, __pyx_t_2) < 0) __PYX_ERR(2, 16198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16211
 *         return GiacMethods['rootof'](self,*args)
 * 
 *      def roots(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for roots:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2603roots, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_roots, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1326)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_roots, __pyx_t_2) < 0) __PYX_ERR(2, 16211, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16223
 *         return GiacMethods['roots'](self,*args)
 * 
 *      def rotate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2605rotate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rotate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1327)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rotate, __pyx_t_2) < 0) __PYX_ERR(2, 16223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16241
 *         return GiacMethods['rotate'](self,*args)
 * 
 *      def rotation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rotation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2607rotation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rotation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1328)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rotation, __pyx_t_2) < 0) __PYX_ERR(2, 16241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16256
 *         return GiacMethods['rotation'](self,*args)
 * 
 *      def round(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for round:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2609round, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_round, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1329)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_round, __pyx_t_2) < 0) __PYX_ERR(2, 16256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16271
 *         return GiacMethods['round'](self,*args)
 * 
 *      def row(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for row:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2611row, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_row, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1330)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_row, __pyx_t_2) < 0) __PYX_ERR(2, 16271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16284
 *         return GiacMethods['row'](self,*args)
 * 
 *      def rowAdd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowAdd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2613rowAdd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowAdd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1331)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowAdd, __pyx_t_2) < 0) __PYX_ERR(2, 16284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16295
 *         return GiacMethods['rowAdd'](self,*args)
 * 
 *      def rowDim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowDim:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2615rowDim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowDim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1332)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowDim, __pyx_t_2) < 0) __PYX_ERR(2, 16295, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16307
 *         return GiacMethods['rowDim'](self,*args)
 * 
 *      def rowNorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowNorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2617rowNorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowNorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1333)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowNorm, __pyx_t_2) < 0) __PYX_ERR(2, 16307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16319
 *         return GiacMethods['rowNorm'](self,*args)
 * 
 *      def rowSwap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowSwap:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2619rowSwap, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowSwap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1334)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowSwap, __pyx_t_2) < 0) __PYX_ERR(2, 16319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16330
 *         return GiacMethods['rowSwap'](self,*args)
 * 
 *      def rowdim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowdim:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2621rowdim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowdim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1335)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowdim, __pyx_t_2) < 0) __PYX_ERR(2, 16330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16342
 *         return GiacMethods['rowdim'](self,*args)
 * 
 *      def rownorm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rownorm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2623rownorm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rownorm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1336)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rownorm, __pyx_t_2) < 0) __PYX_ERR(2, 16342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16354
 *         return GiacMethods['rownorm'](self,*args)
 * 
 *      def rowspace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowspace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2625rowspace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowspace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1337)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowspace, __pyx_t_2) < 0) __PYX_ERR(2, 16354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16366
 *         return GiacMethods['rowspace'](self,*args)
 * 
 *      def rowswap(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rowswap:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2627rowswap, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rowswap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1338)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rowswap, __pyx_t_2) < 0) __PYX_ERR(2, 16366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16377
 *         return GiacMethods['rowswap'](self,*args)
 * 
 *      def rref(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rref:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2629rref, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rref, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1339)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rref, __pyx_t_2) < 0) __PYX_ERR(2, 16377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16391
 *         return GiacMethods['rref'](self,*args)
 * 
 *      def rsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2631rsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1340)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rsolve, __pyx_t_2) < 0) __PYX_ERR(2, 16391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16406
 *         return GiacMethods['rsolve'](self,*args)
 * 
 *      def rur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2633rur, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rur, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1341)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rur, __pyx_t_2) < 0) __PYX_ERR(2, 16406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16418
 *         return GiacMethods['rur'](self,*args)
 * 
 *      def rur_certify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_certify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2635rur_certify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rur_certify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1342)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rur_certify, __pyx_t_2) < 0) __PYX_ERR(2, 16418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16429
 *         return GiacMethods['rur_certify'](self,*args)
 * 
 *      def rur_gbasis(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for rur_gbasis:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2637rur_gbasis, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_rur_gbasis, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1343)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_rur_gbasis, __pyx_t_2) < 0) __PYX_ERR(2, 16429, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16440
 *         return GiacMethods['rur_gbasis'](self,*args)
 * 
 *      def same(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for same:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2639same, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_same, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1344)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_same, __pyx_t_2) < 0) __PYX_ERR(2, 16440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16452
 *         return GiacMethods['same'](self,*args)
 * 
 *      def sample(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sample:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2641sample, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sample, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1345)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sample, __pyx_t_2) < 0) __PYX_ERR(2, 16452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16468
 *         return GiacMethods['sample'](self,*args)
 * 
 *      def samplerate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for samplerate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2643samplerate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_samplerate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1346)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_samplerate, __pyx_t_2) < 0) __PYX_ERR(2, 16468, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16479
 *         return GiacMethods['samplerate'](self,*args)
 * 
 *      def sans_factoriser(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sans_factoriser:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2645sans_factoriser, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sans_factoriser, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1347)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sans_factoriser, __pyx_t_2) < 0) __PYX_ERR(2, 16479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16494
 *         return GiacMethods['sans_factoriser'](self,*args)
 * 
 *      def saute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for saute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2647saute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_saute, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1348)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_saute, __pyx_t_2) < 0) __PYX_ERR(2, 16494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16506
 *         return GiacMethods['saute'](self,*args)
 * 
 *      def scalarProduct(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalarProduct:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2649scalarProduct, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_scalarProduct, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1349)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_scalarProduct, __pyx_t_2) < 0) __PYX_ERR(2, 16506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16519
 *         return GiacMethods['scalarProduct'](self,*args)
 * 
 *      def scalar_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scalar_product:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2651scalar_product, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_scalar_product, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1350)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_scalar_product, __pyx_t_2) < 0) __PYX_ERR(2, 16519, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16532
 *         return GiacMethods['scalar_product'](self,*args)
 * 
 *      def scatterplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for scatterplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2653scatterplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_scatterplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1351)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_scatterplot, __pyx_t_2) < 0) __PYX_ERR(2, 16532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16543
 *         return GiacMethods['scatterplot'](self,*args)
 * 
 *      def schur(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for schur:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2655schur, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_schur, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1352)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_schur, __pyx_t_2) < 0) __PYX_ERR(2, 16543, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16555
 *         return GiacMethods['schur'](self,*args)
 * 
 *      def sec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sec:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2657sec, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sec, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1353)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sec, __pyx_t_2) < 0) __PYX_ERR(2, 16555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16566
 *         return GiacMethods['sec'](self,*args)
 * 
 *      def secant_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for secant_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2659secant_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_secant_solver, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1354)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_secant_solver, __pyx_t_2) < 0) __PYX_ERR(2, 16566, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16582
 *         return GiacMethods['secant_solver'](self,*args)
 * 
 *      def segment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for segment:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2661segment, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_segment, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1355)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_segment, __pyx_t_2) < 0) __PYX_ERR(2, 16582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16599
 *         return GiacMethods['segment'](self,*args)
 * 
 *      def seidel_spectrum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_spectrum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2663seidel_spectrum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_seidel_spectrum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1356)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_seidel_spectrum, __pyx_t_2) < 0) __PYX_ERR(2, 16599, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16610
 *         return GiacMethods['seidel_spectrum'](self,*args)
 * 
 *      def seidel_switch(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seidel_switch:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2665seidel_switch, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_seidel_switch, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1357)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_seidel_switch, __pyx_t_2) < 0) __PYX_ERR(2, 16610, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16621
 *         return GiacMethods['seidel_switch'](self,*args)
 * 
 *      def select(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for select:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2667select, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_select, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1358)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_select, __pyx_t_2) < 0) __PYX_ERR(2, 16621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16633
 *         return GiacMethods['select'](self,*args)
 * 
 *      def semi_augment(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for semi_augment:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2669semi_augment, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_semi_augment, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1359)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_semi_augment, __pyx_t_2) < 0) __PYX_ERR(2, 16633, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16644
 *         return GiacMethods['semi_augment'](self,*args)
 * 
 *      def seq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2671seq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_seq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1360)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_seq, __pyx_t_2) < 0) __PYX_ERR(2, 16644, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16665
 *         return GiacMethods['seq'](self,*args)
 * 
 *      def seqplot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqplot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2673seqplot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_seqplot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1361)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_seqplot, __pyx_t_2) < 0) __PYX_ERR(2, 16665, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16678
 *         return GiacMethods['seqplot'](self,*args)
 * 
 *      def seqsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for seqsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2675seqsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_seqsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1362)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_seqsolve, __pyx_t_2) < 0) __PYX_ERR(2, 16678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16694
 *         return GiacMethods['seqsolve'](self,*args)
 * 
 *      def sequence_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sequence_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2677sequence_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sequence_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1363)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sequence_graph, __pyx_t_2) < 0) __PYX_ERR(2, 16694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16705
 *         return GiacMethods['sequence_graph'](self,*args)
 * 
 *      def series(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for series:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2679series, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_series, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1364)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_series, __pyx_t_2) < 0) __PYX_ERR(2, 16705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16728
 *         return GiacMethods['series'](self,*args)
 * 
 *      def set_channel_data(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_channel_data:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2681set_channel_data, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_channel_dat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1365)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_channel_data, __pyx_t_2) < 0) __PYX_ERR(2, 16728, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16740
 *         return GiacMethods['set_channel_data'](self,*args)
 * 
 *      def set_edge_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2683set_edge_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_edge_attrib, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1366)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_edge_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 16740, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16751
 *         return GiacMethods['set_edge_attribute'](self,*args)
 * 
 *      def set_edge_weight(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_edge_weight:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2685set_edge_weight, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_edge_weight, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1367)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16751, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_edge_weight, __pyx_t_2) < 0) __PYX_ERR(2, 16751, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16762
 *         return GiacMethods['set_edge_weight'](self,*args)
 * 
 *      def set_graph_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_graph_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2687set_graph_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_graph_attri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1368)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_graph_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 16762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16773
 *         return GiacMethods['set_graph_attribute'](self,*args)
 * 
 *      def set_pixel(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_pixel:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2689set_pixel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_pixel, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1369)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_pixel, __pyx_t_2) < 0) __PYX_ERR(2, 16773, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16784
 *         return GiacMethods['set_pixel'](self,*args)
 * 
 *      def set_screen(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_screen:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2691set_screen, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_screen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1370)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_screen, __pyx_t_2) < 0) __PYX_ERR(2, 16784, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16794
 *         return GiacMethods['set_screen'](self,*args)
 * 
 *      def set_vertex_attribute(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_attribute:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2693set_vertex_attribute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_vertex_attr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1371)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_vertex_attribute, __pyx_t_2) < 0) __PYX_ERR(2, 16794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16805
 *         return GiacMethods['set_vertex_attribute'](self,*args)
 * 
 *      def set_vertex_positions(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for set_vertex_positions:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2695set_vertex_positions, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_set_vertex_posi, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1372)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_set_vertex_positions, __pyx_t_2) < 0) __PYX_ERR(2, 16805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16816
 *         return GiacMethods['set_vertex_positions'](self,*args)
 * 
 *      def shift(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2697shift, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_shift, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1373)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_shift, __pyx_t_2) < 0) __PYX_ERR(2, 16816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16831
 *         return GiacMethods['shift'](self,*args)
 * 
 *      def shift_phase(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shift_phase:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2699shift_phase, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_shift_phase, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1374)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_shift_phase, __pyx_t_2) < 0) __PYX_ERR(2, 16831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16847
 *         return GiacMethods['shift_phase'](self,*args)
 * 
 *      def shortest_path(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shortest_path:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2701shortest_path, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_shortest_path, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1375)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16847, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_shortest_path, __pyx_t_2) < 0) __PYX_ERR(2, 16847, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16858
 *         return GiacMethods['shortest_path'](self,*args)
 * 
 *      def show_pixels(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for show_pixels:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2703show_pixels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_show_pixels, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1376)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_show_pixels, __pyx_t_2) < 0) __PYX_ERR(2, 16858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16869
 *         return GiacMethods['show_pixels'](self,*args)
 * 
 *      def shuffle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for shuffle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2705shuffle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_shuffle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1377)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_shuffle, __pyx_t_2) < 0) __PYX_ERR(2, 16869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16884
 *         return GiacMethods['shuffle'](self,*args)
 * 
 *      def sierpinski_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sierpinski_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2707sierpinski_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sierpinski_grap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1378)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sierpinski_graph, __pyx_t_2) < 0) __PYX_ERR(2, 16884, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16899
 *         return GiacMethods['sierpinski_graph'](self,*args)
 * 
 *      def sign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2709sign, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sign, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1379)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sign, __pyx_t_2) < 0) __PYX_ERR(2, 16899, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16911
 *         return GiacMethods['sign'](self,*args)
 * 
 *      def sign2Heaviside(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sign2Heaviside:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2711sign2Heaviside, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sign2Heaviside, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1380)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sign2Heaviside, __pyx_t_2) < 0) __PYX_ERR(2, 16911, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16922
 *         return GiacMethods['sign2Heaviside'](self,*args)
 * 
 *      def signature(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signature:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2713signature, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_signature, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1381)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_signature, __pyx_t_2) < 0) __PYX_ERR(2, 16922, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16933
 *         return GiacMethods['signature'](self,*args)
 * 
 *      def signe(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for signe:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2715signe, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_signe, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1382)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_signe, __pyx_t_2) < 0) __PYX_ERR(2, 16933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16945
 *         return GiacMethods['signe'](self,*args)
 * 
 *      def similarity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for similarity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2717similarity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_similarity, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1383)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_similarity, __pyx_t_2) < 0) __PYX_ERR(2, 16945, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16959
 *         return GiacMethods['similarity'](self,*args)
 * 
 *      def simp2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simp2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2719simp2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simp2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1384)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simp2, __pyx_t_2) < 0) __PYX_ERR(2, 16959, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16971
 *         return GiacMethods['simp2'](self,*args)
 * 
 *      def simplex_reduce(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplex_reduce:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2721simplex_reduce, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simplex_reduce, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1385)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simplex_reduce, __pyx_t_2) < 0) __PYX_ERR(2, 16971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16985
 *         return GiacMethods['simplex_reduce'](self,*args)
 * 
 *      def simplicial_vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplicial_vertices:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2723simplicial_vertices, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simplicial_vert, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1386)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simplicial_vertices, __pyx_t_2) < 0) __PYX_ERR(2, 16985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":16996
 *         return GiacMethods['simplicial_vertices'](self,*args)
 * 
 *      def simplifier(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifier:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2725simplifier, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simplifier, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1387)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 16996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simplifier, __pyx_t_2) < 0) __PYX_ERR(2, 16996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17009
 *         return GiacMethods['simplifier'](self,*args)
 * 
 *      def simplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2727simplify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simplify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1388)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simplify, __pyx_t_2) < 0) __PYX_ERR(2, 17009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17022
 *         return GiacMethods['simplify'](self,*args)
 * 
 *      def simplifyDirac(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simplifyDirac:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2729simplifyDirac, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simplifyDirac, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1389)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simplifyDirac, __pyx_t_2) < 0) __PYX_ERR(2, 17022, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17035
 *         return GiacMethods['simplifyDirac'](self,*args)
 * 
 *      def simpson(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simpson:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2731simpson, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simpson, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1390)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simpson, __pyx_t_2) < 0) __PYX_ERR(2, 17035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17049
 *         return GiacMethods['simpson'](self,*args)
 * 
 *      def simulated_annealing(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simulated_annealing:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2733simulated_annealing, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simulated_annea, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1391)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simulated_annealing, __pyx_t_2) < 0) __PYX_ERR(2, 17049, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17060
 *         return GiacMethods['simulated_annealing'](self,*args)
 * 
 *      def simult(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for simult:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2735simult, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_simult, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1392)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_simult, __pyx_t_2) < 0) __PYX_ERR(2, 17060, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17072
 *         return GiacMethods['simult'](self,*args)
 * 
 *      def sin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2737sin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1393)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sin, __pyx_t_2) < 0) __PYX_ERR(2, 17072, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17084
 *         return GiacMethods['sin'](self,*args)
 * 
 *      def sin2costan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sin2costan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2739sin2costan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sin2costan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1394)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sin2costan, __pyx_t_2) < 0) __PYX_ERR(2, 17084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17095
 *         return GiacMethods['sin2costan'](self,*args)
 * 
 *      def sinc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2741sinc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sinc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1395)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sinc, __pyx_t_2) < 0) __PYX_ERR(2, 17095, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17106
 *         return GiacMethods['sinc'](self,*args)
 * 
 *      def sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sincos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2743sincos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sincos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1396)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sincos, __pyx_t_2) < 0) __PYX_ERR(2, 17106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17119
 *         return GiacMethods['sincos'](self,*args)
 * 
 *      def single_inter(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for single_inter:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2745single_inter, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_single_inter, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1397)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_single_inter, __pyx_t_2) < 0) __PYX_ERR(2, 17119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17136
 *         return GiacMethods['single_inter'](self,*args)
 * 
 *      def sinh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sinh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2747sinh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sinh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1398)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sinh, __pyx_t_2) < 0) __PYX_ERR(2, 17136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17147
 *         return GiacMethods['sinh'](self,*args)
 * 
 *      def sizes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sizes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2749sizes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sizes, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1399)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sizes, __pyx_t_2) < 0) __PYX_ERR(2, 17147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17158
 *         return GiacMethods['sizes'](self,*args)
 * 
 *      def slope(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slope:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2751slope, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_slope, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1400)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_slope, __pyx_t_2) < 0) __PYX_ERR(2, 17158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17176
 *         return GiacMethods['slope'](self,*args)
 * 
 *      def slopeat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2753slopeat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_slopeat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1401)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_slopeat, __pyx_t_2) < 0) __PYX_ERR(2, 17176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17189
 *         return GiacMethods['slopeat'](self,*args)
 * 
 *      def slopeatraw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for slopeatraw:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2755slopeatraw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_slopeatraw, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1402)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_slopeatraw, __pyx_t_2) < 0) __PYX_ERR(2, 17189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17203
 *         return GiacMethods['slopeatraw'](self,*args)
 * 
 *      def smith(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smith:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2757smith, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_smith, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1403)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_smith, __pyx_t_2) < 0) __PYX_ERR(2, 17203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17215
 *         return GiacMethods['smith'](self,*args)
 * 
 *      def smod(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for smod:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2759smod, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_smod, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1404)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_smod, __pyx_t_2) < 0) __PYX_ERR(2, 17215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17228
 *         return GiacMethods['smod'](self,*args)
 * 
 *      def snedecor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2761snedecor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_snedecor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1405)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_snedecor, __pyx_t_2) < 0) __PYX_ERR(2, 17228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17242
 *         return GiacMethods['snedecor'](self,*args)
 * 
 *      def snedecor_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2763snedecor_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_snedecor_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1406)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_snedecor_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 17242, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17254
 *         return GiacMethods['snedecor_cdf'](self,*args)
 * 
 *      def snedecor_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecor_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2765snedecor_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_snedecor_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1407)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_snedecor_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 17254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17266
 *         return GiacMethods['snedecor_icdf'](self,*args)
 * 
 *      def snedecord(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2767snedecord, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_snedecord, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1408)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_snedecord, __pyx_t_2) < 0) __PYX_ERR(2, 17266, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17280
 *         return GiacMethods['snedecord'](self,*args)
 * 
 *      def snedecord_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2769snedecord_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_snedecord_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1409)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_snedecord_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 17280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17292
 *         return GiacMethods['snedecord_cdf'](self,*args)
 * 
 *      def snedecord_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for snedecord_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2771snedecord_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_snedecord_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1410)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_snedecord_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 17292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17304
 *         return GiacMethods['snedecord_icdf'](self,*args)
 * 
 *      def solid_line(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solid_line:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2773solid_line, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_solid_line, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1411)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_solid_line, __pyx_t_2) < 0) __PYX_ERR(2, 17304, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17316
 *         return GiacMethods['solid_line'](self,*args)
 * 
 *      def solve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for solve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2775solve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_solve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1412)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_solve, __pyx_t_2) < 0) __PYX_ERR(2, 17316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17330
 *         return GiacMethods['solve'](self,*args)
 * 
 *      def somme(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for somme:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2777somme, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_somme, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1413)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_somme, __pyx_t_2) < 0) __PYX_ERR(2, 17330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17350
 *         return GiacMethods['somme'](self,*args)
 * 
 *      def sommet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sommet:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2779sommet, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sommet, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1414)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sommet, __pyx_t_2) < 0) __PYX_ERR(2, 17350, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17362
 *         return GiacMethods['sommet'](self,*args)
 * 
 *      def sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sort:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2781sort, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sort, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1415)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sort, __pyx_t_2) < 0) __PYX_ERR(2, 17362, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17377
 *         return GiacMethods['sort'](self,*args)
 * 
 *      def sorta(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorta:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2783sorta, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sorta, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1416)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sorta, __pyx_t_2) < 0) __PYX_ERR(2, 17377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17390
 *         return GiacMethods['sorta'](self,*args)
 * 
 *      def sortd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2785sortd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sortd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1417)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sortd, __pyx_t_2) < 0) __PYX_ERR(2, 17390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17403
 *         return GiacMethods['sortd'](self,*args)
 * 
 *      def sorted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sorted:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2787sorted, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sorted, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1418)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sorted, __pyx_t_2) < 0) __PYX_ERR(2, 17403, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17418
 *         return GiacMethods['sorted'](self,*args)
 * 
 *      def sortperm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sortperm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2789sortperm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sortperm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1419)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sortperm, __pyx_t_2) < 0) __PYX_ERR(2, 17418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17430
 *         return GiacMethods['sortperm'](self,*args)
 * 
 *      def soundsec(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for soundsec:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2791soundsec, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_soundsec, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1420)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_soundsec, __pyx_t_2) < 0) __PYX_ERR(2, 17430, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17442
 *         return GiacMethods['soundsec'](self,*args)
 * 
 *      def spanning_tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spanning_tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2793spanning_tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_spanning_tree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1421)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_spanning_tree, __pyx_t_2) < 0) __PYX_ERR(2, 17442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17454
 *         return GiacMethods['spanning_tree'](self,*args)
 * 
 *      def sphere(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sphere:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2795sphere, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sphere, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1422)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sphere, __pyx_t_2) < 0) __PYX_ERR(2, 17454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17466
 *         return GiacMethods['sphere'](self,*args)
 * 
 *      def splice(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for splice:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2797splice, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_splice, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1423)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_splice, __pyx_t_2) < 0) __PYX_ERR(2, 17466, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17477
 *         return GiacMethods['splice'](self,*args)
 * 
 *      def spline(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spline:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2799spline, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_spline, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1424)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_spline, __pyx_t_2) < 0) __PYX_ERR(2, 17477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17488
 *         return GiacMethods['spline'](self,*args)
 * 
 *      def split(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for split:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2801split, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_split, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1425)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_split, __pyx_t_2) < 0) __PYX_ERR(2, 17488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17501
 *         return GiacMethods['split'](self,*args)
 * 
 *      def spring(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for spring:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2803spring, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_spring, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1426)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_spring, __pyx_t_2) < 0) __PYX_ERR(2, 17501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17511
 *         return GiacMethods['spring'](self,*args)
 * 
 *      def sq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2805sq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1427)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sq, __pyx_t_2) < 0) __PYX_ERR(2, 17511, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17523
 *         return GiacMethods['sq'](self,*args)
 * 
 *      def sqrfree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrfree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2807sqrfree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sqrfree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1428)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sqrfree, __pyx_t_2) < 0) __PYX_ERR(2, 17523, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17535
 *         return GiacMethods['sqrfree'](self,*args)
 * 
 *      def sqrt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sqrt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2809sqrt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sqrt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1429)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sqrt, __pyx_t_2) < 0) __PYX_ERR(2, 17535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17547
 *         return GiacMethods['sqrt'](self,*args)
 * 
 *      def square(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2811square, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_square, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1430)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_square, __pyx_t_2) < 0) __PYX_ERR(2, 17547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17561
 *         return GiacMethods['square'](self,*args)
 * 
 *      def square_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for square_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2813square_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_square_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1431)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_square_point, __pyx_t_2) < 0) __PYX_ERR(2, 17561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17573
 *         return GiacMethods['square_point'](self,*args)
 * 
 *      def srand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for srand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2815srand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_srand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1432)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_srand, __pyx_t_2) < 0) __PYX_ERR(2, 17573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17585
 *         return GiacMethods['srand'](self,*args)
 * 
 *      def sst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2817sst, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sst, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1433)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sst, __pyx_t_2) < 0) __PYX_ERR(2, 17585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17596
 *         return GiacMethods['sst'](self,*args)
 * 
 *      def sst_in(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sst_in:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2819sst_in, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sst_in, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1434)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sst_in, __pyx_t_2) < 0) __PYX_ERR(2, 17596, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17607
 *         return GiacMethods['sst_in'](self,*args)
 * 
 *      def st_ordering(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for st_ordering:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2821st_ordering, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_st_ordering, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1435)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_st_ordering, __pyx_t_2) < 0) __PYX_ERR(2, 17607, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17618
 *         return GiacMethods['st_ordering'](self,*args)
 * 
 *      def star_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2823star_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_star_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1436)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_star_graph, __pyx_t_2) < 0) __PYX_ERR(2, 17618, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17629
 *         return GiacMethods['star_graph'](self,*args)
 * 
 *      def star_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for star_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2825star_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_star_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1437)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_star_point, __pyx_t_2) < 0) __PYX_ERR(2, 17629, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17641
 *         return GiacMethods['star_point'](self,*args)
 * 
 *      def stdDev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stdDev:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2827stdDev, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_stdDev, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1438)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_stdDev, __pyx_t_2) < 0) __PYX_ERR(2, 17641, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17654
 *         return GiacMethods['stdDev'](self,*args)
 * 
 *      def stddev(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddev:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2829stddev, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_stddev, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1439)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_stddev, __pyx_t_2) < 0) __PYX_ERR(2, 17654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17667
 *         return GiacMethods['stddev'](self,*args)
 * 
 *      def stddevp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stddevp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2831stddevp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_stddevp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1440)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_stddevp, __pyx_t_2) < 0) __PYX_ERR(2, 17667, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17680
 *         return GiacMethods['stddevp'](self,*args)
 * 
 *      def steffenson_solver(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for steffenson_solver:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2833steffenson_solver, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_steffenson_solv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1441)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_steffenson_solver, __pyx_t_2) < 0) __PYX_ERR(2, 17680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17696
 *         return GiacMethods['steffenson_solver'](self,*args)
 * 
 *      def stereo2mono(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stereo2mono:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2835stereo2mono, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_stereo2mono, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1442)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_stereo2mono, __pyx_t_2) < 0) __PYX_ERR(2, 17696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17707
 *         return GiacMethods['stereo2mono'](self,*args)
 * 
 *      def stft(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for stft:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2837stft, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_stft, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1443)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_stft, __pyx_t_2) < 0) __PYX_ERR(2, 17707, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17719
 *         return GiacMethods['stft'](self,*args)
 * 
 *      def str(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for str:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2839str, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_str, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1444)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_str, __pyx_t_2) < 0) __PYX_ERR(2, 17719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17733
 *         return GiacMethods['str'](self,*args)
 * 
 *      def strip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strip:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2841strip, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_strip, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1445)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_strip, __pyx_t_2) < 0) __PYX_ERR(2, 17733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17744
 *         return GiacMethods['strip'](self,*args)
 * 
 *      def strongly_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for strongly_connected_components:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2843strongly_connected_components, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_strongly_connec, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1446)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_strongly_connected_components, __pyx_t_2) < 0) __PYX_ERR(2, 17744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17755
 *         return GiacMethods['strongly_connected_components'](self,*args)
 * 
 *      def student(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2845student, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_student, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1447)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_student, __pyx_t_2) < 0) __PYX_ERR(2, 17755, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17767
 *         return GiacMethods['student'](self,*args)
 * 
 *      def student_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2847student_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_student_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1448)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_student_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 17767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17779
 *         return GiacMethods['student_cdf'](self,*args)
 * 
 *      def student_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for student_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2849student_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_student_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1449)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_student_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 17779, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17791
 *         return GiacMethods['student_icdf'](self,*args)
 * 
 *      def studentd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2851studentd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_studentd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1450)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_studentd, __pyx_t_2) < 0) __PYX_ERR(2, 17791, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17803
 *         return GiacMethods['studentd'](self,*args)
 * 
 *      def studentt(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for studentt:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2853studentt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_studentt, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1451)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_studentt, __pyx_t_2) < 0) __PYX_ERR(2, 17803, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17815
 *         return GiacMethods['studentt'](self,*args)
 * 
 *      def sturm(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturm:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2855sturm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sturm, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1452)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sturm, __pyx_t_2) < 0) __PYX_ERR(2, 17815, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17830
 *         return GiacMethods['sturm'](self,*args)
 * 
 *      def sturmab(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmab:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2857sturmab, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sturmab, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1453)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sturmab, __pyx_t_2) < 0) __PYX_ERR(2, 17830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17842
 *         return GiacMethods['sturmab'](self,*args)
 * 
 *      def sturmseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sturmseq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2859sturmseq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sturmseq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1454)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sturmseq, __pyx_t_2) < 0) __PYX_ERR(2, 17842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17855
 *         return GiacMethods['sturmseq'](self,*args)
 * 
 *      def style(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for style:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2861style, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_style, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1455)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_style, __pyx_t_2) < 0) __PYX_ERR(2, 17855, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17867
 *         return GiacMethods['style'](self,*args)
 * 
 *      def subMat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subMat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2863subMat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subMat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1456)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subMat, __pyx_t_2) < 0) __PYX_ERR(2, 17867, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17878
 *         return GiacMethods['subMat'](self,*args)
 * 
 *      def subdivide_edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subdivide_edges:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2865subdivide_edges, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subdivide_edges, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1457)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subdivide_edges, __pyx_t_2) < 0) __PYX_ERR(2, 17878, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17889
 *         return GiacMethods['subdivide_edges'](self,*args)
 * 
 *      def subgraph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subgraph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2867subgraph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subgraph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1458)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subgraph, __pyx_t_2) < 0) __PYX_ERR(2, 17889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17900
 *         return GiacMethods['subgraph'](self,*args)
 * 
 *      def subs(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subs:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2869subs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subs, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1459)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subs, __pyx_t_2) < 0) __PYX_ERR(2, 17900, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17913
 *         return GiacMethods['subs'](self,*args)
 * 
 *      def subsop(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subsop:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2871subsop, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subsop, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1460)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subsop, __pyx_t_2) < 0) __PYX_ERR(2, 17913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17926
 *         return GiacMethods['subsop'](self,*args)
 * 
 *      def subst(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subst:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2873subst, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subst, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1461)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subst, __pyx_t_2) < 0) __PYX_ERR(2, 17926, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17943
 *         return GiacMethods['subst'](self,*args)
 * 
 *      def substituer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for substituer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2875substituer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_substituer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1462)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_substituer, __pyx_t_2) < 0) __PYX_ERR(2, 17943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17960
 *         return GiacMethods['substituer'](self,*args)
 * 
 *      def subtype(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for subtype:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2877subtype, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_subtype, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1463)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_subtype, __pyx_t_2) < 0) __PYX_ERR(2, 17960, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17974
 *         return GiacMethods['subtype'](self,*args)
 * 
 *      def sum(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2879sum, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sum, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1464)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sum, __pyx_t_2) < 0) __PYX_ERR(2, 17974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":17994
 *         return GiacMethods['sum'](self,*args)
 * 
 *      def sum_riemann(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sum_riemann:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2881sum_riemann, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sum_riemann, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1465)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sum_riemann, __pyx_t_2) < 0) __PYX_ERR(2, 17994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18007
 *         return GiacMethods['sum_riemann'](self,*args)
 * 
 *      def suppress(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for suppress:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2883suppress, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_suppress, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1466)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_suppress, __pyx_t_2) < 0) __PYX_ERR(2, 18007, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18021
 *         return GiacMethods['suppress'](self,*args)
 * 
 *      def surd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for surd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2885surd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_surd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1467)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_surd, __pyx_t_2) < 0) __PYX_ERR(2, 18021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18033
 *         return GiacMethods['surd'](self,*args)
 * 
 *      def svd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for svd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2887svd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_svd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1468)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_svd, __pyx_t_2) < 0) __PYX_ERR(2, 18033, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18043
 *         return GiacMethods['svd'](self,*args)
 * 
 *      def swapcol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swapcol:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2889swapcol, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_swapcol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1469)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_swapcol, __pyx_t_2) < 0) __PYX_ERR(2, 18043, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18054
 *         return GiacMethods['swapcol'](self,*args)
 * 
 *      def swaprow(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for swaprow:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2891swaprow, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_swaprow, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1470)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_swaprow, __pyx_t_2) < 0) __PYX_ERR(2, 18054, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18065
 *         return GiacMethods['swaprow'](self,*args)
 * 
 *      def switch_axes(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for switch_axes:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2893switch_axes, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_switch_axes, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1471)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_switch_axes, __pyx_t_2) < 0) __PYX_ERR(2, 18065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18078
 *         return GiacMethods['switch_axes'](self,*args)
 * 
 *      def sylvester(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for sylvester:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2895sylvester, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_sylvester, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1472)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_sylvester, __pyx_t_2) < 0) __PYX_ERR(2, 18078, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18090
 *         return GiacMethods['sylvester'](self,*args)
 * 
 *      def symb2poly(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symb2poly:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2897symb2poly, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_symb2poly, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1473)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_symb2poly, __pyx_t_2) < 0) __PYX_ERR(2, 18090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18106
 *         return GiacMethods['symb2poly'](self,*args)
 * 
 *      def symbol(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2899symbol, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_symbol, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1474)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_symbol, __pyx_t_2) < 0) __PYX_ERR(2, 18106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18120
 *         return GiacMethods['symbol'](self,*args)
 * 
 *      def symbol_array(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for symbol_array:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2901symbol_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_symbol_array, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1475)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_symbol_array, __pyx_t_2) < 0) __PYX_ERR(2, 18120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18133
 *         return GiacMethods['symbol_array'](self,*args)
 * 
 *      def syst2mat(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for syst2mat:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2903syst2mat, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_syst2mat, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1476)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_syst2mat, __pyx_t_2) < 0) __PYX_ERR(2, 18133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18144
 *         return GiacMethods['syst2mat'](self,*args)
 * 
 *      def tCollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tCollect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2905tCollect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tCollect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1477)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tCollect, __pyx_t_2) < 0) __PYX_ERR(2, 18144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18155
 *         return GiacMethods['tCollect'](self,*args)
 * 
 *      def tExpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tExpand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2907tExpand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tExpand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1478)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tExpand, __pyx_t_2) < 0) __PYX_ERR(2, 18155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18168
 *         return GiacMethods['tExpand'](self,*args)
 * 
 *      def table(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for table:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2909table, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_table, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1479)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_table, __pyx_t_2) < 0) __PYX_ERR(2, 18168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18181
 *         return GiacMethods['table'](self,*args)
 * 
 *      def tablefunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tablefunc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2911tablefunc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tablefunc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1480)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tablefunc, __pyx_t_2) < 0) __PYX_ERR(2, 18181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18193
 *         return GiacMethods['tablefunc'](self,*args)
 * 
 *      def tableseq(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tableseq:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2913tableseq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tableseq, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1481)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tableseq, __pyx_t_2) < 0) __PYX_ERR(2, 18193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18205
 *         return GiacMethods['tableseq'](self,*args)
 * 
 *      def tabsign(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabsign:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2915tabsign, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tabsign, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1482)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tabsign, __pyx_t_2) < 0) __PYX_ERR(2, 18205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18218
 *         return GiacMethods['tabsign'](self,*args)
 * 
 *      def tabvar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tabvar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2917tabvar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tabvar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1483)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tabvar, __pyx_t_2) < 0) __PYX_ERR(2, 18218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18233
 *         return GiacMethods['tabvar'](self,*args)
 * 
 *      def tail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tail:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2919tail, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tail, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1484)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tail, __pyx_t_2) < 0) __PYX_ERR(2, 18233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18246
 *         return GiacMethods['tail'](self,*args)
 * 
 *      def tan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2921tan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1485)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tan, __pyx_t_2) < 0) __PYX_ERR(2, 18246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18259
 *         return GiacMethods['tan'](self,*args)
 * 
 *      def tan2cossin2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2cossin2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2923tan2cossin2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tan2cossin2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1486)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tan2cossin2, __pyx_t_2) < 0) __PYX_ERR(2, 18259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18270
 *         return GiacMethods['tan2cossin2'](self,*args)
 * 
 *      def tan2sincos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2925tan2sincos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tan2sincos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1487)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tan2sincos, __pyx_t_2) < 0) __PYX_ERR(2, 18270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18281
 *         return GiacMethods['tan2sincos'](self,*args)
 * 
 *      def tan2sincos2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tan2sincos2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2927tan2sincos2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tan2sincos2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1488)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tan2sincos2, __pyx_t_2) < 0) __PYX_ERR(2, 18281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18292
 *         return GiacMethods['tan2sincos2'](self,*args)
 * 
 *      def tangent(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangent:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2929tangent, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tangent, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1489)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tangent, __pyx_t_2) < 0) __PYX_ERR(2, 18292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18310
 *         return GiacMethods['tangent'](self,*args)
 * 
 *      def tangente(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tangente:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2931tangente, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tangente, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1490)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tangente, __pyx_t_2) < 0) __PYX_ERR(2, 18310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18328
 *         return GiacMethods['tangente'](self,*args)
 * 
 *      def tanh(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tanh:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2933tanh, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tanh, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1491)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tanh, __pyx_t_2) < 0) __PYX_ERR(2, 18328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18340
 *         return GiacMethods['tanh'](self,*args)
 * 
 *      def tar(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tar:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2935tar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tar, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1492)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tar, __pyx_t_2) < 0) __PYX_ERR(2, 18340, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18356
 *         return GiacMethods['tar'](self,*args)
 * 
 *      def taux_accroissement(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taux_accroissement:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2937taux_accroissement, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_taux_accroissem, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1493)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_taux_accroissement, __pyx_t_2) < 0) __PYX_ERR(2, 18356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18369
 *         return GiacMethods['taux_accroissement'](self,*args)
 * 
 *      def taylor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for taylor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2939taylor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_taylor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1494)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_taylor, __pyx_t_2) < 0) __PYX_ERR(2, 18369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18389
 *         return GiacMethods['taylor'](self,*args)
 * 
 *      def tchebyshev1(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev1:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2941tchebyshev1, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tchebyshev1, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1495)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tchebyshev1, __pyx_t_2) < 0) __PYX_ERR(2, 18389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18400
 *         return GiacMethods['tchebyshev1'](self,*args)
 * 
 *      def tchebyshev2(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tchebyshev2:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2943tchebyshev2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tchebyshev2, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1496)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tchebyshev2, __pyx_t_2) < 0) __PYX_ERR(2, 18400, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18411
 *         return GiacMethods['tchebyshev2'](self,*args)
 * 
 *      def tcoeff(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcoeff:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2945tcoeff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tcoeff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1497)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tcoeff, __pyx_t_2) < 0) __PYX_ERR(2, 18411, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18423
 *         return GiacMethods['tcoeff'](self,*args)
 * 
 *      def tcollect(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tcollect:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2947tcollect, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tcollect, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1498)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tcollect, __pyx_t_2) < 0) __PYX_ERR(2, 18423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18434
 *         return GiacMethods['tcollect'](self,*args)
 * 
 *      def tdeg(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tdeg:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2949tdeg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tdeg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1499)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tdeg, __pyx_t_2) < 0) __PYX_ERR(2, 18434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18444
 *         return GiacMethods['tdeg'](self,*args)
 * 
 *      def teal(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for teal:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2951teal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_teal, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1500)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_teal, __pyx_t_2) < 0) __PYX_ERR(2, 18444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18456
 *         return GiacMethods['teal'](self,*args)
 * 
 *      def tensor_product(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tensor_product:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2953tensor_product, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tensor_product, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1501)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tensor_product, __pyx_t_2) < 0) __PYX_ERR(2, 18456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18467
 *         return GiacMethods['tensor_product'](self,*args)
 * 
 *      def tetrahedron(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tetrahedron:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2955tetrahedron, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tetrahedron, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1502)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tetrahedron, __pyx_t_2) < 0) __PYX_ERR(2, 18467, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18479
 *         return GiacMethods['tetrahedron'](self,*args)
 * 
 *      def texpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for texpand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2957texpand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_texpand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1503)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_texpand, __pyx_t_2) < 0) __PYX_ERR(2, 18479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18492
 *         return GiacMethods['texpand'](self,*args)
 * 
 *      def thickness(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for thickness:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2959thickness, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_thickness, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1504)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_thickness, __pyx_t_2) < 0) __PYX_ERR(2, 18492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18504
 *         return GiacMethods['thickness'](self,*args)
 * 
 *      def threshold(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for threshold:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2961threshold, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_threshold, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1505)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_threshold, __pyx_t_2) < 0) __PYX_ERR(2, 18504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18516
 *         return GiacMethods['threshold'](self,*args)
 * 
 *      def throw(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for throw:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2963throw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_throw, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1506)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_throw, __pyx_t_2) < 0) __PYX_ERR(2, 18516, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18528
 *         return GiacMethods['throw'](self,*args)
 * 
 *      def title(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for title:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2965title, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_title, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1507)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_title, __pyx_t_2) < 0) __PYX_ERR(2, 18528, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18540
 *         return GiacMethods['title'](self,*args)
 * 
 *      def titre(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for titre:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2967titre, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_titre, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1508)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_titre, __pyx_t_2) < 0) __PYX_ERR(2, 18540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18552
 *         return GiacMethods['titre'](self,*args)
 * 
 *      def tlin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tlin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2969tlin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tlin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1509)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tlin, __pyx_t_2) < 0) __PYX_ERR(2, 18552, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18564
 *         return GiacMethods['tlin'](self,*args)
 * 
 *      def tonnetz(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tonnetz:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2971tonnetz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tonnetz, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1510)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tonnetz, __pyx_t_2) < 0) __PYX_ERR(2, 18564, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18576
 *         return GiacMethods['tonnetz'](self,*args)
 * 
 *      def topologic_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topologic_sort:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2973topologic_sort, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_topologic_sort, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1511)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_topologic_sort, __pyx_t_2) < 0) __PYX_ERR(2, 18576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18587
 *         return GiacMethods['topologic_sort'](self,*args)
 * 
 *      def topological_sort(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topological_sort:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2975topological_sort, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_topological_sor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1512)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_topological_sort, __pyx_t_2) < 0) __PYX_ERR(2, 18587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18598
 *         return GiacMethods['topological_sort'](self,*args)
 * 
 *      def topology(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for topology:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2977topology, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_topology, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1513)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_topology, __pyx_t_2) < 0) __PYX_ERR(2, 18598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18608
 *         return GiacMethods['topology'](self,*args)
 * 
 *      def torus_grid_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for torus_grid_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2979torus_grid_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_torus_grid_grap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1514)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_torus_grid_graph, __pyx_t_2) < 0) __PYX_ERR(2, 18608, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18619
 *         return GiacMethods['torus_grid_graph'](self,*args)
 * 
 *      def total_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for total_degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2981total_degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_total_degree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1515)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_total_degree, __pyx_t_2) < 0) __PYX_ERR(2, 18619, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18630
 *         return GiacMethods['total_degree'](self,*args)
 * 
 *      def tourne_droite(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_droite:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2983tourne_droite, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tourne_droite, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1516)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tourne_droite, __pyx_t_2) < 0) __PYX_ERR(2, 18630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18642
 *         return GiacMethods['tourne_droite'](self,*args)
 * 
 *      def tourne_gauche(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tourne_gauche:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2985tourne_gauche, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tourne_gauche, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1517)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tourne_gauche, __pyx_t_2) < 0) __PYX_ERR(2, 18642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18654
 *         return GiacMethods['tourne_gauche'](self,*args)
 * 
 *      def tpsolve(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tpsolve:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2987tpsolve, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tpsolve, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1518)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tpsolve, __pyx_t_2) < 0) __PYX_ERR(2, 18654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18666
 *         return GiacMethods['tpsolve'](self,*args)
 * 
 *      def trace(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trace:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2989trace, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trace, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1519)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trace, __pyx_t_2) < 0) __PYX_ERR(2, 18666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18680
 *         return GiacMethods['trace'](self,*args)
 * 
 *      def trail(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2991trail, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trail, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1520)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trail, __pyx_t_2) < 0) __PYX_ERR(2, 18680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18691
 *         return GiacMethods['trail'](self,*args)
 * 
 *      def trail2edges(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trail2edges:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2993trail2edges, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trail2edges, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1521)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trail2edges, __pyx_t_2) < 0) __PYX_ERR(2, 18691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18703
 *         return GiacMethods['trail2edges'](self,*args)
 * 
 *      def train(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for train:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2995train, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_train, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1522)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_train, __pyx_t_2) < 0) __PYX_ERR(2, 18703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18714
 *         return GiacMethods['train'](self,*args)
 * 
 *      def trames(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trames:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2997trames, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trames, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1523)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trames, __pyx_t_2) < 0) __PYX_ERR(2, 18714, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18726
 *         return GiacMethods['trames'](self,*args)
 * 
 *      def tran(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tran:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_2999tran, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tran, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1524)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tran, __pyx_t_2) < 0) __PYX_ERR(2, 18726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18739
 *         return GiacMethods['tran'](self,*args)
 * 
 *      def transitive_closure(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transitive_closure:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3001transitive_closure, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_transitive_clos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1525)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_transitive_closure, __pyx_t_2) < 0) __PYX_ERR(2, 18739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18750
 *         return GiacMethods['transitive_closure'](self,*args)
 * 
 *      def translation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for translation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3003translation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_translation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1526)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_translation, __pyx_t_2) < 0) __PYX_ERR(2, 18750, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18764
 *         return GiacMethods['translation'](self,*args)
 * 
 *      def transpose(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for transpose:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3005transpose, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_transpose, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1527)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_transpose, __pyx_t_2) < 0) __PYX_ERR(2, 18764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18777
 *         return GiacMethods['transpose'](self,*args)
 * 
 *      def trapeze(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapeze:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3007trapeze, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trapeze, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1528)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trapeze, __pyx_t_2) < 0) __PYX_ERR(2, 18777, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18793
 *         return GiacMethods['trapeze'](self,*args)
 * 
 *      def trapezoid(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trapezoid:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3009trapezoid, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trapezoid, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1529)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trapezoid, __pyx_t_2) < 0) __PYX_ERR(2, 18793, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18809
 *         return GiacMethods['trapezoid'](self,*args)
 * 
 *      def traveling_salesman(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for traveling_salesman:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3011traveling_salesman, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_traveling_sales, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1530)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_traveling_salesman, __pyx_t_2) < 0) __PYX_ERR(2, 18809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18824
 *         return GiacMethods['traveling_salesman'](self,*args)
 * 
 *      def tree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3013tree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1531)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tree, __pyx_t_2) < 0) __PYX_ERR(2, 18824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18834
 *         return GiacMethods['tree'](self,*args)
 * 
 *      def tree_height(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tree_height:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3015tree_height, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tree_height, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1532)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tree_height, __pyx_t_2) < 0) __PYX_ERR(2, 18834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18845
 *         return GiacMethods['tree_height'](self,*args)
 * 
 *      def tri(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tri:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3017tri, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tri, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1533)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tri, __pyx_t_2) < 0) __PYX_ERR(2, 18845, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18856
 *         return GiacMethods['tri'](self,*args)
 * 
 *      def triangle(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3019triangle, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_triangle, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1534)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_triangle, __pyx_t_2) < 0) __PYX_ERR(2, 18856, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18869
 *         return GiacMethods['triangle'](self,*args)
 * 
 *      def triangle_paper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_paper:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3021triangle_paper, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_triangle_paper, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1535)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_triangle_paper, __pyx_t_2) < 0) __PYX_ERR(2, 18869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18882
 *         return GiacMethods['triangle_paper'](self,*args)
 * 
 *      def triangle_plein(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_plein:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3023triangle_plein, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_triangle_plein, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1536)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_triangle_plein, __pyx_t_2) < 0) __PYX_ERR(2, 18882, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18896
 *         return GiacMethods['triangle_plein'](self,*args)
 * 
 *      def triangle_point(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_point:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3025triangle_point, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_triangle_point, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1537)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_triangle_point, __pyx_t_2) < 0) __PYX_ERR(2, 18896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18908
 *         return GiacMethods['triangle_point'](self,*args)
 * 
 *      def triangle_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triangle_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3027triangle_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_triangle_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1538)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_triangle_window, __pyx_t_2) < 0) __PYX_ERR(2, 18908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18919
 *         return GiacMethods['triangle_window'](self,*args)
 * 
 *      def trig2exp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trig2exp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3029trig2exp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trig2exp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1539)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trig2exp, __pyx_t_2) < 0) __PYX_ERR(2, 18919, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18930
 *         return GiacMethods['trig2exp'](self,*args)
 * 
 *      def trigcos(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigcos:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3031trigcos, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trigcos, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1540)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18930, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trigcos, __pyx_t_2) < 0) __PYX_ERR(2, 18930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18941
 *         return GiacMethods['trigcos'](self,*args)
 * 
 *      def trigexpand(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigexpand:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3033trigexpand, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trigexpand, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1541)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trigexpand, __pyx_t_2) < 0) __PYX_ERR(2, 18941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18952
 *         return GiacMethods['trigexpand'](self,*args)
 * 
 *      def triginterp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for triginterp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3035triginterp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_triginterp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1542)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_triginterp, __pyx_t_2) < 0) __PYX_ERR(2, 18952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18964
 *         return GiacMethods['triginterp'](self,*args)
 * 
 *      def trigsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsimplify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3037trigsimplify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trigsimplify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1543)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trigsimplify, __pyx_t_2) < 0) __PYX_ERR(2, 18964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18975
 *         return GiacMethods['trigsimplify'](self,*args)
 * 
 *      def trigsin(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigsin:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3039trigsin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trigsin, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1544)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trigsin, __pyx_t_2) < 0) __PYX_ERR(2, 18975, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18986
 *         return GiacMethods['trigsin'](self,*args)
 * 
 *      def trigtan(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trigtan:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3041trigtan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trigtan, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1545)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trigtan, __pyx_t_2) < 0) __PYX_ERR(2, 18986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":18997
 *         return GiacMethods['trigtan'](self,*args)
 * 
 *      def trim(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trim:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3043trim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1546)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 18997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trim, __pyx_t_2) < 0) __PYX_ERR(2, 18997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19010
 *         return GiacMethods['trim'](self,*args)
 * 
 *      def trn(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trn:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3045trn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trn, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1547)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trn, __pyx_t_2) < 0) __PYX_ERR(2, 19010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19021
 *         return GiacMethods['trn'](self,*args)
 * 
 *      def true(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for true:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3047true, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_true, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1548)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_true, __pyx_t_2) < 0) __PYX_ERR(2, 19021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19032
 *         return GiacMethods['true'](self,*args)
 * 
 *      def trunc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for trunc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3049trunc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_trunc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1549)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_trunc, __pyx_t_2) < 0) __PYX_ERR(2, 19032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19047
 *         return GiacMethods['trunc'](self,*args)
 * 
 *      def truncate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3051truncate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_truncate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1550)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_truncate, __pyx_t_2) < 0) __PYX_ERR(2, 19047, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19058
 *         return GiacMethods['truncate'](self,*args)
 * 
 *      def truncate_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for truncate_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3053truncate_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_truncate_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1551)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19058, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_truncate_graph, __pyx_t_2) < 0) __PYX_ERR(2, 19058, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19069
 *         return GiacMethods['truncate_graph'](self,*args)
 * 
 *      def tsimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tsimplify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3055tsimplify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tsimplify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1552)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tsimplify, __pyx_t_2) < 0) __PYX_ERR(2, 19069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19080
 *         return GiacMethods['tsimplify'](self,*args)
 * 
 *      def tstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tstep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3057tstep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tstep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1553)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tstep, __pyx_t_2) < 0) __PYX_ERR(2, 19080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19089
 *         return GiacMethods['tstep'](self,*args)
 * 
 *      def tuer(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tuer:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3059tuer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tuer, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1554)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tuer, __pyx_t_2) < 0) __PYX_ERR(2, 19089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19100
 *         return GiacMethods['tuer'](self,*args)
 * 
 *      def tukey_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tukey_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3061tukey_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tukey_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1555)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tukey_window, __pyx_t_2) < 0) __PYX_ERR(2, 19100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19111
 *         return GiacMethods['tukey_window'](self,*args)
 * 
 *      def tutte_polynomial(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for tutte_polynomial:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3063tutte_polynomial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_tutte_polynomia, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1556)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_tutte_polynomial, __pyx_t_2) < 0) __PYX_ERR(2, 19111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19123
 *         return GiacMethods['tutte_polynomial'](self,*args)
 * 
 *      def two_edge_connected_components(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for two_edge_connected_components:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3065two_edge_connected_components, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_two_edge_connec, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1557)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_two_edge_connected_components, __pyx_t_2) < 0) __PYX_ERR(2, 19123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19134
 *         return GiacMethods['two_edge_connected_components'](self,*args)
 * 
 *      def ufactor(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ufactor:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3067ufactor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ufactor, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1558)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ufactor, __pyx_t_2) < 0) __PYX_ERR(2, 19134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19145
 *         return GiacMethods['ufactor'](self,*args)
 * 
 *      def ugamma(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ugamma:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3069ugamma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ugamma, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1559)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ugamma, __pyx_t_2) < 0) __PYX_ERR(2, 19145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19157
 *         return GiacMethods['ugamma'](self,*args)
 * 
 *      def unapply(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unapply:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3071unapply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_unapply, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1560)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_unapply, __pyx_t_2) < 0) __PYX_ERR(2, 19157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19169
 *         return GiacMethods['unapply'](self,*args)
 * 
 *      def unarchive(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unarchive:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3073unarchive, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_unarchive, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1561)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_unarchive, __pyx_t_2) < 0) __PYX_ERR(2, 19169, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19181
 *         return GiacMethods['unarchive'](self,*args)
 * 
 *      def undef(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for undef:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3075undef, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_undef, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1562)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_undef, __pyx_t_2) < 0) __PYX_ERR(2, 19181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19192
 *         return GiacMethods['undef'](self,*args)
 * 
 *      def underlying_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for underlying_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3077underlying_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_underlying_grap, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1563)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_underlying_graph, __pyx_t_2) < 0) __PYX_ERR(2, 19192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19203
 *         return GiacMethods['underlying_graph'](self,*args)
 * 
 *      def unfactored(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unfactored:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3079unfactored, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_unfactored, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1564)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_unfactored, __pyx_t_2) < 0) __PYX_ERR(2, 19203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19218
 *         return GiacMethods['unfactored'](self,*args)
 * 
 *      def uniform(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3081uniform, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_uniform, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1565)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_uniform, __pyx_t_2) < 0) __PYX_ERR(2, 19218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19232
 *         return GiacMethods['uniform'](self,*args)
 * 
 *      def uniform_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3083uniform_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_uniform_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1566)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_uniform_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 19232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19244
 *         return GiacMethods['uniform_cdf'](self,*args)
 * 
 *      def uniform_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniform_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3085uniform_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_uniform_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1567)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_uniform_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 19244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19256
 *         return GiacMethods['uniform_icdf'](self,*args)
 * 
 *      def uniformd(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3087uniformd, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_uniformd, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1568)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_uniformd, __pyx_t_2) < 0) __PYX_ERR(2, 19256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19270
 *         return GiacMethods['uniformd'](self,*args)
 * 
 *      def uniformd_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3089uniformd_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_uniformd_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1569)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_uniformd_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 19270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19282
 *         return GiacMethods['uniformd_cdf'](self,*args)
 * 
 *      def uniformd_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for uniformd_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3091uniformd_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_uniformd_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1570)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_uniformd_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 19282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19294
 *         return GiacMethods['uniformd_icdf'](self,*args)
 * 
 *      def unitV(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unitV:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3093unitV, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_unitV, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1571)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_unitV, __pyx_t_2) < 0) __PYX_ERR(2, 19294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19308
 *         return GiacMethods['unitV'](self,*args)
 * 
 *      def unquote(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for unquote:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3095unquote, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_unquote, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1572)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_unquote, __pyx_t_2) < 0) __PYX_ERR(2, 19308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19319
 *         return GiacMethods['unquote'](self,*args)
 * 
 *      def upper(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for upper:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3097upper, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_upper, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1573)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_upper, __pyx_t_2) < 0) __PYX_ERR(2, 19319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19331
 *         return GiacMethods['upper'](self,*args)
 * 
 *      def user_operator(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for user_operator:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3099user_operator, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_user_operator, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1574)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_user_operator, __pyx_t_2) < 0) __PYX_ERR(2, 19331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19343
 *         return GiacMethods['user_operator'](self,*args)
 * 
 *      def usimplify(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for usimplify:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3101usimplify, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_usimplify, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1575)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_usimplify, __pyx_t_2) < 0) __PYX_ERR(2, 19343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19354
 *         return GiacMethods['usimplify'](self,*args)
 * 
 *      def ustep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ustep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3103ustep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ustep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1576)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ustep, __pyx_t_2) < 0) __PYX_ERR(2, 19354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19363
 *         return GiacMethods['ustep'](self,*args)
 * 
 *      def valuation(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for valuation:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3105valuation, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_valuation, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1577)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_valuation, __pyx_t_2) < 0) __PYX_ERR(2, 19363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19378
 *         return GiacMethods['valuation'](self,*args)
 * 
 *      def vandermonde(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vandermonde:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3107vandermonde, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vandermonde, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1578)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vandermonde, __pyx_t_2) < 0) __PYX_ERR(2, 19378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19389
 *         return GiacMethods['vandermonde'](self,*args)
 * 
 *      def variables_are_files(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variables_are_files:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3109variables_are_files, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_variables_are_f, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1579)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_variables_are_files, __pyx_t_2) < 0) __PYX_ERR(2, 19389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19401
 *         return GiacMethods['variables_are_files'](self,*args)
 * 
 *      def variance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for variance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3111variance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_variance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1580)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_variance, __pyx_t_2) < 0) __PYX_ERR(2, 19401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19414
 *         return GiacMethods['variance'](self,*args)
 * 
 *      def version(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for version:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3113version, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_version, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1581)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_version, __pyx_t_2) < 0) __PYX_ERR(2, 19414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19425
 *         return GiacMethods['version'](self,*args)
 * 
 *      def vertex_connectivity(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_connectivity:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3115vertex_connectivity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertex_connecti, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1582)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertex_connectivity, __pyx_t_2) < 0) __PYX_ERR(2, 19425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19438
 *         return GiacMethods['vertex_connectivity'](self,*args)
 * 
 *      def vertex_cover_number(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_cover_number:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3117vertex_cover_number, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertex_cover_nu, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1583)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertex_cover_number, __pyx_t_2) < 0) __PYX_ERR(2, 19438, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19449
 *         return GiacMethods['vertex_cover_number'](self,*args)
 * 
 *      def vertex_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3119vertex_degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertex_degree, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1584)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertex_degree, __pyx_t_2) < 0) __PYX_ERR(2, 19449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19460
 *         return GiacMethods['vertex_degree'](self,*args)
 * 
 *      def vertex_distance(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_distance:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3121vertex_distance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertex_distance, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1585)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertex_distance, __pyx_t_2) < 0) __PYX_ERR(2, 19460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19472
 *         return GiacMethods['vertex_distance'](self,*args)
 * 
 *      def vertex_in_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_in_degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3123vertex_in_degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertex_in_degre, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1586)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertex_in_degree, __pyx_t_2) < 0) __PYX_ERR(2, 19472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19483
 *         return GiacMethods['vertex_in_degree'](self,*args)
 * 
 *      def vertex_out_degree(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertex_out_degree:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3125vertex_out_degree, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertex_out_degr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1587)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertex_out_degree, __pyx_t_2) < 0) __PYX_ERR(2, 19483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19494
 *         return GiacMethods['vertex_out_degree'](self,*args)
 * 
 *      def vertices(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3127vertices, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertices, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1588)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertices, __pyx_t_2) < 0) __PYX_ERR(2, 19494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19507
 *         return GiacMethods['vertices'](self,*args)
 * 
 *      def vertices_abc(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abc:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3129vertices_abc, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertices_abc, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1589)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertices_abc, __pyx_t_2) < 0) __PYX_ERR(2, 19507, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19520
 *         return GiacMethods['vertices_abc'](self,*args)
 * 
 *      def vertices_abca(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vertices_abca:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3131vertices_abca, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vertices_abca, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1590)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vertices_abca, __pyx_t_2) < 0) __PYX_ERR(2, 19520, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19533
 *         return GiacMethods['vertices_abca'](self,*args)
 * 
 *      def violet(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for violet:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3133violet, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_violet, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1591)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_violet, __pyx_t_2) < 0) __PYX_ERR(2, 19533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19545
 *         return GiacMethods['violet'](self,*args)
 * 
 *      def vpotential(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vpotential:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3135vpotential, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vpotential, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1592)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vpotential, __pyx_t_2) < 0) __PYX_ERR(2, 19545, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19556
 *         return GiacMethods['vpotential'](self,*args)
 * 
 *      def vstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for vstep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3137vstep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_vstep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1593)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_vstep, __pyx_t_2) < 0) __PYX_ERR(2, 19556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19565
 *         return GiacMethods['vstep'](self,*args)
 * 
 *      def web_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for web_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3139web_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_web_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1594)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_web_graph, __pyx_t_2) < 0) __PYX_ERR(2, 19565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19576
 *         return GiacMethods['web_graph'](self,*args)
 * 
 *      def weibull(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3141weibull, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibull, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1595)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibull, __pyx_t_2) < 0) __PYX_ERR(2, 19576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19589
 *         return GiacMethods['weibull'](self,*args)
 * 
 *      def weibull_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3143weibull_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibull_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1596)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibull_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 19589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19604
 *         return GiacMethods['weibull_cdf'](self,*args)
 * 
 *      def weibull_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibull_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3145weibull_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibull_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1597)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibull_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 19604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19616
 *         return GiacMethods['weibull_icdf'](self,*args)
 * 
 *      def weibulld(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3147weibulld, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibulld, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1598)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibulld, __pyx_t_2) < 0) __PYX_ERR(2, 19616, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19629
 *         return GiacMethods['weibulld'](self,*args)
 * 
 *      def weibulld_cdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_cdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3149weibulld_cdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibulld_cdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1599)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibulld_cdf, __pyx_t_2) < 0) __PYX_ERR(2, 19629, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19644
 *         return GiacMethods['weibulld_cdf'](self,*args)
 * 
 *      def weibulld_icdf(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibulld_icdf:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3151weibulld_icdf, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibulld_icdf, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1600)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibulld_icdf, __pyx_t_2) < 0) __PYX_ERR(2, 19644, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19656
 *         return GiacMethods['weibulld_icdf'](self,*args)
 * 
 *      def weibullvariate(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weibullvariate:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3153weibullvariate, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weibullvariate, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1601)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weibullvariate, __pyx_t_2) < 0) __PYX_ERR(2, 19656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19668
 *         return GiacMethods['weibullvariate'](self,*args)
 * 
 *      def weight_decay(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_decay:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3155weight_decay, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weight_decay, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1602)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weight_decay, __pyx_t_2) < 0) __PYX_ERR(2, 19668, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19678
 *         return GiacMethods['weight_decay'](self,*args)
 * 
 *      def weight_matrix(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weight_matrix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3157weight_matrix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weight_matrix, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1603)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weight_matrix, __pyx_t_2) < 0) __PYX_ERR(2, 19678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19689
 *         return GiacMethods['weight_matrix'](self,*args)
 * 
 *      def weighted(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weighted:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3159weighted, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weighted, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1604)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weighted, __pyx_t_2) < 0) __PYX_ERR(2, 19689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19699
 *         return GiacMethods['weighted'](self,*args)
 * 
 *      def weights(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for weights:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3161weights, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_weights, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1605)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_weights, __pyx_t_2) < 0) __PYX_ERR(2, 19699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19709
 *         return GiacMethods['weights'](self,*args)
 * 
 *      def welch_window(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for welch_window:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3163welch_window, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_welch_window, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1606)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_welch_window, __pyx_t_2) < 0) __PYX_ERR(2, 19709, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19720
 *         return GiacMethods['welch_window'](self,*args)
 * 
 *      def wheel_graph(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wheel_graph:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3165wheel_graph, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_wheel_graph, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1607)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_wheel_graph, __pyx_t_2) < 0) __PYX_ERR(2, 19720, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19731
 *         return GiacMethods['wheel_graph'](self,*args)
 * 
 *      def widget_size(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for widget_size:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3167widget_size, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_widget_size, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1608)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_widget_size, __pyx_t_2) < 0) __PYX_ERR(2, 19731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19744
 *         return GiacMethods['widget_size'](self,*args)
 * 
 *      def wilcoxonp(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxonp:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3169wilcoxonp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_wilcoxonp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1609)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_wilcoxonp, __pyx_t_2) < 0) __PYX_ERR(2, 19744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19756
 *         return GiacMethods['wilcoxonp'](self,*args)
 * 
 *      def wilcoxons(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxons:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3171wilcoxons, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_wilcoxons, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1610)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_wilcoxons, __pyx_t_2) < 0) __PYX_ERR(2, 19756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19768
 *         return GiacMethods['wilcoxons'](self,*args)
 * 
 *      def wilcoxont(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for wilcoxont:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3173wilcoxont, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_wilcoxont, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1611)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_wilcoxont, __pyx_t_2) < 0) __PYX_ERR(2, 19768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19782
 *         return GiacMethods['wilcoxont'](self,*args)
 * 
 *      def writergb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writergb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3175writergb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_writergb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1612)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_writergb, __pyx_t_2) < 0) __PYX_ERR(2, 19782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19795
 *         return GiacMethods['writergb'](self,*args)
 * 
 *      def writewav(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for writewav:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3177writewav, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_writewav, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1613)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_writewav, __pyx_t_2) < 0) __PYX_ERR(2, 19795, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19807
 *         return GiacMethods['writewav'](self,*args)
 * 
 *      def xcas_mode(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xcas_mode:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3179xcas_mode, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_xcas_mode, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1614)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_xcas_mode, __pyx_t_2) < 0) __PYX_ERR(2, 19807, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19819
 *         return GiacMethods['xcas_mode'](self,*args)
 * 
 *      def xml_print(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xml_print:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3181xml_print, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_xml_print, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1615)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_xml_print, __pyx_t_2) < 0) __PYX_ERR(2, 19819, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19830
 *         return GiacMethods['xml_print'](self,*args)
 * 
 *      def xstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xstep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3183xstep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_xstep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1616)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_xstep, __pyx_t_2) < 0) __PYX_ERR(2, 19830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19839
 *         return GiacMethods['xstep'](self,*args)
 * 
 *      def xyz2rgb(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyz2rgb:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3185xyz2rgb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_xyz2rgb, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1617)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_xyz2rgb, __pyx_t_2) < 0) __PYX_ERR(2, 19839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19850
 *         return GiacMethods['xyz2rgb'](self,*args)
 * 
 *      def xyztrange(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for xyztrange:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3187xyztrange, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_xyztrange, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1618)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_xyztrange, __pyx_t_2) < 0) __PYX_ERR(2, 19850, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19860
 *         return GiacMethods['xyztrange'](self,*args)
 * 
 *      def ystep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ystep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3189ystep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ystep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1619)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ystep, __pyx_t_2) < 0) __PYX_ERR(2, 19860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19869
 *         return GiacMethods['ystep'](self,*args)
 * 
 *      def zeros(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zeros:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3191zeros, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_zeros, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1620)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_zeros, __pyx_t_2) < 0) __PYX_ERR(2, 19869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19883
 *         return GiacMethods['zeros'](self,*args)
 * 
 *      def znorder(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znorder:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3193znorder, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_znorder, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1621)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_znorder, __pyx_t_2) < 0) __PYX_ERR(2, 19883, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19896
 *         return GiacMethods['znorder'](self,*args)
 * 
 *      def znprimroot(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for znprimroot:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3195znprimroot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_znprimroot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1622)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_znprimroot, __pyx_t_2) < 0) __PYX_ERR(2, 19896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19907
 *         return GiacMethods['znprimroot'](self,*args)
 * 
 *      def zstep(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zstep:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3197zstep, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_zstep, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1623)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_zstep, __pyx_t_2) < 0) __PYX_ERR(2, 19907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19916
 *         return GiacMethods['zstep'](self,*args)
 * 
 *      def ztrans(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for ztrans:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3199ztrans, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_ztrans, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1624)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_ztrans, __pyx_t_2) < 0) __PYX_ERR(2, 19916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19928
 *         return GiacMethods['ztrans'](self,*args)
 * 
 *      def type(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for type:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3201type, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_type, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1625)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_type, __pyx_t_2) < 0) __PYX_ERR(2, 19928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/auto-methods.pxi":19940
 *         return GiacMethods['type'](self,*args)
 * 
 *      def zip(self,*args):             # <<<<<<<<<<<<<<
 *         r'''From Giac's documentation:
 *         Help for zip:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3203zip, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base_zip, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1626)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 19940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_zip, __pyx_t_2) < 0) __PYX_ERR(2, 19940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3205__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base___reduce_cython, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1628)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_GiacMethods_base, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_GiacMethods_base__set_state(self, __pyx_state)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_16GiacMethods_base_3207__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_GiacMethods_base___setstate_cyth, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1629)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_GiacMethods_base, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_GiacMethods_base);

  /* "giacpy/giacpy.pyx":1101
 *            raise TypeError,"self is not a giac real"
 * 
 *      def eval(self):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         ressetctrl_c()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_22eval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_eval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1631)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_eval, __pyx_t_2) < 0) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1110
 *            raise RuntimeError
 * 
 *      def threadeval(self,*args):             # <<<<<<<<<<<<<<
 *         cdef gen result
 *         cdef gen * param
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_24threadeval, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_threadeval, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1633)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_threadeval, __pyx_t_2) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1446
 * 
 *      # To be able to use the eval function before the GiacMethods initialisation
 *      def cas_setup(self,*args):             # <<<<<<<<<<<<<<
 *         return Pygen('cas_setup')(self,*args)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_58cas_setup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_cas_setup, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1634)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_cas_setup, __pyx_t_2) < 0) __PYX_ERR(0, 1446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1450
 * 
 *      # ipython pretty printing
 *      def _repr_latex_(self):             # <<<<<<<<<<<<<<
 *         # remove quotes
 *         #return str(self.latex())[1:-1]
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_60_repr_latex_, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen__repr_latex, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1635)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_repr_latex, __pyx_t_2) < 0) __PYX_ERR(0, 1450, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1456
 *         return decstring23(GIAC_gen2tex(self.gptr[0], context_ptr).c_str()) #python3
 * 
 *      def _repr_html_(self):             # <<<<<<<<<<<<<<
 *         if self._type == 8:
 *            if self.sommet() == 'pnt':
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_62_repr_html_, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen__repr_html, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1636)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_repr_html, __pyx_t_2) < 0) __PYX_ERR(0, 1456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1469
 * 
 *      #
 *      def save(self, str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Archive a Pygen element to a file in giac compressed format.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_64save, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_save, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1638)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_save, __pyx_t_2) < 0) __PYX_ERR(0, 1469, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1498
 * 
 * 
 *      def htmlhelp(self, str lang='en'):             # <<<<<<<<<<<<<<
 *          """
 *          Open the giac  html  detailled help about self in an external  browser
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_66htmlhelp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_htmlhelp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1640)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__1641);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_htmlhelp, __pyx_t_2) < 0) __PYX_ERR(0, 1498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1523
 * 
 * 
 *      def help(self):             # <<<<<<<<<<<<<<
 *         return self.findhelp()
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_68help, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_help, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1642)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_help, __pyx_t_2) < 0) __PYX_ERR(0, 1523, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1526
 *         return self.findhelp()
 * 
 *      def redim(self,a,b=None):             # <<<<<<<<<<<<<<
 *         """
 *         * Increase the size of a matrix when possible, otherwise return self.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_70redim, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_redim, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1644)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__1645);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_redim, __pyx_t_2) < 0) __PYX_ERR(0, 1526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "giacpy/giacpy.pyx":1552
 * 
 * 
 *      def qcas(self,s=None):             # <<<<<<<<<<<<<<
 *        """
 *        * Send a giac graphic to qcas. (3D is currently not supported in qcas)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_72qcas, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen_qcas, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1647)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__1645);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen, __pyx_n_s_qcas, __pyx_t_2) < 0) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6giacpy_6giacpy_Pygen);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_76__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen___reduce_cython, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1648)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_5Pygen_78__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Pygen___setstate_cython, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1649)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1846
 * #############################################
 * 
 * I=Pygen('i')  # The complex number sqrt(-1)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__1650, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_I, __pyx_t_2) < 0) __PYX_ERR(0, 1846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1849
 * 
 * 
 * def htmlhelp(s='en'):             # <<<<<<<<<<<<<<
 *    """
 *    Open the giac html detailled help in an external  browser
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_7htmlhelp, 0, __pyx_n_s_htmlhelp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1652)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__1641);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_htmlhelp, __pyx_t_2) < 0) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1879
 * #  Qcas string interactive 2D geometry; string input
 * #############################################################
 * def qcas(str s):             # <<<<<<<<<<<<<<
 *    """
 *    * EXPERIMENTAL: Send a giac command to an  interactive 2D geometry display in qcas.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_9qcas, 0, __pyx_n_s_qcas, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1654)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_qcas, __pyx_t_2) < 0) __PYX_ERR(0, 1879, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/keywords.pxi":2
 * # file auto generated by mkkeywords.py
 * blacklist = ['eval', 'cas_setup', 'i', 'list', 'input', 'in', 'sto', 'string', 'and', 'break', 'continue', 'else', 'for', 'from', 'if', 'not', 'or', 'pow', 'print', 'return', 'set[]', 'try', 'while', 'open', 'output', 'do', 'of', 'Request', 'i[]', '[]', 'ffunction', 'sleep', '[..]']             # <<<<<<<<<<<<<<
 * 
 * toremove = ['!', '!=', '#', '$', '%', '/%', '%/', '%{%}', '&&', '&*', '&^', "'", '()', '*', '*=', '+', '-', '+&', '+=', '+infinity', '-<', '-=', '->', '-infinity', '.*', '.+', '.-', './', '.^', '/=', ':=', '<', '<=', '=', '=<', '==', '=>', '>', '>=', '?', '@', '@@', 'ACOSH', 'ACOT', 'ACSC', 'ASEC', 'ASIN', 'ASINH', 'ATAN', 'ATANH', 'COND', 'COS', 'COSH', 'COT', 'CSC', 'CST', 'Celsius2Fahrenheit', 'ClrDraw', 'ClrGraph', 'ClrIO', 'CyclePic', 'DIGITS', 'DOM_COMPLEX', 'DOM_FLOAT', 'DOM_FUNC', 'DOM_IDENT', 'DOM_INT', 'DOM_LIST', 'DOM_RAT', 'DOM_STRING', 'DOM_SYMBOLIC', 'DOM_int', 'DelFold', 'DelVar', 'Det', 'Dialog', 'Digits', 'Disp', 'DispG', 'DispHome', 'DrawFunc', 'DrawInv', 'DrawParm', 'DrawPol', 'DrawSlp', 'DropDown', 'DrwCtour', 'ERROR', 'EXP', 'EndDlog', 'FALSE', 'False', 'Fahrenheit2Celsius', 'Fill', 'Gcd', 'GetFold', 'Graph', 'IFTE', 'Input', 'InputStr', 'Int', 'Inverse', 'LN', 'LQ', 'LSQ', 'NORMALD', 'NewFold', 'NewPic', 'Nullspace', 'Output', 'Ox_2d_unit_vector', 'Ox_3d_unit_vector', 'Oy_2d_unit_vector', 'Oy_3d_unit_vector', 'Oz_3d_unit_vector', 'Pause', 'PopUp', 'Quo', 'REDIM', 'REPLACE', 'RclPic', 'Rem', 'Resultant', 'RplcPic', 'Rref', 'SCALE', 'SCALEADD', 'SCHUR', 'SIN', 'SVD', 'SVL', 'SWAPCOL', 'SWAPROW', 'SetFold', 'Si', 'StoPic', 'Store', 'TAN', 'TRUE', 'True', 'TeX', 'Text', 'Title', 'Unarchiv', 'WAIT', '^', '_(cm/s)', '_(ft/s)', '_(ft*lb)', '_(m/s)', '_(m/s^2)', '_(rad/s)', '_(rad/s^2)', '_(tr/min)', '_(tr/s)', '_A', '_Angstrom', '_Bq', '_Btu', '_Ci', '_F', '_F_', '_Fdy', '_G_', '_Gal', '_Gy', '_H', '_Hz', '_I0_', '_J', '_K', '_Kcal', '_MHz', '_MW', '_MeV', '_N', '_NA_', '_Ohm', '_P', '_PSun_', '_Pa', '_R', '_REarth_', '_RSun_', '_R_', '_Rankine', '_Rinfinity_', '_S', '_St', '_StdP_', '_StdT_', '_Sv', '_T', '_V', '_Vm_', '_W', '_Wb', '_Wh', '_a', '_a0_', '_acre', '_alpha_', '_angl_', '_arcmin', '_arcs', '_atm', '_au', '_b', '_bar', '_bbl', '_bblep', '_bu', '_buUS', '_c3_', '_c_', '_cal', '_cd', '_chain', '_cm', '_cm^2', '_cm^3', '_ct', '_cu', '_d', '_dB', '_deg', '_degreeF', '_dyn', '_eV', '_epsilon0_', '_epsilon0q_', '_epsilonox_', '_epsilonsi_', '_erg', '_f0_', '_fath', '_fbm', '_fc', '_fermi', '_flam', '_fm', '_ft', '_ft*lb', '_ftUS', '_ft^2', '_ft^3', '_g', '_g_', '_ga', '_galC', '_galUK', '_galUS', '_gf', '_gmol', '_gon', '_grad', '_grain', '_h', '_h_', '_ha', '_hbar_', '_hp', '_in', '_inH20', '_inHg', '_in^2', '_in^3', '_j', '_kWh', '_k_', '_kg', '_kip', '_km', '_km^2', '_knot', '_kph', '_kq_', '_l', '_lam', '_lambda0_', '_lambdac_', '_lb', '_lbf', '_lbmol', '_lbt', '_lep', '_liqpt', '_lm', '_lx', '_lyr', '_m', '_mEarth_', '_m^2', '_m^3', '_me_', '_mho', '_miUS', '_miUS^2', '_mi^2', '_mil', '_mile', '_mille', '_ml', '_mm', '_mmHg', '_mn', '_mol', '_mp_', '_mph', '_mpme_', '_mu0_', '_muB_', '_muN_', '_oz', '_ozUK', '_ozfl', '_ozt', '_pc', '_pdl', '_ph', '_phi_', '_pk', '_psi', '_ptUK', '_q_', '_qe_', '_qepsilon0_', '_qme_', '_qt', '_rad', '_rad_', '_rd', '_rem', '_rod', '_rpm', '_s', '_sb', '_sd_', '_sigma_', '_slug', '_sr', '_st', '_syr_', '_t', '_tbsp', '_tec', '_tep', '_tex', '_therm', '_ton', '_tonUK', '_torr', '_tr', '_tsp', '_twopi_', '_u', '_yd', '_yd^2', '_yd^3', '_yr', '_', '_', 'assert', 'affichage', 'alors', 'animate', 'animate3d', 'animation', 'approx_mode', 'archive', 'args', 'as_function_of', 'asc', 'asec', 'assign', 'backquote', 'begin', 'black', 'blanc', 'bleu', 'bloc', 'blue', 'breakpoint', 'by', 'c1oc2', 'c1op2', 'cache_tortue', 'cap', 'cap_flat_line', 'cap_round_line', 'cap_square_line', 'case', 'cat', 'catch', 'cd', 'choosebox', 'click', 'close', 'complex_mode', 'de', 'del', 'debug', 'default', 'div', 'double', 'ecris', 'efface', 'elif', 'end', 'end_for', 'end_if', 'end_while', 'epaisseur', 'epaisseur_ligne_1', 'epaisseur_ligne_2', 'epaisseur_ligne_3', 'epaisseur_ligne_4', 'epaisseur_ligne_5', 'epaisseur_ligne_6', 'epaisseur_ligne_7', 'epaisseur_point_1', 'epaisseur_point_2', 'epaisseur_point_3', 'epaisseur_point_4', 'epaisseur_point_5', 'epaisseur_point_6', 'epaisseur_point_7', 'erase', 'erase3d', 'est_cocyclique', 'est_inclus', 'et', 'faire', 'faux', 'feuille', 'ffaire', 'ffonction', 'fi', 'filled', 'fin_enregistrement', 'float', 'fonction', 'fopen', 'format', 'fpour', 'frame_3d', 'frames', 'fsi', 'ftantque', 'func', 'function', 'gauche', 'gl_ortho', 'gl_quaternion', 'gl_rotation', 'gl_shownames', 'gl_texture', 'gl_x', 'gl_x_axis_color', 'gl_x_axis_name', 'gl_x_axis_unit', 'gl_xtick', 'gl_y', 'gl_y_axis_color', 'gl_y_axis_name', 'gl_y_axis_unit', 'gl_ytick', 'gl_z', 'gl_z_axis_color', 'gl_z_axis_name', 'gl_z_axis_unit', 'gl_ztick', 'gnuplot', 'goto', 'graph2tex', 'graph3d2tex', 'graphe', 'graphe3d', 'graphe_probabiliste', 'graphe_suite', 'green', 'grid_paper', 'hidden_name', 'identifier', 'ifft', 'ifte', 'inputform', 'intersect', 'is_included', 'jusqu_a', 'jusqua', 'jusque', 'keep_algext', 'kill', 'label', 'labels', 'len', 'leve_crayon', 'line_width_1', 'line_width_2', 'line_width_3', 'line_width_4', 'line_width_5', 'line_width_6', 'line_width_7', 'lis', 'local', 'minus', 'mod', 'noir', 'nom_cache', 'non', 'od', 'option', 'otherwise', 'ou', 'pas', 'point_arret', 'point_carre', 'point_croix', 'point_div', 'point_etoile', 'point_invisible', 'point_losange', 'point_milieu', 'point_plus', 'point_point', 'point_polaire', 'point_triangle', 'point_width_1', 'point_width_2', 'point_width_3', 'point_width_4', 'point_width_5', 'point_width_6', 'point_width_7', 'pour', 'proc', 'program', 'quadrant1', 'quadrant2', 'quadrant3', 'quadrant4', 'range', 'redim', 'repeat', 'repete', 'repeter', 'replace', 'restart', 'rouge', 'saisir', 'saisir_chaine', 'sauve', 'save_history', 'scale', 'scaleadd', 'si', 'sinon', 'size', 'stack', 'step', 'switch', 'tantque', 'test', 'textinput', 'then', 'thiele', 'time', 'to', 'union', 'until', 'var', 'vector', 'vers', 'vert', 'vrai', 'watch', 'when', 'white', 'with_sqrt', 'write', 'wz_certificate', 'xor', 'yellow', '{}', '|', '||', 'expression']
 */
  __pyx_t_2 = PyList_New(33); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_eval);
  __Pyx_GIVEREF(__pyx_n_s_eval);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_eval)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cas_setup);
  __Pyx_GIVEREF(__pyx_n_s_cas_setup);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_cas_setup)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_i);
  __Pyx_GIVEREF(__pyx_n_s_i);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_i)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_list);
  __Pyx_GIVEREF(__pyx_n_s_list);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_list)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_input);
  __Pyx_GIVEREF(__pyx_n_s_input);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_input)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_in);
  __Pyx_GIVEREF(__pyx_n_s_in);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_in)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sto);
  __Pyx_GIVEREF(__pyx_n_s_sto);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_s_sto)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_string);
  __Pyx_GIVEREF(__pyx_n_s_string);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_s_string)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_and);
  __Pyx_GIVEREF(__pyx_n_s_and);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 8, __pyx_n_s_and)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_break);
  __Pyx_GIVEREF(__pyx_n_s_break);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 9, __pyx_n_s_break)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_continue);
  __Pyx_GIVEREF(__pyx_n_s_continue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 10, __pyx_n_s_continue)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_else);
  __Pyx_GIVEREF(__pyx_n_s_else);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 11, __pyx_n_s_else)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_for);
  __Pyx_GIVEREF(__pyx_n_s_for);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 12, __pyx_n_s_for)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_from);
  __Pyx_GIVEREF(__pyx_n_s_from);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 13, __pyx_n_s_from)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_if);
  __Pyx_GIVEREF(__pyx_n_s_if);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 14, __pyx_n_s_if)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_not);
  __Pyx_GIVEREF(__pyx_n_s_not);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 15, __pyx_n_s_not)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_or);
  __Pyx_GIVEREF(__pyx_n_s_or);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 16, __pyx_n_s_or)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pow);
  __Pyx_GIVEREF(__pyx_n_s_pow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 17, __pyx_n_s_pow)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_print);
  __Pyx_GIVEREF(__pyx_n_s_print);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 18, __pyx_n_s_print)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_return);
  __Pyx_GIVEREF(__pyx_n_s_return);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 19, __pyx_n_s_return)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_set);
  __Pyx_GIVEREF(__pyx_kp_s_set);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 20, __pyx_kp_s_set)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_try);
  __Pyx_GIVEREF(__pyx_n_s_try);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 21, __pyx_n_s_try)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_while);
  __Pyx_GIVEREF(__pyx_n_s_while);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 22, __pyx_n_s_while)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_open);
  __Pyx_GIVEREF(__pyx_n_s_open);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 23, __pyx_n_s_open)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_output);
  __Pyx_GIVEREF(__pyx_n_s_output);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 24, __pyx_n_s_output)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_do);
  __Pyx_GIVEREF(__pyx_n_s_do);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 25, __pyx_n_s_do)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_of);
  __Pyx_GIVEREF(__pyx_n_s_of);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 26, __pyx_n_s_of)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Request);
  __Pyx_GIVEREF(__pyx_n_s_Request);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 27, __pyx_n_s_Request)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_i_2);
  __Pyx_GIVEREF(__pyx_kp_s_i_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 28, __pyx_kp_s_i_2)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1655);
  __Pyx_GIVEREF(__pyx_kp_s__1655);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 29, __pyx_kp_s__1655)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ffunction);
  __Pyx_GIVEREF(__pyx_n_s_ffunction);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 30, __pyx_n_s_ffunction)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sleep);
  __Pyx_GIVEREF(__pyx_n_s_sleep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 31, __pyx_n_s_sleep)) __PYX_ERR(5, 2, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1656);
  __Pyx_GIVEREF(__pyx_kp_s__1656);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 32, __pyx_kp_s__1656)) __PYX_ERR(5, 2, __pyx_L1_error);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_blacklist, __pyx_t_2) < 0) __PYX_ERR(5, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/keywords.pxi":4
 * blacklist = ['eval', 'cas_setup', 'i', 'list', 'input', 'in', 'sto', 'string', 'and', 'break', 'continue', 'else', 'for', 'from', 'if', 'not', 'or', 'pow', 'print', 'return', 'set[]', 'try', 'while', 'open', 'output', 'do', 'of', 'Request', 'i[]', '[]', 'ffunction', 'sleep', '[..]']
 * 
 * toremove = ['!', '!=', '#', '$', '%', '/%', '%/', '%{%}', '&&', '&*', '&^', "'", '()', '*', '*=', '+', '-', '+&', '+=', '+infinity', '-<', '-=', '->', '-infinity', '.*', '.+', '.-', './', '.^', '/=', ':=', '<', '<=', '=', '=<', '==', '=>', '>', '>=', '?', '@', '@@', 'ACOSH', 'ACOT', 'ACSC', 'ASEC', 'ASIN', 'ASINH', 'ATAN', 'ATANH', 'COND', 'COS', 'COSH', 'COT', 'CSC', 'CST', 'Celsius2Fahrenheit', 'ClrDraw', 'ClrGraph', 'ClrIO', 'CyclePic', 'DIGITS', 'DOM_COMPLEX', 'DOM_FLOAT', 'DOM_FUNC', 'DOM_IDENT', 'DOM_INT', 'DOM_LIST', 'DOM_RAT', 'DOM_STRING', 'DOM_SYMBOLIC', 'DOM_int', 'DelFold', 'DelVar', 'Det', 'Dialog', 'Digits', 'Disp', 'DispG', 'DispHome', 'DrawFunc', 'DrawInv', 'DrawParm', 'DrawPol', 'DrawSlp', 'DropDown', 'DrwCtour', 'ERROR', 'EXP', 'EndDlog', 'FALSE', 'False', 'Fahrenheit2Celsius', 'Fill', 'Gcd', 'GetFold', 'Graph', 'IFTE', 'Input', 'InputStr', 'Int', 'Inverse', 'LN', 'LQ', 'LSQ', 'NORMALD', 'NewFold', 'NewPic', 'Nullspace', 'Output', 'Ox_2d_unit_vector', 'Ox_3d_unit_vector', 'Oy_2d_unit_vector', 'Oy_3d_unit_vector', 'Oz_3d_unit_vector', 'Pause', 'PopUp', 'Quo', 'REDIM', 'REPLACE', 'RclPic', 'Rem', 'Resultant', 'RplcPic', 'Rref', 'SCALE', 'SCALEADD', 'SCHUR', 'SIN', 'SVD', 'SVL', 'SWAPCOL', 'SWAPROW', 'SetFold', 'Si', 'StoPic', 'Store', 'TAN', 'TRUE', 'True', 'TeX', 'Text', 'Title', 'Unarchiv', 'WAIT', '^', '_(cm/s)', '_(ft/s)', '_(ft*lb)', '_(m/s)', '_(m/s^2)', '_(rad/s)', '_(rad/s^2)', '_(tr/min)', '_(tr/s)', '_A', '_Angstrom', '_Bq', '_Btu', '_Ci', '_F', '_F_', '_Fdy', '_G_', '_Gal', '_Gy', '_H', '_Hz', '_I0_', '_J', '_K', '_Kcal', '_MHz', '_MW', '_MeV', '_N', '_NA_', '_Ohm', '_P', '_PSun_', '_Pa', '_R', '_REarth_', '_RSun_', '_R_', '_Rankine', '_Rinfinity_', '_S', '_St', '_StdP_', '_StdT_', '_Sv', '_T', '_V', '_Vm_', '_W', '_Wb', '_Wh', '_a', '_a0_', '_acre', '_alpha_', '_angl_', '_arcmin', '_arcs', '_atm', '_au', '_b', '_bar', '_bbl', '_bblep', '_bu', '_buUS', '_c3_', '_c_', '_cal', '_cd', '_chain', '_cm', '_cm^2', '_cm^3', '_ct', '_cu', '_d', '_dB', '_deg', '_degreeF', '_dyn', '_eV', '_epsilon0_', '_epsilon0q_', '_epsilonox_', '_epsilonsi_', '_erg', '_f0_', '_fath', '_fbm', '_fc', '_fermi', '_flam', '_fm', '_ft', '_ft*lb', '_ftUS', '_ft^2', '_ft^3', '_g', '_g_', '_ga', '_galC', '_galUK', '_galUS', '_gf', '_gmol', '_gon', '_grad', '_grain', '_h', '_h_', '_ha', '_hbar_', '_hp', '_in', '_inH20', '_inHg', '_in^2', '_in^3', '_j', '_kWh', '_k_', '_kg', '_kip', '_km', '_km^2', '_knot', '_kph', '_kq_', '_l', '_lam', '_lambda0_', '_lambdac_', '_lb', '_lbf', '_lbmol', '_lbt', '_lep', '_liqpt', '_lm', '_lx', '_lyr', '_m', '_mEarth_', '_m^2', '_m^3', '_me_', '_mho', '_miUS', '_miUS^2', '_mi^2', '_mil', '_mile', '_mille', '_ml', '_mm', '_mmHg', '_mn', '_mol', '_mp_', '_mph', '_mpme_', '_mu0_', '_muB_', '_muN_', '_oz', '_ozUK', '_ozfl', '_ozt', '_pc', '_pdl', '_ph', '_phi_', '_pk', '_psi', '_ptUK', '_q_', '_qe_', '_qepsilon0_', '_qme_', '_qt', '_rad', '_rad_', '_rd', '_rem', '_rod', '_rpm', '_s', '_sb', '_sd_', '_sigma_', '_slug', '_sr', '_st', '_syr_', '_t', '_tbsp', '_tec', '_tep', '_tex', '_therm', '_ton', '_tonUK', '_torr', '_tr', '_tsp', '_twopi_', '_u', '_yd', '_yd^2', '_yd^3', '_yr', '_', '_', 'assert', 'affichage', 'alors', 'animate', 'animate3d', 'animation', 'approx_mode', 'archive', 'args', 'as_function_of', 'asc', 'asec', 'assign', 'backquote', 'begin', 'black', 'blanc', 'bleu', 'bloc', 'blue', 'breakpoint', 'by', 'c1oc2', 'c1op2', 'cache_tortue', 'cap', 'cap_flat_line', 'cap_round_line', 'cap_square_line', 'case', 'cat', 'catch', 'cd', 'choosebox', 'click', 'close', 'complex_mode', 'de', 'del', 'debug', 'default', 'div', 'double', 'ecris', 'efface', 'elif', 'end', 'end_for', 'end_if', 'end_while', 'epaisseur', 'epaisseur_ligne_1', 'epaisseur_ligne_2', 'epaisseur_ligne_3', 'epaisseur_ligne_4', 'epaisseur_ligne_5', 'epaisseur_ligne_6', 'epaisseur_ligne_7', 'epaisseur_point_1', 'epaisseur_point_2', 'epaisseur_point_3', 'epaisseur_point_4', 'epaisseur_point_5', 'epaisseur_point_6', 'epaisseur_point_7', 'erase', 'erase3d', 'est_cocyclique', 'est_inclus', 'et', 'faire', 'faux', 'feuille', 'ffaire', 'ffonction', 'fi', 'filled', 'fin_enregistrement', 'float', 'fonction', 'fopen', 'format', 'fpour', 'frame_3d', 'frames', 'fsi', 'ftantque', 'func', 'function', 'gauche', 'gl_ortho', 'gl_quaternion', 'gl_rotation', 'gl_shownames', 'gl_texture', 'gl_x', 'gl_x_axis_color', 'gl_x_axis_name', 'gl_x_axis_unit', 'gl_xtick', 'gl_y', 'gl_y_axis_color', 'gl_y_axis_name', 'gl_y_axis_unit', 'gl_ytick', 'gl_z', 'gl_z_axis_color', 'gl_z_axis_name', 'gl_z_axis_unit', 'gl_ztick', 'gnuplot', 'goto', 'graph2tex', 'graph3d2tex', 'graphe', 'graphe3d', 'graphe_probabiliste', 'graphe_suite', 'green', 'grid_paper', 'hidden_name', 'identifier', 'ifft', 'ifte', 'inputform', 'intersect', 'is_included', 'jusqu_a', 'jusqua', 'jusque', 'keep_algext', 'kill', 'label', 'labels', 'len', 'leve_crayon', 'line_width_1', 'line_width_2', 'line_width_3', 'line_width_4', 'line_width_5', 'line_width_6', 'line_width_7', 'lis', 'local', 'minus', 'mod', 'noir', 'nom_cache', 'non', 'od', 'option', 'otherwise', 'ou', 'pas', 'point_arret', 'point_carre', 'point_croix', 'point_div', 'point_etoile', 'point_invisible', 'point_losange', 'point_milieu', 'point_plus', 'point_point', 'point_polaire', 'point_triangle', 'point_width_1', 'point_width_2', 'point_width_3', 'point_width_4', 'point_width_5', 'point_width_6', 'point_width_7', 'pour', 'proc', 'program', 'quadrant1', 'quadrant2', 'quadrant3', 'quadrant4', 'range', 'redim', 'repeat', 'repete', 'repeter', 'replace', 'restart', 'rouge', 'saisir', 'saisir_chaine', 'sauve', 'save_history', 'scale', 'scaleadd', 'si', 'sinon', 'size', 'stack', 'step', 'switch', 'tantque', 'test', 'textinput', 'then', 'thiele', 'time', 'to', 'union', 'until', 'var', 'vector', 'vers', 'vert', 'vrai', 'watch', 'when', 'white', 'with_sqrt', 'write', 'wz_certificate', 'xor', 'yellow', '{}', '|', '||', 'expression']             # <<<<<<<<<<<<<<
 * 
 * nonevaluable = ['e', 'pi']
 */
  __pyx_t_2 = PyList_New(589); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_kp_s__1657);
  __Pyx_GIVEREF(__pyx_kp_s__1657);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_kp_s__1657)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1658);
  __Pyx_GIVEREF(__pyx_kp_s__1658);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_kp_s__1658)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1659);
  __Pyx_GIVEREF(__pyx_kp_s__1659);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_kp_s__1659)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1660);
  __Pyx_GIVEREF(__pyx_kp_s__1660);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_kp_s__1660)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1661);
  __Pyx_GIVEREF(__pyx_kp_s__1661);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_kp_s__1661)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1662);
  __Pyx_GIVEREF(__pyx_kp_s__1662);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_kp_s__1662)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1663);
  __Pyx_GIVEREF(__pyx_kp_s__1663);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, __pyx_kp_s__1663)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1664);
  __Pyx_GIVEREF(__pyx_kp_s__1664);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 7, __pyx_kp_s__1664)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1665);
  __Pyx_GIVEREF(__pyx_kp_s__1665);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 8, __pyx_kp_s__1665)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1666);
  __Pyx_GIVEREF(__pyx_kp_s__1666);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 9, __pyx_kp_s__1666)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1667);
  __Pyx_GIVEREF(__pyx_kp_s__1667);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 10, __pyx_kp_s__1667)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1668);
  __Pyx_GIVEREF(__pyx_kp_s__1668);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 11, __pyx_kp_s__1668)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1669);
  __Pyx_GIVEREF(__pyx_kp_s__1669);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 12, __pyx_kp_s__1669)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s__14);
  __Pyx_GIVEREF(__pyx_n_s__14);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 13, __pyx_n_s__14)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1670);
  __Pyx_GIVEREF(__pyx_kp_s__1670);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 14, __pyx_kp_s__1670)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1671);
  __Pyx_GIVEREF(__pyx_kp_s__1671);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 15, __pyx_kp_s__1671)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1672);
  __Pyx_GIVEREF(__pyx_kp_s__1672);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 16, __pyx_kp_s__1672)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1673);
  __Pyx_GIVEREF(__pyx_kp_s__1673);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 17, __pyx_kp_s__1673)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1674);
  __Pyx_GIVEREF(__pyx_kp_s__1674);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 18, __pyx_kp_s__1674)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_infinity_2);
  __Pyx_GIVEREF(__pyx_kp_s_infinity_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 19, __pyx_kp_s_infinity_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1675);
  __Pyx_GIVEREF(__pyx_kp_s__1675);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 20, __pyx_kp_s__1675)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1676);
  __Pyx_GIVEREF(__pyx_kp_s__1676);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 21, __pyx_kp_s__1676)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1677);
  __Pyx_GIVEREF(__pyx_kp_s__1677);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 22, __pyx_kp_s__1677)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_infinity_3);
  __Pyx_GIVEREF(__pyx_kp_s_infinity_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 23, __pyx_kp_s_infinity_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1678);
  __Pyx_GIVEREF(__pyx_kp_s__1678);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 24, __pyx_kp_s__1678)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1679);
  __Pyx_GIVEREF(__pyx_kp_s__1679);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 25, __pyx_kp_s__1679)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1680);
  __Pyx_GIVEREF(__pyx_kp_s__1680);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 26, __pyx_kp_s__1680)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1681);
  __Pyx_GIVEREF(__pyx_kp_s__1681);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 27, __pyx_kp_s__1681)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1682);
  __Pyx_GIVEREF(__pyx_kp_s__1682);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 28, __pyx_kp_s__1682)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1683);
  __Pyx_GIVEREF(__pyx_kp_s__1683);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 29, __pyx_kp_s__1683)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1684);
  __Pyx_GIVEREF(__pyx_kp_s__1684);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 30, __pyx_kp_s__1684)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1685);
  __Pyx_GIVEREF(__pyx_kp_s__1685);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 31, __pyx_kp_s__1685)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1686);
  __Pyx_GIVEREF(__pyx_kp_s__1686);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 32, __pyx_kp_s__1686)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1687);
  __Pyx_GIVEREF(__pyx_kp_s__1687);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 33, __pyx_kp_s__1687)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1688);
  __Pyx_GIVEREF(__pyx_kp_s__1688);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 34, __pyx_kp_s__1688)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1689);
  __Pyx_GIVEREF(__pyx_kp_s__1689);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 35, __pyx_kp_s__1689)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1690);
  __Pyx_GIVEREF(__pyx_kp_s__1690);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 36, __pyx_kp_s__1690)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1691);
  __Pyx_GIVEREF(__pyx_kp_s__1691);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 37, __pyx_kp_s__1691)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1692);
  __Pyx_GIVEREF(__pyx_kp_s__1692);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 38, __pyx_kp_s__1692)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__12);
  __Pyx_GIVEREF(__pyx_kp_s__12);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 39, __pyx_kp_s__12)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1693);
  __Pyx_GIVEREF(__pyx_kp_s__1693);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 40, __pyx_kp_s__1693)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1694);
  __Pyx_GIVEREF(__pyx_kp_s__1694);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 41, __pyx_kp_s__1694)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ACOSH);
  __Pyx_GIVEREF(__pyx_n_s_ACOSH);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 42, __pyx_n_s_ACOSH)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ACOT);
  __Pyx_GIVEREF(__pyx_n_s_ACOT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 43, __pyx_n_s_ACOT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ACSC);
  __Pyx_GIVEREF(__pyx_n_s_ACSC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 44, __pyx_n_s_ACSC)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ASEC);
  __Pyx_GIVEREF(__pyx_n_s_ASEC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 45, __pyx_n_s_ASEC)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ASIN);
  __Pyx_GIVEREF(__pyx_n_s_ASIN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 46, __pyx_n_s_ASIN)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ASINH);
  __Pyx_GIVEREF(__pyx_n_s_ASINH);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 47, __pyx_n_s_ASINH)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ATAN);
  __Pyx_GIVEREF(__pyx_n_s_ATAN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 48, __pyx_n_s_ATAN)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ATANH);
  __Pyx_GIVEREF(__pyx_n_s_ATANH);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 49, __pyx_n_s_ATANH)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_COND);
  __Pyx_GIVEREF(__pyx_n_s_COND);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 50, __pyx_n_s_COND)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_COS);
  __Pyx_GIVEREF(__pyx_n_s_COS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 51, __pyx_n_s_COS)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_COSH);
  __Pyx_GIVEREF(__pyx_n_s_COSH);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 52, __pyx_n_s_COSH)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_COT);
  __Pyx_GIVEREF(__pyx_n_s_COT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 53, __pyx_n_s_COT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CSC);
  __Pyx_GIVEREF(__pyx_n_s_CSC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 54, __pyx_n_s_CSC)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CST);
  __Pyx_GIVEREF(__pyx_n_s_CST);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 55, __pyx_n_s_CST)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Celsius2Fahrenheit);
  __Pyx_GIVEREF(__pyx_n_s_Celsius2Fahrenheit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 56, __pyx_n_s_Celsius2Fahrenheit)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ClrDraw);
  __Pyx_GIVEREF(__pyx_n_s_ClrDraw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 57, __pyx_n_s_ClrDraw)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ClrGraph);
  __Pyx_GIVEREF(__pyx_n_s_ClrGraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 58, __pyx_n_s_ClrGraph)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ClrIO);
  __Pyx_GIVEREF(__pyx_n_s_ClrIO);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 59, __pyx_n_s_ClrIO)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CyclePic);
  __Pyx_GIVEREF(__pyx_n_s_CyclePic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 60, __pyx_n_s_CyclePic)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DIGITS);
  __Pyx_GIVEREF(__pyx_n_s_DIGITS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 61, __pyx_n_s_DIGITS)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_COMPLEX);
  __Pyx_GIVEREF(__pyx_n_s_DOM_COMPLEX);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 62, __pyx_n_s_DOM_COMPLEX)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_FLOAT);
  __Pyx_GIVEREF(__pyx_n_s_DOM_FLOAT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 63, __pyx_n_s_DOM_FLOAT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_FUNC);
  __Pyx_GIVEREF(__pyx_n_s_DOM_FUNC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 64, __pyx_n_s_DOM_FUNC)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_IDENT);
  __Pyx_GIVEREF(__pyx_n_s_DOM_IDENT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 65, __pyx_n_s_DOM_IDENT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_INT);
  __Pyx_GIVEREF(__pyx_n_s_DOM_INT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 66, __pyx_n_s_DOM_INT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_LIST);
  __Pyx_GIVEREF(__pyx_n_s_DOM_LIST);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 67, __pyx_n_s_DOM_LIST)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_RAT);
  __Pyx_GIVEREF(__pyx_n_s_DOM_RAT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 68, __pyx_n_s_DOM_RAT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_STRING);
  __Pyx_GIVEREF(__pyx_n_s_DOM_STRING);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 69, __pyx_n_s_DOM_STRING)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_SYMBOLIC);
  __Pyx_GIVEREF(__pyx_n_s_DOM_SYMBOLIC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 70, __pyx_n_s_DOM_SYMBOLIC)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DOM_int);
  __Pyx_GIVEREF(__pyx_n_s_DOM_int);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 71, __pyx_n_s_DOM_int)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DelFold);
  __Pyx_GIVEREF(__pyx_n_s_DelFold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 72, __pyx_n_s_DelFold)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DelVar);
  __Pyx_GIVEREF(__pyx_n_s_DelVar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 73, __pyx_n_s_DelVar)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Det);
  __Pyx_GIVEREF(__pyx_n_s_Det);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 74, __pyx_n_s_Det)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Dialog);
  __Pyx_GIVEREF(__pyx_n_s_Dialog);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 75, __pyx_n_s_Dialog)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Digits);
  __Pyx_GIVEREF(__pyx_n_s_Digits);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 76, __pyx_n_s_Digits)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Disp);
  __Pyx_GIVEREF(__pyx_n_s_Disp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 77, __pyx_n_s_Disp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DispG);
  __Pyx_GIVEREF(__pyx_n_s_DispG);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 78, __pyx_n_s_DispG)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DispHome);
  __Pyx_GIVEREF(__pyx_n_s_DispHome);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 79, __pyx_n_s_DispHome)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DrawFunc);
  __Pyx_GIVEREF(__pyx_n_s_DrawFunc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 80, __pyx_n_s_DrawFunc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DrawInv);
  __Pyx_GIVEREF(__pyx_n_s_DrawInv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 81, __pyx_n_s_DrawInv)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DrawParm);
  __Pyx_GIVEREF(__pyx_n_s_DrawParm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 82, __pyx_n_s_DrawParm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DrawPol);
  __Pyx_GIVEREF(__pyx_n_s_DrawPol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 83, __pyx_n_s_DrawPol)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DrawSlp);
  __Pyx_GIVEREF(__pyx_n_s_DrawSlp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 84, __pyx_n_s_DrawSlp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DropDown);
  __Pyx_GIVEREF(__pyx_n_s_DropDown);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 85, __pyx_n_s_DropDown)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DrwCtour);
  __Pyx_GIVEREF(__pyx_n_s_DrwCtour);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 86, __pyx_n_s_DrwCtour)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ERROR);
  __Pyx_GIVEREF(__pyx_n_s_ERROR);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 87, __pyx_n_s_ERROR)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_EXP);
  __Pyx_GIVEREF(__pyx_n_s_EXP);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 88, __pyx_n_s_EXP)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_EndDlog);
  __Pyx_GIVEREF(__pyx_n_s_EndDlog);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 89, __pyx_n_s_EndDlog)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_FALSE);
  __Pyx_GIVEREF(__pyx_n_s_FALSE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 90, __pyx_n_s_FALSE)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_False);
  __Pyx_GIVEREF(__pyx_n_s_False);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 91, __pyx_n_s_False)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Fahrenheit2Celsius);
  __Pyx_GIVEREF(__pyx_n_s_Fahrenheit2Celsius);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 92, __pyx_n_s_Fahrenheit2Celsius)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Fill);
  __Pyx_GIVEREF(__pyx_n_s_Fill);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 93, __pyx_n_s_Fill)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Gcd);
  __Pyx_GIVEREF(__pyx_n_s_Gcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 94, __pyx_n_s_Gcd)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_GetFold);
  __Pyx_GIVEREF(__pyx_n_s_GetFold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 95, __pyx_n_s_GetFold)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Graph);
  __Pyx_GIVEREF(__pyx_n_s_Graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 96, __pyx_n_s_Graph)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_IFTE);
  __Pyx_GIVEREF(__pyx_n_s_IFTE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 97, __pyx_n_s_IFTE)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Input);
  __Pyx_GIVEREF(__pyx_n_s_Input);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 98, __pyx_n_s_Input)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_InputStr);
  __Pyx_GIVEREF(__pyx_n_s_InputStr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 99, __pyx_n_s_InputStr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Int);
  __Pyx_GIVEREF(__pyx_n_s_Int);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 100, __pyx_n_s_Int)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Inverse);
  __Pyx_GIVEREF(__pyx_n_s_Inverse);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 101, __pyx_n_s_Inverse)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LN);
  __Pyx_GIVEREF(__pyx_n_s_LN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 102, __pyx_n_s_LN)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LQ);
  __Pyx_GIVEREF(__pyx_n_s_LQ);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 103, __pyx_n_s_LQ)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LSQ);
  __Pyx_GIVEREF(__pyx_n_s_LSQ);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 104, __pyx_n_s_LSQ)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_NORMALD);
  __Pyx_GIVEREF(__pyx_n_s_NORMALD);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 105, __pyx_n_s_NORMALD)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_NewFold);
  __Pyx_GIVEREF(__pyx_n_s_NewFold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 106, __pyx_n_s_NewFold)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_NewPic);
  __Pyx_GIVEREF(__pyx_n_s_NewPic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 107, __pyx_n_s_NewPic)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Nullspace);
  __Pyx_GIVEREF(__pyx_n_s_Nullspace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 108, __pyx_n_s_Nullspace)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Output);
  __Pyx_GIVEREF(__pyx_n_s_Output);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 109, __pyx_n_s_Output)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Ox_2d_unit_vector);
  __Pyx_GIVEREF(__pyx_n_s_Ox_2d_unit_vector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 110, __pyx_n_s_Ox_2d_unit_vector)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Ox_3d_unit_vector);
  __Pyx_GIVEREF(__pyx_n_s_Ox_3d_unit_vector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 111, __pyx_n_s_Ox_3d_unit_vector)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Oy_2d_unit_vector);
  __Pyx_GIVEREF(__pyx_n_s_Oy_2d_unit_vector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 112, __pyx_n_s_Oy_2d_unit_vector)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Oy_3d_unit_vector);
  __Pyx_GIVEREF(__pyx_n_s_Oy_3d_unit_vector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 113, __pyx_n_s_Oy_3d_unit_vector)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Oz_3d_unit_vector);
  __Pyx_GIVEREF(__pyx_n_s_Oz_3d_unit_vector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 114, __pyx_n_s_Oz_3d_unit_vector)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Pause);
  __Pyx_GIVEREF(__pyx_n_s_Pause);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 115, __pyx_n_s_Pause)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_PopUp);
  __Pyx_GIVEREF(__pyx_n_s_PopUp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 116, __pyx_n_s_PopUp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Quo);
  __Pyx_GIVEREF(__pyx_n_s_Quo);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 117, __pyx_n_s_Quo)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_REDIM);
  __Pyx_GIVEREF(__pyx_n_s_REDIM);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 118, __pyx_n_s_REDIM)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_REPLACE);
  __Pyx_GIVEREF(__pyx_n_s_REPLACE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 119, __pyx_n_s_REPLACE)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_RclPic);
  __Pyx_GIVEREF(__pyx_n_s_RclPic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 120, __pyx_n_s_RclPic)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Rem);
  __Pyx_GIVEREF(__pyx_n_s_Rem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 121, __pyx_n_s_Rem)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Resultant);
  __Pyx_GIVEREF(__pyx_n_s_Resultant);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 122, __pyx_n_s_Resultant)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_RplcPic);
  __Pyx_GIVEREF(__pyx_n_s_RplcPic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 123, __pyx_n_s_RplcPic)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Rref);
  __Pyx_GIVEREF(__pyx_n_s_Rref);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 124, __pyx_n_s_Rref)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SCALE);
  __Pyx_GIVEREF(__pyx_n_s_SCALE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 125, __pyx_n_s_SCALE)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SCALEADD);
  __Pyx_GIVEREF(__pyx_n_s_SCALEADD);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 126, __pyx_n_s_SCALEADD)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SCHUR);
  __Pyx_GIVEREF(__pyx_n_s_SCHUR);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 127, __pyx_n_s_SCHUR)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SIN);
  __Pyx_GIVEREF(__pyx_n_s_SIN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 128, __pyx_n_s_SIN)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SVD);
  __Pyx_GIVEREF(__pyx_n_s_SVD);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 129, __pyx_n_s_SVD)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SVL);
  __Pyx_GIVEREF(__pyx_n_s_SVL);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 130, __pyx_n_s_SVL)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SWAPCOL);
  __Pyx_GIVEREF(__pyx_n_s_SWAPCOL);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 131, __pyx_n_s_SWAPCOL)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SWAPROW);
  __Pyx_GIVEREF(__pyx_n_s_SWAPROW);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 132, __pyx_n_s_SWAPROW)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SetFold);
  __Pyx_GIVEREF(__pyx_n_s_SetFold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 133, __pyx_n_s_SetFold)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Si);
  __Pyx_GIVEREF(__pyx_n_s_Si);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 134, __pyx_n_s_Si)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_StoPic);
  __Pyx_GIVEREF(__pyx_n_s_StoPic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 135, __pyx_n_s_StoPic)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Store);
  __Pyx_GIVEREF(__pyx_n_s_Store);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 136, __pyx_n_s_Store)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_TAN);
  __Pyx_GIVEREF(__pyx_n_s_TAN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 137, __pyx_n_s_TAN)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_TRUE);
  __Pyx_GIVEREF(__pyx_n_s_TRUE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 138, __pyx_n_s_TRUE)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_True);
  __Pyx_GIVEREF(__pyx_n_s_True);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 139, __pyx_n_s_True)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_TeX);
  __Pyx_GIVEREF(__pyx_n_s_TeX);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 140, __pyx_n_s_TeX)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Text);
  __Pyx_GIVEREF(__pyx_n_s_Text);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 141, __pyx_n_s_Text)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Title);
  __Pyx_GIVEREF(__pyx_n_s_Title);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 142, __pyx_n_s_Title)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Unarchiv);
  __Pyx_GIVEREF(__pyx_n_s_Unarchiv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 143, __pyx_n_s_Unarchiv)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_WAIT);
  __Pyx_GIVEREF(__pyx_n_s_WAIT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 144, __pyx_n_s_WAIT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1695);
  __Pyx_GIVEREF(__pyx_kp_s__1695);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 145, __pyx_kp_s__1695)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_cm_s);
  __Pyx_GIVEREF(__pyx_kp_s_cm_s);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 146, __pyx_kp_s_cm_s)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_ft_s);
  __Pyx_GIVEREF(__pyx_kp_s_ft_s);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 147, __pyx_kp_s_ft_s)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_ft_lb);
  __Pyx_GIVEREF(__pyx_kp_s_ft_lb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 148, __pyx_kp_s_ft_lb)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_m_s);
  __Pyx_GIVEREF(__pyx_kp_s_m_s);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 149, __pyx_kp_s_m_s)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_m_s_2);
  __Pyx_GIVEREF(__pyx_kp_s_m_s_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 150, __pyx_kp_s_m_s_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_rad_s);
  __Pyx_GIVEREF(__pyx_kp_s_rad_s);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 151, __pyx_kp_s_rad_s)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_rad_s_2);
  __Pyx_GIVEREF(__pyx_kp_s_rad_s_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 152, __pyx_kp_s_rad_s_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_tr_min);
  __Pyx_GIVEREF(__pyx_kp_s_tr_min);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 153, __pyx_kp_s_tr_min)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_tr_s);
  __Pyx_GIVEREF(__pyx_kp_s_tr_s);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 154, __pyx_kp_s_tr_s)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_A_2);
  __Pyx_GIVEREF(__pyx_n_s_A_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 155, __pyx_n_s_A_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Angstrom);
  __Pyx_GIVEREF(__pyx_n_s_Angstrom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 156, __pyx_n_s_Angstrom)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Bq);
  __Pyx_GIVEREF(__pyx_n_s_Bq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 157, __pyx_n_s_Bq)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Btu);
  __Pyx_GIVEREF(__pyx_n_s_Btu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 158, __pyx_n_s_Btu)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Ci_2);
  __Pyx_GIVEREF(__pyx_n_s_Ci_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 159, __pyx_n_s_Ci_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_F);
  __Pyx_GIVEREF(__pyx_n_s_F);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 160, __pyx_n_s_F)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_F_2);
  __Pyx_GIVEREF(__pyx_n_s_F_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 161, __pyx_n_s_F_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Fdy);
  __Pyx_GIVEREF(__pyx_n_s_Fdy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 162, __pyx_n_s_Fdy)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_G);
  __Pyx_GIVEREF(__pyx_n_s_G);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 163, __pyx_n_s_G)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Gal);
  __Pyx_GIVEREF(__pyx_n_s_Gal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 164, __pyx_n_s_Gal)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Gy);
  __Pyx_GIVEREF(__pyx_n_s_Gy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 165, __pyx_n_s_Gy)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_H);
  __Pyx_GIVEREF(__pyx_n_s_H);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 166, __pyx_n_s_H)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Hz);
  __Pyx_GIVEREF(__pyx_n_s_Hz);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 167, __pyx_n_s_Hz)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_I0);
  __Pyx_GIVEREF(__pyx_n_s_I0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 168, __pyx_n_s_I0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_J);
  __Pyx_GIVEREF(__pyx_n_s_J);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 169, __pyx_n_s_J)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_K);
  __Pyx_GIVEREF(__pyx_n_s_K);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 170, __pyx_n_s_K)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Kcal);
  __Pyx_GIVEREF(__pyx_n_s_Kcal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 171, __pyx_n_s_Kcal)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_MHz);
  __Pyx_GIVEREF(__pyx_n_s_MHz);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 172, __pyx_n_s_MHz)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_MW);
  __Pyx_GIVEREF(__pyx_n_s_MW);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 173, __pyx_n_s_MW)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_MeV);
  __Pyx_GIVEREF(__pyx_n_s_MeV);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 174, __pyx_n_s_MeV)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_N);
  __Pyx_GIVEREF(__pyx_n_s_N);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 175, __pyx_n_s_N)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_NA);
  __Pyx_GIVEREF(__pyx_n_s_NA);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 176, __pyx_n_s_NA)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Ohm);
  __Pyx_GIVEREF(__pyx_n_s_Ohm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 177, __pyx_n_s_Ohm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_P);
  __Pyx_GIVEREF(__pyx_n_s_P);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 178, __pyx_n_s_P)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_PSun);
  __Pyx_GIVEREF(__pyx_n_s_PSun);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 179, __pyx_n_s_PSun)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Pa);
  __Pyx_GIVEREF(__pyx_n_s_Pa);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 180, __pyx_n_s_Pa)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_R);
  __Pyx_GIVEREF(__pyx_n_s_R);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 181, __pyx_n_s_R)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_REarth);
  __Pyx_GIVEREF(__pyx_n_s_REarth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 182, __pyx_n_s_REarth)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_RSun);
  __Pyx_GIVEREF(__pyx_n_s_RSun);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 183, __pyx_n_s_RSun)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_R_2);
  __Pyx_GIVEREF(__pyx_n_s_R_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 184, __pyx_n_s_R_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Rankine);
  __Pyx_GIVEREF(__pyx_n_s_Rankine);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 185, __pyx_n_s_Rankine)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Rinfinity);
  __Pyx_GIVEREF(__pyx_n_s_Rinfinity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 186, __pyx_n_s_Rinfinity)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_S);
  __Pyx_GIVEREF(__pyx_n_s_S);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 187, __pyx_n_s_S)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_St);
  __Pyx_GIVEREF(__pyx_n_s_St);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 188, __pyx_n_s_St)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_StdP);
  __Pyx_GIVEREF(__pyx_n_s_StdP);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 189, __pyx_n_s_StdP)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_StdT);
  __Pyx_GIVEREF(__pyx_n_s_StdT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 190, __pyx_n_s_StdT)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Sv);
  __Pyx_GIVEREF(__pyx_n_s_Sv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 191, __pyx_n_s_Sv)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_T);
  __Pyx_GIVEREF(__pyx_n_s_T);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 192, __pyx_n_s_T)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_V);
  __Pyx_GIVEREF(__pyx_n_s_V);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 193, __pyx_n_s_V)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Vm);
  __Pyx_GIVEREF(__pyx_n_s_Vm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 194, __pyx_n_s_Vm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_W);
  __Pyx_GIVEREF(__pyx_n_s_W);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 195, __pyx_n_s_W)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Wb);
  __Pyx_GIVEREF(__pyx_n_s_Wb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 196, __pyx_n_s_Wb)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Wh);
  __Pyx_GIVEREF(__pyx_n_s_Wh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 197, __pyx_n_s_Wh)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_a_2);
  __Pyx_GIVEREF(__pyx_n_s_a_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 198, __pyx_n_s_a_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_a0);
  __Pyx_GIVEREF(__pyx_n_s_a0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 199, __pyx_n_s_a0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acre);
  __Pyx_GIVEREF(__pyx_n_s_acre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 200, __pyx_n_s_acre)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_alpha);
  __Pyx_GIVEREF(__pyx_n_s_alpha);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 201, __pyx_n_s_alpha)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_angl);
  __Pyx_GIVEREF(__pyx_n_s_angl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 202, __pyx_n_s_angl)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arcmin);
  __Pyx_GIVEREF(__pyx_n_s_arcmin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 203, __pyx_n_s_arcmin)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arcs);
  __Pyx_GIVEREF(__pyx_n_s_arcs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 204, __pyx_n_s_arcs)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atm);
  __Pyx_GIVEREF(__pyx_n_s_atm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 205, __pyx_n_s_atm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_au);
  __Pyx_GIVEREF(__pyx_n_s_au);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 206, __pyx_n_s_au)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_b_2);
  __Pyx_GIVEREF(__pyx_n_s_b_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 207, __pyx_n_s_b_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bar);
  __Pyx_GIVEREF(__pyx_n_s_bar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 208, __pyx_n_s_bar)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bbl);
  __Pyx_GIVEREF(__pyx_n_s_bbl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 209, __pyx_n_s_bbl)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bblep);
  __Pyx_GIVEREF(__pyx_n_s_bblep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 210, __pyx_n_s_bblep)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bu);
  __Pyx_GIVEREF(__pyx_n_s_bu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 211, __pyx_n_s_bu)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_buUS);
  __Pyx_GIVEREF(__pyx_n_s_buUS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 212, __pyx_n_s_buUS)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_c3);
  __Pyx_GIVEREF(__pyx_n_s_c3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 213, __pyx_n_s_c3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_c);
  __Pyx_GIVEREF(__pyx_n_s_c);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 214, __pyx_n_s_c)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cal);
  __Pyx_GIVEREF(__pyx_n_s_cal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 215, __pyx_n_s_cal)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cd);
  __Pyx_GIVEREF(__pyx_n_s_cd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 216, __pyx_n_s_cd)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chain);
  __Pyx_GIVEREF(__pyx_n_s_chain);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 217, __pyx_n_s_chain)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cm);
  __Pyx_GIVEREF(__pyx_n_s_cm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 218, __pyx_n_s_cm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_cm_2);
  __Pyx_GIVEREF(__pyx_kp_s_cm_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 219, __pyx_kp_s_cm_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_cm_3);
  __Pyx_GIVEREF(__pyx_kp_s_cm_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 220, __pyx_kp_s_cm_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ct);
  __Pyx_GIVEREF(__pyx_n_s_ct);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 221, __pyx_n_s_ct)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cu);
  __Pyx_GIVEREF(__pyx_n_s_cu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 222, __pyx_n_s_cu)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_d_2);
  __Pyx_GIVEREF(__pyx_n_s_d_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 223, __pyx_n_s_d_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dB);
  __Pyx_GIVEREF(__pyx_n_s_dB);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 224, __pyx_n_s_dB)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_deg);
  __Pyx_GIVEREF(__pyx_n_s_deg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 225, __pyx_n_s_deg)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_degreeF);
  __Pyx_GIVEREF(__pyx_n_s_degreeF);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 226, __pyx_n_s_degreeF)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dyn);
  __Pyx_GIVEREF(__pyx_n_s_dyn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 227, __pyx_n_s_dyn)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eV);
  __Pyx_GIVEREF(__pyx_n_s_eV);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 228, __pyx_n_s_eV)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epsilon0);
  __Pyx_GIVEREF(__pyx_n_s_epsilon0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 229, __pyx_n_s_epsilon0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epsilon0q);
  __Pyx_GIVEREF(__pyx_n_s_epsilon0q);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 230, __pyx_n_s_epsilon0q)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epsilonox);
  __Pyx_GIVEREF(__pyx_n_s_epsilonox);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 231, __pyx_n_s_epsilonox)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epsilonsi);
  __Pyx_GIVEREF(__pyx_n_s_epsilonsi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 232, __pyx_n_s_epsilonsi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_erg);
  __Pyx_GIVEREF(__pyx_n_s_erg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 233, __pyx_n_s_erg)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_f0);
  __Pyx_GIVEREF(__pyx_n_s_f0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 234, __pyx_n_s_f0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fath);
  __Pyx_GIVEREF(__pyx_n_s_fath);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 235, __pyx_n_s_fath)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fbm);
  __Pyx_GIVEREF(__pyx_n_s_fbm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 236, __pyx_n_s_fbm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fc);
  __Pyx_GIVEREF(__pyx_n_s_fc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 237, __pyx_n_s_fc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fermi);
  __Pyx_GIVEREF(__pyx_n_s_fermi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 238, __pyx_n_s_fermi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_flam);
  __Pyx_GIVEREF(__pyx_n_s_flam);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 239, __pyx_n_s_flam)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fm);
  __Pyx_GIVEREF(__pyx_n_s_fm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 240, __pyx_n_s_fm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ft);
  __Pyx_GIVEREF(__pyx_n_s_ft);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 241, __pyx_n_s_ft)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_ft_lb_2);
  __Pyx_GIVEREF(__pyx_kp_s_ft_lb_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 242, __pyx_kp_s_ft_lb_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ftUS);
  __Pyx_GIVEREF(__pyx_n_s_ftUS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 243, __pyx_n_s_ftUS)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_ft_2);
  __Pyx_GIVEREF(__pyx_kp_s_ft_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 244, __pyx_kp_s_ft_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_ft_3);
  __Pyx_GIVEREF(__pyx_kp_s_ft_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 245, __pyx_kp_s_ft_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_g);
  __Pyx_GIVEREF(__pyx_n_s_g);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 246, __pyx_n_s_g)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_g_2);
  __Pyx_GIVEREF(__pyx_n_s_g_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 247, __pyx_n_s_g_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ga);
  __Pyx_GIVEREF(__pyx_n_s_ga);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 248, __pyx_n_s_ga)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_galC);
  __Pyx_GIVEREF(__pyx_n_s_galC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 249, __pyx_n_s_galC)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_galUK);
  __Pyx_GIVEREF(__pyx_n_s_galUK);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 250, __pyx_n_s_galUK)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_galUS);
  __Pyx_GIVEREF(__pyx_n_s_galUS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 251, __pyx_n_s_galUS)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gf);
  __Pyx_GIVEREF(__pyx_n_s_gf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 252, __pyx_n_s_gf)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gmol);
  __Pyx_GIVEREF(__pyx_n_s_gmol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 253, __pyx_n_s_gmol)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gon);
  __Pyx_GIVEREF(__pyx_n_s_gon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 254, __pyx_n_s_gon)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_grad_2);
  __Pyx_GIVEREF(__pyx_n_s_grad_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 255, __pyx_n_s_grad_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_grain);
  __Pyx_GIVEREF(__pyx_n_s_grain);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 256, __pyx_n_s_grain)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_h);
  __Pyx_GIVEREF(__pyx_n_s_h);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 257, __pyx_n_s_h)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_h_2);
  __Pyx_GIVEREF(__pyx_n_s_h_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 258, __pyx_n_s_h_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ha);
  __Pyx_GIVEREF(__pyx_n_s_ha);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 259, __pyx_n_s_ha)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hbar);
  __Pyx_GIVEREF(__pyx_n_s_hbar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 260, __pyx_n_s_hbar)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hp);
  __Pyx_GIVEREF(__pyx_n_s_hp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 261, __pyx_n_s_hp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_in_2);
  __Pyx_GIVEREF(__pyx_n_s_in_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 262, __pyx_n_s_in_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inH20);
  __Pyx_GIVEREF(__pyx_n_s_inH20);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 263, __pyx_n_s_inH20)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inHg);
  __Pyx_GIVEREF(__pyx_n_s_inHg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 264, __pyx_n_s_inHg)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_in_2_2);
  __Pyx_GIVEREF(__pyx_kp_s_in_2_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 265, __pyx_kp_s_in_2_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_in_3);
  __Pyx_GIVEREF(__pyx_kp_s_in_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 266, __pyx_kp_s_in_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_j);
  __Pyx_GIVEREF(__pyx_n_s_j);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 267, __pyx_n_s_j)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kWh);
  __Pyx_GIVEREF(__pyx_n_s_kWh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 268, __pyx_n_s_kWh)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_k);
  __Pyx_GIVEREF(__pyx_n_s_k);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 269, __pyx_n_s_k)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kg);
  __Pyx_GIVEREF(__pyx_n_s_kg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 270, __pyx_n_s_kg)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kip);
  __Pyx_GIVEREF(__pyx_n_s_kip);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 271, __pyx_n_s_kip)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_km);
  __Pyx_GIVEREF(__pyx_n_s_km);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 272, __pyx_n_s_km)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_km_2);
  __Pyx_GIVEREF(__pyx_kp_s_km_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 273, __pyx_kp_s_km_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_knot);
  __Pyx_GIVEREF(__pyx_n_s_knot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 274, __pyx_n_s_knot)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kph);
  __Pyx_GIVEREF(__pyx_n_s_kph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 275, __pyx_n_s_kph)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kq);
  __Pyx_GIVEREF(__pyx_n_s_kq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 276, __pyx_n_s_kq)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_l_2);
  __Pyx_GIVEREF(__pyx_n_s_l_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 277, __pyx_n_s_l_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lam);
  __Pyx_GIVEREF(__pyx_n_s_lam);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 278, __pyx_n_s_lam)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lambda0);
  __Pyx_GIVEREF(__pyx_n_s_lambda0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 279, __pyx_n_s_lambda0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lambdac);
  __Pyx_GIVEREF(__pyx_n_s_lambdac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 280, __pyx_n_s_lambdac)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lb);
  __Pyx_GIVEREF(__pyx_n_s_lb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 281, __pyx_n_s_lb)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lbf);
  __Pyx_GIVEREF(__pyx_n_s_lbf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 282, __pyx_n_s_lbf)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lbmol);
  __Pyx_GIVEREF(__pyx_n_s_lbmol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 283, __pyx_n_s_lbmol)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lbt);
  __Pyx_GIVEREF(__pyx_n_s_lbt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 284, __pyx_n_s_lbt)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lep);
  __Pyx_GIVEREF(__pyx_n_s_lep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 285, __pyx_n_s_lep)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_liqpt);
  __Pyx_GIVEREF(__pyx_n_s_liqpt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 286, __pyx_n_s_liqpt)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lm);
  __Pyx_GIVEREF(__pyx_n_s_lm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 287, __pyx_n_s_lm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lx);
  __Pyx_GIVEREF(__pyx_n_s_lx);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 288, __pyx_n_s_lx)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lyr);
  __Pyx_GIVEREF(__pyx_n_s_lyr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 289, __pyx_n_s_lyr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_m);
  __Pyx_GIVEREF(__pyx_n_s_m);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 290, __pyx_n_s_m)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mEarth);
  __Pyx_GIVEREF(__pyx_n_s_mEarth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 291, __pyx_n_s_mEarth)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_m_2);
  __Pyx_GIVEREF(__pyx_kp_s_m_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 292, __pyx_kp_s_m_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_m_3);
  __Pyx_GIVEREF(__pyx_kp_s_m_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 293, __pyx_kp_s_m_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_me);
  __Pyx_GIVEREF(__pyx_n_s_me);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 294, __pyx_n_s_me)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mho);
  __Pyx_GIVEREF(__pyx_n_s_mho);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 295, __pyx_n_s_mho)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_miUS);
  __Pyx_GIVEREF(__pyx_n_s_miUS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 296, __pyx_n_s_miUS)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_miUS_2);
  __Pyx_GIVEREF(__pyx_kp_s_miUS_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 297, __pyx_kp_s_miUS_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_mi_2);
  __Pyx_GIVEREF(__pyx_kp_s_mi_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 298, __pyx_kp_s_mi_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mil);
  __Pyx_GIVEREF(__pyx_n_s_mil);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 299, __pyx_n_s_mil)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mile);
  __Pyx_GIVEREF(__pyx_n_s_mile);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 300, __pyx_n_s_mile)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mille);
  __Pyx_GIVEREF(__pyx_n_s_mille);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 301, __pyx_n_s_mille)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ml);
  __Pyx_GIVEREF(__pyx_n_s_ml);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 302, __pyx_n_s_ml)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mm);
  __Pyx_GIVEREF(__pyx_n_s_mm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 303, __pyx_n_s_mm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mmHg);
  __Pyx_GIVEREF(__pyx_n_s_mmHg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 304, __pyx_n_s_mmHg)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mn);
  __Pyx_GIVEREF(__pyx_n_s_mn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 305, __pyx_n_s_mn)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mol);
  __Pyx_GIVEREF(__pyx_n_s_mol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 306, __pyx_n_s_mol)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mp);
  __Pyx_GIVEREF(__pyx_n_s_mp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 307, __pyx_n_s_mp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mph);
  __Pyx_GIVEREF(__pyx_n_s_mph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 308, __pyx_n_s_mph)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mpme);
  __Pyx_GIVEREF(__pyx_n_s_mpme);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 309, __pyx_n_s_mpme)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mu0);
  __Pyx_GIVEREF(__pyx_n_s_mu0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 310, __pyx_n_s_mu0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_muB);
  __Pyx_GIVEREF(__pyx_n_s_muB);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 311, __pyx_n_s_muB)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_muN);
  __Pyx_GIVEREF(__pyx_n_s_muN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 312, __pyx_n_s_muN)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_oz);
  __Pyx_GIVEREF(__pyx_n_s_oz);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 313, __pyx_n_s_oz)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ozUK);
  __Pyx_GIVEREF(__pyx_n_s_ozUK);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 314, __pyx_n_s_ozUK)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ozfl);
  __Pyx_GIVEREF(__pyx_n_s_ozfl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 315, __pyx_n_s_ozfl)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ozt);
  __Pyx_GIVEREF(__pyx_n_s_ozt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 316, __pyx_n_s_ozt)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pc);
  __Pyx_GIVEREF(__pyx_n_s_pc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 317, __pyx_n_s_pc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pdl);
  __Pyx_GIVEREF(__pyx_n_s_pdl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 318, __pyx_n_s_pdl)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ph);
  __Pyx_GIVEREF(__pyx_n_s_ph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 319, __pyx_n_s_ph)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_phi);
  __Pyx_GIVEREF(__pyx_n_s_phi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 320, __pyx_n_s_phi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pk);
  __Pyx_GIVEREF(__pyx_n_s_pk);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 321, __pyx_n_s_pk)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_psi);
  __Pyx_GIVEREF(__pyx_n_s_psi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 322, __pyx_n_s_psi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ptUK);
  __Pyx_GIVEREF(__pyx_n_s_ptUK);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 323, __pyx_n_s_ptUK)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_q);
  __Pyx_GIVEREF(__pyx_n_s_q);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 324, __pyx_n_s_q)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_qe);
  __Pyx_GIVEREF(__pyx_n_s_qe);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 325, __pyx_n_s_qe)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_qepsilon0);
  __Pyx_GIVEREF(__pyx_n_s_qepsilon0);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 326, __pyx_n_s_qepsilon0)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_qme);
  __Pyx_GIVEREF(__pyx_n_s_qme);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 327, __pyx_n_s_qme)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_qt);
  __Pyx_GIVEREF(__pyx_n_s_qt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 328, __pyx_n_s_qt)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rad);
  __Pyx_GIVEREF(__pyx_n_s_rad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 329, __pyx_n_s_rad)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rad_2);
  __Pyx_GIVEREF(__pyx_n_s_rad_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 330, __pyx_n_s_rad_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rd);
  __Pyx_GIVEREF(__pyx_n_s_rd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 331, __pyx_n_s_rd)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rem_2);
  __Pyx_GIVEREF(__pyx_n_s_rem_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 332, __pyx_n_s_rem_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rod);
  __Pyx_GIVEREF(__pyx_n_s_rod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 333, __pyx_n_s_rod)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rpm);
  __Pyx_GIVEREF(__pyx_n_s_rpm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 334, __pyx_n_s_rpm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_s_2);
  __Pyx_GIVEREF(__pyx_n_s_s_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 335, __pyx_n_s_s_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sb);
  __Pyx_GIVEREF(__pyx_n_s_sb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 336, __pyx_n_s_sb)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sd);
  __Pyx_GIVEREF(__pyx_n_s_sd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 337, __pyx_n_s_sd)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sigma);
  __Pyx_GIVEREF(__pyx_n_s_sigma);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 338, __pyx_n_s_sigma)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_slug);
  __Pyx_GIVEREF(__pyx_n_s_slug);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 339, __pyx_n_s_slug)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sr);
  __Pyx_GIVEREF(__pyx_n_s_sr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 340, __pyx_n_s_sr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_st);
  __Pyx_GIVEREF(__pyx_n_s_st);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 341, __pyx_n_s_st)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_syr);
  __Pyx_GIVEREF(__pyx_n_s_syr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 342, __pyx_n_s_syr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_t);
  __Pyx_GIVEREF(__pyx_n_s_t);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 343, __pyx_n_s_t)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tbsp);
  __Pyx_GIVEREF(__pyx_n_s_tbsp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 344, __pyx_n_s_tbsp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tec);
  __Pyx_GIVEREF(__pyx_n_s_tec);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 345, __pyx_n_s_tec)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tep);
  __Pyx_GIVEREF(__pyx_n_s_tep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 346, __pyx_n_s_tep)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tex);
  __Pyx_GIVEREF(__pyx_n_s_tex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 347, __pyx_n_s_tex)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_therm);
  __Pyx_GIVEREF(__pyx_n_s_therm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 348, __pyx_n_s_therm)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ton);
  __Pyx_GIVEREF(__pyx_n_s_ton);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 349, __pyx_n_s_ton)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tonUK);
  __Pyx_GIVEREF(__pyx_n_s_tonUK);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 350, __pyx_n_s_tonUK)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_torr);
  __Pyx_GIVEREF(__pyx_n_s_torr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 351, __pyx_n_s_torr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tr);
  __Pyx_GIVEREF(__pyx_n_s_tr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 352, __pyx_n_s_tr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tsp);
  __Pyx_GIVEREF(__pyx_n_s_tsp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 353, __pyx_n_s_tsp)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_twopi);
  __Pyx_GIVEREF(__pyx_n_s_twopi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 354, __pyx_n_s_twopi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_u);
  __Pyx_GIVEREF(__pyx_n_s_u);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 355, __pyx_n_s_u)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_yd);
  __Pyx_GIVEREF(__pyx_n_s_yd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 356, __pyx_n_s_yd)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_yd_2);
  __Pyx_GIVEREF(__pyx_kp_s_yd_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 357, __pyx_kp_s_yd_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s_yd_3);
  __Pyx_GIVEREF(__pyx_kp_s_yd_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 358, __pyx_kp_s_yd_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_yr);
  __Pyx_GIVEREF(__pyx_n_s_yr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 359, __pyx_n_s_yr)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1696);
  __Pyx_GIVEREF(__pyx_kp_s__1696);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 360, __pyx_kp_s__1696)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1697);
  __Pyx_GIVEREF(__pyx_kp_s__1697);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 361, __pyx_kp_s__1697)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_assert);
  __Pyx_GIVEREF(__pyx_n_s_assert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 362, __pyx_n_s_assert)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_affichage);
  __Pyx_GIVEREF(__pyx_n_s_affichage);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 363, __pyx_n_s_affichage)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_alors);
  __Pyx_GIVEREF(__pyx_n_s_alors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 364, __pyx_n_s_alors)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_animate);
  __Pyx_GIVEREF(__pyx_n_s_animate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 365, __pyx_n_s_animate)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_animate3d);
  __Pyx_GIVEREF(__pyx_n_s_animate3d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 366, __pyx_n_s_animate3d)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_animation);
  __Pyx_GIVEREF(__pyx_n_s_animation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 367, __pyx_n_s_animation)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_approx_mode);
  __Pyx_GIVEREF(__pyx_n_s_approx_mode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 368, __pyx_n_s_approx_mode)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_archive);
  __Pyx_GIVEREF(__pyx_n_s_archive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 369, __pyx_n_s_archive)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_args);
  __Pyx_GIVEREF(__pyx_n_s_args);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 370, __pyx_n_s_args)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_as_function_of);
  __Pyx_GIVEREF(__pyx_n_s_as_function_of);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 371, __pyx_n_s_as_function_of)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_asc);
  __Pyx_GIVEREF(__pyx_n_s_asc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 372, __pyx_n_s_asc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_asec);
  __Pyx_GIVEREF(__pyx_n_s_asec);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 373, __pyx_n_s_asec)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_assign);
  __Pyx_GIVEREF(__pyx_n_s_assign);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 374, __pyx_n_s_assign)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_backquote);
  __Pyx_GIVEREF(__pyx_n_s_backquote);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 375, __pyx_n_s_backquote)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_begin);
  __Pyx_GIVEREF(__pyx_n_s_begin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 376, __pyx_n_s_begin)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_black);
  __Pyx_GIVEREF(__pyx_n_s_black);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 377, __pyx_n_s_black)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_blanc);
  __Pyx_GIVEREF(__pyx_n_s_blanc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 378, __pyx_n_s_blanc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bleu);
  __Pyx_GIVEREF(__pyx_n_s_bleu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 379, __pyx_n_s_bleu)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bloc);
  __Pyx_GIVEREF(__pyx_n_s_bloc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 380, __pyx_n_s_bloc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_blue);
  __Pyx_GIVEREF(__pyx_n_s_blue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 381, __pyx_n_s_blue)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_breakpoint);
  __Pyx_GIVEREF(__pyx_n_s_breakpoint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 382, __pyx_n_s_breakpoint)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_by);
  __Pyx_GIVEREF(__pyx_n_s_by);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 383, __pyx_n_s_by)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_c1oc2);
  __Pyx_GIVEREF(__pyx_n_s_c1oc2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 384, __pyx_n_s_c1oc2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_c1op2);
  __Pyx_GIVEREF(__pyx_n_s_c1op2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 385, __pyx_n_s_c1op2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cache_tortue);
  __Pyx_GIVEREF(__pyx_n_s_cache_tortue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 386, __pyx_n_s_cache_tortue)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cap);
  __Pyx_GIVEREF(__pyx_n_s_cap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 387, __pyx_n_s_cap)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cap_flat_line);
  __Pyx_GIVEREF(__pyx_n_s_cap_flat_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 388, __pyx_n_s_cap_flat_line)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cap_round_line);
  __Pyx_GIVEREF(__pyx_n_s_cap_round_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 389, __pyx_n_s_cap_round_line)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cap_square_line);
  __Pyx_GIVEREF(__pyx_n_s_cap_square_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 390, __pyx_n_s_cap_square_line)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_case);
  __Pyx_GIVEREF(__pyx_n_s_case);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 391, __pyx_n_s_case)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cat);
  __Pyx_GIVEREF(__pyx_n_s_cat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 392, __pyx_n_s_cat)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_catch);
  __Pyx_GIVEREF(__pyx_n_s_catch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 393, __pyx_n_s_catch)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cd_2);
  __Pyx_GIVEREF(__pyx_n_s_cd_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 394, __pyx_n_s_cd_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_choosebox);
  __Pyx_GIVEREF(__pyx_n_s_choosebox);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 395, __pyx_n_s_choosebox)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_click);
  __Pyx_GIVEREF(__pyx_n_s_click);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 396, __pyx_n_s_click)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_close);
  __Pyx_GIVEREF(__pyx_n_s_close);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 397, __pyx_n_s_close)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complex_mode);
  __Pyx_GIVEREF(__pyx_n_s_complex_mode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 398, __pyx_n_s_complex_mode)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_de);
  __Pyx_GIVEREF(__pyx_n_s_de);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 399, __pyx_n_s_de)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_del);
  __Pyx_GIVEREF(__pyx_n_s_del);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 400, __pyx_n_s_del)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_debug);
  __Pyx_GIVEREF(__pyx_n_s_debug);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 401, __pyx_n_s_debug)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_default);
  __Pyx_GIVEREF(__pyx_n_s_default);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 402, __pyx_n_s_default)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_div);
  __Pyx_GIVEREF(__pyx_n_s_div);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 403, __pyx_n_s_div)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_double_2);
  __Pyx_GIVEREF(__pyx_n_s_double_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 404, __pyx_n_s_double_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ecris);
  __Pyx_GIVEREF(__pyx_n_s_ecris);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 405, __pyx_n_s_ecris)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_efface);
  __Pyx_GIVEREF(__pyx_n_s_efface);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 406, __pyx_n_s_efface)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_elif);
  __Pyx_GIVEREF(__pyx_n_s_elif);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 407, __pyx_n_s_elif)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_end);
  __Pyx_GIVEREF(__pyx_n_s_end);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 408, __pyx_n_s_end)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_end_for);
  __Pyx_GIVEREF(__pyx_n_s_end_for);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 409, __pyx_n_s_end_for)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_end_if);
  __Pyx_GIVEREF(__pyx_n_s_end_if);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 410, __pyx_n_s_end_if)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_end_while);
  __Pyx_GIVEREF(__pyx_n_s_end_while);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 411, __pyx_n_s_end_while)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 412, __pyx_n_s_epaisseur)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_1);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 413, __pyx_n_s_epaisseur_ligne_1)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_2);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 414, __pyx_n_s_epaisseur_ligne_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_3);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 415, __pyx_n_s_epaisseur_ligne_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_4);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 416, __pyx_n_s_epaisseur_ligne_4)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_5);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 417, __pyx_n_s_epaisseur_ligne_5)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_6);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 418, __pyx_n_s_epaisseur_ligne_6)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_ligne_7);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_ligne_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 419, __pyx_n_s_epaisseur_ligne_7)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_1);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 420, __pyx_n_s_epaisseur_point_1)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_2);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 421, __pyx_n_s_epaisseur_point_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_3);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 422, __pyx_n_s_epaisseur_point_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_4);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 423, __pyx_n_s_epaisseur_point_4)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_5);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 424, __pyx_n_s_epaisseur_point_5)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_6);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 425, __pyx_n_s_epaisseur_point_6)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epaisseur_point_7);
  __Pyx_GIVEREF(__pyx_n_s_epaisseur_point_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 426, __pyx_n_s_epaisseur_point_7)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_erase);
  __Pyx_GIVEREF(__pyx_n_s_erase);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 427, __pyx_n_s_erase)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_erase3d);
  __Pyx_GIVEREF(__pyx_n_s_erase3d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 428, __pyx_n_s_erase3d)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_est_cocyclique);
  __Pyx_GIVEREF(__pyx_n_s_est_cocyclique);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 429, __pyx_n_s_est_cocyclique)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_est_inclus);
  __Pyx_GIVEREF(__pyx_n_s_est_inclus);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 430, __pyx_n_s_est_inclus)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_et);
  __Pyx_GIVEREF(__pyx_n_s_et);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 431, __pyx_n_s_et)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_faire);
  __Pyx_GIVEREF(__pyx_n_s_faire);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 432, __pyx_n_s_faire)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_faux);
  __Pyx_GIVEREF(__pyx_n_s_faux);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 433, __pyx_n_s_faux)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_feuille);
  __Pyx_GIVEREF(__pyx_n_s_feuille);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 434, __pyx_n_s_feuille)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ffaire);
  __Pyx_GIVEREF(__pyx_n_s_ffaire);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 435, __pyx_n_s_ffaire)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ffonction);
  __Pyx_GIVEREF(__pyx_n_s_ffonction);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 436, __pyx_n_s_ffonction)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fi);
  __Pyx_GIVEREF(__pyx_n_s_fi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 437, __pyx_n_s_fi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_filled);
  __Pyx_GIVEREF(__pyx_n_s_filled);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 438, __pyx_n_s_filled)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fin_enregistrement);
  __Pyx_GIVEREF(__pyx_n_s_fin_enregistrement);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 439, __pyx_n_s_fin_enregistrement)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_float);
  __Pyx_GIVEREF(__pyx_n_s_float);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 440, __pyx_n_s_float)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fonction);
  __Pyx_GIVEREF(__pyx_n_s_fonction);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 441, __pyx_n_s_fonction)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fopen);
  __Pyx_GIVEREF(__pyx_n_s_fopen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 442, __pyx_n_s_fopen)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_format);
  __Pyx_GIVEREF(__pyx_n_s_format);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 443, __pyx_n_s_format)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fpour);
  __Pyx_GIVEREF(__pyx_n_s_fpour);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 444, __pyx_n_s_fpour)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frame_3d);
  __Pyx_GIVEREF(__pyx_n_s_frame_3d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 445, __pyx_n_s_frame_3d)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frames);
  __Pyx_GIVEREF(__pyx_n_s_frames);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 446, __pyx_n_s_frames)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fsi);
  __Pyx_GIVEREF(__pyx_n_s_fsi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 447, __pyx_n_s_fsi)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ftantque);
  __Pyx_GIVEREF(__pyx_n_s_ftantque);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 448, __pyx_n_s_ftantque)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_func);
  __Pyx_GIVEREF(__pyx_n_s_func);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 449, __pyx_n_s_func)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_function);
  __Pyx_GIVEREF(__pyx_n_s_function);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 450, __pyx_n_s_function)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gauche);
  __Pyx_GIVEREF(__pyx_n_s_gauche);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 451, __pyx_n_s_gauche)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_ortho);
  __Pyx_GIVEREF(__pyx_n_s_gl_ortho);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 452, __pyx_n_s_gl_ortho)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_quaternion);
  __Pyx_GIVEREF(__pyx_n_s_gl_quaternion);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 453, __pyx_n_s_gl_quaternion)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_rotation);
  __Pyx_GIVEREF(__pyx_n_s_gl_rotation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 454, __pyx_n_s_gl_rotation)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_shownames);
  __Pyx_GIVEREF(__pyx_n_s_gl_shownames);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 455, __pyx_n_s_gl_shownames)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_texture);
  __Pyx_GIVEREF(__pyx_n_s_gl_texture);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 456, __pyx_n_s_gl_texture)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_x);
  __Pyx_GIVEREF(__pyx_n_s_gl_x);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 457, __pyx_n_s_gl_x)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_x_axis_color);
  __Pyx_GIVEREF(__pyx_n_s_gl_x_axis_color);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 458, __pyx_n_s_gl_x_axis_color)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_x_axis_name);
  __Pyx_GIVEREF(__pyx_n_s_gl_x_axis_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 459, __pyx_n_s_gl_x_axis_name)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_x_axis_unit);
  __Pyx_GIVEREF(__pyx_n_s_gl_x_axis_unit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 460, __pyx_n_s_gl_x_axis_unit)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_xtick);
  __Pyx_GIVEREF(__pyx_n_s_gl_xtick);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 461, __pyx_n_s_gl_xtick)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_y);
  __Pyx_GIVEREF(__pyx_n_s_gl_y);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 462, __pyx_n_s_gl_y)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_y_axis_color);
  __Pyx_GIVEREF(__pyx_n_s_gl_y_axis_color);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 463, __pyx_n_s_gl_y_axis_color)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_y_axis_name);
  __Pyx_GIVEREF(__pyx_n_s_gl_y_axis_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 464, __pyx_n_s_gl_y_axis_name)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_y_axis_unit);
  __Pyx_GIVEREF(__pyx_n_s_gl_y_axis_unit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 465, __pyx_n_s_gl_y_axis_unit)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_ytick);
  __Pyx_GIVEREF(__pyx_n_s_gl_ytick);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 466, __pyx_n_s_gl_ytick)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_z);
  __Pyx_GIVEREF(__pyx_n_s_gl_z);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 467, __pyx_n_s_gl_z)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_z_axis_color);
  __Pyx_GIVEREF(__pyx_n_s_gl_z_axis_color);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 468, __pyx_n_s_gl_z_axis_color)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_z_axis_name);
  __Pyx_GIVEREF(__pyx_n_s_gl_z_axis_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 469, __pyx_n_s_gl_z_axis_name)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_z_axis_unit);
  __Pyx_GIVEREF(__pyx_n_s_gl_z_axis_unit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 470, __pyx_n_s_gl_z_axis_unit)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_ztick);
  __Pyx_GIVEREF(__pyx_n_s_gl_ztick);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 471, __pyx_n_s_gl_ztick)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gnuplot);
  __Pyx_GIVEREF(__pyx_n_s_gnuplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 472, __pyx_n_s_gnuplot)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_goto);
  __Pyx_GIVEREF(__pyx_n_s_goto);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 473, __pyx_n_s_goto)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph2tex);
  __Pyx_GIVEREF(__pyx_n_s_graph2tex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 474, __pyx_n_s_graph2tex)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph3d2tex);
  __Pyx_GIVEREF(__pyx_n_s_graph3d2tex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 475, __pyx_n_s_graph3d2tex)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graphe);
  __Pyx_GIVEREF(__pyx_n_s_graphe);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 476, __pyx_n_s_graphe)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graphe3d);
  __Pyx_GIVEREF(__pyx_n_s_graphe3d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 477, __pyx_n_s_graphe3d)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graphe_probabiliste);
  __Pyx_GIVEREF(__pyx_n_s_graphe_probabiliste);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 478, __pyx_n_s_graphe_probabiliste)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graphe_suite);
  __Pyx_GIVEREF(__pyx_n_s_graphe_suite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 479, __pyx_n_s_graphe_suite)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_green);
  __Pyx_GIVEREF(__pyx_n_s_green);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 480, __pyx_n_s_green)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_grid_paper);
  __Pyx_GIVEREF(__pyx_n_s_grid_paper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 481, __pyx_n_s_grid_paper)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hidden_name);
  __Pyx_GIVEREF(__pyx_n_s_hidden_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 482, __pyx_n_s_hidden_name)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_identifier);
  __Pyx_GIVEREF(__pyx_n_s_identifier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 483, __pyx_n_s_identifier)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ifft);
  __Pyx_GIVEREF(__pyx_n_s_ifft);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 484, __pyx_n_s_ifft)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ifte);
  __Pyx_GIVEREF(__pyx_n_s_ifte);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 485, __pyx_n_s_ifte)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inputform);
  __Pyx_GIVEREF(__pyx_n_s_inputform);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 486, __pyx_n_s_inputform)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_intersect);
  __Pyx_GIVEREF(__pyx_n_s_intersect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 487, __pyx_n_s_intersect)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_included);
  __Pyx_GIVEREF(__pyx_n_s_is_included);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 488, __pyx_n_s_is_included)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jusqu_a);
  __Pyx_GIVEREF(__pyx_n_s_jusqu_a);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 489, __pyx_n_s_jusqu_a)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jusqua);
  __Pyx_GIVEREF(__pyx_n_s_jusqua);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 490, __pyx_n_s_jusqua)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jusque);
  __Pyx_GIVEREF(__pyx_n_s_jusque);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 491, __pyx_n_s_jusque)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_keep_algext);
  __Pyx_GIVEREF(__pyx_n_s_keep_algext);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 492, __pyx_n_s_keep_algext)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kill);
  __Pyx_GIVEREF(__pyx_n_s_kill);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 493, __pyx_n_s_kill)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_label);
  __Pyx_GIVEREF(__pyx_n_s_label);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 494, __pyx_n_s_label)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_labels);
  __Pyx_GIVEREF(__pyx_n_s_labels);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 495, __pyx_n_s_labels)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_len);
  __Pyx_GIVEREF(__pyx_n_s_len);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 496, __pyx_n_s_len)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_leve_crayon);
  __Pyx_GIVEREF(__pyx_n_s_leve_crayon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 497, __pyx_n_s_leve_crayon)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_1);
  __Pyx_GIVEREF(__pyx_n_s_line_width_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 498, __pyx_n_s_line_width_1)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_2);
  __Pyx_GIVEREF(__pyx_n_s_line_width_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 499, __pyx_n_s_line_width_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_3);
  __Pyx_GIVEREF(__pyx_n_s_line_width_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 500, __pyx_n_s_line_width_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_4);
  __Pyx_GIVEREF(__pyx_n_s_line_width_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 501, __pyx_n_s_line_width_4)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_5);
  __Pyx_GIVEREF(__pyx_n_s_line_width_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 502, __pyx_n_s_line_width_5)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_6);
  __Pyx_GIVEREF(__pyx_n_s_line_width_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 503, __pyx_n_s_line_width_6)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_width_7);
  __Pyx_GIVEREF(__pyx_n_s_line_width_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 504, __pyx_n_s_line_width_7)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lis);
  __Pyx_GIVEREF(__pyx_n_s_lis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 505, __pyx_n_s_lis)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_local);
  __Pyx_GIVEREF(__pyx_n_s_local);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 506, __pyx_n_s_local)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minus);
  __Pyx_GIVEREF(__pyx_n_s_minus);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 507, __pyx_n_s_minus)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mod);
  __Pyx_GIVEREF(__pyx_n_s_mod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 508, __pyx_n_s_mod)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_noir);
  __Pyx_GIVEREF(__pyx_n_s_noir);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 509, __pyx_n_s_noir)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nom_cache);
  __Pyx_GIVEREF(__pyx_n_s_nom_cache);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 510, __pyx_n_s_nom_cache)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_non);
  __Pyx_GIVEREF(__pyx_n_s_non);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 511, __pyx_n_s_non)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_od);
  __Pyx_GIVEREF(__pyx_n_s_od);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 512, __pyx_n_s_od)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_option);
  __Pyx_GIVEREF(__pyx_n_s_option);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 513, __pyx_n_s_option)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_otherwise);
  __Pyx_GIVEREF(__pyx_n_s_otherwise);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 514, __pyx_n_s_otherwise)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ou);
  __Pyx_GIVEREF(__pyx_n_s_ou);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 515, __pyx_n_s_ou)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pas);
  __Pyx_GIVEREF(__pyx_n_s_pas);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 516, __pyx_n_s_pas)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_arret);
  __Pyx_GIVEREF(__pyx_n_s_point_arret);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 517, __pyx_n_s_point_arret)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_carre);
  __Pyx_GIVEREF(__pyx_n_s_point_carre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 518, __pyx_n_s_point_carre)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_croix);
  __Pyx_GIVEREF(__pyx_n_s_point_croix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 519, __pyx_n_s_point_croix)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_div);
  __Pyx_GIVEREF(__pyx_n_s_point_div);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 520, __pyx_n_s_point_div)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_etoile);
  __Pyx_GIVEREF(__pyx_n_s_point_etoile);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 521, __pyx_n_s_point_etoile)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_invisible);
  __Pyx_GIVEREF(__pyx_n_s_point_invisible);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 522, __pyx_n_s_point_invisible)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_losange);
  __Pyx_GIVEREF(__pyx_n_s_point_losange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 523, __pyx_n_s_point_losange)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_milieu);
  __Pyx_GIVEREF(__pyx_n_s_point_milieu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 524, __pyx_n_s_point_milieu)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_plus);
  __Pyx_GIVEREF(__pyx_n_s_point_plus);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 525, __pyx_n_s_point_plus)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_point);
  __Pyx_GIVEREF(__pyx_n_s_point_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 526, __pyx_n_s_point_point)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_polaire);
  __Pyx_GIVEREF(__pyx_n_s_point_polaire);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 527, __pyx_n_s_point_polaire)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_triangle);
  __Pyx_GIVEREF(__pyx_n_s_point_triangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 528, __pyx_n_s_point_triangle)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_1);
  __Pyx_GIVEREF(__pyx_n_s_point_width_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 529, __pyx_n_s_point_width_1)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_2);
  __Pyx_GIVEREF(__pyx_n_s_point_width_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 530, __pyx_n_s_point_width_2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_3);
  __Pyx_GIVEREF(__pyx_n_s_point_width_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 531, __pyx_n_s_point_width_3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_4);
  __Pyx_GIVEREF(__pyx_n_s_point_width_4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 532, __pyx_n_s_point_width_4)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_5);
  __Pyx_GIVEREF(__pyx_n_s_point_width_5);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 533, __pyx_n_s_point_width_5)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_6);
  __Pyx_GIVEREF(__pyx_n_s_point_width_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 534, __pyx_n_s_point_width_6)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point_width_7);
  __Pyx_GIVEREF(__pyx_n_s_point_width_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 535, __pyx_n_s_point_width_7)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pour);
  __Pyx_GIVEREF(__pyx_n_s_pour);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 536, __pyx_n_s_pour)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_proc);
  __Pyx_GIVEREF(__pyx_n_s_proc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 537, __pyx_n_s_proc)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_program);
  __Pyx_GIVEREF(__pyx_n_s_program);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 538, __pyx_n_s_program)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quadrant1);
  __Pyx_GIVEREF(__pyx_n_s_quadrant1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 539, __pyx_n_s_quadrant1)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quadrant2);
  __Pyx_GIVEREF(__pyx_n_s_quadrant2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 540, __pyx_n_s_quadrant2)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quadrant3);
  __Pyx_GIVEREF(__pyx_n_s_quadrant3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 541, __pyx_n_s_quadrant3)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quadrant4);
  __Pyx_GIVEREF(__pyx_n_s_quadrant4);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 542, __pyx_n_s_quadrant4)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_range);
  __Pyx_GIVEREF(__pyx_n_s_range);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 543, __pyx_n_s_range)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_redim);
  __Pyx_GIVEREF(__pyx_n_s_redim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 544, __pyx_n_s_redim)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_repeat);
  __Pyx_GIVEREF(__pyx_n_s_repeat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 545, __pyx_n_s_repeat)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_repete);
  __Pyx_GIVEREF(__pyx_n_s_repete);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 546, __pyx_n_s_repete)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_repeter);
  __Pyx_GIVEREF(__pyx_n_s_repeter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 547, __pyx_n_s_repeter)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_replace);
  __Pyx_GIVEREF(__pyx_n_s_replace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 548, __pyx_n_s_replace)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_restart);
  __Pyx_GIVEREF(__pyx_n_s_restart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 549, __pyx_n_s_restart)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rouge);
  __Pyx_GIVEREF(__pyx_n_s_rouge);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 550, __pyx_n_s_rouge)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_saisir);
  __Pyx_GIVEREF(__pyx_n_s_saisir);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 551, __pyx_n_s_saisir)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_saisir_chaine);
  __Pyx_GIVEREF(__pyx_n_s_saisir_chaine);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 552, __pyx_n_s_saisir_chaine)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sauve);
  __Pyx_GIVEREF(__pyx_n_s_sauve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 553, __pyx_n_s_sauve)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_save_history);
  __Pyx_GIVEREF(__pyx_n_s_save_history);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 554, __pyx_n_s_save_history)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_scale);
  __Pyx_GIVEREF(__pyx_n_s_scale);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 555, __pyx_n_s_scale)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_scaleadd);
  __Pyx_GIVEREF(__pyx_n_s_scaleadd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 556, __pyx_n_s_scaleadd)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_si);
  __Pyx_GIVEREF(__pyx_n_s_si);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 557, __pyx_n_s_si)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sinon);
  __Pyx_GIVEREF(__pyx_n_s_sinon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 558, __pyx_n_s_sinon)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_size);
  __Pyx_GIVEREF(__pyx_n_s_size);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 559, __pyx_n_s_size)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_stack);
  __Pyx_GIVEREF(__pyx_n_s_stack);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 560, __pyx_n_s_stack)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_step);
  __Pyx_GIVEREF(__pyx_n_s_step);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 561, __pyx_n_s_step)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_switch);
  __Pyx_GIVEREF(__pyx_n_s_switch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 562, __pyx_n_s_switch)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tantque);
  __Pyx_GIVEREF(__pyx_n_s_tantque);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 563, __pyx_n_s_tantque)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_test);
  __Pyx_GIVEREF(__pyx_n_s_test);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 564, __pyx_n_s_test)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_textinput);
  __Pyx_GIVEREF(__pyx_n_s_textinput);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 565, __pyx_n_s_textinput)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_then);
  __Pyx_GIVEREF(__pyx_n_s_then);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 566, __pyx_n_s_then)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_thiele);
  __Pyx_GIVEREF(__pyx_n_s_thiele);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 567, __pyx_n_s_thiele)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_time);
  __Pyx_GIVEREF(__pyx_n_s_time);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 568, __pyx_n_s_time)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_to);
  __Pyx_GIVEREF(__pyx_n_s_to);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 569, __pyx_n_s_to)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_union);
  __Pyx_GIVEREF(__pyx_n_s_union);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 570, __pyx_n_s_union)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_until);
  __Pyx_GIVEREF(__pyx_n_s_until);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 571, __pyx_n_s_until)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_var);
  __Pyx_GIVEREF(__pyx_n_s_var);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 572, __pyx_n_s_var)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vector);
  __Pyx_GIVEREF(__pyx_n_s_vector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 573, __pyx_n_s_vector)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vers);
  __Pyx_GIVEREF(__pyx_n_s_vers);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 574, __pyx_n_s_vers)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vert);
  __Pyx_GIVEREF(__pyx_n_s_vert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 575, __pyx_n_s_vert)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vrai);
  __Pyx_GIVEREF(__pyx_n_s_vrai);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 576, __pyx_n_s_vrai)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_watch);
  __Pyx_GIVEREF(__pyx_n_s_watch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 577, __pyx_n_s_watch)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_when);
  __Pyx_GIVEREF(__pyx_n_s_when);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 578, __pyx_n_s_when)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_white);
  __Pyx_GIVEREF(__pyx_n_s_white);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 579, __pyx_n_s_white)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_with_sqrt);
  __Pyx_GIVEREF(__pyx_n_s_with_sqrt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 580, __pyx_n_s_with_sqrt)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_write);
  __Pyx_GIVEREF(__pyx_n_s_write);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 581, __pyx_n_s_write)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_wz_certificate);
  __Pyx_GIVEREF(__pyx_n_s_wz_certificate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 582, __pyx_n_s_wz_certificate)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_xor);
  __Pyx_GIVEREF(__pyx_n_s_xor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 583, __pyx_n_s_xor)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_yellow);
  __Pyx_GIVEREF(__pyx_n_s_yellow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 584, __pyx_n_s_yellow)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1698);
  __Pyx_GIVEREF(__pyx_kp_s__1698);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 585, __pyx_kp_s__1698)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1699);
  __Pyx_GIVEREF(__pyx_kp_s__1699);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 586, __pyx_kp_s__1699)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_kp_s__1700);
  __Pyx_GIVEREF(__pyx_kp_s__1700);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 587, __pyx_kp_s__1700)) __PYX_ERR(5, 4, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_expression);
  __Pyx_GIVEREF(__pyx_n_s_expression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 588, __pyx_n_s_expression)) __PYX_ERR(5, 4, __pyx_L1_error);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_toremove, __pyx_t_2) < 0) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/keywords.pxi":6
 * toremove = ['!', '!=', '#', '$', '%', '/%', '%/', '%{%}', '&&', '&*', '&^', "'", '()', '*', '*=', '+', '-', '+&', '+=', '+infinity', '-<', '-=', '->', '-infinity', '.*', '.+', '.-', './', '.^', '/=', ':=', '<', '<=', '=', '=<', '==', '=>', '>', '>=', '?', '@', '@@', 'ACOSH', 'ACOT', 'ACSC', 'ASEC', 'ASIN', 'ASINH', 'ATAN', 'ATANH', 'COND', 'COS', 'COSH', 'COT', 'CSC', 'CST', 'Celsius2Fahrenheit', 'ClrDraw', 'ClrGraph', 'ClrIO', 'CyclePic', 'DIGITS', 'DOM_COMPLEX', 'DOM_FLOAT', 'DOM_FUNC', 'DOM_IDENT', 'DOM_INT', 'DOM_LIST', 'DOM_RAT', 'DOM_STRING', 'DOM_SYMBOLIC', 'DOM_int', 'DelFold', 'DelVar', 'Det', 'Dialog', 'Digits', 'Disp', 'DispG', 'DispHome', 'DrawFunc', 'DrawInv', 'DrawParm', 'DrawPol', 'DrawSlp', 'DropDown', 'DrwCtour', 'ERROR', 'EXP', 'EndDlog', 'FALSE', 'False', 'Fahrenheit2Celsius', 'Fill', 'Gcd', 'GetFold', 'Graph', 'IFTE', 'Input', 'InputStr', 'Int', 'Inverse', 'LN', 'LQ', 'LSQ', 'NORMALD', 'NewFold', 'NewPic', 'Nullspace', 'Output', 'Ox_2d_unit_vector', 'Ox_3d_unit_vector', 'Oy_2d_unit_vector', 'Oy_3d_unit_vector', 'Oz_3d_unit_vector', 'Pause', 'PopUp', 'Quo', 'REDIM', 'REPLACE', 'RclPic', 'Rem', 'Resultant', 'RplcPic', 'Rref', 'SCALE', 'SCALEADD', 'SCHUR', 'SIN', 'SVD', 'SVL', 'SWAPCOL', 'SWAPROW', 'SetFold', 'Si', 'StoPic', 'Store', 'TAN', 'TRUE', 'True', 'TeX', 'Text', 'Title', 'Unarchiv', 'WAIT', '^', '_(cm/s)', '_(ft/s)', '_(ft*lb)', '_(m/s)', '_(m/s^2)', '_(rad/s)', '_(rad/s^2)', '_(tr/min)', '_(tr/s)', '_A', '_Angstrom', '_Bq', '_Btu', '_Ci', '_F', '_F_', '_Fdy', '_G_', '_Gal', '_Gy', '_H', '_Hz', '_I0_', '_J', '_K', '_Kcal', '_MHz', '_MW', '_MeV', '_N', '_NA_', '_Ohm', '_P', '_PSun_', '_Pa', '_R', '_REarth_', '_RSun_', '_R_', '_Rankine', '_Rinfinity_', '_S', '_St', '_StdP_', '_StdT_', '_Sv', '_T', '_V', '_Vm_', '_W', '_Wb', '_Wh', '_a', '_a0_', '_acre', '_alpha_', '_angl_', '_arcmin', '_arcs', '_atm', '_au', '_b', '_bar', '_bbl', '_bblep', '_bu', '_buUS', '_c3_', '_c_', '_cal', '_cd', '_chain', '_cm', '_cm^2', '_cm^3', '_ct', '_cu', '_d', '_dB', '_deg', '_degreeF', '_dyn', '_eV', '_epsilon0_', '_epsilon0q_', '_epsilonox_', '_epsilonsi_', '_erg', '_f0_', '_fath', '_fbm', '_fc', '_fermi', '_flam', '_fm', '_ft', '_ft*lb', '_ftUS', '_ft^2', '_ft^3', '_g', '_g_', '_ga', '_galC', '_galUK', '_galUS', '_gf', '_gmol', '_gon', '_grad', '_grain', '_h', '_h_', '_ha', '_hbar_', '_hp', '_in', '_inH20', '_inHg', '_in^2', '_in^3', '_j', '_kWh', '_k_', '_kg', '_kip', '_km', '_km^2', '_knot', '_kph', '_kq_', '_l', '_lam', '_lambda0_', '_lambdac_', '_lb', '_lbf', '_lbmol', '_lbt', '_lep', '_liqpt', '_lm', '_lx', '_lyr', '_m', '_mEarth_', '_m^2', '_m^3', '_me_', '_mho', '_miUS', '_miUS^2', '_mi^2', '_mil', '_mile', '_mille', '_ml', '_mm', '_mmHg', '_mn', '_mol', '_mp_', '_mph', '_mpme_', '_mu0_', '_muB_', '_muN_', '_oz', '_ozUK', '_ozfl', '_ozt', '_pc', '_pdl', '_ph', '_phi_', '_pk', '_psi', '_ptUK', '_q_', '_qe_', '_qepsilon0_', '_qme_', '_qt', '_rad', '_rad_', '_rd', '_rem', '_rod', '_rpm', '_s', '_sb', '_sd_', '_sigma_', '_slug', '_sr', '_st', '_syr_', '_t', '_tbsp', '_tec', '_tep', '_tex', '_therm', '_ton', '_tonUK', '_torr', '_tr', '_tsp', '_twopi_', '_u', '_yd', '_yd^2', '_yd^3', '_yr', '_', '_', 'assert', 'affichage', 'alors', 'animate', 'animate3d', 'animation', 'approx_mode', 'archive', 'args', 'as_function_of', 'asc', 'asec', 'assign', 'backquote', 'begin', 'black', 'blanc', 'bleu', 'bloc', 'blue', 'breakpoint', 'by', 'c1oc2', 'c1op2', 'cache_tortue', 'cap', 'cap_flat_line', 'cap_round_line', 'cap_square_line', 'case', 'cat', 'catch', 'cd', 'choosebox', 'click', 'close', 'complex_mode', 'de', 'del', 'debug', 'default', 'div', 'double', 'ecris', 'efface', 'elif', 'end', 'end_for', 'end_if', 'end_while', 'epaisseur', 'epaisseur_ligne_1', 'epaisseur_ligne_2', 'epaisseur_ligne_3', 'epaisseur_ligne_4', 'epaisseur_ligne_5', 'epaisseur_ligne_6', 'epaisseur_ligne_7', 'epaisseur_point_1', 'epaisseur_point_2', 'epaisseur_point_3', 'epaisseur_point_4', 'epaisseur_point_5', 'epaisseur_point_6', 'epaisseur_point_7', 'erase', 'erase3d', 'est_cocyclique', 'est_inclus', 'et', 'faire', 'faux', 'feuille', 'ffaire', 'ffonction', 'fi', 'filled', 'fin_enregistrement', 'float', 'fonction', 'fopen', 'format', 'fpour', 'frame_3d', 'frames', 'fsi', 'ftantque', 'func', 'function', 'gauche', 'gl_ortho', 'gl_quaternion', 'gl_rotation', 'gl_shownames', 'gl_texture', 'gl_x', 'gl_x_axis_color', 'gl_x_axis_name', 'gl_x_axis_unit', 'gl_xtick', 'gl_y', 'gl_y_axis_color', 'gl_y_axis_name', 'gl_y_axis_unit', 'gl_ytick', 'gl_z', 'gl_z_axis_color', 'gl_z_axis_name', 'gl_z_axis_unit', 'gl_ztick', 'gnuplot', 'goto', 'graph2tex', 'graph3d2tex', 'graphe', 'graphe3d', 'graphe_probabiliste', 'graphe_suite', 'green', 'grid_paper', 'hidden_name', 'identifier', 'ifft', 'ifte', 'inputform', 'intersect', 'is_included', 'jusqu_a', 'jusqua', 'jusque', 'keep_algext', 'kill', 'label', 'labels', 'len', 'leve_crayon', 'line_width_1', 'line_width_2', 'line_width_3', 'line_width_4', 'line_width_5', 'line_width_6', 'line_width_7', 'lis', 'local', 'minus', 'mod', 'noir', 'nom_cache', 'non', 'od', 'option', 'otherwise', 'ou', 'pas', 'point_arret', 'point_carre', 'point_croix', 'point_div', 'point_etoile', 'point_invisible', 'point_losange', 'point_milieu', 'point_plus', 'point_point', 'point_polaire', 'point_triangle', 'point_width_1', 'point_width_2', 'point_width_3', 'point_width_4', 'point_width_5', 'point_width_6', 'point_width_7', 'pour', 'proc', 'program', 'quadrant1', 'quadrant2', 'quadrant3', 'quadrant4', 'range', 'redim', 'repeat', 'repete', 'repeter', 'replace', 'restart', 'rouge', 'saisir', 'saisir_chaine', 'sauve', 'save_history', 'scale', 'scaleadd', 'si', 'sinon', 'size', 'stack', 'step', 'switch', 'tantque', 'test', 'textinput', 'then', 'thiele', 'time', 'to', 'union', 'until', 'var', 'vector', 'vers', 'vert', 'vrai', 'watch', 'when', 'white', 'with_sqrt', 'write', 'wz_certificate', 'xor', 'yellow', '{}', '|', '||', 'expression']
 * 
 * nonevaluable = ['e', 'pi']             # <<<<<<<<<<<<<<
 * 
 * moremethods = ['type', 'zip']
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_e);
  __Pyx_GIVEREF(__pyx_n_s_e);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_e)) __PYX_ERR(5, 6, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pi);
  __Pyx_GIVEREF(__pyx_n_s_pi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_pi)) __PYX_ERR(5, 6, __pyx_L1_error);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_nonevaluable, __pyx_t_2) < 0) __PYX_ERR(5, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/keywords.pxi":8
 * nonevaluable = ['e', 'pi']
 * 
 * moremethods = ['type', 'zip']             # <<<<<<<<<<<<<<
 * 
 * mostkeywords = ['Airy_Ai', 'Airy_Bi', 'Archive', 'BesselJ', 'BesselY', 'Beta', 'BlockDiagonal', 'Ci', 'Circle', 'Col', 'CopyVar', 'Dirac', 'Ei', 'Factor', 'Fourier', 'GF', 'Gamma', 'Heaviside', 'Heaviside2sign', 'Hilbert', 'JordanBlock', 'LU', 'LambertW', 'Li', 'Line', 'LineHorz', 'LineTan', 'LineVert', 'MSE', 'Phi', 'Pi', 'Psi', 'QR', 'RandSeed', 'ReLU', 'Row', 'SortA', 'SortD', 'UTPC', 'UTPF', 'UTPN', 'UTPT', 'VARS', 'VAS', 'VAS_positive', 'Zeta', 'a2q', 'abcuv', 'about', 'abs', 'abscissa', 'accumulate_head_tail', 'acos', 'acos2asin', 'acos2atan', 'acosh', 'acot', 'acsc', 'acyclic', 'adaptive', 'add', 'add_arc', 'add_edge', 'add_vertex', 'additionally', 'addtable', 'adjacency_matrix', 'adjoint_matrix', 'affix', 'algsubs', 'algvar', 'all_trig_solutions', 'allpairs_distance', 'alog10', 'altitude', 'angle', 'angle_radian', 'angleat', 'angleatraw', 'ans', 'antiprism_graph', 'append', 'apply', 'approx', 'arc', 'arcLen', 'arccos', 'arccosh', 'arclen', 'arcsin', 'arcsinh', 'arctan', 'arctanh', 'area', 'areaat', 'areaatraw', 'areaplot', 'arg', 'array', 'arrivals', 'articulation_points', 'asin', 'asin2acos', 'asin2atan', 'asinh', 'assign_edge_weights', 'assume', 'at', 'atan', 'atan2', 'atan2acos', 'atan2asin', 'atanh', 'atrig2ln', 'augment', 'auto_correlation', 'autosimplify', 'avance', 'avgRC', 'axes', 'axis', 'back', 'backward', 'baisse_crayon', 'bandwidth', 'bar_plot', 'barplot', 'bartlett_hann_window', 'barycenter', 'base', 'basis', 'batons', 'bellman_ford', 'berlekamp_massey', 'bernoulli', 'bernoulli_mod', 'besselJ', 'besselY', 'betad', 'betad_cdf', 'betad_icdf', 'betavariate', 'betweenness_centrality', 'bezier', 'bezout_entiers', 'bezoutian', 'biconnected_components', 'binomial', 'binomial_cdf', 'binomial_icdf', 'bins', 'bipartite', 'bipartite_matching', 'bisection_solver', 'bisector', 'bit_depth', 'bitand', 'bitor', 'bitxor', 'blackman_harris_window', 'blackman_window', 'block_size', 'blockmatrix', 'bohman_window', 'border', 'box_constraints', 'boxcar', 'boxwhisker', 'brent_solver', 'brown', 'bspline', 'bvpsolve', 'cFactor', 'cSolve', 'cZeros', 'camembert', 'canonical_form', 'canonical_labeling', 'cartesian_product', 'cauchy', 'cauchy_cdf', 'cauchy_icdf', 'cauchyd', 'cauchyd_cdf', 'cauchyd_icdf', 'cdf', 'ceil', 'ceiling', 'center', 'center2interval', 'centered_cube', 'centered_tetrahedron', 'cfactor', 'cfsolve', 'changebase', 'channel_data', 'channels', 'char', 'charpoly', 'chinrem', 'chisquare', 'chisquare_cdf', 'chisquare_icdf', 'chisquared', 'chisquared_cdf', 'chisquared_icdf', 'chisquaret', 'choice', 'cholesky', 'chr', 'chrem', 'chromatic_index', 'chromatic_number', 'chromatic_polynomial', 'circle', 'circumcircle', 'classes', 'clear', 'clique_cover', 'clique_cover_number', 'clique_number', 'closeness_centrality', 'cluster', 'clustering_coefficient', 'coeff', 'coeffs', 'col', 'colDim', 'colNorm', 'colSwap', 'coldim', 'collect', 'colnorm', 'color', 'colormap', 'colspace', 'colswap', 'comDenom', 'comb', 'combine', 'comment', 'common_perpendicular', 'companion', 'compare', 'complete_binary_tree', 'complete_graph', 'complete_kary_tree', 'complex', 'complex_variables', 'complexroot', 'concat', 'cond', 'condensation', 'cone', 'confrac', 'conic', 'conj', 'conjugate_equation', 'conjugate_gradient', 'connected', 'connected_components', 'cont', 'contains', 'content', 'contourplot', 'contract_edge', 'contract_subgraph', 'convert', 'convertir', 'convex', 'convexhull', 'convolution', 'coordinates', 'copy', 'correlation', 'cos', 'cos2sintan', 'cosh', 'cosine_window', 'cot', 'cote', 'count', 'count_eq', 'count_inf', 'count_sup', 'courbe_parametrique', 'courbe_polaire', 'covariance', 'covariance_correlation', 'cpartfrac', 'crationalroot', 'crayon', 'createwav', 'cross', 'crossP', 'cross_correlation', 'cross_entropy', 'cross_point', 'cross_ratio', 'crossproduct', 'csc', 'csolve', 'csv2gen', 'cube', 'cumSum', 'cumsum', 'cumulated_frequencies', 'curl', 'current_sheet', 'curvature', 'curve', 'cyan', 'cycle2perm', 'cycle_basis', 'cycle_graph', 'cycleinv', 'cycles2permu', 'cyclotomic', 'cylinder', 'dash_line', 'dashdot_line', 'dashdotdot_line', 'dayofweek', 'deSolve', 'debut_enregistrement', 'degree', 'degree_centrality', 'degree_sequence', 'degrees', 'delcols', 'delete_arc', 'delete_edge', 'delete_vertex', 'delrows', 'deltalist', 'denom', 'densityplot', 'departures', 'derive', 'deriver', 'desolve', 'dessine_tortue', 'det', 'det_minor', 'developper', 'developper_transcendant', 'dfc', 'dfc2f', 'diag', 'diff', 'digraph', 'dijkstra', 'dim', 'directed', 'discard_edge_attribute', 'discard_graph_attribute', 'discard_vertex_attribute', 'disjoint_union', 'display', 'disque', 'disque_centre', 'distance', 'distance2', 'distanceat', 'distanceatraw', 'divergence', 'divide', 'divis', 'division_point', 'divisors', 'divmod', 'divpc', 'dnewton_solver', 'dodecahedron', 'domain', 'dot', 'dotP', 'dot_paper', 'dotprod', 'draw_arc', 'draw_circle', 'draw_graph', 'draw_line', 'draw_pixel', 'draw_polygon', 'draw_rectangle', 'droit', 'droite_tangente', 'dsolve', 'duration', 'dwt', 'e', 'e2r', 'ecart_type', 'ecart_type_population', 'ecef2geodetic', 'ecm_factor', 'edge_connectivity', 'edges', 'egcd', 'egv', 'egvl', 'eigVc', 'eigVl', 'eigenvals', 'eigenvalues', 'eigenvectors', 'eigenvects', 'element', 'eliminate', 'ellipse', 'emd', 'entry', 'envelope', 'epsilon', 'epsilon2zero', 'equal', 'equal2diff', 'equal2list', 'equation', 'equilateral_triangle', 'erf', 'erfc', 'error', 'est_permu', 'euler', 'euler_gamma', 'euler_lagrange', 'eval_level', 'evala', 'evalb', 'evalc', 'evalf', 'evalm', 'even', 'evolute', 'exact', 'exbisector', 'excircle', 'execute', 'exp', 'exp2list', 'exp2pow', 'exp2trig', 'expand', 'expexpand', 'expln', 'exponential', 'exponential_cdf', 'exponential_icdf', 'exponential_regression', 'exponential_regression_plot', 'exponentiald', 'exponentiald_cdf', 'exponentiald_icdf', 'export_graph', 'export_mathml', 'expovariate', 'expr', 'extend', 'extract_measure', 'extrema', 'ezgcd', 'f2nd', 'fMax', 'fMin', 'fPart', 'faces', 'facteurs_premiers', 'factor', 'factor_xn', 'factorial', 'factoriser', 'factoriser_entier', 'factoriser_sur_C', 'factors', 'fadeev', 'false', 'falsepos_solver', 'fclose', 'fcoeff', 'fdistrib', 'fft', 'fieldplot', 'find', 'find_cliques', 'find_cycles', 'find_minimum', 'find_vertex_cover', 'findhelp', 'fisher', 'fisher_cdf', 'fisher_icdf', 'fisherd', 'fisherd_cdf', 'fisherd_icdf', 'fitdistr', 'fitpoly', 'fitspline', 'flatten', 'float2rational', 'floor', 'flow_polynomial', 'flower_snark', 'fmod', 'foldl', 'foldr', 'fonction_derivee', 'forward', 'fourier', 'fourier_an', 'fourier_bn', 'fourier_cn', 'fprint', 'frac', 'fracmod', 'frame_2d', 'frank_wolfe', 'frequencies', 'frobenius_norm', 'froot', 'fsolve', 'fullparfrac', 'funcplot', 'function_diff', 'fundamental_cycle', 'fxnd', 'gammad', 'gammad_cdf', 'gammad_icdf', 'gammavariate', 'gauss', 'gauss15', 'gauss_seidel_linsolve', 'gaussian_window', 'gaussjord', 'gaussquad', 'gbasis', 'gbasis_max_pairs', 'gbasis_reinject', 'gbasis_simult_primes', 'gcd', 'gcdex', 'genpoly', 'geodetic2ecef', 'geometric', 'geometric_cdf', 'geometric_icdf', 'getDenom', 'getKey', 'getNum', 'getType', 'get_edge_attribute', 'get_edge_weight', 'get_graph_attribute', 'get_vertex_attribute', 'girth', 'gl_showaxes', 'gold', 'goldberg_snark', 'grad', 'gramschmidt', 'graph', 'graph_automorphisms', 'graph_charpoly', 'graph_complement', 'graph_diameter', 'graph_equal', 'graph_join', 'graph_power', 'graph_rank', 'graph_spectrum', 'graph_union', 'graph_vertices', 'greduce', 'greedy_clique', 'greedy_color', 'greedy_independent_set', 'grey', 'grid_graph', 'groupermu', 'haar_graph', 'hadamard', 'half_cone', 'half_line', 'halftan', 'halftan_hyp2exp', 'halt', 'hamdist', 'hamming', 'hamming_window', 'hann_poisson_window', 'hann_window', 'harmonic_centrality', 'harmonic_conjugate', 'harmonic_division', 'has', 'has_arc', 'has_edge', 'hasard', 'head', 'heading', 'heapify', 'heappop', 'heappush', 'hermite', 'hessenberg', 'hessian', 'heugcd', 'hexagon', 'hht', 'highlight_edges', 'highlight_subgraph', 'highlight_trail', 'highlight_vertex', 'highpass', 'hilbert', 'histogram', 'hold', 'homogeneize', 'homothety', 'horner', 'hsv', 'hsv2rgb', 'hybrid_solver', 'hybridj_solver', 'hybrids_solver', 'hybridsj_solver', 'hyp2exp', 'hyperbola', 'hypercube_graph', 'iPart', 'iabcuv', 'ibasis', 'ibpdv', 'ibpu', 'icdf', 'ichinrem', 'ichrem', 'icomp', 'icontent', 'icosahedron', 'id', 'identify_graph', 'identity', 'idivis', 'idn', 'idwt', 'iegcd', 'ifactor', 'ifactors', 'ifourier', 'igamma', 'igcd', 'igcdex', 'ihermite', 'ilaplace', 'im', 'imag', 'image', 'imfplot', 'implicitdiff', 'implicitplot', 'import_graph', 'inString', 'in_ideal', 'incidence_matrix', 'incident_edges', 'incircle', 'increasing_power', 'independence_number', 'indets', 'index', 'induced_subgraph', 'inequationplot', 'inertia', 'inf', 'infinity', 'information_centrality', 'insert', 'insmod', 'instfreq', 'instphase', 'int', 'intDiv', 'integer', 'integrate', 'integrer', 'inter', 'interactive_odeplot', 'interactive_plotode', 'interp', 'interval', 'interval2center', 'interval_graph', 'inv', 'inverse', 'inversion', 'invisible_point', 'invlaplace', 'invztrans', 'iquo', 'iquorem', 'iratrecon', 'irem', 'isPrime', 'is_acyclic', 'is_arborescence', 'is_biconnected', 'is_bipartite', 'is_clique', 'is_collinear', 'is_concyclic', 'is_conjugate', 'is_connected', 'is_coplanar', 'is_cospherical', 'is_cut_set', 'is_cycle', 'is_directed', 'is_element', 'is_equilateral', 'is_eulerian', 'is_forest', 'is_graphic_sequence', 'is_hamiltonian', 'is_harmonic', 'is_harmonic_circle_bundle', 'is_harmonic_line_bundle', 'is_inside', 'is_integer_graph', 'is_irreducible', 'is_isomorphic', 'is_isosceles', 'is_network', 'is_orthogonal', 'is_parallel', 'is_parallelogram', 'is_permu', 'is_perpendicular', 'is_planar', 'is_prime', 'is_pseudoprime', 'is_reachable', 'is_rectangle', 'is_regular', 'is_rhombus', 'is_split_graph', 'is_square', 'is_strongly_connected', 'is_strongly_regular', 'is_subgraph_isomorphic', 'is_tournament', 'is_tree', 'is_triconnected', 'is_two_edge_connected', 'is_vertex_colorable', 'is_weighted', 'isinf', 'ismith', 'isnan', 'isobarycenter', 'isolve', 'isom', 'isomorphic_copy', 'isopolygon', 'isosceles_triangle', 'isposdef', 'isprime', 'istft', 'ithprime', 'jacobi_equation', 'jacobi_linsolve', 'jacobi_symbol', 'johnson_graph', 'join', 'jordan', 'katz_centrality', 'kde', 'keep_pivot', 'ker', 'kernel', 'kernel_density', 'kmeans', 'kneser_graph', 'kolmogorovd', 'kolmogorovt', 'kovacicsols', 'kspaths', 'l1norm', 'l2norm', 'lagrange', 'laguerre', 'laplace', 'laplacian', 'laplacian_matrix', 'latex', 'lcf_graph', 'lcm', 'lcoeff', 'ldegree', 'ldl', 'learning_rate', 'left', 'left_rectangle', 'legend', 'legendre', 'legendre_symbol', 'length', 'levenshtein', 'lgcd', 'lhs', 'ligne_chapeau_carre', 'ligne_chapeau_plat', 'ligne_chapeau_rond', 'ligne_polygonale', 'ligne_polygonale_pointee', 'ligne_tiret', 'ligne_tiret_point', 'ligne_tiret_pointpoint', 'ligne_trait_plein', 'limit', 'limite', 'lin', 'linabs', 'line', 'line_graph', 'line_inter', 'line_paper', 'line_segments', 'linear_interpolate', 'linear_regression', 'linear_regression_plot', 'lineariser', 'lineariser_trigo', 'linfnorm', 'linsolve', 'linspace', 'linstep', 'lis_phrase', 'list2exp', 'list2mat', 'list_edge_attributes', 'list_graph_attributes', 'list_vertex_attributes', 'listplot', 'lll', 'ln', 'lname', 'lncollect', 'lnexpand', 'locus', 'log', 'log10', 'log2', 'log_loss', 'logarithmic_regression', 'logarithmic_regression_plot', 'logb', 'logistic', 'logistic_regression', 'logistic_regression_plot', 'lower', 'lowest_common_ancestor', 'lowpass', 'lp_assume', 'lp_bestlocalbound', 'lp_bestprojection', 'lp_binary', 'lp_binaryvariables', 'lp_breadthfirst', 'lp_depthfirst', 'lp_depthlimit', 'lp_firstfractional', 'lp_gaptolerance', 'lp_heuristic', 'lp_hybrid', 'lp_integer', 'lp_integervariables', 'lp_interiorpoint', 'lp_iterationlimit', 'lp_lastfractional', 'lp_maxcuts', 'lp_maximize', 'lp_method', 'lp_mostfractional', 'lp_nodelimit', 'lp_nodeselect', 'lp_nonnegative', 'lp_nonnegint', 'lp_presolve', 'lp_pseudocost', 'lp_simplex', 'lp_timelimit', 'lp_varselect', 'lp_verbose', 'lpsolve', 'lsmod', 'lsq', 'lu', 'lvar', 'mRow', 'mRowAdd', 'magenta', 'make_directed', 'make_symbol', 'make_weighted', 'makelist', 'makemat', 'makesuite', 'makevector', 'map', 'maple2mupad', 'maple2xcas', 'maple_ifactors', 'maple_mode', 'markov', 'mat2list', 'mathml', 'matpow', 'matrix', 'matrix_norm', 'max', 'maxflow', 'maximal_independent_set', 'maximize', 'maximum_clique', 'maximum_degree', 'maximum_independent_set', 'maximum_matching', 'maxnorm', 'mean', 'median', 'median_line', 'member', 'mgf', 'mid', 'middle_point', 'midpoint', 'min', 'minimal_edge_coloring', 'minimal_spanning_tree', 'minimal_vertex_coloring', 'minimax', 'minimize', 'minimum_cut', 'minimum_degree', 'minimum_vertex_cover', 'mixdown', 'mkisom', 'mksa', 'modf', 'modgcd', 'mods', 'momentum', 'monotonic', 'montre_tortue', 'moustache', 'moving_average', 'moyal', 'moyenne', 'mul', 'mult_c_conjugate', 'mult_conjugate', 'multinomial', 'multiplier_conjugue', 'multiplier_conjugue_complexe', 'multiply', 'mupad2maple', 'mupad2xcas', 'mycielski', 'nCr', 'nDeriv', 'nInt', 'nPr', 'nSolve', 'navy', 'ncols', 'negbinomial', 'negbinomial_cdf', 'negbinomial_icdf', 'neighbors', 'network_transitivity', 'neural_network', 'newList', 'newMat', 'newton', 'newton_solver', 'newtonj_solver', 'nextperm', 'nextprime', 'nlp_binary', 'nlp_binaryvariables', 'nlp_initialpoint', 'nlp_integer', 'nlp_integervariables', 'nlp_iterationlimit', 'nlp_maximize', 'nlp_method', 'nlp_nonnegative', 'nlp_nonnegint', 'nlp_precision', 'nlp_presolve', 'nlp_tolerance', 'nlp_verbose', 'nlpsolve', 'nodisp', 'non_recursive_normal', 'nonnegint', 'nop', 'nops', 'norm', 'normal', 'normal_cdf', 'normal_icdf', 'normald', 'normald_cdf', 'normald_icdf', 'normalize', 'normalt', 'normalvariate', 'nprimes', 'nrows', 'nstep', 'nuage_points', 'nullspace', 'number_of_edges', 'number_of_spanning_trees', 'number_of_triangles', 'number_of_vertices', 'numdiff', 'numer', 'octahedron', 'odd', 'odd_girth', 'odd_graph', 'odeplot', 'odesolve', 'olive', 'op', 'open_polygon', 'orange', 'ord', 'order', 'order_size', 'ordinate', 'orthocenter', 'orthogonal', 'osculating_circle', 'p1oc2', 'p1op2', 'pa2b2', 'pade', 'paley_graph', 'parabola', 'parallel', 'parallelepiped', 'parallelogram', 'parameq', 'parameter', 'paramplot', 'parfrac', 'pari', 'part', 'partfrac', 'parzen_window', 'pas_de_cote', 'path_graph', 'pcar', 'pcar_hessenberg', 'pcoef', 'pcoeff', 'pencolor', 'pendown', 'penup', 'perimeter', 'perimeterat', 'perimeteratraw', 'period', 'periodic', 'perm', 'perminv', 'permu2cycles', 'permu2mat', 'permuorder', 'permute_vertices', 'perpen_bisector', 'perpendicular', 'petersen_graph', 'peval', 'pi', 'pie', 'piecewise', 'pink', 'pivot', 'pixoff', 'pixon', 'planar', 'plane', 'plane_dual', 'playsnd', 'plex', 'plot', 'plot3d', 'plotarea', 'plotcdf', 'plotcontour', 'plotdensity', 'plotfield', 'plotfunc', 'plotimf', 'plotimplicit', 'plotinequation', 'plotlist', 'plotode', 'plotparam', 'plotpolar', 'plotproba', 'plotseq', 'plotspectrum', 'plotwav', 'plus_point', 'pmin', 'point', 'point2d', 'point3d', 'poisson', 'poisson_cdf', 'poisson_icdf', 'poisson_window', 'polar', 'polar_coordinates', 'polar_point', 'polarplot', 'pole', 'poly2symb', 'polyEval', 'polygon', 'polygone_rempli', 'polygonplot', 'polygonscatterplot', 'polyhedron', 'polynom', 'polynomial_regression', 'polynomial_regression_plot', 'position', 'poslbdLMQ', 'posubLMQ', 'potential', 'pow2exp', 'power_regression', 'power_regression_plot', 'powermod', 'powerpc', 'powexpand', 'powmod', 'prepend', 'preval', 'prevperm', 'prevprime', 'primpart', 'printf', 'prism', 'prism_graph', 'product', 'projection', 'proot', 'propFrac', 'propfrac', 'pruefer_code', 'psrgcd', 'ptayl', 'purge', 'purple', 'pwd', 'pyramid', 'python_compat', 'q2a', 'qr', 'quadric', 'quadrilateral', 'quantile', 'quartile1', 'quartile3', 'quartiles', 'quest', 'quo', 'quorem', 'quote', 'r2e', 'radians', 'radical_axis', 'radius', 'ramene', 'rand', 'randMat', 'randNorm', 'randPoly', 'randbetad', 'randbinomial', 'randchisquare', 'randexp', 'randfisher', 'randgammad', 'randgeometric', 'randint', 'randmarkov', 'randmatrix', 'randmultinomial', 'randnorm', 'random', 'random_bipartite_graph', 'random_digraph', 'random_graph', 'random_network', 'random_planar_graph', 'random_regular_graph', 'random_sequence_graph', 'random_tournament', 'random_tree', 'random_variable', 'randperm', 'randpoisson', 'randpoly', 'randseed', 'randstudent', 'randvar', 'randvector', 'randweibulld', 'rank', 'ranm', 'ranv', 'rassembler_trigo', 'rat_jordan', 'ratinterp', 'rational', 'rationalroot', 'ratnormal', 'rdiv', 're', 'reachable', 'read', 'readrgb', 'readwav', 'real', 'realroot', 'reciprocation', 'rect', 'rectangle', 'rectangle_droit', 'rectangle_gauche', 'rectangle_plein', 'rectangular_coordinates', 'recule', 'red', 'reduced_conic', 'reduced_quadric', 'ref', 'reflection', 'regroup', 'relabel_vertices', 'reliability_polynomial', 'rem', 'remain', 'remove', 'reorder', 'resample', 'residue', 'resoudre', 'resoudre_dans_C', 'resoudre_systeme_lineaire', 'resultant', 'reverse', 'reverse_graph', 'reverse_rsolve', 'revert', 'revlex', 'revlist', 'rgb', 'rgb2hsv', 'rgb2xyz', 'rhombus', 'rhombus_point', 'rhs', 'riemann_window', 'right', 'right_rectangle', 'right_triangle', 'risch', 'rm_a_z', 'rm_all_vars', 'rmbreakpoint', 'rmmod', 'rms', 'rmwatch', 'romberg', 'rombergm', 'rombergt', 'rond', 'root', 'rootof', 'roots', 'rotate', 'rotation', 'round', 'row', 'rowAdd', 'rowDim', 'rowNorm', 'rowSwap', 'rowdim', 'rownorm', 'rowspace', 'rowswap', 'rref', 'rsolve', 'rur', 'rur_certify', 'rur_gbasis', 'same', 'sample', 'samplerate', 'sans_factoriser', 'saute', 'scalarProduct', 'scalar_product', 'scatterplot', 'schur', 'sec', 'secant_solver', 'segment', 'seidel_spectrum', 'seidel_switch', 'select', 'semi_augment', 'seq', 'seqplot', 'seqsolve', 'sequence_graph', 'series', 'set_channel_data', 'set_edge_attribute', 'set_edge_weight', 'set_graph_attribute', 'set_pixel', 'set_screen', 'set_vertex_attribute', 'set_vertex_positions', 'shift', 'shift_phase', 'shortest_path', 'show_pixels', 'shuffle', 'sierpinski_graph', 'sign', 'sign2Heaviside', 'signature', 'signe', 'similarity', 'simp2', 'simplex_reduce', 'simplicial_vertices', 'simplifier', 'simplify', 'simplifyDirac', 'simpson', 'simulated_annealing', 'simult', 'sin', 'sin2costan', 'sinc', 'sincos', 'single_inter', 'sinh', 'sizes', 'slope', 'slopeat', 'slopeatraw', 'smith', 'smod', 'snedecor', 'snedecor_cdf', 'snedecor_icdf', 'snedecord', 'snedecord_cdf', 'snedecord_icdf', 'solid_line', 'solve', 'somme', 'sommet', 'sort', 'sorta', 'sortd', 'sorted', 'sortperm', 'soundsec', 'spanning_tree', 'sphere', 'splice', 'spline', 'split', 'spring', 'sq', 'sqrfree', 'sqrt', 'square', 'square_point', 'srand', 'sst', 'sst_in', 'st_ordering', 'star_graph', 'star_point', 'stdDev', 'stddev', 'stddevp', 'steffenson_solver', 'stereo2mono', 'stft', 'str', 'strip', 'strongly_connected_components', 'student', 'student_cdf', 'student_icdf', 'studentd', 'studentt', 'sturm', 'sturmab', 'sturmseq', 'style', 'subMat', 'subdivide_edges', 'subgraph', 'subs', 'subsop', 'subst', 'substituer', 'subtype', 'sum', 'sum_riemann', 'suppress', 'surd', 'svd', 'swapcol', 'swaprow', 'switch_axes', 'sylvester', 'symb2poly', 'symbol', 'symbol_array', 'syst2mat', 'tCollect', 'tExpand', 'table', 'tablefunc', 'tableseq', 'tabsign', 'tabvar', 'tail', 'tan', 'tan2cossin2', 'tan2sincos', 'tan2sincos2', 'tangent', 'tangente', 'tanh', 'tar', 'taux_accroissement', 'taylor', 'tchebyshev1', 'tchebyshev2', 'tcoeff', 'tcollect', 'tdeg', 'teal', 'tensor_product', 'tetrahedron', 'texpand', 'thickness', 'threshold', 'throw', 'title', 'titre', 'tlin', 'tonnetz', 'topologic_sort', 'topological_sort', 'topology', 'torus_grid_graph', 'total_degree', 'tourne_droite', 'tourne_gauche', 'tpsolve', 'trace', 'trail', 'trail2edges', 'train', 'trames', 'tran', 'transitive_closure', 'translation', 'transpose', 'trapeze', 'trapezoid', 'traveling_salesman', 'tree', 'tree_height', 'tri', 'triangle', 'triangle_paper', 'triangle_plein', 'triangle_point', 'triangle_window', 'trig2exp', 'trigcos', 'trigexpand', 'triginterp', 'trigsimplify', 'trigsin', 'trigtan', 'trim', 'trn', 'true', 'trunc', 'truncate', 'truncate_graph', 'tsimplify', 'tstep', 'tuer', 'tukey_window', 'tutte_polynomial', 'two_edge_connected_components', 'ufactor', 'ugamma', 'unapply', 'unarchive', 'undef', 'underlying_graph', 'unfactored', 'uniform', 'uniform_cdf', 'uniform_icdf', 'uniformd', 'uniformd_cdf', 'uniformd_icdf', 'unitV', 'unquote', 'upper', 'user_operator', 'usimplify', 'ustep', 'valuation', 'vandermonde', 'variables_are_files', 'variance', 'version', 'vertex_connectivity', 'vertex_cover_number', 'vertex_degree', 'vertex_distance', 'vertex_in_degree', 'vertex_out_degree', 'vertices', 'vertices_abc', 'vertices_abca', 'violet', 'vpotential', 'vstep', 'web_graph', 'weibull', 'weibull_cdf', 'weibull_icdf', 'weibulld', 'weibulld_cdf', 'weibulld_icdf', 'weibullvariate', 'weight_decay', 'weight_matrix', 'weighted', 'weights', 'welch_window', 'wheel_graph', 'widget_size', 'wilcoxonp', 'wilcoxons', 'wilcoxont', 'writergb', 'writewav', 'xcas_mode', 'xml_print', 'xstep', 'xyz2rgb', 'xyztrange', 'ystep', 'zeros', 'znorder', 'znprimroot', 'zstep', 'ztrans']
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_type);
  __Pyx_GIVEREF(__pyx_n_s_type);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_type)) __PYX_ERR(5, 8, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_zip);
  __Pyx_GIVEREF(__pyx_n_s_zip);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_zip)) __PYX_ERR(5, 8, __pyx_L1_error);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_moremethods, __pyx_t_2) < 0) __PYX_ERR(5, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/keywords.pxi":10
 * moremethods = ['type', 'zip']
 * 
 * mostkeywords = ['Airy_Ai', 'Airy_Bi', 'Archive', 'BesselJ', 'BesselY', 'Beta', 'BlockDiagonal', 'Ci', 'Circle', 'Col', 'CopyVar', 'Dirac', 'Ei', 'Factor', 'Fourier', 'GF', 'Gamma', 'Heaviside', 'Heaviside2sign', 'Hilbert', 'JordanBlock', 'LU', 'LambertW', 'Li', 'Line', 'LineHorz', 'LineTan', 'LineVert', 'MSE', 'Phi', 'Pi', 'Psi', 'QR', 'RandSeed', 'ReLU', 'Row', 'SortA', 'SortD', 'UTPC', 'UTPF', 'UTPN', 'UTPT', 'VARS', 'VAS', 'VAS_positive', 'Zeta', 'a2q', 'abcuv', 'about', 'abs', 'abscissa', 'accumulate_head_tail', 'acos', 'acos2asin', 'acos2atan', 'acosh', 'acot', 'acsc', 'acyclic', 'adaptive', 'add', 'add_arc', 'add_edge', 'add_vertex', 'additionally', 'addtable', 'adjacency_matrix', 'adjoint_matrix', 'affix', 'algsubs', 'algvar', 'all_trig_solutions', 'allpairs_distance', 'alog10', 'altitude', 'angle', 'angle_radian', 'angleat', 'angleatraw', 'ans', 'antiprism_graph', 'append', 'apply', 'approx', 'arc', 'arcLen', 'arccos', 'arccosh', 'arclen', 'arcsin', 'arcsinh', 'arctan', 'arctanh', 'area', 'areaat', 'areaatraw', 'areaplot', 'arg', 'array', 'arrivals', 'articulation_points', 'asin', 'asin2acos', 'asin2atan', 'asinh', 'assign_edge_weights', 'assume', 'at', 'atan', 'atan2', 'atan2acos', 'atan2asin', 'atanh', 'atrig2ln', 'augment', 'auto_correlation', 'autosimplify', 'avance', 'avgRC', 'axes', 'axis', 'back', 'backward', 'baisse_crayon', 'bandwidth', 'bar_plot', 'barplot', 'bartlett_hann_window', 'barycenter', 'base', 'basis', 'batons', 'bellman_ford', 'berlekamp_massey', 'bernoulli', 'bernoulli_mod', 'besselJ', 'besselY', 'betad', 'betad_cdf', 'betad_icdf', 'betavariate', 'betweenness_centrality', 'bezier', 'bezout_entiers', 'bezoutian', 'biconnected_components', 'binomial', 'binomial_cdf', 'binomial_icdf', 'bins', 'bipartite', 'bipartite_matching', 'bisection_solver', 'bisector', 'bit_depth', 'bitand', 'bitor', 'bitxor', 'blackman_harris_window', 'blackman_window', 'block_size', 'blockmatrix', 'bohman_window', 'border', 'box_constraints', 'boxcar', 'boxwhisker', 'brent_solver', 'brown', 'bspline', 'bvpsolve', 'cFactor', 'cSolve', 'cZeros', 'camembert', 'canonical_form', 'canonical_labeling', 'cartesian_product', 'cauchy', 'cauchy_cdf', 'cauchy_icdf', 'cauchyd', 'cauchyd_cdf', 'cauchyd_icdf', 'cdf', 'ceil', 'ceiling', 'center', 'center2interval', 'centered_cube', 'centered_tetrahedron', 'cfactor', 'cfsolve', 'changebase', 'channel_data', 'channels', 'char', 'charpoly', 'chinrem', 'chisquare', 'chisquare_cdf', 'chisquare_icdf', 'chisquared', 'chisquared_cdf', 'chisquared_icdf', 'chisquaret', 'choice', 'cholesky', 'chr', 'chrem', 'chromatic_index', 'chromatic_number', 'chromatic_polynomial', 'circle', 'circumcircle', 'classes', 'clear', 'clique_cover', 'clique_cover_number', 'clique_number', 'closeness_centrality', 'cluster', 'clustering_coefficient', 'coeff', 'coeffs', 'col', 'colDim', 'colNorm', 'colSwap', 'coldim', 'collect', 'colnorm', 'color', 'colormap', 'colspace', 'colswap', 'comDenom', 'comb', 'combine', 'comment', 'common_perpendicular', 'companion', 'compare', 'complete_binary_tree', 'complete_graph', 'complete_kary_tree', 'complex', 'complex_variables', 'complexroot', 'concat', 'cond', 'condensation', 'cone', 'confrac', 'conic', 'conj', 'conjugate_equation', 'conjugate_gradient', 'connected', 'connected_components', 'cont', 'contains', 'content', 'contourplot', 'contract_edge', 'contract_subgraph', 'convert', 'convertir', 'convex', 'convexhull', 'convolution', 'coordinates', 'copy', 'correlation', 'cos', 'cos2sintan', 'cosh', 'cosine_window', 'cot', 'cote', 'count', 'count_eq', 'count_inf', 'count_sup', 'courbe_parametrique', 'courbe_polaire', 'covariance', 'covariance_correlation', 'cpartfrac', 'crationalroot', 'crayon', 'createwav', 'cross', 'crossP', 'cross_correlation', 'cross_entropy', 'cross_point', 'cross_ratio', 'crossproduct', 'csc', 'csolve', 'csv2gen', 'cube', 'cumSum', 'cumsum', 'cumulated_frequencies', 'curl', 'current_sheet', 'curvature', 'curve', 'cyan', 'cycle2perm', 'cycle_basis', 'cycle_graph', 'cycleinv', 'cycles2permu', 'cyclotomic', 'cylinder', 'dash_line', 'dashdot_line', 'dashdotdot_line', 'dayofweek', 'deSolve', 'debut_enregistrement', 'degree', 'degree_centrality', 'degree_sequence', 'degrees', 'delcols', 'delete_arc', 'delete_edge', 'delete_vertex', 'delrows', 'deltalist', 'denom', 'densityplot', 'departures', 'derive', 'deriver', 'desolve', 'dessine_tortue', 'det', 'det_minor', 'developper', 'developper_transcendant', 'dfc', 'dfc2f', 'diag', 'diff', 'digraph', 'dijkstra', 'dim', 'directed', 'discard_edge_attribute', 'discard_graph_attribute', 'discard_vertex_attribute', 'disjoint_union', 'display', 'disque', 'disque_centre', 'distance', 'distance2', 'distanceat', 'distanceatraw', 'divergence', 'divide', 'divis', 'division_point', 'divisors', 'divmod', 'divpc', 'dnewton_solver', 'dodecahedron', 'domain', 'dot', 'dotP', 'dot_paper', 'dotprod', 'draw_arc', 'draw_circle', 'draw_graph', 'draw_line', 'draw_pixel', 'draw_polygon', 'draw_rectangle', 'droit', 'droite_tangente', 'dsolve', 'duration', 'dwt', 'e', 'e2r', 'ecart_type', 'ecart_type_population', 'ecef2geodetic', 'ecm_factor', 'edge_connectivity', 'edges', 'egcd', 'egv', 'egvl', 'eigVc', 'eigVl', 'eigenvals', 'eigenvalues', 'eigenvectors', 'eigenvects', 'element', 'eliminate', 'ellipse', 'emd', 'entry', 'envelope', 'epsilon', 'epsilon2zero', 'equal', 'equal2diff', 'equal2list', 'equation', 'equilateral_triangle', 'erf', 'erfc', 'error', 'est_permu', 'euler', 'euler_gamma', 'euler_lagrange', 'eval_level', 'evala', 'evalb', 'evalc', 'evalf', 'evalm', 'even', 'evolute', 'exact', 'exbisector', 'excircle', 'execute', 'exp', 'exp2list', 'exp2pow', 'exp2trig', 'expand', 'expexpand', 'expln', 'exponential', 'exponential_cdf', 'exponential_icdf', 'exponential_regression', 'exponential_regression_plot', 'exponentiald', 'exponentiald_cdf', 'exponentiald_icdf', 'export_graph', 'export_mathml', 'expovariate', 'expr', 'extend', 'extract_measure', 'extrema', 'ezgcd', 'f2nd', 'fMax', 'fMin', 'fPart', 'faces', 'facteurs_premiers', 'factor', 'factor_xn', 'factorial', 'factoriser', 'factoriser_entier', 'factoriser_sur_C', 'factors', 'fadeev', 'false', 'falsepos_solver', 'fclose', 'fcoeff', 'fdistrib', 'fft', 'fieldplot', 'find', 'find_cliques', 'find_cycles', 'find_minimum', 'find_vertex_cover', 'findhelp', 'fisher', 'fisher_cdf', 'fisher_icdf', 'fisherd', 'fisherd_cdf', 'fisherd_icdf', 'fitdistr', 'fitpoly', 'fitspline', 'flatten', 'float2rational', 'floor', 'flow_polynomial', 'flower_snark', 'fmod', 'foldl', 'foldr', 'fonction_derivee', 'forward', 'fourier', 'fourier_an', 'fourier_bn', 'fourier_cn', 'fprint', 'frac', 'fracmod', 'frame_2d', 'frank_wolfe', 'frequencies', 'frobenius_norm', 'froot', 'fsolve', 'fullparfrac', 'funcplot', 'function_diff', 'fundamental_cycle', 'fxnd', 'gammad', 'gammad_cdf', 'gammad_icdf', 'gammavariate', 'gauss', 'gauss15', 'gauss_seidel_linsolve', 'gaussian_window', 'gaussjord', 'gaussquad', 'gbasis', 'gbasis_max_pairs', 'gbasis_reinject', 'gbasis_simult_primes', 'gcd', 'gcdex', 'genpoly', 'geodetic2ecef', 'geometric', 'geometric_cdf', 'geometric_icdf', 'getDenom', 'getKey', 'getNum', 'getType', 'get_edge_attribute', 'get_edge_weight', 'get_graph_attribute', 'get_vertex_attribute', 'girth', 'gl_showaxes', 'gold', 'goldberg_snark', 'grad', 'gramschmidt', 'graph', 'graph_automorphisms', 'graph_charpoly', 'graph_complement', 'graph_diameter', 'graph_equal', 'graph_join', 'graph_power', 'graph_rank', 'graph_spectrum', 'graph_union', 'graph_vertices', 'greduce', 'greedy_clique', 'greedy_color', 'greedy_independent_set', 'grey', 'grid_graph', 'groupermu', 'haar_graph', 'hadamard', 'half_cone', 'half_line', 'halftan', 'halftan_hyp2exp', 'halt', 'hamdist', 'hamming', 'hamming_window', 'hann_poisson_window', 'hann_window', 'harmonic_centrality', 'harmonic_conjugate', 'harmonic_division', 'has', 'has_arc', 'has_edge', 'hasard', 'head', 'heading', 'heapify', 'heappop', 'heappush', 'hermite', 'hessenberg', 'hessian', 'heugcd', 'hexagon', 'hht', 'highlight_edges', 'highlight_subgraph', 'highlight_trail', 'highlight_vertex', 'highpass', 'hilbert', 'histogram', 'hold', 'homogeneize', 'homothety', 'horner', 'hsv', 'hsv2rgb', 'hybrid_solver', 'hybridj_solver', 'hybrids_solver', 'hybridsj_solver', 'hyp2exp', 'hyperbola', 'hypercube_graph', 'iPart', 'iabcuv', 'ibasis', 'ibpdv', 'ibpu', 'icdf', 'ichinrem', 'ichrem', 'icomp', 'icontent', 'icosahedron', 'id', 'identify_graph', 'identity', 'idivis', 'idn', 'idwt', 'iegcd', 'ifactor', 'ifactors', 'ifourier', 'igamma', 'igcd', 'igcdex', 'ihermite', 'ilaplace', 'im', 'imag', 'image', 'imfplot', 'implicitdiff', 'implicitplot', 'import_graph', 'inString', 'in_ideal', 'incidence_matrix', 'incident_edges', 'incircle', 'increasing_power', 'independence_number', 'indets', 'index', 'induced_subgraph', 'inequationplot', 'inertia', 'inf', 'infinity', 'information_centrality', 'insert', 'insmod', 'instfreq', 'instphase', 'int', 'intDiv', 'integer', 'integrate', 'integrer', 'inter', 'interactive_odeplot', 'interactive_plotode', 'interp', 'interval', 'interval2center', 'interval_graph', 'inv', 'inverse', 'inversion', 'invisible_point', 'invlaplace', 'invztrans', 'iquo', 'iquorem', 'iratrecon', 'irem', 'isPrime', 'is_acyclic', 'is_arborescence', 'is_biconnected', 'is_bipartite', 'is_clique', 'is_collinear', 'is_concyclic', 'is_conjugate', 'is_connected', 'is_coplanar', 'is_cospherical', 'is_cut_set', 'is_cycle', 'is_directed', 'is_element', 'is_equilateral', 'is_eulerian', 'is_forest', 'is_graphic_sequence', 'is_hamiltonian', 'is_harmonic', 'is_harmonic_circle_bundle', 'is_harmonic_line_bundle', 'is_inside', 'is_integer_graph', 'is_irreducible', 'is_isomorphic', 'is_isosceles', 'is_network', 'is_orthogonal', 'is_parallel', 'is_parallelogram', 'is_permu', 'is_perpendicular', 'is_planar', 'is_prime', 'is_pseudoprime', 'is_reachable', 'is_rectangle', 'is_regular', 'is_rhombus', 'is_split_graph', 'is_square', 'is_strongly_connected', 'is_strongly_regular', 'is_subgraph_isomorphic', 'is_tournament', 'is_tree', 'is_triconnected', 'is_two_edge_connected', 'is_vertex_colorable', 'is_weighted', 'isinf', 'ismith', 'isnan', 'isobarycenter', 'isolve', 'isom', 'isomorphic_copy', 'isopolygon', 'isosceles_triangle', 'isposdef', 'isprime', 'istft', 'ithprime', 'jacobi_equation', 'jacobi_linsolve', 'jacobi_symbol', 'johnson_graph', 'join', 'jordan', 'katz_centrality', 'kde', 'keep_pivot', 'ker', 'kernel', 'kernel_density', 'kmeans', 'kneser_graph', 'kolmogorovd', 'kolmogorovt', 'kovacicsols', 'kspaths', 'l1norm', 'l2norm', 'lagrange', 'laguerre', 'laplace', 'laplacian', 'laplacian_matrix', 'latex', 'lcf_graph', 'lcm', 'lcoeff', 'ldegree', 'ldl', 'learning_rate', 'left', 'left_rectangle', 'legend', 'legendre', 'legendre_symbol', 'length', 'levenshtein', 'lgcd', 'lhs', 'ligne_chapeau_carre', 'ligne_chapeau_plat', 'ligne_chapeau_rond', 'ligne_polygonale', 'ligne_polygonale_pointee', 'ligne_tiret', 'ligne_tiret_point', 'ligne_tiret_pointpoint', 'ligne_trait_plein', 'limit', 'limite', 'lin', 'linabs', 'line', 'line_graph', 'line_inter', 'line_paper', 'line_segments', 'linear_interpolate', 'linear_regression', 'linear_regression_plot', 'lineariser', 'lineariser_trigo', 'linfnorm', 'linsolve', 'linspace', 'linstep', 'lis_phrase', 'list2exp', 'list2mat', 'list_edge_attributes', 'list_graph_attributes', 'list_vertex_attributes', 'listplot', 'lll', 'ln', 'lname', 'lncollect', 'lnexpand', 'locus', 'log', 'log10', 'log2', 'log_loss', 'logarithmic_regression', 'logarithmic_regression_plot', 'logb', 'logistic', 'logistic_regression', 'logistic_regression_plot', 'lower', 'lowest_common_ancestor', 'lowpass', 'lp_assume', 'lp_bestlocalbound', 'lp_bestprojection', 'lp_binary', 'lp_binaryvariables', 'lp_breadthfirst', 'lp_depthfirst', 'lp_depthlimit', 'lp_firstfractional', 'lp_gaptolerance', 'lp_heuristic', 'lp_hybrid', 'lp_integer', 'lp_integervariables', 'lp_interiorpoint', 'lp_iterationlimit', 'lp_lastfractional', 'lp_maxcuts', 'lp_maximize', 'lp_method', 'lp_mostfractional', 'lp_nodelimit', 'lp_nodeselect', 'lp_nonnegative', 'lp_nonnegint', 'lp_presolve', 'lp_pseudocost', 'lp_simplex', 'lp_timelimit', 'lp_varselect', 'lp_verbose', 'lpsolve', 'lsmod', 'lsq', 'lu', 'lvar', 'mRow', 'mRowAdd', 'magenta', 'make_directed', 'make_symbol', 'make_weighted', 'makelist', 'makemat', 'makesuite', 'makevector', 'map', 'maple2mupad', 'maple2xcas', 'maple_ifactors', 'maple_mode', 'markov', 'mat2list', 'mathml', 'matpow', 'matrix', 'matrix_norm', 'max', 'maxflow', 'maximal_independent_set', 'maximize', 'maximum_clique', 'maximum_degree', 'maximum_independent_set', 'maximum_matching', 'maxnorm', 'mean', 'median', 'median_line', 'member', 'mgf', 'mid', 'middle_point', 'midpoint', 'min', 'minimal_edge_coloring', 'minimal_spanning_tree', 'minimal_vertex_coloring', 'minimax', 'minimize', 'minimum_cut', 'minimum_degree', 'minimum_vertex_cover', 'mixdown', 'mkisom', 'mksa', 'modf', 'modgcd', 'mods', 'momentum', 'monotonic', 'montre_tortue', 'moustache', 'moving_average', 'moyal', 'moyenne', 'mul', 'mult_c_conjugate', 'mult_conjugate', 'multinomial', 'multiplier_conjugue', 'multiplier_conjugue_complexe', 'multiply', 'mupad2maple', 'mupad2xcas', 'mycielski', 'nCr', 'nDeriv', 'nInt', 'nPr', 'nSolve', 'navy', 'ncols', 'negbinomial', 'negbinomial_cdf', 'negbinomial_icdf', 'neighbors', 'network_transitivity', 'neural_network', 'newList', 'newMat', 'newton', 'newton_solver', 'newtonj_solver', 'nextperm', 'nextprime', 'nlp_binary', 'nlp_binaryvariables', 'nlp_initialpoint', 'nlp_integer', 'nlp_integervariables', 'nlp_iterationlimit', 'nlp_maximize', 'nlp_method', 'nlp_nonnegative', 'nlp_nonnegint', 'nlp_precision', 'nlp_presolve', 'nlp_tolerance', 'nlp_verbose', 'nlpsolve', 'nodisp', 'non_recursive_normal', 'nonnegint', 'nop', 'nops', 'norm', 'normal', 'normal_cdf', 'normal_icdf', 'normald', 'normald_cdf', 'normald_icdf', 'normalize', 'normalt', 'normalvariate', 'nprimes', 'nrows', 'nstep', 'nuage_points', 'nullspace', 'number_of_edges', 'number_of_spanning_trees', 'number_of_triangles', 'number_of_vertices', 'numdiff', 'numer', 'octahedron', 'odd', 'odd_girth', 'odd_graph', 'odeplot', 'odesolve', 'olive', 'op', 'open_polygon', 'orange', 'ord', 'order', 'order_size', 'ordinate', 'orthocenter', 'orthogonal', 'osculating_circle', 'p1oc2', 'p1op2', 'pa2b2', 'pade', 'paley_graph', 'parabola', 'parallel', 'parallelepiped', 'parallelogram', 'parameq', 'parameter', 'paramplot', 'parfrac', 'pari', 'part', 'partfrac', 'parzen_window', 'pas_de_cote', 'path_graph', 'pcar', 'pcar_hessenberg', 'pcoef', 'pcoeff', 'pencolor', 'pendown', 'penup', 'perimeter', 'perimeterat', 'perimeteratraw', 'period', 'periodic', 'perm', 'perminv', 'permu2cycles', 'permu2mat', 'permuorder', 'permute_vertices', 'perpen_bisector', 'perpendicular', 'petersen_graph', 'peval', 'pi', 'pie', 'piecewise', 'pink', 'pivot', 'pixoff', 'pixon', 'planar', 'plane', 'plane_dual', 'playsnd', 'plex', 'plot', 'plot3d', 'plotarea', 'plotcdf', 'plotcontour', 'plotdensity', 'plotfield', 'plotfunc', 'plotimf', 'plotimplicit', 'plotinequation', 'plotlist', 'plotode', 'plotparam', 'plotpolar', 'plotproba', 'plotseq', 'plotspectrum', 'plotwav', 'plus_point', 'pmin', 'point', 'point2d', 'point3d', 'poisson', 'poisson_cdf', 'poisson_icdf', 'poisson_window', 'polar', 'polar_coordinates', 'polar_point', 'polarplot', 'pole', 'poly2symb', 'polyEval', 'polygon', 'polygone_rempli', 'polygonplot', 'polygonscatterplot', 'polyhedron', 'polynom', 'polynomial_regression', 'polynomial_regression_plot', 'position', 'poslbdLMQ', 'posubLMQ', 'potential', 'pow2exp', 'power_regression', 'power_regression_plot', 'powermod', 'powerpc', 'powexpand', 'powmod', 'prepend', 'preval', 'prevperm', 'prevprime', 'primpart', 'printf', 'prism', 'prism_graph', 'product', 'projection', 'proot', 'propFrac', 'propfrac', 'pruefer_code', 'psrgcd', 'ptayl', 'purge', 'purple', 'pwd', 'pyramid', 'python_compat', 'q2a', 'qr', 'quadric', 'quadrilateral', 'quantile', 'quartile1', 'quartile3', 'quartiles', 'quest', 'quo', 'quorem', 'quote', 'r2e', 'radians', 'radical_axis', 'radius', 'ramene', 'rand', 'randMat', 'randNorm', 'randPoly', 'randbetad', 'randbinomial', 'randchisquare', 'randexp', 'randfisher', 'randgammad', 'randgeometric', 'randint', 'randmarkov', 'randmatrix', 'randmultinomial', 'randnorm', 'random', 'random_bipartite_graph', 'random_digraph', 'random_graph', 'random_network', 'random_planar_graph', 'random_regular_graph', 'random_sequence_graph', 'random_tournament', 'random_tree', 'random_variable', 'randperm', 'randpoisson', 'randpoly', 'randseed', 'randstudent', 'randvar', 'randvector', 'randweibulld', 'rank', 'ranm', 'ranv', 'rassembler_trigo', 'rat_jordan', 'ratinterp', 'rational', 'rationalroot', 'ratnormal', 'rdiv', 're', 'reachable', 'read', 'readrgb', 'readwav', 'real', 'realroot', 'reciprocation', 'rect', 'rectangle', 'rectangle_droit', 'rectangle_gauche', 'rectangle_plein', 'rectangular_coordinates', 'recule', 'red', 'reduced_conic', 'reduced_quadric', 'ref', 'reflection', 'regroup', 'relabel_vertices', 'reliability_polynomial', 'rem', 'remain', 'remove', 'reorder', 'resample', 'residue', 'resoudre', 'resoudre_dans_C', 'resoudre_systeme_lineaire', 'resultant', 'reverse', 'reverse_graph', 'reverse_rsolve', 'revert', 'revlex', 'revlist', 'rgb', 'rgb2hsv', 'rgb2xyz', 'rhombus', 'rhombus_point', 'rhs', 'riemann_window', 'right', 'right_rectangle', 'right_triangle', 'risch', 'rm_a_z', 'rm_all_vars', 'rmbreakpoint', 'rmmod', 'rms', 'rmwatch', 'romberg', 'rombergm', 'rombergt', 'rond', 'root', 'rootof', 'roots', 'rotate', 'rotation', 'round', 'row', 'rowAdd', 'rowDim', 'rowNorm', 'rowSwap', 'rowdim', 'rownorm', 'rowspace', 'rowswap', 'rref', 'rsolve', 'rur', 'rur_certify', 'rur_gbasis', 'same', 'sample', 'samplerate', 'sans_factoriser', 'saute', 'scalarProduct', 'scalar_product', 'scatterplot', 'schur', 'sec', 'secant_solver', 'segment', 'seidel_spectrum', 'seidel_switch', 'select', 'semi_augment', 'seq', 'seqplot', 'seqsolve', 'sequence_graph', 'series', 'set_channel_data', 'set_edge_attribute', 'set_edge_weight', 'set_graph_attribute', 'set_pixel', 'set_screen', 'set_vertex_attribute', 'set_vertex_positions', 'shift', 'shift_phase', 'shortest_path', 'show_pixels', 'shuffle', 'sierpinski_graph', 'sign', 'sign2Heaviside', 'signature', 'signe', 'similarity', 'simp2', 'simplex_reduce', 'simplicial_vertices', 'simplifier', 'simplify', 'simplifyDirac', 'simpson', 'simulated_annealing', 'simult', 'sin', 'sin2costan', 'sinc', 'sincos', 'single_inter', 'sinh', 'sizes', 'slope', 'slopeat', 'slopeatraw', 'smith', 'smod', 'snedecor', 'snedecor_cdf', 'snedecor_icdf', 'snedecord', 'snedecord_cdf', 'snedecord_icdf', 'solid_line', 'solve', 'somme', 'sommet', 'sort', 'sorta', 'sortd', 'sorted', 'sortperm', 'soundsec', 'spanning_tree', 'sphere', 'splice', 'spline', 'split', 'spring', 'sq', 'sqrfree', 'sqrt', 'square', 'square_point', 'srand', 'sst', 'sst_in', 'st_ordering', 'star_graph', 'star_point', 'stdDev', 'stddev', 'stddevp', 'steffenson_solver', 'stereo2mono', 'stft', 'str', 'strip', 'strongly_connected_components', 'student', 'student_cdf', 'student_icdf', 'studentd', 'studentt', 'sturm', 'sturmab', 'sturmseq', 'style', 'subMat', 'subdivide_edges', 'subgraph', 'subs', 'subsop', 'subst', 'substituer', 'subtype', 'sum', 'sum_riemann', 'suppress', 'surd', 'svd', 'swapcol', 'swaprow', 'switch_axes', 'sylvester', 'symb2poly', 'symbol', 'symbol_array', 'syst2mat', 'tCollect', 'tExpand', 'table', 'tablefunc', 'tableseq', 'tabsign', 'tabvar', 'tail', 'tan', 'tan2cossin2', 'tan2sincos', 'tan2sincos2', 'tangent', 'tangente', 'tanh', 'tar', 'taux_accroissement', 'taylor', 'tchebyshev1', 'tchebyshev2', 'tcoeff', 'tcollect', 'tdeg', 'teal', 'tensor_product', 'tetrahedron', 'texpand', 'thickness', 'threshold', 'throw', 'title', 'titre', 'tlin', 'tonnetz', 'topologic_sort', 'topological_sort', 'topology', 'torus_grid_graph', 'total_degree', 'tourne_droite', 'tourne_gauche', 'tpsolve', 'trace', 'trail', 'trail2edges', 'train', 'trames', 'tran', 'transitive_closure', 'translation', 'transpose', 'trapeze', 'trapezoid', 'traveling_salesman', 'tree', 'tree_height', 'tri', 'triangle', 'triangle_paper', 'triangle_plein', 'triangle_point', 'triangle_window', 'trig2exp', 'trigcos', 'trigexpand', 'triginterp', 'trigsimplify', 'trigsin', 'trigtan', 'trim', 'trn', 'true', 'trunc', 'truncate', 'truncate_graph', 'tsimplify', 'tstep', 'tuer', 'tukey_window', 'tutte_polynomial', 'two_edge_connected_components', 'ufactor', 'ugamma', 'unapply', 'unarchive', 'undef', 'underlying_graph', 'unfactored', 'uniform', 'uniform_cdf', 'uniform_icdf', 'uniformd', 'uniformd_cdf', 'uniformd_icdf', 'unitV', 'unquote', 'upper', 'user_operator', 'usimplify', 'ustep', 'valuation', 'vandermonde', 'variables_are_files', 'variance', 'version', 'vertex_connectivity', 'vertex_cover_number', 'vertex_degree', 'vertex_distance', 'vertex_in_degree', 'vertex_out_degree', 'vertices', 'vertices_abc', 'vertices_abca', 'violet', 'vpotential', 'vstep', 'web_graph', 'weibull', 'weibull_cdf', 'weibull_icdf', 'weibulld', 'weibulld_cdf', 'weibulld_icdf', 'weibullvariate', 'weight_decay', 'weight_matrix', 'weighted', 'weights', 'welch_window', 'wheel_graph', 'widget_size', 'wilcoxonp', 'wilcoxons', 'wilcoxont', 'writergb', 'writewav', 'xcas_mode', 'xml_print', 'xstep', 'xyz2rgb', 'xyztrange', 'ystep', 'zeros', 'znorder', 'znprimroot', 'zstep', 'ztrans']             # <<<<<<<<<<<<<<
 * 
 */
  __pyx_t_2 = PyList_New(1600); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Airy_Ai);
  __Pyx_GIVEREF(__pyx_n_s_Airy_Ai);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Airy_Ai)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Airy_Bi);
  __Pyx_GIVEREF(__pyx_n_s_Airy_Bi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_Airy_Bi)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Archive);
  __Pyx_GIVEREF(__pyx_n_s_Archive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_Archive)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_BesselJ);
  __Pyx_GIVEREF(__pyx_n_s_BesselJ);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_BesselJ)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_BesselY);
  __Pyx_GIVEREF(__pyx_n_s_BesselY);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_BesselY)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Beta);
  __Pyx_GIVEREF(__pyx_n_s_Beta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_Beta)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_BlockDiagonal);
  __Pyx_GIVEREF(__pyx_n_s_BlockDiagonal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_s_BlockDiagonal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Ci);
  __Pyx_GIVEREF(__pyx_n_s_Ci);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_s_Ci)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Circle);
  __Pyx_GIVEREF(__pyx_n_s_Circle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 8, __pyx_n_s_Circle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Col);
  __Pyx_GIVEREF(__pyx_n_s_Col);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 9, __pyx_n_s_Col)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CopyVar);
  __Pyx_GIVEREF(__pyx_n_s_CopyVar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 10, __pyx_n_s_CopyVar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Dirac);
  __Pyx_GIVEREF(__pyx_n_s_Dirac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 11, __pyx_n_s_Dirac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Ei);
  __Pyx_GIVEREF(__pyx_n_s_Ei);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 12, __pyx_n_s_Ei)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Factor);
  __Pyx_GIVEREF(__pyx_n_s_Factor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 13, __pyx_n_s_Factor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Fourier);
  __Pyx_GIVEREF(__pyx_n_s_Fourier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 14, __pyx_n_s_Fourier)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_GF);
  __Pyx_GIVEREF(__pyx_n_s_GF);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 15, __pyx_n_s_GF)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Gamma);
  __Pyx_GIVEREF(__pyx_n_s_Gamma);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 16, __pyx_n_s_Gamma)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Heaviside);
  __Pyx_GIVEREF(__pyx_n_s_Heaviside);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 17, __pyx_n_s_Heaviside)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Heaviside2sign);
  __Pyx_GIVEREF(__pyx_n_s_Heaviside2sign);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 18, __pyx_n_s_Heaviside2sign)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Hilbert);
  __Pyx_GIVEREF(__pyx_n_s_Hilbert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 19, __pyx_n_s_Hilbert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_JordanBlock);
  __Pyx_GIVEREF(__pyx_n_s_JordanBlock);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 20, __pyx_n_s_JordanBlock)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LU);
  __Pyx_GIVEREF(__pyx_n_s_LU);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 21, __pyx_n_s_LU)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LambertW);
  __Pyx_GIVEREF(__pyx_n_s_LambertW);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 22, __pyx_n_s_LambertW)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Li);
  __Pyx_GIVEREF(__pyx_n_s_Li);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 23, __pyx_n_s_Li)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Line);
  __Pyx_GIVEREF(__pyx_n_s_Line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 24, __pyx_n_s_Line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LineHorz);
  __Pyx_GIVEREF(__pyx_n_s_LineHorz);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 25, __pyx_n_s_LineHorz)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LineTan);
  __Pyx_GIVEREF(__pyx_n_s_LineTan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 26, __pyx_n_s_LineTan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_LineVert);
  __Pyx_GIVEREF(__pyx_n_s_LineVert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 27, __pyx_n_s_LineVert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_MSE);
  __Pyx_GIVEREF(__pyx_n_s_MSE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 28, __pyx_n_s_MSE)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Phi);
  __Pyx_GIVEREF(__pyx_n_s_Phi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 29, __pyx_n_s_Phi)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Pi);
  __Pyx_GIVEREF(__pyx_n_s_Pi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 30, __pyx_n_s_Pi)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Psi);
  __Pyx_GIVEREF(__pyx_n_s_Psi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 31, __pyx_n_s_Psi)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_QR);
  __Pyx_GIVEREF(__pyx_n_s_QR);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 32, __pyx_n_s_QR)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_RandSeed);
  __Pyx_GIVEREF(__pyx_n_s_RandSeed);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 33, __pyx_n_s_RandSeed)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ReLU);
  __Pyx_GIVEREF(__pyx_n_s_ReLU);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 34, __pyx_n_s_ReLU)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Row);
  __Pyx_GIVEREF(__pyx_n_s_Row);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 35, __pyx_n_s_Row)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SortA);
  __Pyx_GIVEREF(__pyx_n_s_SortA);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 36, __pyx_n_s_SortA)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_SortD);
  __Pyx_GIVEREF(__pyx_n_s_SortD);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 37, __pyx_n_s_SortD)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UTPC);
  __Pyx_GIVEREF(__pyx_n_s_UTPC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 38, __pyx_n_s_UTPC)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UTPF);
  __Pyx_GIVEREF(__pyx_n_s_UTPF);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 39, __pyx_n_s_UTPF)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UTPN);
  __Pyx_GIVEREF(__pyx_n_s_UTPN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 40, __pyx_n_s_UTPN)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_UTPT);
  __Pyx_GIVEREF(__pyx_n_s_UTPT);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 41, __pyx_n_s_UTPT)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_VARS);
  __Pyx_GIVEREF(__pyx_n_s_VARS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 42, __pyx_n_s_VARS)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_VAS);
  __Pyx_GIVEREF(__pyx_n_s_VAS);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 43, __pyx_n_s_VAS)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_VAS_positive);
  __Pyx_GIVEREF(__pyx_n_s_VAS_positive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 44, __pyx_n_s_VAS_positive)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Zeta);
  __Pyx_GIVEREF(__pyx_n_s_Zeta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 45, __pyx_n_s_Zeta)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_a2q);
  __Pyx_GIVEREF(__pyx_n_s_a2q);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 46, __pyx_n_s_a2q)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_abcuv);
  __Pyx_GIVEREF(__pyx_n_s_abcuv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 47, __pyx_n_s_abcuv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_about);
  __Pyx_GIVEREF(__pyx_n_s_about);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 48, __pyx_n_s_about)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_abs);
  __Pyx_GIVEREF(__pyx_n_s_abs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 49, __pyx_n_s_abs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_abscissa);
  __Pyx_GIVEREF(__pyx_n_s_abscissa);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 50, __pyx_n_s_abscissa)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_accumulate_head_tail);
  __Pyx_GIVEREF(__pyx_n_s_accumulate_head_tail);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 51, __pyx_n_s_accumulate_head_tail)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acos);
  __Pyx_GIVEREF(__pyx_n_s_acos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 52, __pyx_n_s_acos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acos2asin);
  __Pyx_GIVEREF(__pyx_n_s_acos2asin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 53, __pyx_n_s_acos2asin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acos2atan);
  __Pyx_GIVEREF(__pyx_n_s_acos2atan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 54, __pyx_n_s_acos2atan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acosh);
  __Pyx_GIVEREF(__pyx_n_s_acosh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 55, __pyx_n_s_acosh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acot);
  __Pyx_GIVEREF(__pyx_n_s_acot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 56, __pyx_n_s_acot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acsc);
  __Pyx_GIVEREF(__pyx_n_s_acsc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 57, __pyx_n_s_acsc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_acyclic);
  __Pyx_GIVEREF(__pyx_n_s_acyclic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 58, __pyx_n_s_acyclic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_adaptive);
  __Pyx_GIVEREF(__pyx_n_s_adaptive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 59, __pyx_n_s_adaptive)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_add);
  __Pyx_GIVEREF(__pyx_n_s_add);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 60, __pyx_n_s_add)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_add_arc);
  __Pyx_GIVEREF(__pyx_n_s_add_arc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 61, __pyx_n_s_add_arc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_add_edge);
  __Pyx_GIVEREF(__pyx_n_s_add_edge);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 62, __pyx_n_s_add_edge)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_add_vertex);
  __Pyx_GIVEREF(__pyx_n_s_add_vertex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 63, __pyx_n_s_add_vertex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_additionally);
  __Pyx_GIVEREF(__pyx_n_s_additionally);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 64, __pyx_n_s_additionally)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_addtable);
  __Pyx_GIVEREF(__pyx_n_s_addtable);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 65, __pyx_n_s_addtable)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_adjacency_matrix);
  __Pyx_GIVEREF(__pyx_n_s_adjacency_matrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 66, __pyx_n_s_adjacency_matrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_adjoint_matrix);
  __Pyx_GIVEREF(__pyx_n_s_adjoint_matrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 67, __pyx_n_s_adjoint_matrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_affix);
  __Pyx_GIVEREF(__pyx_n_s_affix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 68, __pyx_n_s_affix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_algsubs);
  __Pyx_GIVEREF(__pyx_n_s_algsubs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 69, __pyx_n_s_algsubs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_algvar);
  __Pyx_GIVEREF(__pyx_n_s_algvar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 70, __pyx_n_s_algvar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_all_trig_solutions);
  __Pyx_GIVEREF(__pyx_n_s_all_trig_solutions);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 71, __pyx_n_s_all_trig_solutions)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_allpairs_distance);
  __Pyx_GIVEREF(__pyx_n_s_allpairs_distance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 72, __pyx_n_s_allpairs_distance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_alog10);
  __Pyx_GIVEREF(__pyx_n_s_alog10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 73, __pyx_n_s_alog10)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_altitude);
  __Pyx_GIVEREF(__pyx_n_s_altitude);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 74, __pyx_n_s_altitude)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_angle);
  __Pyx_GIVEREF(__pyx_n_s_angle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 75, __pyx_n_s_angle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_angle_radian);
  __Pyx_GIVEREF(__pyx_n_s_angle_radian);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 76, __pyx_n_s_angle_radian)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_angleat);
  __Pyx_GIVEREF(__pyx_n_s_angleat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 77, __pyx_n_s_angleat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_angleatraw);
  __Pyx_GIVEREF(__pyx_n_s_angleatraw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 78, __pyx_n_s_angleatraw)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ans);
  __Pyx_GIVEREF(__pyx_n_s_ans);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 79, __pyx_n_s_ans)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_antiprism_graph);
  __Pyx_GIVEREF(__pyx_n_s_antiprism_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 80, __pyx_n_s_antiprism_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_append);
  __Pyx_GIVEREF(__pyx_n_s_append);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 81, __pyx_n_s_append)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_apply);
  __Pyx_GIVEREF(__pyx_n_s_apply);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 82, __pyx_n_s_apply)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_approx);
  __Pyx_GIVEREF(__pyx_n_s_approx);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 83, __pyx_n_s_approx)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arc);
  __Pyx_GIVEREF(__pyx_n_s_arc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 84, __pyx_n_s_arc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arcLen);
  __Pyx_GIVEREF(__pyx_n_s_arcLen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 85, __pyx_n_s_arcLen)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arccos);
  __Pyx_GIVEREF(__pyx_n_s_arccos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 86, __pyx_n_s_arccos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arccosh);
  __Pyx_GIVEREF(__pyx_n_s_arccosh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 87, __pyx_n_s_arccosh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arclen);
  __Pyx_GIVEREF(__pyx_n_s_arclen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 88, __pyx_n_s_arclen)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arcsin);
  __Pyx_GIVEREF(__pyx_n_s_arcsin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 89, __pyx_n_s_arcsin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arcsinh);
  __Pyx_GIVEREF(__pyx_n_s_arcsinh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 90, __pyx_n_s_arcsinh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arctan);
  __Pyx_GIVEREF(__pyx_n_s_arctan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 91, __pyx_n_s_arctan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arctanh);
  __Pyx_GIVEREF(__pyx_n_s_arctanh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 92, __pyx_n_s_arctanh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_area);
  __Pyx_GIVEREF(__pyx_n_s_area);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 93, __pyx_n_s_area)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_areaat);
  __Pyx_GIVEREF(__pyx_n_s_areaat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 94, __pyx_n_s_areaat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_areaatraw);
  __Pyx_GIVEREF(__pyx_n_s_areaatraw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 95, __pyx_n_s_areaatraw)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_areaplot);
  __Pyx_GIVEREF(__pyx_n_s_areaplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 96, __pyx_n_s_areaplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arg);
  __Pyx_GIVEREF(__pyx_n_s_arg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 97, __pyx_n_s_arg)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_array);
  __Pyx_GIVEREF(__pyx_n_s_array);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 98, __pyx_n_s_array)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_arrivals);
  __Pyx_GIVEREF(__pyx_n_s_arrivals);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 99, __pyx_n_s_arrivals)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_articulation_points);
  __Pyx_GIVEREF(__pyx_n_s_articulation_points);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 100, __pyx_n_s_articulation_points)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_asin);
  __Pyx_GIVEREF(__pyx_n_s_asin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 101, __pyx_n_s_asin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_asin2acos);
  __Pyx_GIVEREF(__pyx_n_s_asin2acos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 102, __pyx_n_s_asin2acos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_asin2atan);
  __Pyx_GIVEREF(__pyx_n_s_asin2atan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 103, __pyx_n_s_asin2atan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_asinh);
  __Pyx_GIVEREF(__pyx_n_s_asinh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 104, __pyx_n_s_asinh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_assign_edge_weights);
  __Pyx_GIVEREF(__pyx_n_s_assign_edge_weights);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 105, __pyx_n_s_assign_edge_weights)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_assume);
  __Pyx_GIVEREF(__pyx_n_s_assume);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 106, __pyx_n_s_assume)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_at);
  __Pyx_GIVEREF(__pyx_n_s_at);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 107, __pyx_n_s_at)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atan);
  __Pyx_GIVEREF(__pyx_n_s_atan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 108, __pyx_n_s_atan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atan2);
  __Pyx_GIVEREF(__pyx_n_s_atan2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 109, __pyx_n_s_atan2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atan2acos);
  __Pyx_GIVEREF(__pyx_n_s_atan2acos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 110, __pyx_n_s_atan2acos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atan2asin);
  __Pyx_GIVEREF(__pyx_n_s_atan2asin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 111, __pyx_n_s_atan2asin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atanh);
  __Pyx_GIVEREF(__pyx_n_s_atanh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 112, __pyx_n_s_atanh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_atrig2ln);
  __Pyx_GIVEREF(__pyx_n_s_atrig2ln);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 113, __pyx_n_s_atrig2ln)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_augment);
  __Pyx_GIVEREF(__pyx_n_s_augment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 114, __pyx_n_s_augment)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_auto_correlation);
  __Pyx_GIVEREF(__pyx_n_s_auto_correlation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 115, __pyx_n_s_auto_correlation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_autosimplify);
  __Pyx_GIVEREF(__pyx_n_s_autosimplify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 116, __pyx_n_s_autosimplify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_avance);
  __Pyx_GIVEREF(__pyx_n_s_avance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 117, __pyx_n_s_avance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_avgRC);
  __Pyx_GIVEREF(__pyx_n_s_avgRC);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 118, __pyx_n_s_avgRC)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_axes);
  __Pyx_GIVEREF(__pyx_n_s_axes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 119, __pyx_n_s_axes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_axis);
  __Pyx_GIVEREF(__pyx_n_s_axis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 120, __pyx_n_s_axis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_back);
  __Pyx_GIVEREF(__pyx_n_s_back);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 121, __pyx_n_s_back)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_backward);
  __Pyx_GIVEREF(__pyx_n_s_backward);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 122, __pyx_n_s_backward)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_baisse_crayon);
  __Pyx_GIVEREF(__pyx_n_s_baisse_crayon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 123, __pyx_n_s_baisse_crayon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bandwidth);
  __Pyx_GIVEREF(__pyx_n_s_bandwidth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 124, __pyx_n_s_bandwidth)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bar_plot);
  __Pyx_GIVEREF(__pyx_n_s_bar_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 125, __pyx_n_s_bar_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_barplot);
  __Pyx_GIVEREF(__pyx_n_s_barplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 126, __pyx_n_s_barplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bartlett_hann_window);
  __Pyx_GIVEREF(__pyx_n_s_bartlett_hann_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 127, __pyx_n_s_bartlett_hann_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_barycenter);
  __Pyx_GIVEREF(__pyx_n_s_barycenter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 128, __pyx_n_s_barycenter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_base);
  __Pyx_GIVEREF(__pyx_n_s_base);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 129, __pyx_n_s_base)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_basis);
  __Pyx_GIVEREF(__pyx_n_s_basis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 130, __pyx_n_s_basis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_batons);
  __Pyx_GIVEREF(__pyx_n_s_batons);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 131, __pyx_n_s_batons)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bellman_ford);
  __Pyx_GIVEREF(__pyx_n_s_bellman_ford);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 132, __pyx_n_s_bellman_ford)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_berlekamp_massey);
  __Pyx_GIVEREF(__pyx_n_s_berlekamp_massey);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 133, __pyx_n_s_berlekamp_massey)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bernoulli);
  __Pyx_GIVEREF(__pyx_n_s_bernoulli);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 134, __pyx_n_s_bernoulli)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bernoulli_mod);
  __Pyx_GIVEREF(__pyx_n_s_bernoulli_mod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 135, __pyx_n_s_bernoulli_mod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_besselJ);
  __Pyx_GIVEREF(__pyx_n_s_besselJ);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 136, __pyx_n_s_besselJ)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_besselY);
  __Pyx_GIVEREF(__pyx_n_s_besselY);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 137, __pyx_n_s_besselY)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_betad);
  __Pyx_GIVEREF(__pyx_n_s_betad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 138, __pyx_n_s_betad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_betad_cdf);
  __Pyx_GIVEREF(__pyx_n_s_betad_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 139, __pyx_n_s_betad_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_betad_icdf);
  __Pyx_GIVEREF(__pyx_n_s_betad_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 140, __pyx_n_s_betad_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_betavariate);
  __Pyx_GIVEREF(__pyx_n_s_betavariate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 141, __pyx_n_s_betavariate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_betweenness_centrality);
  __Pyx_GIVEREF(__pyx_n_s_betweenness_centrality);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 142, __pyx_n_s_betweenness_centrality)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bezier);
  __Pyx_GIVEREF(__pyx_n_s_bezier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 143, __pyx_n_s_bezier)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bezout_entiers);
  __Pyx_GIVEREF(__pyx_n_s_bezout_entiers);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 144, __pyx_n_s_bezout_entiers)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bezoutian);
  __Pyx_GIVEREF(__pyx_n_s_bezoutian);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 145, __pyx_n_s_bezoutian)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_biconnected_components);
  __Pyx_GIVEREF(__pyx_n_s_biconnected_components);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 146, __pyx_n_s_biconnected_components)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_binomial);
  __Pyx_GIVEREF(__pyx_n_s_binomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 147, __pyx_n_s_binomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_binomial_cdf);
  __Pyx_GIVEREF(__pyx_n_s_binomial_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 148, __pyx_n_s_binomial_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_binomial_icdf);
  __Pyx_GIVEREF(__pyx_n_s_binomial_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 149, __pyx_n_s_binomial_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bins);
  __Pyx_GIVEREF(__pyx_n_s_bins);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 150, __pyx_n_s_bins)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bipartite);
  __Pyx_GIVEREF(__pyx_n_s_bipartite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 151, __pyx_n_s_bipartite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bipartite_matching);
  __Pyx_GIVEREF(__pyx_n_s_bipartite_matching);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 152, __pyx_n_s_bipartite_matching)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bisection_solver);
  __Pyx_GIVEREF(__pyx_n_s_bisection_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 153, __pyx_n_s_bisection_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bisector);
  __Pyx_GIVEREF(__pyx_n_s_bisector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 154, __pyx_n_s_bisector)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bit_depth);
  __Pyx_GIVEREF(__pyx_n_s_bit_depth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 155, __pyx_n_s_bit_depth)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bitand);
  __Pyx_GIVEREF(__pyx_n_s_bitand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 156, __pyx_n_s_bitand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bitor);
  __Pyx_GIVEREF(__pyx_n_s_bitor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 157, __pyx_n_s_bitor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bitxor);
  __Pyx_GIVEREF(__pyx_n_s_bitxor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 158, __pyx_n_s_bitxor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_blackman_harris_window);
  __Pyx_GIVEREF(__pyx_n_s_blackman_harris_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 159, __pyx_n_s_blackman_harris_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_blackman_window);
  __Pyx_GIVEREF(__pyx_n_s_blackman_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 160, __pyx_n_s_blackman_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_block_size);
  __Pyx_GIVEREF(__pyx_n_s_block_size);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 161, __pyx_n_s_block_size)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_blockmatrix);
  __Pyx_GIVEREF(__pyx_n_s_blockmatrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 162, __pyx_n_s_blockmatrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bohman_window);
  __Pyx_GIVEREF(__pyx_n_s_bohman_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 163, __pyx_n_s_bohman_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_border);
  __Pyx_GIVEREF(__pyx_n_s_border);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 164, __pyx_n_s_border)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_box_constraints);
  __Pyx_GIVEREF(__pyx_n_s_box_constraints);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 165, __pyx_n_s_box_constraints)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_boxcar);
  __Pyx_GIVEREF(__pyx_n_s_boxcar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 166, __pyx_n_s_boxcar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_boxwhisker);
  __Pyx_GIVEREF(__pyx_n_s_boxwhisker);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 167, __pyx_n_s_boxwhisker)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_brent_solver);
  __Pyx_GIVEREF(__pyx_n_s_brent_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 168, __pyx_n_s_brent_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_brown);
  __Pyx_GIVEREF(__pyx_n_s_brown);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 169, __pyx_n_s_brown)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bspline);
  __Pyx_GIVEREF(__pyx_n_s_bspline);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 170, __pyx_n_s_bspline)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_bvpsolve);
  __Pyx_GIVEREF(__pyx_n_s_bvpsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 171, __pyx_n_s_bvpsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cFactor);
  __Pyx_GIVEREF(__pyx_n_s_cFactor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 172, __pyx_n_s_cFactor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cSolve);
  __Pyx_GIVEREF(__pyx_n_s_cSolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 173, __pyx_n_s_cSolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cZeros);
  __Pyx_GIVEREF(__pyx_n_s_cZeros);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 174, __pyx_n_s_cZeros)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_camembert);
  __Pyx_GIVEREF(__pyx_n_s_camembert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 175, __pyx_n_s_camembert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_canonical_form);
  __Pyx_GIVEREF(__pyx_n_s_canonical_form);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 176, __pyx_n_s_canonical_form)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_canonical_labeling);
  __Pyx_GIVEREF(__pyx_n_s_canonical_labeling);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 177, __pyx_n_s_canonical_labeling)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cartesian_product);
  __Pyx_GIVEREF(__pyx_n_s_cartesian_product);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 178, __pyx_n_s_cartesian_product)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cauchy);
  __Pyx_GIVEREF(__pyx_n_s_cauchy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 179, __pyx_n_s_cauchy)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cauchy_cdf);
  __Pyx_GIVEREF(__pyx_n_s_cauchy_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 180, __pyx_n_s_cauchy_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cauchy_icdf);
  __Pyx_GIVEREF(__pyx_n_s_cauchy_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 181, __pyx_n_s_cauchy_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cauchyd);
  __Pyx_GIVEREF(__pyx_n_s_cauchyd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 182, __pyx_n_s_cauchyd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cauchyd_cdf);
  __Pyx_GIVEREF(__pyx_n_s_cauchyd_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 183, __pyx_n_s_cauchyd_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cauchyd_icdf);
  __Pyx_GIVEREF(__pyx_n_s_cauchyd_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 184, __pyx_n_s_cauchyd_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cdf);
  __Pyx_GIVEREF(__pyx_n_s_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 185, __pyx_n_s_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ceil);
  __Pyx_GIVEREF(__pyx_n_s_ceil);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 186, __pyx_n_s_ceil)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ceiling);
  __Pyx_GIVEREF(__pyx_n_s_ceiling);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 187, __pyx_n_s_ceiling)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_center);
  __Pyx_GIVEREF(__pyx_n_s_center);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 188, __pyx_n_s_center)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_center2interval);
  __Pyx_GIVEREF(__pyx_n_s_center2interval);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 189, __pyx_n_s_center2interval)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_centered_cube);
  __Pyx_GIVEREF(__pyx_n_s_centered_cube);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 190, __pyx_n_s_centered_cube)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_centered_tetrahedron);
  __Pyx_GIVEREF(__pyx_n_s_centered_tetrahedron);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 191, __pyx_n_s_centered_tetrahedron)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cfactor);
  __Pyx_GIVEREF(__pyx_n_s_cfactor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 192, __pyx_n_s_cfactor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cfsolve);
  __Pyx_GIVEREF(__pyx_n_s_cfsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 193, __pyx_n_s_cfsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_changebase);
  __Pyx_GIVEREF(__pyx_n_s_changebase);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 194, __pyx_n_s_changebase)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_channel_data);
  __Pyx_GIVEREF(__pyx_n_s_channel_data);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 195, __pyx_n_s_channel_data)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_channels);
  __Pyx_GIVEREF(__pyx_n_s_channels);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 196, __pyx_n_s_channels)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_char);
  __Pyx_GIVEREF(__pyx_n_s_char);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 197, __pyx_n_s_char)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_charpoly);
  __Pyx_GIVEREF(__pyx_n_s_charpoly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 198, __pyx_n_s_charpoly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chinrem);
  __Pyx_GIVEREF(__pyx_n_s_chinrem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 199, __pyx_n_s_chinrem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquare);
  __Pyx_GIVEREF(__pyx_n_s_chisquare);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 200, __pyx_n_s_chisquare)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquare_cdf);
  __Pyx_GIVEREF(__pyx_n_s_chisquare_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 201, __pyx_n_s_chisquare_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquare_icdf);
  __Pyx_GIVEREF(__pyx_n_s_chisquare_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 202, __pyx_n_s_chisquare_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquared);
  __Pyx_GIVEREF(__pyx_n_s_chisquared);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 203, __pyx_n_s_chisquared)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquared_cdf);
  __Pyx_GIVEREF(__pyx_n_s_chisquared_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 204, __pyx_n_s_chisquared_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquared_icdf);
  __Pyx_GIVEREF(__pyx_n_s_chisquared_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 205, __pyx_n_s_chisquared_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chisquaret);
  __Pyx_GIVEREF(__pyx_n_s_chisquaret);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 206, __pyx_n_s_chisquaret)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_choice);
  __Pyx_GIVEREF(__pyx_n_s_choice);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 207, __pyx_n_s_choice)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cholesky);
  __Pyx_GIVEREF(__pyx_n_s_cholesky);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 208, __pyx_n_s_cholesky)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chr);
  __Pyx_GIVEREF(__pyx_n_s_chr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 209, __pyx_n_s_chr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chrem);
  __Pyx_GIVEREF(__pyx_n_s_chrem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 210, __pyx_n_s_chrem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chromatic_index);
  __Pyx_GIVEREF(__pyx_n_s_chromatic_index);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 211, __pyx_n_s_chromatic_index)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chromatic_number);
  __Pyx_GIVEREF(__pyx_n_s_chromatic_number);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 212, __pyx_n_s_chromatic_number)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_chromatic_polynomial);
  __Pyx_GIVEREF(__pyx_n_s_chromatic_polynomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 213, __pyx_n_s_chromatic_polynomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_circle);
  __Pyx_GIVEREF(__pyx_n_s_circle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 214, __pyx_n_s_circle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_circumcircle);
  __Pyx_GIVEREF(__pyx_n_s_circumcircle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 215, __pyx_n_s_circumcircle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_classes);
  __Pyx_GIVEREF(__pyx_n_s_classes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 216, __pyx_n_s_classes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_clear);
  __Pyx_GIVEREF(__pyx_n_s_clear);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 217, __pyx_n_s_clear)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_clique_cover);
  __Pyx_GIVEREF(__pyx_n_s_clique_cover);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 218, __pyx_n_s_clique_cover)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_clique_cover_number);
  __Pyx_GIVEREF(__pyx_n_s_clique_cover_number);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 219, __pyx_n_s_clique_cover_number)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_clique_number);
  __Pyx_GIVEREF(__pyx_n_s_clique_number);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 220, __pyx_n_s_clique_number)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_closeness_centrality);
  __Pyx_GIVEREF(__pyx_n_s_closeness_centrality);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 221, __pyx_n_s_closeness_centrality)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cluster);
  __Pyx_GIVEREF(__pyx_n_s_cluster);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 222, __pyx_n_s_cluster)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_clustering_coefficient);
  __Pyx_GIVEREF(__pyx_n_s_clustering_coefficient);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 223, __pyx_n_s_clustering_coefficient)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_coeff);
  __Pyx_GIVEREF(__pyx_n_s_coeff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 224, __pyx_n_s_coeff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_coeffs);
  __Pyx_GIVEREF(__pyx_n_s_coeffs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 225, __pyx_n_s_coeffs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_col);
  __Pyx_GIVEREF(__pyx_n_s_col);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 226, __pyx_n_s_col)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colDim);
  __Pyx_GIVEREF(__pyx_n_s_colDim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 227, __pyx_n_s_colDim)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colNorm);
  __Pyx_GIVEREF(__pyx_n_s_colNorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 228, __pyx_n_s_colNorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colSwap);
  __Pyx_GIVEREF(__pyx_n_s_colSwap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 229, __pyx_n_s_colSwap)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_coldim);
  __Pyx_GIVEREF(__pyx_n_s_coldim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 230, __pyx_n_s_coldim)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_collect);
  __Pyx_GIVEREF(__pyx_n_s_collect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 231, __pyx_n_s_collect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colnorm);
  __Pyx_GIVEREF(__pyx_n_s_colnorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 232, __pyx_n_s_colnorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_color);
  __Pyx_GIVEREF(__pyx_n_s_color);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 233, __pyx_n_s_color)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colormap);
  __Pyx_GIVEREF(__pyx_n_s_colormap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 234, __pyx_n_s_colormap)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colspace);
  __Pyx_GIVEREF(__pyx_n_s_colspace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 235, __pyx_n_s_colspace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_colswap);
  __Pyx_GIVEREF(__pyx_n_s_colswap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 236, __pyx_n_s_colswap)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_comDenom);
  __Pyx_GIVEREF(__pyx_n_s_comDenom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 237, __pyx_n_s_comDenom)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_comb);
  __Pyx_GIVEREF(__pyx_n_s_comb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 238, __pyx_n_s_comb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_combine);
  __Pyx_GIVEREF(__pyx_n_s_combine);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 239, __pyx_n_s_combine)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_comment);
  __Pyx_GIVEREF(__pyx_n_s_comment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 240, __pyx_n_s_comment)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_common_perpendicular);
  __Pyx_GIVEREF(__pyx_n_s_common_perpendicular);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 241, __pyx_n_s_common_perpendicular)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_companion);
  __Pyx_GIVEREF(__pyx_n_s_companion);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 242, __pyx_n_s_companion)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_compare);
  __Pyx_GIVEREF(__pyx_n_s_compare);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 243, __pyx_n_s_compare)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complete_binary_tree);
  __Pyx_GIVEREF(__pyx_n_s_complete_binary_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 244, __pyx_n_s_complete_binary_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complete_graph);
  __Pyx_GIVEREF(__pyx_n_s_complete_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 245, __pyx_n_s_complete_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complete_kary_tree);
  __Pyx_GIVEREF(__pyx_n_s_complete_kary_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 246, __pyx_n_s_complete_kary_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complex);
  __Pyx_GIVEREF(__pyx_n_s_complex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 247, __pyx_n_s_complex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complex_variables);
  __Pyx_GIVEREF(__pyx_n_s_complex_variables);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 248, __pyx_n_s_complex_variables)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_complexroot);
  __Pyx_GIVEREF(__pyx_n_s_complexroot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 249, __pyx_n_s_complexroot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_concat);
  __Pyx_GIVEREF(__pyx_n_s_concat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 250, __pyx_n_s_concat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cond);
  __Pyx_GIVEREF(__pyx_n_s_cond);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 251, __pyx_n_s_cond)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_condensation);
  __Pyx_GIVEREF(__pyx_n_s_condensation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 252, __pyx_n_s_condensation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cone);
  __Pyx_GIVEREF(__pyx_n_s_cone);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 253, __pyx_n_s_cone)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_confrac);
  __Pyx_GIVEREF(__pyx_n_s_confrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 254, __pyx_n_s_confrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_conic);
  __Pyx_GIVEREF(__pyx_n_s_conic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 255, __pyx_n_s_conic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_conj);
  __Pyx_GIVEREF(__pyx_n_s_conj);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 256, __pyx_n_s_conj)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_conjugate_equation);
  __Pyx_GIVEREF(__pyx_n_s_conjugate_equation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 257, __pyx_n_s_conjugate_equation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_conjugate_gradient);
  __Pyx_GIVEREF(__pyx_n_s_conjugate_gradient);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 258, __pyx_n_s_conjugate_gradient)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_connected);
  __Pyx_GIVEREF(__pyx_n_s_connected);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 259, __pyx_n_s_connected)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_connected_components);
  __Pyx_GIVEREF(__pyx_n_s_connected_components);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 260, __pyx_n_s_connected_components)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cont);
  __Pyx_GIVEREF(__pyx_n_s_cont);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 261, __pyx_n_s_cont)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_contains);
  __Pyx_GIVEREF(__pyx_n_s_contains);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 262, __pyx_n_s_contains)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_content);
  __Pyx_GIVEREF(__pyx_n_s_content);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 263, __pyx_n_s_content)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_contourplot);
  __Pyx_GIVEREF(__pyx_n_s_contourplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 264, __pyx_n_s_contourplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_contract_edge);
  __Pyx_GIVEREF(__pyx_n_s_contract_edge);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 265, __pyx_n_s_contract_edge)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_contract_subgraph);
  __Pyx_GIVEREF(__pyx_n_s_contract_subgraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 266, __pyx_n_s_contract_subgraph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_convert);
  __Pyx_GIVEREF(__pyx_n_s_convert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 267, __pyx_n_s_convert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_convertir);
  __Pyx_GIVEREF(__pyx_n_s_convertir);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 268, __pyx_n_s_convertir)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_convex);
  __Pyx_GIVEREF(__pyx_n_s_convex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 269, __pyx_n_s_convex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_convexhull);
  __Pyx_GIVEREF(__pyx_n_s_convexhull);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 270, __pyx_n_s_convexhull)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_convolution);
  __Pyx_GIVEREF(__pyx_n_s_convolution);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 271, __pyx_n_s_convolution)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_coordinates);
  __Pyx_GIVEREF(__pyx_n_s_coordinates);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 272, __pyx_n_s_coordinates)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_copy);
  __Pyx_GIVEREF(__pyx_n_s_copy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 273, __pyx_n_s_copy)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_correlation);
  __Pyx_GIVEREF(__pyx_n_s_correlation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 274, __pyx_n_s_correlation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cos);
  __Pyx_GIVEREF(__pyx_n_s_cos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 275, __pyx_n_s_cos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cos2sintan);
  __Pyx_GIVEREF(__pyx_n_s_cos2sintan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 276, __pyx_n_s_cos2sintan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cosh);
  __Pyx_GIVEREF(__pyx_n_s_cosh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 277, __pyx_n_s_cosh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cosine_window);
  __Pyx_GIVEREF(__pyx_n_s_cosine_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 278, __pyx_n_s_cosine_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cot);
  __Pyx_GIVEREF(__pyx_n_s_cot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 279, __pyx_n_s_cot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cote);
  __Pyx_GIVEREF(__pyx_n_s_cote);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 280, __pyx_n_s_cote)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_count);
  __Pyx_GIVEREF(__pyx_n_s_count);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 281, __pyx_n_s_count)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_count_eq);
  __Pyx_GIVEREF(__pyx_n_s_count_eq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 282, __pyx_n_s_count_eq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_count_inf);
  __Pyx_GIVEREF(__pyx_n_s_count_inf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 283, __pyx_n_s_count_inf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_count_sup);
  __Pyx_GIVEREF(__pyx_n_s_count_sup);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 284, __pyx_n_s_count_sup)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_courbe_parametrique);
  __Pyx_GIVEREF(__pyx_n_s_courbe_parametrique);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 285, __pyx_n_s_courbe_parametrique)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_courbe_polaire);
  __Pyx_GIVEREF(__pyx_n_s_courbe_polaire);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 286, __pyx_n_s_courbe_polaire)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_covariance);
  __Pyx_GIVEREF(__pyx_n_s_covariance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 287, __pyx_n_s_covariance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_covariance_correlation);
  __Pyx_GIVEREF(__pyx_n_s_covariance_correlation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 288, __pyx_n_s_covariance_correlation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cpartfrac);
  __Pyx_GIVEREF(__pyx_n_s_cpartfrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 289, __pyx_n_s_cpartfrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_crationalroot);
  __Pyx_GIVEREF(__pyx_n_s_crationalroot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 290, __pyx_n_s_crationalroot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_crayon);
  __Pyx_GIVEREF(__pyx_n_s_crayon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 291, __pyx_n_s_crayon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_createwav);
  __Pyx_GIVEREF(__pyx_n_s_createwav);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 292, __pyx_n_s_createwav)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cross);
  __Pyx_GIVEREF(__pyx_n_s_cross);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 293, __pyx_n_s_cross)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_crossP);
  __Pyx_GIVEREF(__pyx_n_s_crossP);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 294, __pyx_n_s_crossP)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cross_correlation);
  __Pyx_GIVEREF(__pyx_n_s_cross_correlation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 295, __pyx_n_s_cross_correlation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cross_entropy);
  __Pyx_GIVEREF(__pyx_n_s_cross_entropy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 296, __pyx_n_s_cross_entropy)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cross_point);
  __Pyx_GIVEREF(__pyx_n_s_cross_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 297, __pyx_n_s_cross_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cross_ratio);
  __Pyx_GIVEREF(__pyx_n_s_cross_ratio);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 298, __pyx_n_s_cross_ratio)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_crossproduct);
  __Pyx_GIVEREF(__pyx_n_s_crossproduct);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 299, __pyx_n_s_crossproduct)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_csc);
  __Pyx_GIVEREF(__pyx_n_s_csc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 300, __pyx_n_s_csc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_csolve);
  __Pyx_GIVEREF(__pyx_n_s_csolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 301, __pyx_n_s_csolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_csv2gen);
  __Pyx_GIVEREF(__pyx_n_s_csv2gen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 302, __pyx_n_s_csv2gen)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cube);
  __Pyx_GIVEREF(__pyx_n_s_cube);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 303, __pyx_n_s_cube)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cumSum);
  __Pyx_GIVEREF(__pyx_n_s_cumSum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 304, __pyx_n_s_cumSum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cumsum);
  __Pyx_GIVEREF(__pyx_n_s_cumsum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 305, __pyx_n_s_cumsum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cumulated_frequencies);
  __Pyx_GIVEREF(__pyx_n_s_cumulated_frequencies);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 306, __pyx_n_s_cumulated_frequencies)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_curl);
  __Pyx_GIVEREF(__pyx_n_s_curl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 307, __pyx_n_s_curl)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_current_sheet);
  __Pyx_GIVEREF(__pyx_n_s_current_sheet);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 308, __pyx_n_s_current_sheet)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_curvature);
  __Pyx_GIVEREF(__pyx_n_s_curvature);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 309, __pyx_n_s_curvature)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_curve);
  __Pyx_GIVEREF(__pyx_n_s_curve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 310, __pyx_n_s_curve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cyan);
  __Pyx_GIVEREF(__pyx_n_s_cyan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 311, __pyx_n_s_cyan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cycle2perm);
  __Pyx_GIVEREF(__pyx_n_s_cycle2perm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 312, __pyx_n_s_cycle2perm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cycle_basis);
  __Pyx_GIVEREF(__pyx_n_s_cycle_basis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 313, __pyx_n_s_cycle_basis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cycle_graph);
  __Pyx_GIVEREF(__pyx_n_s_cycle_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 314, __pyx_n_s_cycle_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cycleinv);
  __Pyx_GIVEREF(__pyx_n_s_cycleinv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 315, __pyx_n_s_cycleinv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cycles2permu);
  __Pyx_GIVEREF(__pyx_n_s_cycles2permu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 316, __pyx_n_s_cycles2permu)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cyclotomic);
  __Pyx_GIVEREF(__pyx_n_s_cyclotomic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 317, __pyx_n_s_cyclotomic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_cylinder);
  __Pyx_GIVEREF(__pyx_n_s_cylinder);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 318, __pyx_n_s_cylinder)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dash_line);
  __Pyx_GIVEREF(__pyx_n_s_dash_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 319, __pyx_n_s_dash_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dashdot_line);
  __Pyx_GIVEREF(__pyx_n_s_dashdot_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 320, __pyx_n_s_dashdot_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dashdotdot_line);
  __Pyx_GIVEREF(__pyx_n_s_dashdotdot_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 321, __pyx_n_s_dashdotdot_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dayofweek);
  __Pyx_GIVEREF(__pyx_n_s_dayofweek);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 322, __pyx_n_s_dayofweek)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_deSolve);
  __Pyx_GIVEREF(__pyx_n_s_deSolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 323, __pyx_n_s_deSolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_debut_enregistrement);
  __Pyx_GIVEREF(__pyx_n_s_debut_enregistrement);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 324, __pyx_n_s_debut_enregistrement)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_degree);
  __Pyx_GIVEREF(__pyx_n_s_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 325, __pyx_n_s_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_degree_centrality);
  __Pyx_GIVEREF(__pyx_n_s_degree_centrality);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 326, __pyx_n_s_degree_centrality)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_degree_sequence);
  __Pyx_GIVEREF(__pyx_n_s_degree_sequence);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 327, __pyx_n_s_degree_sequence)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_degrees);
  __Pyx_GIVEREF(__pyx_n_s_degrees);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 328, __pyx_n_s_degrees)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_delcols);
  __Pyx_GIVEREF(__pyx_n_s_delcols);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 329, __pyx_n_s_delcols)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_delete_arc);
  __Pyx_GIVEREF(__pyx_n_s_delete_arc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 330, __pyx_n_s_delete_arc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_delete_edge);
  __Pyx_GIVEREF(__pyx_n_s_delete_edge);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 331, __pyx_n_s_delete_edge)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_delete_vertex);
  __Pyx_GIVEREF(__pyx_n_s_delete_vertex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 332, __pyx_n_s_delete_vertex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_delrows);
  __Pyx_GIVEREF(__pyx_n_s_delrows);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 333, __pyx_n_s_delrows)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_deltalist);
  __Pyx_GIVEREF(__pyx_n_s_deltalist);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 334, __pyx_n_s_deltalist)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_denom);
  __Pyx_GIVEREF(__pyx_n_s_denom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 335, __pyx_n_s_denom)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_densityplot);
  __Pyx_GIVEREF(__pyx_n_s_densityplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 336, __pyx_n_s_densityplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_departures);
  __Pyx_GIVEREF(__pyx_n_s_departures);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 337, __pyx_n_s_departures)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_derive);
  __Pyx_GIVEREF(__pyx_n_s_derive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 338, __pyx_n_s_derive)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_deriver);
  __Pyx_GIVEREF(__pyx_n_s_deriver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 339, __pyx_n_s_deriver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_desolve);
  __Pyx_GIVEREF(__pyx_n_s_desolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 340, __pyx_n_s_desolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dessine_tortue);
  __Pyx_GIVEREF(__pyx_n_s_dessine_tortue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 341, __pyx_n_s_dessine_tortue)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_det);
  __Pyx_GIVEREF(__pyx_n_s_det);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 342, __pyx_n_s_det)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_det_minor);
  __Pyx_GIVEREF(__pyx_n_s_det_minor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 343, __pyx_n_s_det_minor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_developper);
  __Pyx_GIVEREF(__pyx_n_s_developper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 344, __pyx_n_s_developper)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_developper_transcendant);
  __Pyx_GIVEREF(__pyx_n_s_developper_transcendant);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 345, __pyx_n_s_developper_transcendant)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dfc);
  __Pyx_GIVEREF(__pyx_n_s_dfc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 346, __pyx_n_s_dfc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dfc2f);
  __Pyx_GIVEREF(__pyx_n_s_dfc2f);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 347, __pyx_n_s_dfc2f)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_diag);
  __Pyx_GIVEREF(__pyx_n_s_diag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 348, __pyx_n_s_diag)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_diff);
  __Pyx_GIVEREF(__pyx_n_s_diff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 349, __pyx_n_s_diff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_digraph);
  __Pyx_GIVEREF(__pyx_n_s_digraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 350, __pyx_n_s_digraph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dijkstra);
  __Pyx_GIVEREF(__pyx_n_s_dijkstra);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 351, __pyx_n_s_dijkstra)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dim);
  __Pyx_GIVEREF(__pyx_n_s_dim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 352, __pyx_n_s_dim)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_directed);
  __Pyx_GIVEREF(__pyx_n_s_directed);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 353, __pyx_n_s_directed)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_discard_edge_attribute);
  __Pyx_GIVEREF(__pyx_n_s_discard_edge_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 354, __pyx_n_s_discard_edge_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_discard_graph_attribute);
  __Pyx_GIVEREF(__pyx_n_s_discard_graph_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 355, __pyx_n_s_discard_graph_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_discard_vertex_attribute);
  __Pyx_GIVEREF(__pyx_n_s_discard_vertex_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 356, __pyx_n_s_discard_vertex_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_disjoint_union);
  __Pyx_GIVEREF(__pyx_n_s_disjoint_union);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 357, __pyx_n_s_disjoint_union)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_display);
  __Pyx_GIVEREF(__pyx_n_s_display);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 358, __pyx_n_s_display)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_disque);
  __Pyx_GIVEREF(__pyx_n_s_disque);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 359, __pyx_n_s_disque)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_disque_centre);
  __Pyx_GIVEREF(__pyx_n_s_disque_centre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 360, __pyx_n_s_disque_centre)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_distance);
  __Pyx_GIVEREF(__pyx_n_s_distance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 361, __pyx_n_s_distance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_distance2);
  __Pyx_GIVEREF(__pyx_n_s_distance2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 362, __pyx_n_s_distance2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_distanceat);
  __Pyx_GIVEREF(__pyx_n_s_distanceat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 363, __pyx_n_s_distanceat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_distanceatraw);
  __Pyx_GIVEREF(__pyx_n_s_distanceatraw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 364, __pyx_n_s_distanceatraw)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_divergence);
  __Pyx_GIVEREF(__pyx_n_s_divergence);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 365, __pyx_n_s_divergence)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_divide);
  __Pyx_GIVEREF(__pyx_n_s_divide);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 366, __pyx_n_s_divide)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_divis);
  __Pyx_GIVEREF(__pyx_n_s_divis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 367, __pyx_n_s_divis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_division_point);
  __Pyx_GIVEREF(__pyx_n_s_division_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 368, __pyx_n_s_division_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_divisors);
  __Pyx_GIVEREF(__pyx_n_s_divisors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 369, __pyx_n_s_divisors)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_divmod);
  __Pyx_GIVEREF(__pyx_n_s_divmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 370, __pyx_n_s_divmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_divpc);
  __Pyx_GIVEREF(__pyx_n_s_divpc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 371, __pyx_n_s_divpc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dnewton_solver);
  __Pyx_GIVEREF(__pyx_n_s_dnewton_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 372, __pyx_n_s_dnewton_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dodecahedron);
  __Pyx_GIVEREF(__pyx_n_s_dodecahedron);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 373, __pyx_n_s_dodecahedron)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_domain);
  __Pyx_GIVEREF(__pyx_n_s_domain);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 374, __pyx_n_s_domain)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dot);
  __Pyx_GIVEREF(__pyx_n_s_dot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 375, __pyx_n_s_dot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dotP);
  __Pyx_GIVEREF(__pyx_n_s_dotP);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 376, __pyx_n_s_dotP)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dot_paper);
  __Pyx_GIVEREF(__pyx_n_s_dot_paper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 377, __pyx_n_s_dot_paper)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dotprod);
  __Pyx_GIVEREF(__pyx_n_s_dotprod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 378, __pyx_n_s_dotprod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_arc);
  __Pyx_GIVEREF(__pyx_n_s_draw_arc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 379, __pyx_n_s_draw_arc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_circle);
  __Pyx_GIVEREF(__pyx_n_s_draw_circle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 380, __pyx_n_s_draw_circle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_graph);
  __Pyx_GIVEREF(__pyx_n_s_draw_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 381, __pyx_n_s_draw_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_line);
  __Pyx_GIVEREF(__pyx_n_s_draw_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 382, __pyx_n_s_draw_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_pixel);
  __Pyx_GIVEREF(__pyx_n_s_draw_pixel);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 383, __pyx_n_s_draw_pixel)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_polygon);
  __Pyx_GIVEREF(__pyx_n_s_draw_polygon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 384, __pyx_n_s_draw_polygon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_draw_rectangle);
  __Pyx_GIVEREF(__pyx_n_s_draw_rectangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 385, __pyx_n_s_draw_rectangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_droit);
  __Pyx_GIVEREF(__pyx_n_s_droit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 386, __pyx_n_s_droit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_droite_tangente);
  __Pyx_GIVEREF(__pyx_n_s_droite_tangente);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 387, __pyx_n_s_droite_tangente)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dsolve);
  __Pyx_GIVEREF(__pyx_n_s_dsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 388, __pyx_n_s_dsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_duration);
  __Pyx_GIVEREF(__pyx_n_s_duration);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 389, __pyx_n_s_duration)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_dwt);
  __Pyx_GIVEREF(__pyx_n_s_dwt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 390, __pyx_n_s_dwt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_e);
  __Pyx_GIVEREF(__pyx_n_s_e);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 391, __pyx_n_s_e)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_e2r);
  __Pyx_GIVEREF(__pyx_n_s_e2r);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 392, __pyx_n_s_e2r)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ecart_type);
  __Pyx_GIVEREF(__pyx_n_s_ecart_type);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 393, __pyx_n_s_ecart_type)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ecart_type_population);
  __Pyx_GIVEREF(__pyx_n_s_ecart_type_population);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 394, __pyx_n_s_ecart_type_population)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ecef2geodetic);
  __Pyx_GIVEREF(__pyx_n_s_ecef2geodetic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 395, __pyx_n_s_ecef2geodetic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ecm_factor);
  __Pyx_GIVEREF(__pyx_n_s_ecm_factor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 396, __pyx_n_s_ecm_factor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_edge_connectivity);
  __Pyx_GIVEREF(__pyx_n_s_edge_connectivity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 397, __pyx_n_s_edge_connectivity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_edges);
  __Pyx_GIVEREF(__pyx_n_s_edges);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 398, __pyx_n_s_edges)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_egcd);
  __Pyx_GIVEREF(__pyx_n_s_egcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 399, __pyx_n_s_egcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_egv);
  __Pyx_GIVEREF(__pyx_n_s_egv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 400, __pyx_n_s_egv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_egvl);
  __Pyx_GIVEREF(__pyx_n_s_egvl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 401, __pyx_n_s_egvl)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eigVc);
  __Pyx_GIVEREF(__pyx_n_s_eigVc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 402, __pyx_n_s_eigVc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eigVl);
  __Pyx_GIVEREF(__pyx_n_s_eigVl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 403, __pyx_n_s_eigVl)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eigenvals);
  __Pyx_GIVEREF(__pyx_n_s_eigenvals);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 404, __pyx_n_s_eigenvals)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eigenvalues);
  __Pyx_GIVEREF(__pyx_n_s_eigenvalues);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 405, __pyx_n_s_eigenvalues)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eigenvectors);
  __Pyx_GIVEREF(__pyx_n_s_eigenvectors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 406, __pyx_n_s_eigenvectors)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eigenvects);
  __Pyx_GIVEREF(__pyx_n_s_eigenvects);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 407, __pyx_n_s_eigenvects)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_element);
  __Pyx_GIVEREF(__pyx_n_s_element);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 408, __pyx_n_s_element)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eliminate);
  __Pyx_GIVEREF(__pyx_n_s_eliminate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 409, __pyx_n_s_eliminate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ellipse);
  __Pyx_GIVEREF(__pyx_n_s_ellipse);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 410, __pyx_n_s_ellipse)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_emd);
  __Pyx_GIVEREF(__pyx_n_s_emd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 411, __pyx_n_s_emd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_entry);
  __Pyx_GIVEREF(__pyx_n_s_entry);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 412, __pyx_n_s_entry)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_envelope);
  __Pyx_GIVEREF(__pyx_n_s_envelope);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 413, __pyx_n_s_envelope)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epsilon);
  __Pyx_GIVEREF(__pyx_n_s_epsilon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 414, __pyx_n_s_epsilon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_epsilon2zero);
  __Pyx_GIVEREF(__pyx_n_s_epsilon2zero);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 415, __pyx_n_s_epsilon2zero)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_equal);
  __Pyx_GIVEREF(__pyx_n_s_equal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 416, __pyx_n_s_equal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_equal2diff);
  __Pyx_GIVEREF(__pyx_n_s_equal2diff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 417, __pyx_n_s_equal2diff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_equal2list);
  __Pyx_GIVEREF(__pyx_n_s_equal2list);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 418, __pyx_n_s_equal2list)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_equation);
  __Pyx_GIVEREF(__pyx_n_s_equation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 419, __pyx_n_s_equation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_equilateral_triangle);
  __Pyx_GIVEREF(__pyx_n_s_equilateral_triangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 420, __pyx_n_s_equilateral_triangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_erf);
  __Pyx_GIVEREF(__pyx_n_s_erf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 421, __pyx_n_s_erf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_erfc);
  __Pyx_GIVEREF(__pyx_n_s_erfc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 422, __pyx_n_s_erfc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_error);
  __Pyx_GIVEREF(__pyx_n_s_error);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 423, __pyx_n_s_error)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_est_permu);
  __Pyx_GIVEREF(__pyx_n_s_est_permu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 424, __pyx_n_s_est_permu)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_euler);
  __Pyx_GIVEREF(__pyx_n_s_euler);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 425, __pyx_n_s_euler)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_euler_gamma);
  __Pyx_GIVEREF(__pyx_n_s_euler_gamma);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 426, __pyx_n_s_euler_gamma)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_euler_lagrange);
  __Pyx_GIVEREF(__pyx_n_s_euler_lagrange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 427, __pyx_n_s_euler_lagrange)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_eval_level);
  __Pyx_GIVEREF(__pyx_n_s_eval_level);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 428, __pyx_n_s_eval_level)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_evala);
  __Pyx_GIVEREF(__pyx_n_s_evala);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 429, __pyx_n_s_evala)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_evalb);
  __Pyx_GIVEREF(__pyx_n_s_evalb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 430, __pyx_n_s_evalb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_evalc);
  __Pyx_GIVEREF(__pyx_n_s_evalc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 431, __pyx_n_s_evalc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_evalf);
  __Pyx_GIVEREF(__pyx_n_s_evalf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 432, __pyx_n_s_evalf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_evalm);
  __Pyx_GIVEREF(__pyx_n_s_evalm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 433, __pyx_n_s_evalm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_even);
  __Pyx_GIVEREF(__pyx_n_s_even);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 434, __pyx_n_s_even)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_evolute);
  __Pyx_GIVEREF(__pyx_n_s_evolute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 435, __pyx_n_s_evolute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exact);
  __Pyx_GIVEREF(__pyx_n_s_exact);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 436, __pyx_n_s_exact)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exbisector);
  __Pyx_GIVEREF(__pyx_n_s_exbisector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 437, __pyx_n_s_exbisector)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_excircle);
  __Pyx_GIVEREF(__pyx_n_s_excircle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 438, __pyx_n_s_excircle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_execute);
  __Pyx_GIVEREF(__pyx_n_s_execute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 439, __pyx_n_s_execute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exp);
  __Pyx_GIVEREF(__pyx_n_s_exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 440, __pyx_n_s_exp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exp2list);
  __Pyx_GIVEREF(__pyx_n_s_exp2list);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 441, __pyx_n_s_exp2list)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exp2pow);
  __Pyx_GIVEREF(__pyx_n_s_exp2pow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 442, __pyx_n_s_exp2pow)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exp2trig);
  __Pyx_GIVEREF(__pyx_n_s_exp2trig);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 443, __pyx_n_s_exp2trig)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_expand);
  __Pyx_GIVEREF(__pyx_n_s_expand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 444, __pyx_n_s_expand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_expexpand);
  __Pyx_GIVEREF(__pyx_n_s_expexpand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 445, __pyx_n_s_expexpand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_expln);
  __Pyx_GIVEREF(__pyx_n_s_expln);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 446, __pyx_n_s_expln)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponential);
  __Pyx_GIVEREF(__pyx_n_s_exponential);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 447, __pyx_n_s_exponential)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponential_cdf);
  __Pyx_GIVEREF(__pyx_n_s_exponential_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 448, __pyx_n_s_exponential_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponential_icdf);
  __Pyx_GIVEREF(__pyx_n_s_exponential_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 449, __pyx_n_s_exponential_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponential_regression);
  __Pyx_GIVEREF(__pyx_n_s_exponential_regression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 450, __pyx_n_s_exponential_regression)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponential_regression_plot);
  __Pyx_GIVEREF(__pyx_n_s_exponential_regression_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 451, __pyx_n_s_exponential_regression_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponentiald);
  __Pyx_GIVEREF(__pyx_n_s_exponentiald);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 452, __pyx_n_s_exponentiald)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponentiald_cdf);
  __Pyx_GIVEREF(__pyx_n_s_exponentiald_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 453, __pyx_n_s_exponentiald_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_exponentiald_icdf);
  __Pyx_GIVEREF(__pyx_n_s_exponentiald_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 454, __pyx_n_s_exponentiald_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_export_graph);
  __Pyx_GIVEREF(__pyx_n_s_export_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 455, __pyx_n_s_export_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_export_mathml);
  __Pyx_GIVEREF(__pyx_n_s_export_mathml);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 456, __pyx_n_s_export_mathml)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_expovariate);
  __Pyx_GIVEREF(__pyx_n_s_expovariate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 457, __pyx_n_s_expovariate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_expr);
  __Pyx_GIVEREF(__pyx_n_s_expr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 458, __pyx_n_s_expr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_extend);
  __Pyx_GIVEREF(__pyx_n_s_extend);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 459, __pyx_n_s_extend)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_extract_measure);
  __Pyx_GIVEREF(__pyx_n_s_extract_measure);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 460, __pyx_n_s_extract_measure)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_extrema);
  __Pyx_GIVEREF(__pyx_n_s_extrema);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 461, __pyx_n_s_extrema)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ezgcd);
  __Pyx_GIVEREF(__pyx_n_s_ezgcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 462, __pyx_n_s_ezgcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_f2nd);
  __Pyx_GIVEREF(__pyx_n_s_f2nd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 463, __pyx_n_s_f2nd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fMax);
  __Pyx_GIVEREF(__pyx_n_s_fMax);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 464, __pyx_n_s_fMax)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fMin);
  __Pyx_GIVEREF(__pyx_n_s_fMin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 465, __pyx_n_s_fMin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fPart);
  __Pyx_GIVEREF(__pyx_n_s_fPart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 466, __pyx_n_s_fPart)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_faces);
  __Pyx_GIVEREF(__pyx_n_s_faces);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 467, __pyx_n_s_faces)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_facteurs_premiers);
  __Pyx_GIVEREF(__pyx_n_s_facteurs_premiers);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 468, __pyx_n_s_facteurs_premiers)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factor);
  __Pyx_GIVEREF(__pyx_n_s_factor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 469, __pyx_n_s_factor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factor_xn);
  __Pyx_GIVEREF(__pyx_n_s_factor_xn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 470, __pyx_n_s_factor_xn)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factorial);
  __Pyx_GIVEREF(__pyx_n_s_factorial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 471, __pyx_n_s_factorial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factoriser);
  __Pyx_GIVEREF(__pyx_n_s_factoriser);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 472, __pyx_n_s_factoriser)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factoriser_entier);
  __Pyx_GIVEREF(__pyx_n_s_factoriser_entier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 473, __pyx_n_s_factoriser_entier)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factoriser_sur_C);
  __Pyx_GIVEREF(__pyx_n_s_factoriser_sur_C);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 474, __pyx_n_s_factoriser_sur_C)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_factors);
  __Pyx_GIVEREF(__pyx_n_s_factors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 475, __pyx_n_s_factors)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fadeev);
  __Pyx_GIVEREF(__pyx_n_s_fadeev);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 476, __pyx_n_s_fadeev)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_false);
  __Pyx_GIVEREF(__pyx_n_s_false);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 477, __pyx_n_s_false)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_falsepos_solver);
  __Pyx_GIVEREF(__pyx_n_s_falsepos_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 478, __pyx_n_s_falsepos_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fclose);
  __Pyx_GIVEREF(__pyx_n_s_fclose);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 479, __pyx_n_s_fclose)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fcoeff);
  __Pyx_GIVEREF(__pyx_n_s_fcoeff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 480, __pyx_n_s_fcoeff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fdistrib);
  __Pyx_GIVEREF(__pyx_n_s_fdistrib);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 481, __pyx_n_s_fdistrib)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fft);
  __Pyx_GIVEREF(__pyx_n_s_fft);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 482, __pyx_n_s_fft)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fieldplot);
  __Pyx_GIVEREF(__pyx_n_s_fieldplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 483, __pyx_n_s_fieldplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_find);
  __Pyx_GIVEREF(__pyx_n_s_find);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 484, __pyx_n_s_find)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_find_cliques);
  __Pyx_GIVEREF(__pyx_n_s_find_cliques);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 485, __pyx_n_s_find_cliques)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_find_cycles);
  __Pyx_GIVEREF(__pyx_n_s_find_cycles);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 486, __pyx_n_s_find_cycles)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_find_minimum);
  __Pyx_GIVEREF(__pyx_n_s_find_minimum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 487, __pyx_n_s_find_minimum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_find_vertex_cover);
  __Pyx_GIVEREF(__pyx_n_s_find_vertex_cover);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 488, __pyx_n_s_find_vertex_cover)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_findhelp);
  __Pyx_GIVEREF(__pyx_n_s_findhelp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 489, __pyx_n_s_findhelp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fisher);
  __Pyx_GIVEREF(__pyx_n_s_fisher);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 490, __pyx_n_s_fisher)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fisher_cdf);
  __Pyx_GIVEREF(__pyx_n_s_fisher_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 491, __pyx_n_s_fisher_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fisher_icdf);
  __Pyx_GIVEREF(__pyx_n_s_fisher_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 492, __pyx_n_s_fisher_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fisherd);
  __Pyx_GIVEREF(__pyx_n_s_fisherd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 493, __pyx_n_s_fisherd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fisherd_cdf);
  __Pyx_GIVEREF(__pyx_n_s_fisherd_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 494, __pyx_n_s_fisherd_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fisherd_icdf);
  __Pyx_GIVEREF(__pyx_n_s_fisherd_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 495, __pyx_n_s_fisherd_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fitdistr);
  __Pyx_GIVEREF(__pyx_n_s_fitdistr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 496, __pyx_n_s_fitdistr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fitpoly);
  __Pyx_GIVEREF(__pyx_n_s_fitpoly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 497, __pyx_n_s_fitpoly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fitspline);
  __Pyx_GIVEREF(__pyx_n_s_fitspline);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 498, __pyx_n_s_fitspline)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_flatten);
  __Pyx_GIVEREF(__pyx_n_s_flatten);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 499, __pyx_n_s_flatten)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_float2rational);
  __Pyx_GIVEREF(__pyx_n_s_float2rational);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 500, __pyx_n_s_float2rational)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_floor);
  __Pyx_GIVEREF(__pyx_n_s_floor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 501, __pyx_n_s_floor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_flow_polynomial);
  __Pyx_GIVEREF(__pyx_n_s_flow_polynomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 502, __pyx_n_s_flow_polynomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_flower_snark);
  __Pyx_GIVEREF(__pyx_n_s_flower_snark);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 503, __pyx_n_s_flower_snark)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fmod);
  __Pyx_GIVEREF(__pyx_n_s_fmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 504, __pyx_n_s_fmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_foldl);
  __Pyx_GIVEREF(__pyx_n_s_foldl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 505, __pyx_n_s_foldl)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_foldr);
  __Pyx_GIVEREF(__pyx_n_s_foldr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 506, __pyx_n_s_foldr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fonction_derivee);
  __Pyx_GIVEREF(__pyx_n_s_fonction_derivee);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 507, __pyx_n_s_fonction_derivee)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_forward);
  __Pyx_GIVEREF(__pyx_n_s_forward);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 508, __pyx_n_s_forward)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fourier);
  __Pyx_GIVEREF(__pyx_n_s_fourier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 509, __pyx_n_s_fourier)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fourier_an);
  __Pyx_GIVEREF(__pyx_n_s_fourier_an);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 510, __pyx_n_s_fourier_an)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fourier_bn);
  __Pyx_GIVEREF(__pyx_n_s_fourier_bn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 511, __pyx_n_s_fourier_bn)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fourier_cn);
  __Pyx_GIVEREF(__pyx_n_s_fourier_cn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 512, __pyx_n_s_fourier_cn)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fprint);
  __Pyx_GIVEREF(__pyx_n_s_fprint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 513, __pyx_n_s_fprint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frac);
  __Pyx_GIVEREF(__pyx_n_s_frac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 514, __pyx_n_s_frac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fracmod);
  __Pyx_GIVEREF(__pyx_n_s_fracmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 515, __pyx_n_s_fracmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frame_2d);
  __Pyx_GIVEREF(__pyx_n_s_frame_2d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 516, __pyx_n_s_frame_2d)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frank_wolfe);
  __Pyx_GIVEREF(__pyx_n_s_frank_wolfe);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 517, __pyx_n_s_frank_wolfe)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frequencies);
  __Pyx_GIVEREF(__pyx_n_s_frequencies);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 518, __pyx_n_s_frequencies)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_frobenius_norm);
  __Pyx_GIVEREF(__pyx_n_s_frobenius_norm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 519, __pyx_n_s_frobenius_norm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_froot);
  __Pyx_GIVEREF(__pyx_n_s_froot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 520, __pyx_n_s_froot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fsolve);
  __Pyx_GIVEREF(__pyx_n_s_fsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 521, __pyx_n_s_fsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fullparfrac);
  __Pyx_GIVEREF(__pyx_n_s_fullparfrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 522, __pyx_n_s_fullparfrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_funcplot);
  __Pyx_GIVEREF(__pyx_n_s_funcplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 523, __pyx_n_s_funcplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_function_diff);
  __Pyx_GIVEREF(__pyx_n_s_function_diff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 524, __pyx_n_s_function_diff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fundamental_cycle);
  __Pyx_GIVEREF(__pyx_n_s_fundamental_cycle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 525, __pyx_n_s_fundamental_cycle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_fxnd);
  __Pyx_GIVEREF(__pyx_n_s_fxnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 526, __pyx_n_s_fxnd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gammad);
  __Pyx_GIVEREF(__pyx_n_s_gammad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 527, __pyx_n_s_gammad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gammad_cdf);
  __Pyx_GIVEREF(__pyx_n_s_gammad_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 528, __pyx_n_s_gammad_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gammad_icdf);
  __Pyx_GIVEREF(__pyx_n_s_gammad_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 529, __pyx_n_s_gammad_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gammavariate);
  __Pyx_GIVEREF(__pyx_n_s_gammavariate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 530, __pyx_n_s_gammavariate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gauss);
  __Pyx_GIVEREF(__pyx_n_s_gauss);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 531, __pyx_n_s_gauss)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gauss15);
  __Pyx_GIVEREF(__pyx_n_s_gauss15);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 532, __pyx_n_s_gauss15)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gauss_seidel_linsolve);
  __Pyx_GIVEREF(__pyx_n_s_gauss_seidel_linsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 533, __pyx_n_s_gauss_seidel_linsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gaussian_window);
  __Pyx_GIVEREF(__pyx_n_s_gaussian_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 534, __pyx_n_s_gaussian_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gaussjord);
  __Pyx_GIVEREF(__pyx_n_s_gaussjord);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 535, __pyx_n_s_gaussjord)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gaussquad);
  __Pyx_GIVEREF(__pyx_n_s_gaussquad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 536, __pyx_n_s_gaussquad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gbasis);
  __Pyx_GIVEREF(__pyx_n_s_gbasis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 537, __pyx_n_s_gbasis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gbasis_max_pairs);
  __Pyx_GIVEREF(__pyx_n_s_gbasis_max_pairs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 538, __pyx_n_s_gbasis_max_pairs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gbasis_reinject);
  __Pyx_GIVEREF(__pyx_n_s_gbasis_reinject);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 539, __pyx_n_s_gbasis_reinject)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gbasis_simult_primes);
  __Pyx_GIVEREF(__pyx_n_s_gbasis_simult_primes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 540, __pyx_n_s_gbasis_simult_primes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gcd);
  __Pyx_GIVEREF(__pyx_n_s_gcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 541, __pyx_n_s_gcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gcdex);
  __Pyx_GIVEREF(__pyx_n_s_gcdex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 542, __pyx_n_s_gcdex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_genpoly);
  __Pyx_GIVEREF(__pyx_n_s_genpoly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 543, __pyx_n_s_genpoly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_geodetic2ecef);
  __Pyx_GIVEREF(__pyx_n_s_geodetic2ecef);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 544, __pyx_n_s_geodetic2ecef)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_geometric);
  __Pyx_GIVEREF(__pyx_n_s_geometric);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 545, __pyx_n_s_geometric)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_geometric_cdf);
  __Pyx_GIVEREF(__pyx_n_s_geometric_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 546, __pyx_n_s_geometric_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_geometric_icdf);
  __Pyx_GIVEREF(__pyx_n_s_geometric_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 547, __pyx_n_s_geometric_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_getDenom);
  __Pyx_GIVEREF(__pyx_n_s_getDenom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 548, __pyx_n_s_getDenom)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_getKey);
  __Pyx_GIVEREF(__pyx_n_s_getKey);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 549, __pyx_n_s_getKey)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_getNum);
  __Pyx_GIVEREF(__pyx_n_s_getNum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 550, __pyx_n_s_getNum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_getType);
  __Pyx_GIVEREF(__pyx_n_s_getType);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 551, __pyx_n_s_getType)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_get_edge_attribute);
  __Pyx_GIVEREF(__pyx_n_s_get_edge_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 552, __pyx_n_s_get_edge_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_get_edge_weight);
  __Pyx_GIVEREF(__pyx_n_s_get_edge_weight);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 553, __pyx_n_s_get_edge_weight)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_get_graph_attribute);
  __Pyx_GIVEREF(__pyx_n_s_get_graph_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 554, __pyx_n_s_get_graph_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_get_vertex_attribute);
  __Pyx_GIVEREF(__pyx_n_s_get_vertex_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 555, __pyx_n_s_get_vertex_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_girth);
  __Pyx_GIVEREF(__pyx_n_s_girth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 556, __pyx_n_s_girth)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gl_showaxes);
  __Pyx_GIVEREF(__pyx_n_s_gl_showaxes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 557, __pyx_n_s_gl_showaxes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gold);
  __Pyx_GIVEREF(__pyx_n_s_gold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 558, __pyx_n_s_gold)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_goldberg_snark);
  __Pyx_GIVEREF(__pyx_n_s_goldberg_snark);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 559, __pyx_n_s_goldberg_snark)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_grad);
  __Pyx_GIVEREF(__pyx_n_s_grad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 560, __pyx_n_s_grad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_gramschmidt);
  __Pyx_GIVEREF(__pyx_n_s_gramschmidt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 561, __pyx_n_s_gramschmidt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph);
  __Pyx_GIVEREF(__pyx_n_s_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 562, __pyx_n_s_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_automorphisms);
  __Pyx_GIVEREF(__pyx_n_s_graph_automorphisms);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 563, __pyx_n_s_graph_automorphisms)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_charpoly);
  __Pyx_GIVEREF(__pyx_n_s_graph_charpoly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 564, __pyx_n_s_graph_charpoly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_complement);
  __Pyx_GIVEREF(__pyx_n_s_graph_complement);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 565, __pyx_n_s_graph_complement)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_diameter);
  __Pyx_GIVEREF(__pyx_n_s_graph_diameter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 566, __pyx_n_s_graph_diameter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_equal);
  __Pyx_GIVEREF(__pyx_n_s_graph_equal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 567, __pyx_n_s_graph_equal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_join);
  __Pyx_GIVEREF(__pyx_n_s_graph_join);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 568, __pyx_n_s_graph_join)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_power);
  __Pyx_GIVEREF(__pyx_n_s_graph_power);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 569, __pyx_n_s_graph_power)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_rank);
  __Pyx_GIVEREF(__pyx_n_s_graph_rank);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 570, __pyx_n_s_graph_rank)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_spectrum);
  __Pyx_GIVEREF(__pyx_n_s_graph_spectrum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 571, __pyx_n_s_graph_spectrum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_union);
  __Pyx_GIVEREF(__pyx_n_s_graph_union);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 572, __pyx_n_s_graph_union)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_graph_vertices);
  __Pyx_GIVEREF(__pyx_n_s_graph_vertices);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 573, __pyx_n_s_graph_vertices)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_greduce);
  __Pyx_GIVEREF(__pyx_n_s_greduce);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 574, __pyx_n_s_greduce)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_greedy_clique);
  __Pyx_GIVEREF(__pyx_n_s_greedy_clique);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 575, __pyx_n_s_greedy_clique)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_greedy_color);
  __Pyx_GIVEREF(__pyx_n_s_greedy_color);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 576, __pyx_n_s_greedy_color)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_greedy_independent_set);
  __Pyx_GIVEREF(__pyx_n_s_greedy_independent_set);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 577, __pyx_n_s_greedy_independent_set)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_grey);
  __Pyx_GIVEREF(__pyx_n_s_grey);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 578, __pyx_n_s_grey)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_grid_graph);
  __Pyx_GIVEREF(__pyx_n_s_grid_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 579, __pyx_n_s_grid_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_groupermu);
  __Pyx_GIVEREF(__pyx_n_s_groupermu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 580, __pyx_n_s_groupermu)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_haar_graph);
  __Pyx_GIVEREF(__pyx_n_s_haar_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 581, __pyx_n_s_haar_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hadamard);
  __Pyx_GIVEREF(__pyx_n_s_hadamard);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 582, __pyx_n_s_hadamard)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_half_cone);
  __Pyx_GIVEREF(__pyx_n_s_half_cone);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 583, __pyx_n_s_half_cone)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_half_line);
  __Pyx_GIVEREF(__pyx_n_s_half_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 584, __pyx_n_s_half_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_halftan);
  __Pyx_GIVEREF(__pyx_n_s_halftan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 585, __pyx_n_s_halftan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_halftan_hyp2exp);
  __Pyx_GIVEREF(__pyx_n_s_halftan_hyp2exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 586, __pyx_n_s_halftan_hyp2exp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_halt);
  __Pyx_GIVEREF(__pyx_n_s_halt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 587, __pyx_n_s_halt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hamdist);
  __Pyx_GIVEREF(__pyx_n_s_hamdist);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 588, __pyx_n_s_hamdist)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hamming);
  __Pyx_GIVEREF(__pyx_n_s_hamming);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 589, __pyx_n_s_hamming)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hamming_window);
  __Pyx_GIVEREF(__pyx_n_s_hamming_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 590, __pyx_n_s_hamming_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hann_poisson_window);
  __Pyx_GIVEREF(__pyx_n_s_hann_poisson_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 591, __pyx_n_s_hann_poisson_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hann_window);
  __Pyx_GIVEREF(__pyx_n_s_hann_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 592, __pyx_n_s_hann_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_harmonic_centrality);
  __Pyx_GIVEREF(__pyx_n_s_harmonic_centrality);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 593, __pyx_n_s_harmonic_centrality)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_harmonic_conjugate);
  __Pyx_GIVEREF(__pyx_n_s_harmonic_conjugate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 594, __pyx_n_s_harmonic_conjugate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_harmonic_division);
  __Pyx_GIVEREF(__pyx_n_s_harmonic_division);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 595, __pyx_n_s_harmonic_division)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_has);
  __Pyx_GIVEREF(__pyx_n_s_has);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 596, __pyx_n_s_has)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_has_arc);
  __Pyx_GIVEREF(__pyx_n_s_has_arc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 597, __pyx_n_s_has_arc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_has_edge);
  __Pyx_GIVEREF(__pyx_n_s_has_edge);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 598, __pyx_n_s_has_edge)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hasard);
  __Pyx_GIVEREF(__pyx_n_s_hasard);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 599, __pyx_n_s_hasard)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_head);
  __Pyx_GIVEREF(__pyx_n_s_head);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 600, __pyx_n_s_head)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_heading);
  __Pyx_GIVEREF(__pyx_n_s_heading);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 601, __pyx_n_s_heading)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_heapify);
  __Pyx_GIVEREF(__pyx_n_s_heapify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 602, __pyx_n_s_heapify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_heappop);
  __Pyx_GIVEREF(__pyx_n_s_heappop);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 603, __pyx_n_s_heappop)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_heappush);
  __Pyx_GIVEREF(__pyx_n_s_heappush);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 604, __pyx_n_s_heappush)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hermite);
  __Pyx_GIVEREF(__pyx_n_s_hermite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 605, __pyx_n_s_hermite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hessenberg);
  __Pyx_GIVEREF(__pyx_n_s_hessenberg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 606, __pyx_n_s_hessenberg)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hessian);
  __Pyx_GIVEREF(__pyx_n_s_hessian);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 607, __pyx_n_s_hessian)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_heugcd);
  __Pyx_GIVEREF(__pyx_n_s_heugcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 608, __pyx_n_s_heugcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hexagon);
  __Pyx_GIVEREF(__pyx_n_s_hexagon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 609, __pyx_n_s_hexagon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hht);
  __Pyx_GIVEREF(__pyx_n_s_hht);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 610, __pyx_n_s_hht)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_highlight_edges);
  __Pyx_GIVEREF(__pyx_n_s_highlight_edges);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 611, __pyx_n_s_highlight_edges)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_highlight_subgraph);
  __Pyx_GIVEREF(__pyx_n_s_highlight_subgraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 612, __pyx_n_s_highlight_subgraph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_highlight_trail);
  __Pyx_GIVEREF(__pyx_n_s_highlight_trail);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 613, __pyx_n_s_highlight_trail)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_highlight_vertex);
  __Pyx_GIVEREF(__pyx_n_s_highlight_vertex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 614, __pyx_n_s_highlight_vertex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_highpass);
  __Pyx_GIVEREF(__pyx_n_s_highpass);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 615, __pyx_n_s_highpass)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hilbert);
  __Pyx_GIVEREF(__pyx_n_s_hilbert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 616, __pyx_n_s_hilbert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_histogram);
  __Pyx_GIVEREF(__pyx_n_s_histogram);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 617, __pyx_n_s_histogram)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hold);
  __Pyx_GIVEREF(__pyx_n_s_hold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 618, __pyx_n_s_hold)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_homogeneize);
  __Pyx_GIVEREF(__pyx_n_s_homogeneize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 619, __pyx_n_s_homogeneize)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_homothety);
  __Pyx_GIVEREF(__pyx_n_s_homothety);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 620, __pyx_n_s_homothety)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_horner);
  __Pyx_GIVEREF(__pyx_n_s_horner);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 621, __pyx_n_s_horner)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hsv);
  __Pyx_GIVEREF(__pyx_n_s_hsv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 622, __pyx_n_s_hsv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hsv2rgb);
  __Pyx_GIVEREF(__pyx_n_s_hsv2rgb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 623, __pyx_n_s_hsv2rgb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hybrid_solver);
  __Pyx_GIVEREF(__pyx_n_s_hybrid_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 624, __pyx_n_s_hybrid_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hybridj_solver);
  __Pyx_GIVEREF(__pyx_n_s_hybridj_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 625, __pyx_n_s_hybridj_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hybrids_solver);
  __Pyx_GIVEREF(__pyx_n_s_hybrids_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 626, __pyx_n_s_hybrids_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hybridsj_solver);
  __Pyx_GIVEREF(__pyx_n_s_hybridsj_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 627, __pyx_n_s_hybridsj_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hyp2exp);
  __Pyx_GIVEREF(__pyx_n_s_hyp2exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 628, __pyx_n_s_hyp2exp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hyperbola);
  __Pyx_GIVEREF(__pyx_n_s_hyperbola);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 629, __pyx_n_s_hyperbola)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_hypercube_graph);
  __Pyx_GIVEREF(__pyx_n_s_hypercube_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 630, __pyx_n_s_hypercube_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_iPart);
  __Pyx_GIVEREF(__pyx_n_s_iPart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 631, __pyx_n_s_iPart)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_iabcuv);
  __Pyx_GIVEREF(__pyx_n_s_iabcuv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 632, __pyx_n_s_iabcuv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ibasis);
  __Pyx_GIVEREF(__pyx_n_s_ibasis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 633, __pyx_n_s_ibasis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ibpdv);
  __Pyx_GIVEREF(__pyx_n_s_ibpdv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 634, __pyx_n_s_ibpdv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ibpu);
  __Pyx_GIVEREF(__pyx_n_s_ibpu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 635, __pyx_n_s_ibpu)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_icdf);
  __Pyx_GIVEREF(__pyx_n_s_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 636, __pyx_n_s_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ichinrem);
  __Pyx_GIVEREF(__pyx_n_s_ichinrem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 637, __pyx_n_s_ichinrem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ichrem);
  __Pyx_GIVEREF(__pyx_n_s_ichrem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 638, __pyx_n_s_ichrem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_icomp);
  __Pyx_GIVEREF(__pyx_n_s_icomp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 639, __pyx_n_s_icomp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_icontent);
  __Pyx_GIVEREF(__pyx_n_s_icontent);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 640, __pyx_n_s_icontent)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_icosahedron);
  __Pyx_GIVEREF(__pyx_n_s_icosahedron);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 641, __pyx_n_s_icosahedron)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_id);
  __Pyx_GIVEREF(__pyx_n_s_id);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 642, __pyx_n_s_id)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_identify_graph);
  __Pyx_GIVEREF(__pyx_n_s_identify_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 643, __pyx_n_s_identify_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_identity);
  __Pyx_GIVEREF(__pyx_n_s_identity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 644, __pyx_n_s_identity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_idivis);
  __Pyx_GIVEREF(__pyx_n_s_idivis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 645, __pyx_n_s_idivis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_idn);
  __Pyx_GIVEREF(__pyx_n_s_idn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 646, __pyx_n_s_idn)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_idwt);
  __Pyx_GIVEREF(__pyx_n_s_idwt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 647, __pyx_n_s_idwt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_iegcd);
  __Pyx_GIVEREF(__pyx_n_s_iegcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 648, __pyx_n_s_iegcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ifactor);
  __Pyx_GIVEREF(__pyx_n_s_ifactor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 649, __pyx_n_s_ifactor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ifactors);
  __Pyx_GIVEREF(__pyx_n_s_ifactors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 650, __pyx_n_s_ifactors)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ifourier);
  __Pyx_GIVEREF(__pyx_n_s_ifourier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 651, __pyx_n_s_ifourier)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_igamma);
  __Pyx_GIVEREF(__pyx_n_s_igamma);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 652, __pyx_n_s_igamma)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_igcd);
  __Pyx_GIVEREF(__pyx_n_s_igcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 653, __pyx_n_s_igcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_igcdex);
  __Pyx_GIVEREF(__pyx_n_s_igcdex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 654, __pyx_n_s_igcdex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ihermite);
  __Pyx_GIVEREF(__pyx_n_s_ihermite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 655, __pyx_n_s_ihermite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ilaplace);
  __Pyx_GIVEREF(__pyx_n_s_ilaplace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 656, __pyx_n_s_ilaplace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_im);
  __Pyx_GIVEREF(__pyx_n_s_im);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 657, __pyx_n_s_im)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_imag);
  __Pyx_GIVEREF(__pyx_n_s_imag);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 658, __pyx_n_s_imag)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_image);
  __Pyx_GIVEREF(__pyx_n_s_image);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 659, __pyx_n_s_image)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_imfplot);
  __Pyx_GIVEREF(__pyx_n_s_imfplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 660, __pyx_n_s_imfplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_implicitdiff);
  __Pyx_GIVEREF(__pyx_n_s_implicitdiff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 661, __pyx_n_s_implicitdiff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_implicitplot);
  __Pyx_GIVEREF(__pyx_n_s_implicitplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 662, __pyx_n_s_implicitplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_import_graph);
  __Pyx_GIVEREF(__pyx_n_s_import_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 663, __pyx_n_s_import_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inString);
  __Pyx_GIVEREF(__pyx_n_s_inString);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 664, __pyx_n_s_inString)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_in_ideal);
  __Pyx_GIVEREF(__pyx_n_s_in_ideal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 665, __pyx_n_s_in_ideal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_incidence_matrix);
  __Pyx_GIVEREF(__pyx_n_s_incidence_matrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 666, __pyx_n_s_incidence_matrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_incident_edges);
  __Pyx_GIVEREF(__pyx_n_s_incident_edges);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 667, __pyx_n_s_incident_edges)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_incircle);
  __Pyx_GIVEREF(__pyx_n_s_incircle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 668, __pyx_n_s_incircle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_increasing_power);
  __Pyx_GIVEREF(__pyx_n_s_increasing_power);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 669, __pyx_n_s_increasing_power)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_independence_number);
  __Pyx_GIVEREF(__pyx_n_s_independence_number);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 670, __pyx_n_s_independence_number)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_indets);
  __Pyx_GIVEREF(__pyx_n_s_indets);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 671, __pyx_n_s_indets)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_index);
  __Pyx_GIVEREF(__pyx_n_s_index);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 672, __pyx_n_s_index)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_induced_subgraph);
  __Pyx_GIVEREF(__pyx_n_s_induced_subgraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 673, __pyx_n_s_induced_subgraph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inequationplot);
  __Pyx_GIVEREF(__pyx_n_s_inequationplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 674, __pyx_n_s_inequationplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inertia);
  __Pyx_GIVEREF(__pyx_n_s_inertia);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 675, __pyx_n_s_inertia)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inf);
  __Pyx_GIVEREF(__pyx_n_s_inf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 676, __pyx_n_s_inf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_infinity);
  __Pyx_GIVEREF(__pyx_n_s_infinity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 677, __pyx_n_s_infinity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_information_centrality);
  __Pyx_GIVEREF(__pyx_n_s_information_centrality);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 678, __pyx_n_s_information_centrality)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_insert);
  __Pyx_GIVEREF(__pyx_n_s_insert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 679, __pyx_n_s_insert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_insmod);
  __Pyx_GIVEREF(__pyx_n_s_insmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 680, __pyx_n_s_insmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_instfreq);
  __Pyx_GIVEREF(__pyx_n_s_instfreq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 681, __pyx_n_s_instfreq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_instphase);
  __Pyx_GIVEREF(__pyx_n_s_instphase);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 682, __pyx_n_s_instphase)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_int);
  __Pyx_GIVEREF(__pyx_n_s_int);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 683, __pyx_n_s_int)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_intDiv);
  __Pyx_GIVEREF(__pyx_n_s_intDiv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 684, __pyx_n_s_intDiv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_integer);
  __Pyx_GIVEREF(__pyx_n_s_integer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 685, __pyx_n_s_integer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_integrate);
  __Pyx_GIVEREF(__pyx_n_s_integrate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 686, __pyx_n_s_integrate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_integrer);
  __Pyx_GIVEREF(__pyx_n_s_integrer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 687, __pyx_n_s_integrer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inter);
  __Pyx_GIVEREF(__pyx_n_s_inter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 688, __pyx_n_s_inter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interactive_odeplot);
  __Pyx_GIVEREF(__pyx_n_s_interactive_odeplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 689, __pyx_n_s_interactive_odeplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interactive_plotode);
  __Pyx_GIVEREF(__pyx_n_s_interactive_plotode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 690, __pyx_n_s_interactive_plotode)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interp);
  __Pyx_GIVEREF(__pyx_n_s_interp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 691, __pyx_n_s_interp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interval);
  __Pyx_GIVEREF(__pyx_n_s_interval);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 692, __pyx_n_s_interval)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interval2center);
  __Pyx_GIVEREF(__pyx_n_s_interval2center);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 693, __pyx_n_s_interval2center)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_interval_graph);
  __Pyx_GIVEREF(__pyx_n_s_interval_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 694, __pyx_n_s_interval_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inv);
  __Pyx_GIVEREF(__pyx_n_s_inv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 695, __pyx_n_s_inv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inverse);
  __Pyx_GIVEREF(__pyx_n_s_inverse);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 696, __pyx_n_s_inverse)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_inversion);
  __Pyx_GIVEREF(__pyx_n_s_inversion);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 697, __pyx_n_s_inversion)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_invisible_point);
  __Pyx_GIVEREF(__pyx_n_s_invisible_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 698, __pyx_n_s_invisible_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_invlaplace);
  __Pyx_GIVEREF(__pyx_n_s_invlaplace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 699, __pyx_n_s_invlaplace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_invztrans);
  __Pyx_GIVEREF(__pyx_n_s_invztrans);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 700, __pyx_n_s_invztrans)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_iquo);
  __Pyx_GIVEREF(__pyx_n_s_iquo);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 701, __pyx_n_s_iquo)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_iquorem);
  __Pyx_GIVEREF(__pyx_n_s_iquorem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 702, __pyx_n_s_iquorem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_iratrecon);
  __Pyx_GIVEREF(__pyx_n_s_iratrecon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 703, __pyx_n_s_iratrecon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_irem);
  __Pyx_GIVEREF(__pyx_n_s_irem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 704, __pyx_n_s_irem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isPrime);
  __Pyx_GIVEREF(__pyx_n_s_isPrime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 705, __pyx_n_s_isPrime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_acyclic);
  __Pyx_GIVEREF(__pyx_n_s_is_acyclic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 706, __pyx_n_s_is_acyclic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_arborescence);
  __Pyx_GIVEREF(__pyx_n_s_is_arborescence);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 707, __pyx_n_s_is_arborescence)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_biconnected);
  __Pyx_GIVEREF(__pyx_n_s_is_biconnected);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 708, __pyx_n_s_is_biconnected)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_bipartite);
  __Pyx_GIVEREF(__pyx_n_s_is_bipartite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 709, __pyx_n_s_is_bipartite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_clique);
  __Pyx_GIVEREF(__pyx_n_s_is_clique);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 710, __pyx_n_s_is_clique)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_collinear);
  __Pyx_GIVEREF(__pyx_n_s_is_collinear);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 711, __pyx_n_s_is_collinear)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_concyclic);
  __Pyx_GIVEREF(__pyx_n_s_is_concyclic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 712, __pyx_n_s_is_concyclic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_conjugate);
  __Pyx_GIVEREF(__pyx_n_s_is_conjugate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 713, __pyx_n_s_is_conjugate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_connected);
  __Pyx_GIVEREF(__pyx_n_s_is_connected);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 714, __pyx_n_s_is_connected)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_coplanar);
  __Pyx_GIVEREF(__pyx_n_s_is_coplanar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 715, __pyx_n_s_is_coplanar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_cospherical);
  __Pyx_GIVEREF(__pyx_n_s_is_cospherical);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 716, __pyx_n_s_is_cospherical)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_cut_set);
  __Pyx_GIVEREF(__pyx_n_s_is_cut_set);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 717, __pyx_n_s_is_cut_set)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_cycle);
  __Pyx_GIVEREF(__pyx_n_s_is_cycle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 718, __pyx_n_s_is_cycle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_directed);
  __Pyx_GIVEREF(__pyx_n_s_is_directed);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 719, __pyx_n_s_is_directed)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_element);
  __Pyx_GIVEREF(__pyx_n_s_is_element);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 720, __pyx_n_s_is_element)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_equilateral);
  __Pyx_GIVEREF(__pyx_n_s_is_equilateral);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 721, __pyx_n_s_is_equilateral)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_eulerian);
  __Pyx_GIVEREF(__pyx_n_s_is_eulerian);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 722, __pyx_n_s_is_eulerian)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_forest);
  __Pyx_GIVEREF(__pyx_n_s_is_forest);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 723, __pyx_n_s_is_forest)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_graphic_sequence);
  __Pyx_GIVEREF(__pyx_n_s_is_graphic_sequence);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 724, __pyx_n_s_is_graphic_sequence)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_hamiltonian);
  __Pyx_GIVEREF(__pyx_n_s_is_hamiltonian);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 725, __pyx_n_s_is_hamiltonian)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_harmonic);
  __Pyx_GIVEREF(__pyx_n_s_is_harmonic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 726, __pyx_n_s_is_harmonic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_harmonic_circle_bundle);
  __Pyx_GIVEREF(__pyx_n_s_is_harmonic_circle_bundle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 727, __pyx_n_s_is_harmonic_circle_bundle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_harmonic_line_bundle);
  __Pyx_GIVEREF(__pyx_n_s_is_harmonic_line_bundle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 728, __pyx_n_s_is_harmonic_line_bundle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_inside);
  __Pyx_GIVEREF(__pyx_n_s_is_inside);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 729, __pyx_n_s_is_inside)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_integer_graph);
  __Pyx_GIVEREF(__pyx_n_s_is_integer_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 730, __pyx_n_s_is_integer_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_irreducible);
  __Pyx_GIVEREF(__pyx_n_s_is_irreducible);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 731, __pyx_n_s_is_irreducible)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_isomorphic);
  __Pyx_GIVEREF(__pyx_n_s_is_isomorphic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 732, __pyx_n_s_is_isomorphic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_isosceles);
  __Pyx_GIVEREF(__pyx_n_s_is_isosceles);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 733, __pyx_n_s_is_isosceles)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_network);
  __Pyx_GIVEREF(__pyx_n_s_is_network);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 734, __pyx_n_s_is_network)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_orthogonal);
  __Pyx_GIVEREF(__pyx_n_s_is_orthogonal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 735, __pyx_n_s_is_orthogonal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_parallel);
  __Pyx_GIVEREF(__pyx_n_s_is_parallel);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 736, __pyx_n_s_is_parallel)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_parallelogram);
  __Pyx_GIVEREF(__pyx_n_s_is_parallelogram);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 737, __pyx_n_s_is_parallelogram)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_permu);
  __Pyx_GIVEREF(__pyx_n_s_is_permu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 738, __pyx_n_s_is_permu)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_perpendicular);
  __Pyx_GIVEREF(__pyx_n_s_is_perpendicular);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 739, __pyx_n_s_is_perpendicular)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_planar);
  __Pyx_GIVEREF(__pyx_n_s_is_planar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 740, __pyx_n_s_is_planar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_prime);
  __Pyx_GIVEREF(__pyx_n_s_is_prime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 741, __pyx_n_s_is_prime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_pseudoprime);
  __Pyx_GIVEREF(__pyx_n_s_is_pseudoprime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 742, __pyx_n_s_is_pseudoprime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_reachable);
  __Pyx_GIVEREF(__pyx_n_s_is_reachable);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 743, __pyx_n_s_is_reachable)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_rectangle);
  __Pyx_GIVEREF(__pyx_n_s_is_rectangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 744, __pyx_n_s_is_rectangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_regular);
  __Pyx_GIVEREF(__pyx_n_s_is_regular);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 745, __pyx_n_s_is_regular)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_rhombus);
  __Pyx_GIVEREF(__pyx_n_s_is_rhombus);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 746, __pyx_n_s_is_rhombus)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_split_graph);
  __Pyx_GIVEREF(__pyx_n_s_is_split_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 747, __pyx_n_s_is_split_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_square);
  __Pyx_GIVEREF(__pyx_n_s_is_square);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 748, __pyx_n_s_is_square)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_strongly_connected);
  __Pyx_GIVEREF(__pyx_n_s_is_strongly_connected);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 749, __pyx_n_s_is_strongly_connected)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_strongly_regular);
  __Pyx_GIVEREF(__pyx_n_s_is_strongly_regular);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 750, __pyx_n_s_is_strongly_regular)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_subgraph_isomorphic);
  __Pyx_GIVEREF(__pyx_n_s_is_subgraph_isomorphic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 751, __pyx_n_s_is_subgraph_isomorphic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_tournament);
  __Pyx_GIVEREF(__pyx_n_s_is_tournament);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 752, __pyx_n_s_is_tournament)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_tree);
  __Pyx_GIVEREF(__pyx_n_s_is_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 753, __pyx_n_s_is_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_triconnected);
  __Pyx_GIVEREF(__pyx_n_s_is_triconnected);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 754, __pyx_n_s_is_triconnected)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_two_edge_connected);
  __Pyx_GIVEREF(__pyx_n_s_is_two_edge_connected);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 755, __pyx_n_s_is_two_edge_connected)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_vertex_colorable);
  __Pyx_GIVEREF(__pyx_n_s_is_vertex_colorable);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 756, __pyx_n_s_is_vertex_colorable)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_is_weighted);
  __Pyx_GIVEREF(__pyx_n_s_is_weighted);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 757, __pyx_n_s_is_weighted)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isinf);
  __Pyx_GIVEREF(__pyx_n_s_isinf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 758, __pyx_n_s_isinf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ismith);
  __Pyx_GIVEREF(__pyx_n_s_ismith);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 759, __pyx_n_s_ismith)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isnan);
  __Pyx_GIVEREF(__pyx_n_s_isnan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 760, __pyx_n_s_isnan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isobarycenter);
  __Pyx_GIVEREF(__pyx_n_s_isobarycenter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 761, __pyx_n_s_isobarycenter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isolve);
  __Pyx_GIVEREF(__pyx_n_s_isolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 762, __pyx_n_s_isolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isom);
  __Pyx_GIVEREF(__pyx_n_s_isom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 763, __pyx_n_s_isom)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isomorphic_copy);
  __Pyx_GIVEREF(__pyx_n_s_isomorphic_copy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 764, __pyx_n_s_isomorphic_copy)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isopolygon);
  __Pyx_GIVEREF(__pyx_n_s_isopolygon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 765, __pyx_n_s_isopolygon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isosceles_triangle);
  __Pyx_GIVEREF(__pyx_n_s_isosceles_triangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 766, __pyx_n_s_isosceles_triangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isposdef);
  __Pyx_GIVEREF(__pyx_n_s_isposdef);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 767, __pyx_n_s_isposdef)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_isprime);
  __Pyx_GIVEREF(__pyx_n_s_isprime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 768, __pyx_n_s_isprime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_istft);
  __Pyx_GIVEREF(__pyx_n_s_istft);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 769, __pyx_n_s_istft)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ithprime);
  __Pyx_GIVEREF(__pyx_n_s_ithprime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 770, __pyx_n_s_ithprime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jacobi_equation);
  __Pyx_GIVEREF(__pyx_n_s_jacobi_equation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 771, __pyx_n_s_jacobi_equation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jacobi_linsolve);
  __Pyx_GIVEREF(__pyx_n_s_jacobi_linsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 772, __pyx_n_s_jacobi_linsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jacobi_symbol);
  __Pyx_GIVEREF(__pyx_n_s_jacobi_symbol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 773, __pyx_n_s_jacobi_symbol)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_johnson_graph);
  __Pyx_GIVEREF(__pyx_n_s_johnson_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 774, __pyx_n_s_johnson_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_join);
  __Pyx_GIVEREF(__pyx_n_s_join);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 775, __pyx_n_s_join)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_jordan);
  __Pyx_GIVEREF(__pyx_n_s_jordan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 776, __pyx_n_s_jordan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_katz_centrality);
  __Pyx_GIVEREF(__pyx_n_s_katz_centrality);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 777, __pyx_n_s_katz_centrality)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kde);
  __Pyx_GIVEREF(__pyx_n_s_kde);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 778, __pyx_n_s_kde)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_keep_pivot);
  __Pyx_GIVEREF(__pyx_n_s_keep_pivot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 779, __pyx_n_s_keep_pivot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ker);
  __Pyx_GIVEREF(__pyx_n_s_ker);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 780, __pyx_n_s_ker)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kernel);
  __Pyx_GIVEREF(__pyx_n_s_kernel);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 781, __pyx_n_s_kernel)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kernel_density);
  __Pyx_GIVEREF(__pyx_n_s_kernel_density);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 782, __pyx_n_s_kernel_density)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kmeans);
  __Pyx_GIVEREF(__pyx_n_s_kmeans);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 783, __pyx_n_s_kmeans)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kneser_graph);
  __Pyx_GIVEREF(__pyx_n_s_kneser_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 784, __pyx_n_s_kneser_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kolmogorovd);
  __Pyx_GIVEREF(__pyx_n_s_kolmogorovd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 785, __pyx_n_s_kolmogorovd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kolmogorovt);
  __Pyx_GIVEREF(__pyx_n_s_kolmogorovt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 786, __pyx_n_s_kolmogorovt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kovacicsols);
  __Pyx_GIVEREF(__pyx_n_s_kovacicsols);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 787, __pyx_n_s_kovacicsols)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_kspaths);
  __Pyx_GIVEREF(__pyx_n_s_kspaths);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 788, __pyx_n_s_kspaths)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_l1norm);
  __Pyx_GIVEREF(__pyx_n_s_l1norm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 789, __pyx_n_s_l1norm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_l2norm);
  __Pyx_GIVEREF(__pyx_n_s_l2norm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 790, __pyx_n_s_l2norm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lagrange);
  __Pyx_GIVEREF(__pyx_n_s_lagrange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 791, __pyx_n_s_lagrange)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_laguerre);
  __Pyx_GIVEREF(__pyx_n_s_laguerre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 792, __pyx_n_s_laguerre)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_laplace);
  __Pyx_GIVEREF(__pyx_n_s_laplace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 793, __pyx_n_s_laplace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_laplacian);
  __Pyx_GIVEREF(__pyx_n_s_laplacian);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 794, __pyx_n_s_laplacian)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_laplacian_matrix);
  __Pyx_GIVEREF(__pyx_n_s_laplacian_matrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 795, __pyx_n_s_laplacian_matrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_latex);
  __Pyx_GIVEREF(__pyx_n_s_latex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 796, __pyx_n_s_latex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lcf_graph);
  __Pyx_GIVEREF(__pyx_n_s_lcf_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 797, __pyx_n_s_lcf_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lcm);
  __Pyx_GIVEREF(__pyx_n_s_lcm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 798, __pyx_n_s_lcm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lcoeff);
  __Pyx_GIVEREF(__pyx_n_s_lcoeff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 799, __pyx_n_s_lcoeff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ldegree);
  __Pyx_GIVEREF(__pyx_n_s_ldegree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 800, __pyx_n_s_ldegree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ldl);
  __Pyx_GIVEREF(__pyx_n_s_ldl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 801, __pyx_n_s_ldl)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_learning_rate);
  __Pyx_GIVEREF(__pyx_n_s_learning_rate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 802, __pyx_n_s_learning_rate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_left);
  __Pyx_GIVEREF(__pyx_n_s_left);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 803, __pyx_n_s_left)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_left_rectangle);
  __Pyx_GIVEREF(__pyx_n_s_left_rectangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 804, __pyx_n_s_left_rectangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_legend);
  __Pyx_GIVEREF(__pyx_n_s_legend);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 805, __pyx_n_s_legend)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_legendre);
  __Pyx_GIVEREF(__pyx_n_s_legendre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 806, __pyx_n_s_legendre)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_legendre_symbol);
  __Pyx_GIVEREF(__pyx_n_s_legendre_symbol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 807, __pyx_n_s_legendre_symbol)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_length);
  __Pyx_GIVEREF(__pyx_n_s_length);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 808, __pyx_n_s_length)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_levenshtein);
  __Pyx_GIVEREF(__pyx_n_s_levenshtein);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 809, __pyx_n_s_levenshtein)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lgcd);
  __Pyx_GIVEREF(__pyx_n_s_lgcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 810, __pyx_n_s_lgcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lhs);
  __Pyx_GIVEREF(__pyx_n_s_lhs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 811, __pyx_n_s_lhs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_chapeau_carre);
  __Pyx_GIVEREF(__pyx_n_s_ligne_chapeau_carre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 812, __pyx_n_s_ligne_chapeau_carre)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_chapeau_plat);
  __Pyx_GIVEREF(__pyx_n_s_ligne_chapeau_plat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 813, __pyx_n_s_ligne_chapeau_plat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_chapeau_rond);
  __Pyx_GIVEREF(__pyx_n_s_ligne_chapeau_rond);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 814, __pyx_n_s_ligne_chapeau_rond)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_polygonale);
  __Pyx_GIVEREF(__pyx_n_s_ligne_polygonale);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 815, __pyx_n_s_ligne_polygonale)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_polygonale_pointee);
  __Pyx_GIVEREF(__pyx_n_s_ligne_polygonale_pointee);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 816, __pyx_n_s_ligne_polygonale_pointee)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_tiret);
  __Pyx_GIVEREF(__pyx_n_s_ligne_tiret);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 817, __pyx_n_s_ligne_tiret)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_tiret_point);
  __Pyx_GIVEREF(__pyx_n_s_ligne_tiret_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 818, __pyx_n_s_ligne_tiret_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_tiret_pointpoint);
  __Pyx_GIVEREF(__pyx_n_s_ligne_tiret_pointpoint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 819, __pyx_n_s_ligne_tiret_pointpoint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ligne_trait_plein);
  __Pyx_GIVEREF(__pyx_n_s_ligne_trait_plein);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 820, __pyx_n_s_ligne_trait_plein)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_limit);
  __Pyx_GIVEREF(__pyx_n_s_limit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 821, __pyx_n_s_limit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_limite);
  __Pyx_GIVEREF(__pyx_n_s_limite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 822, __pyx_n_s_limite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lin);
  __Pyx_GIVEREF(__pyx_n_s_lin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 823, __pyx_n_s_lin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linabs);
  __Pyx_GIVEREF(__pyx_n_s_linabs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 824, __pyx_n_s_linabs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line);
  __Pyx_GIVEREF(__pyx_n_s_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 825, __pyx_n_s_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_graph);
  __Pyx_GIVEREF(__pyx_n_s_line_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 826, __pyx_n_s_line_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_inter);
  __Pyx_GIVEREF(__pyx_n_s_line_inter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 827, __pyx_n_s_line_inter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_paper);
  __Pyx_GIVEREF(__pyx_n_s_line_paper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 828, __pyx_n_s_line_paper)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_line_segments);
  __Pyx_GIVEREF(__pyx_n_s_line_segments);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 829, __pyx_n_s_line_segments)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linear_interpolate);
  __Pyx_GIVEREF(__pyx_n_s_linear_interpolate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 830, __pyx_n_s_linear_interpolate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linear_regression);
  __Pyx_GIVEREF(__pyx_n_s_linear_regression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 831, __pyx_n_s_linear_regression)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linear_regression_plot);
  __Pyx_GIVEREF(__pyx_n_s_linear_regression_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 832, __pyx_n_s_linear_regression_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lineariser);
  __Pyx_GIVEREF(__pyx_n_s_lineariser);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 833, __pyx_n_s_lineariser)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lineariser_trigo);
  __Pyx_GIVEREF(__pyx_n_s_lineariser_trigo);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 834, __pyx_n_s_lineariser_trigo)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linfnorm);
  __Pyx_GIVEREF(__pyx_n_s_linfnorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 835, __pyx_n_s_linfnorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linsolve);
  __Pyx_GIVEREF(__pyx_n_s_linsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 836, __pyx_n_s_linsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linspace);
  __Pyx_GIVEREF(__pyx_n_s_linspace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 837, __pyx_n_s_linspace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_linstep);
  __Pyx_GIVEREF(__pyx_n_s_linstep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 838, __pyx_n_s_linstep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lis_phrase);
  __Pyx_GIVEREF(__pyx_n_s_lis_phrase);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 839, __pyx_n_s_lis_phrase)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_list2exp);
  __Pyx_GIVEREF(__pyx_n_s_list2exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 840, __pyx_n_s_list2exp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_list2mat);
  __Pyx_GIVEREF(__pyx_n_s_list2mat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 841, __pyx_n_s_list2mat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_list_edge_attributes);
  __Pyx_GIVEREF(__pyx_n_s_list_edge_attributes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 842, __pyx_n_s_list_edge_attributes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_list_graph_attributes);
  __Pyx_GIVEREF(__pyx_n_s_list_graph_attributes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 843, __pyx_n_s_list_graph_attributes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_list_vertex_attributes);
  __Pyx_GIVEREF(__pyx_n_s_list_vertex_attributes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 844, __pyx_n_s_list_vertex_attributes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_listplot);
  __Pyx_GIVEREF(__pyx_n_s_listplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 845, __pyx_n_s_listplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lll);
  __Pyx_GIVEREF(__pyx_n_s_lll);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 846, __pyx_n_s_lll)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ln);
  __Pyx_GIVEREF(__pyx_n_s_ln);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 847, __pyx_n_s_ln)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lname);
  __Pyx_GIVEREF(__pyx_n_s_lname);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 848, __pyx_n_s_lname)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lncollect);
  __Pyx_GIVEREF(__pyx_n_s_lncollect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 849, __pyx_n_s_lncollect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lnexpand);
  __Pyx_GIVEREF(__pyx_n_s_lnexpand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 850, __pyx_n_s_lnexpand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_locus);
  __Pyx_GIVEREF(__pyx_n_s_locus);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 851, __pyx_n_s_locus)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_log);
  __Pyx_GIVEREF(__pyx_n_s_log);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 852, __pyx_n_s_log)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_log10);
  __Pyx_GIVEREF(__pyx_n_s_log10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 853, __pyx_n_s_log10)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_log2);
  __Pyx_GIVEREF(__pyx_n_s_log2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 854, __pyx_n_s_log2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_log_loss);
  __Pyx_GIVEREF(__pyx_n_s_log_loss);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 855, __pyx_n_s_log_loss)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_logarithmic_regression);
  __Pyx_GIVEREF(__pyx_n_s_logarithmic_regression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 856, __pyx_n_s_logarithmic_regression)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_logarithmic_regression_plot);
  __Pyx_GIVEREF(__pyx_n_s_logarithmic_regression_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 857, __pyx_n_s_logarithmic_regression_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_logb);
  __Pyx_GIVEREF(__pyx_n_s_logb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 858, __pyx_n_s_logb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_logistic);
  __Pyx_GIVEREF(__pyx_n_s_logistic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 859, __pyx_n_s_logistic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_logistic_regression);
  __Pyx_GIVEREF(__pyx_n_s_logistic_regression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 860, __pyx_n_s_logistic_regression)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_logistic_regression_plot);
  __Pyx_GIVEREF(__pyx_n_s_logistic_regression_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 861, __pyx_n_s_logistic_regression_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lower);
  __Pyx_GIVEREF(__pyx_n_s_lower);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 862, __pyx_n_s_lower)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lowest_common_ancestor);
  __Pyx_GIVEREF(__pyx_n_s_lowest_common_ancestor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 863, __pyx_n_s_lowest_common_ancestor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lowpass);
  __Pyx_GIVEREF(__pyx_n_s_lowpass);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 864, __pyx_n_s_lowpass)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_assume);
  __Pyx_GIVEREF(__pyx_n_s_lp_assume);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 865, __pyx_n_s_lp_assume)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_bestlocalbound);
  __Pyx_GIVEREF(__pyx_n_s_lp_bestlocalbound);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 866, __pyx_n_s_lp_bestlocalbound)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_bestprojection);
  __Pyx_GIVEREF(__pyx_n_s_lp_bestprojection);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 867, __pyx_n_s_lp_bestprojection)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_binary);
  __Pyx_GIVEREF(__pyx_n_s_lp_binary);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 868, __pyx_n_s_lp_binary)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_binaryvariables);
  __Pyx_GIVEREF(__pyx_n_s_lp_binaryvariables);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 869, __pyx_n_s_lp_binaryvariables)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_breadthfirst);
  __Pyx_GIVEREF(__pyx_n_s_lp_breadthfirst);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 870, __pyx_n_s_lp_breadthfirst)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_depthfirst);
  __Pyx_GIVEREF(__pyx_n_s_lp_depthfirst);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 871, __pyx_n_s_lp_depthfirst)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_depthlimit);
  __Pyx_GIVEREF(__pyx_n_s_lp_depthlimit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 872, __pyx_n_s_lp_depthlimit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_firstfractional);
  __Pyx_GIVEREF(__pyx_n_s_lp_firstfractional);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 873, __pyx_n_s_lp_firstfractional)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_gaptolerance);
  __Pyx_GIVEREF(__pyx_n_s_lp_gaptolerance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 874, __pyx_n_s_lp_gaptolerance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_heuristic);
  __Pyx_GIVEREF(__pyx_n_s_lp_heuristic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 875, __pyx_n_s_lp_heuristic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_hybrid);
  __Pyx_GIVEREF(__pyx_n_s_lp_hybrid);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 876, __pyx_n_s_lp_hybrid)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_integer);
  __Pyx_GIVEREF(__pyx_n_s_lp_integer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 877, __pyx_n_s_lp_integer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_integervariables);
  __Pyx_GIVEREF(__pyx_n_s_lp_integervariables);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 878, __pyx_n_s_lp_integervariables)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_interiorpoint);
  __Pyx_GIVEREF(__pyx_n_s_lp_interiorpoint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 879, __pyx_n_s_lp_interiorpoint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_iterationlimit);
  __Pyx_GIVEREF(__pyx_n_s_lp_iterationlimit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 880, __pyx_n_s_lp_iterationlimit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_lastfractional);
  __Pyx_GIVEREF(__pyx_n_s_lp_lastfractional);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 881, __pyx_n_s_lp_lastfractional)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_maxcuts);
  __Pyx_GIVEREF(__pyx_n_s_lp_maxcuts);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 882, __pyx_n_s_lp_maxcuts)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_maximize);
  __Pyx_GIVEREF(__pyx_n_s_lp_maximize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 883, __pyx_n_s_lp_maximize)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_method);
  __Pyx_GIVEREF(__pyx_n_s_lp_method);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 884, __pyx_n_s_lp_method)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_mostfractional);
  __Pyx_GIVEREF(__pyx_n_s_lp_mostfractional);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 885, __pyx_n_s_lp_mostfractional)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_nodelimit);
  __Pyx_GIVEREF(__pyx_n_s_lp_nodelimit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 886, __pyx_n_s_lp_nodelimit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_nodeselect);
  __Pyx_GIVEREF(__pyx_n_s_lp_nodeselect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 887, __pyx_n_s_lp_nodeselect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_nonnegative);
  __Pyx_GIVEREF(__pyx_n_s_lp_nonnegative);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 888, __pyx_n_s_lp_nonnegative)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_nonnegint);
  __Pyx_GIVEREF(__pyx_n_s_lp_nonnegint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 889, __pyx_n_s_lp_nonnegint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_presolve);
  __Pyx_GIVEREF(__pyx_n_s_lp_presolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 890, __pyx_n_s_lp_presolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_pseudocost);
  __Pyx_GIVEREF(__pyx_n_s_lp_pseudocost);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 891, __pyx_n_s_lp_pseudocost)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_simplex);
  __Pyx_GIVEREF(__pyx_n_s_lp_simplex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 892, __pyx_n_s_lp_simplex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_timelimit);
  __Pyx_GIVEREF(__pyx_n_s_lp_timelimit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 893, __pyx_n_s_lp_timelimit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_varselect);
  __Pyx_GIVEREF(__pyx_n_s_lp_varselect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 894, __pyx_n_s_lp_varselect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lp_verbose);
  __Pyx_GIVEREF(__pyx_n_s_lp_verbose);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 895, __pyx_n_s_lp_verbose)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lpsolve);
  __Pyx_GIVEREF(__pyx_n_s_lpsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 896, __pyx_n_s_lpsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lsmod);
  __Pyx_GIVEREF(__pyx_n_s_lsmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 897, __pyx_n_s_lsmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lsq);
  __Pyx_GIVEREF(__pyx_n_s_lsq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 898, __pyx_n_s_lsq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lu);
  __Pyx_GIVEREF(__pyx_n_s_lu);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 899, __pyx_n_s_lu)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_lvar);
  __Pyx_GIVEREF(__pyx_n_s_lvar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 900, __pyx_n_s_lvar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mRow);
  __Pyx_GIVEREF(__pyx_n_s_mRow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 901, __pyx_n_s_mRow)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mRowAdd);
  __Pyx_GIVEREF(__pyx_n_s_mRowAdd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 902, __pyx_n_s_mRowAdd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_magenta);
  __Pyx_GIVEREF(__pyx_n_s_magenta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 903, __pyx_n_s_magenta)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_make_directed);
  __Pyx_GIVEREF(__pyx_n_s_make_directed);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 904, __pyx_n_s_make_directed)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_make_symbol);
  __Pyx_GIVEREF(__pyx_n_s_make_symbol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 905, __pyx_n_s_make_symbol)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_make_weighted);
  __Pyx_GIVEREF(__pyx_n_s_make_weighted);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 906, __pyx_n_s_make_weighted)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_makelist);
  __Pyx_GIVEREF(__pyx_n_s_makelist);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 907, __pyx_n_s_makelist)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_makemat);
  __Pyx_GIVEREF(__pyx_n_s_makemat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 908, __pyx_n_s_makemat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_makesuite);
  __Pyx_GIVEREF(__pyx_n_s_makesuite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 909, __pyx_n_s_makesuite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_makevector);
  __Pyx_GIVEREF(__pyx_n_s_makevector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 910, __pyx_n_s_makevector)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_map);
  __Pyx_GIVEREF(__pyx_n_s_map);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 911, __pyx_n_s_map)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maple2mupad);
  __Pyx_GIVEREF(__pyx_n_s_maple2mupad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 912, __pyx_n_s_maple2mupad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maple2xcas);
  __Pyx_GIVEREF(__pyx_n_s_maple2xcas);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 913, __pyx_n_s_maple2xcas)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maple_ifactors);
  __Pyx_GIVEREF(__pyx_n_s_maple_ifactors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 914, __pyx_n_s_maple_ifactors)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maple_mode);
  __Pyx_GIVEREF(__pyx_n_s_maple_mode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 915, __pyx_n_s_maple_mode)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_markov);
  __Pyx_GIVEREF(__pyx_n_s_markov);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 916, __pyx_n_s_markov)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mat2list);
  __Pyx_GIVEREF(__pyx_n_s_mat2list);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 917, __pyx_n_s_mat2list)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mathml);
  __Pyx_GIVEREF(__pyx_n_s_mathml);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 918, __pyx_n_s_mathml)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_matpow);
  __Pyx_GIVEREF(__pyx_n_s_matpow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 919, __pyx_n_s_matpow)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_matrix);
  __Pyx_GIVEREF(__pyx_n_s_matrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 920, __pyx_n_s_matrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_matrix_norm);
  __Pyx_GIVEREF(__pyx_n_s_matrix_norm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 921, __pyx_n_s_matrix_norm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_max);
  __Pyx_GIVEREF(__pyx_n_s_max);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 922, __pyx_n_s_max)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maxflow);
  __Pyx_GIVEREF(__pyx_n_s_maxflow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 923, __pyx_n_s_maxflow)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maximal_independent_set);
  __Pyx_GIVEREF(__pyx_n_s_maximal_independent_set);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 924, __pyx_n_s_maximal_independent_set)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maximize);
  __Pyx_GIVEREF(__pyx_n_s_maximize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 925, __pyx_n_s_maximize)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maximum_clique);
  __Pyx_GIVEREF(__pyx_n_s_maximum_clique);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 926, __pyx_n_s_maximum_clique)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maximum_degree);
  __Pyx_GIVEREF(__pyx_n_s_maximum_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 927, __pyx_n_s_maximum_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maximum_independent_set);
  __Pyx_GIVEREF(__pyx_n_s_maximum_independent_set);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 928, __pyx_n_s_maximum_independent_set)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maximum_matching);
  __Pyx_GIVEREF(__pyx_n_s_maximum_matching);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 929, __pyx_n_s_maximum_matching)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_maxnorm);
  __Pyx_GIVEREF(__pyx_n_s_maxnorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 930, __pyx_n_s_maxnorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mean);
  __Pyx_GIVEREF(__pyx_n_s_mean);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 931, __pyx_n_s_mean)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_median);
  __Pyx_GIVEREF(__pyx_n_s_median);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 932, __pyx_n_s_median)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_median_line);
  __Pyx_GIVEREF(__pyx_n_s_median_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 933, __pyx_n_s_median_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_member);
  __Pyx_GIVEREF(__pyx_n_s_member);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 934, __pyx_n_s_member)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mgf);
  __Pyx_GIVEREF(__pyx_n_s_mgf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 935, __pyx_n_s_mgf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mid);
  __Pyx_GIVEREF(__pyx_n_s_mid);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 936, __pyx_n_s_mid)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_middle_point);
  __Pyx_GIVEREF(__pyx_n_s_middle_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 937, __pyx_n_s_middle_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_midpoint);
  __Pyx_GIVEREF(__pyx_n_s_midpoint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 938, __pyx_n_s_midpoint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_min);
  __Pyx_GIVEREF(__pyx_n_s_min);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 939, __pyx_n_s_min)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimal_edge_coloring);
  __Pyx_GIVEREF(__pyx_n_s_minimal_edge_coloring);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 940, __pyx_n_s_minimal_edge_coloring)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimal_spanning_tree);
  __Pyx_GIVEREF(__pyx_n_s_minimal_spanning_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 941, __pyx_n_s_minimal_spanning_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimal_vertex_coloring);
  __Pyx_GIVEREF(__pyx_n_s_minimal_vertex_coloring);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 942, __pyx_n_s_minimal_vertex_coloring)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimax);
  __Pyx_GIVEREF(__pyx_n_s_minimax);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 943, __pyx_n_s_minimax)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimize);
  __Pyx_GIVEREF(__pyx_n_s_minimize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 944, __pyx_n_s_minimize)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimum_cut);
  __Pyx_GIVEREF(__pyx_n_s_minimum_cut);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 945, __pyx_n_s_minimum_cut)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimum_degree);
  __Pyx_GIVEREF(__pyx_n_s_minimum_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 946, __pyx_n_s_minimum_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_minimum_vertex_cover);
  __Pyx_GIVEREF(__pyx_n_s_minimum_vertex_cover);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 947, __pyx_n_s_minimum_vertex_cover)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mixdown);
  __Pyx_GIVEREF(__pyx_n_s_mixdown);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 948, __pyx_n_s_mixdown)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mkisom);
  __Pyx_GIVEREF(__pyx_n_s_mkisom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 949, __pyx_n_s_mkisom)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mksa);
  __Pyx_GIVEREF(__pyx_n_s_mksa);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 950, __pyx_n_s_mksa)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_modf);
  __Pyx_GIVEREF(__pyx_n_s_modf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 951, __pyx_n_s_modf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_modgcd);
  __Pyx_GIVEREF(__pyx_n_s_modgcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 952, __pyx_n_s_modgcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mods);
  __Pyx_GIVEREF(__pyx_n_s_mods);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 953, __pyx_n_s_mods)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_momentum);
  __Pyx_GIVEREF(__pyx_n_s_momentum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 954, __pyx_n_s_momentum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_monotonic);
  __Pyx_GIVEREF(__pyx_n_s_monotonic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 955, __pyx_n_s_monotonic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_montre_tortue);
  __Pyx_GIVEREF(__pyx_n_s_montre_tortue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 956, __pyx_n_s_montre_tortue)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_moustache);
  __Pyx_GIVEREF(__pyx_n_s_moustache);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 957, __pyx_n_s_moustache)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_moving_average);
  __Pyx_GIVEREF(__pyx_n_s_moving_average);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 958, __pyx_n_s_moving_average)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_moyal);
  __Pyx_GIVEREF(__pyx_n_s_moyal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 959, __pyx_n_s_moyal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_moyenne);
  __Pyx_GIVEREF(__pyx_n_s_moyenne);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 960, __pyx_n_s_moyenne)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mul);
  __Pyx_GIVEREF(__pyx_n_s_mul);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 961, __pyx_n_s_mul)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mult_c_conjugate);
  __Pyx_GIVEREF(__pyx_n_s_mult_c_conjugate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 962, __pyx_n_s_mult_c_conjugate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mult_conjugate);
  __Pyx_GIVEREF(__pyx_n_s_mult_conjugate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 963, __pyx_n_s_mult_conjugate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_multinomial);
  __Pyx_GIVEREF(__pyx_n_s_multinomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 964, __pyx_n_s_multinomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_multiplier_conjugue);
  __Pyx_GIVEREF(__pyx_n_s_multiplier_conjugue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 965, __pyx_n_s_multiplier_conjugue)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_multiplier_conjugue_complexe);
  __Pyx_GIVEREF(__pyx_n_s_multiplier_conjugue_complexe);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 966, __pyx_n_s_multiplier_conjugue_complexe)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_multiply);
  __Pyx_GIVEREF(__pyx_n_s_multiply);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 967, __pyx_n_s_multiply)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mupad2maple);
  __Pyx_GIVEREF(__pyx_n_s_mupad2maple);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 968, __pyx_n_s_mupad2maple)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mupad2xcas);
  __Pyx_GIVEREF(__pyx_n_s_mupad2xcas);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 969, __pyx_n_s_mupad2xcas)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_mycielski);
  __Pyx_GIVEREF(__pyx_n_s_mycielski);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 970, __pyx_n_s_mycielski)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nCr);
  __Pyx_GIVEREF(__pyx_n_s_nCr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 971, __pyx_n_s_nCr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nDeriv);
  __Pyx_GIVEREF(__pyx_n_s_nDeriv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 972, __pyx_n_s_nDeriv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nInt);
  __Pyx_GIVEREF(__pyx_n_s_nInt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 973, __pyx_n_s_nInt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nPr);
  __Pyx_GIVEREF(__pyx_n_s_nPr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 974, __pyx_n_s_nPr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nSolve);
  __Pyx_GIVEREF(__pyx_n_s_nSolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 975, __pyx_n_s_nSolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_navy);
  __Pyx_GIVEREF(__pyx_n_s_navy);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 976, __pyx_n_s_navy)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ncols);
  __Pyx_GIVEREF(__pyx_n_s_ncols);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 977, __pyx_n_s_ncols)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_negbinomial);
  __Pyx_GIVEREF(__pyx_n_s_negbinomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 978, __pyx_n_s_negbinomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_negbinomial_cdf);
  __Pyx_GIVEREF(__pyx_n_s_negbinomial_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 979, __pyx_n_s_negbinomial_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_negbinomial_icdf);
  __Pyx_GIVEREF(__pyx_n_s_negbinomial_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 980, __pyx_n_s_negbinomial_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_neighbors);
  __Pyx_GIVEREF(__pyx_n_s_neighbors);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 981, __pyx_n_s_neighbors)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_network_transitivity);
  __Pyx_GIVEREF(__pyx_n_s_network_transitivity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 982, __pyx_n_s_network_transitivity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_neural_network);
  __Pyx_GIVEREF(__pyx_n_s_neural_network);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 983, __pyx_n_s_neural_network)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_newList);
  __Pyx_GIVEREF(__pyx_n_s_newList);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 984, __pyx_n_s_newList)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_newMat);
  __Pyx_GIVEREF(__pyx_n_s_newMat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 985, __pyx_n_s_newMat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_newton);
  __Pyx_GIVEREF(__pyx_n_s_newton);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 986, __pyx_n_s_newton)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_newton_solver);
  __Pyx_GIVEREF(__pyx_n_s_newton_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 987, __pyx_n_s_newton_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_newtonj_solver);
  __Pyx_GIVEREF(__pyx_n_s_newtonj_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 988, __pyx_n_s_newtonj_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nextperm);
  __Pyx_GIVEREF(__pyx_n_s_nextperm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 989, __pyx_n_s_nextperm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nextprime);
  __Pyx_GIVEREF(__pyx_n_s_nextprime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 990, __pyx_n_s_nextprime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_binary);
  __Pyx_GIVEREF(__pyx_n_s_nlp_binary);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 991, __pyx_n_s_nlp_binary)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_binaryvariables);
  __Pyx_GIVEREF(__pyx_n_s_nlp_binaryvariables);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 992, __pyx_n_s_nlp_binaryvariables)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_initialpoint);
  __Pyx_GIVEREF(__pyx_n_s_nlp_initialpoint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 993, __pyx_n_s_nlp_initialpoint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_integer);
  __Pyx_GIVEREF(__pyx_n_s_nlp_integer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 994, __pyx_n_s_nlp_integer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_integervariables);
  __Pyx_GIVEREF(__pyx_n_s_nlp_integervariables);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 995, __pyx_n_s_nlp_integervariables)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_iterationlimit);
  __Pyx_GIVEREF(__pyx_n_s_nlp_iterationlimit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 996, __pyx_n_s_nlp_iterationlimit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_maximize);
  __Pyx_GIVEREF(__pyx_n_s_nlp_maximize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 997, __pyx_n_s_nlp_maximize)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_method);
  __Pyx_GIVEREF(__pyx_n_s_nlp_method);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 998, __pyx_n_s_nlp_method)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_nonnegative);
  __Pyx_GIVEREF(__pyx_n_s_nlp_nonnegative);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 999, __pyx_n_s_nlp_nonnegative)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_nonnegint);
  __Pyx_GIVEREF(__pyx_n_s_nlp_nonnegint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1000, __pyx_n_s_nlp_nonnegint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_precision);
  __Pyx_GIVEREF(__pyx_n_s_nlp_precision);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1001, __pyx_n_s_nlp_precision)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_presolve);
  __Pyx_GIVEREF(__pyx_n_s_nlp_presolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1002, __pyx_n_s_nlp_presolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_tolerance);
  __Pyx_GIVEREF(__pyx_n_s_nlp_tolerance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1003, __pyx_n_s_nlp_tolerance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlp_verbose);
  __Pyx_GIVEREF(__pyx_n_s_nlp_verbose);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1004, __pyx_n_s_nlp_verbose)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nlpsolve);
  __Pyx_GIVEREF(__pyx_n_s_nlpsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1005, __pyx_n_s_nlpsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nodisp);
  __Pyx_GIVEREF(__pyx_n_s_nodisp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1006, __pyx_n_s_nodisp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_non_recursive_normal);
  __Pyx_GIVEREF(__pyx_n_s_non_recursive_normal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1007, __pyx_n_s_non_recursive_normal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nonnegint);
  __Pyx_GIVEREF(__pyx_n_s_nonnegint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1008, __pyx_n_s_nonnegint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nop);
  __Pyx_GIVEREF(__pyx_n_s_nop);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1009, __pyx_n_s_nop)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nops);
  __Pyx_GIVEREF(__pyx_n_s_nops);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1010, __pyx_n_s_nops)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_norm);
  __Pyx_GIVEREF(__pyx_n_s_norm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1011, __pyx_n_s_norm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normal);
  __Pyx_GIVEREF(__pyx_n_s_normal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1012, __pyx_n_s_normal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normal_cdf);
  __Pyx_GIVEREF(__pyx_n_s_normal_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1013, __pyx_n_s_normal_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normal_icdf);
  __Pyx_GIVEREF(__pyx_n_s_normal_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1014, __pyx_n_s_normal_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normald);
  __Pyx_GIVEREF(__pyx_n_s_normald);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1015, __pyx_n_s_normald)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normald_cdf);
  __Pyx_GIVEREF(__pyx_n_s_normald_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1016, __pyx_n_s_normald_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normald_icdf);
  __Pyx_GIVEREF(__pyx_n_s_normald_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1017, __pyx_n_s_normald_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normalize);
  __Pyx_GIVEREF(__pyx_n_s_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1018, __pyx_n_s_normalize)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normalt);
  __Pyx_GIVEREF(__pyx_n_s_normalt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1019, __pyx_n_s_normalt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_normalvariate);
  __Pyx_GIVEREF(__pyx_n_s_normalvariate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1020, __pyx_n_s_normalvariate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nprimes);
  __Pyx_GIVEREF(__pyx_n_s_nprimes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1021, __pyx_n_s_nprimes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nrows);
  __Pyx_GIVEREF(__pyx_n_s_nrows);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1022, __pyx_n_s_nrows)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nstep);
  __Pyx_GIVEREF(__pyx_n_s_nstep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1023, __pyx_n_s_nstep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nuage_points);
  __Pyx_GIVEREF(__pyx_n_s_nuage_points);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1024, __pyx_n_s_nuage_points)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_nullspace);
  __Pyx_GIVEREF(__pyx_n_s_nullspace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1025, __pyx_n_s_nullspace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_number_of_edges);
  __Pyx_GIVEREF(__pyx_n_s_number_of_edges);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1026, __pyx_n_s_number_of_edges)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_number_of_spanning_trees);
  __Pyx_GIVEREF(__pyx_n_s_number_of_spanning_trees);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1027, __pyx_n_s_number_of_spanning_trees)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_number_of_triangles);
  __Pyx_GIVEREF(__pyx_n_s_number_of_triangles);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1028, __pyx_n_s_number_of_triangles)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_number_of_vertices);
  __Pyx_GIVEREF(__pyx_n_s_number_of_vertices);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1029, __pyx_n_s_number_of_vertices)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_numdiff);
  __Pyx_GIVEREF(__pyx_n_s_numdiff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1030, __pyx_n_s_numdiff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_numer);
  __Pyx_GIVEREF(__pyx_n_s_numer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1031, __pyx_n_s_numer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_octahedron);
  __Pyx_GIVEREF(__pyx_n_s_octahedron);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1032, __pyx_n_s_octahedron)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_odd);
  __Pyx_GIVEREF(__pyx_n_s_odd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1033, __pyx_n_s_odd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_odd_girth);
  __Pyx_GIVEREF(__pyx_n_s_odd_girth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1034, __pyx_n_s_odd_girth)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_odd_graph);
  __Pyx_GIVEREF(__pyx_n_s_odd_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1035, __pyx_n_s_odd_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_odeplot);
  __Pyx_GIVEREF(__pyx_n_s_odeplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1036, __pyx_n_s_odeplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_odesolve);
  __Pyx_GIVEREF(__pyx_n_s_odesolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1037, __pyx_n_s_odesolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_olive);
  __Pyx_GIVEREF(__pyx_n_s_olive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1038, __pyx_n_s_olive)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_op);
  __Pyx_GIVEREF(__pyx_n_s_op);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1039, __pyx_n_s_op)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_open_polygon);
  __Pyx_GIVEREF(__pyx_n_s_open_polygon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1040, __pyx_n_s_open_polygon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_orange);
  __Pyx_GIVEREF(__pyx_n_s_orange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1041, __pyx_n_s_orange)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ord);
  __Pyx_GIVEREF(__pyx_n_s_ord);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1042, __pyx_n_s_ord)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_order);
  __Pyx_GIVEREF(__pyx_n_s_order);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1043, __pyx_n_s_order)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_order_size);
  __Pyx_GIVEREF(__pyx_n_s_order_size);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1044, __pyx_n_s_order_size)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ordinate);
  __Pyx_GIVEREF(__pyx_n_s_ordinate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1045, __pyx_n_s_ordinate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_orthocenter);
  __Pyx_GIVEREF(__pyx_n_s_orthocenter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1046, __pyx_n_s_orthocenter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_orthogonal);
  __Pyx_GIVEREF(__pyx_n_s_orthogonal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1047, __pyx_n_s_orthogonal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_osculating_circle);
  __Pyx_GIVEREF(__pyx_n_s_osculating_circle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1048, __pyx_n_s_osculating_circle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_p1oc2);
  __Pyx_GIVEREF(__pyx_n_s_p1oc2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1049, __pyx_n_s_p1oc2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_p1op2);
  __Pyx_GIVEREF(__pyx_n_s_p1op2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1050, __pyx_n_s_p1op2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pa2b2);
  __Pyx_GIVEREF(__pyx_n_s_pa2b2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1051, __pyx_n_s_pa2b2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pade);
  __Pyx_GIVEREF(__pyx_n_s_pade);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1052, __pyx_n_s_pade)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_paley_graph);
  __Pyx_GIVEREF(__pyx_n_s_paley_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1053, __pyx_n_s_paley_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parabola);
  __Pyx_GIVEREF(__pyx_n_s_parabola);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1054, __pyx_n_s_parabola)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parallel);
  __Pyx_GIVEREF(__pyx_n_s_parallel);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1055, __pyx_n_s_parallel)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parallelepiped);
  __Pyx_GIVEREF(__pyx_n_s_parallelepiped);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1056, __pyx_n_s_parallelepiped)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parallelogram);
  __Pyx_GIVEREF(__pyx_n_s_parallelogram);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1057, __pyx_n_s_parallelogram)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parameq);
  __Pyx_GIVEREF(__pyx_n_s_parameq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1058, __pyx_n_s_parameq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parameter);
  __Pyx_GIVEREF(__pyx_n_s_parameter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1059, __pyx_n_s_parameter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_paramplot);
  __Pyx_GIVEREF(__pyx_n_s_paramplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1060, __pyx_n_s_paramplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parfrac);
  __Pyx_GIVEREF(__pyx_n_s_parfrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1061, __pyx_n_s_parfrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pari);
  __Pyx_GIVEREF(__pyx_n_s_pari);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1062, __pyx_n_s_pari)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_part);
  __Pyx_GIVEREF(__pyx_n_s_part);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1063, __pyx_n_s_part)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_partfrac);
  __Pyx_GIVEREF(__pyx_n_s_partfrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1064, __pyx_n_s_partfrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_parzen_window);
  __Pyx_GIVEREF(__pyx_n_s_parzen_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1065, __pyx_n_s_parzen_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pas_de_cote);
  __Pyx_GIVEREF(__pyx_n_s_pas_de_cote);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1066, __pyx_n_s_pas_de_cote)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_path_graph);
  __Pyx_GIVEREF(__pyx_n_s_path_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1067, __pyx_n_s_path_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pcar);
  __Pyx_GIVEREF(__pyx_n_s_pcar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1068, __pyx_n_s_pcar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pcar_hessenberg);
  __Pyx_GIVEREF(__pyx_n_s_pcar_hessenberg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1069, __pyx_n_s_pcar_hessenberg)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pcoef);
  __Pyx_GIVEREF(__pyx_n_s_pcoef);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1070, __pyx_n_s_pcoef)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pcoeff);
  __Pyx_GIVEREF(__pyx_n_s_pcoeff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1071, __pyx_n_s_pcoeff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pencolor);
  __Pyx_GIVEREF(__pyx_n_s_pencolor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1072, __pyx_n_s_pencolor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pendown);
  __Pyx_GIVEREF(__pyx_n_s_pendown);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1073, __pyx_n_s_pendown)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_penup);
  __Pyx_GIVEREF(__pyx_n_s_penup);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1074, __pyx_n_s_penup)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perimeter);
  __Pyx_GIVEREF(__pyx_n_s_perimeter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1075, __pyx_n_s_perimeter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perimeterat);
  __Pyx_GIVEREF(__pyx_n_s_perimeterat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1076, __pyx_n_s_perimeterat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perimeteratraw);
  __Pyx_GIVEREF(__pyx_n_s_perimeteratraw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1077, __pyx_n_s_perimeteratraw)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_period);
  __Pyx_GIVEREF(__pyx_n_s_period);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1078, __pyx_n_s_period)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_periodic);
  __Pyx_GIVEREF(__pyx_n_s_periodic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1079, __pyx_n_s_periodic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perm);
  __Pyx_GIVEREF(__pyx_n_s_perm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1080, __pyx_n_s_perm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perminv);
  __Pyx_GIVEREF(__pyx_n_s_perminv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1081, __pyx_n_s_perminv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_permu2cycles);
  __Pyx_GIVEREF(__pyx_n_s_permu2cycles);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1082, __pyx_n_s_permu2cycles)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_permu2mat);
  __Pyx_GIVEREF(__pyx_n_s_permu2mat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1083, __pyx_n_s_permu2mat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_permuorder);
  __Pyx_GIVEREF(__pyx_n_s_permuorder);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1084, __pyx_n_s_permuorder)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_permute_vertices);
  __Pyx_GIVEREF(__pyx_n_s_permute_vertices);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1085, __pyx_n_s_permute_vertices)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perpen_bisector);
  __Pyx_GIVEREF(__pyx_n_s_perpen_bisector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1086, __pyx_n_s_perpen_bisector)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_perpendicular);
  __Pyx_GIVEREF(__pyx_n_s_perpendicular);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1087, __pyx_n_s_perpendicular)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_petersen_graph);
  __Pyx_GIVEREF(__pyx_n_s_petersen_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1088, __pyx_n_s_petersen_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_peval);
  __Pyx_GIVEREF(__pyx_n_s_peval);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1089, __pyx_n_s_peval)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pi);
  __Pyx_GIVEREF(__pyx_n_s_pi);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1090, __pyx_n_s_pi)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pie);
  __Pyx_GIVEREF(__pyx_n_s_pie);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1091, __pyx_n_s_pie)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_piecewise);
  __Pyx_GIVEREF(__pyx_n_s_piecewise);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1092, __pyx_n_s_piecewise)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pink);
  __Pyx_GIVEREF(__pyx_n_s_pink);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1093, __pyx_n_s_pink)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pivot);
  __Pyx_GIVEREF(__pyx_n_s_pivot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1094, __pyx_n_s_pivot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pixoff);
  __Pyx_GIVEREF(__pyx_n_s_pixoff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1095, __pyx_n_s_pixoff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pixon);
  __Pyx_GIVEREF(__pyx_n_s_pixon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1096, __pyx_n_s_pixon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_planar);
  __Pyx_GIVEREF(__pyx_n_s_planar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1097, __pyx_n_s_planar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plane);
  __Pyx_GIVEREF(__pyx_n_s_plane);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1098, __pyx_n_s_plane)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plane_dual);
  __Pyx_GIVEREF(__pyx_n_s_plane_dual);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1099, __pyx_n_s_plane_dual)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_playsnd);
  __Pyx_GIVEREF(__pyx_n_s_playsnd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1100, __pyx_n_s_playsnd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plex);
  __Pyx_GIVEREF(__pyx_n_s_plex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1101, __pyx_n_s_plex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plot);
  __Pyx_GIVEREF(__pyx_n_s_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1102, __pyx_n_s_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plot3d);
  __Pyx_GIVEREF(__pyx_n_s_plot3d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1103, __pyx_n_s_plot3d)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotarea);
  __Pyx_GIVEREF(__pyx_n_s_plotarea);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1104, __pyx_n_s_plotarea)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotcdf);
  __Pyx_GIVEREF(__pyx_n_s_plotcdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1105, __pyx_n_s_plotcdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotcontour);
  __Pyx_GIVEREF(__pyx_n_s_plotcontour);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1106, __pyx_n_s_plotcontour)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotdensity);
  __Pyx_GIVEREF(__pyx_n_s_plotdensity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1107, __pyx_n_s_plotdensity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotfield);
  __Pyx_GIVEREF(__pyx_n_s_plotfield);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1108, __pyx_n_s_plotfield)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotfunc);
  __Pyx_GIVEREF(__pyx_n_s_plotfunc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1109, __pyx_n_s_plotfunc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotimf);
  __Pyx_GIVEREF(__pyx_n_s_plotimf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1110, __pyx_n_s_plotimf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotimplicit);
  __Pyx_GIVEREF(__pyx_n_s_plotimplicit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1111, __pyx_n_s_plotimplicit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotinequation);
  __Pyx_GIVEREF(__pyx_n_s_plotinequation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1112, __pyx_n_s_plotinequation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotlist);
  __Pyx_GIVEREF(__pyx_n_s_plotlist);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1113, __pyx_n_s_plotlist)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotode);
  __Pyx_GIVEREF(__pyx_n_s_plotode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1114, __pyx_n_s_plotode)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotparam);
  __Pyx_GIVEREF(__pyx_n_s_plotparam);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1115, __pyx_n_s_plotparam)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotpolar);
  __Pyx_GIVEREF(__pyx_n_s_plotpolar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1116, __pyx_n_s_plotpolar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotproba);
  __Pyx_GIVEREF(__pyx_n_s_plotproba);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1117, __pyx_n_s_plotproba)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotseq);
  __Pyx_GIVEREF(__pyx_n_s_plotseq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1118, __pyx_n_s_plotseq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotspectrum);
  __Pyx_GIVEREF(__pyx_n_s_plotspectrum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1119, __pyx_n_s_plotspectrum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plotwav);
  __Pyx_GIVEREF(__pyx_n_s_plotwav);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1120, __pyx_n_s_plotwav)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_plus_point);
  __Pyx_GIVEREF(__pyx_n_s_plus_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1121, __pyx_n_s_plus_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pmin);
  __Pyx_GIVEREF(__pyx_n_s_pmin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1122, __pyx_n_s_pmin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point);
  __Pyx_GIVEREF(__pyx_n_s_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1123, __pyx_n_s_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point2d);
  __Pyx_GIVEREF(__pyx_n_s_point2d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1124, __pyx_n_s_point2d)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_point3d);
  __Pyx_GIVEREF(__pyx_n_s_point3d);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1125, __pyx_n_s_point3d)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_poisson);
  __Pyx_GIVEREF(__pyx_n_s_poisson);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1126, __pyx_n_s_poisson)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_poisson_cdf);
  __Pyx_GIVEREF(__pyx_n_s_poisson_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1127, __pyx_n_s_poisson_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_poisson_icdf);
  __Pyx_GIVEREF(__pyx_n_s_poisson_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1128, __pyx_n_s_poisson_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_poisson_window);
  __Pyx_GIVEREF(__pyx_n_s_poisson_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1129, __pyx_n_s_poisson_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polar);
  __Pyx_GIVEREF(__pyx_n_s_polar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1130, __pyx_n_s_polar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polar_coordinates);
  __Pyx_GIVEREF(__pyx_n_s_polar_coordinates);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1131, __pyx_n_s_polar_coordinates)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polar_point);
  __Pyx_GIVEREF(__pyx_n_s_polar_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1132, __pyx_n_s_polar_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polarplot);
  __Pyx_GIVEREF(__pyx_n_s_polarplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1133, __pyx_n_s_polarplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pole);
  __Pyx_GIVEREF(__pyx_n_s_pole);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1134, __pyx_n_s_pole)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_poly2symb);
  __Pyx_GIVEREF(__pyx_n_s_poly2symb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1135, __pyx_n_s_poly2symb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polyEval);
  __Pyx_GIVEREF(__pyx_n_s_polyEval);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1136, __pyx_n_s_polyEval)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polygon);
  __Pyx_GIVEREF(__pyx_n_s_polygon);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1137, __pyx_n_s_polygon)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polygone_rempli);
  __Pyx_GIVEREF(__pyx_n_s_polygone_rempli);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1138, __pyx_n_s_polygone_rempli)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polygonplot);
  __Pyx_GIVEREF(__pyx_n_s_polygonplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1139, __pyx_n_s_polygonplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polygonscatterplot);
  __Pyx_GIVEREF(__pyx_n_s_polygonscatterplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1140, __pyx_n_s_polygonscatterplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polyhedron);
  __Pyx_GIVEREF(__pyx_n_s_polyhedron);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1141, __pyx_n_s_polyhedron)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polynom);
  __Pyx_GIVEREF(__pyx_n_s_polynom);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1142, __pyx_n_s_polynom)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polynomial_regression);
  __Pyx_GIVEREF(__pyx_n_s_polynomial_regression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1143, __pyx_n_s_polynomial_regression)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_polynomial_regression_plot);
  __Pyx_GIVEREF(__pyx_n_s_polynomial_regression_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1144, __pyx_n_s_polynomial_regression_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_position);
  __Pyx_GIVEREF(__pyx_n_s_position);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1145, __pyx_n_s_position)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_poslbdLMQ);
  __Pyx_GIVEREF(__pyx_n_s_poslbdLMQ);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1146, __pyx_n_s_poslbdLMQ)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_posubLMQ);
  __Pyx_GIVEREF(__pyx_n_s_posubLMQ);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1147, __pyx_n_s_posubLMQ)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_potential);
  __Pyx_GIVEREF(__pyx_n_s_potential);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1148, __pyx_n_s_potential)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pow2exp);
  __Pyx_GIVEREF(__pyx_n_s_pow2exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1149, __pyx_n_s_pow2exp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_power_regression);
  __Pyx_GIVEREF(__pyx_n_s_power_regression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1150, __pyx_n_s_power_regression)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_power_regression_plot);
  __Pyx_GIVEREF(__pyx_n_s_power_regression_plot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1151, __pyx_n_s_power_regression_plot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_powermod);
  __Pyx_GIVEREF(__pyx_n_s_powermod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1152, __pyx_n_s_powermod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_powerpc);
  __Pyx_GIVEREF(__pyx_n_s_powerpc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1153, __pyx_n_s_powerpc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_powexpand);
  __Pyx_GIVEREF(__pyx_n_s_powexpand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1154, __pyx_n_s_powexpand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_powmod);
  __Pyx_GIVEREF(__pyx_n_s_powmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1155, __pyx_n_s_powmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_prepend);
  __Pyx_GIVEREF(__pyx_n_s_prepend);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1156, __pyx_n_s_prepend)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_preval);
  __Pyx_GIVEREF(__pyx_n_s_preval);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1157, __pyx_n_s_preval)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_prevperm);
  __Pyx_GIVEREF(__pyx_n_s_prevperm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1158, __pyx_n_s_prevperm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_prevprime);
  __Pyx_GIVEREF(__pyx_n_s_prevprime);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1159, __pyx_n_s_prevprime)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_primpart);
  __Pyx_GIVEREF(__pyx_n_s_primpart);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1160, __pyx_n_s_primpart)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_printf);
  __Pyx_GIVEREF(__pyx_n_s_printf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1161, __pyx_n_s_printf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_prism);
  __Pyx_GIVEREF(__pyx_n_s_prism);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1162, __pyx_n_s_prism)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_prism_graph);
  __Pyx_GIVEREF(__pyx_n_s_prism_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1163, __pyx_n_s_prism_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_product);
  __Pyx_GIVEREF(__pyx_n_s_product);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1164, __pyx_n_s_product)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_projection);
  __Pyx_GIVEREF(__pyx_n_s_projection);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1165, __pyx_n_s_projection)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_proot);
  __Pyx_GIVEREF(__pyx_n_s_proot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1166, __pyx_n_s_proot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_propFrac);
  __Pyx_GIVEREF(__pyx_n_s_propFrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1167, __pyx_n_s_propFrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_propfrac);
  __Pyx_GIVEREF(__pyx_n_s_propfrac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1168, __pyx_n_s_propfrac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pruefer_code);
  __Pyx_GIVEREF(__pyx_n_s_pruefer_code);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1169, __pyx_n_s_pruefer_code)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_psrgcd);
  __Pyx_GIVEREF(__pyx_n_s_psrgcd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1170, __pyx_n_s_psrgcd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ptayl);
  __Pyx_GIVEREF(__pyx_n_s_ptayl);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1171, __pyx_n_s_ptayl)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_purge);
  __Pyx_GIVEREF(__pyx_n_s_purge);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1172, __pyx_n_s_purge)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_purple);
  __Pyx_GIVEREF(__pyx_n_s_purple);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1173, __pyx_n_s_purple)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pwd);
  __Pyx_GIVEREF(__pyx_n_s_pwd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1174, __pyx_n_s_pwd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_pyramid);
  __Pyx_GIVEREF(__pyx_n_s_pyramid);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1175, __pyx_n_s_pyramid)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_python_compat);
  __Pyx_GIVEREF(__pyx_n_s_python_compat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1176, __pyx_n_s_python_compat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_q2a);
  __Pyx_GIVEREF(__pyx_n_s_q2a);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1177, __pyx_n_s_q2a)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_qr);
  __Pyx_GIVEREF(__pyx_n_s_qr);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1178, __pyx_n_s_qr)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quadric);
  __Pyx_GIVEREF(__pyx_n_s_quadric);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1179, __pyx_n_s_quadric)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quadrilateral);
  __Pyx_GIVEREF(__pyx_n_s_quadrilateral);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1180, __pyx_n_s_quadrilateral)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quantile);
  __Pyx_GIVEREF(__pyx_n_s_quantile);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1181, __pyx_n_s_quantile)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quartile1);
  __Pyx_GIVEREF(__pyx_n_s_quartile1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1182, __pyx_n_s_quartile1)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quartile3);
  __Pyx_GIVEREF(__pyx_n_s_quartile3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1183, __pyx_n_s_quartile3)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quartiles);
  __Pyx_GIVEREF(__pyx_n_s_quartiles);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1184, __pyx_n_s_quartiles)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quest);
  __Pyx_GIVEREF(__pyx_n_s_quest);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1185, __pyx_n_s_quest)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quo);
  __Pyx_GIVEREF(__pyx_n_s_quo);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1186, __pyx_n_s_quo)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quorem);
  __Pyx_GIVEREF(__pyx_n_s_quorem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1187, __pyx_n_s_quorem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_quote);
  __Pyx_GIVEREF(__pyx_n_s_quote);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1188, __pyx_n_s_quote)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_r2e);
  __Pyx_GIVEREF(__pyx_n_s_r2e);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1189, __pyx_n_s_r2e)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_radians);
  __Pyx_GIVEREF(__pyx_n_s_radians);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1190, __pyx_n_s_radians)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_radical_axis);
  __Pyx_GIVEREF(__pyx_n_s_radical_axis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1191, __pyx_n_s_radical_axis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_radius);
  __Pyx_GIVEREF(__pyx_n_s_radius);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1192, __pyx_n_s_radius)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ramene);
  __Pyx_GIVEREF(__pyx_n_s_ramene);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1193, __pyx_n_s_ramene)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rand);
  __Pyx_GIVEREF(__pyx_n_s_rand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1194, __pyx_n_s_rand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randMat);
  __Pyx_GIVEREF(__pyx_n_s_randMat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1195, __pyx_n_s_randMat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randNorm);
  __Pyx_GIVEREF(__pyx_n_s_randNorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1196, __pyx_n_s_randNorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randPoly);
  __Pyx_GIVEREF(__pyx_n_s_randPoly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1197, __pyx_n_s_randPoly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randbetad);
  __Pyx_GIVEREF(__pyx_n_s_randbetad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1198, __pyx_n_s_randbetad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randbinomial);
  __Pyx_GIVEREF(__pyx_n_s_randbinomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1199, __pyx_n_s_randbinomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randchisquare);
  __Pyx_GIVEREF(__pyx_n_s_randchisquare);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1200, __pyx_n_s_randchisquare)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randexp);
  __Pyx_GIVEREF(__pyx_n_s_randexp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1201, __pyx_n_s_randexp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randfisher);
  __Pyx_GIVEREF(__pyx_n_s_randfisher);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1202, __pyx_n_s_randfisher)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randgammad);
  __Pyx_GIVEREF(__pyx_n_s_randgammad);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1203, __pyx_n_s_randgammad)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randgeometric);
  __Pyx_GIVEREF(__pyx_n_s_randgeometric);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1204, __pyx_n_s_randgeometric)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randint);
  __Pyx_GIVEREF(__pyx_n_s_randint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1205, __pyx_n_s_randint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randmarkov);
  __Pyx_GIVEREF(__pyx_n_s_randmarkov);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1206, __pyx_n_s_randmarkov)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randmatrix);
  __Pyx_GIVEREF(__pyx_n_s_randmatrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1207, __pyx_n_s_randmatrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randmultinomial);
  __Pyx_GIVEREF(__pyx_n_s_randmultinomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1208, __pyx_n_s_randmultinomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randnorm);
  __Pyx_GIVEREF(__pyx_n_s_randnorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1209, __pyx_n_s_randnorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random);
  __Pyx_GIVEREF(__pyx_n_s_random);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1210, __pyx_n_s_random)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_bipartite_graph);
  __Pyx_GIVEREF(__pyx_n_s_random_bipartite_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1211, __pyx_n_s_random_bipartite_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_digraph);
  __Pyx_GIVEREF(__pyx_n_s_random_digraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1212, __pyx_n_s_random_digraph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_graph);
  __Pyx_GIVEREF(__pyx_n_s_random_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1213, __pyx_n_s_random_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_network);
  __Pyx_GIVEREF(__pyx_n_s_random_network);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1214, __pyx_n_s_random_network)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_planar_graph);
  __Pyx_GIVEREF(__pyx_n_s_random_planar_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1215, __pyx_n_s_random_planar_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_regular_graph);
  __Pyx_GIVEREF(__pyx_n_s_random_regular_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1216, __pyx_n_s_random_regular_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_sequence_graph);
  __Pyx_GIVEREF(__pyx_n_s_random_sequence_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1217, __pyx_n_s_random_sequence_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_tournament);
  __Pyx_GIVEREF(__pyx_n_s_random_tournament);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1218, __pyx_n_s_random_tournament)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_tree);
  __Pyx_GIVEREF(__pyx_n_s_random_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1219, __pyx_n_s_random_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_random_variable);
  __Pyx_GIVEREF(__pyx_n_s_random_variable);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1220, __pyx_n_s_random_variable)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randperm);
  __Pyx_GIVEREF(__pyx_n_s_randperm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1221, __pyx_n_s_randperm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randpoisson);
  __Pyx_GIVEREF(__pyx_n_s_randpoisson);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1222, __pyx_n_s_randpoisson)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randpoly);
  __Pyx_GIVEREF(__pyx_n_s_randpoly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1223, __pyx_n_s_randpoly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randseed);
  __Pyx_GIVEREF(__pyx_n_s_randseed);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1224, __pyx_n_s_randseed)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randstudent);
  __Pyx_GIVEREF(__pyx_n_s_randstudent);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1225, __pyx_n_s_randstudent)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randvar);
  __Pyx_GIVEREF(__pyx_n_s_randvar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1226, __pyx_n_s_randvar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randvector);
  __Pyx_GIVEREF(__pyx_n_s_randvector);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1227, __pyx_n_s_randvector)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_randweibulld);
  __Pyx_GIVEREF(__pyx_n_s_randweibulld);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1228, __pyx_n_s_randweibulld)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rank);
  __Pyx_GIVEREF(__pyx_n_s_rank);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1229, __pyx_n_s_rank)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ranm);
  __Pyx_GIVEREF(__pyx_n_s_ranm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1230, __pyx_n_s_ranm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ranv);
  __Pyx_GIVEREF(__pyx_n_s_ranv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1231, __pyx_n_s_ranv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rassembler_trigo);
  __Pyx_GIVEREF(__pyx_n_s_rassembler_trigo);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1232, __pyx_n_s_rassembler_trigo)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rat_jordan);
  __Pyx_GIVEREF(__pyx_n_s_rat_jordan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1233, __pyx_n_s_rat_jordan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ratinterp);
  __Pyx_GIVEREF(__pyx_n_s_ratinterp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1234, __pyx_n_s_ratinterp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rational);
  __Pyx_GIVEREF(__pyx_n_s_rational);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1235, __pyx_n_s_rational)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rationalroot);
  __Pyx_GIVEREF(__pyx_n_s_rationalroot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1236, __pyx_n_s_rationalroot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ratnormal);
  __Pyx_GIVEREF(__pyx_n_s_ratnormal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1237, __pyx_n_s_ratnormal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rdiv);
  __Pyx_GIVEREF(__pyx_n_s_rdiv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1238, __pyx_n_s_rdiv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_re);
  __Pyx_GIVEREF(__pyx_n_s_re);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1239, __pyx_n_s_re)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reachable);
  __Pyx_GIVEREF(__pyx_n_s_reachable);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1240, __pyx_n_s_reachable)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_read);
  __Pyx_GIVEREF(__pyx_n_s_read);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1241, __pyx_n_s_read)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_readrgb);
  __Pyx_GIVEREF(__pyx_n_s_readrgb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1242, __pyx_n_s_readrgb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_readwav);
  __Pyx_GIVEREF(__pyx_n_s_readwav);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1243, __pyx_n_s_readwav)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_real);
  __Pyx_GIVEREF(__pyx_n_s_real);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1244, __pyx_n_s_real)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_realroot);
  __Pyx_GIVEREF(__pyx_n_s_realroot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1245, __pyx_n_s_realroot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reciprocation);
  __Pyx_GIVEREF(__pyx_n_s_reciprocation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1246, __pyx_n_s_reciprocation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rect);
  __Pyx_GIVEREF(__pyx_n_s_rect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1247, __pyx_n_s_rect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rectangle);
  __Pyx_GIVEREF(__pyx_n_s_rectangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1248, __pyx_n_s_rectangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rectangle_droit);
  __Pyx_GIVEREF(__pyx_n_s_rectangle_droit);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1249, __pyx_n_s_rectangle_droit)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rectangle_gauche);
  __Pyx_GIVEREF(__pyx_n_s_rectangle_gauche);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1250, __pyx_n_s_rectangle_gauche)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rectangle_plein);
  __Pyx_GIVEREF(__pyx_n_s_rectangle_plein);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1251, __pyx_n_s_rectangle_plein)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rectangular_coordinates);
  __Pyx_GIVEREF(__pyx_n_s_rectangular_coordinates);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1252, __pyx_n_s_rectangular_coordinates)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_recule);
  __Pyx_GIVEREF(__pyx_n_s_recule);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1253, __pyx_n_s_recule)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_red);
  __Pyx_GIVEREF(__pyx_n_s_red);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1254, __pyx_n_s_red)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reduced_conic);
  __Pyx_GIVEREF(__pyx_n_s_reduced_conic);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1255, __pyx_n_s_reduced_conic)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reduced_quadric);
  __Pyx_GIVEREF(__pyx_n_s_reduced_quadric);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1256, __pyx_n_s_reduced_quadric)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ref);
  __Pyx_GIVEREF(__pyx_n_s_ref);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1257, __pyx_n_s_ref)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reflection);
  __Pyx_GIVEREF(__pyx_n_s_reflection);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1258, __pyx_n_s_reflection)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_regroup);
  __Pyx_GIVEREF(__pyx_n_s_regroup);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1259, __pyx_n_s_regroup)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_relabel_vertices);
  __Pyx_GIVEREF(__pyx_n_s_relabel_vertices);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1260, __pyx_n_s_relabel_vertices)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reliability_polynomial);
  __Pyx_GIVEREF(__pyx_n_s_reliability_polynomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1261, __pyx_n_s_reliability_polynomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rem);
  __Pyx_GIVEREF(__pyx_n_s_rem);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1262, __pyx_n_s_rem)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_remain);
  __Pyx_GIVEREF(__pyx_n_s_remain);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1263, __pyx_n_s_remain)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_remove);
  __Pyx_GIVEREF(__pyx_n_s_remove);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1264, __pyx_n_s_remove)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reorder);
  __Pyx_GIVEREF(__pyx_n_s_reorder);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1265, __pyx_n_s_reorder)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_resample);
  __Pyx_GIVEREF(__pyx_n_s_resample);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1266, __pyx_n_s_resample)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_residue);
  __Pyx_GIVEREF(__pyx_n_s_residue);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1267, __pyx_n_s_residue)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_resoudre);
  __Pyx_GIVEREF(__pyx_n_s_resoudre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1268, __pyx_n_s_resoudre)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_resoudre_dans_C);
  __Pyx_GIVEREF(__pyx_n_s_resoudre_dans_C);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1269, __pyx_n_s_resoudre_dans_C)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_resoudre_systeme_lineaire);
  __Pyx_GIVEREF(__pyx_n_s_resoudre_systeme_lineaire);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1270, __pyx_n_s_resoudre_systeme_lineaire)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_resultant);
  __Pyx_GIVEREF(__pyx_n_s_resultant);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1271, __pyx_n_s_resultant)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reverse);
  __Pyx_GIVEREF(__pyx_n_s_reverse);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1272, __pyx_n_s_reverse)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reverse_graph);
  __Pyx_GIVEREF(__pyx_n_s_reverse_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1273, __pyx_n_s_reverse_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_reverse_rsolve);
  __Pyx_GIVEREF(__pyx_n_s_reverse_rsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1274, __pyx_n_s_reverse_rsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_revert);
  __Pyx_GIVEREF(__pyx_n_s_revert);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1275, __pyx_n_s_revert)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_revlex);
  __Pyx_GIVEREF(__pyx_n_s_revlex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1276, __pyx_n_s_revlex)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_revlist);
  __Pyx_GIVEREF(__pyx_n_s_revlist);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1277, __pyx_n_s_revlist)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rgb);
  __Pyx_GIVEREF(__pyx_n_s_rgb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1278, __pyx_n_s_rgb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rgb2hsv);
  __Pyx_GIVEREF(__pyx_n_s_rgb2hsv);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1279, __pyx_n_s_rgb2hsv)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rgb2xyz);
  __Pyx_GIVEREF(__pyx_n_s_rgb2xyz);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1280, __pyx_n_s_rgb2xyz)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rhombus);
  __Pyx_GIVEREF(__pyx_n_s_rhombus);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1281, __pyx_n_s_rhombus)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rhombus_point);
  __Pyx_GIVEREF(__pyx_n_s_rhombus_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1282, __pyx_n_s_rhombus_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rhs);
  __Pyx_GIVEREF(__pyx_n_s_rhs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1283, __pyx_n_s_rhs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_riemann_window);
  __Pyx_GIVEREF(__pyx_n_s_riemann_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1284, __pyx_n_s_riemann_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_right);
  __Pyx_GIVEREF(__pyx_n_s_right);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1285, __pyx_n_s_right)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_right_rectangle);
  __Pyx_GIVEREF(__pyx_n_s_right_rectangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1286, __pyx_n_s_right_rectangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_right_triangle);
  __Pyx_GIVEREF(__pyx_n_s_right_triangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1287, __pyx_n_s_right_triangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_risch);
  __Pyx_GIVEREF(__pyx_n_s_risch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1288, __pyx_n_s_risch)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rm_a_z);
  __Pyx_GIVEREF(__pyx_n_s_rm_a_z);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1289, __pyx_n_s_rm_a_z)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rm_all_vars);
  __Pyx_GIVEREF(__pyx_n_s_rm_all_vars);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1290, __pyx_n_s_rm_all_vars)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rmbreakpoint);
  __Pyx_GIVEREF(__pyx_n_s_rmbreakpoint);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1291, __pyx_n_s_rmbreakpoint)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rmmod);
  __Pyx_GIVEREF(__pyx_n_s_rmmod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1292, __pyx_n_s_rmmod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rms);
  __Pyx_GIVEREF(__pyx_n_s_rms);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1293, __pyx_n_s_rms)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rmwatch);
  __Pyx_GIVEREF(__pyx_n_s_rmwatch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1294, __pyx_n_s_rmwatch)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_romberg);
  __Pyx_GIVEREF(__pyx_n_s_romberg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1295, __pyx_n_s_romberg)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rombergm);
  __Pyx_GIVEREF(__pyx_n_s_rombergm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1296, __pyx_n_s_rombergm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rombergt);
  __Pyx_GIVEREF(__pyx_n_s_rombergt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1297, __pyx_n_s_rombergt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rond);
  __Pyx_GIVEREF(__pyx_n_s_rond);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1298, __pyx_n_s_rond)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_root);
  __Pyx_GIVEREF(__pyx_n_s_root);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1299, __pyx_n_s_root)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rootof);
  __Pyx_GIVEREF(__pyx_n_s_rootof);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1300, __pyx_n_s_rootof)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_roots);
  __Pyx_GIVEREF(__pyx_n_s_roots);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1301, __pyx_n_s_roots)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rotate);
  __Pyx_GIVEREF(__pyx_n_s_rotate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1302, __pyx_n_s_rotate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rotation);
  __Pyx_GIVEREF(__pyx_n_s_rotation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1303, __pyx_n_s_rotation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_round);
  __Pyx_GIVEREF(__pyx_n_s_round);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1304, __pyx_n_s_round)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_row);
  __Pyx_GIVEREF(__pyx_n_s_row);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1305, __pyx_n_s_row)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowAdd);
  __Pyx_GIVEREF(__pyx_n_s_rowAdd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1306, __pyx_n_s_rowAdd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowDim);
  __Pyx_GIVEREF(__pyx_n_s_rowDim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1307, __pyx_n_s_rowDim)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowNorm);
  __Pyx_GIVEREF(__pyx_n_s_rowNorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1308, __pyx_n_s_rowNorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowSwap);
  __Pyx_GIVEREF(__pyx_n_s_rowSwap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1309, __pyx_n_s_rowSwap)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowdim);
  __Pyx_GIVEREF(__pyx_n_s_rowdim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1310, __pyx_n_s_rowdim)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rownorm);
  __Pyx_GIVEREF(__pyx_n_s_rownorm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1311, __pyx_n_s_rownorm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowspace);
  __Pyx_GIVEREF(__pyx_n_s_rowspace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1312, __pyx_n_s_rowspace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rowswap);
  __Pyx_GIVEREF(__pyx_n_s_rowswap);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1313, __pyx_n_s_rowswap)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rref);
  __Pyx_GIVEREF(__pyx_n_s_rref);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1314, __pyx_n_s_rref)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rsolve);
  __Pyx_GIVEREF(__pyx_n_s_rsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1315, __pyx_n_s_rsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rur);
  __Pyx_GIVEREF(__pyx_n_s_rur);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1316, __pyx_n_s_rur)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rur_certify);
  __Pyx_GIVEREF(__pyx_n_s_rur_certify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1317, __pyx_n_s_rur_certify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_rur_gbasis);
  __Pyx_GIVEREF(__pyx_n_s_rur_gbasis);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1318, __pyx_n_s_rur_gbasis)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_same);
  __Pyx_GIVEREF(__pyx_n_s_same);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1319, __pyx_n_s_same)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sample);
  __Pyx_GIVEREF(__pyx_n_s_sample);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1320, __pyx_n_s_sample)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_samplerate);
  __Pyx_GIVEREF(__pyx_n_s_samplerate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1321, __pyx_n_s_samplerate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sans_factoriser);
  __Pyx_GIVEREF(__pyx_n_s_sans_factoriser);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1322, __pyx_n_s_sans_factoriser)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_saute);
  __Pyx_GIVEREF(__pyx_n_s_saute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1323, __pyx_n_s_saute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_scalarProduct);
  __Pyx_GIVEREF(__pyx_n_s_scalarProduct);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1324, __pyx_n_s_scalarProduct)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_scalar_product);
  __Pyx_GIVEREF(__pyx_n_s_scalar_product);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1325, __pyx_n_s_scalar_product)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_scatterplot);
  __Pyx_GIVEREF(__pyx_n_s_scatterplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1326, __pyx_n_s_scatterplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_schur);
  __Pyx_GIVEREF(__pyx_n_s_schur);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1327, __pyx_n_s_schur)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sec);
  __Pyx_GIVEREF(__pyx_n_s_sec);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1328, __pyx_n_s_sec)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_secant_solver);
  __Pyx_GIVEREF(__pyx_n_s_secant_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1329, __pyx_n_s_secant_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_segment);
  __Pyx_GIVEREF(__pyx_n_s_segment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1330, __pyx_n_s_segment)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_seidel_spectrum);
  __Pyx_GIVEREF(__pyx_n_s_seidel_spectrum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1331, __pyx_n_s_seidel_spectrum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_seidel_switch);
  __Pyx_GIVEREF(__pyx_n_s_seidel_switch);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1332, __pyx_n_s_seidel_switch)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_select);
  __Pyx_GIVEREF(__pyx_n_s_select);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1333, __pyx_n_s_select)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_semi_augment);
  __Pyx_GIVEREF(__pyx_n_s_semi_augment);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1334, __pyx_n_s_semi_augment)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_seq);
  __Pyx_GIVEREF(__pyx_n_s_seq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1335, __pyx_n_s_seq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_seqplot);
  __Pyx_GIVEREF(__pyx_n_s_seqplot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1336, __pyx_n_s_seqplot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_seqsolve);
  __Pyx_GIVEREF(__pyx_n_s_seqsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1337, __pyx_n_s_seqsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sequence_graph);
  __Pyx_GIVEREF(__pyx_n_s_sequence_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1338, __pyx_n_s_sequence_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_series);
  __Pyx_GIVEREF(__pyx_n_s_series);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1339, __pyx_n_s_series)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_channel_data);
  __Pyx_GIVEREF(__pyx_n_s_set_channel_data);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1340, __pyx_n_s_set_channel_data)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_edge_attribute);
  __Pyx_GIVEREF(__pyx_n_s_set_edge_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1341, __pyx_n_s_set_edge_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_edge_weight);
  __Pyx_GIVEREF(__pyx_n_s_set_edge_weight);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1342, __pyx_n_s_set_edge_weight)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_graph_attribute);
  __Pyx_GIVEREF(__pyx_n_s_set_graph_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1343, __pyx_n_s_set_graph_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_pixel);
  __Pyx_GIVEREF(__pyx_n_s_set_pixel);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1344, __pyx_n_s_set_pixel)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_screen);
  __Pyx_GIVEREF(__pyx_n_s_set_screen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1345, __pyx_n_s_set_screen)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_vertex_attribute);
  __Pyx_GIVEREF(__pyx_n_s_set_vertex_attribute);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1346, __pyx_n_s_set_vertex_attribute)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_set_vertex_positions);
  __Pyx_GIVEREF(__pyx_n_s_set_vertex_positions);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1347, __pyx_n_s_set_vertex_positions)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_shift);
  __Pyx_GIVEREF(__pyx_n_s_shift);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1348, __pyx_n_s_shift)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_shift_phase);
  __Pyx_GIVEREF(__pyx_n_s_shift_phase);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1349, __pyx_n_s_shift_phase)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_shortest_path);
  __Pyx_GIVEREF(__pyx_n_s_shortest_path);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1350, __pyx_n_s_shortest_path)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_show_pixels);
  __Pyx_GIVEREF(__pyx_n_s_show_pixels);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1351, __pyx_n_s_show_pixels)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_shuffle);
  __Pyx_GIVEREF(__pyx_n_s_shuffle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1352, __pyx_n_s_shuffle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sierpinski_graph);
  __Pyx_GIVEREF(__pyx_n_s_sierpinski_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1353, __pyx_n_s_sierpinski_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sign);
  __Pyx_GIVEREF(__pyx_n_s_sign);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1354, __pyx_n_s_sign)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sign2Heaviside);
  __Pyx_GIVEREF(__pyx_n_s_sign2Heaviside);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1355, __pyx_n_s_sign2Heaviside)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_signature);
  __Pyx_GIVEREF(__pyx_n_s_signature);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1356, __pyx_n_s_signature)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_signe);
  __Pyx_GIVEREF(__pyx_n_s_signe);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1357, __pyx_n_s_signe)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_similarity);
  __Pyx_GIVEREF(__pyx_n_s_similarity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1358, __pyx_n_s_similarity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simp2);
  __Pyx_GIVEREF(__pyx_n_s_simp2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1359, __pyx_n_s_simp2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simplex_reduce);
  __Pyx_GIVEREF(__pyx_n_s_simplex_reduce);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1360, __pyx_n_s_simplex_reduce)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simplicial_vertices);
  __Pyx_GIVEREF(__pyx_n_s_simplicial_vertices);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1361, __pyx_n_s_simplicial_vertices)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simplifier);
  __Pyx_GIVEREF(__pyx_n_s_simplifier);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1362, __pyx_n_s_simplifier)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simplify);
  __Pyx_GIVEREF(__pyx_n_s_simplify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1363, __pyx_n_s_simplify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simplifyDirac);
  __Pyx_GIVEREF(__pyx_n_s_simplifyDirac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1364, __pyx_n_s_simplifyDirac)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simpson);
  __Pyx_GIVEREF(__pyx_n_s_simpson);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1365, __pyx_n_s_simpson)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simulated_annealing);
  __Pyx_GIVEREF(__pyx_n_s_simulated_annealing);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1366, __pyx_n_s_simulated_annealing)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_simult);
  __Pyx_GIVEREF(__pyx_n_s_simult);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1367, __pyx_n_s_simult)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sin);
  __Pyx_GIVEREF(__pyx_n_s_sin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1368, __pyx_n_s_sin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sin2costan);
  __Pyx_GIVEREF(__pyx_n_s_sin2costan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1369, __pyx_n_s_sin2costan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sinc);
  __Pyx_GIVEREF(__pyx_n_s_sinc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1370, __pyx_n_s_sinc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sincos);
  __Pyx_GIVEREF(__pyx_n_s_sincos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1371, __pyx_n_s_sincos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_single_inter);
  __Pyx_GIVEREF(__pyx_n_s_single_inter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1372, __pyx_n_s_single_inter)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sinh);
  __Pyx_GIVEREF(__pyx_n_s_sinh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1373, __pyx_n_s_sinh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sizes);
  __Pyx_GIVEREF(__pyx_n_s_sizes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1374, __pyx_n_s_sizes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_slope);
  __Pyx_GIVEREF(__pyx_n_s_slope);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1375, __pyx_n_s_slope)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_slopeat);
  __Pyx_GIVEREF(__pyx_n_s_slopeat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1376, __pyx_n_s_slopeat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_slopeatraw);
  __Pyx_GIVEREF(__pyx_n_s_slopeatraw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1377, __pyx_n_s_slopeatraw)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_smith);
  __Pyx_GIVEREF(__pyx_n_s_smith);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1378, __pyx_n_s_smith)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_smod);
  __Pyx_GIVEREF(__pyx_n_s_smod);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1379, __pyx_n_s_smod)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_snedecor);
  __Pyx_GIVEREF(__pyx_n_s_snedecor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1380, __pyx_n_s_snedecor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_snedecor_cdf);
  __Pyx_GIVEREF(__pyx_n_s_snedecor_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1381, __pyx_n_s_snedecor_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_snedecor_icdf);
  __Pyx_GIVEREF(__pyx_n_s_snedecor_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1382, __pyx_n_s_snedecor_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_snedecord);
  __Pyx_GIVEREF(__pyx_n_s_snedecord);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1383, __pyx_n_s_snedecord)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_snedecord_cdf);
  __Pyx_GIVEREF(__pyx_n_s_snedecord_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1384, __pyx_n_s_snedecord_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_snedecord_icdf);
  __Pyx_GIVEREF(__pyx_n_s_snedecord_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1385, __pyx_n_s_snedecord_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_solid_line);
  __Pyx_GIVEREF(__pyx_n_s_solid_line);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1386, __pyx_n_s_solid_line)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_solve);
  __Pyx_GIVEREF(__pyx_n_s_solve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1387, __pyx_n_s_solve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_somme);
  __Pyx_GIVEREF(__pyx_n_s_somme);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1388, __pyx_n_s_somme)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sommet);
  __Pyx_GIVEREF(__pyx_n_s_sommet);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1389, __pyx_n_s_sommet)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sort);
  __Pyx_GIVEREF(__pyx_n_s_sort);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1390, __pyx_n_s_sort)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sorta);
  __Pyx_GIVEREF(__pyx_n_s_sorta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1391, __pyx_n_s_sorta)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sortd);
  __Pyx_GIVEREF(__pyx_n_s_sortd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1392, __pyx_n_s_sortd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sorted);
  __Pyx_GIVEREF(__pyx_n_s_sorted);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1393, __pyx_n_s_sorted)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sortperm);
  __Pyx_GIVEREF(__pyx_n_s_sortperm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1394, __pyx_n_s_sortperm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_soundsec);
  __Pyx_GIVEREF(__pyx_n_s_soundsec);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1395, __pyx_n_s_soundsec)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_spanning_tree);
  __Pyx_GIVEREF(__pyx_n_s_spanning_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1396, __pyx_n_s_spanning_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sphere);
  __Pyx_GIVEREF(__pyx_n_s_sphere);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1397, __pyx_n_s_sphere)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_splice);
  __Pyx_GIVEREF(__pyx_n_s_splice);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1398, __pyx_n_s_splice)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_spline);
  __Pyx_GIVEREF(__pyx_n_s_spline);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1399, __pyx_n_s_spline)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_split);
  __Pyx_GIVEREF(__pyx_n_s_split);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1400, __pyx_n_s_split)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_spring);
  __Pyx_GIVEREF(__pyx_n_s_spring);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1401, __pyx_n_s_spring)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sq);
  __Pyx_GIVEREF(__pyx_n_s_sq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1402, __pyx_n_s_sq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sqrfree);
  __Pyx_GIVEREF(__pyx_n_s_sqrfree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1403, __pyx_n_s_sqrfree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sqrt);
  __Pyx_GIVEREF(__pyx_n_s_sqrt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1404, __pyx_n_s_sqrt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_square);
  __Pyx_GIVEREF(__pyx_n_s_square);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1405, __pyx_n_s_square)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_square_point);
  __Pyx_GIVEREF(__pyx_n_s_square_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1406, __pyx_n_s_square_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_srand);
  __Pyx_GIVEREF(__pyx_n_s_srand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1407, __pyx_n_s_srand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sst);
  __Pyx_GIVEREF(__pyx_n_s_sst);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1408, __pyx_n_s_sst)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sst_in);
  __Pyx_GIVEREF(__pyx_n_s_sst_in);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1409, __pyx_n_s_sst_in)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_st_ordering);
  __Pyx_GIVEREF(__pyx_n_s_st_ordering);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1410, __pyx_n_s_st_ordering)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_star_graph);
  __Pyx_GIVEREF(__pyx_n_s_star_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1411, __pyx_n_s_star_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_star_point);
  __Pyx_GIVEREF(__pyx_n_s_star_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1412, __pyx_n_s_star_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_stdDev);
  __Pyx_GIVEREF(__pyx_n_s_stdDev);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1413, __pyx_n_s_stdDev)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_stddev);
  __Pyx_GIVEREF(__pyx_n_s_stddev);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1414, __pyx_n_s_stddev)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_stddevp);
  __Pyx_GIVEREF(__pyx_n_s_stddevp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1415, __pyx_n_s_stddevp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_steffenson_solver);
  __Pyx_GIVEREF(__pyx_n_s_steffenson_solver);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1416, __pyx_n_s_steffenson_solver)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_stereo2mono);
  __Pyx_GIVEREF(__pyx_n_s_stereo2mono);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1417, __pyx_n_s_stereo2mono)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_stft);
  __Pyx_GIVEREF(__pyx_n_s_stft);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1418, __pyx_n_s_stft)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_str);
  __Pyx_GIVEREF(__pyx_n_s_str);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1419, __pyx_n_s_str)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_strip);
  __Pyx_GIVEREF(__pyx_n_s_strip);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1420, __pyx_n_s_strip)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_strongly_connected_components);
  __Pyx_GIVEREF(__pyx_n_s_strongly_connected_components);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1421, __pyx_n_s_strongly_connected_components)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_student);
  __Pyx_GIVEREF(__pyx_n_s_student);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1422, __pyx_n_s_student)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_student_cdf);
  __Pyx_GIVEREF(__pyx_n_s_student_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1423, __pyx_n_s_student_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_student_icdf);
  __Pyx_GIVEREF(__pyx_n_s_student_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1424, __pyx_n_s_student_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_studentd);
  __Pyx_GIVEREF(__pyx_n_s_studentd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1425, __pyx_n_s_studentd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_studentt);
  __Pyx_GIVEREF(__pyx_n_s_studentt);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1426, __pyx_n_s_studentt)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sturm);
  __Pyx_GIVEREF(__pyx_n_s_sturm);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1427, __pyx_n_s_sturm)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sturmab);
  __Pyx_GIVEREF(__pyx_n_s_sturmab);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1428, __pyx_n_s_sturmab)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sturmseq);
  __Pyx_GIVEREF(__pyx_n_s_sturmseq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1429, __pyx_n_s_sturmseq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_style);
  __Pyx_GIVEREF(__pyx_n_s_style);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1430, __pyx_n_s_style)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subMat);
  __Pyx_GIVEREF(__pyx_n_s_subMat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1431, __pyx_n_s_subMat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subdivide_edges);
  __Pyx_GIVEREF(__pyx_n_s_subdivide_edges);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1432, __pyx_n_s_subdivide_edges)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subgraph);
  __Pyx_GIVEREF(__pyx_n_s_subgraph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1433, __pyx_n_s_subgraph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subs);
  __Pyx_GIVEREF(__pyx_n_s_subs);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1434, __pyx_n_s_subs)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subsop);
  __Pyx_GIVEREF(__pyx_n_s_subsop);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1435, __pyx_n_s_subsop)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subst);
  __Pyx_GIVEREF(__pyx_n_s_subst);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1436, __pyx_n_s_subst)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_substituer);
  __Pyx_GIVEREF(__pyx_n_s_substituer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1437, __pyx_n_s_substituer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_subtype);
  __Pyx_GIVEREF(__pyx_n_s_subtype);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1438, __pyx_n_s_subtype)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sum);
  __Pyx_GIVEREF(__pyx_n_s_sum);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1439, __pyx_n_s_sum)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sum_riemann);
  __Pyx_GIVEREF(__pyx_n_s_sum_riemann);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1440, __pyx_n_s_sum_riemann)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_suppress);
  __Pyx_GIVEREF(__pyx_n_s_suppress);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1441, __pyx_n_s_suppress)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_surd);
  __Pyx_GIVEREF(__pyx_n_s_surd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1442, __pyx_n_s_surd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_svd);
  __Pyx_GIVEREF(__pyx_n_s_svd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1443, __pyx_n_s_svd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_swapcol);
  __Pyx_GIVEREF(__pyx_n_s_swapcol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1444, __pyx_n_s_swapcol)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_swaprow);
  __Pyx_GIVEREF(__pyx_n_s_swaprow);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1445, __pyx_n_s_swaprow)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_switch_axes);
  __Pyx_GIVEREF(__pyx_n_s_switch_axes);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1446, __pyx_n_s_switch_axes)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_sylvester);
  __Pyx_GIVEREF(__pyx_n_s_sylvester);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1447, __pyx_n_s_sylvester)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_symb2poly);
  __Pyx_GIVEREF(__pyx_n_s_symb2poly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1448, __pyx_n_s_symb2poly)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_symbol);
  __Pyx_GIVEREF(__pyx_n_s_symbol);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1449, __pyx_n_s_symbol)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_symbol_array);
  __Pyx_GIVEREF(__pyx_n_s_symbol_array);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1450, __pyx_n_s_symbol_array)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_syst2mat);
  __Pyx_GIVEREF(__pyx_n_s_syst2mat);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1451, __pyx_n_s_syst2mat)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tCollect);
  __Pyx_GIVEREF(__pyx_n_s_tCollect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1452, __pyx_n_s_tCollect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tExpand);
  __Pyx_GIVEREF(__pyx_n_s_tExpand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1453, __pyx_n_s_tExpand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_table);
  __Pyx_GIVEREF(__pyx_n_s_table);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1454, __pyx_n_s_table)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tablefunc);
  __Pyx_GIVEREF(__pyx_n_s_tablefunc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1455, __pyx_n_s_tablefunc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tableseq);
  __Pyx_GIVEREF(__pyx_n_s_tableseq);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1456, __pyx_n_s_tableseq)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tabsign);
  __Pyx_GIVEREF(__pyx_n_s_tabsign);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1457, __pyx_n_s_tabsign)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tabvar);
  __Pyx_GIVEREF(__pyx_n_s_tabvar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1458, __pyx_n_s_tabvar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tail);
  __Pyx_GIVEREF(__pyx_n_s_tail);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1459, __pyx_n_s_tail)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tan);
  __Pyx_GIVEREF(__pyx_n_s_tan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1460, __pyx_n_s_tan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tan2cossin2);
  __Pyx_GIVEREF(__pyx_n_s_tan2cossin2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1461, __pyx_n_s_tan2cossin2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tan2sincos);
  __Pyx_GIVEREF(__pyx_n_s_tan2sincos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1462, __pyx_n_s_tan2sincos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tan2sincos2);
  __Pyx_GIVEREF(__pyx_n_s_tan2sincos2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1463, __pyx_n_s_tan2sincos2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tangent);
  __Pyx_GIVEREF(__pyx_n_s_tangent);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1464, __pyx_n_s_tangent)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tangente);
  __Pyx_GIVEREF(__pyx_n_s_tangente);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1465, __pyx_n_s_tangente)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tanh);
  __Pyx_GIVEREF(__pyx_n_s_tanh);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1466, __pyx_n_s_tanh)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tar);
  __Pyx_GIVEREF(__pyx_n_s_tar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1467, __pyx_n_s_tar)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_taux_accroissement);
  __Pyx_GIVEREF(__pyx_n_s_taux_accroissement);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1468, __pyx_n_s_taux_accroissement)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_taylor);
  __Pyx_GIVEREF(__pyx_n_s_taylor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1469, __pyx_n_s_taylor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tchebyshev1);
  __Pyx_GIVEREF(__pyx_n_s_tchebyshev1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1470, __pyx_n_s_tchebyshev1)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tchebyshev2);
  __Pyx_GIVEREF(__pyx_n_s_tchebyshev2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1471, __pyx_n_s_tchebyshev2)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tcoeff);
  __Pyx_GIVEREF(__pyx_n_s_tcoeff);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1472, __pyx_n_s_tcoeff)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tcollect);
  __Pyx_GIVEREF(__pyx_n_s_tcollect);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1473, __pyx_n_s_tcollect)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tdeg);
  __Pyx_GIVEREF(__pyx_n_s_tdeg);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1474, __pyx_n_s_tdeg)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_teal);
  __Pyx_GIVEREF(__pyx_n_s_teal);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1475, __pyx_n_s_teal)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tensor_product);
  __Pyx_GIVEREF(__pyx_n_s_tensor_product);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1476, __pyx_n_s_tensor_product)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tetrahedron);
  __Pyx_GIVEREF(__pyx_n_s_tetrahedron);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1477, __pyx_n_s_tetrahedron)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_texpand);
  __Pyx_GIVEREF(__pyx_n_s_texpand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1478, __pyx_n_s_texpand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_thickness);
  __Pyx_GIVEREF(__pyx_n_s_thickness);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1479, __pyx_n_s_thickness)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_threshold);
  __Pyx_GIVEREF(__pyx_n_s_threshold);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1480, __pyx_n_s_threshold)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_throw);
  __Pyx_GIVEREF(__pyx_n_s_throw);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1481, __pyx_n_s_throw)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_title);
  __Pyx_GIVEREF(__pyx_n_s_title);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1482, __pyx_n_s_title)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_titre);
  __Pyx_GIVEREF(__pyx_n_s_titre);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1483, __pyx_n_s_titre)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tlin);
  __Pyx_GIVEREF(__pyx_n_s_tlin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1484, __pyx_n_s_tlin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tonnetz);
  __Pyx_GIVEREF(__pyx_n_s_tonnetz);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1485, __pyx_n_s_tonnetz)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_topologic_sort);
  __Pyx_GIVEREF(__pyx_n_s_topologic_sort);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1486, __pyx_n_s_topologic_sort)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_topological_sort);
  __Pyx_GIVEREF(__pyx_n_s_topological_sort);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1487, __pyx_n_s_topological_sort)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_topology);
  __Pyx_GIVEREF(__pyx_n_s_topology);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1488, __pyx_n_s_topology)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_torus_grid_graph);
  __Pyx_GIVEREF(__pyx_n_s_torus_grid_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1489, __pyx_n_s_torus_grid_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_total_degree);
  __Pyx_GIVEREF(__pyx_n_s_total_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1490, __pyx_n_s_total_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tourne_droite);
  __Pyx_GIVEREF(__pyx_n_s_tourne_droite);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1491, __pyx_n_s_tourne_droite)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tourne_gauche);
  __Pyx_GIVEREF(__pyx_n_s_tourne_gauche);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1492, __pyx_n_s_tourne_gauche)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tpsolve);
  __Pyx_GIVEREF(__pyx_n_s_tpsolve);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1493, __pyx_n_s_tpsolve)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trace);
  __Pyx_GIVEREF(__pyx_n_s_trace);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1494, __pyx_n_s_trace)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trail);
  __Pyx_GIVEREF(__pyx_n_s_trail);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1495, __pyx_n_s_trail)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trail2edges);
  __Pyx_GIVEREF(__pyx_n_s_trail2edges);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1496, __pyx_n_s_trail2edges)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_train);
  __Pyx_GIVEREF(__pyx_n_s_train);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1497, __pyx_n_s_train)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trames);
  __Pyx_GIVEREF(__pyx_n_s_trames);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1498, __pyx_n_s_trames)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tran);
  __Pyx_GIVEREF(__pyx_n_s_tran);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1499, __pyx_n_s_tran)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_transitive_closure);
  __Pyx_GIVEREF(__pyx_n_s_transitive_closure);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1500, __pyx_n_s_transitive_closure)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_translation);
  __Pyx_GIVEREF(__pyx_n_s_translation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1501, __pyx_n_s_translation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_transpose);
  __Pyx_GIVEREF(__pyx_n_s_transpose);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1502, __pyx_n_s_transpose)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trapeze);
  __Pyx_GIVEREF(__pyx_n_s_trapeze);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1503, __pyx_n_s_trapeze)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trapezoid);
  __Pyx_GIVEREF(__pyx_n_s_trapezoid);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1504, __pyx_n_s_trapezoid)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_traveling_salesman);
  __Pyx_GIVEREF(__pyx_n_s_traveling_salesman);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1505, __pyx_n_s_traveling_salesman)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tree);
  __Pyx_GIVEREF(__pyx_n_s_tree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1506, __pyx_n_s_tree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tree_height);
  __Pyx_GIVEREF(__pyx_n_s_tree_height);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1507, __pyx_n_s_tree_height)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tri);
  __Pyx_GIVEREF(__pyx_n_s_tri);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1508, __pyx_n_s_tri)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_triangle);
  __Pyx_GIVEREF(__pyx_n_s_triangle);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1509, __pyx_n_s_triangle)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_triangle_paper);
  __Pyx_GIVEREF(__pyx_n_s_triangle_paper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1510, __pyx_n_s_triangle_paper)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_triangle_plein);
  __Pyx_GIVEREF(__pyx_n_s_triangle_plein);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1511, __pyx_n_s_triangle_plein)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_triangle_point);
  __Pyx_GIVEREF(__pyx_n_s_triangle_point);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1512, __pyx_n_s_triangle_point)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_triangle_window);
  __Pyx_GIVEREF(__pyx_n_s_triangle_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1513, __pyx_n_s_triangle_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trig2exp);
  __Pyx_GIVEREF(__pyx_n_s_trig2exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1514, __pyx_n_s_trig2exp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trigcos);
  __Pyx_GIVEREF(__pyx_n_s_trigcos);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1515, __pyx_n_s_trigcos)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trigexpand);
  __Pyx_GIVEREF(__pyx_n_s_trigexpand);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1516, __pyx_n_s_trigexpand)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_triginterp);
  __Pyx_GIVEREF(__pyx_n_s_triginterp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1517, __pyx_n_s_triginterp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trigsimplify);
  __Pyx_GIVEREF(__pyx_n_s_trigsimplify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1518, __pyx_n_s_trigsimplify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trigsin);
  __Pyx_GIVEREF(__pyx_n_s_trigsin);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1519, __pyx_n_s_trigsin)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trigtan);
  __Pyx_GIVEREF(__pyx_n_s_trigtan);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1520, __pyx_n_s_trigtan)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trim);
  __Pyx_GIVEREF(__pyx_n_s_trim);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1521, __pyx_n_s_trim)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trn);
  __Pyx_GIVEREF(__pyx_n_s_trn);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1522, __pyx_n_s_trn)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_true);
  __Pyx_GIVEREF(__pyx_n_s_true);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1523, __pyx_n_s_true)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_trunc);
  __Pyx_GIVEREF(__pyx_n_s_trunc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1524, __pyx_n_s_trunc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_truncate);
  __Pyx_GIVEREF(__pyx_n_s_truncate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1525, __pyx_n_s_truncate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_truncate_graph);
  __Pyx_GIVEREF(__pyx_n_s_truncate_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1526, __pyx_n_s_truncate_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tsimplify);
  __Pyx_GIVEREF(__pyx_n_s_tsimplify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1527, __pyx_n_s_tsimplify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tstep);
  __Pyx_GIVEREF(__pyx_n_s_tstep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1528, __pyx_n_s_tstep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tuer);
  __Pyx_GIVEREF(__pyx_n_s_tuer);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1529, __pyx_n_s_tuer)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tukey_window);
  __Pyx_GIVEREF(__pyx_n_s_tukey_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1530, __pyx_n_s_tukey_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_tutte_polynomial);
  __Pyx_GIVEREF(__pyx_n_s_tutte_polynomial);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1531, __pyx_n_s_tutte_polynomial)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_two_edge_connected_components);
  __Pyx_GIVEREF(__pyx_n_s_two_edge_connected_components);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1532, __pyx_n_s_two_edge_connected_components)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ufactor);
  __Pyx_GIVEREF(__pyx_n_s_ufactor);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1533, __pyx_n_s_ufactor)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ugamma);
  __Pyx_GIVEREF(__pyx_n_s_ugamma);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1534, __pyx_n_s_ugamma)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_unapply);
  __Pyx_GIVEREF(__pyx_n_s_unapply);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1535, __pyx_n_s_unapply)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_unarchive);
  __Pyx_GIVEREF(__pyx_n_s_unarchive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1536, __pyx_n_s_unarchive)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_undef);
  __Pyx_GIVEREF(__pyx_n_s_undef);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1537, __pyx_n_s_undef)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_underlying_graph);
  __Pyx_GIVEREF(__pyx_n_s_underlying_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1538, __pyx_n_s_underlying_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_unfactored);
  __Pyx_GIVEREF(__pyx_n_s_unfactored);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1539, __pyx_n_s_unfactored)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_uniform);
  __Pyx_GIVEREF(__pyx_n_s_uniform);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1540, __pyx_n_s_uniform)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_uniform_cdf);
  __Pyx_GIVEREF(__pyx_n_s_uniform_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1541, __pyx_n_s_uniform_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_uniform_icdf);
  __Pyx_GIVEREF(__pyx_n_s_uniform_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1542, __pyx_n_s_uniform_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_uniformd);
  __Pyx_GIVEREF(__pyx_n_s_uniformd);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1543, __pyx_n_s_uniformd)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_uniformd_cdf);
  __Pyx_GIVEREF(__pyx_n_s_uniformd_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1544, __pyx_n_s_uniformd_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_uniformd_icdf);
  __Pyx_GIVEREF(__pyx_n_s_uniformd_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1545, __pyx_n_s_uniformd_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_unitV);
  __Pyx_GIVEREF(__pyx_n_s_unitV);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1546, __pyx_n_s_unitV)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_unquote);
  __Pyx_GIVEREF(__pyx_n_s_unquote);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1547, __pyx_n_s_unquote)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_upper);
  __Pyx_GIVEREF(__pyx_n_s_upper);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1548, __pyx_n_s_upper)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_user_operator);
  __Pyx_GIVEREF(__pyx_n_s_user_operator);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1549, __pyx_n_s_user_operator)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_usimplify);
  __Pyx_GIVEREF(__pyx_n_s_usimplify);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1550, __pyx_n_s_usimplify)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ustep);
  __Pyx_GIVEREF(__pyx_n_s_ustep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1551, __pyx_n_s_ustep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_valuation);
  __Pyx_GIVEREF(__pyx_n_s_valuation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1552, __pyx_n_s_valuation)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vandermonde);
  __Pyx_GIVEREF(__pyx_n_s_vandermonde);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1553, __pyx_n_s_vandermonde)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_variables_are_files);
  __Pyx_GIVEREF(__pyx_n_s_variables_are_files);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1554, __pyx_n_s_variables_are_files)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_variance);
  __Pyx_GIVEREF(__pyx_n_s_variance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1555, __pyx_n_s_variance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_version);
  __Pyx_GIVEREF(__pyx_n_s_version);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1556, __pyx_n_s_version)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertex_connectivity);
  __Pyx_GIVEREF(__pyx_n_s_vertex_connectivity);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1557, __pyx_n_s_vertex_connectivity)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertex_cover_number);
  __Pyx_GIVEREF(__pyx_n_s_vertex_cover_number);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1558, __pyx_n_s_vertex_cover_number)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertex_degree);
  __Pyx_GIVEREF(__pyx_n_s_vertex_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1559, __pyx_n_s_vertex_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertex_distance);
  __Pyx_GIVEREF(__pyx_n_s_vertex_distance);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1560, __pyx_n_s_vertex_distance)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertex_in_degree);
  __Pyx_GIVEREF(__pyx_n_s_vertex_in_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1561, __pyx_n_s_vertex_in_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertex_out_degree);
  __Pyx_GIVEREF(__pyx_n_s_vertex_out_degree);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1562, __pyx_n_s_vertex_out_degree)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertices);
  __Pyx_GIVEREF(__pyx_n_s_vertices);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1563, __pyx_n_s_vertices)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertices_abc);
  __Pyx_GIVEREF(__pyx_n_s_vertices_abc);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1564, __pyx_n_s_vertices_abc)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vertices_abca);
  __Pyx_GIVEREF(__pyx_n_s_vertices_abca);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1565, __pyx_n_s_vertices_abca)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_violet);
  __Pyx_GIVEREF(__pyx_n_s_violet);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1566, __pyx_n_s_violet)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vpotential);
  __Pyx_GIVEREF(__pyx_n_s_vpotential);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1567, __pyx_n_s_vpotential)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_vstep);
  __Pyx_GIVEREF(__pyx_n_s_vstep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1568, __pyx_n_s_vstep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_web_graph);
  __Pyx_GIVEREF(__pyx_n_s_web_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1569, __pyx_n_s_web_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibull);
  __Pyx_GIVEREF(__pyx_n_s_weibull);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1570, __pyx_n_s_weibull)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibull_cdf);
  __Pyx_GIVEREF(__pyx_n_s_weibull_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1571, __pyx_n_s_weibull_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibull_icdf);
  __Pyx_GIVEREF(__pyx_n_s_weibull_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1572, __pyx_n_s_weibull_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibulld);
  __Pyx_GIVEREF(__pyx_n_s_weibulld);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1573, __pyx_n_s_weibulld)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibulld_cdf);
  __Pyx_GIVEREF(__pyx_n_s_weibulld_cdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1574, __pyx_n_s_weibulld_cdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibulld_icdf);
  __Pyx_GIVEREF(__pyx_n_s_weibulld_icdf);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1575, __pyx_n_s_weibulld_icdf)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weibullvariate);
  __Pyx_GIVEREF(__pyx_n_s_weibullvariate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1576, __pyx_n_s_weibullvariate)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weight_decay);
  __Pyx_GIVEREF(__pyx_n_s_weight_decay);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1577, __pyx_n_s_weight_decay)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weight_matrix);
  __Pyx_GIVEREF(__pyx_n_s_weight_matrix);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1578, __pyx_n_s_weight_matrix)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weighted);
  __Pyx_GIVEREF(__pyx_n_s_weighted);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1579, __pyx_n_s_weighted)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weights);
  __Pyx_GIVEREF(__pyx_n_s_weights);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1580, __pyx_n_s_weights)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_welch_window);
  __Pyx_GIVEREF(__pyx_n_s_welch_window);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1581, __pyx_n_s_welch_window)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_wheel_graph);
  __Pyx_GIVEREF(__pyx_n_s_wheel_graph);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1582, __pyx_n_s_wheel_graph)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_widget_size);
  __Pyx_GIVEREF(__pyx_n_s_widget_size);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1583, __pyx_n_s_widget_size)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_wilcoxonp);
  __Pyx_GIVEREF(__pyx_n_s_wilcoxonp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1584, __pyx_n_s_wilcoxonp)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_wilcoxons);
  __Pyx_GIVEREF(__pyx_n_s_wilcoxons);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1585, __pyx_n_s_wilcoxons)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_wilcoxont);
  __Pyx_GIVEREF(__pyx_n_s_wilcoxont);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1586, __pyx_n_s_wilcoxont)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_writergb);
  __Pyx_GIVEREF(__pyx_n_s_writergb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1587, __pyx_n_s_writergb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_writewav);
  __Pyx_GIVEREF(__pyx_n_s_writewav);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1588, __pyx_n_s_writewav)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_xcas_mode);
  __Pyx_GIVEREF(__pyx_n_s_xcas_mode);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1589, __pyx_n_s_xcas_mode)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_xml_print);
  __Pyx_GIVEREF(__pyx_n_s_xml_print);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1590, __pyx_n_s_xml_print)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_xstep);
  __Pyx_GIVEREF(__pyx_n_s_xstep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1591, __pyx_n_s_xstep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_xyz2rgb);
  __Pyx_GIVEREF(__pyx_n_s_xyz2rgb);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1592, __pyx_n_s_xyz2rgb)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_xyztrange);
  __Pyx_GIVEREF(__pyx_n_s_xyztrange);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1593, __pyx_n_s_xyztrange)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ystep);
  __Pyx_GIVEREF(__pyx_n_s_ystep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1594, __pyx_n_s_ystep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_zeros);
  __Pyx_GIVEREF(__pyx_n_s_zeros);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1595, __pyx_n_s_zeros)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_znorder);
  __Pyx_GIVEREF(__pyx_n_s_znorder);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1596, __pyx_n_s_znorder)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_znprimroot);
  __Pyx_GIVEREF(__pyx_n_s_znprimroot);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1597, __pyx_n_s_znprimroot)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_zstep);
  __Pyx_GIVEREF(__pyx_n_s_zstep);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1598, __pyx_n_s_zstep)) __PYX_ERR(5, 10, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_ztrans);
  __Pyx_GIVEREF(__pyx_n_s_ztrans);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1599, __pyx_n_s_ztrans)) __PYX_ERR(5, 10, __pyx_L1_error);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mostkeywords, __pyx_t_2) < 0) __PYX_ERR(5, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1910
 * #############################################################
 * include 'keywords.pxi'
 * GiacMethods={}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GiacMethods, __pyx_t_2) < 0) __PYX_ERR(0, 1910, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1914
 * 
 * 
 * __all__=['giac','Pygen','giacsettings','I','htmlhelp','qcas','loadgiacgen']+mostkeywords+nonevaluable             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyList_New(7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_giac);
  __Pyx_GIVEREF(__pyx_n_s_giac);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_giac)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_Pygen);
  __Pyx_GIVEREF(__pyx_n_s_Pygen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_Pygen)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_giacsettings);
  __Pyx_GIVEREF(__pyx_n_s_giacsettings);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_giacsettings)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_I);
  __Pyx_GIVEREF(__pyx_n_s_I);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_I)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_htmlhelp);
  __Pyx_GIVEREF(__pyx_n_s_htmlhelp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_htmlhelp)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_qcas);
  __Pyx_GIVEREF(__pyx_n_s_qcas);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_qcas)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_loadgiacgen);
  __Pyx_GIVEREF(__pyx_n_s_loadgiacgen);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_s_loadgiacgen)) __PYX_ERR(0, 1914, __pyx_L1_error);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_mostkeywords); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_nonevaluable); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_all, __pyx_t_2) < 0) __PYX_ERR(0, 1914, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1921
 * #################################################################
 * 
 * class ThreadedPygen(Pygen):             # <<<<<<<<<<<<<<
 *    """
 *    Use this subclass of to call your objects with the threadeval method.
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen);
  __Pyx_GIVEREF((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen))) __PYX_ERR(0, 1921, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_5, __pyx_t_3, __pyx_n_s_ThreadedPygen, __pyx_n_s_ThreadedPygen, (PyObject *) NULL, __pyx_n_s_giacpy_giacpy, __pyx_kp_s_Use_this_subclass_of_to_call_yo); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_3 != __pyx_t_2) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_2) < 0))) __PYX_ERR(0, 1921, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1927
 *    This class is used by GiacFunction
 *    """
 *    def __call__(self, *args):             # <<<<<<<<<<<<<<
 *       return self.threadeval(*args)
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_13ThreadedPygen_1__call__, 0, __pyx_n_s_ThreadedPygen___call, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1701)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_call, __pyx_t_2) < 0) __PYX_ERR(0, 1927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":1921
 * #################################################################
 * 
 * class ThreadedPygen(Pygen):             # <<<<<<<<<<<<<<
 *    """
 *    Use this subclass of to call your objects with the threadeval method.
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(__pyx_t_5, __pyx_n_s_ThreadedPygen, __pyx_t_3, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ThreadedPygen, __pyx_t_2) < 0) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "giacpy/giacpy.pyx":1931
 * 
 * 
 * class GiacFunction:             # <<<<<<<<<<<<<<
 *    # docstring removed to show  self.__doc__  under IEP.
 * 
 */
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_GiacFunction, __pyx_n_s_GiacFunction, (PyObject *) NULL, __pyx_n_s_giacpy_giacpy, (PyObject *) NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "giacpy/giacpy.pyx":1934
 *    # docstring removed to show  self.__doc__  under IEP.
 * 
 *    def __init__(self,str s):             # <<<<<<<<<<<<<<
 * 
 *       directevalued=['assume', 'supposons', 'randseed', 'srand']
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_1__init__, 0, __pyx_n_s_GiacFunction___init, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1703)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_5) < 0) __PYX_ERR(0, 1934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1949
 * 
 * 
 *    def __call__(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen(*args)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_3__call__, 0, __pyx_n_s_GiacFunction___call, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1704)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_call, __pyx_t_5) < 0) __PYX_ERR(0, 1949, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1953
 * 
 * 
 *    def __repr__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__repr__()
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_5__repr__, 0, __pyx_n_s_GiacFunction___repr, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1705)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_repr, __pyx_t_5) < 0) __PYX_ERR(0, 1953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1957
 * 
 * 
 *    def __str__(self):             # <<<<<<<<<<<<<<
 *       return self.Pygen.__str__()
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_7__str__, 0, __pyx_n_s_GiacFunction___str, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1706)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_str_2, __pyx_t_5) < 0) __PYX_ERR(0, 1957, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1961
 * 
 * 
 *    def __add__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_9__add__, 0, __pyx_n_s_GiacFunction___add, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1708)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_add_2, __pyx_t_5) < 0) __PYX_ERR(0, 1961, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1969
 * 
 * 
 *    def __sub__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_11__sub__, 0, __pyx_n_s_GiacFunction___sub, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1709)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_sub, __pyx_t_5) < 0) __PYX_ERR(0, 1969, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1977
 * 
 * 
 *    def __mul__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_13__mul__, 0, __pyx_n_s_GiacFunction___mul, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1710)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_mul_2, __pyx_t_5) < 0) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1985
 * 
 * 
 *    def __div__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_15__div__, 0, __pyx_n_s_GiacFunction___div, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1711)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_div_2, __pyx_t_5) < 0) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1993
 * 
 * 
 *    def __truediv__(self,right):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_17__truediv__, 0, __pyx_n_s_GiacFunction___truediv, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1712)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_truediv, __pyx_t_5) < 0) __PYX_ERR(0, 1993, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2001
 * 
 * 
 *    def __pow__(self,right,ignored):             # <<<<<<<<<<<<<<
 *       if isinstance(right,GiacFunction):
 *          right=right.Pygen
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_19__pow__, 0, __pyx_n_s_GiacFunction___pow, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1714)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_pow_2, __pyx_t_5) < 0) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2009
 * 
 * 
 *    def __neg__(self):             # <<<<<<<<<<<<<<
 *       return -self.Pygen
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_21__neg__, 0, __pyx_n_s_GiacFunction___neg, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1715)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_neg, __pyx_t_5) < 0) __PYX_ERR(0, 2009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2013
 * 
 * 
 *    def diff(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.diff(args)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_23diff, 0, __pyx_n_s_GiacFunction_diff, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1716)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_diff, __pyx_t_5) < 0) __PYX_ERR(0, 2013, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2017
 * 
 * 
 *    def int(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.int(args)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_25int, 0, __pyx_n_s_GiacFunction_int, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1717)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_int, __pyx_t_5) < 0) __PYX_ERR(0, 2017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2021
 * 
 * 
 *    def plot(self,*args):             # <<<<<<<<<<<<<<
 *       return self.Pygen.plot(args)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_27plot, 0, __pyx_n_s_GiacFunction_plot, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1718)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_plot, __pyx_t_5) < 0) __PYX_ERR(0, 2021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2025
 * 
 * 
 *    def htmlhelp(self,str lang='en'):             # <<<<<<<<<<<<<<
 *       return self.Pygen.htmlhelp(lang)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_12GiacFunction_29htmlhelp, 0, __pyx_n_s_GiacFunction_htmlhelp, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1720)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__1641);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_htmlhelp, __pyx_t_5) < 0) __PYX_ERR(0, 2025, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":1931
 * 
 * 
 * class GiacFunction:             # <<<<<<<<<<<<<<
 *    # docstring removed to show  self.__doc__  under IEP.
 * 
 */
  __pyx_t_5 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_n_s_GiacFunction, __pyx_empty_tuple, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GiacFunction, __pyx_t_5) < 0) __PYX_ERR(0, 1931, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "giacpy/giacpy.pyx":2034
 * # Some convenient settings
 * #############################################################
 * Pygen('printpow(-1)').eval() ; # default power is ** instead of ^             # <<<<<<<<<<<<<<
 * Pygen('add_language(1)').eval() ; # Add the french keywords in the giac library language.
 * # FIXME: print I for sqrt(-1) instead of i
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__1721, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_eval); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "giacpy/giacpy.pyx":2035
 * #############################################################
 * Pygen('printpow(-1)').eval() ; # default power is ** instead of ^
 * Pygen('add_language(1)').eval() ; # Add the french keywords in the giac library language.             # <<<<<<<<<<<<<<
 * # FIXME: print I for sqrt(-1) instead of i
 * #GIAC_try_parse_i(False,context_ptr);
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_tuple__1722, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_eval); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "giacpy/giacpy.pyx":2040
 * 
 * 
 * for i in mostkeywords:             # <<<<<<<<<<<<<<
 *    #print i
 *    #tmp=Pygen(i)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_mostkeywords); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_5 = __pyx_t_3; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2040, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2040, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2040, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2040, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2040, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2040, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2040, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_8(__pyx_t_5);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2040, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_i, __pyx_t_3) < 0) __PYX_ERR(0, 2040, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":2043
 *    #print i
 *    #tmp=Pygen(i)
 *    tmp=GiacFunction(i)             # <<<<<<<<<<<<<<
 *    globals()[i]=tmp
 *    #GiacMethods[i]=tmp
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2043, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tmp, __pyx_t_3) < 0) __PYX_ERR(0, 2043, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":2044
 *    #tmp=Pygen(i)
 *    tmp=GiacFunction(i)
 *    globals()[i]=tmp             # <<<<<<<<<<<<<<
 *    #GiacMethods[i]=tmp
 *    GiacMethods[i]=tmp.Pygen
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_tmp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_Globals(); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely((PyObject_SetItem(__pyx_t_6, __pyx_t_2, __pyx_t_3) < 0))) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":2046
 *    globals()[i]=tmp
 *    #GiacMethods[i]=tmp
 *    GiacMethods[i]=tmp.Pygen             # <<<<<<<<<<<<<<
 * 
 * # We put the giac names that should not be exported to Python in moremethods.
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_tmp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2046, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_t_6, __pyx_t_2) < 0))) __PYX_ERR(0, 2046, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":2040
 * 
 * 
 * for i in mostkeywords:             # <<<<<<<<<<<<<<
 *    #print i
 *    #tmp=Pygen(i)
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "giacpy/giacpy.pyx":2049
 * 
 * # We put the giac names that should not be exported to Python in moremethods.
 * for i in moremethods:             # <<<<<<<<<<<<<<
 *    #tmp=Pygen(i)
 *    tmp=GiacFunction(i)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_moremethods); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
    __pyx_t_2 = __pyx_t_5; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2049, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2049, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2049, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2049, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2049, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_5); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2049, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2049, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_8(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2049, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_i, __pyx_t_5) < 0) __PYX_ERR(0, 2049, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":2051
 * for i in moremethods:
 *    #tmp=Pygen(i)
 *    tmp=GiacFunction(i)             # <<<<<<<<<<<<<<
 *    #GiacMethods[i]=tmp
 *    GiacMethods[i]=tmp.Pygen
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_GiacFunction); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_3};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tmp, __pyx_t_5) < 0) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "giacpy/giacpy.pyx":2053
 *    tmp=GiacFunction(i)
 *    #GiacMethods[i]=tmp
 *    GiacMethods[i]=tmp.Pygen             # <<<<<<<<<<<<<<
 * 
 * for i in nonevaluable:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_tmp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Pygen); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyObject_SetItem(__pyx_t_5, __pyx_t_3, __pyx_t_6) < 0))) __PYX_ERR(0, 2053, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "giacpy/giacpy.pyx":2049
 * 
 * # We put the giac names that should not be exported to Python in moremethods.
 * for i in moremethods:             # <<<<<<<<<<<<<<
 *    #tmp=Pygen(i)
 *    tmp=GiacFunction(i)
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "giacpy/giacpy.pyx":2055
 *    GiacMethods[i]=tmp.Pygen
 * 
 * for i in nonevaluable:             # <<<<<<<<<<<<<<
 * #   print i
 *    tmp=Pygen(i)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_nonevaluable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_6 = __pyx_t_2; __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2055, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_6))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2055, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2055, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2055, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2055, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2055, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2055, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_8(__pyx_t_6);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2055, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_i, __pyx_t_2) < 0) __PYX_ERR(0, 2055, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "giacpy/giacpy.pyx":2057
 * for i in nonevaluable:
 * #   print i
 *    tmp=Pygen(i)             # <<<<<<<<<<<<<<
 *    globals()[i]=tmp
 *    GiacMethods[i]=tmp
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2057, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6giacpy_6giacpy_Pygen), __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2057, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_tmp, __pyx_t_3) < 0) __PYX_ERR(0, 2057, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":2058
 * #   print i
 *    tmp=Pygen(i)
 *    globals()[i]=tmp             # <<<<<<<<<<<<<<
 *    GiacMethods[i]=tmp
 * ##
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_tmp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_t_5, __pyx_t_3) < 0))) __PYX_ERR(0, 2058, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":2059
 *    tmp=Pygen(i)
 *    globals()[i]=tmp
 *    GiacMethods[i]=tmp             # <<<<<<<<<<<<<<
 * ##
 * def moretests():
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_tmp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_GiacMethods); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely((PyObject_SetItem(__pyx_t_5, __pyx_t_2, __pyx_t_3) < 0))) __PYX_ERR(0, 2059, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "giacpy/giacpy.pyx":2055
 *    GiacMethods[i]=tmp.Pygen
 * 
 * for i in nonevaluable:             # <<<<<<<<<<<<<<
 * #   print i
 *    tmp=Pygen(i)
 */
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "giacpy/giacpy.pyx":2061
 *    GiacMethods[i]=tmp
 * ##
 * def moretests():             # <<<<<<<<<<<<<<
 *    """
 *      >>> from giacpy import giac
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_11moretests, 0, __pyx_n_s_moretests, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1723)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_moretests, __pyx_t_6) < 0) __PYX_ERR(0, 2061, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "giacpy/giacpy.pyx":2106
 * 
 * 
 * def loadgiacgen(str filename):             # <<<<<<<<<<<<<<
 *         """
 *           Open a file in giac compressed format to create a Pygen element.
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_13loadgiacgen, 0, __pyx_n_s_loadgiacgen, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1725)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_loadgiacgen, __pyx_t_6) < 0) __PYX_ERR(0, 2106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_GiacMethods_base(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6giacpy_6giacpy_15__pyx_unpickle_GiacMethods_base, 0, __pyx_n_s_pyx_unpickle_GiacMethods_base, NULL, __pyx_n_s_giacpy_giacpy, __pyx_d, ((PyObject *)__pyx_codeobj__1727)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_GiacMethods_base, __pyx_t_6) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "giacpy/giacpy.pyx":1
 * #*****************************************************************************             # <<<<<<<<<<<<<<
 * #    AUTHOR:  Han Frederic <frederic.han@imj-prg.fr>
 * #  2012
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(21); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_giac_line_163, __pyx_kp_u_This_function_evaluate_a_python) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___repr___line_877, __pyx_kp_u_vide_Pygen_giac_version_dpt_eit) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___getitem___line_913, __pyx_kp_u_Lists_of_10_6_integers_should_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___setitem___line_986, __pyx_kp_u_Set_the_value_of_a_coefficient) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___iter___line_1035, __pyx_kp_u_Pygen_lists_of_10_6_elements_sh) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___int___line_1059, __pyx_kp_u_Convert_a_giac_integer_type_Pyg) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___float___line_1078, __pyx_kp_u_Convert_a_giac_real_to_a_Python) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___radd___line_1192, __pyx_kp_u_Reverse_operator_d_giac_d_1_d_C) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___rsub___line_1248, __pyx_kp_u_Reverse_operator_d_giac_d_2_d_C) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___rmul___line_1286, __pyx_kp_u_Reverse_operator_d_giac_d_7_d_C) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___rtruediv___line_1337, __pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___rpow___line_1372, __pyx_kp_u_Reverse_operator_d_giac_d_7_d_C_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen___rmod___line_1410, __pyx_kp_u_Reverse_operator_7_giac_3_Calle) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen_save_line_1469, __pyx_kp_u_Archive_a_Pygen_element_to_a_fi) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen_htmlhelp_line_1498, __pyx_kp_u_Open_the_giac_html_detailled_he) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen_redim_line_1526, __pyx_kp_u_Increase_the_size_of_a_matrix_w) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_Pygen_qcas_line_1552, __pyx_kp_u_Send_a_giac_graphic_to_qcas_3D) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_htmlhelp_line_1849, __pyx_kp_u_Open_the_giac_html_detailled_he_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_qcas_line_1879, __pyx_kp_u_EXPERIMENTAL_Send_a_giac_comman) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_moretests_line_2061, __pyx_kp_u_from_giacpy_import_giac_giac_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_kp_u_loadgiacgen_line_2106, __pyx_kp_u_Open_a_file_in_giac_compressed) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_2, __pyx_t_6) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init giacpy.giacpy", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init giacpy.giacpy");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_ass_subscript) {
            int r;
            PyObject *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return -1;
            r = mm->mp_ass_subscript(o, key, v);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return sm->sq_ass_item(o, i, v);
        }
    }
#else
    if (is_list || !PyMapping_Check(o))
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            if (__Pyx_PyLong_IsZero(op1) == 1) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                Py_RETURN_FALSE;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc;
    __Pyx_PyThreadState_declare
    #ifdef __Pyx_StopAsyncIteration_USED
    int is_async_stopiteration = 0;
    #endif
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    cur_exc = PyErr_Occurred();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        #ifdef __Pyx_StopAsyncIteration_USED
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, __Pyx_PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else
        #endif
            return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(val);
    Py_XDECREF(tb);
    PyErr_SetString(PyExc_RuntimeError,
        #ifdef __Pyx_StopAsyncIteration_USED
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        #endif
        "generator raised StopIteration");
}

/* pybytes_as_double */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj) {
    PyObject *float_value;
#if PY_MAJOR_VERSION >= 3
    float_value = PyFloat_FromString(obj);
#else
    float_value = PyFloat_FromString(obj, 0);
#endif
    if (likely(float_value)) {
#if CYTHON_ASSUME_SAFE_MACROS
        double value = PyFloat_AS_DOUBLE(float_value);
#else
        double value = PyFloat_AsDouble(float_value);
#endif
        Py_DECREF(float_value);
        return value;
    }
    return (double)-1;
}
static const char* __Pyx__PyBytes_AsDouble_Copy(const char* start, char* buffer, Py_ssize_t length) {
    int last_was_punctuation = 1;
    Py_ssize_t i;
    for (i=0; i < length; i++) {
        char chr = start[i];
        int is_punctuation = (chr == '_') | (chr == '.') | (chr == 'e') | (chr == 'E');
        *buffer = chr;
        buffer += (chr != '_');
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyBytes_AsDouble_inf_nan(const char* start, Py_ssize_t length) {
    int matches = 1;
    char sign = start[0];
    int is_signed = (sign == '+') | (sign == '-');
    start += is_signed;
    length -= is_signed;
    switch (start[0]) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            matches &= (start[1] == 'a' || start[1] == 'A');
            matches &= (start[2] == 'n' || start[2] == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            matches &= (start[1] == 'n' || start[1] == 'N');
            matches &= (start[2] == 'f' || start[2] == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            matches &= (start[3] == 'i' || start[3] == 'I');
            matches &= (start[4] == 'n' || start[4] == 'N');
            matches &= (start[5] == 'i' || start[5] == 'I');
            matches &= (start[6] == 't' || start[6] == 'T');
            matches &= (start[7] == 'y' || start[7] == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static CYTHON_INLINE int __Pyx__PyBytes_AsDouble_IsSpace(char ch) {
    return (ch == 0x20) | !((ch < 0x9) | (ch > 0xd));
}
CYTHON_UNUSED static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length) {
    double value;
    Py_ssize_t i, digits;
    const char *last = start + length;
    char *end;
    while (__Pyx__PyBytes_AsDouble_IsSpace(*start))
        start++;
    while (start < last - 1 && __Pyx__PyBytes_AsDouble_IsSpace(last[-1]))
        last--;
    length = last - start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyBytes_AsDouble_inf_nan(start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    digits = 0;
    for (i=0; i < length; digits += start[i++] != '_');
    if (likely(digits == length)) {
        value = PyOS_string_to_double(start, &end, NULL);
    } else if (digits < 40) {
        char number[40];
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((digits + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}

/* pynumber_float */
static CYTHON_INLINE PyObject* __Pyx__PyNumber_Float(PyObject* obj) {
    double val;
    if (PyLong_CheckExact(obj)) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (likely(__Pyx_PyLong_IsCompact(obj))) {
            val = (double) __Pyx_PyLong_CompactValue(obj);
            goto no_error;
        }
#endif
        val = PyLong_AsDouble(obj);
    } else if (PyUnicode_CheckExact(obj)) {
        val = __Pyx_PyUnicode_AsDouble(obj);
    } else if (PyBytes_CheckExact(obj)) {
        val = __Pyx_PyBytes_AsDouble(obj);
    } else if (PyByteArray_CheckExact(obj)) {
        val = __Pyx_PyByteArray_AsDouble(obj);
    } else {
        return PyNumber_Float(obj);
    }
    if (unlikely(val == -1 && PyErr_Occurred())) {
        return NULL;
    }
#if CYTHON_USE_PYLONG_INTERNALS
no_error:
#endif
    return PyFloat_FromDouble(val);
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            if (unlikely(b == -1 && ((unsigned long)a) == 0-(unsigned long)a))
                return PyInt_Type.tp_as_number->nb_floor_divide(op1, op2);
            else {
                long q, r;
                q = a / b;
                r = a - q*b;
                q -= ((r != 0) & ((r ^ b) < 0));
                x = q;
            }
            return PyInt_FromLong(x);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_floor_divide(op1, op2);
            }
        }
                {
                    long q, r;
                    q = a / b;
                    r = a - q*b;
                    q -= ((r != 0) & ((r ^ b) < 0));
                    x = q;
                }
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                {
                    PY_LONG_LONG q, r;
                    q = lla / llb;
                    r = lla - q*llb;
                    q -= ((r != 0) & ((r ^ llb) < 0));
                    llx = q;
                }
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceFloorDivide : PyNumber_FloorDivide)(op1, op2);
}
#endif

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__8);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a - (unsigned long)b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return PyLong_FromLong(-intval);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
static int
__Pyx_unicode_modifiable(PyObject *unicode)
{
    if (Py_REFCNT(unicode) != 1)
        return 0;
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !(CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY)
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_0_11
#define __PYX_HAVE_RT_ImportType_3_0_11
static PyTypeObject *__Pyx_ImportType_3_0_11(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_11 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_11 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_11 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__14;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_MACROS
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc_2, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    return __Pyx_NewRef(__pyx_d);
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PY_LONG_LONG neg_one = (PY_LONG_LONG) -1, const_zero = (PY_LONG_LONG) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(PY_LONG_LONG) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (PY_LONG_LONG) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (PY_LONG_LONG) -1;
        val = __Pyx_PyInt_As_PY_LONG_LONG(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(PY_LONG_LONG) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) >= 2 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) (((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PY_LONG_LONG) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) >= 3 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) (((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PY_LONG_LONG) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) >= 4 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) (((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (PY_LONG_LONG) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(PY_LONG_LONG) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(PY_LONG_LONG) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(PY_LONG_LONG) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(PY_LONG_LONG) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) ((((((PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PY_LONG_LONG) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) ((((((((PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) (((PY_LONG_LONG)-1)*(((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PY_LONG_LONG) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT)) {
                            return (PY_LONG_LONG) ((((((((((PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (PY_LONG_LONG)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(PY_LONG_LONG) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(PY_LONG_LONG) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PY_LONG_LONG, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        PY_LONG_LONG val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (PY_LONG_LONG) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (PY_LONG_LONG) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (PY_LONG_LONG) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (PY_LONG_LONG) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(PY_LONG_LONG) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((PY_LONG_LONG) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(PY_LONG_LONG) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((PY_LONG_LONG) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((PY_LONG_LONG) 1) << (sizeof(PY_LONG_LONG) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (PY_LONG_LONG) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE short __Pyx_PyInt_As_short(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const short neg_one = (short) -1, const_zero = (short) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(short) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(short, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (short) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        short val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (short) -1;
        val = __Pyx_PyInt_As_short(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(short, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(short) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) >= 2 * PyLong_SHIFT)) {
                            return (short) (((((short)digits[1]) << PyLong_SHIFT) | (short)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(short) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) >= 3 * PyLong_SHIFT)) {
                            return (short) (((((((short)digits[2]) << PyLong_SHIFT) | (short)digits[1]) << PyLong_SHIFT) | (short)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(short) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) >= 4 * PyLong_SHIFT)) {
                            return (short) (((((((((short)digits[3]) << PyLong_SHIFT) | (short)digits[2]) << PyLong_SHIFT) | (short)digits[1]) << PyLong_SHIFT) | (short)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (short) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(short) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(short, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(short) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(short, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(short, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(short) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) - 1 > 2 * PyLong_SHIFT)) {
                            return (short) (((short)-1)*(((((short)digits[1]) << PyLong_SHIFT) | (short)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(short) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) - 1 > 2 * PyLong_SHIFT)) {
                            return (short) ((((((short)digits[1]) << PyLong_SHIFT) | (short)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(short) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) - 1 > 3 * PyLong_SHIFT)) {
                            return (short) (((short)-1)*(((((((short)digits[2]) << PyLong_SHIFT) | (short)digits[1]) << PyLong_SHIFT) | (short)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(short) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) - 1 > 3 * PyLong_SHIFT)) {
                            return (short) ((((((((short)digits[2]) << PyLong_SHIFT) | (short)digits[1]) << PyLong_SHIFT) | (short)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(short) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) - 1 > 4 * PyLong_SHIFT)) {
                            return (short) (((short)-1)*(((((((((short)digits[3]) << PyLong_SHIFT) | (short)digits[2]) << PyLong_SHIFT) | (short)digits[1]) << PyLong_SHIFT) | (short)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(short) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(short, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(short) - 1 > 4 * PyLong_SHIFT)) {
                            return (short) ((((((((((short)digits[3]) << PyLong_SHIFT) | (short)digits[2]) << PyLong_SHIFT) | (short)digits[1]) << PyLong_SHIFT) | (short)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(short) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(short, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(short) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(short, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        short val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (short) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (short) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (short) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (short) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(short) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((short) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(short) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((short) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((short) 1) << (sizeof(short) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (short) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to short");
    return (short) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to short");
    return (short) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_char(unsigned char value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const unsigned char neg_one = (unsigned char) -1, const_zero = (unsigned char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned char) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned char) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned char) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned char) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned char) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned char),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(unsigned char));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_signed_char(signed char value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const signed char neg_one = (signed char) -1, const_zero = (signed char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(signed char) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(signed char) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(signed char) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(signed char) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(signed char) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(signed char),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(signed char));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_kp_s__12);
    }
    return name;
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectCallMethod1 */
#if !(CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2)
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_GetMethod;
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* CoroutineBase */
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(PyObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body(self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject* gen, PyObject *retval) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval))
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    gen->is_running = 0;
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        Py_TYPE(gen)->tp_del(self);
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (likely(--self->ob_refcnt == 0)) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context)
{
    PyObject *frame = self->gi_frame;
    CYTHON_UNUSED_VAR(context);
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (unlikely(!module)) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) __Pyx_PyObject_GenericGetAttrNoDict},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    __pyx_GeneratorType_slots
};
#else
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_Generator_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_GeneratorType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
#endif
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s_pyx_capi);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s_pyx_capi, d) < 0)
            goto bad;
    }
    cobj = PyCapsule_New(p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
